/*
Most files in FFmpeg are under the GNU Lesser General Public License version 2.1
or later (LGPL v2.1+). Read the file COPYING.LGPLv2.1 for details. Some other
files have MIT/X11/BSD-style licenses. In combination the LGPL v2.1+ applies to
FFmpeg.

The source code used to build this file can be obtained at https://github.com/bgrins/videoconverter.js,
and in zip form at https://github.com/bgrins/videoconverter.js/archive/master.zip
*/

function ffmpeg_run(opts) {
  var isNode = typeof(exports) !== 'undefined';
  if (!isNode) {
    var Module = {
      'outputDirectory': 'output'
    };
    for (var i in opts) {
      Module[i] = opts[i];
    }
    var outputFilePath = Module['arguments'][Module['arguments'].length - 1];
    if (Module['arguments'].length > 2 && outputFilePath && outputFilePath.indexOf(".") > -1) {
      Module['arguments'][Module['arguments'].length - 1] = "output/" + outputFilePath;
    }
    Module['preRun'] = function() {
      FS.createFolder('/', Module['outputDirectory'], true, true);
      /* fileData / fileName is deprecated - please use file.name and file.data instead */
      if (Module['fileData']) {
        FS.createDataFile('/', Module['fileName'], Module['fileData'], true, true);
      }
      if (Module['files']) {
        Module['files'].forEach(function(file) {
          FS.createDataFile('/', file.name, file.data, true, true);
        });
      }
    };
    Module['postRun'] = function() {
      var handle = FS.analyzePath(Module['outputDirectory']);
      Module['return'] = getAllBuffers(handle);
    };
    function getAllBuffers(result) {
      var buffers = [];
      if (result && result.object && result.object.contents) {
        for (var i in result.object.contents) {
          if (result.object.contents.hasOwnProperty(i)) {
            buffers.push({
              name: i,
              data: new Uint8Array(result.object.contents[i].contents).buffer
            });
          }
        }
      }
      return buffers;
    }
  }
// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = eval('(function() { try { return Module || {} } catch(e) { return {} } })()');

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = function print(x) {
    process['stdout'].write(x + '\n');
  };
  if (!Module['printErr']) Module['printErr'] = function printErr(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function read(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };

  Module['readBinary'] = function readBinary(filename) { return Module['read'](filename, true) };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  Module['arguments'] = process['argv'].slice(2);

  module['exports'] = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }

  Module['readBinary'] = function readBinary(f) {
    return read(f, 'binary');
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  this['Module'] = Module;

  eval("if (typeof gc === 'function' && gc.toString().indexOf('[native code]') > 0) var gc = undefined"); // wipe out the SpiderMonkey shell 'gc' function, which can confuse closure (uses it as a minified name, and it is then initted to a non-falsey value unexpectedly)
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function printErr(x) {
      console.log(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WEB) {
    this['Module'] = Module;
  } else {
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}



// === Auto-generated preamble library stuff ===

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      return '(((' +target + ')+' + (quantum-1) + ')&' + -quantum + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?\{ ?[^}]* ?\}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (vararg) return 8;
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          if (Types.types[field]) {
            alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
          } else {
            alignSize = type.alignSize || QUANTUM_SIZE;
          }
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else if (field[0] === '<') {
        // vector type
        size = alignSize = Types.types[field].flatSize; // fully aligned
      } else if (field[0] === 'i') {
        // illegal integer field, that could not be legalized because it is an internal structure field
        // it is ok to have such fields, if we just use them as markers of field size and nothing more complex
        size = alignSize = parseInt(field.substr(1))/8;
        assert(size % 1 === 0, 'cannot handle non-byte-size field ' + field);
      } else {
        assert(false, 'invalid type for calculateStructAlignment');
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    if (type.name_ && type.name_[0] === '[') {
      // arrays have 2 elements, so we get the proper difference. then we scale here. that way we avoid
      // allocating a potentially huge array for [999999 x i8] etc.
      type.flatSize = parseInt(type.name_.substr(1))*type.flatSize/2;
    }
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  getAsmConst: function (code, numArgs) {
    // code is a constant string on the heap, so we can cache these
    if (!Runtime.asmConstCache) Runtime.asmConstCache = {};
    var func = Runtime.asmConstCache[code];
    if (func) return func;
    var args = [];
    for (var i = 0; i < numArgs; i++) {
      args.push(String.fromCharCode(36) + i); // $0, $1 etc
    }
    code = Pointer_stringify(code);
    if (code[0] === '"') {
      // tolerate EM_ASM("..code..") even though EM_ASM(..code..) is correct
      if (code.indexOf('"', 1) === code.length-1) {
        code = code.substr(1, code.length-2);
      } else {
        // something invalid happened, e.g. EM_ASM("..code($0)..", input)
        abort('invalid EM_ASM input |' + code + '|. Please use EM_ASM(..code..) (no quotes) or EM_ASM({ ..code($0).. }, input) (to input values)');
      }
    }
    return Runtime.asmConstCache[code] = eval('(function(' + args.join(',') + '){ ' + code + ' })'); // new Function does not allow upvars in node
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function dynCall_wrapper() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;

      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }

      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }

      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function processJSString(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+7)&-8); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = (((STATICTOP)+7)&-8); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = (((DYNAMICTOP)+7)&-8); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*(+4294967296))) : ((+((low>>>0)))+((+((high|0)))*(+4294967296)))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}


Module['Runtime'] = Runtime;









//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.

var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD, tempDouble, tempFloat;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      value = intArrayFromString(value);
      type = 'array';
    }
    if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}

// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;

// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;

// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module['allocate'] = allocate;

function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }

  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;

// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.
function UTF16ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
    if (codeUnit == 0)
      return str;
    ++i;
    // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
    str += String.fromCharCode(codeUnit);
  }
}
Module['UTF16ToString'] = UTF16ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF16LE form. The copy will require at most (str.length*2+1)*2 bytes of space in the HEAP.
function stringToUTF16(str, outPtr) {
  for(var i = 0; i < str.length; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[(((outPtr)+(i*2))>>1)]=codeUnit;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[(((outPtr)+(str.length*2))>>1)]=0;
}
Module['stringToUTF16'] = stringToUTF16;

// Given a pointer 'ptr' to a null-terminated UTF32LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.
function UTF32ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}
Module['UTF32ToString'] = UTF32ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF32LE form. The copy will require at most (str.length+1)*4 bytes of space in the HEAP,
// but can use less, since str.length does not return the number of characters in the string, but the number of UTF-16 code units in the string.
function stringToUTF32(str, outPtr) {
  var iChar = 0;
  for(var iCodeUnit = 0; iCodeUnit < str.length; ++iCodeUnit) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    var codeUnit = str.charCodeAt(iCodeUnit); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++iCodeUnit);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[(((outPtr)+(iChar*4))>>2)]=codeUnit;
    ++iChar;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[(((outPtr)+(iChar*4))>>2)]=0;
}
Module['stringToUTF32'] = stringToUTF32;

function demangle(func) {
  var i = 3;
  // params, etc.
  var basicTypes = {
    'v': 'void',
    'b': 'bool',
    'c': 'char',
    's': 'short',
    'i': 'int',
    'l': 'long',
    'f': 'float',
    'd': 'double',
    'w': 'wchar_t',
    'a': 'signed char',
    'h': 'unsigned char',
    't': 'unsigned short',
    'j': 'unsigned int',
    'm': 'unsigned long',
    'x': 'long long',
    'y': 'unsigned long long',
    'z': '...'
  };
  var subs = [];
  var first = true;
  function dump(x) {
    //return;
    if (x) Module.print(x);
    Module.print(func);
    var pre = '';
    for (var a = 0; a < i; a++) pre += ' ';
    Module.print (pre + '^');
  }
  function parseNested() {
    i++;
    if (func[i] === 'K') i++; // ignore const
    var parts = [];
    while (func[i] !== 'E') {
      if (func[i] === 'S') { // substitution
        i++;
        var next = func.indexOf('_', i);
        var num = func.substring(i, next) || 0;
        parts.push(subs[num] || '?');
        i = next+1;
        continue;
      }
      if (func[i] === 'C') { // constructor
        parts.push(parts[parts.length-1]);
        i += 2;
        continue;
      }
      var size = parseInt(func.substr(i));
      var pre = size.toString().length;
      if (!size || !pre) { i--; break; } // counter i++ below us
      var curr = func.substr(i + pre, size);
      parts.push(curr);
      subs.push(curr);
      i += pre + size;
    }
    i++; // skip E
    return parts;
  }
  function parse(rawList, limit, allowVoid) { // main parser
    limit = limit || Infinity;
    var ret = '', list = [];
    function flushList() {
      return '(' + list.join(', ') + ')';
    }
    var name;
    if (func[i] === 'N') {
      // namespaced N-E
      name = parseNested().join('::');
      limit--;
      if (limit === 0) return rawList ? [name] : name;
    } else {
      // not namespaced
      if (func[i] === 'K' || (first && func[i] === 'L')) i++; // ignore const and first 'L'
      var size = parseInt(func.substr(i));
      if (size) {
        var pre = size.toString().length;
        name = func.substr(i + pre, size);
        i += pre + size;
      }
    }
    first = false;
    if (func[i] === 'I') {
      i++;
      var iList = parse(true);
      var iRet = parse(true, 1, true);
      ret += iRet[0] + ' ' + name + '<' + iList.join(', ') + '>';
    } else {
      ret = name;
    }
    paramLoop: while (i < func.length && limit-- > 0) {
      //dump('paramLoop');
      var c = func[i++];
      if (c in basicTypes) {
        list.push(basicTypes[c]);
      } else {
        switch (c) {
          case 'P': list.push(parse(true, 1, true)[0] + '*'); break; // pointer
          case 'R': list.push(parse(true, 1, true)[0] + '&'); break; // reference
          case 'L': { // literal
            i++; // skip basic type
            var end = func.indexOf('E', i);
            var size = end - i;
            list.push(func.substr(i, size));
            i += size + 2; // size + 'EE'
            break;
          }
          case 'A': { // array
            var size = parseInt(func.substr(i));
            i += size.toString().length;
            if (func[i] !== '_') throw '?';
            i++; // skip _
            list.push(parse(true, 1, true)[0] + ' [' + size + ']');
            break;
          }
          case 'E': break paramLoop;
          default: ret += '?' + c; break paramLoop;
        }
      }
    }
    if (!allowVoid && list.length === 1 && list[0] === 'void') list = []; // avoid (void)
    return rawList ? list : ret + flushList();
  }
  try {
    // Special-case the entry point, since its name differs from other name mangling.
    if (func == 'Object._main' || func == '_main') {
      return 'main()';
    }
    if (typeof func === 'number') func = Pointer_stringify(func);
    if (func[0] !== '_') return func;
    if (func[1] !== '_') return func; // C function
    if (func[2] !== 'Z') return func;
    switch (func[3]) {
      case 'n': return 'operator new()';
      case 'd': return 'operator delete()';
    }
    return parse();
  } catch(e) {
    return func;
  }
}

function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}

function stackTrace() {
  var stack = new Error().stack;
  return stack ? demangleAll(stack) : '(no stack trace available)'; // Stack trace is not available at least on IE10 and Safari 6.
}

// Memory management

var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return (x+4095)&-4096;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk

function enlargeMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.');
}

var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 33554432;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;

var totalMemory = 4096;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2*TOTAL_STACK) {
  if (totalMemory < 16*1024*1024) {
    totalMemory *= 2;
  } else {
    totalMemory += 16*1024*1024
  }
}
if (totalMemory !== TOTAL_MEMORY) {
  Module.printErr('increasing TOTAL_MEMORY to ' + totalMemory + ' to be more reasonable');
  TOTAL_MEMORY = totalMemory;
}

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'JS engine does not provide full typed array support');

var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;

function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}

function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;

// Tools

// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr;
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=str.charCodeAt(i);
  }
  if (!dontAddNull) HEAP8[(((buffer)+(str.length))|0)]=0;
}
Module['writeAsciiToMemory'] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data


var memoryInitializer = null;

// === Body ===



STATIC_BASE = 8;

STATICTOP = STATIC_BASE + 9218304;


/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } });

















































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































var _stdout;
var _stdout=_stdout=allocate(1, "i32*", ALLOC_STATIC);


var _stderr;
var _stderr=_stderr=allocate(1, "i32*", ALLOC_STATIC);












































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































/* memory initializer */ allocate([0,9,17,18,12,40,27,7,35,57,29,30,58,38,53,47,1,2,24,11,19,48,20,14,42,50,22,37,59,31,60,55,8,3,32,4,26,41,13,21,49,43,15,44,52,39,61,62,16,10,25,5,33,34,6,28,56,36,23,51,45,46,54,63,0,0,0,0,0,0,0,0,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,0,0,0,0,0,0,0,0,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,0,0,0,0,0,0,0,0,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,10,0,0,0,1,0,0,0,2,0,0,0,128,2,128,2,157,2,224,1,196,2,98,1,236,2,1,1,24,3,198,0,248,2,143,0,40,3,101,0,4,3,72,0,224,1,157,2,25,2,25,2,86,2,160,1,149,2,60,1,207,2,250,0,195,2,185,0,0,3,134,0,233,2,97,0,98,1,196,2,160,1,86,2,232,1,232,1,52,2,132,1,122,2,61,1,130,2,241,0,204,2,179,0,194,2,132,0,1,1,236,2,60,1,149,2,132,1,52,2,213,1,213,1,31,2,139,1,59,2,55,1,143,2,238,0,148,2,180,0,198,0,24,3,250,0,207,2,61,1,122,2,139,1,31,2,213,1,213,1,251,1,124,1,85,2,43,1,104,2,231,0,161,0,87,3,206,0,20,3,10,1,198,2,84,1,111,2,155,1,36,2,199,1,199,1,36,2,110,1,64,2,32,1,122,0,204,3,159,0,146,3,211,0,74,3,20,1,246,2,85,1,170,2,133,1,72,2,227,1,227,1,8,2,134,1,110,0,148,4,144,0,83,4,193,0,4,4,254,0,164,3,61,1,78,3,110,1,219,2,202,1,99,2,243,1,243,1,64,1,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,6,0,0,0,7,0,0,0,35,0,0,0,0,0,0,0,4,0,0,0,44,1,0,0,33,0,0,0,5,0,0,0,43,1,0,0,70,0,0,0,80,0,0,0,76,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,98,0,0,0,100,0,0,0,102,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,14,0,0,0,13,0,0,0,12,0,0,0,34,0,0,0,255,255,255,255,219,16,138,255,0,0,0,0,208,3,0,0,192,3,0,0,176,3,0,0,160,3,0,0,0,0,0,0,0,0,0,0,0,0,252,255,4,0,240,255,16,0,220,255,36,0,176,255,4,0,250,255,20,0,236,255,46,0,210,255,94,0,162,255,0,0,254,255,4,0,250,255,8,0,244,255,12,0,244,255,0,0,254,255,2,0,250,255,6,0,244,255,12,0,244,255,192,252,32,0,24,232,31,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,192,252,32,0,24,25,31,0,136,107,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,252,32,0,32,227,29,0,144,118,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,252,32,0,144,31,29,0,16,206,28,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,252,32,0,224,202,35,0,96,118,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,252,32,0,136,28,35,0,184,215,34,0,8,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,136,28,35,0,0,156,34,0,144,95,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,136,28,35,0,16,40,34,0,8,248,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,136,28,35,0,0,207,33,0,160,167,33,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,136,28,35,0,32,138,33,0,0,97,33,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,32,138,33,0,0,35,33,0,0,0,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,138,33,0,216,229,32,0,176,202,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,138,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,203,31,0,108,0,0,0,224,3,0,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,12,0,0,0,15,0,0,0,20,0,0,0,25,0,0,0,34,0,0,0,46,0,0,0,64,0,0,0,82,0,0,0,94,0,0,0,103,0,0,0,108,0,0,0,113,0,0,0,116,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,32,17,17,9,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,3,0,0,0,8,0,0,0,2,0,0,0,3,0,0,0,1,0,0,0,7,0,0,0,6,0,0,0,3,0,0,0,5,0,0,0,2,0,0,0,14,0,0,0,13,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,13,0,0,0,24,0,0,0,4,0,0,0,11,0,0,0,4,0,0,0,28,0,0,0,25,0,0,0,4,0,0,0,6,0,0,0,6,0,0,0,26,0,0,0,48,0,0,0,5,0,0,0,22,0,0,0,8,0,0,0,56,0,0,0,50,0,0,0,5,0,0,0,12,0,0,0,12,0,0,0,52,0,0,0,96,0,0,0,6,0,0,0,44,0,0,0,16,0,0,0,112,0,0,0,100,0,0,0,6,0,0,0,24,0,0,0,24,0,0,0,104,0,0,0,192,0,0,0,7,0,0,0,88,0,0,0,32,0,0,0,224,0,0,0,200,0,0,0,7,0,0,0,48,0,0,0,48,0,0,0,208,0,0,0,128,1,0,0,8,0,0,0,176,0,0,0,64,0,0,0,192,1,0,0,144,1,0,0,8,0,0,0,96,0,0,0,96,0,0,0,160,1,0,0,0,3,0,0,9,0,0,0,96,1,0,0,128,0,0,0,128,3,0,0,32,3,0,0,9,0,0,0,192,0,0,0,192,0,0,0,64,3,0,0,0,6,0,0,10,0,0,0,192,2,0,0,0,1,0,0,0,7,0,0,64,6,0,0,10,0,0,0,128,1,0,0,128,1,0,0,128,6,0,0,0,12,0,0,11,0,0,0,128,5,0,0,0,2,0,0,0,14,0,0,128,12,0,0,11,0,0,0,0,3,0,0,0,3,0,0,0,13,0,0,0,24,0,0,12,0,0,0,0,11,0,0,0,4,0,0,0,28,0,0,0,25,0,0,12,0,0,0,0,6,0,0,0,6,0,0,0,26,0,0,0,48,0,0,13,0,0,0,0,22,0,0,0,8,0,0,0,56,0,0,0,50,0,0,13,0,0,0,0,12,0,0,0,12,0,0,0,52,0,0,0,96,0,0,14,0,0,0,0,44,0,0,0,16,0,0,0,112,0,0,0,100,0,0,14,0,0,0,0,24,0,0,0,24,0,0,0,104,0,0,0,192,0,0,15,0,0,0,0,88,0,0,0,32,0,0,0,224,0,0,0,200,0,0,15,0,0,0,0,48,0,0,0,48,0,0,0,208,0,0,0,128,1,0,16,0,0,0,0,176,0,0,0,64,0,0,0,192,1,0,0,144,1,0,16,0,0,0,0,96,0,0,0,96,0,0,0,160,1,0,0,0,3,0,17,0,0,0,0,96,1,0,0,128,0,0,0,128,3,0,0,32,3,0,17,0,0,0,0,192,0,0,0,192,0,0,0,64,3,0,0,0,6,0,18,0,0,0,0,192,2,0,0,0,1,0,0,0,7,0,0,64,6,0,18,0,0,0,0,128,1,0,0,128,1,0,0,128,6,0,0,0,12,0,19,0,0,0,0,128,5,0,0,0,2,0,0,0,14,0,0,128,12,0,19,0,0,0,0,0,3,0,0,0,3,0,0,0,13,0,0,0,24,0,20,0,0,0,0,0,11,0,0,0,4,0,0,0,28,0,0,0,25,0,20,0,0,0,0,0,6,0,0,0,6,0,0,0,26,0,0,0,48,0,21,0,0,0,0,0,22,0,0,0,8,0,0,0,56,0,0,0,50,0,21,0,0,0,0,0,12,0,0,0,12,0,0,0,52,0,0,0,96,0,22,0,0,0,0,0,44,0,0,0,16,0,0,0,112,0,0,0,100,0,22,0,0,0,0,0,24,0,0,0,24,0,0,0,104,0,0,0,192,0,23,0,0,0,0,0,88,0,0,0,32,0,0,0,224,0,0,0,200,0,23,0,0,0,0,0,48,0,0,0,48,0,0,0,208,0,0,0,128,1,24,0,0,0,0,0,176,0,0,0,64,0,0,0,192,1,0,0,144,1,24,0,0,0,0,0,96,0,0,0,96,0,0,0,160,1,0,0,0,3,25,0,0,0,0,0,96,1,0,0,128,0,0,0,128,3,0,0,32,3,25,0,0,0,0,0,192,0,0,0,192,0,0,0,64,3,0,0,0,6,26,0,0,0,0,0,192,2,0,0,0,1,0,0,0,7,0,0,64,6,26,0,0,0,0,0,128,1,0,0,128,1,0,0,128,6,0,0,0,12,0,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,115,0,0,0,204,255,255,255,98,0,0,0,201,255,255,255,122,0,0,0,196,255,255,255,51,51,243,64,102,102,102,64,205,204,140,64,205,204,108,64,51,51,195,64,51,51,163,64,51,51,19,64,205,204,204,63,102,102,198,64,0,0,192,63,102,102,230,63,154,153,153,63,0,0,0,0,0,0,0,0,64,2,36,2,70,2,106,2,34,2,104,2,48,2,130,2,72,2,70,2,192,2,152,2,0,2,32,2,144,2,128,2,0,2,136,2,70,2,54,2,20,2,102,2,84,2,136,2,74,2,40,2,72,2,78,2,32,2,66,2,72,2,112,2,16,2,16,2,14,2,16,2,24,2,16,2,14,2,32,2,32,2,0,2,0,2,16,2,16,2,32,2,0,2,32,2,128,0,128,0,128,0,128,0,128,0,128,0,0,0,0,0,0,8,4,10,11,2,6,9,1,3,5,7,4,0,8,11,10,3,5,2,6,9,1,7,8,0,4,10,11,1,7,2,6,9,3,5,0,0,0,0,0,0,1,0,4,0,3,0,5,0,3,0,12,0,4,0,13,0,4,0,56,0,6,0,29,0,5,0,57,0,6,0,60,0,6,0,61,0,6,0,62,0,6,0,63,0,6,0,0,0,5,0,1,0,5,0,2,0,5,0,1,0,2,0,2,0,2,0,2,0,4,0,3,0,5,0,6,0,3,0,3,0,4,0,14,0,4,0,30,0,5,0,31,0,5,0,0,0,2,0,1,0,2,0,4,0,3,0,5,0,3,0,6,0,3,0,56,0,6,0,57,0,6,0,29,0,5,0,60,0,6,0,61,0,6,0,62,0,6,0,63,0,6,0,0,0,3,0,2,0,4,0,3,0,4,0,1,0,2,0,2,0,2,0,24,0,5,0,25,0,5,0,13,0,4,0,28,0,5,0,29,0,5,0,30,0,5,0,31,0,5,0,0,0,2,0,1,0,2,0,4,0,3,0,5,0,3,0,6,0,3,0,56,0,6,0,29,0,5,0,57,0,6,0,60,0,6,0,61,0,6,0,62,0,6,0,63,0,6,0,0,0,1,0,2,0,2,0,6,0,3,0,28,0,5,0,29,0,5,0,120,0,7,0,61,0,6,0,121,0,7,0,124,0,7,0,125,0,7,0,126,0,7,0,127,0,7,0,34,50,51,83,35,66,67,99,36,82,52,115,37,98,68,131,38,114,53,84,39,130,69,100,40,146,54,116,41,162,70,132,0,0,5,0,1,0,4,0,1,0,5,0,4,0,5,0,5,0,5,0,6,0,5,0,14,0,6,0,15,0,6,0,64,0,8,0,65,0,8,0,64,8,13,0,65,8,13,0,66,8,13,0,67,8,13,0,68,8,13,0,69,8,13,0,70,8,13,0,2,0,2,0,3,0,2,0,3,0,3,0,5,0,4,0,9,0,5,0,17,0,6,0,67,0,8,0,133,0,9,0,71,8,13,0,72,8,13,0,73,8,13,0,74,8,13,0,75,8,13,0,76,8,13,0,77,8,13,0,78,8,13,0,79,8,13,0,0,0,4,0,1,0,3,0,2,0,3,0,1,0,4,0,6,0,4,0,4,0,3,0,7,0,4,0,5,0,3,0,12,0,4,0,13,0,4,0,28,0,5,0,58,0,6,0,216,1,9,0,217,1,9,0,160,29,13,0,161,29,13,0,162,29,13,0,60,0,6,0,61,0,6,0,62,0,6,0,119,0,7,0,219,1,9,0,126,0,7,0,254,0,8,0,254,1,9,0,163,29,13,0,164,29,13,0,165,29,13,0,211,14,12,0,212,14,12,0,255,1,9,0,213,14,12,0,214,14,12,0,215,14,12,0,0,0,4,0,1,0,3,0,2,0,3,0,1,0,4,0,6,0,4,0,7,0,4,0,8,0,4,0,9,0,4,0,40,0,6,0,41,0,6,0,84,0,7,0,85,0,7,0,192,10,12,0,193,10,12,0,194,10,12,0,195,10,12,0,196,10,12,0,11,0,4,0,6,0,3,0,14,0,4,0,30,0,5,0,62,0,6,0,63,0,6,0,87,0,7,0,173,0,8,0,197,10,12,0,198,10,12,0,199,10,12,0,200,10,12,0,201,10,12,0,202,10,12,0,203,10,12,0,102,5,11,0,103,5,11,0,0,0,4,0,1,0,2,0,1,0,3,0,4,0,3,0,5,0,3,0,6,0,3,0,1,0,4,0,14,0,4,0,60,0,6,0,61,0,6,0,124,0,7,0,250,0,8,0,192,62,14,0,193,62,14,0,194,62,14,0,195,62,14,0,98,31,13,0,247,1,9,0,126,0,7,0,254,0,8,0,255,0,8,0,99,31,13,0,100,31,13,0,101,31,13,0,102,31,13,0,103,31,13,0,104,31,13,0,105,31,13,0,106,31,13,0,107,31,13,0,108,31,13,0,109,31,13,0,110,31,13,0,111,31,13,0,0,0,7,0,1,0,7,0,2,0,7,0,3,0,7,0,4,0,7,0,5,0,7,0,6,0,7,0,7,0,7,0,8,0,7,0,9,0,7,0,10,0,7,0,11,0,7,0,12,0,7,0,13,0,7,0,14,0,7,0,15,0,7,0,16,0,7,0,1,0,1,0,1,0,2,0,17,0,7,0,18,0,7,0,19,0,7,0,20,0,7,0,21,0,7,0,22,0,7,0,23,0,7,0,24,0,7,0,25,0,7,0,26,0,7,0,27,0,7,0,28,0,7,0,29,0,7,0,30,0,7,0,31,0,7,0,0,0,5,0,1,0,4,0,1,0,5,0,8,0,6,0,9,0,6,0,10,0,6,0,22,0,7,0,12,0,6,0,23,0,7,0,13,0,6,0,56,0,8,0,29,0,7,0,57,0,8,0,128,7,13,0,129,7,13,0,130,7,13,0,131,7,13,0,2,0,3,0,1,0,1,0,3,0,3,0,31,0,7,0,61,0,8,0,121,0,9,0,132,7,13,0,133,7,13,0,134,7,13,0,135,7,13,0,136,7,13,0,137,7,13,0,138,7,13,0,139,7,13,0,140,7,13,0,141,7,13,0,199,3,12,0,0,0,4,0,1,0,2,0,1,0,3,0,4,0,3,0,1,0,4,0,10,0,4,0,22,0,5,0,46,0,6,0,94,0,7,0,95,0,7,0,192,0,8,0,64,48,14,0,65,48,14,0,5,3,10,0,131,1,9,0,66,48,14,0,67,48,14,0,13,0,4,0,7,0,3,0,25,0,5,0,49,0,6,0,194,0,8,0,195,0,8,0,68,48,14,0,69,48,14,0,70,48,14,0,71,48,14,0,72,48,14,0,73,48,14,0,74,48,14,0,75,48,14,0,76,48,14,0,77,48,14,0,39,24,13,0,0,0,6,0,1,0,6,0,2,0,6,0,6,0,7,0,7,0,7,0,4,0,6,0,5,0,6,0,6,0,6,0,14,0,7,0,30,0,8,0,31,0,8,0,64,0,9,0,130,0,10,0,48,8,14,0,49,8,14,0,50,8,14,0,51,8,14,0,1,0,1,0,1,0,2,0,3,0,4,0,5,0,5,0,9,0,6,0,17,0,7,0,33,0,8,0,52,8,14,0,53,8,14,0,54,8,14,0,55,8,14,0,56,8,14,0,57,8,14,0,58,8,14,0,59,8,14,0,30,4,13,0,31,4,13,0,0,0,5,0,1,0,4,0,2,0,4,0,1,0,5,0,6,0,5,0,4,0,4,0,7,0,5,0,10,0,5,0,44,0,7,0,45,0,7,0,192,5,12,0,193,5,12,0,194,5,12,0,195,5,12,0,196,5,12,0,197,5,12,0,198,5,12,0,3,0,3,0,2,0,2,0,6,0,3,0,14,0,4,0,30,0,5,0,31,0,5,0,47,0,7,0,93,0,8,0,199,5,12,0,200,5,12,0,201,5,12,0,202,5,12,0,203,5,12,0,204,5,12,0,205,5,12,0,206,5,12,0,207,5,12,0,0,0,3,0,1,0,3,0,2,0,3,0,6,0,4,0,7,0,4,0,4,0,3,0,10,0,4,0,11,0,4,0,48,0,6,0,98,0,7,0,99,0,7,0,64,6,11,0,65,6,11,0,66,6,11,0,67,6,11,0,68,6,11,0,69,6,11,0,51,0,6,0,13,0,4,0,28,0,5,0,29,0,5,0,60,0,6,0,31,0,5,0,101,0,7,0,122,0,7,0,70,6,11,0,123,0,7,0,71,6,11,0,72,6,11,0,73,6,11,0,74,6,11,0,75,6,11,0,38,3,10,0,39,3,10,0,0,0,7,0,1,0,7,0,1,0,6,0,4,0,7,0,3,0,6,0,5,0,7,0,16,0,8,0,17,0,8,0,64,2,13,0,65,2,13,0,66,2,13,0,67,2,13,0,68,2,13,0,69,2,13,0,70,2,13,0,71,2,13,0,36,1,12,0,1,0,1,0,1,0,2,0,1,0,3,0,3,0,5,0,5,0,6,0,19,0,8,0,37,1,12,0,38,1,12,0,39,1,12,0,40,1,12,0,41,1,12,0,42,1,12,0,43,1,12,0,44,1,12,0,45,1,12,0,46,1,12,0,47,1,12,0,0,0,4,0,1,0,3,0,2,0,3,0,1,0,4,0,6,0,4,0,4,0,3,0,5,0,3,0,6,0,3,0,14,0,5,0,15,0,5,0,112,0,7,0,16,7,11,0,17,7,11,0,18,7,11,0,19,7,11,0,20,7,11,0,21,7,11,0,29,0,5,0,114,0,7,0,60,0,6,0,61,0,6,0,115,0,7,0,124,0,7,0,125,0,7,0,126,0,7,0,22,7,11,0,23,7,11,0,24,7,11,0,127,0,7,0,25,7,11,0,26,7,11,0,27,7,11,0,142,3,10,0,143,3,10,0,0,0,8,0,1,0,7,0,2,0,7,0,3,0,7,0,2,0,9,0,8,0,8,0,3,0,9,0,64,2,14,0,65,2,14,0,66,2,14,0,67,2,14,0,68,2,14,0,69,2,14,0,70,2,14,0,71,2,14,0,36,1,13,0,37,1,13,0,1,0,2,0,1,0,1,0,1,0,3,0,1,0,4,0,3,0,6,0,5,0,7,0,19,0,9,0,38,1,13,0,39,1,13,0,40,1,13,0,41,1,13,0,42,1,13,0,43,1,13,0,44,1,13,0,45,1,13,0,46,1,13,0,47,1,13,0,0,0,7,0,1,0,7,0,1,0,6,0,2,0,6,0,3,0,6,0,4,0,6,0,5,0,6,0,6,0,6,0,7,0,6,0,8,0,6,0,9,0,6,0,10,0,6,0,11,0,6,0,12,0,6,0,13,0,6,0,14,0,6,0,15,0,6,0,16,0,6,0,17,0,6,0,18,0,6,0,19,0,6,0,20,0,6,0,21,0,6,0,22,0,6,0,23,0,6,0,24,0,6,0,25,0,6,0,1,0,1,0,26,0,6,0,27,0,6,0,28,0,6,0,29,0,6,0,30,0,6,0,31,0,6,0,0,0,5,0,1,0,4,0,1,0,5,0,4,0,5,0,10,0,6,0,6,0,5,0,11,0,6,0,14,0,6,0,60,0,8,0,61,0,8,0,192,7,13,0,193,7,13,0,194,7,13,0,195,7,13,0,196,7,13,0,197,7,13,0,198,7,13,0,1,0,2,0,2,0,2,0,6,0,3,0,14,0,4,0,30,0,5,0,31,0,5,0,63,0,8,0,125,0,9,0,199,7,13,0,200,7,13,0,201,7,13,0,202,7,13,0,203,7,13,0,204,7,13,0,205,7,13,0,206,7,13,0,207,7,13,0,0,0,7,0,1,0,7,0,2,0,7,0,3,0,7,0,4,0,7,0,5,0,7,0,6,0,7,0,7,0,7,0,8,0,7,0,9,0,7,0,10,0,7,0,11,0,7,0,12,0,7,0,13,0,7,0,14,0,7,0,15,0,7,0,16,0,7,0,1,0,1,0,1,0,2,0,17,0,7,0,18,0,7,0,19,0,7,0,20,0,7,0,21,0,7,0,22,0,7,0,23,0,7,0,24,0,7,0,25,0,7,0,26,0,7,0,27,0,7,0,28,0,7,0,29,0,7,0,30,0,7,0,31,0,7,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,18,0,6,0,38,0,7,0,20,0,6,0,78,0,8,0,79,0,8,0,168,0,9,0,82,1,10,0,170,0,9,0,171,0,9,0,172,0,9,0,96,42,15,0,167,2,11,0,6,0,4,0,11,0,5,0,28,0,6,0,58,0,7,0,15,0,5,0,59,0,7,0,16,0,5,0,5,0,3,0,9,0,4,0,17,0,5,0,24,0,5,0,25,0,5,0,26,0,5,0,54,0,6,0,55,0,6,0,112,0,7,0,87,0,8,0,226,0,8,0,227,0,8,0,228,0,8,0,229,0,8,0,173,0,9,0,152,3,10,0,58,0,6,0,118,0,7,0,231,0,8,0,238,0,8,0,239,0,8,0,50,7,11,0,154,3,10,0,51,7,11,0,97,42,15,0,120,0,7,0,49,21,14,0,50,21,14,0,51,21,14,0,61,0,6,0,155,3,10,0,52,21,14,0,53,21,14,0,54,21,14,0,121,0,7,0,55,21,14,0,248,0,8,0,242,1,9,0,204,7,11,0,231,3,10,0,205,7,11,0,128,62,14,0,251,0,8,0,233,3,10,0,129,62,14,0,130,62,14,0,131,62,14,0,132,62,14,0,133,62,14,0,134,62,14,0,63,0,6,0,245,1,9,0,209,7,11,0,135,62,14,0,0,0,2,0,2,0,3,0,6,0,4,0,14,0,5,0,30,0,6,0,31,0,6,0,64,0,7,0,130,0,8,0,131,0,8,0,132,0,8,0,10,1,9,0,11,1,9,0,48,4,11,0,49,4,11,0,50,4,11,0,51,4,11,0,5,0,3,0,17,0,5,0,36,0,6,0,74,0,7,0,12,0,4,0,38,0,6,0,13,0,4,0,135,0,8,0,13,1,9,0,88,2,10,0,45,1,9,0,89,2,10,0,92,2,10,0,116,9,12,0,94,2,10,0,95,2,10,0,112,2,10,0,113,2,10,0,187,4,11,0,117,9,12,0,114,2,10,0,204,9,12,0,205,9,12,0,112,78,15,0,113,78,15,0,114,78,15,0,115,78,15,0,58,39,14,0,59,39,14,0,60,39,14,0,232,4,11,0,233,4,11,0,158,0,8,0,117,2,10,0,216,9,12,0,61,39,14,0,14,0,4,0,60,0,6,0,122,0,7,0,159,0,8,0,119,2,10,0,62,0,6,0,246,0,8,0,237,4,11,0,220,3,10,0,62,39,14,0,186,7,11,0,217,9,12,0,63,39,14,0,216,61,14,0,217,61,14,0,218,61,14,0,219,61,14,0,220,61,14,0,221,61,14,0,222,61,14,0,223,61,14,0,63,0,6,0,188,7,11,0,189,7,11,0,223,3,10,0,0,0,3,0,2,0,4,0,6,0,5,0,14,0,6,0,30,0,7,0,62,0,8,0,63,0,8,0,64,0,8,0,4,1,10,0,131,0,9,0,5,1,10,0,8,1,10,0,64,66,16,0,10,1,10,0,11,1,10,0,65,66,16,0,3,0,3,0,9,0,5,0,17,0,6,0,67,0,8,0,4,0,3,0,10,0,5,0,10,0,4,0,44,0,7,0,180,0,9,0,181,0,9,0,182,0,9,0,183,0,9,0,184,0,9,0,114,1,10,0,115,1,10,0,116,1,10,0,117,1,10,0,118,1,10,0,119,1,10,0,188,0,9,0,122,1,10,0,19,2,11,0,66,66,16,0,123,1,10,0,248,2,11,0,125,1,10,0,249,2,11,0,126,1,10,0,67,66,16,0,254,2,11,0,34,33,15,0,35,33,15,0,88,0,7,0,100,1,9,0,36,33,15,0,37,33,15,0,6,0,3,0,14,0,4,0,45,0,6,0,46,0,6,0,179,0,8,0,30,0,5,0,94,0,7,0,38,33,15,0,39,33,15,0,40,33,15,0,41,33,15,0,255,2,11,0,42,33,15,0,148,5,11,0,149,5,11,0,150,5,11,0,43,33,15,0,44,33,15,0,45,33,15,0,46,33,15,0,47,33,15,0,31,0,5,0,151,5,11,0,190,0,8,0,191,0,8,0,0,0,2,0,2,0,3,0,6,0,4,0,7,0,4,0,16,0,5,0,17,0,5,0,36,0,6,0,37,0,6,0,38,0,6,0,39,0,6,0,80,0,7,0,81,0,7,0,164,0,8,0,165,0,8,0,166,0,8,0,78,1,9,0,11,0,4,0,42,0,6,0,86,0,7,0,79,1,9,0,48,0,6,0,174,0,8,0,98,0,7,0,50,0,6,0,51,0,6,0,52,0,6,0,53,0,6,0,54,0,6,0,99,0,7,0,110,0,7,0,111,0,7,0,112,0,7,0,113,0,7,0,114,0,7,0,115,0,7,0,116,0,7,0,175,0,8,0,234,0,8,0,214,1,9,0,92,7,11,0,175,3,10,0,208,117,15,0,209,117,15,0,210,117,15,0,211,117,15,0,212,117,15,0,118,0,7,0,238,0,8,0,239,0,8,0,187,14,12,0,224,1,9,0,213,117,15,0,121,0,7,0,225,1,9,0,214,117,15,0,215,117,15,0,128,120,15,0,244,0,8,0,137,7,11,0,62,0,6,0,123,0,7,0,245,0,8,0,252,0,8,0,127,0,7,0,227,1,9,0,138,7,11,0,139,7,11,0,129,120,15,0,130,120,15,0,131,120,15,0,66,60,14,0,67,60,14,0,68,60,14,0,253,0,8,0,69,60,14,0,70,60,14,0,71,60,14,0,0,0,2,0,4,0,4,0,10,0,5,0,22,0,6,0,23,0,6,0,48,0,7,0,49,0,7,0,100,0,8,0,101,0,8,0,102,0,8,0,206,0,9,0,207,0,9,0,160,1,10,0,161,1,10,0,32,26,14,0,137,6,12,0,4,0,3,0,14,0,5,0,27,0,6,0,53,0,7,0,10,0,4,0,30,0,6,0,22,0,5,0,23,0,5,0,31,0,6,0,48,0,6,0,49,0,6,0,100,0,7,0,101,0,7,0,105,0,8,0,102,0,7,0,206,0,8,0,207,0,8,0,208,0,8,0,209,0,8,0,210,0,8,0,166,1,9,0,163,1,10,0,78,3,10,0,106,0,7,0,214,0,8,0,174,1,9,0,175,1,9,0,79,3,10,0,69,3,11,0,176,1,9,0,177,1,9,0,100,3,10,0,109,0,7,0,220,0,8,0,148,13,12,0,149,13,12,0,14,0,4,0,60,0,6,0,221,0,8,0,222,0,8,0,179,1,9,0,61,0,6,0,223,0,8,0,240,1,9,0,226,3,10,0,227,3,10,0,203,6,11,0,228,3,10,0,202,7,11,0,243,1,9,0,244,1,9,0,203,7,11,0,212,7,11,0,33,26,14,0,34,26,14,0,213,7,11,0,35,26,14,0,63,0,6,0,246,1,9,0,247,1,9,0,235,3,10,0,0,0,2,0,2,0,3,0,6,0,4,0,14,0,5,0,15,0,5,0,32,0,6,0,33,0,6,0,68,0,7,0,69,0,7,0,70,0,7,0,142,0,8,0,143,0,8,0,144,0,8,0,34,1,9,0,70,2,10,0,36,1,9,0,5,0,3,0,19,0,5,0,74,0,7,0,147,0,8,0,24,0,5,0,75,0,7,0,50,0,6,0,26,0,5,0,51,0,6,0,108,0,7,0,109,0,7,0,110,0,7,0,222,0,8,0,223,0,8,0,112,0,7,0,226,0,8,0,227,0,8,0,228,0,8,0,229,0,8,0,230,0,8,0,231,0,8,0,37,1,9,0,208,1,9,0,142,4,11,0,30,9,12,0,31,9,12,0,64,116,15,0,17,29,13,0,65,116,15,0,66,116,15,0,233,0,8,0,212,1,9,0,235,0,8,0,163,3,10,0,213,1,9,0,18,29,13,0,30,0,5,0,118,0,7,0,220,1,9,0,221,1,9,0,67,116,15,0,124,0,7,0,69,7,11,0,239,0,8,0,250,0,8,0,251,0,8,0,248,1,9,0,253,0,8,0,228,7,11,0,202,15,12,0,19,29,13,0,88,126,15,0,89,126,15,0,90,126,15,0,91,126,15,0,92,126,15,0,93,126,15,0,127,0,7,0,47,63,14,0,230,7,11,0,231,7,11,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,9,0,5,0,20,0,6,0,21,0,6,0,44,0,7,0,90,0,8,0,91,0,8,0,92,0,8,0,186,0,9,0,187,0,9,0,188,0,9,0,244,2,11,0,234,5,12,0,3,0,3,0,16,0,5,0,34,0,6,0,70,0,7,0,9,0,4,0,40,0,6,0,21,0,5,0,11,0,4,0,24,0,5,0,41,0,6,0,50,0,6,0,71,0,7,0,102,0,7,0,103,0,7,0,104,0,7,0,105,0,7,0,106,0,7,0,95,0,8,0,214,0,8,0,215,0,8,0,176,1,9,0,217,0,8,0,123,1,10,0,109,0,7,0,220,0,8,0,177,1,9,0,232,6,11,0,187,1,9,0,117,3,10,0,235,5,12,0,188,1,9,0,144,110,15,0,56,0,6,0,114,0,7,0,145,110,15,0,146,110,15,0,29,0,5,0,115,0,7,0,189,1,9,0,248,6,11,0,147,110,15,0,60,0,6,0,191,1,9,0,244,0,8,0,234,1,9,0,125,3,10,0,214,3,10,0,249,6,11,0,148,110,15,0,246,0,8,0,238,1,9,0,149,110,15,0,150,110,15,0,151,110,15,0,76,55,14,0,77,55,14,0,78,55,14,0,31,0,5,0,215,3,10,0,239,1,9,0,79,55,14,0,0,0,2,0,4,0,4,0,10,0,5,0,22,0,6,0,46,0,7,0,47,0,7,0,96,0,8,0,97,0,8,0,196,0,9,0,197,0,9,0,198,0,9,0,142,1,10,0,224,49,15,0,225,49,15,0,226,49,15,0,227,49,15,0,4,0,3,0,13,0,5,0,25,0,6,0,56,0,7,0,10,0,4,0,29,0,6,0,11,0,4,0,114,0,8,0,115,0,8,0,240,0,9,0,226,1,10,0,242,0,9,0,227,1,10,0,243,0,9,0,232,1,10,0,233,1,10,0,228,49,15,0,234,1,10,0,31,3,11,0,214,3,11,0,229,49,15,0,236,1,10,0,230,49,15,0,247,0,9,0,215,3,11,0,231,49,15,0,232,49,15,0,218,3,11,0,219,3,11,0,233,49,15,0,224,3,11,0,234,49,15,0,63,0,7,0,241,1,10,0,235,49,15,0,236,49,15,0,6,0,3,0,28,0,5,0,116,0,7,0,117,0,7,0,249,0,9,0,30,0,5,0,118,0,7,0,250,0,9,0,225,3,11,0,237,49,15,0,247,24,14,0,96,31,14,0,97,31,14,0,220,1,9,0,221,1,9,0,98,31,14,0,99,31,14,0,100,31,14,0,101,31,14,0,102,31,14,0,103,31,14,0,31,0,5,0,237,3,11,0,239,0,8,0,247,1,10,0,0,0,3,0,2,0,4,0,6,0,5,0,7,0,5,0,8,0,5,0,9,0,5,0,20,0,6,0,42,0,7,0,22,0,6,0,43,0,7,0,92,0,8,0,47,0,7,0,48,0,7,0,93,0,8,0,98,0,8,0,198,0,9,0,7,0,4,0,25,0,6,0,26,0,6,0,54,0,7,0,16,0,5,0,110,0,8,0,34,0,6,0,9,0,4,0,10,0,4,0,22,0,5,0,35,0,6,0,46,0,6,0,47,0,6,0,48,0,6,0,98,0,7,0,99,0,7,0,100,0,7,0,101,0,7,0,102,0,7,0,103,0,7,0,104,0,7,0,105,0,7,0,106,0,7,0,107,0,7,0,108,0,7,0,199,0,9,0,222,0,9,0,223,0,9,0,208,6,11,0,181,1,9,0,55,0,6,0,219,0,8,0,28,0,5,0,116,0,7,0,212,1,9,0,213,1,9,0,118,0,7,0,105,3,10,0,136,54,14,0,137,54,14,0,138,54,14,0,119,0,7,0,172,3,10,0,120,0,7,0,242,0,8,0,215,1,9,0,243,0,8,0,122,0,7,0,139,54,14,0,123,0,7,0,124,0,7,0,173,3,10,0,232,3,10,0,140,54,14,0,141,54,14,0,233,3,10,0,142,54,14,0,63,0,6,0,245,1,9,0,251,0,8,0,143,54,14,0,0,0,2,0,4,0,4,0,10,0,5,0,11,0,5,0,24,0,6,0,50,0,7,0,51,0,7,0,52,0,7,0,106,0,8,0,214,0,9,0,215,0,9,0,216,0,9,0,217,0,9,0,128,54,15,0,181,1,10,0,105,3,11,0,4,0,3,0,14,0,5,0,30,0,6,0,55,0,7,0,10,0,4,0,22,0,5,0,12,0,4,0,31,0,6,0,92,0,7,0,93,0,7,0,188,0,8,0,189,0,8,0,95,0,7,0,208,0,8,0,219,0,9,0,209,0,8,0,164,1,9,0,165,1,9,0,166,1,9,0,167,1,9,0,80,3,10,0,162,6,11,0,163,6,11,0,169,1,9,0,170,1,9,0,172,6,11,0,129,54,15,0,87,3,10,0,130,54,15,0,131,54,15,0,132,54,15,0,133,54,15,0,54,0,6,0,214,0,8,0,134,54,15,0,135,54,15,0,14,0,4,0,110,0,7,0,215,0,8,0,173,6,11,0,136,54,15,0,30,0,5,0,222,0,8,0,248,6,11,0,125,3,10,0,137,54,15,0,138,54,15,0,139,54,15,0,140,54,15,0,191,1,9,0,141,54,15,0,71,27,14,0,200,55,14,0,201,55,14,0,202,55,14,0,203,55,14,0,204,55,14,0,31,0,5,0,205,55,14,0,206,55,14,0,207,55,14,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,18,0,6,0,38,0,7,0,20,0,6,0,39,0,7,0,168,0,9,0,169,0,9,0,85,0,8,0,0,43,15,0,173,0,9,0,1,43,15,0,2,43,15,0,3,43,15,0,3,0,3,0,11,0,5,0,64,0,7,0,65,0,7,0,9,0,4,0,33,0,6,0,17,0,5,0,10,0,4,0,11,0,4,0,24,0,5,0,50,0,6,0,51,0,6,0,52,0,6,0,53,0,6,0,108,0,7,0,87,0,8,0,109,0,7,0,220,0,8,0,89,1,10,0,221,0,8,0,188,1,9,0,122,3,10,0,123,3,10,0,56,0,6,0,114,0,7,0,190,1,9,0,191,1,9,0,230,0,8,0,156,3,10,0,207,1,9,0,4,43,15,0,5,43,15,0,116,0,7,0,212,1,9,0,6,43,15,0,7,43,15,0,30,0,5,0,235,0,8,0,132,21,14,0,133,21,14,0,134,21,14,0,59,0,6,0,213,1,9,0,240,1,9,0,157,3,10,0,226,3,10,0,135,21,14,0,136,21,14,0,137,21,14,0,249,0,8,0,138,21,14,0,139,21,14,0,227,3,10,0,140,21,14,0,141,21,14,0,244,1,9,0,142,21,14,0,63,0,6,0,251,0,8,0,245,1,9,0,143,21,14,0,0,0,3,0,2,0,4,0,6,0,5,0,7,0,5,0,16,0,6,0,17,0,6,0,36,0,7,0,37,0,7,0,19,0,6,0,20,0,6,0,42,0,7,0,43,0,7,0,176,0,9,0,177,0,9,0,45,0,7,0,89,0,8,0,12,0,5,0,23,0,6,0,208,0,9,0,53,0,7,0,27,0,6,0,56,0,7,0,57,0,7,0,4,0,3,0,5,0,3,0,15,0,5,0,24,0,5,0,29,0,6,0,50,0,6,0,51,0,6,0,104,0,7,0,105,0,7,0,105,0,8,0,212,0,8,0,213,0,8,0,214,0,8,0,108,0,7,0,55,0,6,0,109,0,7,0,112,0,7,0,57,0,6,0,215,0,8,0,209,0,9,0,128,56,14,0,129,56,14,0,130,56,14,0,116,0,7,0,197,1,9,0,117,0,7,0,227,0,8,0,131,56,14,0,132,56,14,0,236,0,8,0,133,56,14,0,67,28,13,0,68,28,13,0,69,28,13,0,237,0,8,0,70,28,13,0,60,0,6,0,119,0,7,0,232,1,9,0,62,0,6,0,123,0,7,0,71,28,13,0,126,0,7,0,127,0,7,0,72,28,13,0,73,28,13,0,74,28,13,0,75,28,13,0,76,28,13,0,77,28,13,0,245,0,8,0,78,28,13,0,233,1,9,0,79,28,13,0,0,0,2,0,4,0,4,0,10,0,5,0,11,0,5,0,24,0,6,0,25,0,6,0,52,0,7,0,53,0,7,0,54,0,7,0,110,0,8,0,222,0,9,0,223,0,9,0,192,1,10,0,193,1,10,0,194,1,10,0,96,56,15,0,4,0,3,0,15,0,5,0,29,0,6,0,57,0,7,0,10,0,4,0,44,0,6,0,45,0,6,0,12,0,4,0,23,0,5,0,52,0,6,0,53,0,6,0,54,0,6,0,110,0,7,0,111,0,7,0,112,0,7,0,113,0,7,0,113,0,8,0,228,0,8,0,229,0,8,0,230,0,8,0,231,0,8,0,232,0,8,0,164,3,10,0,117,0,7,0,236,0,8,0,211,1,9,0,218,1,9,0,165,3,10,0,182,3,10,0,13,7,12,0,183,3,10,0,14,7,12,0,60,0,6,0,238,0,8,0,97,56,15,0,98,56,15,0,61,0,6,0,222,1,9,0,99,56,15,0,100,56,15,0,101,56,15,0,124,0,7,0,15,7,12,0,190,3,10,0,191,3,10,0,102,56,15,0,160,15,12,0,209,7,11,0,103,56,15,0,251,0,8,0,245,1,9,0,8,125,15,0,164,15,12,0,9,125,15,0,10,125,15,0,11,125,15,0,134,62,14,0,63,0,6,0,165,15,12,0,211,7,11,0,135,62,14,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,9,0,5,0,20,0,6,0,42,0,7,0,86,0,8,0,184,2,11,0,175,0,9,0,185,2,11,0,93,1,10,0,192,2,11,0,16,44,15,0,17,44,15,0,18,44,15,0,6,0,4,0,14,0,5,0,23,0,6,0,45,0,7,0,15,0,5,0,64,0,7,0,33,0,6,0,5,0,3,0,9,0,4,0,17,0,5,0,24,0,5,0,25,0,5,0,26,0,5,0,54,0,6,0,55,0,6,0,65,0,7,0,89,0,8,0,224,0,8,0,225,0,8,0,113,0,7,0,228,0,8,0,177,0,9,0,194,2,11,0,29,0,5,0,115,0,7,0,229,0,8,0,240,0,8,0,121,0,7,0,196,3,10,0,227,1,9,0,232,1,9,0,19,44,15,0,123,0,7,0,20,44,15,0,21,44,15,0,22,44,15,0,124,0,7,0,195,2,11,0,23,44,15,0,12,22,14,0,13,22,14,0,125,0,7,0,14,22,14,0,233,1,9,0,197,3,10,0,212,3,10,0,235,1,9,0,15,22,14,0,80,61,14,0,252,0,8,0,171,7,11,0,81,61,14,0,82,61,14,0,83,61,14,0,84,61,14,0,250,1,9,0,85,61,14,0,127,0,7,0,251,1,9,0,86,61,14,0,87,61,14,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,9,0,5,0,10,0,5,0,11,0,5,0,24,0,6,0,50,0,7,0,13,0,5,0,51,0,7,0,0,14,13,0,57,0,7,0,1,14,13,0,58,0,7,0,2,14,13,0,8,0,4,0,30,0,6,0,59,0,7,0,62,0,7,0,18,0,5,0,63,0,7,0,19,0,5,0,40,0,6,0,41,0,6,0,84,0,7,0,43,0,6,0,85,0,7,0,88,0,7,0,3,14,13,0,89,0,7,0,90,0,7,0,4,14,13,0,5,14,13,0,3,7,12,0,91,0,7,0,92,0,7,0,4,7,12,0,5,7,12,0,93,0,7,0,6,7,12,0,7,7,12,0,8,7,12,0,9,7,12,0,10,7,12,0,11,7,12,0,24,0,5,0,47,0,6,0,13,0,4,0,25,0,5,0,12,7,12,0,112,0,7,0,29,0,5,0,13,7,12,0,14,7,12,0,15,7,12,0,16,7,12,0,57,0,6,0,17,7,12,0,60,0,6,0,18,7,12,0,19,7,12,0,20,7,12,0,21,7,12,0,22,7,12,0,61,0,6,0,23,7,12,0,24,7,12,0,25,7,12,0,26,7,12,0,27,7,12,0,28,7,12,0,29,7,12,0,31,0,5,0,30,7,12,0,113,0,7,0,31,7,12,0,0,0,3,0,2,0,4,0,6,0,5,0,14,0,6,0,15,0,6,0,64,0,8,0,65,0,8,0,66,0,8,0,24,2,11], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);
/* memory initializer */ allocate([144,33,15,0,145,33,15,0,146,33,15,0,147,33,15,0,148,33,15,0,149,33,15,0,150,33,15,0,5,0,4,0,17,0,6,0,36,0,7,0,135,0,9,0,12,0,5,0,74,0,8,0,75,0,8,0,2,0,2,0,6,0,3,0,13,0,5,0,14,0,5,0,15,0,5,0,19,0,6,0,56,0,6,0,228,0,8,0,229,0,8,0,204,1,9,0,231,0,8,0,116,0,7,0,234,0,8,0,205,1,9,0,26,2,11,0,151,33,15,0,30,0,5,0,118,0,7,0,235,0,8,0,220,1,9,0,239,0,8,0,221,1,9,0,240,1,9,0,152,33,15,0,153,33,15,0,249,0,8,0,226,3,10,0,154,33,15,0,155,33,15,0,250,0,8,0,156,33,15,0,157,33,15,0,158,33,15,0,159,33,15,0,246,1,9,0,176,33,15,0,252,0,8,0,247,1,9,0,177,33,15,0,178,33,15,0,179,33,15,0,180,33,15,0,250,1,9,0,181,33,15,0,182,33,15,0,183,33,15,0,184,33,15,0,185,33,15,0,227,3,10,0,221,16,14,0,127,0,7,0,251,1,9,0,222,16,14,0,223,16,14,0,0,0,2,0,2,0,3,0,6,0,4,0,14,0,5,0,30,0,6,0,62,0,7,0,63,0,7,0,64,0,7,0,4,1,9,0,131,0,8,0,132,0,8,0,133,0,8,0,10,2,10,0,11,2,10,0,24,2,10,0,25,2,10,0,9,0,4,0,68,0,7,0,13,1,9,0,28,2,10,0,35,0,6,0,69,0,7,0,80,0,7,0,11,0,4,0,12,0,4,0,21,0,5,0,26,0,5,0,27,0,5,0,41,0,6,0,56,0,6,0,57,0,6,0,58,0,6,0,81,0,7,0,118,0,7,0,119,0,7,0,120,0,7,0,121,0,7,0,122,0,7,0,123,0,7,0,248,0,8,0,15,1,9,0,29,2,10,0,64,62,14,0,65,62,14,0,66,62,14,0,67,62,14,0,229,3,10,0,68,62,14,0,243,1,9,0,69,62,14,0,70,62,14,0,71,62,14,0,250,0,8,0,72,62,14,0,73,62,14,0,74,62,14,0,75,62,14,0,236,3,10,0,76,62,14,0,126,0,7,0,254,0,8,0,255,0,8,0,247,1,9,0,77,62,14,0,78,62,14,0,79,62,14,0,208,62,14,0,209,62,14,0,210,62,14,0,211,62,14,0,212,62,14,0,213,62,14,0,107,31,13,0,108,31,13,0,109,31,13,0,110,31,13,0,111,31,13,0,0,0,3,0,4,0,5,0,20,0,7,0,11,0,6,0,12,0,6,0,42,0,8,0,43,0,8,0,52,0,8,0,64,13,14,0,65,13,14,0,27,0,7,0,66,13,14,0,67,13,14,0,68,13,14,0,69,13,14,0,70,13,14,0,14,0,6,0,60,0,8,0,71,13,14,0,61,0,8,0,72,13,14,0,73,13,14,0,74,13,14,0,1,0,2,0,4,0,3,0,20,0,5,0,11,0,4,0,12,0,4,0,13,0,4,0,42,0,6,0,31,0,7,0,86,0,7,0,87,0,7,0,112,0,7,0,226,0,8,0,114,0,7,0,58,0,6,0,59,0,6,0,60,0,6,0,61,0,6,0,227,0,8,0,75,13,14,0,230,0,8,0,231,0,8,0,248,0,8,0,76,13,14,0,77,13,14,0,78,13,14,0,249,0,8,0,79,13,14,0,80,13,14,0,81,13,14,0,169,6,13,0,170,6,13,0,171,6,13,0,172,6,13,0,173,6,13,0,174,6,13,0,175,6,13,0,63,0,6,0,176,6,13,0,177,6,13,0,178,6,13,0,179,6,13,0,180,6,13,0,125,0,7,0,181,6,13,0,182,6,13,0,183,6,13,0,184,6,13,0,185,6,13,0,186,6,13,0,187,6,13,0,188,6,13,0,189,6,13,0,190,6,13,0,191,6,13,0,0,0,2,0,2,0,3,0,3,0,3,0,8,0,4,0,18,0,5,0,19,0,5,0,40,0,6,0,41,0,6,0,84,0,7,0,85,0,7,0,86,0,7,0,174,0,8,0,175,0,8,0,176,0,8,0,98,1,9,0,198,2,10,0,12,0,4,0,45,0,6,0,178,0,8,0,102,1,9,0,46,0,6,0,103,1,9,0,188,0,8,0,26,0,5,0,54,0,6,0,55,0,6,0,56,0,6,0,95,0,7,0,114,0,7,0,115,0,7,0,116,0,7,0,117,0,7,0,118,0,7,0,119,0,7,0,120,0,7,0,121,0,7,0,122,0,7,0,123,0,7,0,189,0,8,0,192,177,16,0,193,177,16,0,225,88,15,0,29,11,12,0,226,88,15,0,227,88,15,0,228,88,15,0,248,0,8,0,228,3,10,0,243,1,9,0,30,11,12,0,229,88,15,0,230,88,15,0,250,0,8,0,231,88,15,0,248,88,15,0,249,88,15,0,250,88,15,0,246,1,9,0,251,88,15,0,126,0,7,0,254,0,8,0,255,0,8,0,202,7,11,0,150,15,12,0,252,88,15,0,253,88,15,0,254,88,15,0,255,88,15,0,184,124,15,0,185,124,15,0,186,124,15,0,187,124,15,0,188,124,15,0,247,1,9,0,189,124,15,0,190,124,15,0,191,124,15,0,0,0,2,0,2,0,3,0,6,0,4,0,14,0,5,0,15,0,5,0,32,0,6,0,33,0,6,0,68,0,7,0,69,0,7,0,140,0,8,0,141,0,8,0,28,1,9,0,29,1,9,0,30,1,9,0,62,2,10,0,63,2,10,0,5,0,3,0,18,0,5,0,76,0,7,0,77,0,7,0,12,0,4,0,78,0,7,0,26,0,5,0,54,0,6,0,79,0,7,0,110,0,7,0,111,0,7,0,224,0,8,0,225,0,8,0,226,0,8,0,227,0,8,0,228,0,8,0,229,0,8,0,204,1,9,0,231,0,8,0,232,0,8,0,233,0,8,0,205,1,9,0,80,7,11,0,169,3,10,0,81,7,11,0,64,117,15,0,171,3,10,0,65,117,15,0,66,117,15,0,67,117,15,0,214,1,9,0,85,7,11,0,118,0,7,0,169,14,12,0,68,117,15,0,69,117,15,0,30,0,5,0,119,0,7,0,248,0,8,0,174,3,10,0,94,7,11,0,125,0,7,0,228,3,10,0,252,0,8,0,253,0,8,0,229,3,10,0,230,3,10,0,190,14,12,0,70,117,15,0,206,7,11,0,71,117,15,0,248,117,15,0,249,117,15,0,250,117,15,0,251,117,15,0,252,117,15,0,253,117,15,0,127,0,7,0,255,58,14,0,158,15,12,0,159,15,12,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,18,0,6,0,19,0,6,0,20,0,6,0,42,0,7,0,22,0,6,0,43,0,7,0,92,0,8,0,93,0,8,0,94,0,8,0,190,0,9,0,191,0,9,0,96,0,8,0,7,0,4,0,13,0,5,0,25,0,6,0,32,0,6,0,9,0,4,0,33,0,6,0,17,0,5,0,20,0,5,0,42,0,6,0,43,0,6,0,44,0,6,0,45,0,6,0,46,0,6,0,47,0,6,0,48,0,6,0,49,0,7,0,98,0,7,0,99,0,7,0,100,0,7,0,101,0,7,0,102,0,7,0,97,0,8,0,112,6,11,0,104,0,7,0,105,0,7,0,207,0,8,0,157,1,9,0,168,1,9,0,169,1,9,0,57,3,10,0,170,1,9,0,86,3,10,0,54,0,6,0,214,0,8,0,16,103,15,0,17,103,15,0,14,0,4,0,110,0,7,0,174,1,9,0,18,103,15,0,19,103,15,0,60,0,6,0,87,3,10,0,111,0,7,0,244,0,8,0,245,0,8,0,94,3,10,0,236,1,9,0,20,103,15,0,237,1,9,0,95,3,10,0,220,3,10,0,221,3,10,0,21,103,15,0,139,51,14,0,140,51,14,0,141,51,14,0,31,0,5,0,239,1,9,0,142,51,14,0,143,51,14,0,0,0,2,0,4,0,4,0,10,0,5,0,11,0,5,0,24,0,6,0,25,0,6,0,52,0,7,0,106,0,8,0,107,0,8,0,108,0,8,0,218,0,9,0,108,3,11,0,110,0,8,0,183,1,10,0,109,3,11,0,128,55,15,0,4,0,3,0,14,0,5,0,30,0,6,0,62,0,7,0,10,0,4,0,44,0,6,0,23,0,5,0,45,0,6,0,63,0,7,0,192,0,8,0,97,0,7,0,193,0,8,0,98,0,7,0,198,0,8,0,100,0,7,0,199,0,8,0,202,0,8,0,223,0,9,0,150,1,9,0,151,1,9,0,152,1,9,0,153,1,9,0,121,3,11,0,154,1,9,0,189,1,10,0,108,6,11,0,129,55,15,0,55,3,10,0,109,6,11,0,112,6,11,0,57,3,10,0,113,6,11,0,52,0,6,0,207,0,8,0,130,55,15,0,131,55,15,0,14,0,4,0,27,0,5,0,106,0,7,0,107,0,7,0,157,1,9,0,60,0,6,0,244,0,8,0,245,0,8,0,216,3,10,0,178,7,11,0,132,55,15,0,218,3,10,0,133,55,15,0,219,3,10,0,220,3,10,0,134,55,15,0,135,55,15,0,196,27,14,0,197,27,14,0,198,27,14,0,199,27,14,0,31,0,5,0,221,3,10,0,179,7,11,0,239,1,9,0,0,0,2,0,4,0,4,0,10,0,5,0,22,0,6,0,23,0,6,0,96,0,8,0,194,0,9,0,134,1,10,0,135,1,10,0,196,0,9,0,64,49,15,0,65,49,15,0,139,1,10,0,66,49,15,0,140,1,10,0,67,49,15,0,7,0,4,0,13,0,5,0,100,0,8,0,101,0,8,0,16,0,5,0,199,0,9,0,102,0,8,0,5,0,3,0,6,0,3,0,9,0,4,0,17,0,5,0,56,0,6,0,57,0,6,0,116,0,7,0,117,0,7,0,118,0,7,0,103,0,8,0,238,0,8,0,222,1,9,0,240,0,8,0,141,1,10,0,68,49,15,0,223,1,9,0,61,0,6,0,62,0,6,0,226,1,9,0,198,3,10,0,242,0,8,0,243,0,8,0,199,3,10,0,69,49,15,0,70,49,15,0,248,1,9,0,71,49,15,0,72,49,15,0,73,49,15,0,253,0,8,0,74,49,15,0,75,49,15,0,76,49,15,0,77,49,15,0,249,1,9,0,78,49,15,0,252,1,9,0,79,49,15,0,80,49,15,0,81,49,15,0,82,49,15,0,83,49,15,0,250,3,10,0,251,3,10,0,84,49,15,0,85,49,15,0,86,49,15,0,87,49,15,0,88,49,15,0,89,49,15,0,255,0,8,0,173,24,14,0,174,24,14,0,175,24,14,0,0,0,4,0,128,0,11,0,129,0,11,0,130,0,11,0,131,0,11,0,132,0,11,0,133,0,11,0,134,0,11,0,135,0,11,0,136,0,11,0,137,0,11,0,138,0,11,0,139,0,11,0,140,0,11,0,141,0,11,0,142,0,11,0,143,0,11,0,72,0,10,0,73,0,10,0,74,0,10,0,75,0,10,0,76,0,10,0,77,0,10,0,1,0,1,0,1,0,2,0,78,0,10,0,2,0,4,0,3,0,4,0,79,0,10,0,80,0,10,0,81,0,10,0,82,0,10,0,83,0,10,0,84,0,10,0,85,0,10,0,86,0,10,0,87,0,10,0,88,0,10,0,89,0,10,0,90,0,10,0,91,0,10,0,92,0,10,0,93,0,10,0,94,0,10,0,95,0,10,0,96,0,10,0,97,0,10,0,98,0,10,0,99,0,10,0,100,0,10,0,101,0,10,0,102,0,10,0,103,0,10,0,104,0,10,0,105,0,10,0,106,0,10,0,107,0,10,0,108,0,10,0,109,0,10,0,110,0,10,0,111,0,10,0,112,0,10,0,113,0,10,0,114,0,10,0,115,0,10,0,116,0,10,0,117,0,10,0,118,0,10,0,119,0,10,0,120,0,10,0,121,0,10,0,122,0,10,0,123,0,10,0,124,0,10,0,125,0,10,0,126,0,10,0,127,0,10,0,0,0,3,0,2,0,4,0,12,0,6,0,13,0,6,0,28,0,7,0,15,0,6,0,0,29,15,0,59,0,8,0,1,29,15,0,117,0,9,0,2,29,15,0,128,0,9,0,3,29,15,0,4,29,15,0,5,29,15,0,131,14,14,0,9,0,5,0,17,0,6,0,129,0,9,0,130,0,9,0,33,0,7,0,40,0,7,0,131,0,9,0,2,0,2,0,3,0,3,0,12,0,4,0,13,0,4,0,11,0,5,0,21,0,6,0,82,0,8,0,112,0,7,0,57,0,6,0,113,0,7,0,83,0,8,0,132,14,14,0,116,0,7,0,117,0,7,0,118,0,7,0,220,1,9,0,30,0,5,0,62,0,6,0,221,1,9,0,239,0,8,0,248,1,9,0,249,1,9,0,133,14,14,0,134,14,14,0,135,14,14,0,253,0,8,0,136,14,14,0,137,14,14,0,138,14,14,0,139,14,14,0,140,14,14,0,141,14,14,0,142,14,14,0,143,14,14,0,144,14,14,0,145,14,14,0,252,1,9,0,146,14,14,0,147,14,14,0,148,14,14,0,149,14,14,0,150,14,14,0,151,14,14,0,253,1,9,0,152,14,14,0,254,1,9,0,153,14,14,0,154,14,14,0,155,14,14,0,156,14,14,0,255,1,9,0,157,14,14,0,158,14,14,0,159,14,14,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,18,0,6,0,19,0,6,0,20,0,6,0,21,0,6,0,44,0,7,0,90,0,8,0,91,0,8,0,92,0,8,0,93,0,8,0,128,23,14,0,121,1,10,0,122,1,10,0,6,0,4,0,14,0,5,0,30,0,6,0,62,0,7,0,16,0,5,0,34,0,6,0,18,0,5,0,10,0,4,0,19,0,5,0,22,0,5,0,35,0,6,0,46,0,6,0,47,0,6,0,48,0,6,0,49,0,6,0,63,0,7,0,95,0,8,0,200,0,8,0,101,0,7,0,102,0,7,0,103,0,7,0,104,0,7,0,201,0,8,0,105,0,7,0,106,0,7,0,214,0,8,0,215,0,8,0,216,0,8,0,129,23,14,0,123,1,10,0,178,1,9,0,130,23,14,0,28,0,5,0,179,1,9,0,131,23,14,0,132,23,14,0,29,0,5,0,218,0,8,0,133,23,14,0,134,23,14,0,135,23,14,0,55,0,6,0,219,0,8,0,120,0,7,0,242,0,8,0,230,1,9,0,244,0,8,0,136,23,14,0,137,23,14,0,245,0,8,0,231,1,9,0,138,23,14,0,139,23,14,0,140,23,14,0,141,23,14,0,236,1,9,0,142,23,14,0,31,0,5,0,247,0,8,0,237,1,9,0,143,23,14,0,0,0,4,0,2,0,5,0,128,1,12,0,129,1,12,0,130,1,12,0,131,1,12,0,132,1,12,0,133,1,12,0,134,1,12,0,135,1,12,0,136,1,12,0,137,1,12,0,197,0,11,0,198,0,11,0,199,0,11,0,200,0,11,0,201,0,11,0,202,0,11,0,203,0,11,0,204,0,11,0,205,0,11,0,206,0,11,0,207,0,11,0,1,0,1,0,1,0,2,0,4,0,5,0,5,0,5,0,6,0,5,0,208,0,11,0,209,0,11,0,210,0,11,0,211,0,11,0,212,0,11,0,213,0,11,0,214,0,11,0,215,0,11,0,216,0,11,0,217,0,11,0,218,0,11,0,7,0,5,0,219,0,11,0,220,0,11,0,221,0,11,0,222,0,11,0,223,0,11,0,224,0,11,0,225,0,11,0,226,0,11,0,227,0,11,0,228,0,11,0,229,0,11,0,230,0,11,0,231,0,11,0,232,0,11,0,233,0,11,0,234,0,11,0,235,0,11,0,236,0,11,0,237,0,11,0,238,0,11,0,239,0,11,0,240,0,11,0,241,0,11,0,242,0,11,0,243,0,11,0,244,0,11,0,245,0,11,0,246,0,11,0,247,0,11,0,248,0,11,0,249,0,11,0,250,0,11,0,251,0,11,0,252,0,11,0,253,0,11,0,254,0,11,0,255,0,11,0,0,0,8,0,1,0,8,0,2,0,8,0,3,0,8,0,4,0,8,0,5,0,8,0,6,0,8,0,7,0,8,0,8,0,8,0,9,0,8,0,10,0,8,0,11,0,8,0,12,0,8,0,13,0,8,0,14,0,8,0,15,0,8,0,16,0,8,0,17,0,8,0,18,0,8,0,19,0,8,0,20,0,8,0,21,0,8,0,22,0,8,0,1,0,1,0,23,0,8,0,12,0,7,0,13,0,7,0,14,0,7,0,15,0,7,0,16,0,7,0,17,0,7,0,18,0,7,0,19,0,7,0,20,0,7,0,21,0,7,0,22,0,7,0,23,0,7,0,24,0,7,0,25,0,7,0,26,0,7,0,27,0,7,0,28,0,7,0,29,0,7,0,30,0,7,0,31,0,7,0,32,0,7,0,33,0,7,0,34,0,7,0,35,0,7,0,36,0,7,0,37,0,7,0,38,0,7,0,39,0,7,0,40,0,7,0,41,0,7,0,42,0,7,0,43,0,7,0,44,0,7,0,45,0,7,0,46,0,7,0,47,0,7,0,48,0,7,0,49,0,7,0,50,0,7,0,51,0,7,0,52,0,7,0,53,0,7,0,54,0,7,0,55,0,7,0,56,0,7,0,57,0,7,0,58,0,7,0,59,0,7,0,60,0,7,0,61,0,7,0,62,0,7,0,63,0,7,0,0,0,9,0,1,0,9,0,2,0,9,0,3,0,9,0,4,0,9,0,5,0,9,0,6,0,9,0,7,0,9,0,8,0,9,0,9,0,9,0,10,0,9,0,11,0,9,0,12,0,9,0,13,0,9,0,14,0,9,0,15,0,9,0,16,0,9,0,17,0,9,0,18,0,9,0,19,0,9,0,20,0,9,0,21,0,9,0,11,0,8,0,1,0,2,0,1,0,1,0,12,0,8,0,13,0,8,0,14,0,8,0,15,0,8,0,16,0,8,0,17,0,8,0,18,0,8,0,19,0,8,0,20,0,8,0,21,0,8,0,22,0,8,0,23,0,8,0,24,0,8,0,25,0,8,0,26,0,8,0,27,0,8,0,28,0,8,0,29,0,8,0,30,0,8,0,31,0,8,0,32,0,8,0,33,0,8,0,34,0,8,0,35,0,8,0,36,0,8,0,37,0,8,0,38,0,8,0,39,0,8,0,40,0,8,0,41,0,8,0,42,0,8,0,43,0,8,0,44,0,8,0,45,0,8,0,46,0,8,0,47,0,8,0,48,0,8,0,49,0,8,0,50,0,8,0,51,0,8,0,52,0,8,0,53,0,8,0,54,0,8,0,55,0,8,0,56,0,8,0,57,0,8,0,58,0,8,0,59,0,8,0,60,0,8,0,61,0,8,0,62,0,8,0,63,0,8,0,0,0,10,0,1,0,10,0,2,0,10,0,3,0,10,0,4,0,10,0,5,0,10,0,6,0,10,0,7,0,10,0,8,0,10,0,9,0,10,0,10,0,10,0,11,0,10,0,12,0,10,0,13,0,10,0,14,0,10,0,15,0,10,0,16,0,10,0,17,0,10,0,18,0,10,0,19,0,10,0,10,0,9,0,11,0,9,0,12,0,9,0,1,0,1,0,1,0,3,0,13,0,9,0,14,0,9,0,1,0,2,0,15,0,9,0,16,0,9,0,17,0,9,0,18,0,9,0,19,0,9,0,20,0,9,0,21,0,9,0,22,0,9,0,23,0,9,0,24,0,9,0,25,0,9,0,26,0,9,0,27,0,9,0,28,0,9,0,29,0,9,0,30,0,9,0,31,0,9,0,32,0,9,0,33,0,9,0,34,0,9,0,35,0,9,0,36,0,9,0,37,0,9,0,38,0,9,0,39,0,9,0,40,0,9,0,41,0,9,0,42,0,9,0,43,0,9,0,44,0,9,0,45,0,9,0,46,0,9,0,47,0,9,0,48,0,9,0,49,0,9,0,50,0,9,0,51,0,9,0,52,0,9,0,53,0,9,0,54,0,9,0,55,0,9,0,56,0,9,0,57,0,9,0,58,0,9,0,59,0,9,0,60,0,9,0,61,0,9,0,62,0,9,0,63,0,9,0,0,0,2,0,4,0,4,0,10,0,5,0,11,0,5,0,24,0,6,0,25,0,6,0,52,0,7,0,106,0,8,0,107,0,8,0,108,0,8,0,218,0,9,0,219,0,9,0,184,1,10,0,221,0,9,0,185,1,10,0,128,55,15,0,4,0,3,0,14,0,5,0,30,0,6,0,31,0,6,0,10,0,4,0,88,0,7,0,23,0,5,0,24,0,5,0,89,0,7,0,90,0,7,0,91,0,7,0,200,0,8,0,101,0,7,0,102,0,7,0,201,0,8,0,206,0,8,0,207,0,8,0,208,0,8,0,209,0,8,0,210,0,8,0,211,0,8,0,223,0,9,0,212,0,8,0,213,0,8,0,214,0,8,0,174,1,9,0,129,55,15,0,189,1,10,0,94,3,10,0,95,3,10,0,130,55,15,0,96,3,10,0,55,0,6,0,177,1,9,0,131,55,15,0,132,55,15,0,14,0,4,0,60,0,6,0,97,3,10,0,133,55,15,0,195,27,14,0,61,0,6,0,217,0,8,0,196,27,14,0,104,3,10,0,197,27,14,0,198,27,14,0,199,27,14,0,200,27,14,0,219,0,8,0,105,3,10,0,106,3,10,0,201,27,14,0,202,27,14,0,203,27,14,0,204,27,14,0,205,27,14,0,31,0,5,0,107,3,10,0,206,27,14,0,207,27,14,0,0,0,3,0,2,0,4,0,6,0,5,0,7,0,5,0,16,0,6,0,68,0,8,0,35,0,7,0,18,0,6,0,38,0,7,0,160,8,13,0,78,0,8,0,79,0,8,0,161,8,13,0,162,8,13,0,163,8,13,0,80,0,8,0,6,0,4,0,11,0,5,0,41,0,7,0,21,0,6,0,28,0,6,0,58,0,7,0,30,0,6,0,4,0,3,0,20,0,5,0,21,0,5,0,11,0,4,0,31,0,6,0,48,0,6,0,49,0,6,0,25,0,5,0,81,0,8,0,52,0,6,0,53,0,6,0,54,0,6,0,55,0,6,0,118,0,8,0,119,0,8,0,112,0,7,0,29,0,5,0,113,0,7,0,114,0,7,0,164,8,13,0,115,0,7,0,240,0,8,0,165,8,13,0,166,8,13,0,167,8,13,0,121,0,7,0,122,0,7,0,168,8,13,0,169,8,13,0,241,0,8,0,170,8,13,0,171,8,13,0,172,8,13,0,173,8,13,0,246,0,8,0,174,8,13,0,124,0,7,0,247,0,8,0,175,8,13,0,176,8,13,0,177,8,13,0,178,8,13,0,250,0,8,0,179,8,13,0,180,8,13,0,181,8,13,0,182,8,13,0,183,8,13,0,251,0,8,0,92,4,12,0,63,0,6,0,93,4,12,0,94,4,12,0,95,4,12,0,112,23,0,0,64,31,0,0,128,37,0,0,17,43,0,0,224,46,0,0,128,62,0,0,34,86,0,0,192,93,0,0,0,125,0,0,68,172,0,0,128,187,0,0,0,250,0,0,136,88,1,0,0,119,1,0,0,238,2,0,0,0,0,0,112,23,0,0,64,31,0,0,128,37,0,0,17,43,0,0,224,46,0,0,128,62,0,0,34,86,0,0,192,93,0,0,0,125,0,0,68,172,0,0,128,187,0,0,0,250,0,0,136,88,1,0,0,119,1,0,0,238,2,0,0,0,0,0,112,23,0,0,64,31,0,0,128,37,0,0,17,43,0,0,224,46,0,0,128,62,0,0,34,86,0,0,192,93,0,0,0,125,0,0,68,172,0,0,128,187,0,0,0,250,0,0,136,88,1,0,0,119,1,0,0,238,2,0,255,255,255,255,0,0,2,2,2,1,0,1,1,0,0,0,0,0,0,0,192,215,2,0,60,0,0,0,28,5,0,0,32,243,16,0,62,0,0,0,0,0,0,0,96,243,16,0,16,0,0,0,0,0,0,0,24,6,3,0,56,0,0,0,54,5,0,0,240,46,17,0,58,0,0,0,0,0,0,0,176,5,3,0,64,0,0,0,0,0,0,0,240,5,3,0,38,0,0,0,250,1,0,0,200,46,17,0,40,0,0,0,0,0,0,0,247,248,250,251,252,253,254,255,0,1,2,3,4,5,6,8,1,2,3,5,4,10,9,8,11,15,17,16,23,22,21,20,19,18,25,24,27,26,11,7,6,1,2,13,2,2,2,2,6,12,3,9,1,3,4,3,7,4,1,1,5,5,14,6,1,7,1,8,1,1,1,1,10,1,1,5,9,17,25,24,29,33,32,41,2,23,28,31,3,22,30,4,27,40,8,26,6,39,7,38,16,37,15,10,11,12,13,14,1,21,20,18,19,2,1,34,35,36,0,0,1,0,0,0,232,3,0,0,0,1,3,4,6,7,9,10,11,13,14,16,17,18,20,21,22,24,25,26,28,29,30,32,33,34,36,37,38,40,41,42,44,45,46,47,49,50,51,52,54,55,56,57,59,60,61,62,63,65,66,67,68,69,71,72,73,74,75,77,78,79,80,81,82,84,85,86,87,88,89,90,92,93,94,95,96,97,98,99,100,102,103,104,105,106,107,108,109,110,111,112,113,114,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,169,170,171,172,173,174,175,176,177,178,178,179,180,181,182,183,184,185,185,186,187,188,189,190,191,192,192,193,194,195,196,197,198,198,199,200,201,202,203,203,204,205,206,207,208,208,209,210,211,212,212,213,214,215,216,216,217,218,219,220,220,221,222,223,224,224,225,226,227,228,228,229,230,231,231,232,233,234,234,235,236,237,238,238,239,240,241,241,242,243,244,244,245,246,247,247,248,249,249,250,251,252,252,253,254,255,255,0,1,3,4,6,7,9,10,11,13,14,16,17,18,20,21,22,24,25,26,28,29,30,32,33,34,36,37,38,40,41,42,44,45,46,47,49,50,51,52,54,55,56,57,59,60,61,62,63,65,66,67,68,69,71,72,73,74,75,77,78,79,80,81,82,84,85,86,87,88,89,90,92,93,94,95,96,97,98,99,100,102,103,104,105,106,107,108,109,110,111,112,113,114,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,169,170,171,172,173,174,175,176,177,178,178,179,180,181,182,183,184,185,185,186,187,188,189,190,191,192,192,193,194,195,196,197,198,198,199,200,201,202,203,203,204,205,206,207,208,208,209,210,211,212,212,213,214,215,216,216,217,218,219,220,220,221,222,223,224,224,225,226,227,228,228,229,230,231,231,232,233,234,234,235,236,237,238,238,239,240,241,241,242,243,244,244,245,246,247,247,248,249,249,250,251,252,252,253,254,255,255,0,1,1,2,3,3,4,5,6,6,7,8,8,9,10,11,11,12,13,14,14,15,16,16,17,18,19,19,20,21,22,22,23,24,25,25,26,27,28,29,29,30,31,32,32,33,34,35,36,36,37,38,39,40,40,41,42,43,44,44,45,46,47,48,48,49,50,51,52,53,53,54,55,56,57,58,58,59,60,61,62,63,64,65,65,66,67,68,69,70,71,72,72,73,74,75,76,77,78,79,80,81,81,82,83,84,85,86,87,88,89,90,91,92,93,94,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,135,136,137,138,139,140,141,142,143,144,145,146,147,149,150,151,152,153,154,155,156,157,159,160,161,162,163,164,165,166,168,169,170,171,172,173,175,176,177,178,179,180,182,183,184,185,186,188,189,190,191,192,194,195,196,197,198,200,201,202,203,205,206,207,208,210,211,212,214,215,216,217,219,220,221,222,224,225,226,228,229,230,232,233,234,236,237,238,240,241,242,244,245,246,248,249,250,252,253,255,0,1,1,2,3,3,4,5,6,6,7,8,8,9,10,11,11,12,13,14,14,15,16,16,17,18,19,19,20,21,22,22,23,24,25,25,26,27,28,29,29,30,31,32,32,33,34,35,36,36,37,38,39,40,40,41,42,43,44,44,45,46,47,48,48,49,50,51,52,53,53,54,55,56,57,58,58,59,60,61,62,63,64,65,65,66,67,68,69,70,71,72,72,73,74,75,76,77,78,79,80,81,81,82,83,84,85,86,87,88,89,90,91,92,93,94,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,135,136,137,138,139,140,141,142,143,144,145,146,147,149,150,151,152,153,154,155,156,157,159,160,161,162,163,164,165,166,168,169,170,171,172,173,175,176,177,178,179,180,182,183,184,185,186,188,189,190,191,192,194,195,196,197,198,200,201,202,203,205,206,207,208,210,211,212,214,215,216,217,219,220,221,222,224,225,226,228,229,230,232,233,234,236,237,238,240,241,242,244,245,246,248,249,250,252,253,255,32,240,118,255,19,128,128,255,54,184,198,255,19,128,128,255,188,154,16,255,19,128,128,255,191,128,128,255,0,0,0,0,56,21,29,0,108,0,0,0,168,235,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,116,61,190,197,3,26,190,115,15,53,191,142,117,145,190,154,5,98,63,118,227,73,191,97,224,121,61,108,181,191,62,122,138,92,61,91,234,104,191,128,41,11,63,255,150,96,62,2,71,146,62,9,108,30,62,106,246,232,190,217,64,218,62,22,109,94,191,129,203,115,191,222,204,12,191,29,86,80,63,43,164,180,190,212,238,119,62,246,11,82,63,176,31,66,190,216,41,230,190,59,142,255,62,212,186,125,190,243,32,25,63,249,102,59,63,233,124,16,191,220,188,33,191,20,236,231,190,75,4,146,62,158,152,173,190,94,158,134,62,0,31,44,62,18,191,2,190,186,18,45,191,243,58,234,190,227,24,109,63,21,253,21,191,10,244,105,191,139,250,20,62,91,38,51,63,225,155,118,62,110,195,48,63,97,27,1,62,197,115,190,62,236,247,60,63,251,121,19,63,255,63,62,62,41,90,29,191,132,41,58,190,103,242,205,59,104,119,72,62,102,193,188,62,252,57,253,190,37,175,114,63,168,229,7,189,5,54,67,191,196,205,29,191,148,137,171,62,58,176,92,190,114,52,43,63,123,248,126,63,207,220,115,191,57,15,39,190,106,221,6,190,137,239,32,191,79,61,194,62,221,121,82,190,188,178,91,190,59,85,238,62,44,160,112,63,67,198,3,191,179,92,150,190,153,99,33,63,132,128,28,63,119,244,107,191,11,183,188,62,251,233,63,62,17,55,135,62,92,1,65,63,210,143,126,191,147,200,58,191,145,11,78,189,161,161,191,62,255,149,101,190,160,140,209,189,121,173,40,191,235,30,89,60,80,1,144,62,80,23,45,63,109,56,76,63,100,174,76,189,187,15,44,63,159,91,88,63,76,113,73,63,30,79,235,190,234,147,72,191,205,63,42,62,243,115,171,62,209,205,254,58,223,138,188,190,74,180,140,62,71,114,249,62,110,24,173,62,14,18,194,189,62,205,201,61,127,47,213,62,172,230,57,191,218,203,54,191,112,153,163,190,79,229,120,191,171,91,53,191,168,84,73,189,18,193,184,188,37,117,42,63,54,5,58,63,83,8,96,63,84,56,126,191,157,44,133,190,234,35,32,62,252,222,46,63,195,187,236,190,236,193,100,191,110,221,181,62,67,2,30,191,96,175,100,63,40,71,101,63,90,44,205,190,35,244,115,61,134,4,108,62,58,233,25,63,228,249,48,63,115,73,253,190,236,18,181,61,76,195,240,60,43,50,210,62,251,35,80,191,38,226,13,191,89,50,47,63,212,239,6,191,137,68,1,62,10,77,54,63,65,46,113,190,40,68,108,191,254,241,158,190,107,214,17,191,13,193,77,63,88,225,222,190,191,14,16,191,164,170,233,190,95,152,56,63,194,47,97,191,102,102,166,61,115,214,83,63,233,125,243,62,54,149,237,62,211,133,56,63,57,12,190,62,146,203,111,191,171,235,96,190,132,241,203,190,168,29,42,63,7,65,7,191,35,20,219,61,235,255,124,190,2,69,0,63,238,8,247,190,87,63,118,189,220,98,114,63,13,82,76,191,109,88,211,62,111,159,149,61,253,250,105,63,90,159,82,191,22,191,25,62,227,251,202,190,104,235,200,190,208,242,60,189,137,69,44,62,212,184,55,61,2,183,254,62,247,177,226,189,43,47,41,62,66,175,215,190,151,255,144,190,163,234,183,190,23,13,117,191,9,250,15,191,53,239,124,191,169,216,100,191,48,44,95,62,238,207,197,190,15,69,69,63,5,138,48,63,141,122,56,63,216,245,243,190,29,60,67,62,234,9,67,191,28,66,237,62,143,199,12,62,247,91,15,191,221,149,253,189,30,26,74,191,250,96,37,191,169,222,90,61,80,171,184,62,187,238,45,189,55,56,41,63,133,121,47,191,138,205,95,191,154,152,150,190,252,225,79,63,183,9,119,60,126,255,94,63,182,245,27,191,91,92,59,63,167,235,249,190,188,2,17,191,157,157,84,191,239,201,243,190,204,182,235,190,222,90,198,62,3,204,12,62,87,150,48,191,157,187,157,61,199,73,17,190,78,69,42,190,116,121,59,191,38,29,197,61,53,240,51,191,223,112,207,62,174,71,9,63,63,116,49,62,65,158,29,63,180,230,99,63,6,245,69,191,237,130,193,188,34,225,27,190,49,67,99,63,199,244,148,62,65,186,216,188,56,18,208,190,252,226,210,61,85,22,125,63,158,9,9,191,83,205,252,62,176,114,56,63,20,236,191,188,237,99,109,63,19,213,99,63,151,27,0,63,121,119,8,191,3,5,142,62,174,98,185,190,63,55,100,190,250,69,37,191,77,248,253,62,221,96,28,63,254,126,193,190,106,192,208,190,168,112,104,63,16,7,121,191,135,24,95,191,189,109,166,61,66,151,36,63,228,49,123,191,100,177,157,62,171,233,194,190,177,168,8,190,139,111,72,62,142,5,105,63,2,16,87,63,199,18,74,63,87,123,88,60,87,38,84,63,215,246,62,191,210,110,252,190,7,153,12,63,32,39,108,62,124,211,16,191,51,220,224,62,66,181,137,190,168,87,202,189,201,30,145,190,16,232,188,62,59,167,45,63,13,85,145,61,70,63,10,190,48,16,148,62,35,107,49,63,243,31,234,62,0,227,73,62,19,100,56,63,115,247,21,63,136,185,56,191,169,246,185,62,143,197,26,63,42,31,22,63,127,134,123,63,140,100,7,191,207,19,95,190,13,140,100,63,155,84,48,191,90,100,219,190,46,144,192,189,69,46,92,191,18,164,50,190,34,109,211,62,194,106,48,63,60,159,113,191,21,227,88,63,111,99,3,62,117,231,89,190,192,207,128,190,119,73,88,63,213,5,88,191,165,192,18,191,192,95,172,189,39,75,173,60,132,71,55,63,171,65,200,190,157,133,5,191,223,253,177,189,178,188,43,191,42,142,111,191,239,26,68,62,146,62,49,63,101,55,43,63,106,104,99,190,17,197,44,63,40,45,92,191,242,96,15,63,30,81,17,63,195,129,12,191,59,81,94,191,249,192,6,191,15,96,209,190,253,163,47,189,153,245,98,63,70,69,56,191,241,160,89,60,174,216,59,63,45,39,209,62,183,236,76,63,50,143,4,191,250,185,129,62,226,230,116,63,183,126,186,189,234,174,84,191,149,216,181,188,165,16,192,190,255,62,99,190,62,151,233,62,241,183,9,63,115,156,219,61,117,61,5,63,199,130,138,190,59,55,77,190,170,211,65,62,130,228,1,63,190,136,6,191,134,143,168,62,157,43,138,61,176,55,117,191,0,198,71,63,225,208,75,62,48,241,247,190,247,233,32,191,24,6,88,191,16,3,25,191,120,94,178,190,241,129,45,62,99,42,93,191,166,155,112,191,167,91,246,188,42,115,195,190,174,130,160,62,217,95,150,189,148,246,6,63,217,36,247,62,64,133,103,63,190,17,89,191,83,61,61,191,190,161,184,62,34,166,48,63,118,108,188,62,218,140,243,189,48,155,20,191,148,23,85,191,194,252,109,191,82,73,109,63,163,64,183,190,3,150,204,62,107,157,184,187,3,176,161,190,7,68,56,62,19,125,78,191,123,102,201,62,94,161,59,63,16,232,212,190,137,122,57,191,177,20,117,63,62,148,100,191,44,99,243,62,190,191,49,62,182,76,214,190,0,230,154,190,183,151,32,63,39,49,72,63,211,189,254,62,131,107,14,62,203,242,17,63,238,124,59,63,248,198,232,190,81,188,154,62,243,200,159,188,52,188,97,63,69,244,107,189,8,204,139,62,23,14,212,62,113,229,0,191,96,6,163,189,66,233,171,189,110,53,235,59,27,13,48,190,81,193,1,63,45,93,5,63,11,182,33,63,142,91,204,189,55,253,129,62,253,189,72,191,87,232,51,62,240,76,88,62,59,82,45,191,168,168,178,190,212,124,29,191,55,197,195,189,88,113,178,62,29,229,124,191,222,142,160,190,236,161,29,190,203,214,26,62,164,84,62,191,249,214,215,190,55,82,50,63,133,9,15,63,60,22,15,63,124,14,20,63,127,107,255,190,2,15,44,190,187,68,245,187,115,48,27,187,116,155,64,63,95,152,104,63,198,196,126,191,167,207,214,190,62,179,212,62,103,152,6,63,200,177,73,191,194,49,47,191,56,164,97,190,198,111,18,191,134,144,251,62,63,170,125,63,3,8,127,190,17,140,91,191,149,210,31,191,88,197,39,63,54,89,251,62,179,183,28,191,23,130,40,191,224,187,41,191,0,254,9,63,117,173,205,190,231,58,173,189,221,64,113,62,54,205,87,191,50,145,6,191,52,133,62,190,201,5,175,190,27,214,156,62,42,116,78,63,235,225,39,63,18,104,112,61,137,12,55,63,38,29,41,63,174,158,35,63,158,152,5,62,241,213,62,62,229,236,89,63,203,104,228,62,127,76,119,63,207,130,56,191,189,26,128,189,190,246,116,63,254,101,247,60,186,132,163,61,232,219,42,191,239,254,160,190,189,197,219,190,53,39,143,190,49,206,223,60,245,245,188,189,154,149,61,191,183,39,32,63,229,185,82,63,58,117,253,62,146,90,72,63,77,215,51,191,176,230,48,191,82,40,15,191,209,147,26,63,134,114,98,191,120,70,103,191,92,203,172,190,2,154,84,63,174,214,65,63,0,199,50,191,97,253,31,189,92,61,103,189,27,218,88,191,113,203,23,191,180,58,185,189,234,92,17,191,111,98,176,62,97,194,8,190,106,188,236,62,49,94,19,191,255,205,75,62,66,33,90,191,202,135,160,187,229,95,107,63,0,117,51,62,50,32,103,63,181,53,82,191,37,236,75,190,22,218,57,63,232,132,44,63,238,64,213,190,38,253,121,191,56,158,123,63,193,228,198,60,154,150,32,63,78,212,102,191,249,133,247,61,20,207,53,191,181,197,109,63,30,197,249,189,40,44,209,190,133,208,225,189,151,83,82,63,93,224,130,190,220,244,151,62,126,167,137,190,92,203,52,62,181,168,183,190,152,251,24,63,198,221,184,190,165,107,134,61,95,67,80,190,150,64,90,190,155,115,112,191,7,98,145,190,10,77,118,63,151,172,118,63,194,53,215,189,254,183,114,190,190,134,48,63,160,195,220,190,19,99,177,62,152,137,54,63,47,135,229,190,80,23,33,191,100,64,174,62,169,47,179,190,221,178,251,62,30,81,33,63,64,164,215,190,53,95,33,191,246,68,71,191,159,231,239,62,158,11,79,191,68,82,11,189,11,71,112,190,232,250,158,189,77,130,91,191,198,51,208,62,138,199,245,190,193,196,95,190,168,24,7,191,198,22,162,62,153,126,17,63,135,24,239,190,160,165,119,191,180,203,7,63,173,223,0,191,195,98,148,189,76,226,52,191,239,88,80,191,175,35,254,62,62,207,35,63,152,48,102,63,192,177,115,191,19,72,125,191,40,67,117,62,41,147,154,190,92,145,0,63,28,120,5,190,151,200,141,62,56,50,95,63,146,231,186,61,202,79,130,190,102,217,111,191,50,88,113,191,88,198,2,63,252,52,110,188,127,218,76,191,38,254,168,189,103,99,1,63,243,117,153,188,4,143,199,62,216,68,54,190,44,154,230,190,63,59,108,63,89,219,20,190,98,129,107,191,110,164,20,191,209,60,72,63,174,99,32,191,185,250,201,190,115,157,142,62,112,148,124,191,137,153,253,190,243,57,167,62,131,220,121,191,22,132,62,63,155,172,121,191,217,180,6,63,3,180,197,190,97,111,154,62,33,206,203,62,2,131,52,63,53,240,115,191,84,27,236,62,208,42,67,63,19,214,14,63,42,171,13,191,80,80,118,63,178,73,6,191,61,184,115,63,242,181,103,189,225,125,93,63,229,99,103,190,21,111,252,62,31,185,73,63,48,240,32,63,57,182,18,63,79,235,74,191,37,90,210,62,122,82,114,63,173,162,63,190,137,8,159,190,10,190,117,63,33,149,162,62,75,231,123,191,151,225,123,63,108,234,124,61,213,147,117,191,112,150,2,63,165,244,44,63,182,71,175,62,253,19,188,189,44,239,194,62,77,103,199,62,214,116,33,191,152,137,18,62,107,100,87,189,65,128,60,190,179,149,215,61,15,128,216,62,10,159,109,190,152,136,115,191,208,123,147,62,68,191,10,63,243,174,10,63,61,184,155,61,211,189,46,62,95,41,235,61,114,23,145,62,241,70,214,190,95,122,123,61,3,93,103,191,167,176,138,62,246,181,174,60,60,219,211,62,17,226,146,62,135,163,171,59,204,67,6,191,103,186,167,62,146,36,248,190,39,79,89,191,4,254,168,190,111,214,216,62,128,40,8,63,92,203,112,191,98,246,74,63,51,106,166,190,207,46,223,59,93,83,200,190,157,189,71,63,155,1,18,191,30,221,192,62,5,53,84,63,77,188,55,63,234,145,166,189,239,199,189,62,173,50,83,190,184,34,105,191,237,182,3,191,3,65,108,191,97,140,168,190,185,0,12,63,245,157,83,191,35,18,113,63,14,19,221,190,152,79,22,63,174,12,106,62,192,205,18,63,52,244,111,191,100,63,227,190,137,68,105,191,91,67,73,191,47,133,103,62,175,38,3,63,38,229,62,63,224,43,146,62,33,58,156,62,244,79,20,191,178,43,53,191,98,243,105,63,88,146,76,191,155,90,142,190,194,195,148,62,83,93,120,191,0,113,15,191,76,112,74,191,74,13,205,62,83,9,111,62,3,147,51,191,183,207,98,63,163,2,159,62,124,38,251,188,224,160,221,62,185,198,247,62,13,57,182,189,23,185,127,191,162,151,145,61,246,67,92,191,169,20,19,63,1,251,8,62,80,199,155,190,32,208,41,63,203,246,177,62,164,253,107,63,60,219,51,62,87,4,191,61,81,78,84,62,32,236,4,191,151,144,3,63,230,207,255,62,190,248,26,191,63,254,54,63,90,69,71,191,35,105,47,63,236,160,62,63,181,108,173,190,215,248,100,63,69,158,20,62,250,11,101,63,61,154,78,191,20,233,254,60,47,53,82,62,60,50,38,62,71,56,9,191,176,30,159,190,147,58,109,191,78,241,8,191,140,163,66,63,153,126,73,191,165,220,117,191,162,237,216,189,10,18,187,189,124,243,51,63,79,34,66,191,117,146,45,190,172,173,248,189,154,124,171,62,248,80,118,191,84,252,183,62,114,196,26,190,251,150,9,63,108,5,65,63,186,101,223,190,160,81,66,63,30,221,224,62,241,17,49,191,187,100,20,191,171,206,170,62,31,43,232,62,193,88,47,191,24,205,6,63,40,243,3,191,139,52,5,63,178,76,159,190,229,181,82,189,205,90,74,191,174,131,115,190,168,198,211,62,207,72,120,63,153,240,203,188,61,13,232,62,147,83,11,190,58,62,98,63,104,232,31,62,99,70,216,61,165,76,146,190,139,27,119,191,231,56,15,191,43,221,125,190,63,197,201,62,250,43,148,62,97,224,53,191,48,160,23,62,15,99,90,63,193,142,115,191,235,82,211,190,226,174,86,191,124,243,7,191,224,189,107,63,174,102,29,63,240,48,93,190,18,22,229,62,105,140,102,191,160,23,50,191,80,27,93,191,136,131,68,61,218,228,248,190,218,225,207,189,132,212,9,191,174,41,4,191,64,164,95,63,43,50,106,63,218,2,178,62,122,226,65,63,40,98,145,61,182,245,11,191,233,67,7,191,211,133,216,61,230,116,217,189,48,19,101,62,183,12,0,191,160,24,81,191,107,100,3,63,85,219,37,63,145,181,118,191,170,213,15,63,33,206,67,191,115,100,77,191,210,29,120,191,48,16,88,191,58,2,80,63,55,168,61,190,200,122,26,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+10240);
/* memory initializer */ allocate([209,117,105,63,10,242,243,61,120,95,61,63,100,31,36,189,212,11,34,63,134,57,185,190,11,211,215,62,218,29,98,191,40,241,249,190,97,55,172,62,71,199,237,62,26,22,59,191,11,184,23,191,238,237,106,63,7,180,132,190,159,88,3,63,188,2,65,190,200,234,118,63,7,180,124,191,247,175,172,187,103,158,244,62,78,39,41,63,242,35,254,60,211,77,34,61,46,89,101,63,177,50,106,62,214,55,144,61,2,183,114,191,108,238,40,61,237,156,98,63,198,195,39,63,129,180,63,189,45,151,141,59,124,70,202,62,194,194,105,63,251,177,185,190,133,121,119,191,176,88,171,62,94,219,123,190,17,228,232,190,17,112,168,190,52,19,72,191,138,32,62,190,103,127,160,61,70,37,93,191,218,29,14,63,199,46,209,190,95,96,86,189,162,8,5,63,246,150,202,190,171,64,113,63,143,25,40,187,45,36,60,191,201,200,217,188,77,131,118,191,255,202,86,191,154,65,76,191,243,29,220,61,2,130,73,191,51,53,121,62,71,170,239,187,196,65,94,63,235,173,77,191,218,59,127,63,37,202,134,62,41,235,99,191,71,58,187,190,27,215,151,62,94,130,227,62,10,216,198,62,133,121,87,63,217,118,98,191,209,88,27,63,59,29,176,190,145,100,70,62,139,51,62,63,195,240,73,191,176,1,73,63,245,100,158,190,223,23,59,63,186,73,28,191,159,227,187,190,117,32,139,190,207,219,176,190,234,63,27,63,30,78,112,190,155,227,60,190,80,254,78,63,55,112,95,63,236,162,232,60,216,186,84,61,119,188,9,190,159,200,211,189,201,118,126,62,16,205,12,190,18,20,87,191,52,101,183,62,15,95,254,62,247,174,233,62,31,49,74,190,154,35,235,189,1,162,152,62,131,24,168,189,162,11,2,191,99,66,116,63,253,105,99,191,23,216,67,191,96,174,85,191,196,151,101,63,139,84,152,189,127,105,101,63,7,178,54,191,159,3,15,63,119,77,192,190,235,254,113,189,36,14,41,62,122,139,199,62,59,167,65,63,227,196,215,188,232,107,134,62,181,78,92,190,122,114,121,191,42,57,95,191,63,115,46,63,5,136,9,193,102,148,185,63,200,195,97,186,39,7,206,63,194,244,136,148,16,147,221,63,9,31,89,223,17,172,229,63,35,236,118,30,94,181,234,63,52,149,153,96,165,27,240,63,115,135,245,208,195,131,242,63,52,207,26,143,156,68,245,63,27,177,129,58,6,232,247,63,148,120,131,99,171,143,250,63,136,50,67,7,190,137,253,63,226,26,175,98,112,108,0,64,254,160,248,241,19,39,2,64,141,110,168,11,189,245,3,64,211,145,165,212,250,188,5,64,122,36,89,156,245,84,7,64,67,182,116,16,41,130,183,63,130,138,43,41,30,176,207,63,212,50,67,123,93,156,222,63,97,71,83,165,124,28,228,63,232,51,133,174,130,40,233,63,38,250,33,219,158,197,237,63,233,8,131,99,52,129,241,63,98,54,249,20,157,8,244,63,238,227,75,93,119,24,247,63,242,72,255,52,117,123,250,63,188,214,116,49,204,68,254,63,175,142,205,89,25,198,0,64,166,189,28,209,152,98,2,64,176,140,43,124,102,220,3,64,12,99,14,103,94,118,5,64,176,170,127,140,144,12,7,64,110,108,91,116,240,156,204,63,252,13,0,188,81,57,218,63,131,13,156,171,30,123,230,63,66,116,29,110,52,185,241,63,71,79,75,220,124,77,246,63,61,211,148,171,59,201,250,63,47,161,41,84,227,72,255,63,138,153,44,142,132,194,1,64,33,105,159,38,45,21,4,64,190,192,211,60,108,67,6,64,111,248,44,114,128,30,195,63,182,57,17,102,154,197,215,63,2,254,38,157,19,166,232,63,125,67,139,106,157,249,240,63,3,24,221,93,138,59,245,63,228,244,200,178,38,74,249,63,143,67,177,87,7,112,253,63,42,161,226,89,181,228,0,64,131,2,194,209,13,15,3,64,228,154,45,98,25,126,5,64,176,13,11,63,136,62,248,189,216,24,125,190,0,4,140,61,172,65,17,62,170,248,128,62,154,218,189,62,68,11,212,62,142,60,18,63,253,211,21,63,30,43,17,63,177,223,35,63,228,15,37,63,22,49,44,63,220,186,255,62,54,182,14,63,56,248,80,62,48,40,2,190,32,14,104,190,224,112,38,189,192,169,109,188,0,240,231,60,88,77,174,61,64,3,187,61,144,225,5,62,20,70,69,62,148,148,108,62,96,206,144,62,66,103,162,62,46,139,226,62,180,150,151,62,158,194,179,62,30,177,78,63,32,26,37,61,87,13,10,63,66,95,49,63,69,98,38,63,108,153,59,63,40,140,70,63,132,208,70,63,59,204,97,63,40,163,87,63,88,208,99,63,103,78,89,63,81,141,93,63,194,62,44,63,178,238,29,63,233,243,44,63,170,19,187,62,56,67,173,189,224,197,183,188,16,134,229,61,16,4,209,61,60,94,50,62,28,26,90,62,20,51,93,62,126,80,185,62,82,80,214,62,127,167,11,63,90,81,9,63,153,252,10,63,66,126,179,62,54,194,168,62,0,101,185,62,64,200,60,62,192,87,147,60,174,228,159,62,144,83,184,62,36,154,124,62,52,123,94,62,60,75,74,62,136,42,241,61,64,30,245,61,80,251,173,61,232,40,197,61,188,252,34,62,208,144,107,62,80,214,157,62,204,60,207,62,90,246,200,62,0,18,226,188,136,203,162,189,88,62,239,61,16,239,34,62,248,139,187,61,112,208,60,61,208,65,102,61,64,80,10,60,128,124,28,188,80,130,39,189,0,13,26,189,160,198,136,188,200,90,134,61,128,25,251,61,104,209,106,62,60,98,91,62,204,213,244,62,25,187,159,191,122,24,250,62,189,136,70,63,81,179,45,63,255,180,40,63,247,33,30,63,2,142,36,63,221,74,10,63,121,31,13,63,21,118,36,63,180,135,216,62,224,184,2,63,179,123,3,63,130,232,229,62,210,93,243,62,212,8,146,62,132,213,176,191,48,250,66,62,152,150,249,62,48,43,235,62,78,39,214,62,196,192,213,62,148,193,235,62,172,95,209,62,218,64,199,62,100,171,240,62,164,14,116,62,190,113,143,62,14,254,173,62,188,167,141,62,154,195,172,62,22,175,23,63,48,146,197,62,7,167,137,63,82,64,19,63,102,55,13,63,40,133,248,62,124,161,241,62,61,119,0,63,150,131,155,62,84,243,3,63,223,135,97,63,40,140,70,63,11,25,24,63,238,120,203,62,129,178,23,63,4,23,28,63,198,4,154,62,32,183,144,61,15,51,89,63,70,205,131,62,80,42,144,62,116,179,69,62,48,54,129,62,92,207,137,62,224,63,2,62,128,213,135,62,95,183,37,63,183,15,7,63,94,31,201,62,220,76,118,62,26,60,205,62,214,69,233,62,51,225,59,63,88,174,219,62,22,156,47,63,229,137,34,63,90,173,77,63,31,215,89,63,190,239,91,63,6,112,141,63,232,71,178,63,157,209,171,63,17,222,138,63,74,246,100,63,140,164,91,63,253,43,49,63,36,179,15,63,104,82,220,62,144,45,232,62,176,169,184,61,14,105,177,62,106,173,177,62,231,144,5,63,139,99,22,63,143,247,25,63,0,139,106,63,72,36,164,63,211,19,156,63,175,6,99,63,100,197,38,63,165,249,31,63,254,9,228,62,14,170,187,62,144,149,101,62,134,208,219,62,234,33,169,62,186,64,30,63,227,8,125,63,247,213,125,63,179,66,75,63,84,148,154,62,232,50,122,62,240,154,232,62,124,206,15,63,50,161,250,62,240,245,40,63,170,7,33,63,58,223,14,63,215,194,11,63,32,242,237,62,148,75,16,62,128,74,164,187,126,160,130,62,4,46,45,63,205,21,54,63,162,6,238,62,32,228,246,60,32,44,193,188,176,150,208,61,8,16,120,62,52,104,118,62,186,206,204,62,246,30,190,62,178,227,166,62,42,159,195,62,88,231,147,62,47,249,69,63,60,5,85,63,160,170,167,63,11,61,132,63,102,223,132,63,246,175,114,63,135,89,121,63,73,189,113,63,127,133,100,63,37,53,95,63,115,52,93,63,177,36,87,63,191,254,85,63,53,129,68,63,130,132,48,63,175,2,58,63,44,40,187,62,112,187,237,62,13,204,155,63,137,138,85,63,188,186,86,63,163,219,43,63,36,118,46,63,2,35,33,63,138,103,4,63,181,69,5,63,76,119,10,63,27,166,7,63,37,3,20,63,114,6,0,63,6,8,242,62,48,127,221,62,69,232,99,63,140,111,235,62,1,169,35,63,206,136,229,62,19,65,31,63,255,222,33,63,131,212,52,63,124,92,190,62,209,253,43,63,32,165,73,63,240,188,143,62,40,167,159,62,29,158,43,63,87,40,68,63,190,86,54,63,16,1,73,63,220,82,33,63,104,35,250,61,186,225,180,62,72,171,16,62,236,193,177,62,104,227,175,62,228,180,228,62,100,95,14,62,134,143,209,62,160,105,10,63,120,103,141,61,232,208,169,61,218,217,236,62,92,241,17,63,183,229,13,63,13,143,39,63,248,98,225,189,148,189,194,62,202,190,78,63,50,187,48,63,204,29,77,63,176,147,72,63,236,208,81,63,77,142,86,63,132,166,77,63,140,76,64,63,108,172,35,63,46,16,28,63,70,136,49,63,63,69,43,63,28,227,35,63,177,93,15,63,232,245,53,190,96,43,240,188,92,185,27,62,156,203,50,62,8,142,99,62,212,73,156,62,74,120,152,62,98,114,194,62,224,219,173,62,158,106,152,62,82,221,128,62,216,35,118,62,188,171,182,62,20,27,169,62,146,113,172,62,200,122,169,62,62,8,15,63,26,106,239,62,192,163,14,62,200,244,202,189,160,44,167,189,56,201,234,189,64,133,63,188,224,206,85,61,192,144,38,62,90,177,149,62,96,84,206,62,94,226,231,62,50,96,240,62,108,126,1,63,136,115,9,63,10,178,2,63,20,158,96,62,224,27,248,61,192,87,147,60,92,29,79,190,232,92,16,190,88,53,89,190,88,17,236,189,16,143,115,189,192,16,72,188,160,172,224,60,248,225,16,62,236,87,81,62,40,0,94,62,38,240,133,62,206,109,171,62,196,211,189,62,229,72,24,63,196,222,52,63,183,4,113,63,93,31,111,63,90,47,98,63,1,28,121,63,134,177,89,63,69,232,99,63,76,234,95,63,12,235,48,63,51,244,35,63,75,150,50,63,251,116,23,63,212,42,26,63,66,225,69,63,153,19,28,63,28,60,1,62,212,47,5,62,87,208,40,63,135,81,39,63,10,94,16,63,79,191,50,63,8,61,247,62,77,199,14,63,216,15,235,62,142,198,151,62,54,255,137,62,48,58,170,62,52,118,146,62,234,159,148,62,172,183,236,62,20,134,172,62,17,211,97,63,93,157,90,63,58,105,148,62,204,113,63,63,98,205,2,63,117,147,91,63,122,24,250,62,226,222,72,63,229,183,68,63,111,7,52,63,21,76,43,63,106,253,91,63,163,55,112,63,221,21,123,63,51,53,46,63,200,240,35,63,192,28,15,63,198,138,215,62,192,72,212,60,124,31,221,62,48,124,87,62,62,157,11,63,252,163,54,62,186,187,228,62,210,219,222,62,172,95,209,62,136,131,204,62,188,52,25,63,137,241,47,63,253,108,59,63,68,183,225,62,68,141,232,62,115,25,35,63,98,144,33,63,252,28,55,63,24,102,49,63,16,182,106,62,146,155,165,62,159,228,118,63,97,244,124,63,18,77,95,63,62,196,223,62,124,115,207,62,198,35,253,62,87,13,10,63,157,209,24,63,60,143,218,62,44,132,255,62,58,197,216,62,204,186,186,62,30,124,222,62,32,5,214,62,0,228,37,186,112,21,112,61,124,19,67,63,208,177,80,63,117,185,43,63,196,147,86,62,152,17,95,62,158,41,142,62,156,225,160,62,240,1,195,62,244,15,137,62,194,154,143,62,154,222,230,62,82,244,114,63,254,20,91,63,28,189,83,63,207,9,49,63,104,112,59,63,192,51,32,63,181,157,32,63,159,25,6,63,238,253,4,63,250,201,210,62,250,48,173,62,214,65,192,62,186,61,249,62,168,145,17,63,75,188,2,63,112,155,202,61,77,222,31,63,100,171,240,62,150,242,199,62,184,168,134,62,72,25,154,62,252,60,92,62,40,191,83,62,40,15,29,62,164,243,57,62,32,168,209,61,160,35,25,61,240,206,183,61,164,94,61,62,170,15,146,62,8,114,134,62,229,210,126,63,80,149,116,63,92,226,82,63,33,100,122,63,87,231,57,63,101,216,73,63,68,22,75,63,171,68,61,63,142,217,96,63,100,61,133,63,49,202,130,63,233,121,106,63,109,172,94,63,234,174,52,63,194,43,68,63,158,228,59,63,98,148,74,63,137,134,44,63,238,146,1,63,192,181,52,63,34,54,178,62,106,28,222,62,222,193,226,62,218,106,192,62,195,161,24,63,255,226,74,63,176,254,75,63,195,184,41,63,171,236,33,63,140,111,235,62,184,244,7,63,125,72,13,63,234,125,237,62,48,198,119,61,116,72,66,62,106,66,174,62,238,17,241,62,33,46,6,63,45,43,27,63,14,9,37,63,184,57,59,63,74,135,56,63,135,123,32,63,15,173,27,63,116,144,251,62,182,184,180,62,126,172,253,62,113,163,19,63,92,162,10,62,224,201,224,188,1,16,133,57,32,247,222,60,224,122,99,61,184,182,133,61,136,252,206,61,200,205,219,61,44,163,32,62,56,15,98,62,212,219,18,62,196,170,103,62,48,15,241,61,96,62,133,60,98,129,129,62,42,75,209,62,88,82,120,63,56,224,125,63,233,121,106,63,73,82,110,63,83,45,102,63,12,113,110,63,20,237,103,63,135,131,114,63,219,224,117,63,10,18,112,63,215,118,107,63,240,16,99,63,8,198,89,63,171,7,92,63,209,1,85,63,221,189,95,63,50,23,148,62,96,197,97,61,216,216,182,61,40,82,237,61,112,132,185,61,112,86,151,61,208,229,33,61,64,231,196,60,192,111,67,61,176,230,153,61,104,226,239,61,180,63,31,62,0,201,13,62,0,56,58,62,220,137,87,62,180,231,3,62,188,3,210,62,178,78,170,62,14,239,238,62,120,249,1,63,193,215,22,63,236,197,218,62,32,34,119,61,132,234,93,191,129,32,142,191,248,94,184,189,192,144,38,62,8,92,24,62,224,116,211,62,83,14,3,63,19,0,21,63,40,113,12,63,0,252,28,61,212,47,5,62,24,8,107,62,196,142,138,62,44,147,190,62,204,225,45,62,168,107,191,189,159,36,94,191,19,70,137,191,28,164,93,190,0,130,186,187,96,1,247,188,208,6,5,62,120,24,132,62,164,74,178,62,128,222,124,62,90,104,26,63,144,48,13,63,218,194,219,62,195,180,0,63,90,24,81,63,73,217,139,63,181,230,124,63,252,177,51,63,158,125,128,62,228,116,125,62,45,234,16,63,164,188,3,63,130,255,246,62,8,213,24,63,89,131,25,63,167,214,9,63,72,71,188,62,82,179,135,62,88,102,34,62,156,165,98,62,134,127,14,63,63,180,87,63,242,172,66,63,2,158,231,62,72,123,139,61,104,4,151,61,234,75,162,62,190,220,146,62,182,73,136,62,146,29,186,62,58,48,220,62,156,164,191,62,210,115,0,63,241,218,41,63,156,217,47,63,154,229,52,63,72,36,17,63,128,101,126,61,176,249,129,61,176,179,109,62,125,15,85,63,230,76,124,63,151,100,84,63,74,47,29,63,89,215,11,63,110,76,44,63,41,132,47,63,54,247,24,63,206,63,137,62,90,51,170,62,172,221,188,62,126,252,198,62,112,7,142,62,108,147,45,190,88,152,10,190,192,64,130,60,67,236,22,63,188,56,66,63,117,97,16,63,0,208,188,62,18,39,174,62,156,61,229,62,120,227,244,62,230,145,206,62,220,67,98,63,233,14,103,63,43,143,59,63,169,252,79,63,82,72,101,63,227,227,140,63,128,247,162,63,53,251,153,63,152,189,138,63,129,102,119,63,105,85,60,63,32,184,49,63,123,23,49,63,123,107,35,63,50,122,38,63,127,83,25,63,226,195,14,63,10,91,235,62,174,18,194,62,186,41,13,63,5,191,59,63,32,20,118,63,228,76,153,63,255,2,142,63,175,6,99,63,169,206,45,63,112,187,237,62,138,77,206,62,208,124,224,62,22,61,198,62,48,127,221,62,176,6,189,62,81,34,90,63,55,98,87,63,136,77,57,63,155,15,105,63,158,14,53,63,248,220,37,63,88,90,233,62,144,103,67,62,96,23,105,189,144,140,207,189,40,228,128,62,212,146,248,62,126,3,21,63,189,174,22,63,98,37,30,63,172,102,31,63,2,184,29,63,132,29,235,62,38,80,243,62,124,38,43,63,48,127,221,62,114,194,208,62,72,244,108,62,64,55,142,60,140,32,98,190,162,88,154,190,48,144,3,61,8,7,131,62,148,124,184,62,186,118,177,62,22,126,208,62,154,138,244,62,101,86,53,63,175,113,102,63,66,244,45,63,25,29,163,63,130,2,175,63,127,207,160,63,147,17,91,63,124,42,84,63,202,83,75,63,51,248,76,63,134,24,52,63,185,68,12,63,43,162,35,63,58,246,31,63,25,178,12,63,124,161,241,62,186,206,204,62,172,60,38,63,78,169,234,62,156,255,146,63,199,70,160,63,43,198,143,63,166,115,29,63,101,231,8,63,48,1,242,62,179,230,6,63,72,10,219,62,76,150,140,62,18,20,198,62,250,52,214,62,26,228,177,62,38,72,161,62,112,49,104,63,14,204,67,63,34,58,219,62,97,41,12,63,102,178,211,62,108,253,240,62,248,236,232,62,204,255,237,62,150,32,234,62,214,241,246,62,56,232,238,62,238,231,247,62,210,196,205,62,12,14,220,62,74,235,237,62,0,238,27,63,174,45,252,62,204,122,83,62,160,70,194,61,252,205,47,62,128,63,203,61,124,127,8,62,12,152,0,62,16,193,0,62,24,170,195,61,176,24,229,61,224,128,12,62,20,66,28,62,96,224,184,61,188,252,34,62,128,50,111,62,16,223,192,62,254,24,163,62,32,39,94,63,224,20,71,63,128,232,80,63,19,199,92,63,190,67,78,63,37,160,98,63,156,221,88,63,160,29,106,63,246,3,101,63,199,38,93,63,173,102,90,63,42,21,62,63,229,30,31,63,241,111,38,63,11,90,34,63,240,173,76,189,192,222,140,61,40,60,156,62,146,113,172,62,110,8,253,62,88,193,195,62,38,125,17,63,35,34,1,63,13,185,32,63,98,228,19,63,227,19,19,63,29,219,12,63,242,77,217,62,226,249,161,62,6,130,180,62,250,113,183,62,60,223,163,62,34,8,113,63,49,84,27,63,104,185,182,62,40,229,35,62,152,119,150,62,48,166,80,62,210,127,154,62,238,177,131,62,94,142,245,62,51,160,49,63,121,77,47,63,132,36,57,63,77,115,28,63,130,21,4,63,86,167,248,62,240,95,139,61,124,229,32,63,36,187,128,62,32,206,161,61,16,230,140,189,224,206,85,61,0,23,183,187,208,0,92,61,192,45,154,60,80,215,64,62,176,10,230,62,58,48,220,62,206,52,243,62,90,74,187,62,170,187,159,62,126,76,144,62,68,190,47,63,177,112,138,63,134,223,123,63,75,112,98,63,241,161,113,63,145,136,99,63,33,96,81,63,56,178,91,63,87,124,54,63,18,73,54,63,55,10,60,63,76,104,75,63,146,21,73,63,150,127,83,63,74,177,49,63,35,38,42,63,78,203,145,62,68,26,116,63,128,79,43,63,237,173,0,63,99,52,24,63,48,62,211,62,126,252,198,62,68,137,191,62,88,68,123,62,182,245,149,62,42,220,164,62,14,44,208,62,150,135,196,62,172,160,219,62,242,54,200,62,214,172,195,62,214,22,145,63,40,254,132,63,103,181,51,63,221,204,30,63,166,245,49,63,10,7,249,62,94,252,29,63,100,239,31,63,224,58,23,63,247,205,43,63,62,119,59,63,96,72,52,63,29,70,16,63,224,16,30,63,236,55,44,63,132,162,36,63,16,224,129,63,151,184,70,63,208,79,97,62,188,218,123,62,150,108,138,62,64,238,12,62,174,33,129,62,4,73,134,62,8,165,116,62,4,96,151,62,186,141,194,62,170,19,187,62,96,34,131,62,242,134,145,62,230,145,206,62,230,122,189,62,225,96,34,63,63,119,118,63,208,127,5,63,192,232,185,188,166,199,15,63,174,29,57,63,80,229,61,63,212,199,104,63,28,86,121,63,114,205,71,63,8,87,45,63,103,158,34,63,6,157,238,62,200,68,22,63,235,82,43,63,253,62,25,63,86,56,204,62,110,34,51,63,164,56,109,62,144,104,131,190,84,125,137,62,122,150,229,62,130,232,229,62,210,77,48,63,241,50,69,63,207,177,21,63,236,113,232,62,226,211,209,62,120,24,132,62,242,222,172,62,84,114,243,62,25,113,2,63,70,129,227,62,41,230,1,64,71,44,40,63,159,220,36,63,178,196,36,63,75,253,12,63,88,9,28,63,91,77,27,63,101,231,8,63,98,129,129,62,28,136,227,62,240,54,51,63,234,113,83,63,45,192,23,63,78,0,2,63,38,57,226,62,200,234,120,62,72,233,244,63,174,167,190,62,226,188,192,62,26,102,198,62,160,117,164,62,142,53,196,62,152,20,229,62,116,159,186,62,240,183,166,61,42,239,140,62,32,242,237,62,210,119,41,63,20,96,220,62,30,246,160,62,238,135,138,62,242,92,121,63,32,90,137,63,9,110,121,63,109,237,104,63,165,1,114,63,106,85,119,63,91,85,109,63,52,225,118,63,81,187,127,63,212,115,118,63,162,82,111,63,215,141,124,63,152,161,112,63,36,168,121,63,243,19,88,63,101,197,97,63,83,3,109,63,126,146,132,63,87,170,88,63,31,150,79,63,169,210,86,63,174,75,91,63,29,162,84,63,183,88,99,63,226,12,107,63,219,243,93,63,29,162,84,63,22,76,102,63,132,124,84,63,224,1,95,63,66,53,56,63,242,88,80,63,32,162,8,63,192,78,246,62,192,216,192,190,128,188,246,189,0,0,184,189,0,80,232,187,0,101,232,61,192,251,8,62,224,113,191,62,96,18,197,62,192,18,216,62,144,93,10,63,192,193,5,63,224,223,12,63,64,6,8,63,160,149,225,62,0,202,53,62,128,246,43,62,0,98,138,190,0,51,11,190,64,187,20,190,0,252,181,189,0,66,210,188,0,144,27,187,0,247,219,61,128,153,18,62,192,255,10,62,64,118,81,62,64,140,137,62,224,79,174,62,96,81,164,62,128,251,24,62,96,128,61,63,128,172,171,61,128,12,38,63,128,80,29,63,192,172,59,63,144,226,55,63,32,98,62,63,128,70,67,63,208,239,67,63,176,145,71,63,176,5,87,63,96,221,86,63,144,108,82,63,176,86,63,63,16,9,43,63,16,42,38,63,64,242,145,62,0,224,94,189,0,222,245,188,0,172,167,60,0,187,6,61,0,100,113,61,128,27,163,61,128,58,243,61,64,56,7,62,0,154,29,62,64,62,96,62,192,179,146,62,32,68,152,62,64,218,133,62,0,119,119,62,128,185,120,62,16,237,28,63,224,229,58,63,0,92,84,62,160,38,0,63,64,69,18,63,96,153,9,63,176,26,33,63,32,92,16,63,16,131,61,63,16,195,50,63,160,5,239,62,160,124,43,63,240,55,96,63,224,43,94,63,224,43,94,63,32,245,71,63,96,229,152,62,128,103,167,62,0,248,29,60,128,100,56,62,0,88,125,62,0,161,97,62,64,2,154,62,0,235,136,62,224,140,226,62,192,43,207,62,0,90,83,62,192,147,216,62,192,73,31,63,80,78,40,63,64,123,45,63,128,18,41,63,96,206,57,63,192,228,1,63,32,27,202,190,240,133,6,63,24,47,135,63,192,122,120,63,208,3,121,63,80,40,107,63,32,136,81,63,80,206,104,63,48,82,93,63,208,122,73,63,32,128,34,63,160,44,3,63,32,183,145,62,32,139,166,62,128,123,220,62,128,135,95,62,128,1,251,190,0,161,54,62,16,65,71,63,0,25,55,63,208,141,61,63,112,236,25,63,16,201,10,63,240,117,41,63,144,182,33,63,80,71,15,63,224,92,202,62,192,165,182,62,192,29,26,62,192,28,4,62,160,142,157,62,96,56,130,62,160,32,145,62,0,58,7,63,32,248,8,63,160,33,253,62,192,134,231,62,224,4,158,62,192,248,114,62,128,207,167,61,0,227,13,190,0,193,173,189,0,6,28,189,0,39,244,61,160,72,165,62,192,66,154,62,0,82,104,61,0,74,161,60,128,194,139,61,128,76,87,62,64,30,123,62,0,4,83,62,128,234,37,62,128,150,160,61,0,89,43,61,0,24,80,189,64,167,96,190,0,109,40,190,128,115,11,190,0,234,251,188,0,58,24,62,192,74,113,62,32,169,224,62,112,136,18,63,160,96,29,63,0,83,127,63,248,15,149,63,104,78,152,63,120,46,132,63,128,163,49,63,16,63,27,63,32,242,239,62,192,232,237,62,96,167,250,62,144,191,16,63,96,185,25,63,144,47,30,63,112,215,36,63,0,153,7,62,64,110,120,62,224,94,160,62,224,104,60,63,240,148,121,63,192,28,116,63,192,126,79,63,32,227,210,62,32,72,154,62,64,110,77,62,0,187,110,62,224,204,129,62,224,204,172,62,224,22,210,62,128,17,210,62,128,231,231,62,80,202,59,63,224,155,107,63,160,109,248,62,240,92,93,63,16,254,58,63,48,24,64,63,48,5,33,63,224,166,48,63,48,97,36,63,176,183,4,63,64,148,227,62,64,52,136,62,192,116,91,62,64,106,118,62,192,166,247,62,0,74,15,63,224,236,188,62,0,84,254,62,0,246,240,61,208,68,3,63,0,164,165,62,192,108,175,62,128,140,119,62,0,129,169,62,128,166,134,62,64,50,90,62,0,26,8,62,0,2,64,61,0,76,6,188,0,240,111,60,128,230,121,62,160,133,174,62,208,73,113,63,64,181,117,63,160,182,29,63,48,129,52,63,80,111,78,63,192,4,104,63,112,49,125,63,40,127,128,63,24,84,132,63,64,3,114,63,192,161,118,63,224,140,78,63,32,154,47,63,64,18,100,63,48,193,127,63,160,146,129,63,80,137,48,63,192,42,37,63,96,77,162,62,0,141,218,62,128,13,17,63,80,179,69,63,96,116,98,63,0,250,103,63,128,125,116,63,112,215,79,63,240,47,92,63,16,237,28,63,224,201,1,63,64,223,52,63,112,74,73,63,224,210,70,63,64,108,16,63,0,231,192,189,0,42,41,61,128,102,57,62,32,32,177,62,96,183,215,62,32,85,225,62,128,42,10,63,224,143,15,63,48,136,34,63,64,170,47,63,48,98,58,63,128,9,58,63,48,13,37,63,128,70,24,63,32,41,12,63,192,68,67,62,0,161,84,189,0,20,121,189,0,160,246,186,0,231,28,61,0,129,20,61,0,9,89,61,0,220,141,61,128,48,195,61,192,249,7,62,128,102,14,62,64,4,67,62,0,236,113,62,0,90,83,62,0,183,108,62,64,168,106,62,0,122,125,63,128,127,117,63,128,183,102,63,80,66,77,63,160,152,100,63,192,232,89,63,224,6,97,63,96,30,98,63,80,28,101,63,160,121,106,63,112,232,109,63,160,78,106,63,112,187,108,63,176,23,96,63,128,126,95,63,32,130,78,63,32,153,216,62,0,74,62,189,0,136,149,60,128,132,237,61,0,148,112,62,192,81,140,62,32,240,152,62,128,96,185,62,64,223,200,62,160,93,240,62,240,45,5,63,112,32,9,63,80,112,14,63,192,72,9,63,128,87,245,62,96,51,1,63,112,129,122,63,192,205,97,63,128,3,203,62,0,66,245,62,0,19,200,62,64,208,214,62,128,112,150,62,0,123,209,62,192,89,187,62,128,95,206,62,128,109,213,62,144,202,0,63,128,151,0,63,80,24,13,63,80,16,9,63,240,106,14,63,64,199,40,63,96,53,150,62,0,121,102,61,192,198,3,62,0,76,155,61,128,60,244,61,0,120,80,61,128,181,240,61,128,24,140,61,0,127,202,61,0,58,189,61,0,83,58,62,64,59,73,62,0,44,103,62,128,38,156,62,192,64,153,62,96,71,54,63,0,231,72,63,208,73,27,63,64,61,57,63,192,142,44,63,80,76,39,63,96,49,191,62,128,44,245,62,32,214,225,62,64,88,49,63,112,181,137,63,176,180,142,63,216,18,137,63,240,190,99,63,224,226,35,63,144,118,1,63,192,145,215,62,64,223,243,62,96,83,165,62,192,217,208,62,128,212,200,62,224,177,180,62,192,235,0,62,0,26,94,62,128,12,98,62,64,207,235,62,80,61,96,63,240,222,115,63,240,102,98,63,0,60,51,63,224,148,230,62,160,98,178,62,64,131,6,63,192,242,8,63,112,32,52,63,0,192,31,63,16,126,37,63,64,247,64,63,144,198,84,63,64,194,59,63,96,109,178,62,128,24,61,62,128,24,183,61,32,170,203,62,192,104,68,63,160,39,108,63,80,192,97,63,160,205,62,63,224,124,132,62,32,65,129,62,128,191,211,62,64,57,160,62,32,69,174,62,32,7,229,62,112,116,8,63,128,115,216,62,128,57,221,61,0,80,146,187,0,229,148,189,192,45,34,62,176,189,7,63,224,59,59,63,128,110,44,63,96,38,16,63,128,43,75,63,16,232,90,63,240,191,121,63,128,52,101,63,112,64,111,63,224,96,56,63,32,189,86,63,112,78,75,63,64,77,65,63,16,28,74,63,16,234,91,63,240,7,72,63,160,44,89,63,224,127,93,63,224,209,91,63,64,95,117,63,32,209,244,62,192,70,242,62,112,53,84,63,176,20,30,63,160,238,57,63,160,71,186,62,80,239,13,63,32,207,243,62,224,179,224,62,192,140,0,63,176,35,16,63,128,149,233,62,0,224,4,63,160,0,24,63,80,183,28,63,64,133,50,63,232,69,137,63,152,193,133,63,240,4,92,63,160,170,66,63,128,166,72,63,0,75,80,63,64,38,67,63,208,32,28,63,112,172,36,63,224,183,35,63,128,116,47,63,0,123,61,63,144,109,61,63,192,231,67,63,144,123,68,63,240,71,61,63,160,47,112,63,16,140,87,63,0,21,158,62,32,91,185,62,192,163,181,62,224,36,217,62,0,83,146,62,128,123,89,62,0,64,113,62,224,17,143,62,32,221,164,62,96,151,199,62,96,155,201,62,160,199,207,62,64,126,216,62,32,20,214,62,128,134,131,63,16,10,140,63,88,26,130,63,128,230,104,63,144,168,112,63,0,203,101,63,32,229,106,63,128,220,99,63,96,89,106,63,144,2,115,63,32,37,128,63,176,160,132,63,248,153,132,63,208,153,110,63,144,189,101,63,80,149,97,63,88,151,128,63,176,2,139,63,96,189,113,63,80,81,63,63,112,160,73,63,32,182,61,63,96,1,62,63,96,57,47,63,160,195,57,63,224,117,88,63,80,157,101,63,240,171,111,63,144,195,104,63,240,156,82,63,16,135,63,63,112,120,53,63,0,204,97,62,0,60,84,188,0,35,199,61,128,130,236,61,0,240,194,61,0,238,28,62,0,231,3,62,128,47,51,62,64,239,34,62,192,157,90,62,0,174,125,62,0,231,134,62,32,74,155,62,32,141,167,62,32,88,162,62,64,104,162,62,0,80,87,59,0,187,54,189,0,46,233,60,0,184,126,60,0,200,206,187,0,36,185,60,0,132,14,60,0,180,214,60,0,122,142,60,0,170,19,61,0,47,22,61,0,104,176,60,0,212,40,61,128,129,214,61,64,214,0,62,0,202,121,61,128,38,25,62,32,184,167,62,32,29,92,63,48,76,47,63,64,77,65,63,80,245,16,63,16,107,49,63,0,172,64,63,48,227,58,63,16,125,58,63,16,48,41,63,96,188,5,63,224,210,218,62,32,98,19,63,160,214,236,62,240,41,3,63,0,68,16,189,0,173,47,189,96,71,159,62,64,56,138,62,96,91,169,62,192,227,82,62,128,208,110,62,224,16,164,62,128,188,145,62,128,197,171,62,128,189,122,62,64,10,27,62,0,157,217,61,32,202,133,62,192,112,89,62,128,161,153,62,64,52,31,63,128,117,26,63,192,9,233,62,224,225,161,62,96,174,146,62,96,152,30,63,240,251,65,63,192,203,128,63,96,55,89,63,80,131,45,63,16,219,62,63,128,225,185,62,64,90,110,62,240,106,14,63,160,196,227,62,192,232,194,62,0,102,134,62,224,48,137,62,192,97,60,62,0,150,9,61,0,232,240,60,224,156,148,62,128,232,253,62,160,100,74,63,176,41,19,63,96,51,192,62,160,152,248,62,0,40,223,61,0,172,20,61,96,252,185,62,96,70,137,62,64,17,140,62,224,217,52,63,64,232,226,62,48,73,67,63,16,39,58,63,48,253,71,63,64,218,71,63,160,23,100,63,112,87,101,63,80,165,105,63,208,96,103,63,96,179,108,63,240,99,118,63,192,38,121,63,240,243,61,63,192,142,1,63,240,215,4,63,224,255,176,62,0,124,116,188,128,136,162,62,32,87,183,62,128,74,217,62,96,232,218,62,16,182,22,63,112,217,37,63,192,206,33,63,0,169,41,63,240,215,47,63,192,90,61,63,240,79,65,63,80,12,7,63,192,115,157,62,192,232,194,62,0,24,224,62,160,29,251,62,208,83,32,63,112,17,23,63,0,217,213,62,0,114,181,60,128,38,37,190,128,250,100,190,0,205,222,189,0,128,19,187,0,110,215,61,96,91,169,62,192,98,213,62,192,225,255,62,0,222,237,62,240,217,5,63,0,139,251,61,128,31,43,62,32,21,150,62,96,142,130,62,0,5,19,62,0,92,230,189,128,111,95,190,192,110,139,190,128,30,33,190,0,146,171,189,0,89,5,189,128,205,209,61,128,128,70,62,96,170,144,62,64,31,102,62,224,111,147,62,64,46,28,63,0,63,74,63,16,71,117,63,48,100,102,63,160,127,109,63,128,219,120,63,160,34,127,63,144,137,118,63,64,9,117,63,208,51,102,63,224,70,86,63,128,230,61,63,32,170,55,63,96,191,28,63,16,183,44,63,208,250,51,63,0,245,175,61,0,54,187,61,16,149,27,63,240,16,12,63,240,40,24,63,96,55,46,63,176,3,43,63,128,117,26,63,48,91,33,63,224,143,249,62,224,189,186,62,192,212,141,62,32,67,130,62,160,137,133,62,32,147,170,62,0,125,253,62,64,108,207,62,120,21,141,63,16,132,83,63,64,70,40,63,48,73,24,63,80,233,10,63,192,96,255,62,0,194,223,62,128,92,226,62,128,118,196,62,32,230,190,62,64,201,189,62,160,125,213,62,0,69,182,62,128,75,153,62,128,124,199,62,128,208,146,61,112,230,108,63,128,96,142,62,128,234,123,62,0,139,43,62,0,109,28,62,0,229,2,62,0,53,251,61,0,156,238,61,0,39,201,61,128,5,195,61,0,7,228,61,128,124,25,62,0,150,192,61,128,115,164,61,192,211,31,62,48,213,51,63,192,131,60,63,48,132,118,63,208,169,118,63,168,125,138,63,8,149,147,63,80,51,166,63,64,121,162,63,136,118,164,63,152,212,164,63,176,77,155,63,136,234,136,63,120,17,139,63,208,52,124,63,240,203,84,63,128,6,78,63,64,172,153,62,128,196,104,62,0,194,32,63,176,144,49,63,0,73,79,63,64,173,113,63,248,42,141,63,96,156,150,63,80,91,143,63,176,149,148,63,192,133,136,63,16,35,99,63,192,133,104,63,224,159,66,63,0,122,39,63,16,84,59,63,0,200,131,61,240,78,46,191,64,246,147,62,176,61,29,63,64,187,34,63,192,189,46,63,80,62,32,63,32,55,253,62,176,47,22,63,160,192,34,63,240,88,5,63,128,113,215,62,96,55,3,63,32,105,192,62,224,219,10,63,144,4,30,63,0,107,130,189,16,49,66,191,128,49,174,61,32,113,153,62,128,96,185,62,128,137,227,62,192,99,235,62,96,200,159,62,192,168,205,62,176,175,0,63,192,135,210,62,192,254,162,62,128,186,187,62,192,95,59,62,32,98,167,62,32,182,209,62,160,127,109,63,160,18,119,63,32,208,117,63,48,202,110,63,32,188,107,63,48,8,99,63,32,178,102,63,0,97,91,63,80,202,102,63,0,160,101,63,48,204,111,63,208,202,113,63,192,152,92,63,176,81,82,63,176,87,85,63,80,62,75,63,64,9,48,62,128,253,233,61,0,18,255,61,192,143,40,62,128,63,16,62,128,132,194,61,0,196,222,60,0,186,217,60,0,208,210,187,0,164,50,188,0,88,121,60,0,250,206,60,0,196,136,60,0,195,150,61,128,236,246,61,192,23,66,62,80,175,24,63,112,68,27,63,48,10,57,63,160,29,60,63,0,17,147,61,128,173,114,62,192,137,123,62,96,3,254,62,80,27,36,63,96,53,45,63,80,88,45,63,32,133,58,63,96,178,43,63,176,179,2,63,208,193,1,63,48,4,11,63,0,118,142,62,128,37,134,62,128,135,226,62,96,46,211,62,128,84,237,189,0,142,152,60,0,88,196,59,64,207,61,62,224,181,182,62,224,33,194,62,160,246,209,62,64,84,238,62,128,69,236,62,192,86,164,62,0,203,163,62,32,113,196,62,176,30,78,63,32,195,89,63,224,87,116,63,176,246,14,63,16,96,22,63,240,157,18,63,128,39,30,63,112,21,68,63,240,222,115,63,72,110,133,63,24,8,137,63,152,140,128,63,16,188,25,63,224,0,199,62,224,172,242,62,176,124,39,63,128,128,244,62,48,223,13,63,112,122,54,63,128,213,91,62,64,36,128,62,0,219,126,62,96,18,154,62,64,0,239,62,96,104,49,63,224,39,92,63,240,227,96,63,128,19,63,63,224,188,164,62,0,143,2,62,32,175,141,62,16,15,3,63,176,10,25,63,96,96,2,63,152,115,137,63,64,212,68,63,80,76,82,63,64,169,68,63,0,127,254,62,192,128,142,62,128,211,135,62,160,155,185,62,64,239,17,63,144,32,1,63,96,247,204,62,64,41,4,63,160,160,18,63,176,201,13,63,64,232,140,62,192,249,50,62,96,16,91,63,64,46,219,62,160,173,3,63,64,245,211,62,64,113,57,62,0,120,51,60,0,220,1,61,128,131,172,61,64,57,160,62,160,223,133,62,192,41,32,62,0,234,112,62,128,101,166,62,128,127,179,62,176,152,53,63,32,63,66,63,136,6,237,63,48,47,129,63,16,208,78,63,176,25,97,63,112,49,82,63,64,45,92,63,224,252,48,63,80,199,36,63,208,38,31,63,192,196,28,63,112,19,24,63,240,81,23,63,128,141,38,63,176,129,20,63,32,151,172,62,0,183,239,62,200,56,246,63,32,44,78,63,80,57,8,63,48,93,34,63,112,102,1,63,96,46,20,63,192,79,225,62,224,63,209,62,0,234,200,62,192,18,216,62,160,91,196,62,32,153,216,62,176,226,4,63,192,80,204,62,224,177,32,63,88,93,142,63,112,83,131,63,64,218,114,63,64,32,107,63,64,239,103,63,240,114,104,63,16,5,84,63,112,18,88,63,96,238,73,63,96,46,63,63,16,183,44,63,176,198,33,63,0,235,31,63,0,244,57,63,0,35,60,63,64,153,120,62,120,230,138,63,160,55,30,63,48,110,21,63,96,109,221,62,160,220,239,62,128,194,191,62,224,254,154,62,128,184,186,62,128,181,118,62,128,2,93,62,192,55,82,62,128,33,87,62,128,26,105,62,96,144,174,62,96,38,207,62,160,210,86,63,80,16,95,63,224,124,145,63,112,113,146,63,216,122,146,63,32,59,139,63,72,155,134,63,8,70,129,63,48,239,107,63,16,41,102,63,240,110,102,63,48,57,102,63,224,54,78,63,16,169,80,63,32,47,58,63,144,56,56,63,224,76,237,62,0,170,20,63,56,124,144,63,240,167,141,63,240,202,137,63,208,194,109,63,80,71,101,63,16,120,77,63,0,46,44,63,48,239,21,63,32,129,13,63,0,181,4,63,128,231,231,62,112,231,1,63,0,50,237,62,48,53,14,63,226,232,249,62,106,157,76,190,169,69,198,190,96,71,51,60,40,176,38,61,210,34,55,62,96,100,43,62,175,148,174,62,253,238,207,62,130,169,5,63,154,205,24,62,208,134,12,190,175,103,137,190,72,192,126,189,40,211,127,189,128,103,223,187,128,44,249,187,240,79,139,61,220,55,216,61,236,190,245,61,123,30,75,63,0,239,162,58,109,15,217,62,148,88,13,63,184,83,38,63,176,114,36,63,155,142,55,63,79,138,55,63,75,32,71,63,178,246,86,63,58,187,141,62,64,85,73,189,104,107,5,189,48,49,214,60,40,117,64,61,12,1,133,61,164,29,160,61,144,64,211,61,12,172,244,61,170,12,123,62,122,161,56,63,62,217,41,62,224,100,38,60,49,72,16,63,162,166,168,63,46,120,152,63,21,55,144,63,202,179,82,63,228,67,92,63,189,58,79,63,211,84,187,62,176,58,167,61,74,71,86,190,32,79,71,62,197,246,138,63,55,251,114,63,153,155,88,63,31,245,4,63,246,248,24,63,242,129,7,63,76,98,115,63,106,105,104,63,251,151,96,63,236,36,94,63,227,106,77,63,124,17,80,63,221,26,83,63,163,190,96,63,104,6,114,63,187,130,124,63,185,57,48,63,24,165,48,63,195,184,52,63,201,192,39,63,99,149,21,63,8,43,14,63,113,185,22,63,138,66,38,63,178,200,69,63,199,126,71,63,120,191,117,62,248,128,70,62,176,109,227,62,197,35,229,62,148,109,156,62,246,180,50,62,232,130,240,61,148,45,139,61,0,64,160,61,78,155,45,62,96,145,139,60,240,191,207,60,160,49,84,62,134,89,67,62,36,138,224,61,120,240,5,61,32,38,92,188,48,252,60,189,40,191,24,189,176,49,199,188,173,179,11,63,58,69,193,62,254,7,6,63,185,78,153,62,8,54,117,62,244,182,18,63,26,67,127,63,155,20,149,63,181,30,103,63,255,27,71,63,236,86,106,62,220,252,241,61,42,101,84,62,96,123,17,61,0,88,35,187,176,240,132,62,190,91,63,63,159,12,105,63,110,191,23,63,143,95,244,62,198,119,39,63,173,41,36,63,72,51,67,63,210,89,72,63,34,195,247,62,53,140,169,62,201,95,234,62,189,117,91,63,25,185,113,63,97,11,84,63,186,6,146,62,52,225,133,62,128,39,216,62,66,235,220,62,202,229,18,62,200,127,50,61,140,18,15,62,165,118,13,63,113,218,44,63,63,121,12,63,5,154,44,63,121,209,135,63,179,104,134,63,155,254,116,63,154,188,110,63,113,159,108,63,249,52,106,63,3,239,84,63,109,7,69,63,49,177,45,63,170,222,105,62,178,82,121,63,106,157,8,63,59,181,254,62,93,182,204,62,251,34,188,62,148,63,139,62,229,147,133,62,240,205,85,62,234,151,43,62,109,74,191,62,59,220,197,191,165,243,107,63,176,193,75,63,63,95,60,63,234,42,57,63,5,36,58,63,145,107,47,63,67,109,48,63,77,177,40,63,112,70,255,61,244,190,219,191,188,38,52,63,177,234,245,62,94,97,240,62,99,85,238,62,155,83,5,63,141,211,7,63,151,95,7,63,42,31,7,63,35,124,129,63,73,255,124,63,57,225,86,63,123,148,99,63,136,184,100,63,218,255,99,63,1,22,108,63,239,181,101,63,238,253,108,63,13,64,110,63,16,130,2,63,96,13,47,188,168,90,17,62,66,156,143,62,174,115,190,62,68,45,189,62,105,152,237,62,116,225,0,63,111,40,15,63,158,77,42,63,66,201,120,63,219,242,66,63,30,118,94,62,70,236,251,62,184,183,220,62,57,251,0,63,47,1,239,62,151,174,8,63,78,8,228,62,246,92,207,62,168,132,39,63,204,209,246,61,64,108,165,187,174,203,33,62,74,3,6,62,190,36,46,62,180,60,50,62,24,51,95,62,224,116,73,62,164,122,46,62,99,44,68,63,140,22,206,62,172,201,176,63,185,7,149,63,189,21,137,63,186,51,123,63,213,46,129,63,35,174,104,63,104,19,71,63,128,169,81,63,33,188,177,62,88,174,118,61,16,205,178,63,97,197,138,63,48,223,100,63,49,59,59,63,89,9,60,63,246,202,7,63,142,180,208,62,9,58,232,62,34,53,5,62,62,125,7,62,218,163,65,63,236,200,59,63,15,222,74,63,145,153,26,63,159,143,48,63,68,45,189,62,34,175,144,62,15,197,162,62,128,189,170,188,96,112,89,189,19,152,176,62,86,141,195,62,26,180,228,62,158,190,143,62,146,194,196,62,188,120,234,61,224,218,124,61,188,41,157,61,202,133,65,63,48,164,88,63,170,47,37,63,132,192,144,63,150,196,135,63,118,42,115,63,84,21,62,63,218,71,31,63,133,78,40,63,78,151,50,63,182,38,175,62,33,175,220,62,184,104,143,62,197,132,110,63,241,50,82,63,13,77,29,63,181,64,165,62,66,100,124,62,104,204,141,62,140,81,180,62,127,208,66,63,144,192,49,63,131,21,147,63,179,195,222,62], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+20480);
/* memory initializer */ allocate([226,53,28,63,196,230,31,63,142,172,60,63,237,246,38,63,226,86,50,63,113,172,65,63,71,177,201,62,19,152,176,62,191,203,124,63,112,142,186,61,171,147,143,62,194,231,147,62,102,230,207,62,6,44,168,62,86,95,178,62,112,193,246,62,0,107,72,63,125,118,151,63,69,237,254,63,128,228,93,63,135,0,108,63,112,185,98,63,34,246,111,63,232,212,61,63,137,184,62,63,140,27,53,63,133,224,239,62,128,237,149,63,29,31,254,63,18,229,30,63,236,154,42,63,53,119,26,63,71,228,27,63,19,198,193,62,62,175,215,62,150,57,176,62,34,44,239,62,100,223,213,62,220,173,164,61,54,27,60,190,176,140,56,190,152,234,158,189,128,25,205,188,180,13,181,61,60,197,90,62,184,196,177,62,24,50,243,61,132,232,229,61,128,60,28,189,240,240,105,190,202,192,107,190,66,10,50,190,180,62,10,190,16,107,96,189,250,15,133,56,136,152,95,61,126,247,13,63,170,88,245,62,73,12,82,63,48,164,88,63,149,213,107,63,215,5,101,63,3,75,119,63,246,235,105,63,123,43,108,63,56,179,107,63,88,12,241,61,248,212,47,189,112,76,7,189,136,47,104,61,248,81,201,61,116,52,35,62,94,93,49,62,186,160,109,62,70,65,140,62,195,41,192,62,0,61,55,63,83,1,35,63,124,18,154,191,75,242,53,63,80,66,48,63,191,183,59,63,88,94,62,63,242,24,54,63,248,242,23,63,201,54,26,63,139,153,187,62,124,248,167,62,175,115,167,191,188,46,200,62,125,117,186,62,18,14,201,62,181,156,199,62,254,61,209,62,13,39,160,62,183,58,202,62,52,108,131,63,251,245,135,63,135,81,133,63,26,67,127,63,51,250,121,63,5,141,125,63,12,136,117,63,128,18,111,63,211,17,103,63,90,75,104,63,50,79,124,63,119,5,135,63,58,140,122,63,8,122,91,63,122,10,86,63,250,190,81,63,238,23,61,63,83,47,52,63,72,38,34,63,104,183,36,63,192,157,31,63,0,120,67,63,189,58,79,63,67,4,57,63,16,48,122,189,220,12,11,190,108,151,113,190,180,223,163,61,92,103,203,62,130,5,2,63,178,188,152,62,125,45,255,62,20,67,212,62,6,44,168,62,110,3,164,190,233,241,178,190,78,101,242,190,78,39,57,190,8,7,248,61,56,242,76,62,179,128,100,63,35,102,97,63,226,132,29,63,71,18,45,63,63,233,73,63,201,214,128,63,148,156,138,63,49,114,132,63,32,226,122,63,166,158,105,63,29,120,24,63,14,156,30,63,156,183,149,62,115,246,181,62,176,173,10,63,37,17,95,63,13,110,127,63,10,188,97,63,108,184,67,63,22,20,41,63,220,61,148,63,217,152,132,63,15,235,69,63,171,21,47,63,247,25,47,63,236,154,42,63,208,233,48,63,149,108,40,63,212,142,45,63,150,213,31,63,126,79,147,63,44,12,87,63,38,133,113,62,82,48,130,62,166,103,126,62,131,46,134,62,166,8,137,62,69,242,138,62,247,33,157,62,148,4,165,62,204,236,12,62,248,238,160,63,44,255,91,63,96,50,31,63,161,71,3,63,18,19,10,63,97,32,227,62,244,236,221,62,224,28,230,62,231,233,204,62,48,145,237,189,143,37,159,63,118,4,246,62,33,201,134,62,156,48,53,62,190,82,63,62,218,62,31,62,6,178,28,62,16,154,24,62,238,165,31,62,186,22,58,62,128,158,11,188,164,134,151,61,54,38,57,62,150,221,141,62,74,66,171,62,52,199,219,62,202,87,10,63,19,249,19,63,87,28,18,63,0,16,104,187,240,24,154,188,128,11,189,187,0,220,88,60,16,197,101,61,80,8,91,61,100,54,205,61,206,230,49,62,92,191,46,62,126,179,39,62,180,253,118,63,248,100,128,63,239,63,115,63,234,147,86,63,76,39,65,63,206,29,67,63,200,80,54,63,249,157,59,63,148,226,64,63,156,208,61,63,210,185,63,62,32,64,6,188,244,244,135,61,48,75,197,61,72,144,80,61,24,166,103,61,80,67,65,61,188,192,165,61,68,224,214,61,148,79,51,62,187,228,45,63,200,192,115,63,108,151,7,63,165,67,187,62,50,251,199,62,39,209,159,62,17,158,139,62,106,152,161,62,55,101,146,62,15,197,162,62,34,73,108,62,71,26,193,62,204,84,152,61,80,30,213,60,200,173,67,61,160,131,32,61,224,207,186,60,0,154,106,61,248,59,10,61,152,149,73,61,62,108,93,63,181,89,115,63,185,171,133,63,149,209,149,63,164,173,162,63,81,95,169,63,151,183,159,63,172,96,147,63,230,109,132,63,240,50,120,63,183,150,236,62,155,142,17,63,210,194,101,63,62,25,134,63,195,42,157,63,106,81,157,63,137,29,153,63,138,167,128,63,230,225,94,63,236,108,63,63,107,113,214,62,46,229,25,63,174,253,241,62,90,147,35,63,9,227,44,63,50,197,72,63,135,98,29,63,251,190,43,63,186,254,35,63,110,53,10,63,36,92,207,61,100,193,108,62,176,151,53,62,33,96,143,62,61,109,171,62,159,92,222,62,47,132,144,62,177,155,168,62,219,217,154,62,2,243,117,62,60,68,1,63,156,90,75,63,70,31,116,63,119,213,112,63,190,124,123,63,60,134,121,63,198,220,129,63,114,133,118,63,217,222,115,63,186,169,109,63,208,234,103,61,148,78,199,61,134,203,20,63,50,151,17,63,79,243,46,63,101,97,41,63,97,221,66,63,197,27,43,63,98,116,37,63,65,161,28,63,42,156,101,63,240,155,111,63,80,40,96,63,186,136,87,63,240,214,85,63,55,67,46,63,22,238,171,62,115,95,173,62,232,115,180,62,119,37,230,62,79,164,7,63,189,217,235,62,169,160,252,62,24,22,226,62,179,149,205,62,60,46,82,62,184,7,7,189,64,111,125,188,96,64,43,61,178,7,39,62,151,115,34,63,40,87,33,64,23,200,132,63,240,168,106,63,145,245,98,63,113,8,100,63,7,43,90,63,222,164,58,63,162,19,61,63,76,111,34,63,99,65,135,62,240,116,36,64,253,158,90,63,165,59,39,63,100,215,27,63,56,205,21,63,71,18,7,63,106,185,221,62,46,86,203,62,189,79,184,62,230,199,2,63,40,213,68,61,229,68,193,191,46,119,44,63,138,239,64,63,180,224,67,63,65,223,89,63,120,177,42,63,40,242,65,63,46,138,53,63,6,100,10,62,36,65,73,190,240,207,208,191,46,203,164,62,38,149,211,62,19,197,238,62,197,160,20,63,228,220,202,62,179,181,246,62,51,63,251,62,180,10,91,63,79,8,71,63,112,251,143,188,84,191,64,190,244,193,65,62,29,87,248,62,43,133,32,63,54,249,33,63,178,189,38,63,180,133,27,63,13,244,223,62,251,128,179,62,80,22,156,189,88,239,144,190,32,76,128,189,240,161,25,62,32,63,133,62,89,109,142,62,176,43,162,62,180,37,184,62,150,137,66,62,156,75,133,61,138,250,45,62,15,138,105,63,185,230,104,63,131,75,62,63,6,104,33,63,104,55,4,63,173,190,213,62,157,130,5,63,196,90,144,61,240,115,138,60,48,85,154,60,148,11,15,63,128,250,4,63,139,52,181,62,140,124,120,62,74,63,48,62,84,114,12,62,79,219,132,62,107,201,98,63,223,248,104,63,76,102,100,63,205,232,110,63,214,226,130,63,171,26,135,63,232,150,140,63,224,131,144,63,71,166,132,63,95,130,109,63,226,81,246,62,11,11,20,63,253,255,46,63,42,220,67,63,244,220,102,63,228,231,127,63,176,208,130,63,132,19,134,63,219,51,105,63,79,8,71,63,126,53,223,62,48,8,105,62,144,122,203,61,88,146,52,62,72,61,216,61,64,149,208,61,68,162,239,61,60,32,250,61,124,205,59,62,138,6,153,62,172,37,33,62,12,67,213,61,184,155,79,61,184,23,160,61,128,28,193,59,0,97,48,187,0,154,75,187,64,173,231,59,96,179,62,60,200,254,103,61,56,85,90,63,109,137,77,63,219,158,239,62,246,209,103,63,24,231,175,63,155,255,141,63,28,22,211,62,88,253,204,62,254,210,34,63,246,61,36,63,16,192,217,62,12,198,195,62,202,181,43,62,6,47,6,63,136,139,153,63,52,167,104,63,108,177,250,61,192,153,149,61,114,71,157,62,142,38,193,62,89,6,13,63,120,223,144,62,128,158,16,187,164,139,213,61,211,18,132,63,96,181,169,63,181,114,173,63,240,65,126,63,191,50,56,63,247,69,46,63,93,46,137,62,80,172,196,61,208,2,11,190,182,70,4,190,90,37,37,63,104,50,127,63,215,118,115,63,71,43,41,63,115,136,194,62,159,69,191,62,85,41,127,63,98,68,131,63,228,227,122,63,36,64,75,63,216,46,84,63,204,201,86,63,69,179,93,63,70,191,108,63,209,169,105,63,18,82,94,63,45,202,74,63,85,18,113,63,185,207,90,63,189,233,8,63,23,135,31,63,221,152,43,63,157,225,50,63,207,149,80,63,145,154,61,63,68,76,38,63,224,100,19,62,60,130,163,190,232,89,79,190,100,233,61,190,176,168,179,61,6,157,37,62,20,15,158,62,19,102,193,62,83,52,200,62,121,165,245,62,96,171,128,188,16,29,54,190,30,55,31,190,14,51,52,190,56,240,120,189,128,18,132,188,88,26,33,61,236,105,155,61,152,91,238,61,212,109,71,62,173,19,141,63,89,238,126,63,142,133,238,62,77,42,158,62,36,133,191,62,184,173,151,62,15,89,162,62,54,217,119,62,44,168,135,62,249,93,150,62,21,175,240,62,36,64,57,62,144,72,255,60,192,175,45,60,144,72,255,60,96,107,218,60,48,142,181,60,144,62,128,60,184,193,97,61,176,225,206,61,182,195,149,62,142,0,175,62,119,226,59,63,147,117,59,63,66,151,58,63,220,224,74,63,25,189,69,63,175,42,72,63,216,35,85,63,245,163,75,63,216,40,101,61,48,214,58,189,136,99,61,189,132,218,205,189,176,133,81,189,152,141,58,189,64,231,144,187,56,236,56,61,252,100,252,61,94,137,85,62,138,108,100,62,172,190,103,191,123,64,159,63,172,145,138,63,189,171,104,63,158,53,97,63,35,102,93,63,196,33,79,63,188,106,67,63,231,50,63,63,24,235,79,190,107,87,181,191,123,87,173,63,175,65,86,63,163,102,29,63,162,90,14,63,59,137,11,63,216,229,254,62,108,14,215,62,231,26,251,62,233,219,27,63,215,184,24,63,3,156,39,63,161,1,91,63,87,13,153,190,204,55,118,62,65,250,182,62,137,250,63,63,219,231,68,63,101,183,46,63,249,55,132,62,228,87,139,62,78,69,177,62,236,208,246,62,88,192,244,190,60,5,146,189,96,249,163,60,101,110,217,62,180,151,238,62,116,163,213,62,50,102,150,63,67,229,137,63,60,65,135,63,248,47,131,63,194,165,126,63,19,113,118,63,31,203,116,63,99,67,104,63,218,242,67,63,190,23,37,63,79,108,148,63,182,26,111,63,152,184,202,62,24,28,189,62,235,124,200,62,239,241,158,62,61,38,179,62,224,15,101,62,122,189,39,62,188,136,57,62,46,15,117,63,98,97,112,63,223,115,41,63,49,86,47,63,32,74,58,63,204,178,72,63,51,121,76,63,230,91,70,63,179,201,53,63,169,78,58,63,253,187,20,63,115,190,14,63,35,125,181,62,2,52,186,62,178,78,191,62,19,178,229,62,96,222,239,62,142,114,229,62,182,252,176,62,66,78,229,62,72,246,0,62,136,162,167,63,151,43,138,63,12,31,128,63,65,246,103,63,27,243,107,63,139,59,101,63,16,127,106,63,53,133,91,63,246,118,63,63,96,227,188,190,237,194,195,63,29,122,59,63,245,14,210,62,69,225,195,62,82,205,144,62,148,95,135,62,162,100,123,62,108,40,126,62,244,32,111,62,252,190,9,63,118,233,35,62,124,173,134,189,72,200,116,190,116,244,198,190,206,126,212,190,173,176,153,190,0,167,20,190,144,89,6,62,33,71,143,62,36,121,84,62,112,113,101,61,188,237,195,189,6,32,148,190,230,42,199,190,241,158,200,190,117,195,181,190,230,165,135,190,128,26,99,189,20,17,239,61,34,247,27,63,253,149,2,63,60,106,205,62,96,166,10,63,241,82,18,63,58,205,37,63,39,230,50,63,175,8,59,63,200,207,64,63,88,74,39,63,6,252,82,62,126,88,16,62,236,219,209,61,124,205,59,62,174,91,71,62,67,114,130,62,51,129,160,62,21,23,168,62,136,123,196,62,137,74,179,62,68,56,231,62,108,0,9,63,10,140,78,63,244,121,52,63,167,111,55,63,254,191,25,63,68,94,249,62,36,0,128,62,231,92,160,62,141,125,228,62,24,172,215,61,110,27,10,62,8,62,228,62,80,47,179,62,101,34,181,62,242,151,134,62,68,129,42,62,144,138,164,60,184,3,7,61,72,47,28,62,102,176,52,63,37,4,59,63,243,144,149,63,144,234,185,63,98,29,169,63,21,115,161,63,177,235,149,63,61,199,142,63,90,60,134,63,58,86,106,63,106,24,106,62,216,1,146,62,151,207,153,63,242,250,193,63,219,228,162,63,103,173,146,63,109,232,122,63,224,252,109,63,173,91,89,63,147,94,45,63,249,43,43,63,38,169,18,63,184,107,242,62,48,112,50,63,193,208,21,63,156,58,156,189,74,102,82,190,182,89,13,190,84,95,3,62,211,132,177,62,182,195,149,62,8,31,112,62,240,199,43,62,182,176,140,62,228,189,86,62,143,32,143,190,24,147,192,190,50,3,163,190,124,249,170,189,20,202,23,62,174,237,39,63,78,19,70,63,253,155,124,63,230,194,125,63,196,109,115,63,157,83,105,63,112,108,85,63,210,97,74,63,90,109,68,63,82,212,64,63,144,203,60,62,30,85,131,62,239,214,65,63,134,42,65,63,57,235,45,63,50,33,25,63,68,0,2,63,46,61,219,62,104,39,202,62,200,130,230,62,35,220,226,62,48,59,28,63,98,55,89,63,34,124,91,63,175,103,104,63,0,123,127,63,207,66,133,63,218,182,134,63,193,124,130,63,65,1,103,63,128,104,229,59,32,134,10,60,72,66,37,62,174,103,178,62,80,142,224,62,14,234,22,63,230,4,35,63,46,119,44,63,177,223,51,63,157,168,23,63,19,210,134,63,114,144,141,63,238,199,144,63,145,2,144,63,115,114,133,63,190,213,127,63,15,161,119,63,178,74,112,63,178,51,98,63,112,108,85,63,232,168,122,63,255,245,146,63,60,84,144,63,63,13,129,63,73,135,97,63,147,155,77,63,47,142,58,63,206,80,38,63,100,103,5,63,165,98,242,62,224,204,205,188,128,187,53,189,46,77,3,62,241,39,197,62,16,192,217,62,174,217,232,62,248,38,240,62,144,130,249,62,59,160,25,63,99,152,22,63,160,129,102,189,144,212,201,188,128,104,229,59,16,241,198,61,252,100,252,61,112,242,2,62,124,91,5,62,198,187,21,62,216,84,84,62,180,120,122,62,237,99,150,63,198,203,142,63,37,114,108,63,34,251,32,63,78,203,38,63,147,7,10,63,105,48,10,63,217,218,255,62,25,55,208,62,211,189,204,62,151,183,112,63,214,15,60,63,30,149,60,62,50,33,7,62,96,219,14,62,96,176,175,61,12,29,195,61,144,65,176,61,52,224,169,61,240,213,231,61,131,155,103,63,11,235,123,63,4,75,126,63,73,158,111,63,210,158,106,63,108,220,107,63,127,195,94,63,30,176,97,63,153,104,87,63,246,156,81,63,156,208,196,61,128,117,113,188,240,172,165,60,108,82,205,61,12,34,16,62,58,40,60,62,174,72,62,62,234,104,83,62,24,54,100,62,169,101,146,62,156,140,206,62,152,115,68,62,73,138,12,64,195,223,243,62,28,95,40,63,191,35,52,63,199,165,41,63,161,215,67,63,114,48,69,63,83,133,39,63,0,180,192,61,188,95,250,189,113,88,22,64,76,221,13,62,94,73,156,62,32,177,187,62,91,144,171,62,98,200,241,62,152,222,220,62,127,241,196,62,232,77,82,63,72,131,92,63,131,30,133,63,245,64,180,63,253,163,208,62,197,125,209,62,110,230,5,63,29,50,28,63,33,67,64,63,130,71,57,63,226,81,246,62,127,39,17,63,31,184,107,63,41,128,166,63,0,198,57,61,172,212,175,61,244,174,56,62,61,218,142,62,58,128,203,62,81,150,234,62,129,204,203,63,245,213,191,63,246,233,144,63,124,209,82,63,207,88,48,63,124,129,41,63,121,132,30,63,69,65,39,63,210,59,56,63,160,169,39,63,122,170,203,63,24,9,189,63,54,149,111,63,67,86,239,62,195,90,180,62,61,0,161,62,43,217,152,62,178,59,182,62,148,247,207,62,133,175,202,62,17,44,76,63,23,12,95,63,30,191,101,63,158,4,154,62,181,99,14,63,86,100,42,63,194,97,100,63,169,193,139,63,178,89,116,63,161,1,91,63,66,2,193,62,185,115,252,62,223,115,41,63,64,199,28,189,22,237,52,62,111,104,154,62,163,98,24,63,85,240,99,63,249,81,61,63,55,223,30,63,88,241,97,62,198,151,28,64,82,98,165,63,53,16,131,63,69,198,102,63,123,239,90,63,171,109,82,63,73,139,102,63,60,240,66,63,183,191,70,63,177,94,139,190,147,100,57,64,131,232,166,63,138,254,68,63,73,254,28,63,170,243,17,63,34,228,18,63,69,65,39,63,191,211,10,63,170,220,3,63,0,0,128,63,125,57,91,63,194,191,22,63,145,152,135,62,0,0,0,0,112,80,11,190,231,230,18,190,134,87,155,189,0,0,0,0,214,25,40,61,69,244,40,61,150,228,163,60,0,0,0,0,3,90,5,188,208,141,223,187,248,27,64,187,0,0,0,0,34,130,41,59,25,224,173,59,39,123,182,59,0,0,0,0,154,178,43,188,65,152,153,188,171,142,131,188,0,0,0,0,170,251,173,60,17,154,7,61,37,100,206,60,0,0,0,0,69,111,224,188,139,204,32,189,215,75,226,188,0,0,0,0,59,125,33,63,227,228,66,63,117,254,92,63,90,146,109,63,27,51,115,63,216,99,109,63,121,165,92,63,11,105,66,63,132,103,55,190,155,96,10,190,199,165,113,189,77,177,65,61,103,183,54,62,205,6,167,62,227,218,245,62,244,232,32,63,0,0,0,0,215,190,68,190,226,240,54,190,97,99,9,190,39,157,107,189,131,143,73,61,147,7,57,62,70,71,168,62,7,28,247,62,96,94,165,61,83,101,79,61,219,66,3,60,237,133,47,189,200,80,196,189,197,15,19,190,110,125,54,190,46,186,68,190,0,0,0,0,235,189,196,61,202,156,164,61,110,248,76,61,55,133,237,59,194,0,51,189,253,1,198,189,145,193,19,190,97,231,54,190,13,137,32,189,185,86,155,188,89,33,230,59,25,15,18,61,159,13,129,61,137,170,173,61,209,134,198,61,122,1,197,61,0,0,0,0,10,57,83,189,155,113,31,189,92,63,152,188,57,198,244,59,104,240,19,61,94,225,129,61,114,61,174,61,109,185,198,61,143,123,146,60,182,155,159,59,231,3,49,188,4,36,222,188,220,156,42,189,154,184,84,189,15,124,100,189,142,197,83,189,0,0,0,0,18,205,218,60,96,4,145,60,139,236,151,59,7,79,53,188,46,55,224,188,48,115,43,189,149,51,85,189,252,123,100,189,65,252,226,187,240,105,87,58,221,103,31,60,128,42,152,60,12,158,212,60,113,172,249,60,245,233,253,60,15,172,219,60,0,0,0,0,245,174,77,188,6,100,223,187,95,35,123,58,155,202,33,60,94,66,153,60,83,108,213,60,78,5,250,60,127,173,253,60,76,255,250,58,116,122,19,187,136,195,224,187,158,67,56,188,195,46,112,188,110,23,134,188,50,97,129,188,209,220,78,188,0,0,0,0,213,9,167,59,0,24,243,58,158,47,24,187,81,47,227,187,100,81,57,188,82,225,112,188,114,44,134,188,122,34,129,188,193,215,243,184,100,37,253,58,135,197,133,59,23,61,197,59,33,20,242,59,141,151,0,60,85,249,233,59,181,109,168,59,0,0,0,0,148,227,234,186,68,194,179,184,72,211,0,59,89,223,134,59,77,34,198,59,236,148,242,59,229,144,0,60,247,66,233,59,144,247,214,185,104,99,201,186,62,13,39,187,66,129,89,187,12,197,115,187,16,170,110,187,90,100,69,187,180,248,237,186,0,0,0,0,168,19,53,58,174,139,224,185,112,172,203,186,194,1,40,187,2,35,90,187,160,243,115,187,12,76,110,187,22,109,68,187,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,12,0,13,0,14,0,60,0,61,0,62,0,252,0,253,0,254,0,252,3,253,3,254,3,252,15,253,15,254,15,252,63,253,63,254,63,255,63,0,0,0,0,2,2,2,4,4,4,6,6,6,8,8,8,10,10,10,12,12,12,14,14,14,14,0,0,0,0,0,0,0,0,0,0,73,255,207,53,73,255,207,53,209,255,31,55,10,0,138,55,13,0,31,56,12,128,79,56,251,191,167,56,249,255,221,56,255,127,13,57,1,160,42,57,2,224,78,57,254,223,115,57,255,15,140,57,0,224,162,57,1,48,188,57,1,96,216,57,0,64,240,57,0,240,4,58,0,248,22,58,255,183,44,58,1,8,70,58,255,127,97,58,0,24,128,58,0,20,145,58,0,52,165,58,0,12,182,58,0,88,202,58,0,212,221,58,0,200,248,58,0,92,11,59,0,224,26,59,0,98,40,59,0,236,58,59,0,10,81,59,0,28,99,59,0,74,120,59,0,151,136,59,0,0,151,59,0,187,165,59,0,76,182,59,0,145,202,59,0,82,223,59,0,85,242,59,0,13,6,60,128,102,21,60,0,105,40,60,0,122,68,60,0,205,91,60,0,172,125,60,64,96,142,60,128,154,163,60,0,252,187,60,128,178,219,60,96,219,2,61,64,0,33,61,128,118,60,61,192,105,86,61,176,164,130,61,16,39,173,61,224,101,226,61,64,135,25,62,48,62,99,62,18,0,158,55,233,255,208,55,3,0,247,55,13,128,25,56,1,128,49,56,250,255,66,56,5,0,81,56,1,128,92,56,2,0,103,56,6,0,113,56,244,255,121,56,1,0,129,56,250,255,132,56,5,64,136,56,2,128,139,56,1,128,142,56,0,64,145,56,1,192,147,56,2,64,150,56,3,192,152,56,7,192,154,56,253,191,156,56,1,128,158,56,250,255,159,56,0,128,161,56,5,64,163,56,253,191,164,56,3,64,166,56,251,191,167,56,2,64,169,56,250,191,170,56,255,127,172,56,5,0,174,56,252,191,175,56,2,64,177,56,5,64,179,56,250,127,181,56,252,191,183,56,252,127,186,56,7,192,189,56,0,192,193,56,255,63,199,56,0,64,207,56,250,127,216,56,3,64,228,56,250,191,240,56,253,127,0,57,1,96,10,57,3,32,22,57,254,127,36,57,1,224,54,57,255,191,76,57,0,96,103,57,1,240,132,57,0,128,155,57,0,160,181,57,255,111,215,57,0,56,0,58,255,231,26,58,0,88,62,58,0,120,104,58,0,136,140,58,0,108,166,58,0,168,197,58,0,224,228,58,0,240,2,59,0,134,16,59,0,48,27,59,0,250,36,59,0,10,46,59,0,6,55,59,0,202,63,59,0,138,71,59,0,116,80,59,0,170,88,59,0,224,96,59,0,90,104,59,0,218,111,59,0,252,118,59,0,212,125,59,0,81,130,59,0,96,133,59,0,132,136,59,0,120,139,59,0,55,142,59,0,255,144,59,0,186,147,59,0,104,150,59,0,1,153,59,0,108,155,59,0,217,157,59,0,45,160,59,0,127,162,59,0,171,164,59,0,186,166,59,0,191,168,59,0,170,170,59,0,152,172,59,0,122,174,59,0,75,176,59,0,23,178,59,0,197,179,59,0,110,181,59,0,13,183,59,0,170,184,59,0,36,186,59,0,155,187,59,0,23,189,59,0,107,190,59,0,210,191,59,0,57,193,59,0,136,194,59,0,180,195,59,0,232,196,59,0,11,198,59,0,54,199,59,0,104,200,59,0,122,201,59,0,150,202,59,0,170,203,59,0,203,204,59,0,218,205,59,0,22,207,59,0,62,208,59,0,122,209,59,0,209,210,59,0,61,212,59,0,161,213,59,0,248,214,59,0,74,216,59,0,157,217,59,0,250,218,59,0,80,220,59,0,177,221,59,0,5,223,59,0,90,224,59,0,169,225,59,0,220,226,59,0,25,228,59,0,82,229,59,0,148,230,59,0,214,231,59,0,14,233,59,0,104,234,59,0,216,235,59,0,70,237,59,0,180,238,59,0,85,240,59,0,239,241,59,0,170,243,59,0,93,245,59,0,40,247,59,0,16,249,59,0,224,250,59,0,193,252,59,0,142,254,59,0,59,0,60,128,50,1,60,0,60,2,60,0,90,3,60,128,109,4,60,128,147,5,60,128,178,6,60,128,201,7,60,0,211,8,60,128,214,9,60,128,229,10,60,128,2,12,60,128,21,13,60,0,47,14,60,128,93,15,60,128,147,16,60,128,210,17,60,128,5,19,60,128,38,20,60,0,80,21,60,128,110,22,60,0,130,23,60,0,164,24,60,128,221,25,60,0,31,27,60,0,89,28,60,0,147,29,60,0,208,30,60,128,4,32,60,0,55,33,60,128,121,34,60,128,192,35,60,128,17,37,60,128,123,38,60,128,251,39,60,128,144,41,60,0,27,43,60,128,196,44,60,128,160,46,60,128,132,48,60,0,142,50,60,0,117,52,60,128,98,54,60,128,70,56,60,128,21,58,60,0,17,60,60,0,26,62,60,128,60,64,60,128,112,66,60,0,207,68,60,128,50,71,60,128,138,73,60,0,51,76,60,0,25,79,60,128,24,82,60,0,57,85,60,128,114,88,60,0,5,92,60,0,217,95,60,0,152,99,60,128,156,103,60,128,240,107,60,0,55,112,60,0,172,116,60,0,66,121,60,0,9,126,60,0,190,129,60,0,196,132,60,64,247,135,60,64,52,139,60,128,205,142,60,0,220,146,60,192,25,151,60,0,66,156,60,0,150,161,60,128,72,167,60,64,12,174,60,192,120,181,60,64,178,189,60,128,23,199,60,128,10,210,60,128,193,222,60,0,62,237,60,0,3,254,60,64,175,8,61,192,3,21,61,64,107,36,61,160,220,53,61,160,13,76,61,224,110,102,61,240,21,131,61,144,18,150,61,48,86,171,61,208,54,197,61,32,227,229,61,160,202,8,62,120,194,36,62,88,201,75,62,220,246,133,62,68,3,201,62,108,14,88,191,32,69,29,191,170,211,28,190,155,110,204,189,29,137,164,62,157,104,193,62,89,68,55,63,183,144,162,63,181,252,215,191,160,211,155,191,95,145,250,190,113,190,212,190,237,196,0,62,254,106,71,62,150,157,22,63,241,112,153,63,51,233,173,191,135,234,127,191,28,246,192,190,40,187,159,190,60,167,64,62,75,47,129,62,137,201,32,63,209,48,156,63,10,247,60,191,121,241,7,191,154,43,202,189,182,123,73,189,215,13,182,62,95,251,209,62,24,52,61,63,97,62,164,63,244,188,127,190,72,169,238,189,60,167,64,62,35,244,102,62,224,5,12,63,208,155,23,63,11,150,95,63,3,128,174,63,110,245,177,191,120,197,130,191,23,185,199,190,134,91,165,190,59,253,56,62,2,252,123,62,9,142,31,63,90,227,155,63,75,114,26,191,59,76,214,190,75,103,207,188,40,69,178,60,33,59,206,62,123,58,233,62,198,128,69,63,8,180,166,63,131,133,141,191,145,2,81,191,144,47,141,190,0,217,92,190,227,200,124,62,250,206,157,62,247,145,42,63,211,244,158,63,34,33,10,191,106,6,187,190,111,61,51,60,129,15,99,61,235,103,218,62,176,119,244,62,140,186,73,63,97,234,167,63,87,5,117,191,193,4,52,191,200,64,85,190,80,162,27,190,75,42,147,62,76,94,177,62,24,114,49,63,172,230,160,63,155,225,119,190,158,230,224,189,31,187,69,62,141,168,108,62,10,233,12,63,15,153,24,63,5,58,96,63,163,186,174,63,72,15,40,63,191,99,54,63,19,98,91,63,151,112,96,63,133,67,135,63,65,198,138,63,233,243,161,63,118,130,207,63,6,89,197,191,241,220,143,191,200,230,226,190,209,139,169,192,127,160,26,62,108,146,95,62,116,180,26,63,69,142,154,63,201,50,3,191,228,90,175,190,46,64,218,60,235,52,146,61,183,185,223,62,185,214,249,62,169,149,75,63,17,128,168,63,221,0,99,191,184,238,37,191,178,137,50,190,136,147,245,189,63,47,158,62,108,104,187,62,139,33,53,63,170,234,161,63,245,37,193,189,37,64,170,60,4,21,149,62,127,99,166,62,219,186,30,63,33,132,41,63,22,56,109,63,37,184,178,63,205,204,76,61,41,92,15,62,10,215,35,62,205,204,76,61,123,20,46,62,0,0,128,62,41,92,143,61,61,10,87,62,143,194,245,61,174,71,97,62,31,133,107,62,184,30,5,62,143,194,117,62,10,215,163,62,41,92,15,62,225,122,148,62,82,184,158,62,133,235,209,62,246,40,220,62,10,215,163,62,246,40,220,62,92,143,2,63,123,20,174,62,143,194,245,62,92,143,194,62,215,163,240,62,72,225,250,62,92,143,194,62,72,225,250,62,133,235,17,63,205,204,204,62,113,61,10,63,72,225,250,62,61,10,23,63,246,40,28,63,0,0,0,63,246,40,28,63,215,163,48,63,184,30,5,63,195,245,40,63,41,92,15,63,102,102,38,63,31,133,43,63,41,92,15,63,31,133,43,63,0,0,64,63,225,122,20,63,236,81,56,63,102,102,38,63,164,112,61,63,92,143,66,63,102,102,38,63,92,143,66,63,61,10,87,63,31,133,43,63,41,92,79,63,143,194,53,63,205,204,76,63,133,235,81,63,143,194,53,63,133,235,81,63,102,102,102,63,72,225,58,63,82,184,94,63,41,92,79,63,102,102,102,63,31,133,107,63,41,92,79,63,123,20,110,63,174,71,129,63,225,122,84,63,236,81,120,63,82,184,94,63,143,194,117,63,72,225,122,63,82,184,94,63,72,225,122,63,20,174,135,63,10,215,99,63,10,215,131,63,31,133,107,63,92,143,130,63,184,30,133,63,123,20,110,63,184,30,133,63,41,92,143,63,51,51,115,63,31,133,139,63,123,20,110,63,92,143,130,63,184,30,133,63,123,20,110,63,184,30,133,63,41,92,143,63,51,51,115,63,31,133,139,63,215,163,112,63,184,30,133,63,102,102,134,63,205,204,204,61,20,174,135,63,133,235,145,63,143,194,117,63,123,20,142,63,72,225,122,63,113,61,138,63,205,204,140,63,164,112,125,63,205,204,140,63,61,10,151,63,174,71,129,63,51,51,147,63,20,174,135,63,51,51,147,63,143,194,149,63,20,174,135,63,143,194,149,63,0,0,160,63,113,61,138,63,246,40,156,63,225,122,148,63,0,0,160,63,92,143,162,63,225,122,148,63,10,215,163,63,123,20,174,63,61,10,151,63,195,245,168,63,217,63,139,60,39,222,143,60,172,163,148,60,181,145,153,60,153,169,158,60,187,236,163,60,140,92,169,60,134,250,174,60,49,200,180,60,35,199,186,60,252,248,192,60,111,95,199,60,57,252,205,60,40,209,212,60,24,224,219,60,246,42,227,60,191,179,234,60,129,124,242,60,90,135,250,60,62,107,1,61,21,182,5,61,94,37,10,61,78,186,14,61,37,118,19,61,46,90,24,61,189,103,29,61,50,160,34,61,252,4,40,61,145,151,45,61,118,89,51,61,61,76,57,61,134,113,63,61,253,202,69,61,93,90,76,61,112,33,83,61,15,34,90,61,34,94,97,61,162,215,104,61,153,144,112,61,34,139,120,61,180,100,128,61,214,166,132,61,32,13,137,61,197,152,141,61,2,75,146,61,30,37,151,61,109,40,156,61,76,86,161,61,36,176,166,61,107,55,172,61,163,237,177,61,89,212,183,61,42,237,189,61,192,57,196,61,209,187,202,61,36,117,209,61,143,103,216,61,244,148,223,61,75,255,230,61,152,168,238,61,241,146,246,61,127,192,254,61,190,153,3,62,27,247,7,62,135,121,12,62,61,34,17,62,130,242,21,62,166,235,26,62,3,15,32,62,0,94,37,62,16,218,42,62,177,132,48,62,111,95,54,62,226,107,60,62,176,171,66,62,142,32,73,62,61,204,79,62,144,176,86,62,102,207,93,62,178,42,101,62,116,196,108,62,190,158,116,62,181,187,124,62,199,142,130,62,74,227,134,62,144,92,139,62,211,251,143,62,84,194,148,62,97,177,153,62,81,202,158,62,138,14,164,62,122,127,169,62,156,30,175,62,122,237,180,62,168,237,186,62,200,32,193,62,141,136,199,62,180,38,206,62,12,253,212,62,112,13,220,62,208,89,227,62,38,228,234,62,131,174,242,62,4,187,250,62,238,133,1,63,168,209,5,63,219,65,10,63,190,215,14,63,143,148,19,63,153,121,24,63,51,136,29,63,188,193,34,63,162,39,40,63,93,187,45,63,115,126,51,63,116,114,57,63,2,153,63,63,200,243,69,63,130,132,76,63,251,76,83,63,11,79,90,63,156,140,97,63,167,7,105,63,54,194,112,63,100,190,120,63,47,127,128,63,50,194,132,63,100,41,137,63,84,82,95,94,125,131,98,102,94,93,104,104,127,113,87,77,125,114,109,94,94,91,106,105,168,125,163,120,128,100,119,99,108,97,108,106,86,85,128,125,79,73,103,102,123,123,116,117,84,76,135,131,133,133,129,130,125,123,115,114,94,97,79,81,115,115,94,93,128,127,126,125,124,111,105,114,104,117,109,110,124,125,118,117,107,110,106,110,93,93,149,148,118,119,111,110,147,157,143,156,134,136,118,121,106,107,105,105,114,83,114,46,106,53,110,83,107,94,105,103,92,90,109,106,172,160,114,110,109,110,110,109,90,98,98,109,102,98,97,92,100,100,101,102,123,117,124,98,82,80,117,115,112,110,109,108,107,111,100,115,105,120,104,105,83,82,95,96,109,120,72,71,97,104,69,74,99,102,118,117,137,133,142,135,105,110,121,121,125,122,114,112,151,186,115,132,103,111,100,104,99,101,104,105,18,38,56,65,76,83,85,91,101,103,108,110,144,135,126,121,115,113,79,80,118,117,117,117,117,124,115,115,126,113,130,116,112,106,108,105,77,76,76,80,109,109,125,129,130,133,116,118,96,86,109,99,102,69,84,69,107,103,114,113,78,118,82,114,84,129,69,112,78,98,96,103,89,137,96,111,105,97,93,93,101,105,105,105,141,123,102,93,91,79,87,81,102,99,109,108,94,92,124,123,130,134,100,107,71,75,92,91,94,104,107,83,106,101,113,114,122,122,114,114,118,124,103,106,95,116,90,93,107,104,109,107,116,118,76,72,88,88,132,132,140,141,116,116,90,81,111,95,139,97,123,96,112,100,110,108,112,116,133,140,112,120,80,85,55,55,85,84,125,94,111,104,116,103,112,86,93,84,99,98,180,179,197,197,169,163,149,146,130,124,116,115,76,47,36,11,43,28,66,53,82,80,102,99,119,123,176,201,113,120,112,111,103,105,106,110,145,114,112,89,120,93,123,104,131,123,113,111,97,109,82,106,75,104,103,115,120,124,111,114,114,111,113,105,34,33,63,63,105,106,122,122,51,41,96,92,125,125,118,118,118,119,113,113,111,180,108,178,107,171,110,160,105,136,102,117,76,79,90,92,80,88,88,93,123,124,122,122,131,128,123,122,151,158,108,107,129,128,119,119,97,99,114,120,121,125,151,157,82,89,95,96,128,94,130,95,149,113,149,120,127,115,113,109,167,171,83,80,84,79,106,106,112,110,107,108,130,139,81,88,107,106,112,112,119,118,114,112,108,105,100,98,120,116,122,117,38,37,72,73,118,125,110,120,114,126,135,142,139,142,118,119,119,119,156,145,78,75,94,94,112,110,113,113,101,108,98,104,103,109,117,118,167,167,132,132,116,108,118,111,149,136,85,74,95,92,113,112,74,69,104,107,96,100,117,121,103,105,103,103,110,106,111,101,82,72,96,92,132,130,120,121,116,113,138,139,104,103,131,131,68,69,92,92,97,97,146,151,122,132,97,95,117,116,115,116,139,134,110,110,124,129,100,110,86,91,100,102,116,136,88,90,137,139,103,114,114,117,111,110,82,83,104,102,97,99,97,97,58,56,84,84,83,122,76,105,112,126,120,134,112,120,108,110,114,128,73,90,72,76,98,100,95,96,101,102,101,108,118,126,94,102,81,83,138,140,131,130,88,100,112,124,105,106,122,123,121,121,114,114,76,108,73,83,93,95,110,111,98,99,103,103,105,112,98,108,114,95,117,98,120,116,116,115,231,238,150,146,124,126,115,122,117,121,112,112,74,73,72,74,60,61,62,61,85,85,101,101,67,69,50,51,83,83,110,110,118,113,112,111,199,124,184,115,176,117,165,120,138,115,116,114,52,116,36,107,49,99,72,106,91,107,104,105,140,138,141,135,154,147,166,159,139,136,116,115,130,119,180,157,183,149,136,121,119,114,111,110,104,129,113,154,111,148,108,132,105,117,106,111,114,35,99,65,113,94,110,98,111,107,107,106,106,110,128,135,162,175,143,155,115,116,109,109,168,155,112,109,125,125,126,122,126,124,111,112,128,96,160,77,151,77,121,80,114,94,107,103,97,104,101,116,56,79,74,83,92,95,104,106,63,68,76,77,110,107,96,90,85,83,97,96,116,110,46,42,103,100,122,120,102,101,104,104,106,101,109,98,96,61,67,35,72,61,96,93,88,80,81,76,113,110,144,143,88,89,93,94,95,96,100,101,136,132,166,160,148,147,115,116,80,78,130,129,120,108,91,85,95,91,104,102,151,147,106,109,110,110,64,69,68,67,96,96,90,166,97,128,99,120,104,121,109,118,105,109,122,138,110,143,75,97,83,94,89,94,102,103,136,142,103,110,83,89,99,101,138,138,120,122,168,88,105,90,109,107,110,111,106,105,103,102,68,72,102,104,92,102,65,75,89,94,106,106,83,74,93,85,73,66,106,102,100,92,99,97,93,99,101,96,116,112,125,120,88,88,96,96,44,98,93,115,104,116,103,107,112,113,107,107,93,83,105,99,93,84,127,125,141,143,117,118,106,103,126,121,137,123,123,114,147,142,127,123,103,110,89,91,121,124,66,71,68,69,96,97,114,105,68,65,69,67,96,94,131,130,123,121,111,104,130,121,95,95,72,74,88,88,105,104,135,124,110,98,114,111,159,158,111,113,104,106,103,108,94,107,55,57,115,118,121,122,111,111,97,99,106,111,119,126,59,62,111,112,124,125,86,93,100,110,118,145,113,132,120,125,112,112,101,115,78,149,81,114,111,121,108,112,107,108,104,104,94,96,84,83,135,132,71,69,88,86,100,98,62,60,81,80,90,89,63,66,89,90,123,116,108,99,90,86,91,92,65,65,88,88,84,79,115,109,123,111,99,99,134,136,121,123,127,137,84,88,104,107,128,130,74,69,89,89,118,112,143,132,141,131,113,113,99,102,104,105,117,115,100,99,131,126,90,88,145,144,128,127,112,114,131,133,85,84,118,119,151,152,117,117,110,105,162,140,116,107,140,134,124,122,113,113,107,110,124,133,98,103,99,107,109,113,112,112,115,105,82,77,125,122,133,132,118,120,113,113,101,88,84,80,97,99,91,91,94,94,101,100,121,86,139,108,106,93,103,99,112,108,108,107,113,83,105,102,125,125,114,115,110,112,108,109,93,112,113,121,125,131,101,101,107,109,111,111,98,102,117,126,80,84,107,109,83,84,96,97,132,136,112,118,94,93,121,118,99,98,102,103,122,127,128,133,118,104,102,88,100,94,104,102,115,116,102,105,140,142,135,130,90,88,100,101,94,86,112,112,89,121,92,101,109,108,110,112,99,93,129,114,109,99,131,119,102,97,103,103,103,116,124,101,115,95,105,101,94,91,100,100,113,90,94,86,92,92,117,111,106,103,106,105,115,99,110,91,107,104,81,90,108,113,112,113,113,114,93,101,101,102,101,126,93,103,104,105,117,106,124,107,104,119,108,133,104,111,104,106,98,98,119,121,109,112,128,135,115,121,159,113,113,106,127,114,101,102,105,111,161,162,137,138,161,159,152,150,150,148,128,79,131,102,142,120,133,119,130,117,121,115,142,133,186,155,179,144,169,135,107,103,106,106,122,122,111,112,112,115,127,123,118,115,128,125,123,119,115,109,124,130,117,126,121,133,84,144,99,114,122,125,123,131,124,135,176,200,158,176,68,74,86,87,117,115,119,116,135,128,115,116,102,104,119,123,133,148,102,109,71,121,106,117,107,127,106,122,100,110,117,115,129,128,87,84,116,116,151,157,116,128,110,117,119,134,100,114,120,129,142,141,146,151,94,91,114,114,118,118,114,112,112,109,115,112,123,123,147,148,110,164,106,152,110,158,106,151,105,135,85,51,71,27,71,34,74,45,85,53,145,134,140,130,136,134,118,122,118,126,117,84,121,81,106,80,109,106,121,127,95,94,112,110,90,94,109,107,114,109,117,118,118,123,107,107,86,93,29,31,125,112,104,60,121,111,127,116,133,130,118,117,148,145,122,126,124,127,90,91,113,110,119,118,152,147,115,112,132,131,129,140,98,112,73,85,109,115,122,126,123,122,122,122,126,125,137,140,203,210,164,176,114,114,125,122,119,112,125,120,124,122,118,115,95,96,141,144,132,131,127,130,132,134,116,114,122,123,137,134,111,111,112,116,106,118,77,101,104,115,111,111,125,126,118,121,113,115,113,113,171,170,202,199,221,206,199,184,177,167,73,90,61,93,43,74,51,71,51,72,130,130,140,137,134,132,164,160,118,111,123,136,133,154,130,158,106,110,110,114,97,97,91,94,70,69,125,123,141,140,119,100,116,77,111,67,105,52,95,34,100,122,90,124,68,120,43,117,50,112,130,129,192,188,123,118,124,117,121,115,122,111,129,111,157,85,125,109,125,119,143,152,119,128,114,116,129,136,148,157,119,117,115,115,150,148,163,154,109,102,120,126,73,119,106,121,102,122,96,113,84,83,117,115,122,117,154,143,159,142,118,122,114,117,115,122,114,130,99,156,123,120,122,116,100,81,99,91,121,112,139,131,164,142,132,119,145,133,157,141,112,109,118,116,142,134,108,110,96,99,111,110,113,112,111,104,98,94,131,131,115,114,121,118,120,115,173,148,123,117,121,124,122,124,140,146,78,82,96,93,86,90,124,125,121,123,105,106,134,135,107,109,132,141,100,95,113,114,102,105,113,130,98,145,116,115,124,117,115,105,120,123,89,87,109,108,102,101,117,117,113,122,132,138,77,116,86,99,118,126,123,120,117,111,124,119,129,118,63,58,141,135,108,106,109,111,108,110,135,138,117,114,134,127,139,129,138,130,126,122,121,118,124,121,133,130,98,85,130,123,147,129,118,112,148,130,136,123,148,131,113,112,123,118,123,115,147,95,117,110,118,119,112,113,112,113,119,119,120,120,158,133,198,145,188,129,197,137,195,133,132,140,140,139,158,156,223,217,233,233,48,56,34,37,82,84,102,102,108,110,120,142,136,169,146,195,136,186,140,182,196,186,158,155,142,134,132,125,120,119,97,105,72,75,82,85,81,84,107,109,67,121,43,119,69,124,87,129,88,128,53,57,93,98,91,94,93,98,104,104,124,123,133,133,182,181,119,121,114,116,128,105,134,112,131,72,119,59,111,84,132,142,145,180,124,132,131,143,122,134,88,85,103,103,136,140,131,143,114,132,116,57,113,57,121,76,126,80,118,86,127,112,127,97,131,100,149,91,163,86,122,119,128,121,128,116,142,127,173,139,162,116,166,107,149,103,152,107,141,108,114,113,118,116,56,43,90,90,105,105,132,134,110,107,106,105,82,84,84,84,102,106,79,89,99,99,127,129,114,118,139,157,116,123,116,123,87,89,110,113,119,126,97,97,155,163,142,153,143,146,117,114,66,67,125,126,127,128,114,113,111,114,127,133,123,132,143,162,133,148,105,108,114,114,110,109,57,48,109,106,113,130,104,131,88,139,102,169,100,172,129,114,150,97,114,112,117,119,109,116,92,107,96,116,90,125,101,122,125,140,125,133,122,129,136,153,125,135,131,139,84,71,129,123,135,120,114,103,112,101,108,121,115,156,106,123,116,131,127,139,137,147,109,117,119,126,135,144,117,119,120,127,76,105,111,116,120,125,141,138,107,104,162,155,135,130,127,123,127,121,102,104,84,87,112,115,97,102,78,82,119,118,120,123,91,105,114,119,119,126,130,126,134,126,158,134,133,99,116,100,125,122,145,143,126,117,98,96,121,120,152,148,131,126,130,129,126,119,87,87,131,131,139,137,101,102,104,105,86,83,92,89,111,105,121,115,137,124,96,84,100,96,122,119,107,108,93,96,79,82,128,123,108,106,123,120,150,150,143,140,121,120,97,99,79,80,116,116,88,90,128,131,101,97,140,140,117,116,116,118,137,135,100,91,115,112,134,121], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+30720);
/* memory initializer */ allocate([107,99,120,122,122,125,124,126,136,141,89,95,103,119,103,116,122,139,125,137,152,170,121,122,124,124,98,97,137,140,96,92,115,113,136,136,128,132,122,124,151,158,100,107,121,131,131,158,119,130,113,114,114,109,148,130,103,95,127,116,137,120,103,108,97,97,133,128,113,109,136,128,125,124,118,118,122,121,101,99,157,152,138,134,124,115,113,101,123,112,124,110,116,113,128,121,119,110,124,113,128,67,114,118,114,123,109,121,102,123,56,116,117,111,112,99,124,114,112,79,114,88,112,113,115,117,126,127,130,132,123,122,111,104,111,102,112,102,129,118,129,115,123,124,130,133,114,117,125,127,112,117,124,125,119,120,117,116,105,104,110,110,125,124,118,116,124,123,124,121,133,132,111,111,124,124,120,119,116,116,134,130,114,116,112,113,109,111,116,118,95,98,147,145,193,168,188,156,141,145,141,139,148,149,148,149,153,157,144,144,152,152,141,145,153,143,243,134,151,133,166,135,150,149,135,132,32,39,110,111,109,114,126,127,147,146,177,169,162,156,210,187,141,147,95,150,127,155,108,133,139,148,138,138,140,140,147,146,134,130,136,134,147,146,142,150,62,174,126,151,122,156,154,156,179,184,115,107,105,99,127,124,146,131,140,44,132,125,156,146,153,153,136,137,145,144,141,139,158,152,138,132,145,145,147,145,146,141,144,140,110,97,140,141,143,142,130,123,127,117,126,120,147,146,161,155,169,135,122,117,166,155,144,144,142,142,125,122,137,128,194,172,127,85,148,143,153,141,147,147,140,143,118,140,0,69,51,60,111,123,137,135,146,146,164,165,207,214,145,143,149,147,178,168,197,170,134,154,148,159,115,140,103,118,13,38,139,138,135,138,140,141,144,144,140,140,150,150,156,157,164,171,143,143,140,142,118,120,172,172,160,163,146,147,150,151,176,176,230,237,153,153,168,156,173,149,164,148,162,146,178,158,147,145,143,145,111,126,111,130,89,118,153,158,122,120,142,125,124,105,148,138,145,144,156,151,193,154,146,147,119,135,142,141,145,145,152,147,142,141,146,146,139,138,154,154,148,150,147,149,144,145,134,134,141,140,135,134,145,147,160,163,144,145,149,146,115,67,127,119,141,135,145,141,130,124,143,144,151,165,141,144,154,152,160,136,115,82,64,71,64,65,143,143,151,149,240,251,165,173,173,179,148,134,156,55,160,105,133,91,129,96,149,149,145,144,160,154,171,159,140,142,154,163,178,244,147,140,153,150,137,121,145,144,145,146,138,139,149,152,189,198,148,148,156,158,168,182,165,182,172,201,143,142,99,92,152,152,143,143,127,127,165,148,173,124,113,122,134,142,127,142,124,126,137,137,131,132,144,142,141,138,172,176,138,111,152,136,167,154,156,137,140,150,78,145,158,157,161,154,155,147,153,164,156,191,129,109,153,146,153,141,138,137,141,138,115,94,144,141,155,147,144,142,144,137,168,113,141,134,145,137,146,144,150,148,140,155,103,178,137,149,145,147,148,153,175,201,138,146,110,108,143,146,124,134,124,127,164,158,127,135,145,146,150,150,145,147,95,80,150,151,149,149,162,162,144,152,170,169,145,154,145,149,143,146,142,145,152,146,160,98,141,141,153,153,140,137,131,131,145,146,133,132,127,124,158,150,173,164,178,167,146,146,154,155,117,127,143,147,147,156,142,143,144,145,146,152,170,199,151,165,146,147,139,140,147,149,132,134,147,149,138,139,142,143,162,188,145,149,160,164,150,150,139,139,143,142,146,146,137,138,142,142,141,140,152,153,164,171,110,112,139,139,143,143,138,138,142,142,143,143,137,140,142,142,145,141,149,141,182,135,146,146,150,150,144,145,150,151,135,137,137,145,51,62,68,54,69,57,62,41,137,139,139,144,135,150,225,232,208,197,136,135,141,143,145,150,160,169,213,247,142,137,72,54,110,107,105,107,127,130,145,143,169,155,219,174,195,164,183,157,155,157,239,232,169,164,170,172,156,159,142,143,136,144,59,100,139,142,130,138,147,146,150,161,128,235,143,155,146,167,154,149,128,151,42,149,55,136,59,127,128,126,74,92,143,153,140,150,166,176,146,152,150,145,140,100,140,105,124,59,195,191,146,148,144,136,136,133,129,122,133,148,40,147,102,140,123,148,118,136,143,143,150,148,184,153,160,147,166,149,58,68,127,135,141,145,143,147,150,151,140,143,137,137,120,114,71,65,125,123,153,148,215,159,136,135,150,146,150,150,148,138,166,94,150,145,145,139,147,145,146,147,150,139,171,63,158,142,153,133,147,148,143,143,76,72,155,159,164,176,149,149,173,195,145,165,138,144,150,167,180,169,146,151,146,166,147,166,149,171,157,156,168,166,147,149,121,122,116,124,145,145,147,148,172,189,168,180,144,146,139,145,141,150,115,172,141,146,143,148,145,145,142,143,145,147,138,143,58,73,141,142,146,145,163,149,218,161,147,132,152,147,146,147,140,150,141,152,89,150,78,134,135,137,139,142,140,137,137,130,144,144,152,151,145,140,181,170,191,168,164,166,136,148,112,124,139,144,146,149,142,151,113,182,137,150,143,156,138,147,154,156,108,102,118,119,133,139,113,111,145,144,150,147,175,151,104,106,116,114,143,144,151,157,151,191,135,113,138,123,146,146,155,157,106,145,132,127,140,125,161,165,146,150,151,154,139,140,142,143,144,148,145,149,147,138,168,104,146,136,138,140,91,108,111,110,145,140,158,154,130,112,122,118,136,135,119,118,141,140,147,146,146,145,138,138,182,188,132,132,144,144,156,155,168,172,123,128,144,151,142,140,145,145,137,144,141,152,128,188,149,149,160,161,160,160,166,163,130,107,143,143,142,142,149,149,132,132,170,174,148,148,154,153,118,111,157,155,114,109,140,139,138,137,205,187,137,133,147,144,144,145,147,149,105,125,108,117,155,162,146,146,162,157,144,122,154,143,161,139,141,142,130,131,144,144,142,141,144,142,132,132,141,141,150,151,139,141,151,153,142,142,154,154,150,150,148,148,166,165,143,142,144,144,132,132,142,144,130,128,142,142,143,143,153,153,147,142,129,125,142,141,143,142,143,147,105,122,135,140,141,140,140,140,151,151,156,155,146,146,133,134,140,142,142,145,141,146,112,133,142,142,145,145,137,138,155,157,149,150,144,144,139,138,130,128,132,131,147,147,139,140,142,143,115,121,141,143,137,141,146,146,150,150,145,144,133,133,133,135,143,144,144,144,166,167,139,142,139,140,150,149,138,138,142,140,148,147,160,155,146,146,147,147,138,137,143,142,151,150,70,100,121,129,132,132,201,188,165,145,144,136,112,127,116,125,130,129,124,135,135,146,129,128,162,158,144,151,135,129,103,86,111,113,112,122,90,139,129,117,126,129,142,145,167,147,124,124,230,209,189,175,156,141,64,80,86,108,121,129,44,79,115,113,115,128,133,106,79,109,125,127,171,156,132,109,103,115,106,70,93,145,141,128,148,125,122,107,110,117,146,145,128,110,98,111,237,212,185,156,139,133,84,55,26,77,114,127,172,170,171,168,162,143,82,82,76,70,104,126,17,95,109,111,120,132,81,74,57,126,141,131,110,127,162,148,129,123,177,172,155,151,145,134,144,123,90,66,109,130,82,127,103,123,132,131,127,97,97,142,140,128,159,134,136,123,113,117,131,140,154,169,158,134,96,109,150,122,105,120,120,150,152,122,119,125,123,126,124,107,100,113,248,233,216,189,160,142,58,24,13,77,111,127,183,189,182,157,140,131,96,83,59,43,73,119,222,196,171,146,129,128,32,13,53,101,114,127,119,101,70,70,110,127,77,86,161,148,130,118,199,183,170,167,156,141,30,115,142,133,131,130,101,103,181,176,152,126,66,44,73,94,111,128,150,122,100,101,104,118,61,110,87,76,93,125,190,170,150,134,135,129,112,89,63,123,141,132,175,154,136,142,140,132,117,143,129,128,136,132,168,142,112,113,128,128,155,169,159,144,139,131,61,136,144,124,112,123,86,81,104,121,129,130,160,127,118,150,151,134,126,115,121,132,134,131,137,148,144,139,140,134,106,102,105,90,87,113,134,129,128,121,121,123,153,151,129,139,142,134,150,142,141,148,149,141,100,121,133,147,150,134,163,158,147,132,141,132,142,127,141,136,136,132,232,218,205,189,169,146,243,224,201,171,147,138,224,196,169,162,154,140,51,20,59,111,121,128,203,197,193,177,162,145,75,40,47,122,130,129,102,77,47,83,121,129,111,108,84,56,63,114,211,181,154,137,126,125,213,198,186,162,144,138,41,45,90,110,118,130,83,63,130,164,153,128,195,167,142,123,113,119,19,42,105,113,120,132,50,63,49,64,112,128,114,90,132,171,162,134,129,128,107,83,74,110,50,116,109,120,128,132,94,59,73,111,117,126,197,170,166,153,138,132,65,48,109,133,131,128,170,163,172,158,138,130,66,126,147,160,151,132,42,129,117,95,91,120,97,165,164,142,133,125,163,142,114,88,97,122,104,77,142,143,128,120,136,160,188,169,149,130,113,83,85,102,114,125,164,169,142,120,122,124,98,152,132,105,92,117,42,71,125,155,151,137,94,105,81,107,118,126,84,56,123,117,108,122,174,179,166,137,118,121,130,103,147,152,134,124,148,127,94,117,144,134,129,106,102,95,106,118,147,157,153,125,103,117,155,128,113,132,120,122,181,151,136,126,122,122,110,111,109,108,120,124,97,130,103,89,107,124,179,158,158,142,131,128,142,111,115,122,126,125,145,145,134,115,129,128,130,139,112,99,121,125,79,104,119,102,105,123,116,121,136,125,126,127,124,100,122,119,111,119,159,140,139,128,138,131,105,100,116,128,135,132,159,142,156,147,140,134,130,150,129,126,114,120,138,124,146,131,109,119,93,115,125,131,125,129,125,121,101,119,114,120,163,154,151,153,153,139,166,153,150,133,119,121,159,151,128,130,122,123,147,154,144,133,128,127,129,131,134,140,148,138,138,136,120,131,135,131,150,140,137,144,129,129,23,12,107,119,110,205,214,212,208,201,102,95,69,117,107,118,123,118,123,121,82,58,83,95,84,139,145,153,161,169,102,100,138,121,101,129,130,138,150,139,76,104,86,112,133,113,91,63,73,129,199,193,182,181,172,119,101,83,94,76,161,157,152,157,158,110,90,121,96,79,124,107,114,88,73,152,137,121,107,99,57,50,100,81,74,115,96,72,49,69,83,68,40,53,103,36,131,107,84,64,236,245,242,231,213,95,109,88,69,110,228,221,204,182,170,129,110,97,118,104,98,76,98,75,61,93,77,113,91,72,116,94,106,134,118,177,188,169,162,153,163,149,131,131,132,177,163,173,168,158,113,131,107,113,100,132,143,131,134,142,45,36,121,113,102,43,95,84,67,56,76,82,68,48,33,55,58,59,43,65,66,85,66,81,94,102,82,54,33,94,113,111,89,60,34,138,120,101,101,86,88,73,55,114,115,92,74,93,77,123,90,117,99,79,59,97,75,97,122,104,233,237,227,208,190,209,230,233,240,241,195,197,188,167,147,204,185,168,162,157,142,124,119,123,106,117,110,81,121,123,74,116,124,119,120,178,168,146,132,125,102,104,105,110,114,104,82,78,100,86,120,102,105,93,143,127,108,128,106,88,177,189,203,207,215,101,131,119,95,73,149,139,135,147,153,160,167,165,174,177,120,109,134,140,145,131,130,142,139,161,143,158,148,145,145,123,142,132,116,102,40,23,79,82,84,26,83,141,130,122,65,46,43,89,86,28,75,80,79,98,84,65,47,26,44,49,112,101,100,94,88,76,75,48,82,104,100,75,45,15,99,83,63,34,30,66,55,94,118,113,122,106,91,68,60,135,122,104,77,59,82,102,84,62,46,92,74,55,82,71,145,134,118,93,75,79,62,83,65,55,91,94,64,70,98,89,117,110,87,97,210,223,225,223,213,83,103,86,101,85,126,106,81,79,105,216,219,217,199,179,86,78,115,138,135,102,84,87,59,46,219,206,184,167,158,201,188,165,145,135,87,113,142,152,155,190,170,153,149,146,205,208,201,185,167,84,73,124,104,96,76,88,99,74,80,110,125,122,99,112,108,84,70,130,137,161,152,136,119,105,110,91,101,74,96,111,101,93,153,149,133,124,102,97,120,101,93,75,81,64,111,94,107,79,58,188,206,215,221,232,163,175,165,150,136,103,106,123,133,132,168,184,191,183,170,110,117,90,98,93,104,87,122,98,127,129,110,127,113,125,134,118,102,140,132,186,199,202,198,188,149,147,175,185,186,117,93,99,112,93,107,138,138,129,128,96,129,104,118,134,145,136,115,121,129,138,155,148,134,120,170,151,150,145,138,168,173,185,194,200,144,159,172,168,156,121,121,138,173,168,126,111,140,139,117,149,133,142,137,130,143,139,158,158,146,119,128,121,132,145,122,136,159,153,141,133,133,130,129,126,120,76,50,149,109,92,155,118,90,66,132,117,87,156,117,119,102,44,83,91,109,73,106,84,29,55,130,112,81,241,75,40,91,89,67,112,90,149,81,72,128,90,71,28,160,73,157,123,143,108,63,88,70,81,97,75,111,149,113,96,78,104,83,179,95,105,106,65,130,66,51,118,92,53,68,105,75,176,151,115,94,75,68,95,220,103,125,105,43,95,39,114,65,145,135,33,142,138,103,52,82,85,117,110,67,102,74,42,62,118,144,121,82,57,102,67,75,44,129,96,75,63,88,48,116,135,94,85,102,66,122,77,105,122,152,120,56,90,83,100,90,128,63,80,103,126,117,103,80,193,42,73,117,93,91,95,128,100,128,162,70,120,126,73,123,99,99,91,75,135,81,125,111,77,13,94,78,85,187,157,11,143,109,99,119,53,141,82,122,68,132,89,136,119,88,75,49,174,119,70,138,121,108,78,52,104,90,96,93,93,114,90,78,46,58,62,114,69,44,162,103,58,98,141,83,137,95,119,73,111,81,46,126,111,123,107,117,122,121,54,106,104,59,110,148,97,155,97,83,133,97,71,57,91,58,52,79,127,152,109,96,92,145,107,149,102,61,125,61,170,56,89,77,106,38,147,96,77,105,123,85,83,117,63,69,126,133,93,107,92,77,115,95,111,103,61,87,103,98,155,94,111,80,78,54,117,128,130,99,109,106,99,113,133,115,89,65,74,112,127,142,121,141,112,99,119,92,122,183,155,122,98,75,78,85,101,108,134,128,123,115,90,79,58,73,127,106,60,97,107,141,163,130,123,136,156,201,189,204,206,140,116,69,60,117,123,106,124,91,63,150,144,110,80,63,112,80,70,76,63,114,86,147,165,137,125,120,140,115,101,101,99,166,158,158,104,126,131,134,143,121,102,73,36,83,132,113,76,38,20,132,111,78,73,51,131,108,131,105,80,148,138,101,65,47,115,86,50,124,129,116,89,85,87,64,111,74,39,115,113,112,83,75,122,127,114,91,106,125,130,131,108,79,136,112,110,147,164,144,124,121,236,218,190,168,106,101,160,172,191,113,138,102,91,109,100,71,85,112,119,121,96,51,64,126,135,114,76,34,104,145,127,90,56,131,142,131,92,123,102,128,105,63,24,95,115,87,49,156,174,123,105,88,58,55,141,119,99,75,81,137,117,114,80,56,119,91,106,166,135,114,84,38,93,116,129,103,97,87,97,115,184,193,173,157,117,88,114,151,121,126,111,75,129,133,130,107,71,115,92,128,108,120,100,97,111,80,119,122,91,114,94,149,129,136,114,88,132,110,85,116,99,101,71,71,110,140,142,131,110,122,98,83,127,100,106,130,123,114,103,113,87,140,116,113,140,161,171,145,129,115,178,158,161,160,118,195,209,221,228,99,83,140,134,140,127,186,168,187,187,107,114,100,111,111,104,130,131,116,128,128,104,64,18,49,126,107,69,56,153,154,142,110,113,89,120,93,73,190,172,119,96,57,21,60,126,122,81,99,117,159,141,108,88,120,144,125,89,44,94,147,131,93,81,61,133,113,85,47,62,123,121,87,53,90,120,94,76,70,48,125,103,93,64,35,140,129,88,47,30,127,104,58,51,103,124,100,102,76,47,115,87,54,46,77,182,218,174,163,145,140,126,89,105,82,125,119,101,69,58,125,107,172,145,128,138,113,109,92,90,117,93,83,93,132,125,102,67,148,161,131,110,96,99,74,119,92,54,84,81,110,152,120,106,131,108,74,68,99,107,121,97,120,101,78,132,110,127,164,134,111,159,204,189,178,158,183,146,144,137,123,106,136,108,135,117,91,163,135,113,119,177,134,122,121,132,109,157,131,113,115,87,87,100,92,120,95,59,146,139,129,101,135,122,101,119,100,112,88,99,118,90,123,125,107,121,98,73,104,80,112,79,86,122,96,104,81,107,90,93,112,150,140,109,115,113,86,73,76,112,130,111,101,112,84,123,97,63,134,115,109,77,128,141,119,125,101,108,147,119,134,149,150,127,115,136,244,220,210,189,105,138,171,156,174,117,162,133,146,141,115,93,119,98,122,114,106,154,145,162,107,131,189,165,152,101,107,129,114,139,116,186,186,161,180,100,89,137,116,116,106,130,194,196,207,110,156,157,138,149,102,93,159,138,120,109,132,105,122,135,148,128,85,76,102,168,154,141,117,100,125,106,62,101,146,124,102,65,25,15,120,94,46,21,94,149,128,115,85,92,119,93,70,52,30,162,151,123,91,80,126,112,84,47,33,138,114,73,60,87,126,211,174,158,143,129,106,65,31,133,119,95,52,99,173,123,96,119,206,178,127,104,60,61,67,152,136,104,63,83,133,130,92,64,45,120,96,53,30,130,128,103,74,59,35,135,114,77,30,57,108,130,123,90,87,143,125,93,54,60,133,118,79,87,95,115,89,111,88,65,124,102,70,40,47,148,131,123,130,104,127,109,87,56,121,147,123,121,107,85,178,237,200,193,170,139,118,100,75,110,133,121,81,73,68,120,195,157,141,131,127,102,107,88,60,136,113,100,69,45,128,105,93,77,67,131,116,149,184,156,115,85,35,45,112,128,108,68,73,111,118,93,187,162,139,136,115,84,57,37,131,133,125,98,85,138,115,92,86,61,116,96,70,52,110,115,109,135,104,88,136,159,122,109,115,122,110,98,70,95,112,81,68,85,90,124,101,87,56,89,109,82,98,100,115,124,102,76,88,63,111,78,42,78,102,110,71,64,131,111,125,104,107,87,123,129,131,99,85,68,147,137,102,99,75,120,155,142,109,91,132,109,131,141,113,136,119,94,152,128,127,102,79,159,134,111,78,98,109,80,115,86,51,63,103,116,86,170,149,123,135,178,159,125,114,113,189,226,203,202,140,117,116,94,70,128,103,94,174,149,118,98,83,84,106,115,157,120,94,95,131,112,75,96,74,121,97,144,117,95,120,90,140,138,110,119,93,55,92,114,114,87,151,125,100,111,82,83,160,139,114,86,56,90,138,104,109,101,77,118,140,142,143,148,126,121,102,129,107,111,113,79,58,111,91,120,94,63,115,98,121,94,99,97,78,120,92,68,173,148,122,114,109,87,82,132,229,192,176,155,137,116,123,97,115,132,115,86,120,95,135,116,101,136,108,109,74,100,125,115,112,158,144,124,134,114,83,73,147,120,120,104,150,122,116,110,104,192,183,174,134,112,116,120,93,121,101,93,110,90,121,93,147,152,122,115,153,171,161,142,123,95,116,114,93,113,89,96,77,93,113,174,180,143,138,116,86,100,135,106,103,121,149,115,103,121,95,82,149,121,117,92,93,111,114,123,209,196,193,183,125,102,107,130,104,115,91,113,103,99,114,86,68,108,110,111,159,162,125,113,125,235,234,225,214,99,74,118,121,127,104,123,158,128,127,113,96,116,136,158,100,80,138,155,166,118,143,115,125,114,119,137,133,136,139,151,188,172,174,173,138,161,158,158,155,121,198,194,211,202,100,90,112,110,122,100,91,122,128,135,101,109,127,101,114,105,126,160,147,143,109,138,142,158,163,113,174,185,188,206,112,154,166,176,183,101,108,140,140,143,106,135,130,137,126,103,114,115,128,126,107,86,21,115,75,117,139,97,65,105,64,191,101,106,139,107,98,218,132,104,73,136,165,84,118,150,111,58,130,107,99,136,132,56,52,102,136,69,78,163,85,173,148,138,85,69,106,128,133,155,104,91,149,56,104,103,101,172,96,57,104,97,125,197,166,107,169,47,120,103,150,89,99,139,162,101,69,137,158,126,191,173,127,79,155,51,131,112,86,74,135,61,114,81,125,117,112,72,175,72,127,123,142,132,78,116,158,111,121,143,108,102,89,20,194,81,99,107,65,150,103,78,91,69,96,104,116,116,103,105,107,117,110,130,28,88,103,62,72,85,125,126,141,126,178,121,102,57,46,124,97,91,89,138,95,98,143,99,169,123,140,119,113,82,140,118,112,91,92,241,134,89,95,112,78,167,140,145,121,100,109,205,144,91,100,113,103,142,175,95,117,121,35,121,127,159,129,85,64,75,116,98,103,127,129,66,68,110,96,86,79,100,156,133,92,135,96,164,132,121,93,163,134,91,208,104,77,126,116,58,136,118,132,81,61,73,115,66,129,123,111,85,42,178,134,108,132,159,45,157,105,164,100,94,60,96,57,154,105,102,103,114,96,12,91,119,115,67,92,64,94,61,106,106,165,105,94,98,68,30,146,130,107,173,140,102,90,163,106,184,100,53,68,131,92,105,111,68,153,186,101,82,48,99,147,122,136,176,96,96,104,132,167,149,136,138,144,97,120,92,128,128,129,129,130,130,131,130,129,129,134,133,127,125,136,135,135,134,173,172,133,139,136,165,133,176,137,159,135,152,147,161,147,152,149,156,146,146,140,136,134,135,136,140,139,155,123,133,132,142,132,148,143,177,124,143,123,136,126,134,126,125,125,124,129,128,123,123,133,133,116,116,121,121,121,120,129,128,131,131,132,133,132,129,138,124,138,124,132,100,135,94,149,111,152,115,150,128,141,133,129,129,130,129,147,145,136,137,120,122,120,122,127,129,104,108,113,115,124,124,140,139,147,145,132,130,184,177,201,196,170,171,160,161,145,147,137,145,131,131,130,130,130,130,130,130,132,134,131,132,131,133,141,144,142,149,84,93,103,104,139,139,142,140,147,147,172,165,122,121,98,100,101,106,112,117,122,124,124,124,134,133,133,133,146,142,147,145,156,156,143,146,119,124,129,132,151,149,136,135,147,148,181,180,199,188,190,173,166,161,147,142,153,149,154,146,150,146,138,134,131,135,96,136,48,138,56,131,63,124,85,128,103,132,117,134,120,132,125,129,131,130,129,128,129,128,163,168,117,120,121,121,136,138,131,132,135,136,131,133,133,133,133,134,117,118,105,109,142,151,144,159,131,138,121,126,123,123,121,124,131,131,129,129,141,140,142,134,87,90,109,109,130,127,139,143,133,131,127,126,134,135,134,136,97,98,130,132,134,137,115,119,125,130,107,109,119,118,126,127,134,135,127,132,172,203,160,196,152,179,152,172,148,168,153,172,145,156,137,140,102,116,42,56,74,61,82,70,86,78,101,97,104,100,115,108,116,108,123,118,149,143,166,129,168,96,142,95,135,98,117,86,116,93,121,108,119,107,121,117,135,135,127,138,72,132,99,136,112,147,120,152,136,155,138,146,140,142,134,139,163,145,192,130,147,124,147,125,133,125,127,124,128,123,129,122,130,122,130,125,130,137,135,180,124,133,130,129,132,133,124,124,131,130,132,136,126,124,127,125,132,132,133,133,144,140,143,142,137,135,143,138,152,149,221,219,158,161,143,141,130,129,140,135,170,145,193,156,186,152,167,139,151,131,142,127,134,120,131,125,135,133,141,125,199,109,137,126,134,123,130,129,132,123,128,125,122,126,125,125,130,128,91,89,138,135,139,134,133,129,132,130,125,128,136,135,129,127,126,126,132,131,133,131,128,120,132,126,126,119,134,130,131,123,104,95,140,141,136,137,133,133,133,134,117,98,74,49,112,111,123,122,126,127,131,131,127,126,128,129,130,131,124,127,101,107,108,109,115,115,100,99,130,128,134,136,125,127,128,130,136,137,145,150,149,164,136,151,114,111,124,125,143,150,162,174,158,169,136,137,131,131,131,131,132,133,111,110,122,121,136,136,134,133,131,132,127,127,125,125,128,129,129,130,125,127,140,140,148,149,133,136,146,153,110,118,127,129,128,129,131,133,127,131,140,161,167,224,131,139,136,143,135,139,138,143,149,155,141,143,134,132,120,111,83,83,121,126,102,107,112,115,97,104,120,115,129,123,122,122,134,135,122,131,102,124,114,119,93,103,78,79,67,72,66,73,78,82,103,102,144,135,165,139,165,129,160,126,153,127,161,134,160,142,160,143,148,140,138,135,138,95,147,54,143,78,140,112,142,113,140,121,135,117,135,122,136,131,131,132,147,159,140,156,127,81,142,128,146,127,144,125,146,128,149,130,144,135,133,128,130,131,131,131,134,139,126,134,141,154,168,205,153,176,148,163,147,158,141,143,131,135,126,146,108,157,107,156,119,146,100,138,104,125,119,134,101,122,113,122,95,133,52,140,83,136,110,133,114,131,123,131,133,131,138,135,132,132,127,127,129,128,124,122,128,126,145,170,143,172,141,163,143,176,138,164,139,155,135,145,135,136,136,127,132,76,128,76,127,63,125,66,123,67,120,71,124,92,122,111,133,133,135,136,139,140,147,147,150,144,156,147,150,145,154,146,120,123,123,124,137,133,170,141,124,124,135,134,134,135,132,132,129,129,130,130,136,136,130,132,147,159,135,158,115,146,120,148,117,136,115,137,113,132,133,142,140,144,132,134,134,135,134,137,137,147,162,178,136,147,134,144,123,132,111,113,113,113,124,124,132,131,126,126,117,114,100,95,130,125,157,145,164,156,163,158,145,145,133,134,134,134,127,126,113,102,136,130,124,122,143,145,127,131,135,143,133,137,132,132,92,94,122,125,128,129,131,130,134,135,132,128,129,127,132,132,131,129,127,127,129,129,132,131,139,131,137,132,216,178,146,134,147,137,151,142,148,139,144,138,128,127,129,129,123,131,71,91,126,128,130,134,117,123,125,125,135,140,129,132,132,132,133,134,124,130,127,133,133,138,142,149,135,141,145,149,154,164,135,138,135,135,141,142,138,137,116,96,105,86,127,118,128,120,124,117,125,117,125,121,131,131,132,134,144,145,112,112,121,123,113,116,121,123,139,138,128,128,131,131,134,132,132,132,125,128,127,130,125,131,120,128,90,119,68,98,99,112,115,124,135,135,134,134,128,129,137,137,137,138,110,114,129,130,144,145,123,125,129,129,132,133,129,130,168,187,140,149,137,144,129,130,129,134,133,138,118,118,122,120,131,130,129,128,133,133,125,125,124,123,181,179,129,129,131,127,139,136,130,128,133,133,132,132,121,120,122,119,132,129,129,125,107,96,136,137,150,146,135,134,131,131,130,130,126,123,126,123,128,125,130,123,134,127,183,159,143,135,137,134,129,129,128,128,134,133,139,138,133,132,129,127,154,151,150,144,146,146,141,142,132,132,131,131,130,130,132,133,114,115,132,132,122,122,132,131,115,117,120,120,129,129,130,130,130,129,130,131,129,131,130,130,129,129,133,132,143,144,91,91,137,136,118,107,60,45,56,49,57,52,60,56,71,75,77,80,92,97,106,106,112,131,58,121,19,65,84,101,108,122,121,127,112,117,106,112,117,124,126,127,130,129,138,133,166,155,192,179,192,177,208,191,204,192,186,179,163,163,138,142,134,134,144,142,243,236,148,146,141,137,145,141,151,144,147,143,135,139,134,133,134,128,138,88,142,10,127,76,130,96,129,102,128,108,123,111,127,119,127,124,136,136,139,139,142,140,246,241,158,167,143,145,146,149,143,145,148,152,133,134,139,135,135,136,99,137,95,133,75,138,67,135,73,128,83,132,96,126,115,127,130,132,137,136,140,135,134,130,137,131,159,151,215,197,181,170,160,149,150,143,145,148,186,207,141,147,135,137,122,122,126,125,128,126,127,127,134,126,131,123,133,133,126,122,128,122,99,93,59,60,82,82,106,107,119,123,124,128,128,129,134,137,133,139,133,136,141,132,139,122,142,97,130,81,128,89,129,101,125,112,137,140,129,148,101,159,118,180,122,178,120,178,116,168,118,153,127,151,126,136,132,134,125,126,118,105,156,124,180,132,163,124,148,121,131,112,127,115,125,122,129,131,128,129,136,134,142,141,165,158,203,182,141,136,132,130,135,135,130,130,133,133,132,132,127,126,106,105,112,110,106,105,80,84,100,101,122,125,126,128,101,109,46,59,114,112,119,119,126,121,129,124,128,125,125,122,123,120,125,122,135,134,121,134,56,139,131,145,135,138,136,139,126,130,122,132,126,129,124,129,153,169,146,179,138,139,151,143,148,138,153,137,142,129,144,126,140,128,133,126,136,134,154,149,173,157,152,144,149,141,137,136,127,121,123,121,121,126,120,123,157,143,166,135,120,122,112,118,102,118,111,124,134,131,141,138,135,134,126,129,140,123,152,76,131,116,138,136,126,134,130,142,126,136,120,132,126,128,124,127,131,138,80,147,126,138,130,140,129,134,133,135,131,132,126,127,127,125,125,123,132,132,130,132,123,130,102,102,107,110,116,127,132,152,142,160,143,151,142,146,132,132,132,132,125,126,132,140,158,199,135,149,134,140,135,131,129,120,127,121,129,130,122,123,125,124,138,138,138,135,140,141,101,94,105,98,121,122,127,128,126,127,119,121,133,156,132,159,130,148,137,164,127,138,130,137,135,140,126,126,128,129,129,129,126,124,130,128,143,138,149,143,185,170,129,127,138,133,138,135,132,134,137,144,139,183,131,145,127,128,128,127,128,122,129,125,145,139,135,131,132,133,132,130,152,96,159,85,150,105,154,115,143,120,138,126,134,124,130,126,128,127,121,123,122,123,116,125,84,87,133,135,129,131,123,126,133,135,131,130,136,134,129,119,79,63,116,116,136,133,133,130,140,143,127,127,124,125,127,128,128,126,124,120,139,128,153,134,151,134,174,145,159,136,165,144,171,149,143,135,134,134,133,133,121,119,177,162,166,154,127,130,132,132,136,137,142,143,138,137,167,151,162,142,128,136,142,148,128,143,145,153,140,149,132,141,128,139,127,133,156,169,131,129,126,120,127,125,129,120,131,126,126,123,124,121,122,121,123,123,138,140,149,156,145,152,105,102,131,126,151,146,147,139,144,137,143,133,135,130,132,130,131,129,126,130,126,129,110,135,115,139,108,146,105,147,121,134,124,133,137,137,135,134,143,142,146,146,120,121,139,137,133,129,149,145,139,133,130,127,134,134,134,134,125,124,117,119,120,113,84,80,122,125,108,112,97,102,118,120,124,123,115,116,110,111,98,97,127,124,129,127,120,117,114,109,106,104,116,116,138,138,139,141,142,146,127,125,133,130,134,128,134,127,116,91,105,84,114,106,128,128,126,126,131,137,126,129,133,139,134,145,132,143,150,192,131,142,138,141,132,130,132,130,149,138,196,152,137,125,134,125,139,128,133,125,141,134,134,135,134,135,134,135,131,130,136,133,110,106,142,144,153,162,131,129,134,132,131,130,126,125,132,130,168,153,126,124,130,126,140,135,140,134,138,133,145,137,135,134,130,130,132,131,133,132,129,129,125,128,128,130,133,139,143,152,193,215,152,160,130,131,129,131,130,131,135,136,136,141,83,81,121,120,136,130,150,145,147,145,134,133,135,133,146,142,135,131,127,128,134,135,93,102,126,132,131,133,127,129,124,125,120,122,103,106,128,129,139,138,127,128,134,134,143,138,139,134,135,133,131,130,133,131,139,134,138,136,166,156,119,116,121,122,126,124,116,117,123,124,131,131,129,129,130,128,141,138,135,132,154,145,137,129,131,125,146,137,138,135,131,131,131,132,129,130,134,138,111,116,113,118,123,125,122,124,143,147,138,140,116,113,114,112,130,126,117,115,127,126,139,137,141,139,131,132,143,144,139,140,130,130,129,128,136,134,119,117,152,143,155,143,120,119,142,139,124,130,126,128,112,110,112,109,136,132,125,118,121,115,103,101,109,100,125,120,121,117,122,121,128,128,127,127,124,124,128,127,131,129,142,138,147,141,115,108,113,109,122,119,136,133,150,139,142,131,119,111,151,137,121,116,146,134,137,129,121,123,127,129,130,130,130,130,136,137,126,126,136,136,133,133,139,139,142,143,119,120,134,134,132,132,133,133,135,138,129,131,133,134,135,138,126,130,117,118,131,132,135,135,129,129,128,128,126,129,127,129,123,125,115,117,156,157,127,131,129,129,128,129,129,130,131,131,126,127,135,134,136,135,140,136,117,113,132,128,104,97,109,106,131,131,131,131,121,123,124,125,126,127,127,127,135,135,128,128,130,130,141,140,129,129,129,129,129,127,127,125,149,146,125,123,134,133,134,132,152,150,138,138,128,128,126,125,132,133,141,143,136,136,126,127,126,127,129,131,128,129,135,134,176,139,192,135,145,122,149,117,155,134,169,133,157,139,142,136,151,152,142,147,166,174,103,107,141,134,140,136,144,135,147,135,156,131,153,127,133,126,130,124,127,130,123,124,114,105,195,193,156,157,165,158,126,122,149,141,174,173,152,147,136,139,131,138,163,169,103,124,80,102,153,186,121,151,134,161,156,190,141,151,121,123,124,127,119,127,133,134,157,156,81,69,136,134,160,169,118,114,135,128,114,116,97,97,117,122,152,161,115,121,106,122,135,137,111,113,125,135,141,145,143,146,143,150,132,136,142,150,151,167,101,107,155,173,112,124,105,100,128,126,127,130,133,134,142,121,131,116,176,145,161,120,209,150,196,133,147,115,149,130,144,145,144,145,120,119,163,160,117,118,123,117,154,119,193,98,149,101,137,116,133,135,140,143,144,156,131,146,186,201,140,139,123,125,158,169,157,166,142,143,130,131,132,132,128,128,141,142,147,149,145,148,137,139,129,129,107,108,157,157,120,121,119,119,140,132,137,131,118,113,143,136,134,135,164,158,133,125,127,124,148,122,197,130,173,145,110,139,123,165,83,158,90,167,93,142,136,169,134,152,130,126,154,138,227,150,156,114,147,114,142,109,135,110,166,135,176,150,152,142,132,132,136,136,130,135,143,152,136,144,152,160,177,185,112,112,165,166,160,161,145,145,138,139,116,118,127,131,66,80,132,142,119,127,101,108,120,130,126,130,135,135,142,139,153,137,55,30,142,139,139,143,135,133,129,133,109,108,129,129,136,135,134,131,129,132,132,134,135,149,79,206,123,137,135,143,130,140,131,134,100,99,165,164,142,123,148,133,133,122,142,133,138,125,119,111,129,123,137,130,131,132,123,129,174,185,196,181,127,111,156,141,132,114,129,106,132,107,126,117,134,140,131,136,119,146,92,246,128,132,125,129,132,140,128,141,126,145,137,142,130,130,110,115,124,139,127,151,118,152,98,146,36,108,126,158,112,146,112,130,138,136,145,138,153,145,116,125,90,103,137,138,189,185,141,151,86,93,111,111,133,171,125,209,140,132,130,134,129,101,142,120,142,132,135,126,141,140,140,134,128,123,131,123,138,118,163,133,240,197,176,151,126,123,81,94,109,118,124,133,135,133,137,134,154,135,140,155,69,190,119,149,141,151,142,123,135,125,129,130,127,125,132,127,107,80,123,103,145,131,133,107,140,103,135,106,170,145,159,143,136,137,127,130,105,119,129,134,141,151,116,127,119,140,75,119,152,162,149,152,72,138,9,143,118,160,126,134,141,147,135,131,129,129,135,129,136,126,133,125,137,135,146,141,145,139,141,140,133,130,213,208,139,130,139,136,117,117,126,125,133,130,138,131,141,100,145,93,159,121,144,132,117,160,102,187,99,162,117,144,132,132,134,134,140,141,127,126,128,131,116,116,121,127,119,126,114,114,99,100,141,144,148,159,179,224,95,131,100,125,87,110,112,132,134,147,111,125,122,122,137,140,141,129,169,12,144,132,133,144,141,146,137,147,136,122,133,130,131,128,141,142,128,139,15,69,160,159,142,130,137,126,159,141,145,143,128,125,134,128,131,130,127,127,114,104,119,98,83,68,139,120,173,142,199,154,191,153,158,145,128,130,127,127,148,150,110,99,119,109,120,113,163,154,110,90,138,129,149,144,131,134,124,142,76,217,130,129,140,138,133,135,145,150,136,138,127,130,130,134,144,119,178,70,143,130,115,136,139,138,129,109,136,116,147,122,126,112,126,123,132,139,128,144,107,156,75,163,120,164,151,136,151,99,160,112,159,126,143,126,140,138,137,135,152,108,251,85,138,116,137,118,141,119,136,121,150,134,138,131,137,137,143,144,150,153,148,154,152,151,117,104,124,96,93,67,146,138,149,148,149,153,172,193,108,114,125,128,145,165,149,160,121,130,115,120,110,112,121,118,145,146,141,142,127,127,103,95,138,143,114,126,109,115,143,136,153,149,144,142,140,138,150,144,128,116,142,136,135,122,93,88,164,163,141,142,171,182,154,160,124,125,122,123,158,155,111,97,138,130,157,134,101,65,129,118,121,114,124,119,131,133,125,129,136,147,135,152,131,133,110,115,118,114,161,159,233,218,172,166,140,107,125,0,140,103,140,115,125,113,132,135,128,133,138,146,131,145,127,133,131,131,122,122,135,132,126,124,132,133,164,167,121,127,117,120,167,162,145,143,135,134,136,134,156,146,195,177,127,139,108,140,141,173,141,178,131,155,129,141,134,134,119,114,184,184,127,126,147,151,130,140,146,159,134,145,131,136,137,142,135,137,128,136,83,108,97,98,152,119,207,144,142,121,144,129,131,127,130,132,124,125,108,107,94,116,81,114,139,173,131,158,145,177,141,163,136,140,143,144,135,141,132,136,134,142,142,136,173,50,143,106,142,127,134,139,127,133,125,125,129,130,131,133,132,148,110,138,113,135,138,175,108,151,55,119,51,100,93,116,121,121,146,151,99,120,127,137,107,122,125,139,110,132,135,156,141,156,148,157,137,137,141,140,139,137,130,128,138,136,132,134,115,110,177,179,81,86,100,98,84,83,121,121,148,157,127,133,146,156,127,136,143,151,135,139,138,142,136,136,201,164,151,129,123,136,147,148,127,142,128,143,101,126,119,133,114,131,116,126,132,133,140,140,126,125,156,153,142,129,140,130,77,69,134,132,146,148,135,136,133,132,123,116,116,103,150,135,144,127,130,117,136,122,122,106,48,38,81,78,145,146,135,136,123,122,126,133,133,138,145,145,144,150,160,181,142,139,150,150,136,136,139,139,133,133,139,135,134,129,140,137,153,145,132,131,151,144,68,66,137,137,139,139,146,146,142,139,129,128,131,129,133,132,135,134,135,134,201,200,137,136,146,143,155,153,157,158,131,138,140,139,143,144,128,123,216,192,159,150,137,138,136,142,145,148,126,162,140,170,186,95,131,140,143,148,133,128,130,133,141,139,153,150,122,122,134,144,124,130,159,166,133,139,151,150,138,139,131,134,121,121,131,129,148,180,121,135,118,131,124,148,119,119,129,126,150,156,155,160,40,154,115,157,133,129,140,133,143,133,143,132,144,130,141,131,134,130,137,133,134,136,141,140,145,137,152,124,183,91,118,154,123,158,136,134,140,142,138,142,138,135,131,131,138,129,121,128,146,219,124,123,125,135,120,126,127,141,133,136,127,124,120,107,152,125,149,108,158,144,196,185,174,164,151,149,138,131,140,137,149,148,144,145,143,145,140,143,141,147,112,125,113,113,149,155,143,149,146,151,138,138,141,138,144,129,134,125,143,140,153,154,142,123,162,42,154,106,153,130,153,153,137,137,144,144,142,140,165,151,161,140,144,134,156,124,167,143,166,155,132,132,137,138,137,132,124,127,140,144,134,140,162,180,127,131,152,169,145,156,133,134,131,133,130,132,147,149,125,117,127,118,159,155,147,142,122,117,145,144,138,137,130,133,113,149,168,224,166,201,129,151,147,154,136,135,140,136,152,141,120,112,140,127,161,100,132,115,118,125,115,133,115,157,144,146,114,135,127,139,138,141,135,135,137,136,147,142,143,144,139,152,142,136,147,143,177,39,125,71,147,143,66,88,132,158,123,126,116,135,119,124,128,135,133,140,137,126,137,130,155,38,149,103,130,135,139,143,127,137,135,141,138,148,131,148,136,147,132,139,136,140,115,129,115,151,136,160,87,131,157,176,150,164,140,141,135,119,137,133,141,140,140,139,134,134,142,144,131,132,131,134,131,132,116,114,129,133,205,207,130,133,160,170,137,127,124,112,158,146,155,137,134,136,137,142,177,184,149,152,135,134,133,132,135,129,144,136,139,134,161,155,126,109,215,186,177,153,160,149,139,139,136,140,140,142,186,71,129,144,131,165,142,152,140,151,141,143,137,139,144,138,150,135,133,126,136,143,99,152,139,131,190,118,122,147,134,155,136,143,138,135,137,132,147,144,150,144,138,134,129,133,130,138,56,175,129,166,147,165,140,138,144,137,141,133,150,139,129,135,40,83,126,130,110,120,100,110,126,128,141,142,217,175,172,151,146,153,125,132,128,137,141,141,145,145,140,133,132,131,129,144,128,177,133,195,147,120,138,131,161,114,166,134,162,118,161,115,155,129,137,136,141,129,141,132,55,168,121,126,136,139,120,133,149,147,132,141,131,136,147,150,151,132,101,31,117,101,129,132,122,138,128,137,140,170,131,143,131,134,149,192,122,158,136,146,133,166,143,141,141,136,141,129,125,155,140,138,137,131,111,112,131,132,120,127,149,148,151,141,156,148,133,129,127,124,144,137,142,139,134,133,141,138,133,135,124,96,226,152,116,108,128,105,155,130,153,138,144,139,142,141,137,135,142,143,156,162,136,89,188,145,181,152,138,146,146,154,145,149,152,133,158,133,42,153,117,144,149,139,125,139,134,128,150,128,143,125,135,132,143,141,143,141,164,173,141,142,156,155,154,154,169,170,77,80,112,105,135,134,126,143,120,172,111,144,120,154,107,153,95,134,104,134,128,116,163,131,151,136,135,133,142,143,152,204,149,112,156,128,150,126,127,129,139,175,143,141,138,135,168,148,152,105,164,121,134,122,119,109,122,148,136,143,153,132,158,148,149,150,133,131,142,141,150,149,156,173,138,155,129,144,111,107,130,129,96,89,106,104,135,135,144,146,131,153,134,154,146,166,117,138,163,187,190,216,149,156,149,152,142,142,153,154,109,145,40,102,116,126,137,139,149,157,108,124,139,146,142,147,130,126,120,111,172,146,169,136,150,135,126,96,159,143,150,122,162,129,156,142,135,142,144,138,222,109,137,145,144,142,141,143,138,136,124,150,133,144,137,145,141,144,139,144,134,154,114,136,145,173,151,215,110,115,127,134,145,150,145,144,144,142,139,131,147,132,141,119,143,106,165,41,147,129,129,144,138,135,138,140,128,150,89,163,154,115,141,127,132,145,135,157,143,145,140,141,127,135,127,129,142,147,116,147,104,162,153,143,146,130,144,110,133,123,130,137,118,198,126,152,154,146,139,127,147,112,207,151,156,136,162,137,108,121,130,135,125,131,131,134,134,134,141,144,107,143,137,144,124,136,115,147,130,157,119,167,71,144,97,128,134,138,132,133,138,138,146,146,147,131,141,138,185,65,145,123,139,130,142,128,139,136,157,147,124,119,164,148,170,154,133,130,157,148,140,141,130,135,134,137,136,137,143,144,144,144,178,186,71,73,120,118,127,124,152,151,155,146,141,138,142,143,139,143,133,134,139,140,138,135,146,141,78,198,129,139,141,141,134,141,137,136,120,120,124,118,143,148,148,152,131,143,129,137,152,158,157,160,175,178,137,139,131,133,146,152,121,147,142,143,129,136,149,145,197,114,103,141,124,140,141,140,129,129,127,130,131,124,123,117,150,139,120,109,119,120,163,163,117,121,139,139,136,136,94,74,150,145,126,127,147,150,158,162,84,74,136,129,140,132,136,135,146,145,124,116,129,120,130,129,130,109,122,111,160,141,135,113,131,121,136,135,135,135,147,147,140,140,144,145,139,142,131,137,145,145,143,153,48,49,145,143,151,147,158,146,135,124,124,116,159,140,131,126,123,120,103,117,113,119,148,146,128,124,123,126,123,120,158,141,148,137,146,143,125,143,89,107,116,123,149,147,141,139,149,153,118,121,139,138,105,119,168,147,139,141,143,138,133,130,126,126,143,142,146,144,124,123,143,145,149,148,147,141,151,143,118,113,175,171,125,109,84,55,34,51,109,112,118,132,122,102,78,80,132,119,132,132,125,131,109,91,131,131,136,136,137,137,140,145,140,143,117,136,122,106,109,91,115,119,133,117,103,80,55,117,123,102,93,80,139,116,70,39,95,89,103,113,112,122,135,244,229,215,199,181,163,150,146,144,143,173,171,154,155,154,151,148,145,143,132,138,116,85,117,94,108,117,107,116,132,118,123,119,88,67,49,95,84,95,121,103,74,70,179,164,141,126,107,112,119,95,103,149,139,148,144,147,148,141,151,133,142,129,111,131,108,128,122,108,121,96,115,138,116,93,105,115,115,123,129,106,136,180,147,130,108,141,131,118,136,155,176,156,135,129,140,146,142,134,141,130,109,80,52,38,18,47,118,134,155,141,100,78,72,89,79,96,92,98,133,111,83,91,72,58,105,115,112,120,145,127,135,113,113,105,105,85,69,61,115,96,116,145,159,170,175,175,168,155,140,120,84,52,80,145,125,127,116,126,128,108,101,198,227,200,178,159,147,148,121,88,46,109,124,126,126,137,147,147,129,107,164,148,127,117,134,120,111,116,120,103,98,73,66,61,70,115,116,125,126,100,77,188,162,140,114,128,139,123,145,165,164,134,109,100,108,118,127,130,156,182,190,173,167,165,162,157,152,147,150,164,179,183,173,155,140,136,134,135,122,92,69,140,132,118,108,128,138,132,123,127,148,137,150,149,139,127,124,130], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+40960);
/* memory initializer */ allocate([136,138,112,70,41,37,132,140,129,125,130,111,78,33,51,161,141,136,120,122,126,110,87,106,85,68,48,81,112,113,135,125,98,85,102,80,100,87,86,116,142,133,110,66,48,152,139,135,136,123,128,116,89,102,128,99,83,61,105,124,120,94,73,83,78,100,122,124,128,132,144,137,116,102,75,144,136,127,140,127,154,144,118,99,90,90,89,75,68,83,123,103,89,198,180,154,138,122,136,120,138,118,121,136,110,105,85,111,101,104,121,126,139,115,99,101,107,110,123,126,127,115,88,109,164,134,138,138,120,121,130,202,195,202,199,201,181,164,159,148,120,116,194,199,186,171,154,142,137,133,137,129,112,149,134,112,149,138,120,134,119,102,107,83,79,114,119,127,128,128,144,148,165,155,161,150,135,122,116,115,120,99,80,120,123,124,111,89,70,108,118,95,66,53,105,126,125,105,83,111,129,197,191,197,206,213,216,208,196,169,133,109,127,164,134,121,99,92,82,71,131,121,93,91,136,105,115,140,120,110,150,164,139,108,87,81,93,92,104,116,133,114,125,126,111,136,110,156,147,133,113,94,118,120,115,125,124,126,127,134,116,131,161,158,166,157,150,150,144,141,125,185,169,142,140,143,139,131,134,138,179,188,170,150,134,140,144,133,127,127,150,177,204,184,192,194,190,193,177,158,114,113,138,116,137,135,132,131,127,134,120,147,163,135,133,137,136,136,133,135,137,120,95,73,46,48,111,97,97,123,139,130,109,76,52,72,61,61,125,127,132,119,119,90,66,41,64,156,143,129,131,106,58,25,99,115,122,136,129,132,134,123,97,53,27,114,125,114,120,123,122,107,93,57,47,133,128,138,141,131,145,132,122,110,79,57,30,73,153,144,150,132,85,59,133,125,130,115,100,96,148,127,111,86,61,38,110,121,108,99,157,143,105,77,116,118,115,131,122,122,133,119,134,108,86,61,129,165,143,127,125,105,89,111,97,85,113,99,98,117,149,131,101,106,88,95,79,119,123,120,125,109,81,100,201,183,156,138,115,116,141,119,129,105,76,60,110,99,92,82,150,156,129,95,69,115,115,113,134,125,118,97,67,96,203,197,171,151,133,125,143,131,120,134,105,80,51,60,139,134,129,160,223,219,219,212,197,173,157,146,132,112,164,144,119,102,92,76,73,94,132,112,124,114,93,92,83,73,69,99,129,103,188,163,142,132,127,101,82,59,140,141,111,74,46,105,113,99,127,122,125,94,63,112,116,101,81,120,136,134,133,190,224,193,179,158,146,143,140,136,152,161,132,120,112,94,114,102,92,116,129,194,196,202,211,212,210,190,169,152,166,166,145,111,91,132,133,128,136,130,118,94,72,74,92,86,89,92,106,123,126,100,86,137,117,92,76,104,106,114,133,109,204,192,166,148,138,128,111,81,118,99,79,146,169,141,123,102,131,120,127,105,136,204,170,154,131,145,135,119,117,95,64,83,141,136,118,96,99,126,115,93,98,102,95,105,106,114,119,128,131,121,98,139,149,119,109,86,105,129,134,119,104,169,185,155,141,122,107,127,136,115,85,108,87,126,102,128,136,129,125,99,126,158,133,139,132,113,91,107,141,122,128,161,130,127,105,120,118,106,122,140,161,168,187,184,176,158,144,140,127,111,89,130,132,105,134,121,100,122,129,110,128,115,129,116,132,118,114,119,138,133,132,188,183,159,161,147,134,140,132,113,84,167,147,132,124,109,133,121,132,128,116,121,98,101,145,129,128,129,124,112,152,158,136,161,139,165,158,142,139,138,110,127,148,117,126,118,101,116,155,168,154,128,120,152,150,141,140,135,127,111,109,134,104,133,110,112,132,114,111,87,68,89,107,121,121,126,126,129,120,148,169,163,173,178,185,188,178,163,122,97,86,117,101,138,118,142,155,139,125,114,131,138,153,149,163,150,143,141,157,161,138,152,134,121,122,109,110,124,151,171,196,168,145,139,147,151,146,139,134,169,179,170,175,178,177,173,165,154,120,151,118,107,125,129,133,133,136,139,119,141,159,151,160,165,168,169,162,152,115,111,119,94,117,121,127,127,132,136,134,153,147,142,142,147,159,159,154,147,110,106,139,135,143,142,147,146,147,147,115,133,151,133,141,142,151,152,147,144,115,132,144,131,125,126,128,130,131,136,138,118,96,71,48,26,43,130,125,125,134,122,98,54,28,84,77,73,109,125,133,112,67,48,141,129,126,113,112,118,143,123,89,54,71,73,75,131,123,123,126,109,81,31,15,94,110,109,119,128,132,122,97,92,73,50,27,22,104,133,133,119,94,48,34,168,160,154,151,130,147,133,90,54,71,123,106,105,93,117,143,132,107,69,45,78,178,169,150,139,138,123,116,96,69,49,32,113,103,112,154,151,125,79,60,152,160,154,155,137,142,151,124,88,66,59,94,87,95,119,166,154,122,92,138,132,124,114,97,97,122,99,98,219,191,176,165,159,153,131,130,119,91,51,24,41,144,156,147,139,139,122,81,65,124,111,104,90,94,98,138,120,112,91,63,65,89,75,78,106,126,107,91,85,69,95,90,84,108,120,155,139,100,78,120,110,109,91,77,73,144,130,135,112,88,65,62,142,129,126,170,154,150,131,121,116,100,92,83,86,131,122,98,107,102,75,54,38,117,130,146,139,117,107,86,66,44,30,97,128,129,116,100,59,108,127,119,139,129,129,124,106,79,49,154,190,166,152,133,123,141,149,123,89,61,70,143,132,125,126,136,113,177,166,141,123,109,108,105,93,137,117,147,123,99,85,109,98,91,75,129,121,102,78,53,90,149,136,134,135,144,136,126,90,114,152,137,152,138,128,133,115,107,129,99,78,60,129,125,118,147,141,119,124,110,91,79,64,106,117,134,111,164,143,123,113,116,95,76,56,147,159,140,109,83,84,140,135,127,129,123,104,116,99,91,87,80,110,113,121,124,106,174,174,152,141,132,134,126,124,140,190,240,215,212,189,173,158,144,137,123,97,79,102,110,111,90,75,126,124,134,121,104,145,127,100,77,65,120,118,123,106,87,41,68,119,106,115,109,119,137,232,241,225,217,202,183,169,156,145,161,146,127,110,97,107,88,114,108,106,141,244,216,192,172,163,148,143,144,144,128,127,109,89,77,68,124,120,121,125,125,94,48,71,116,113,104,120,142,137,133,129,115,82,68,120,99,133,134,124,130,106,108,160,130,111,89,129,124,119,134,120,149,143,116,95,87,142,132,122,126,114,108,107,80,141,133,123,137,124,117,95,69,43,62,98,114,116,112,120,122,99,87,164,145,123,99,95,118,105,126,101,102,120,113,110,92,139,134,126,148,194,241,219,221,215,200,193,174,151,127,104,122,136,113,106,110,95,78,106,131,163,217,199,194,175,164,155,142,138,139,124,88,57,161,161,145,139,124,116,127,110,91,98,126,104,113,98,94,94,145,138,114,90,75,130,117,107,99,90,119,98,86,101,148,133,103,83,124,131,143,168,169,133,110,117,139,149,147,137,124,106,80,138,194,163,142,119,106,130,136,125,105,114,87,113,101,89,108,102,114,90,53,46,105,116,126,122,118,122,124,102,92,195,167,160,144,154,154,132,118,97,88,72,98,120,112,98,79,117,114,107,185,191,191,188,175,165,153,143,119,97,90,89,120,151,136,113,99,112,141,121,144,122,125,113,133,111,92,69,120,98,78,109,151,145,157,157,151,143,130,110,120,188,159,141,119,112,109,98,126,112,83,110,169,139,127,105,93,123,141,145,117,106,91,78,123,107,101,125,117,95,71,147,176,153,148,133,135,127,124,106,79,64,115,96,108,115,106,105,127,115,90,98,105,81,144,135,117,125,126,104,98,165,138,136,112,149,148,131,119,144,186,185,204,202,209,200,182,161,123,153,190,189,199,194,191,176,157,147,121,103,119,98,100,120,106,97,95,126,137,130,102,117,117,92,126,114,101,118,131,219,190,167,153,151,144,140,142,143,114,102,151,152,132,120,112,120,127,131,138,122,91,143,118,120,114,104,124,117,148,142,117,126,97,125,108,116,142,125,126,106,91,169,208,178,158,138,127,135,133,126,101,83,147,130,125,117,114,117,120,103,94,149,136,129,139,118,133,133,147,152,126,132,119,97,132,129,114,126,112,107,148,125,112,114,124,125,129,135,139,121,157,151,131,140,118,147,136,121,115,105,159,167,185,191,196,190,176,160,124,106,104,122,130,114,152,144,134,136,136,152,159,153,131,114,116,126,129,129,124,109,87,131,107,115,130,107,144,131,126,162,176,175,180,176,160,141,134,134,136,127,108,161,162,133,141,124,112,128,130,115,110,140,107,155,134,131,156,137,122,106,116,127,118,161,150,170,167,152,139,177,203,176,155,139,130,128,129,132,137,119,125,103,110,123,107,120,108,101,113,107,160,154,160,166,169,176,168,156,115,90,65,115,115,104,120,112,109,124,131,123,100,109,185,158,141,132,116,119,139,130,119,156,124,138,127,116,141,128,133,118,115,180,149,151,135,130,147,129,117,90,80,119,124,128,132,130,128,135,112,97,142,161,167,165,154,142,136,135,118,141,193,172,157,152,148,145,146,141,125,147,165,166,149,133,123,122,128,131,128,193,177,174,182,186,197,193,191,173,124,144,162,133,113,113,123,128,129,130,117,98,121,122,137,132,110,97,111,130,128,176,151,125,126,134,130,121,127,130,122,151,142,111,106,121,126,126,130,134,148,167,186,153,129,122,124,128,130,128,148,172,206,178,171,182,169,180,172,156,133,164,174,160,155,163,163,172,169,158,132,150,147,142,152,140,140,140,134,135,137,158,167,172,163,153,169,158,146,147,150,161,162,172,153,133,140,144,136,135,109,84,101,120,129,134,133,136,137,143,112,114,157,147,141,136,135,133,135,138,121,154,161,150,149,154,151,144,146,144,111,117,125,125,130,131,135,137,143,148,121,141,146,131,138,126,118,111,119,130,120,135,145,121,140,134,138,137,131,134,115,137,132,137,139,138,138,139,145,149,131,149,147,133,132,126,131,134,130,133,110,98,84,141,107,169,169,123,125,126,118,210,98,126,132,138,128,139,156,157,140,142,129,95,192,178,182,186,183,159,135,134,144,124,100,228,203,161,122,104,139,159,134,161,121,126,192,152,218,180,132,132,119,99,96,97,80,53,134,143,102,114,133,114,127,83,77,126,85,107,110,114,194,186,139,116,147,104,129,138,126,133,109,144,115,45,130,97,159,155,157,162,189,185,168,163,151,151,142,135,144,147,120,74,192,186,149,118,71,84,143,156,133,178,168,107,119,149,105,112,182,184,158,118,118,148,128,177,171,152,139,135,126,209,171,150,123,100,190,158,166,97,136,123,136,139,128,138,126,121,132,131,128,95,60,168,127,140,208,161,109,102,119,162,150,137,107,200,156,136,136,128,103,95,74,91,220,173,152,138,139,129,140,136,122,82,180,115,53,90,121,107,99,148,116,139,100,63,191,155,130,129,163,155,98,175,95,151,127,107,124,124,116,88,71,164,148,96,57,89,125,117,77,63,162,144,113,109,137,134,134,130,149,174,158,158,130,81,28,67,142,139,129,100,194,134,68,175,131,103,136,132,122,96,119,82,115,249,215,168,125,139,199,96,146,123,136,179,142,137,181,166,106,86,122,106,123,131,106,119,129,189,188,147,126,110,101,114,147,136,132,106,72,175,148,99,130,153,125,136,123,119,147,170,157,126,209,188,158,152,101,89,142,131,161,150,148,124,89,119,141,137,131,103,81,85,64,175,129,121,137,144,142,145,119,205,148,80,165,138,143,137,167,165,148,149,110,234,217,170,167,152,75,140,155,155,175,129,136,134,136,152,161,131,140,121,91,79,255,209,132,147,120,114,177,128,110,61,89,131,125,127,93,87,167,115,186,162,107,106,134,162,151,100,79,67,151,116,130,142,162,153,155,143,122,85,202,187,135,125,158,155,103,129,74,149,130,98,129,126,148,152,153,133,118,94,80,70,47,90,124,118,143,184,158,126,70,82,111,113,126,135,175,141,203,166,123,123,134,133,113,111,128,76,128,177,151,178,134,125,120,120,193,106,98,134,101,86,101,114,136,127,134,196,86,105,145,128,119,137,138,126,230,161,141,128,129,136,88,83,103,118,178,123,89,101,161,173,165,147,130,123,171,158,131,81,50,177,162,136,125,115,82,173,195,168,130,112,112,121,152,148,167,87,82,161,142,147,98,89,168,138,97,157,132,114,74,126,161,141,135,123,68,137,124,118,112,92,65,96,191,181,161,151,141,145,129,102,97,111,144,128,55,128,115,155,129,184,167,147,131,141,125,33,127,111,127,131,125,130,137,130,121,195,172,177,176,149,98,97,126,106,168,159,144,185,156,151,182,158,123,93,110,116,98,99,125,136,139,148,79,112,149,128,147,136,118,105,166,152,117,115,92,128,148,132,170,143,226,190,122,192,165,121,143,144,174,124,113,124,122,135,34,93,118,111,111,136,123,116,99,195,139,99,114,102,96,108,111,112,113,129,172,137,105,139,154,86,113,108,132,79,63,120,93,162,90,103,94,95,117,127,104,100,142,129,93,27,196,153,113,91,101,90,84,68,138,38,118,148,87,103,125,109,96,152,100,56,31,62,176,129,124,115,103,92,100,121,130,125,128,71,82,71,152,85,107,116,138,133,103,116,139,144,72,37,118,141,109,95,86,92,121,167,156,104,92,91,122,114,89,61,172,128,95,103,84,101,88,84,116,125,108,62,74,108,160,143,189,164,91,115,144,43,116,79,106,108,74,83,87,90,61,71,76,76,95,130,89,94,114,107,101,145,161,147,143,163,147,129,101,73,111,108,93,104,186,141,99,89,112,126,111,113,152,41,159,115,131,124,117,101,115,130,124,87,59,177,63,85,109,116,103,68,145,132,29,119,96,89,117,90,181,103,101,111,97,96,199,171,113,120,93,119,101,64,56,55,63,90,105,101,86,45,136,179,142,102,115,114,113,108,121,84,23,125,76,102,119,107,120,104,73,177,83,114,128,85,152,126,137,115,149,109,163,133,110,98,54,61,95,111,135,103,88,164,115,187,122,98,129,132,95,86,71,119,146,111,38,67,102,100,66,148,137,103,145,95,35,85,44,136,102,111,108,115,136,105,120,110,108,147,112,169,116,146,81,120,94,84,93,97,90,119,102,91,48,147,204,151,148,160,144,131,144,175,158,133,212,163,172,152,151,112,148,151,145,179,160,124,164,164,167,161,141,120,131,141,198,177,169,156,146,156,124,185,164,195,181,193,201,147,148,168,165,159,162,148,150,148,146,157,158,149,164,129,160,214,174,166,154,176,146,141,155,140,140,169,106,155,166,162,134,193,157,155,146,196,171,107,177,174,163,155,147,203,162,146,150,83,157,170,180,178,159,157,151,117,115,183,170,180,174,150,177,173,136,181,196,184,164,168,165,148,175,168,209,189,159,114,157,158,141,168,170,139,175,128,151,39,128,154,159,161,148,180,131,165,159,131,163,150,174,178,178,198,172,138,184,191,143,164,161,163,210,171,155,168,150,116,182,170,145,152,141,139,191,149,160,202,145,169,145,181,148,183,197,165,146,171,161,153,157,170,164,149,183,167,246,235,162,144,170,152,173,150,113,135,156,154,158,148,178,159,161,114,180,156,116,163,164,161,122,164,164,183,135,135,144,182,160,147,163,152,169,185,159,177,99,211,168,167,215,170,150,157,154,176,154,143,163,117,178,160,163,165,164,166,174,136,159,169,152,123,199,149,169,140,159,208,155,161,186,122,134,167,171,145,148,176,148,137,114,160,166,153,162,156,164,172,155,148,155,182,114,150,157,154,140,159,166,160,169,206,182,145,157,165,147,202,131,154,193,162,162,149,167,157,191,188,149,205,147,166,150,150,159,153,171,160,111,34,114,63,134,244,114,63,33,174,115,63,106,84,116,63,18,235,116,63,206,116,117,63,177,243,117,63,83,105,118,63,251,214,118,63,175,61,119,63,69,158,119,63,112,249,119,63,197,79,120,63,194,161,120,63,211,239,120,63,84,58,121,63,151,129,121,63,224,197,121,63,111,7,122,63,121,70,122,63,46,131,122,63,186,189,122,63,68,246,122,63,236,44,123,63,212,97,123,63,23,149,123,63,207,198,123,63,19,247,123,63,249,37,124,63,148,83,124,63,246,127,124,63,48,171,124,63,81,213,124,63,102,254,124,63,126,38,125,63,164,77,125,63,227,115,125,63,71,153,125,63,216,189,125,63,160,225,125,63,167,4,126,63,246,38,126,63,148,72,126,63,136,105,126,63,216,137,126,63,140,169,126,63,169,200,126,63,52,231,126,63,51,5,127,63,171,34,127,63,161,63,127,63,24,92,127,63,22,120,127,63,158,147,127,63,180,174,127,63,92,201,127,63,154,227,127,63,112,253,127,63,113,11,128,63,250,23,128,63,83,36,128,63,126,48,128,63,126,60,128,63,82,72,128,63,31,5,101,63,55,147,102,63,8,244,103,63,7,49,105,63,242,80,106,63,200,88,107,63,88,76,108,63,151,46,109,63,222,1,110,63,22,200,110,63,203,130,111,63,73,51,112,63,167,218,112,63,206,121,113,63,137,17,114,63,133,162,114,63,89,45,115,63,136,178,115,63,133,50,116,63,184,173,116,63,122,36,117,63,29,151,117,63,233,5,118,63,32,113,118,63,252,216,118,63,179,61,119,63,117,159,119,63,110,254,119,63,200,90,120,63,167,180,120,63,45,12,121,63,121,97,121,63,168,180,121,63,214,5,122,63,27,85,122,63,141,162,122,63,68,238,122,63,81,56,123,63,201,128,123,63,188,199,123,63,59,13,124,63,86,81,124,63,26,148,124,63,149,213,124,63,212,21,125,63,227,84,125,63,204,146,125,63,156,207,125,63,92,11,126,63,22,70,126,63,210,127,126,63,153,184,126,63,116,240,126,63,106,39,127,63,130,93,127,63,196,146,127,63,55,199,127,63,224,250,127,63,227,22,128,63,248,47,128,63,176,72,128,63,15,97,128,63,24,121,128,63,204,144,128,63,166,157,88,63,103,211,90,63,105,202,92,63,159,143,94,63,79,44,96,63,90,167,97,63,0,6,99,63,90,76,100,63,171,125,101,63,149,156,102,63,69,171,103,63,135,171,104,63,222,158,105,63,149,134,106,63,195,99,107,63,92,55,108,63,52,2,109,63,4,197,109,63,109,128,110,63,0,53,111,63,61,227,111,63,149,139,112,63,112,46,113,63,41,204,113,63,20,101,114,63,123,249,114,63,165,137,115,63,208,21,116,63,52,158,116,63,7,35,117,63,121,164,117,63,182,34,118,63,232,157,118,63,52,22,119,63,191,139,119,63,169,254,119,63,17,111,120,63,18,221,120,63,200,72,121,63,76,178,121,63,181,25,122,63,25,127,122,63,141,226,122,63,35,68,123,63,239,163,123,63,1,2,124,63,105,94,124,63,55,185,124,63,122,18,125,63,63,106,125,63,147,192,125,63,131,21,126,63,26,105,126,63,99,187,126,63,106,12,127,63,56,92,127,63,215,170,127,63,80,248,127,63,86,34,128,63,250,71,128,63,24,109,128,63,178,145,128,63,207,181,128,63,112,217,128,63,42,226,76,63,219,172,79,63,80,42,82,63,71,106,84,63,19,120,86,63,31,92,88,63,217,28,90,63,76,191,91,63,122,71,93,63,165,184,94,63,122,21,96,63,52,96,97,63,179,154,98,63,144,198,99,63,41,229,100,63,171,247,101,63,31,255,102,63,106,252,103,63,88,240,104,63,156,219,105,63,214,190,106,63,150,154,107,63,92,111,108,63,155,61,109,63,188,5,110,63,29,200,110,63,23,133,111,63,246,60,112,63,4,240,112,63,131,158,113,63,175,72,114,63,194,238,114,63,239,144,115,63,102,47,116,63,85,202,116,63,228,97,117,63,58,246,117,63,124,135,118,63,203,21,119,63,71,161,119,63,14,42,120,63,59,176,120,63,232,51,121,63,47,181,121,63,38,52,122,63,228,176,122,63,124,43,123,63,3,164,123,63,139,26,124,63,38,143,124,63,228,1,125,63,213,114,125,63,8,226,125,63,139,79,126,63,108,187,126,63,184,37,127,63,123,142,127,63,193,245,127,63,202,45,128,63,1,96,128,63,137,145,128,63,104,194,128,63,162,242,128,63,60,34,129,63,91,201,65,63,197,23,69,63,29,13,72,63,87,187,74,63,97,47,77,63,226,114,79,63,60,141,81,63,59,132,83,63,129,92,85,63,209,25,87,63,66,191,88,63,108,79,90,63,122,204,91,63,72,56,93,63,110,148,94,63,75,226,95,63,19,35,97,63,212,87,98,63,121,129,99,63,215,160,100,63,167,182,101,63,147,195,102,63,49,200,103,63,8,197,104,63,148,186,105,63,69,169,106,63,128,145,107,63,162,115,108,63,1,80,109,63,235,38,110,63,168,248,110,63,122,197,111,63,160,141,112,63,81,81,113,63,196,16,114,63,41,204,114,63,175,131,115,63,128,55,116,63,197,231,116,63,162,148,117,63,60,62,118,63,179,228,118,63,39,136,119,63,180,40,120,63,120,198,120,63,138,97,121,63,5,250,121,63,0,144,122,63,144,35,123,63,203,180,123,63,196,67,124,63,143,208,124,63,61,91,125,63,224,227,125,63,135,106,126,63,67,239,126,63,33,114,127,63,49,243,127,63,64,57,128,63,13,120,128,63,6,182,128,63,48,243,128,63,146,47,129,63,50,107,129,63,105,74,55,63,186,12,59,63,133,108,62,63,105,125,65,63,146,77,68,63,153,231,70,63,164,83,73,63,23,152,75,63,17,186,77,63,188,189,79,63,137,166,81,63,88,119,83,63,148,50,85,63,78,218,86,63,78,112,88,63,30,246,89,63,21,109,91,63,97,214,92,63,12,51,94,63,2,132,95,63,22,202,96,63,4,6,98,63,119,56,99,63,8,98,100,63,65,131,101,63,161,156,102,63,154,174,103,63,150,185,104,63,245,189,105,63,16,188,106,63,56,180,107,63,186,166,108,63,219,147,109,63,219,123,110,63,247,94,111,63,104,61,112,63,96,23,113,63,18,237,113,63,171,190,114,63,85,140,115,63,57,86,116,63,125,28,117,63,68,223,117,63,175,158,118,63,223,90,119,63,241,19,120,63,1,202,120,63,43,125,121,63,134,45,122,63,44,219,122,63,51,134,123,63,177,46,124,63,186,212,124,63,98,120,125,63,188,25,126,63,217,184,126,63,203,85,127,63,161,240,127,63,182,68,128,63,29,144,128,63,140,218,128,63,11,36,129,63,160,108,129,63,80,180,129,63,254,92,45,63,177,132,49,63,136,66,53,63,85,171,56,63,48,206,59,63,103,182,62,63,177,108,65,63,233,247,67,63,143,93,70,63,30,162,72,63,76,201,74,63,49,214,76,63,110,203,78,63,62,171,80,63,143,119,82,63,13,50,84,63,45,220,85,63,55,119,87,63,77,4,89,63,113,132,90,63,137,248,91,63,99,97,93,63,185,191,94,63,50,20,96,63,102,95,97,63,224,161,98,63,29,220,99,63,146,14,101,63,169,57,102,63,194,93,103,63,57,123,104,63,95,146,105,63,130,163,106,63,234,174,107,63,216,180,108,63,140,181,109,63,62,177,110,63,36,168,111,63,114,154,112,63,86,136,113,63,253,113,114,63,145,87,115,63,58,57,116,63,28,23,117,63,90,241,117,63,22,200,118,63,111,155,119,63,131,107,120,63,110,56,121,63,74,2,122,63,49,201,122,63,59,141,123,63,127,78,124,63,18,13,125,63,11,201,125,63,123,130,126,63,120,57,127,63,18,238,127,63,45,80,128,63,49,168,128,63,29,255,128,63,248,84,129,63,201,169,129,63,153,253,129,63,58,249,35,63,255,120,40,63,114,137,44,63,50,64,48,63,249,172,51,63,149,219,54,63,38,213,57,63,219,160,60,63,124,68,63,63,195,196,65,63,151,37,68,63,64,106,70,63,130,149,72,63,190,169,74,63,254,168,76,63,8,149,78,63,105,111,80,63,128,57,82,63,128,244,83,63,126,161,85,63,110,65,87,63,45,213,88,63,129,93,90,63,31,219,91,63,169,78,93,63,179,184,94,63,197,25,96,63,92,114,97,63,233,194,98,63,212,11,100,63,128,77,101,63,70,136,102,63,120,188,103,63,100,234,104,63,81,18,106,63,131,52,107,63,55,81,108,63,169,104,109,63,15,123,110,63,156,136,111,63,129,145,112,63,235,149,113,63,4,150,114,63,246,145,115,63,230,137,116,63,247,125,117,63,77,110,118,63,8,91,119,63,69,68,120,63,35,42,121,63,188,12,122,63,44,236,122,63,138,200,123,63,240,161,124,63,115,120,125,63,41,76,126,63,40,29,127,63,130,235,127,63,165,91,128,63,74,192,128,63,184,35,129,63,248,133,129,63,16,231,129,63,10,71,130,63,168,23,27,63,77,227,31,63,210,59,36,63,78,55,40,63,217,229,43,63,149,83,47,63,227,137,50,63,45,144,53,63,110,108,56,63,136,35,59,63,137,185,61,63,216,49,64,63,87,143,66,63,126,212,68,63,112,3,71,63,6,30,73,63,224,37,75,63,108,28,77,63,237,2,79,63,132,218,80,63,51,164,82,63,225,96,84,63,96,17,86,63,108,182,87,63,178,80,89,63,205,224,90,63,78,103,92,63,182,228,93,63,128,89,95,63,25,198,96,63,232,42,98,63,77,136,99,63,159,222,100,63,48,46,102,63,76,119,103,63,59,186,104,63,62,247,105,63,148,46,107,63,120,96,108,63,31,141,109,63,189,180,110,63,131,215,111,63,159,245,112,63,58,15,114,63,126,36,115,63,146,53,116,63,153,66,117,63,183,75,118,63,12,81,119,63,183,82,120,63,214,80,121,63,132,75,122,63,221,66,123,63,251,54,124,63,245,39,125,63,227,21,126,63,219,0,127,63,242,232,127,63,31,103,128,63,104,216,128,63,94,72,129,63,10,183,129,63,116,36,130,63,165,144,130,63,57,177,18,63,151,189,23,63,126,84,28,63,46,140,32,63,235,116,36,63,253,26,40,63,234,135,43,63,62,195,46,63,17,211,49,63,95,188,52,63,79,131,55,63,92,43,58,63,124,183,60,63,57,42,63,63,197,133,65,63,7,204,67,63,173,254,69,63,48,31,72,63,222,46,74,63,227,46,76,63,74,32,78,63,2,4,80,63,229,218,81,63,183,165,83,63,42,101,85,63,226,25,87,63,116,196,88,63,103,101,90,63,59,253,91,63,99,140,93,63,73,19,95,63,82,146,96,63,218,9,98,63,53,122,99,63,180,227,100,63,161,70,102,63,66,163,103,63,216,249,104,63,161,74,106,63,213,149,107,63,170,219,108,63,85,28,110,63,3,88,111,63,228,142,112,63,33,193,113,63,228,238,114,63,82,24,116,63,144,61,117,63,193,94,118,63,5,124,119,63,124,149,120,63,67,171,121,63,119,189,122,63,51,204,123,63,144,215,124,63,168,223,125,63,145,228,126,63,99,230,127,63,153,114,128,63,138,240,128,63,14,109,129,63,47,232,129,63,245,97,130,63,106,218,130,63,67,191,10,63,41,2,16,63,137,206,20,63,141,58,25,63,115,86,29,63,136,46,33,63,91,204,36,63,133,55,40,63,39,118,43,63,76,141,46,63,38,129,49,63,59,85,52,63,142,12,55,63,178,169,57,63,226,46,60,63,16,158,62,63,240,248,64,63,5,65,67,63,164,119,69,63,255,157,71,63,40,181,73,63,20,190,75,63,163,185,77,63,158,168,79,63,189,139,81,63,166,99,83,63,245,48,85,63,53,244,86,63,232,173,88,63,134,94,90,63,125,6,92,63,53,166,93,63,12,62,95,63,90,206,96,63,115,87,98,63,164,217,99,63,52,85,101,63,104,202,102,63,127,57,104,63,181,162,105,63,65,6,107,63,89,100,108,63,46,189,109,63,240,16,111,63,204,95,112,63,235,169,113,63,118,239,114,63,146,48,116,63,99,109,117,63,13,166,118,63,175,218,119,63,105,11,121,63,88,56,122,63,152,97,123,63,69,135,124,63,120,169,125,63,74,200,126,63,211,227,127,63,20,126,128,63,176,8,129,63,200,145,129,63,102,25,130,63,147,159,130,63,88,36,131,63,119,59,3,63,152,171,8,63,68,165,13,63,85,62,18,63,222,134,22,63,19,139,26,63,115,84,30,63,143,234,33,63,134,83,37,63,99,148,40,63,89,177,43,63,242,173,46,63,52,141,49,63,181,81,52,63,182,253,54,63,44,147,57,63,209,19,60,63,42,129,62,63,146,220,64,63,63,39,67,63,69,98,69,63,160,142,71,63,48,173,73,63,196,190,75,63,22,196,77,63,208,189,79,63,144,172,81,63,230,144,83,63,84,107,85,63,87,60,87,63,94,4,89,63,212,195,90,63,24,123,92,63,135,42,94,63,117,210,95,63,49,115,97,63,5,13,99,63,56,160,100,63,9,45,102,63,182,179,103,63,122,52,105,63,138,175,106,63,26,37,108,63,91,149,109,63,123,0,111,63,165,102,112,63,2,200,113,63,186,36,115,63,242,124,116,63,206,208,117,63,111,32,119,63,245,107,120,63,127,179,121,63,43,247,122,63,20,55,124,63,85,115,125,63,7,172,126,63,67,225,127,63,145,137,128,63,220,32,129,63,141,182,129,63,176,74,130,63,78,221,130,63,112,110,131,63,182,108,216,178,102,198,150,54,54,0,0,0,0,0,0,0,255,127,127,255,0,0,0,0,255,255,255,255,0,0,0,0,235,128,128,255,0,0,0,0,208,133,30,0,96,245,29,0,160,135,29,0,184,44,29,0,168,220,28,0,240,215,35,0,8,137,35,0,184,41,35,0,200,227,34,0,72,165,34,0,88,105,34,0,48,49,34,0,8,2,34,0,240,211,33,0,144,175,33,0,64,143,33,0,48,73,35,0,108,0,0,0,208,57,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,199,33,0,108,0,0,0,176,80,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,245,29,0,108,0,0,0,0,112,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,0,0,0,61,1,0,0,4,0,0,0,0,0,0,0,5,0,0,0,33,0,0,0,7,0,0,0,6,0,0,0,34,0,0,0,64,1,0,0,12,0,0,0,13,0,0,0,14,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,8,0,0,0,255,255,255,255,88,118,32,0,108,0,0,0,240,58,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,78,29,0,48,252,28,0,0,173,28,0,160,170,35,0,72,74,35,0,40,251,34,0,8,188,34,0,48,126,34,0,0,0,0,0,0,0,0,0,160,114,31,0,108,0,0,0,16,21,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,1,0,0,239,0,0,0,239,0,0,0,213,0,0,0,0,0,0,0,224,0,0,0,224,0,0,0,152,0,0,0,0,0,0,0,135,0,0,0,135,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,1,0,0,54,1,0,0,54,1,0,0,24,1,0,0,0,0,0,0,64,1,0,0,64,1,0,0,228,0,0,0,0,0,0,0,175,0,0,0,175,0,0,0,136,0,0,0,0,0,0,0,129,0,0,0,129,0,0,0,102,0,0,0,19,1,0,0,245,0,0,0,245,0,0,0,218,0,0,0,0,0,0,0,230,0,0,0,230,0,0,0,156,0,0,0,0,0,0,0,138,0,0,0,138,0,0,0,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,1,0,0,61,1,0,0,61,1,0,0,30,1,0,0,0,0,0,0,72,1,0,0,72,1,0,0,233,0,0,0,0,0,0,0,180,0,0,0,180,0,0,0,140,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,105,0,0,0,160,28,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,10,0,0,56,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,253,32,0,112,232,31,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,24,253,32,0,112,25,31,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,24,253,32,0,224,107,30,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,24,253,32,0,72,227,29,0,200,118,29,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,72,227,29,0,168,31,29,0,88,206,28,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,227,29,0,248,202,35,0,168,118,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,227,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,28,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,146,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,206,31,0,108,0,0,0,16,229,0,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,63,120,51,98,136,11,53,151,200,193,53,80,233,61,54,183,247,156,54,46,124,234,54,153,192,35,55,244,2,90,55,56,3,140,55,227,228,174,55,177,166,213,55,108,36,0,56,146,101,23,56,201,150,48,56,18,184,75,56,81,201,104,56,94,229,131,56,29,94,148,56,229,206,165,56,167,55,184,56,128,152,203,56,85,241,223,56,36,66,245,56,126,197,5,57,238,101,17,57,99,130,29,57,207,26,42,57,63,47,55,57,179,191,68,57,30,204,82,57,141,84,97,57,243,88,112,57,94,217,127,57,227,234,135,57,18,39,144,57,64,161,152,57,105,89,161,57,146,79,170,57,181,131,179,57,215,245,188,57,245,165,198,57,14,148,208,57,34,192,218,57,46,42,229,57,57,210,239,57,60,184,250,57,27,238,2,58,22,159,8,58,13,111,14,58,0,94,20,58,239,107,26,58,218,152,32,58,192,228,38,58,161,79,45,58,124,217,51,58,83,130,58,58,37,74,65,58,240,48,72,58,182,54,79,58,116,91,86,58,45,159,93,58,222,1,101,58,136,131,108,58,42,36,116,58,196,227,123,58,44,225,129,58,241,223,133,58,49,238,137,58,238,11,142,58,37,57,146,58,215,117,150,58,5,194,154,58,174,29,159,58,209,136,163,58,110,3,168,58,134,141,172,58,24,39,177,58,36,208,181,58,169,136,186,58,169,80,191,58,33,40,196,58,19,15,201,58,126,5,206,58,98,11,211,58,191,32,216,58,148,69,221,58,225,121,226,58,166,189,231,58,227,16,237,58,152,115,242,58,196,229,247,58,103,103,253,58,65,124,1,59,137,76,4,59,141,36,7,59,76,4,10,59,198,235,12,59,251,218,15,59,235,209,18,59,149,208,21,59,251,214,24,59,26,229,27,59,244,250,30,59,136,24,34,59,215,61,37,59,223,106,40,59,161,159,43,59,29,220,46,59,83,32,50,59,66,108,53,59,234,191,56,59,76,27,60,59,103,126,63,59,59,233,66,59,199,91,70,59,12,214,73,59,10,88,77,59,193,225,80,59,48,115,84,59,86,12,88,59,53,173,91,59,204,85,95,59,26,6,99,59,32,190,102,59,222,125,106,59,82,69,110,59,127,20,114,59,97,235,117,59,251,201,121,59,76,176,125,59,41,207,128,59,8,202,130,59,194,200,132,59,87,203,134,59,198,209,136,59,17,220,138,59,55,234,140,59,55,252,142,59,18,18,145,59,199,43,147,59,87,73,149,59,194,106,151,59,6,144,153,59,37,185,155,59,30,230,157,59,241,22,160,59,158,75,162,59,37,132,164,59,134,192,166,59,192,0,169,59,212,68,171,59,193,140,173,59,137,216,175,59,41,40,178,59,163,123,180,59,245,210,182,59,33,46,185,59,38,141,187,59,4,240,189,59,186,86,192,59,73,193,194,59,177,47,197,59,242,161,199,59,10,24,202,59,251,145,204,59,196,15,207,59,102,145,209,59,223,22,212,59,49,160,214,59,90,45,217,59,91,190,219,59,51,83,222,59,227,235,224,59,107,136,227,59,201,40,230,59,255,204,232,59,12,117,235,59,240,32,238,59,171,208,240,59,61,132,243,59,165,59,246,59,228,246,248,59,250,181,251,59,229,120,254,59,212,159,0,60,32,5,2,60,87,108,3,60,121,213,4,60,134,64,6,60,126,173,7,60,96,28,9,60,45,141,10,60,229,255,11,60,136,116,13,60,21,235,14,60,141,99,16,60,239,221,17,60,59,90,19,60,114,216,20,60,147,88,22,60,158,218,23,60,147,94,25,60,115,228,26,60,60,108,28,60,240,245,29,60,141,129,31,60,20,15,33,60,133,158,34,60,224,47,36,60,36,195,37,60,82,88,39,60,105,239,40,60,106,136,42,60,84,35,44,60,40,192,45,60,229,94,47,60,139,255,48,60,26,162,50,60,146,70,52,60,243,236,53,60,61,149,55,60,112,63,57,60,140,235,58,60,145,153,60,60,126,73,62,60,84,251,63,60,18,175,65,60,185,100,67,60,72,28,69,60,192,213,70,60,31,145,72,60,103,78,74,60,151,13,76,60,175,206,77,60,176,145,79,60,152,86,81,60,103,29,83,60,31,230,84,60,190,176,86,60,69,125,88,60,179,75,90,60,9,28,92,60,71,238,93,60,107,194,95,60,119,152,97,60,106,112,99,60,68,74,101,60,5,38,103,60,173,3,105,60,60,227,106,60,178,196,108,60,14,168,110,60,81,141,112,60,123,116,114,60,139,93,116,60,130,72,118,60,95,53,120,60,34,36,122,60,203,20,124,60,90,7,126,60,208,251,127,60,22,249,128,60,54,245,129,60,74,242,130,60,80,240,131,60,73,239,132,60,53,239,133,60,19,240,134,60,229,241,135,60,169,244,136,60,95,248,137,60,8,253,138,60,164,2,140,60,50,9,141,60,178,16,142,60,37,25,143,60,139,34,144,60,226,44,145,60,44,56,146,60,104,68,147,60,150,81,148,60,182,95,149,60,201,110,150,60,205,126,151,60,196,143,152,60,172,161,153,60,135,180,154,60,83,200,155,60,17,221,156,60,193,242,157,60,98,9,159,60,245,32,160,60,122,57,161,60,241,82,162,60,89,109,163,60,178,136,164,60,253,164,165,60,57,194,166,60,103,224,167,60,134,255,168,60,151,31,170,60,152,64,171,60,139,98,172,60,111,133,173,60,68,169,174,60,10,206,175,60,193,243,176,60,105,26,178,60,2,66,179,60,139,106,180,60,6,148,181,60,113,190,182,60,205,233,183,60,26,22,185,60,87,67,186,60,133,113,187,60,163,160,188,60,177,208,189,60,177,1,191,60,160,51,192,60,128,102,193,60,80,154,194,60,16,207,195,60,193,4,197,60,97,59,198,60,242,114,199,60,114,171,200,60,227,228,201,60,67,31,203,60,147,90,204,60,211,150,205,60,3,212,206,60,34,18,208,60,49,81,209,60,48,145,210,60,30,210,211,60,252,19,213,60,201,86,214,60,133,154,215,60,49,223,216,60,204,36,218,60,86,107,219,60,208,178,220,60,56,251,221,60,144,68,223,60,214,142,224,60,12,218,225,60,48,38,227,60,67,115,228,60,69,193,229,60,54,16,231,60,21,96,232,60,227,176,233,60,160,2,235,60,75,85,236,60,228,168,237,60,108,253,238,60,226,82,240,60,70,169,241,60,153,0,243,60,218,88,244,60,8,178,245,60,37,12,247,60,48,103,248,60,41,195,249,60,15,32,251,60,228,125,252,60,166,220,253,60,85,60,255,60,121,78,0,61,63,255,0,61,123,176,1,61,46,98,2,61,88,20,3,61,248,198,3,61,15,122,4,61,156,45,5,61,161,225,5,61,27,150,6,61,12,75,7,61,116,0,8,61,82,182,8,61,167,108,9,61,113,35,10,61,179,218,10,61,106,146,11,61,152,74,12,61,60,3,13,61,87,188,13,61,231,117,14,61,238,47,15,61,107,234,15,61,94,165,16,61,199,96,17,61,166,28,18,61,251,216,18,61,198,149,19,61,7,83,20,61,190,16,21,61,234,206,21,61,141,141,22,61,165,76,23,61,52,12,24,61,56,204,24,61,177,140,25,61,161,77,26,61,6,15,27,61,224,208,27,61,48,147,28,61,246,85,29,61,49,25,30,61,226,220,30,61,8,161,31,61,164,101,32,61,181,42,33,61,59,240,33,61,55,182,34,61,168,124,35,61,142,67,36,61,233,10,37,61,186,210,37,61,255,154,38,61,186,99,39,61,234,44,40,61,143,246,40,61,168,192,41,61,55,139,42,61,59,86,43,61,180,33,44,61,161,237,44,61,4,186,45,61,219,134,46,61,38,84,47,61,231,33,48,61,28,240,48,61,198,190,49,61,229,141,50,61,120,93,51,61,127,45,52,61,251,253,52,61,236,206,53,61,81,160,54,61,42,114,55,61,120,68,56,61,58,23,57,61,112,234,57,61,27,190,58,61,58,146,59,61,204,102,60,61,211,59,61,61,79,17,62,61,62,231,62,61,161,189,63,61,120,148,64,61,195,107,65,61,130,67,66,61,181,27,67,61,92,244,67,61,118,205,68,61,4,167,69,61,6,129,70,61,124,91,71,61,101,54,72,61,194,17,73,61,146,237,73,61,214,201,74,61,141,166,75,61,184,131,76,61,86,97,77,61,104,63,78,61,236,29,79,61,229,252,79,61,80,220,80,61,46,188,81,61,128,156,82,61,69,125,83,61,125,94,84,61,40,64,85,61,69,34,86,61,214,4,87,61,218,231,87,61,81,203,88,61,58,175,89,61,150,147,90,61,101,120,91,61,167,93,92,61,91,67,93,61,130,41,94,61,28,16,95,61,40,247,95,61,167,222,96,61,152,198,97,61,251,174,98,61,209,151,99,61,25,129,100,61,212,106,101,61,0,85,102,61,159,63,103,61,176,42,104,61,51,22,105,61,41,2,106,61,144,238,106,61,105,219,107,61,180,200,108,61,113,182,109,61,160,164,110,61,65,147,111,61,84,130,112,61,216,113,113,61,206,97,114,61,54,82,115,61,15,67,116,61,89,52,117,61,22,38,118,61,67,24,119,61,226,10,120,61,243,253,120,61,117,241,121,61,104,229,122,61,204,217,123,61,162,206,124,61,232,195,125,61,160,185,126,61,201,175,127,61,49,83,128,61,183,206,128,61,117,74,129,61,107,198,129,61,154,66,130,61,1,191,130,61,160,59,131,61,120,184,131,61,136,53,132,61,209,178,132,61,81,48,133,61,10,174,133,61,251,43,134,61,37,170,134,61,134,40,135,61,32,167,135,61,242,37,136,61,252,164,136,61,62,36,137,61,184,163,137,61,106,35,138,61,84,163,138,61,118,35,139,61,209,163,139,61,99,36,140,61,45,165,140,61,46,38,141,61,104,167,141,61,218,40,142,61,131,170,142,61,100,44,143,61,125,174,143,61,206,48,144,61,86,179,144,61,23,54,145,61,14,185,145,61,62,60,146,61,165,191,146,61,67,67,147,61,26,199,147,61,39,75,148,61,109,207,148,61,234,83,149,61,158,216,149,61,138,93,150,61,173,226,150,61,7,104,151,61,153,237,151,61,98,115,152,61,99,249,152,61,155,127,153,61,10,6,154,61], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+51200);
/* memory initializer */ allocate([176,140,154,61,142,19,155,61,163,154,155,61,239,33,156,61,114,169,156,61,44,49,157,61,29,185,157,61,69,65,158,61,165,201,158,61,59,82,159,61,8,219,159,61,13,100,160,61,72,237,160,61,186,118,161,61,99,0,162,61,67,138,162,61,90,20,163,61,167,158,163,61,43,41,164,61,230,179,164,61,216,62,165,61,0,202,165,61,95,85,166,61,245,224,166,61,193,108,167,61,196,248,167,61,254,132,168,61,110,17,169,61,20,158,169,61,241,42,170,61,4,184,170,61,78,69,171,61,206,210,171,61,133,96,172,61,113,238,172,61,149,124,173,61,238,10,174,61,126,153,174,61,67,40,175,61,63,183,175,61,114,70,176,61,218,213,176,61,120,101,177,61,77,245,177,61,88,133,178,61,152,21,179,61,15,166,179,61,187,54,180,61,158,199,180,61,182,88,181,61,4,234,181,61,137,123,182,61,67,13,183,61,50,159,183,61,88,49,184,61,179,195,184,61,68,86,185,61,11,233,185,61,7,124,186,61,57,15,187,61,160,162,187,61,61,54,188,61,16,202,188,61,24,94,189,61,85,242,189,61,200,134,190,61,112,27,191,61,78,176,191,61,97,69,192,61,170,218,192,61,39,112,193,61,218,5,194,61,194,155,194,61,224,49,195,61,50,200,195,61,186,94,196,61,119,245,196,61,104,140,197,61,143,35,198,61,235,186,198,61,124,82,199,61,66,234,199,61,61,130,200,61,108,26,201,61,209,178,201,61,106,75,202,61,57,228,202,61,59,125,203,61,115,22,204,61,224,175,204,61,129,73,205,61,86,227,205,61,97,125,206,61,159,23,207,61,19,178,207,61,187,76,208,61,151,231,208,61,168,130,209,61,237,29,210,61,103,185,210,61,21,85,211,61,248,240,211,61,14,141,212,61,89,41,213,61,216,197,213,61,140,98,214,61,115,255,214,61,143,156,215,61,223,57,216,61,99,215,216,61,27,117,217,61,7,19,218,61,38,177,218,61,122,79,219,61,2,238,219,61,189,140,220,61,173,43,221,61,208,202,221,61,39,106,222,61,178,9,223,61,112,169,223,61,98,73,224,61,136,233,224,61,226,137,225,61,111,42,226,61,47,203,226,61,35,108,227,61,74,13,228,61,165,174,228,61,52,80,229,61,245,241,229,61,234,147,230,61,19,54,231,61,110,216,231,61,253,122,232,61,191,29,233,61,180,192,233,61,221,99,234,61,56,7,235,61,199,170,235,61,136,78,236,61,125,242,236,61,164,150,237,61,255,58,238,61,140,223,238,61,76,132,239,61,63,41,240,61,101,206,240,61,189,115,241,61,73,25,242,61,7,191,242,61,247,100,243,61,26,11,244,61,112,177,244,61,248,87,245,61,179,254,245,61,160,165,246,61,192,76,247,61,18,244,247,61,151,155,248,61,77,67,249,61,55,235,249,61,82,147,250,61,159,59,251,61,31,228,251,61,209,140,252,61,181,53,253,61,203,222,253,61,19,136,254,61,141,49,255,61,57,219,255,61,140,66,0,62,148,151,0,62,181,236,0,62,238,65,1,62,65,151,1,62,173,236,1,62,49,66,2,62,206,151,2,62,132,237,2,62,83,67,3,62,59,153,3,62,59,239,3,62,84,69,4,62,134,155,4,62,209,241,4,62,52,72,5,62,176,158,5,62,68,245,5,62,242,75,6,62,183,162,6,62,150,249,6,62,141,80,7,62,156,167,7,62,196,254,7,62,5,86,8,62,94,173,8,62,207,4,9,62,89,92,9,62,252,179,9,62,183,11,10,62,138,99,10,62,118,187,10,62,122,19,11,62,150,107,11,62,203,195,11,62,24,28,12,62,125,116,12,62,250,204,12,62,144,37,13,62,62,126,13,62,4,215,13,62,227,47,14,62,217,136,14,62,232,225,14,62,15,59,15,62,78,148,15,62,165,237,15,62,20,71,16,62,155,160,16,62,58,250,16,62,241,83,17,62,193,173,17,62,168,7,18,62,167,97,18,62,190,187,18,62,237,21,19,62,51,112,19,62,146,202,19,62,9,37,20,62,151,127,20,62,61,218,20,62,251,52,21,62,209,143,21,62,190,234,21,62,195,69,22,62,224,160,22,62,21,252,22,62,97,87,23,62,197,178,23,62,64,14,24,62,211,105,24,62,126,197,24,62,64,33,25,62,26,125,25,62,11,217,25,62,20,53,26,62,52,145,26,62,108,237,26,62,187,73,27,62,34,166,27,62,160,2,28,62,53,95,28,62,226,187,28,62,166,24,29,62,129,117,29,62,116,210,29,62,126,47,30,62,159,140,30,62,215,233,30,62,39,71,31,62,141,164,31,62,11,2,32,62,160,95,32,62,76,189,32,62,16,27,33,62,234,120,33,62,219,214,33,62,228,52,34,62,3,147,34,62,58,241,34,62,135,79,35,62,235,173,35,62,103,12,36,62,249,106,36,62,162,201,36,62,98,40,37,62,56,135,37,62,38,230,37,62,42,69,38,62,69,164,38,62,119,3,39,62,192,98,39,62,31,194,39,62,149,33,40,62,33,129,40,62,197,224,40,62,126,64,41,62,79,160,41,62,54,0,42,62,51,96,42,62,72,192,42,62,114,32,43,62,179,128,43,62,11,225,43,62,121,65,44,62,253,161,44,62,152,2,45,62,73,99,45,62,16,196,45,62,238,36,46,62,226,133,46,62,237,230,46,62,13,72,47,62,68,169,47,62,145,10,48,62,245,107,48,62,110,205,48,62,254,46,49,62,163,144,49,62,95,242,49,62,49,84,50,62,25,182,50,62,23,24,51,62,43,122,51,62,85,220,51,62,148,62,52,62,234,160,52,62,86,3,53,62,216,101,53,62,111,200,53,62,28,43,54,62,223,141,54,62,184,240,54,62,167,83,55,62,171,182,55,62,197,25,56,62,245,124,56,62,59,224,56,62,150,67,57,62,7,167,57,62,141,10,58,62,41,110,58,62,219,209,58,62,162,53,59,62,126,153,59,62,112,253,59,62,120,97,60,62,149,197,60,62,199,41,61,62,15,142,61,62,108,242,61,62,222,86,62,62,102,187,62,62,3,32,63,62,181,132,63,62,125,233,63,62,90,78,64,62,75,179,64,62,83,24,65,62,111,125,65,62,160,226,65,62,231,71,66,62,66,173,66,62,179,18,67,62,57,120,67,62,211,221,67,62,131,67,68,62,71,169,68,62,33,15,69,62,15,117,69,62,18,219,69,62,42,65,70,62,87,167,70,62,153,13,71,62,240,115,71,62,91,218,71,62,219,64,72,62,111,167,72,62,25,14,73,62,215,116,73,62,169,219,73,62,144,66,74,62,140,169,74,62,157,16,75,62,193,119,75,62,251,222,75,62,73,70,76,62,171,173,76,62,34,21,77,62,173,124,77,62,76,228,77,62,0,76,78,62,200,179,78,62,164,27,79,62,149,131,79,62,154,235,79,62,179,83,80,62,225,187,80,62,34,36,81,62,120,140,81,62,225,244,81,62,95,93,82,62,241,197,82,62,151,46,83,62,81,151,83,62,31,0,84,62,1,105,84,62,247,209,84,62,0,59,85,62,30,164,85,62,79,13,86,62,149,118,86,62,238,223,86,62,91,73,87,62,219,178,87,62,112,28,88,62,24,134,88,62,211,239,88,62,163,89,89,62,134,195,89,62,124,45,90,62,134,151,90,62,164,1,91,62,213,107,91,62,26,214,91,62,114,64,92,62,221,170,92,62,92,21,93,62,239,127,93,62,148,234,93,62,77,85,94,62,26,192,94,62,249,42,95,62,236,149,95,62,242,0,96,62,11,108,96,62,55,215,96,62,119,66,97,62,202,173,97,62,47,25,98,62,168,132,98,62,52,240,98,62,210,91,99,62,132,199,99,62,73,51,100,62,32,159,100,62,11,11,101,62,8,119,101,62,24,227,101,62,59,79,102,62,113,187,102,62,186,39,103,62,21,148,103,62,131,0,104,62,3,109,104,62,151,217,104,62,60,70,105,62,245,178,105,62,192,31,106,62,157,140,106,62,141,249,106,62,144,102,107,62,165,211,107,62,204,64,108,62,6,174,108,62,82,27,109,62,176,136,109,62,33,246,109,62,164,99,110,62,57,209,110,62,225,62,111,62,154,172,111,62,102,26,112,62,68,136,112,62,52,246,112,62,55,100,113,62,75,210,113,62,113,64,114,62,169,174,114,62,243,28,115,62,80,139,115,62,190,249,115,62,61,104,116,62,207,214,116,62,115,69,117,62,40,180,117,62,239,34,118,62,200,145,118,62,179,0,119,62,175,111,119,62,189,222,119,62,221,77,120,62,14,189,120,62,80,44,121,62,165,155,121,62,10,11,122,62,130,122,122,62,10,234,122,62,164,89,123,62,80,201,123,62,13,57,124,62,219,168,124,62,186,24,125,62,171,136,125,62,173,248,125,62,192,104,126,62,228,216,126,62,26,73,127,62,96,185,127,62,220,20,128,62,16,77,128,62,77,133,128,62,147,189,128,62,225,245,128,62,55,46,129,62,150,102,129,62,253,158,129,62,109,215,129,62,229,15,130,62,102,72,130,62,238,128,130,62,128,185,130,62,25,242,130,62,187,42,131,62,102,99,131,62,24,156,131,62,211,212,131,62,150,13,132,62,98,70,132,62,53,127,132,62,17,184,132,62,245,240,132,62,226,41,133,62,214,98,133,62,211,155,133,62,216,212,133,62,229,13,134,62,250,70,134,62,23,128,134,62,61,185,134,62,106,242,134,62,160,43,135,62,221,100,135,62,35,158,135,62,112,215,135,62,198,16,136,62,35,74,136,62,137,131,136,62,247,188,136,62,108,246,136,62,233,47,137,62,111,105,137,62,252,162,137,62,145,220,137,62,46,22,138,62,211,79,138,62,127,137,138,62,52,195,138,62,240,252,138,62,180,54,139,62,128,112,139,62,84,170,139,62,47,228,139,62,18,30,140,62,253,87,140,62,239,145,140,62,233,203,140,62,235,5,141,62,245,63,141,62,6,122,141,62,31,180,141,62,63,238,141,62,103,40,142,62,150,98,142,62,205,156,142,62,12,215,142,62,82,17,143,62,159,75,143,62,245,133,143,62,81,192,143,62,181,250,143,62,33,53,144,62,147,111,144,62,14,170,144,62,143,228,144,62,25,31,145,62,169,89,145,62,65,148,145,62,224,206,145,62,134,9,146,62,52,68,146,62,233,126,146,62,165,185,146,62,105,244,146,62,52,47,147,62,6,106,147,62,223,164,147,62,191,223,147,62,167,26,148,62,150,85,148,62,139,144,148,62,136,203,148,62,140,6,149,62,152,65,149,62,170,124,149,62,195,183,149,62,227,242,149,62,11,46,150,62,57,105,150,62,111,164,150,62,171,223,150,62,238,26,151,62,56,86,151,62,138,145,151,62,226,204,151,62,65,8,152,62,167,67,152,62,19,127,152,62,135,186,152,62,1,246,152,62,130,49,153,62,10,109,153,62,153,168,153,62,47,228,153,62,203,31,154,62,110,91,154,62,24,151,154,62,200,210,154,62,127,14,155,62,61,74,155,62,2,134,155,62,205,193,155,62,158,253,155,62,119,57,156,62,85,117,156,62,59,177,156,62,39,237,156,62,25,41,157,62,18,101,157,62,18,161,157,62,24,221,157,62,36,25,158,62,55,85,158,62,80,145,158,62,112,205,158,62,150,9,159,62,195,69,159,62,246,129,159,62,47,190,159,62,111,250,159,62,180,54,160,62,1,115,160,62,83,175,160,62,172,235,160,62,11,40,161,62,112,100,161,62,219,160,161,62,77,221,161,62,196,25,162,62,66,86,162,62,198,146,162,62,81,207,162,62,225,11,163,62,119,72,163,62,20,133,163,62,182,193,163,62,95,254,163,62,13,59,164,62,194,119,164,62,125,180,164,62,61,241,164,62,4,46,165,62,208,106,165,62,162,167,165,62,123,228,165,62,89,33,166,62,61,94,166,62,39,155,166,62,23,216,166,62,12,21,167,62,7,82,167,62,8,143,167,62,15,204,167,62,28,9,168,62,46,70,168,62,70,131,168,62,100,192,168,62,136,253,168,62,177,58,169,62,223,119,169,62,20,181,169,62,78,242,169,62,141,47,170,62,211,108,170,62,29,170,170,62,109,231,170,62,195,36,171,62,31,98,171,62,127,159,171,62,230,220,171,62,81,26,172,62,194,87,172,62,57,149,172,62,181,210,172,62,54,16,173,62,189,77,173,62,73,139,173,62,218,200,173,62,113,6,174,62,13,68,174,62,174,129,174,62,85,191,174,62,0,253,174,62,177,58,175,62,103,120,175,62,35,182,175,62,227,243,175,62,169,49,176,62,116,111,176,62,68,173,176,62,25,235,176,62,243,40,177,62,210,102,177,62,182,164,177,62,160,226,177,62,142,32,178,62,129,94,178,62,121,156,178,62,119,218,178,62,121,24,179,62,128,86,179,62,140,148,179,62,157,210,179,62,178,16,180,62,205,78,180,62,236,140,180,62,16,203,180,62,57,9,181,62,103,71,181,62,154,133,181,62,209,195,181,62,13,2,182,62,78,64,182,62,147,126,182,62,221,188,182,62,44,251,182,62,127,57,183,62,215,119,183,62,52,182,183,62,149,244,183,62,251,50,184,62,101,113,184,62,212,175,184,62,71,238,184,62,191,44,185,62,59,107,185,62,188,169,185,62,65,232,185,62,202,38,186,62,88,101,186,62,235,163,186,62,129,226,186,62,28,33,187,62,188,95,187,62,95,158,187,62,7,221,187,62,180,27,188,62,100,90,188,62,25,153,188,62,210,215,188,62,143,22,189,62,80,85,189,62,22,148,189,62,223,210,189,62,173,17,190,62,127,80,190,62,85,143,190,62,47,206,190,62,13,13,191,62,239,75,191,62,213,138,191,62,191,201,191,62,173,8,192,62,159,71,192,62,149,134,192,62,143,197,192,62,141,4,193,62,143,67,193,62,148,130,193,62,158,193,193,62,171,0,194,62,188,63,194,62,209,126,194,62,234,189,194,62,6,253,194,62,38,60,195,62,74,123,195,62,113,186,195,62,157,249,195,62,204,56,196,62,254,119,196,62,52,183,196,62,110,246,196,62,171,53,197,62,236,116,197,62,49,180,197,62,121,243,197,62,196,50,198,62,19,114,198,62,102,177,198,62,188,240,198,62,21,48,199,62,114,111,199,62,210,174,199,62,54,238,199,62,157,45,200,62,7,109,200,62,117,172,200,62,230,235,200,62,90,43,201,62,209,106,201,62,76,170,201,62,202,233,201,62,75,41,202,62,208,104,202,62,88,168,202,62,226,231,202,62,112,39,203,62,1,103,203,62,149,166,203,62,45,230,203,62,199,37,204,62,100,101,204,62,4,165,204,62,168,228,204,62,78,36,205,62,248,99,205,62,164,163,205,62,83,227,205,62,5,35,206,62,186,98,206,62,114,162,206,62,45,226,206,62,234,33,207,62,171,97,207,62,110,161,207,62,52,225,207,62,253,32,208,62,200,96,208,62,150,160,208,62,103,224,208,62,59,32,209,62,17,96,209,62,234,159,209,62,198,223,209,62,164,31,210,62,133,95,210,62,104,159,210,62,78,223,210,62,55,31,211,62,33,95,211,62,15,159,211,62,255,222,211,62,241,30,212,62,230,94,212,62,221,158,212,62,215,222,212,62,211,30,213,62,209,94,213,62,210,158,213,62,213,222,213,62,219,30,214,62,226,94,214,62,236,158,214,62,248,222,214,62,7,31,215,62,24,95,215,62,42,159,215,62,63,223,215,62,87,31,216,62,112,95,216,62,139,159,216,62,169,223,216,62,200,31,217,62,234,95,217,62,14,160,217,62,51,224,217,62,91,32,218,62,133,96,218,62,176,160,218,62,222,224,218,62,13,33,219,62,63,97,219,62,114,161,219,62,167,225,219,62,222,33,220,62,23,98,220,62,82,162,220,62,142,226,220,62,204,34,221,62,12,99,221,62,78,163,221,62,146,227,221,62,215,35,222,62,29,100,222,62,102,164,222,62,176,228,222,62,252,36,223,62,73,101,223,62,152,165,223,62,232,229,223,62,58,38,224,62,142,102,224,62,227,166,224,62,57,231,224,62,145,39,225,62,234,103,225,62,69,168,225,62,161,232,225,62,255,40,226,62,94,105,226,62,190,169,226,62,32,234,226,62,131,42,227,62,231,106,227,62,76,171,227,62,179,235,227,62,27,44,228,62,132,108,228,62,238,172,228,62,90,237,228,62,199,45,229,62,52,110,229,62,163,174,229,62,19,239,229,62,133,47,230,62,247,111,230,62,106,176,230,62,222,240,230,62,83,49,231,62,202,113,231,62,65,178,231,62,185,242,231,62,50,51,232,62,172,115,232,62,38,180,232,62,162,244,232,62,31,53,233,62,156,117,233,62,26,182,233,62,153,246,233,62,25,55,234,62,153,119,234,62,26,184,234,62,156,248,234,62,31,57,235,62,162,121,235,62,38,186,235,62,170,250,235,62,47,59,236,62,181,123,236,62,59,188,236,62,194,252,236,62,73,61,237,62,209,125,237,62,89,190,237,62,226,254,237,62,107,63,238,62,245,127,238,62,127,192,238,62,10,1,239,62,149,65,239,62,32,130,239,62,171,194,239,62,55,3,240,62,196,67,240,62,80,132,240,62,221,196,240,62,106,5,241,62,247,69,241,62,132,134,241,62,18,199,241,62,160,7,242,62,45,72,242,62,187,136,242,62,74,201,242,62,216,9,243,62,102,74,243,62,244,138,243,62,131,203,243,62,17,12,244,62,159,76,244,62,46,141,244,62,188,205,244,62,74,14,245,62,216,78,245,62,102,143,245,62,244,207,245,62,129,16,246,62,15,81,246,62,156,145,246,62,41,210,246,62,182,18,247,62,67,83,247,62,207,147,247,62,91,212,247,62,231,20,248,62,115,85,248,62,254,149,248,62,136,214,248,62,19,23,249,62,157,87,249,62,38,152,249,62,175,216,249,62,56,25,250,62,192,89,250,62,72,154,250,62,207,218,250,62,86,27,251,62,220,91,251,62,97,156,251,62,230,220,251,62,106,29,252,62,238,93,252,62,113,158,252,62,243,222,252,62,117,31,253,62,245,95,253,62,118,160,253,62,245,224,253,62,116,33,254,62,241,97,254,62,110,162,254,62,235,226,254,62,102,35,255,62,224,99,255,62,90,164,255,62,211,228,255,62,165,18,0,63,225,50,0,63,27,83,0,63,86,115,0,63,144,147,0,63,201,179,0,63,2,212,0,63,58,244,0,63,114,20,1,63,169,52,1,63,224,84,1,63,22,117,1,63,76,149,1,63,129,181,1,63,181,213,1,63,233,245,1,63,28,22,2,63,78,54,2,63,128,86,2,63,178,118,2,63,226,150,2,63,18,183,2,63,65,215,2,63,112,247,2,63,157,23,3,63,203,55,3,63,247,87,3,63,35,120,3,63,78,152,3,63,120,184,3,63,161,216,3,63,202,248,3,63,242,24,4,63,25,57,4,63,63,89,4,63,101,121,4,63,137,153,4,63,173,185,4,63,208,217,4,63,243,249,4,63,20,26,5,63,52,58,5,63,84,90,5,63,115,122,5,63,145,154,5,63,173,186,5,63,202,218,5,63,229,250,5,63,255,26,6,63,24,59,6,63,48,91,6,63,72,123,6,63,94,155,6,63,116,187,6,63,136,219,6,63,155,251,6,63,174,27,7,63,191,59,7,63,208,91,7,63,223,123,7,63,237,155,7,63,250,187,7,63,7,220,7,63,18,252,7,63,28,28,8,63,37,60,8,63,44,92,8,63,51,124,8,63,57,156,8,63,61,188,8,63,64,220,8,63,67,252,8,63,68,28,9,63,68,60,9,63,66,92,9,63,64,124,9,63,60,156,9,63,55,188,9,63,49,220,9,63,41,252,9,63,33,28,10,63,23,60,10,63,12,92,10,63,255,123,10,63,242,155,10,63,227,187,10,63,211,219,10,63,193,251,10,63,174,27,11,63,154,59,11,63,133,91,11,63,110,123,11,63,86,155,11,63,60,187,11,63,33,219,11,63,5,251,11,63,231,26,12,63,200,58,12,63,168,90,12,63,134,122,12,63,98,154,12,63,62,186,12,63,23,218,12,63,240,249,12,63,199,25,13,63,156,57,13,63,112,89,13,63,66,121,13,63,19,153,13,63,227,184,13,63,176,216,13,63,125,248,13,63,72,24,14,63,17,56,14,63,216,87,14,63,159,119,14,63,99,151,14,63,38,183,14,63,232,214,14,63,167,246,14,63,101,22,15,63,34,54,15,63,221,85,15,63,150,117,15,63,78,149,15,63,4,181,15,63,184,212,15,63,106,244,15,63,27,20,16,63,202,51,16,63,120,83,16,63,36,115,16,63,206,146,16,63,118,178,16,63,28,210,16,63,193,241,16,63,100,17,17,63,6,49,17,63,165,80,17,63,67,112,17,63,223,143,17,63,121,175,17,63,17,207,17,63,167,238,17,63,60,14,18,63,206,45,18,63,95,77,18,63,238,108,18,63,123,140,18,63,7,172,18,63,144,203,18,63,23,235,18,63,157,10,19,63,32,42,19,63,162,73,19,63,34,105,19,63,159,136,19,63,27,168,19,63,149,199,19,63,13,231,19,63,131,6,20,63,247,37,20,63,104,69,20,63,216,100,20,63,70,132,20,63,178,163,20,63,27,195,20,63,131,226,20,63,233,1,21,63,76,33,21,63,174,64,21,63,13,96,21,63,106,127,21,63,197,158,21,63,31,190,21,63,117,221,21,63,202,252,21,63,29,28,22,63,109,59,22,63,188,90,22,63,8,122,22,63,82,153,22,63,153,184,22,63,223,215,22,63,34,247,22,63,100,22,23,63,162,53,23,63,223,84,23,63,26,116,23,63,82,147,23,63,136,178,23,63,187,209,23,63,237,240,23,63,28,16,24,63,73,47,24,63,115,78,24,63,155,109,24,63,193,140,24,63,228,171,24,63,6,203,24,63,36,234,24,63,65,9,25,63,91,40,25,63,115,71,25,63,136,102,25,63,155,133,25,63,171,164,25,63,185,195,25,63,197,226,25,63,206,1,26,63,213,32,26,63,217,63,26,63,219,94,26,63,218,125,26,63,215,156,26,63,210,187,26,63,202,218,26,63,191,249,26,63,178,24,27,63,162,55,27,63,144,86,27,63,123,117,27,63,100,148,27,63,74,179,27,63,46,210,27,63,15,241,27,63,237,15,28,63,201,46,28,63,162,77,28,63,121,108,28,63,77,139,28,63,31,170,28,63,237,200,28,63,185,231,28,63,131,6,29,63,74,37,29,63,14,68,29,63,207,98,29,63,142,129,29,63,74,160,29,63,3,191,29,63,186,221,29,63,110,252,29,63,31,27,30,63,205,57,30,63,121,88,30,63,34,119,30,63,200,149,30,63,107,180,30,63,12,211,30,63,170,241,30,63,69,16,31,63,221,46,31,63,114,77,31,63,5,108,31,63,148,138,31,63,33,169,31,63,171,199,31,63,50,230,31,63,182,4,32,63,56,35,32,63,182,65,32,63,50,96,32,63,170,126,32,63,32,157,32,63,147,187,32,63,3,218,32,63,112,248,32,63,218,22,33,63,65,53,33,63,165,83,33,63,6,114,33,63,100,144,33,63,191,174,33,63,23,205,33,63,108,235,33,63,190,9,34,63,13,40,34,63,89,70,34,63,162,100,34,63,232,130,34,63,43,161,34,63,107,191,34,63,167,221,34,63,225,251,34,63,24,26,35,63,75,56,35,63,123,86,35,63,168,116,35,63,211,146,35,63,249,176,35,63,29,207,35,63,62,237,35,63,91,11,36,63,118,41,36,63,141,71,36,63,161,101,36,63,177,131,36,63,191,161,36,63,201,191,36,63,208,221,36,63,212,251,36,63,213,25,37,63,210,55,37,63,204,85,37,63,195,115,37,63,183,145,37,63,167,175,37,63,148,205,37,63,126,235,37,63,101,9,38,63,72,39,38,63,40,69,38,63,4,99,38,63,221,128,38,63,179,158,38,63,134,188,38,63,85,218,38,63,33,248,38,63,233,21,39,63,174,51,39,63,112,81,39,63,46,111,39,63,233,140,39,63,160,170,39,63,84,200,39,63,4,230,39,63,178,3,40,63,91,33,40,63,1,63,40,63,164,92,40,63,67,122,40,63,223,151,40,63,120,181,40,63,12,211,40,63,158,240,40,63,43,14,41,63,182,43,41,63,60,73,41,63,192,102,41,63,63,132,41,63,187,161,41,63,52,191,41,63,169,220,41,63,26,250,41,63,136,23,42,63,242,52,42,63,89,82,42,63,188,111,42,63,28,141,42,63,119,170,42,63,208,199,42,63,36,229,42,63,117,2,43,63,194,31,43,63,12,61,43,63,82,90,43,63,148,119,43,63,211,148,43,63,14,178,43,63,69,207,43,63,120,236,43,63,168,9,44,63,212,38,44,63,252,67,44,63,33,97,44,63,66,126,44,63,95,155,44,63,120,184,44,63,142,213,44,63,159,242,44,63,173,15,45,63,184,44,45,63,190,73,45,63,193,102,45,63,191,131,45,63,186,160,45,63,177,189,45,63,165,218,45,63,148,247,45,63,128,20,46,63,103,49,46,63,75,78,46,63,43,107,46,63,7,136,46,63,224,164,46,63,180,193,46,63,132,222,46,63,81,251,46,63,26,24,47,63,222,52,47,63,159,81,47,63,92,110,47,63,21,139,47,63,202,167,47,63,123,196,47,63,40,225,47,63,209,253,47,63,118,26,48,63,23,55,48,63,180,83,48,63,77,112,48,63,226,140,48,63,115,169,48,63,0,198,48,63,137,226,48,63,14,255,48,63,142,27,49,63,11,56,49,63,132,84,49,63,248,112,49,63,105,141,49,63,214,169,49,63,62,198,49,63,162,226,49,63,2,255,49,63,95,27,50,63,182,55,50,63,10,84,50,63,90,112,50,63,166,140,50,63,237,168,50,63,48,197,50,63,111,225,50,63,170,253,50,63,225,25,51,63,19,54,51,63,66,82,51,63,108,110,51,63,146,138,51,63,180,166,51,63,209,194,51,63,234,222,51,63,0,251,51,63,16,23,52,63,29,51,52,63,37,79,52,63,41,107,52,63,41,135,52,63,37,163,52,63,28,191,52,63,15,219,52,63,253,246,52,63,232,18,53,63,206,46,53,63,176,74,53,63,141,102,53,63,102,130,53,63,59,158,53,63,11,186,53,63,215,213,53,63,159,241,53,63,98,13,54,63,33,41,54,63,220,68,54,63,146,96,54,63,68,124,54,63,241,151,54,63,154,179,54,63,63,207,54,63,223,234,54,63,123,6,55,63,18,34,55,63,165,61,55,63,52,89,55,63,190,116,55,63,67,144,55,63,196,171,55,63,65,199,55,63,185,226,55,63,45,254,55,63,156,25,56,63,7,53,56,63,109,80,56,63,207,107,56,63,44,135,56,63,133,162,56,63,217,189,56,63,40,217,56,63,115,244,56,63,186,15,57,63,252,42,57,63,57,70,57,63,114,97,57,63,166,124,57,63,214,151,57,63,1,179,57,63,40,206,57,63,74,233,57,63,103,4,58,63,128,31,58,63,148,58,58,63,163,85,58,63,174,112,58,63,180,139,58,63,182,166,58,63,179,193,58,63,171,220,58,63,159,247,58,63,142,18,59,63,120,45,59,63,94,72,59,63,63,99,59,63,27,126,59,63,243,152,59,63,197,179,59,63,148,206,59,63,93,233,59,63,34,4,60,63,226,30,60,63,157,57,60,63,84,84,60,63,5,111,60,63,178,137,60,63,91,164,60,63,254,190,60,63,157,217,60,63,55,244,60,63,204,14,61,63,93,41,61,63,232,67,61,63,111,94,61,63,241,120,61,63,110,147,61,63,231,173,61,63,91,200,61,63,201,226,61,63,51,253,61,63,152,23,62,63,249,49,62,63,84,76,62,63,171,102,62,63,252,128,62,63,73,155,62,63,145,181,62,63,212,207,62,63,19,234,62,63,76,4,63,63,128,30,63,63,176,56,63,63,219,82,63,63,0,109,63,63,33,135,63,63,61,161,63,63,84,187,63,63,102,213,63,63,115,239,63,63,123,9,64,63,127,35,64,63,125,61,64,63,118,87,64,63,106,113,64,63,90,139,64,63,68,165,64,63,42,191,64,63,10,217,64,63,229,242,64,63,188,12,65,63,141,38,65,63,90,64,65,63,33,90,65,63,228,115,65,63,161,141,65,63,89,167,65,63,13,193,65,63,187,218,65,63,100,244,65,63,8,14,66,63,167,39,66,63,65,65,66,63,214,90,66,63,102,116,66,63,241,141,66,63,119,167,66,63,248,192,66,63,115,218,66,63,234,243,66,63,91,13,67,63,199,38,67,63,47,64,67,63,145,89,67,63,238,114,67,63,69,140,67,63,152,165,67,63,230,190,67,63,46,216,67,63,113,241,67,63,175,10,68,63,232,35,68,63,28,61,68,63,75,86,68,63,116,111,68,63,153,136,68,63,184,161,68,63,210,186,68,63,230,211,68,63,246,236,68,63,0,6,69,63,5,31,69,63,5,56,69,63,0,81,69,63,245,105,69,63,230,130,69,63,209,155,69,63,182,180,69,63,151,205,69,63,114,230,69,63,72,255,69,63,25,24,70,63,229,48,70,63,171,73,70,63,108,98,70,63,40,123,70,63,222,147,70,63,143,172,70,63,59,197,70,63,226,221,70,63,131,246,70,63,31,15,71,63,182,39,71,63,71,64,71,63,211,88,71,63,90,113,71,63,220,137,71,63,88,162,71,63,207,186,71,63,64,211,71,63,172,235,71,63,19,4,72,63,116,28,72,63,209,52,72,63,39,77,72,63,121,101,72,63,197,125,72,63,11,150,72,63,77,174,72,63,137,198,72,63,191,222,72,63,240,246,72,63,28,15,73,63,66,39,73,63,99,63,73,63,127,87,73,63,149,111,73,63,166,135,73,63,177,159,73,63,183,183,73,63,183,207,73,63,178,231,73,63,168,255,73,63,152,23,74,63,131,47,74,63,104,71,74,63,72,95,74,63,34,119,74,63,247,142,74,63,199,166,74,63,145,190,74,63,85,214,74,63,20,238,74,63,206,5,75,63,130,29,75,63,49,53,75,63,218,76,75,63,126,100,75,63,28,124,75,63,181,147,75,63,72,171,75,63,213,194,75,63,93,218,75,63,224,241,75,63,93,9,76,63,213,32,76,63,71,56,76,63,179,79,76,63,26,103,76,63,124,126,76,63,216,149,76,63,46,173,76,63,127,196,76,63,202,219,76,63,16,243,76,63,80,10,77,63,139,33,77,63,192,56,77,63,240,79,77,63,26,103,77,63,62,126,77,63,93,149,77,63,118,172,77,63,137,195,77,63,151,218,77,63,160,241,77,63,163,8,78,63,160,31,78,63,151,54,78,63,137,77,78,63,118,100,78,63,93,123,78,63,62,146,78,63,25,169,78,63,239,191,78,63,192,214,78,63,138,237,78,63,79,4,79,63,15,27,79,63,201,49,79,63,125,72,79,63,43,95,79,63,212,117,79,63,119,140,79,63,21,163,79,63,172,185,79,63,63,208,79,63,203,230,79,63,82,253,79,63,211,19,80,63,79,42,80,63,197,64,80,63,53,87,80,63,159,109,80,63,4,132,80,63,99,154,80,63,189,176,80,63,16,199,80,63,94,221,80,63,167,243,80,63,233,9,81,63,38,32,81,63,93,54,81,63,143,76,81,63,187,98,81,63,225,120,81,63,1,143,81,63,28,165,81,63,48,187,81,63,64,209,81,63,73,231,81,63,77,253,81,63,75,19,82,63,67,41,82,63,53,63,82,63,34,85,82,63,9,107,82,63,234,128,82,63,198,150,82,63,155,172,82,63,107,194,82,63,53,216,82,63,250,237,82,63,185,3,83,63,113,25,83,63,37,47,83,63,210,68,83,63,121,90,83,63,27,112,83,63,183,133,83,63,77,155,83,63,222,176,83,63,104,198,83,63,237,219,83,63,108,241,83,63,230,6,84,63,89,28,84,63,199,49,84,63,46,71,84,63,145,92,84,63,237,113,84,63,67,135,84,63,148,156,84,63,223,177,84,63,35,199,84,63,99,220,84,63,156,241,84,63,207,6,85,63,253,27,85,63,37,49,85,63,71,70,85,63,99,91,85,63,121,112,85,63,138,133,85,63,149,154,85,63,153,175,85,63,152,196,85,63,146,217,85,63,133,238,85,63,114,3,86,63,90,24,86,63,60,45,86,63,24,66,86,63,238,86,86,63,190,107,86,63,136,128,86,63,76,149,86,63,11,170,86,63,196,190,86,63,118,211,86,63,35,232,86,63,203,252,86,63,108,17,87,63,7,38,87,63,156,58,87,63,44,79,87,63,182,99,87,63,58,120,87,63,183,140,87,63,47,161,87,63,162,181,87,63,14,202,87,63,116,222,87,63,213,242,87,63,47,7,88,63,132,27,88,63,211,47,88,63,28,68,88,63,95,88,88,63,156,108,88,63,211,128,88,63,4,149,88,63,47,169,88,63,85,189,88,63,116,209,88,63,142,229,88,63,162,249,88,63,175,13,89,63,183,33,89,63,185,53,89,63,181,73,89,63,171,93,89,63,155,113,89,63,134,133,89,63,106,153,89,63,72,173,89,63,33,193,89,63,243,212,89,63,192,232,89,63,135,252,89,63,71,16,90,63,2,36,90,63,183,55,90,63,102,75,90,63,15,95,90,63,178,114,90,63,79,134,90,63,230,153,90,63,119,173,90,63,3,193,90,63,136,212,90,63,7,232,90,63,129,251,90,63,244,14,91,63,98,34,91,63,201,53,91,63,43,73,91,63,135,92,91,63,220,111,91,63,44,131,91,63,118,150,91,63,186,169,91,63,248,188,91,63,47,208,91,63,97,227,91,63,141,246,91,63,179,9,92,63,212,28,92,63,238,47,92,63,2,67,92,63,16,86,92,63,24,105,92,63,26,124,92,63,23,143,92,63,13,162,92,63,253,180,92,63,232,199,92,63,204,218,92,63,171,237,92,63,131,0,93,63,86,19,93,63,34,38,93,63,233,56,93,63,169,75,93,63,100,94,93,63,24,113,93,63,199,131,93,63,112,150,93,63,18,169,93,63,175,187,93,63,70,206,93,63,215,224,93,63,97,243,93,63,230,5,94,63,101,24,94,63,222,42,94,63,81,61,94,63,190,79,94,63,36,98,94,63,133,116,94,63,224,134,94,63,53,153,94,63,132,171,94,63,205,189,94,63,16,208,94,63,77,226,94,63,132,244,94,63,181,6,95,63,224,24,95,63,5,43,95,63,36,61,95,63,61,79,95,63,80,97,95,63,93,115,95,63,101,133,95,63,102,151,95,63,97,169,95,63,86,187,95,63,69,205,95,63,46,223,95,63,18,241,95,63,239,2,96,63,198,20,96,63,151,38,96,63,98,56,96,63,40,74,96,63,231,91,96,63,160,109,96,63,84,127,96,63,1,145,96,63,168,162,96,63,73,180,96,63,229,197,96,63,122,215,96,63,10,233,96,63,147,250,96,63,22,12,97,63,148,29,97,63,11,47,97,63,125,64,97,63,232,81,97,63,77,99,97,63,173,116,97,63,6,134,97,63,90,151,97,63,167,168,97,63,239,185,97,63,48,203,97,63,108,220,97,63,162,237,97,63,209,254,97,63,251,15,98,63,30,33,98,63,60,50,98,63,84,67,98,63,101,84,98,63,113,101,98,63,119,118,98,63,119,135,98,63,112,152,98,63,100,169,98,63,82,186,98,63,58,203,98,63,28,220,98,63,247,236,98,63,205,253,98,63,157,14,99,63,103,31,99,63,43,48,99,63,233,64,99,63,161,81,99,63,83,98,99,63,255,114,99,63,165,131,99,63,69,148,99,63,224,164,99,63,116,181,99,63,2,198,99,63,138,214,99,63,13,231,99,63,137,247,99,63,255,7,100,63,112,24,100,63,218,40,100,63,62,57,100,63,157,73,100,63,246,89,100,63,72,106,100,63,149,122,100,63,219,138,100,63,28,155,100,63,87,171,100,63,140,187,100,63,186,203,100,63,227,219,100,63,6,236,100,63,35,252,100,63,58,12,101,63,75,28,101,63,86,44,101,63,91,60,101,63,91,76,101,63,84,92,101,63,71,108,101,63,53,124,101,63,28,140,101,63,254,155,101,63,217,171,101,63,175,187,101,63,126,203,101,63,72,219,101,63,12,235,101,63,202,250,101,63,130,10,102,63,52,26,102,63,224,41,102,63,134,57,102,63,38,73,102,63,193,88,102,63,85,104,102,63,227,119,102,63,108,135,102,63,238,150,102,63,107,166,102,63,226,181,102,63,83,197,102,63,190,212,102,63,35,228,102,63,130,243,102,63,219,2,103,63,46,18,103,63,124,33,103,63,195,48,103,63,5,64,103,63,64,79,103,63,118,94,103,63,166,109,103,63,208,124,103,63,244,139,103,63,18,155,103,63,42,170,103,63,61,185,103,63,73,200,103,63,80,215,103,63,80,230,103,63,75,245,103,63,64,4,104,63,47,19,104,63,24,34,104,63,251,48,104,63,217,63,104,63,176,78,104,63,130,93,104,63,78,108,104,63,20,123,104,63,212,137,104,63,142,152,104,63,66,167,104,63,240,181,104,63,153,196,104,63,60,211,104,63,217,225,104,63,112,240,104,63,1,255,104,63,140,13,105,63,17,28,105,63,145,42,105,63,11,57,105,63,127,71,105,63,237,85,105,63,85,100,105,63,183,114,105,63,20,129,105,63,106,143,105,63,187,157,105,63,6,172,105,63,75,186,105,63,139,200,105,63,196,214,105,63,248,228,105,63,38,243,105,63,78,1,106,63,112,15,106,63,141,29,106,63,163,43,106,63,180,57,106,63,191,71,106,63,196,85,106,63,196,99,106,63,189,113,106,63,177,127,106,63,159,141,106,63,135,155,106,63,106,169,106,63,70,183,106,63,29,197,106,63,238,210,106,63,186,224,106,63,127,238,106,63,63,252,106,63,249,9,107,63,173,23,107,63,91,37,107,63,4,51,107,63,167,64,107,63,68,78,107,63,219,91,107,63,109,105,107,63,249,118,107,63,127,132,107,63,255,145,107,63,122,159,107,63,238,172,107,63,94,186,107,63,199,199,107,63,42,213,107,63,136,226,107,63,224,239,107,63,51,253,107,63,128,10,108,63,198,23,108,63,8,37,108,63,67,50,108,63,121,63,108,63,169,76,108,63,211,89,108,63,248,102,108,63,23,116,108,63,48,129,108,63,68,142,108,63,82,155,108,63,90,168,108,63,92,181,108,63,89,194,108,63,80,207,108,63,65,220,108,63,45,233,108,63,19,246,108,63,243,2,109,63,206,15,109,63,163,28,109,63,114,41,109,63,60,54,109,63,0,67,109,63,190,79,109,63,119,92,109,63,42,105,109,63,215,117,109,63,127,130,109,63,33,143,109,63,189,155,109,63,84,168,109,63,229,180,109,63,113,193,109,63,247,205,109,63,119,218,109,63,242,230,109,63,103,243,109,63,214,255,109,63,64,12,110,63,164,24,110,63,3,37,110,63,91,49,110,63,175,61,110,63,253,73,110,63,69,86,110,63,135,98,110,63,196,110,110,63,252,122,110,63,45,135,110,63,90,147,110,63,128,159,110,63,161,171,110,63,189,183,110,63,211,195,110,63,227,207,110,63,238,219,110,63,243,231,110,63,243,243,110,63,237,255,110,63,226,11,111,63,209,23,111,63,186,35,111,63,158,47,111,63,125,59,111,63,85,71,111,63,41,83,111,63,247,94,111,63,191,106,111,63,130,118,111,63,63,130,111,63,247,141,111,63,169,153,111,63,86,165,111,63,253,176,111,63,159,188,111,63,59,200,111,63,210,211,111,63,99,223,111,63,239,234,111,63,117,246,111,63,246,1,112,63,114,13,112,63,231,24,112,63,88,36,112,63,195,47,112,63,40,59,112,63,137,70,112,63,227,81,112,63,56,93,112,63,136,104,112,63,210,115,112,63,23,127,112,63,87,138,112,63,145,149,112,63,197,160,112,63,244,171,112,63,30,183,112,63,66,194,112,63,97,205,112,63,123,216,112,63,143,227,112,63,157,238,112,63,167,249,112,63,171,4,113,63,169,15,113,63,162,26,113,63,150,37,113,63,132,48,113,63,109,59,113,63,81,70,113,63,47,81,113,63,8,92,113,63,219,102,113,63,170,113,113,63,114,124,113,63,54,135,113,63,244,145,113,63,173,156,113,63,96,167,113,63,14,178,113,63,183,188,113,63,91,199,113,63,249,209,113,63,146,220,113,63,37,231,113,63,179,241,113,63,60,252,113,63,192,6,114,63,62,17,114,63,183,27,114,63,43,38,114,63,154,48,114,63,3,59,114,63,103,69,114,63,197,79,114,63,31,90,114,63,115,100,114,63,194,110,114,63,11,121,114,63,79,131,114,63,143,141,114,63,200,151,114,63,253,161,114,63,44,172,114,63,87,182,114,63,123,192,114,63,155,202,114,63,182,212,114,63,203,222,114,63,219,232,114,63,230,242,114,63,235,252,114,63,236,6,115,63,231,16,115,63,221,26,115,63,206,36,115,63,186,46,115,63,160,56,115,63,130,66,115,63,94,76,115,63,53,86,115,63,7,96,115,63,212,105,115,63,155,115,115,63,94,125,115,63,27,135,115,63,211,144,115,63,134,154,115,63,52,164,115,63,221,173,115,63,128,183,115,63,31,193,115,63,184,202,115,63,77,212,115,63,220,221,115,63,102,231,115,63,235,240,115,63,107,250,115,63,230,3,116,63,92,13,116,63,204,22,116,63,56,32,116,63,159,41,116,63,0,51,116,63,93,60,116,63,180,69,116,63,6,79,116,63,84,88,116,63,156,97,116,63,223,106,116,63,29,116,116,63,87,125,116,63,139,134,116,63,186,143,116,63,228,152,116,63,9,162,116,63,41,171,116,63,68,180,116,63,91,189,116,63,108,198,116,63,120,207,116,63,127,216,116,63,129,225,116,63,127,234,116,63,119,243,116,63,106,252,116,63,89,5,117,63,66,14,117,63,38,23,117,63,6,32,117,63,225,40,117,63,182,49,117,63,135,58,117,63,83,67,117,63,26,76,117,63,220,84,117,63,153,93,117,63,81,102,117,63,4,111,117,63,179,119,117,63,92,128,117,63,1,137,117,63,160,145,117,63,59,154,117,63,209,162,117,63,98,171,117,63,239,179,117,63,118,188,117,63,249,196,117,63,118,205,117,63,239,213,117,63,99,222,117,63,210,230,117,63,61,239,117,63,162,247,117,63,3,0,118,63,95,8,118,63,182,16,118,63,8,25,118,63,86,33,118,63,159,41,118,63,227,49,118,63,34,58,118,63,92,66,118,63,146,74,118,63,195,82,118,63,239,90,118,63,22,99,118,63,57,107,118,63,86,115,118,63,112,123,118,63,132,131,118,63,148,139,118,63,158,147,118,63,165,155,118,63,166,163,118,63,163,171,118,63,155,179,118,63,142,187,118,63,125,195,118,63,103,203,118,63,76,211,118,63,45,219,118,63,9,227,118,63,224,234,118,63,178,242,118,63,128,250,118,63,74,2,119,63,14,10,119,63,206,17,119,63,137,25,119,63,64,33,119,63,242,40,119,63,160,48,119,63,72,56,119,63,237,63,119,63,140,71,119,63,39,79,119,63,190,86,119,63,79,94,119,63,220,101,119,63,101,109,119,63,233,116,119,63,105,124,119,63,228,131,119,63,90,139,119,63,204,146,119,63,57,154,119,63,162,161,119,63,6,169,119,63,101,176,119,63,192,183,119,63,23,191,119,63,105,198,119,63,182,205,119,63,255,212,119,63,68,220,119,63,132,227,119,63,191,234,119,63,246,241,119,63,41,249,119,63,87,0,120,63,129,7,120,63,166,14,120,63,198,21,120,63,227,28,120,63,250,35,120,63,14,43,120,63,28,50,120,63,39,57,120,63,45,64,120,63,46,71,120,63,44,78,120,63,36,85,120,63,25,92,120,63,9,99,120,63,244,105,120,63,219,112,120,63,190,119,120,63,156,126,120,63,118,133,120,63,76,140,120,63,29,147,120,63,234,153,120,63,179,160,120,63,119,167,120,63,55,174,120,63,242,180,120,63,169,187,120,63,92,194,120,63,11,201,120,63,181,207,120,63,91,214,120,63,252,220,120,63,154,227,120,63,51,234,120,63,199,240,120,63,88,247,120,63,228,253,120,63,108,4,121,63,240,10,121,63,111,17,121,63,234,23,121,63,97,30,121,63,211,36,121,63,66,43,121,63,172,49,121,63,18,56,121,63,116,62,121,63,209,68,121,63,42,75,121,63,127,81,121,63,208,87,121,63,29,94,121,63,101,100,121,63,170,106,121,63,234,112,121,63,38,119,121,63,93,125,121,63,145,131,121,63,193,137,121,63,236,143,121,63,19,150,121,63,54,156,121,63,85,162,121,63,112,168,121,63,134,174,121,63,153,180,121,63,167,186,121,63,178,192,121,63,184,198,121,63,186,204,121,63,184,210,121,63,178,216,121,63,168,222,121,63,154,228,121,63,135,234,121,63,113,240,121,63,87,246,121,63,56,252,121,63,22,2,122,63,239,7,122,63,197,13,122,63,150,19,122,63,100,25,122,63,45,31,122,63,243,36,122,63,180,42,122,63,113,48,122,63,43,54,122,63,224,59,122,63,146,65,122,63,63,71,122,63,233,76,122,63,142,82,122,63,48,88,122,63,206,93,122,63,103,99,122,63,253,104,122,63,143,110,122,63,29,116,122,63,167,121,122,63,45,127,122,63,175,132,122,63,45,138,122,63,168,143,122,63,30,149,122,63,145,154,122,63,255,159,122,63,106,165,122,63,209,170,122,63,52,176,122,63,147,181,122,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+61440);
/* memory initializer */ allocate([239,186,122,63,70,192,122,63,154,197,122,63,234,202,122,63,54,208,122,63,126,213,122,63,194,218,122,63,3,224,122,63,64,229,122,63,121,234,122,63,174,239,122,63,223,244,122,63,13,250,122,63,55,255,122,63,93,4,123,63,127,9,123,63,157,14,123,63,184,19,123,63,207,24,123,63,227,29,123,63,242,34,123,63,254,39,123,63,6,45,123,63,10,50,123,63,11,55,123,63,8,60,123,63,1,65,123,63,247,69,123,63,233,74,123,63,215,79,123,63,193,84,123,63,168,89,123,63,139,94,123,63,107,99,123,63,71,104,123,63,31,109,123,63,243,113,123,63,196,118,123,63,146,123,123,63,91,128,123,63,33,133,123,63,228,137,123,63,163,142,123,63,94,147,123,63,22,152,123,63,202,156,123,63,122,161,123,63,39,166,123,63,208,170,123,63,118,175,123,63,24,180,123,63,183,184,123,63,82,189,123,63,233,193,123,63,125,198,123,63,14,203,123,63,155,207,123,63,36,212,123,63,170,216,123,63,45,221,123,63,172,225,123,63,39,230,123,63,159,234,123,63,19,239,123,63,132,243,123,63,242,247,123,63,92,252,123,63,195,0,124,63,38,5,124,63,133,9,124,63,226,13,124,63,58,18,124,63,144,22,124,63,226,26,124,63,48,31,124,63,123,35,124,63,195,39,124,63,7,44,124,63,72,48,124,63,134,52,124,63,192,56,124,63,247,60,124,63,42,65,124,63,90,69,124,63,135,73,124,63,176,77,124,63,214,81,124,63,249,85,124,63,24,90,124,63,52,94,124,63,77,98,124,63,98,102,124,63,116,106,124,63,131,110,124,63,142,114,124,63,150,118,124,63,155,122,124,63,157,126,124,63,155,130,124,63,150,134,124,63,142,138,124,63,130,142,124,63,116,146,124,63,98,150,124,63,77,154,124,63,52,158,124,63,24,162,124,63,249,165,124,63,215,169,124,63,178,173,124,63,137,177,124,63,94,181,124,63,47,185,124,63,253,188,124,63,199,192,124,63,143,196,124,63,83,200,124,63,20,204,124,63,211,207,124,63,141,211,124,63,69,215,124,63,250,218,124,63,171,222,124,63,90,226,124,63,5,230,124,63,173,233,124,63,82,237,124,63,244,240,124,63,147,244,124,63,46,248,124,63,199,251,124,63,93,255,124,63,239,2,125,63,127,6,125,63,11,10,125,63,148,13,125,63,27,17,125,63,158,20,125,63,30,24,125,63,155,27,125,63,21,31,125,63,140,34,125,63,0,38,125,63,114,41,125,63,224,44,125,63,75,48,125,63,179,51,125,63,24,55,125,63,122,58,125,63,217,61,125,63,54,65,125,63,143,68,125,63,229,71,125,63,56,75,125,63,137,78,125,63,214,81,125,63,33,85,125,63,104,88,125,63,173,91,125,63,239,94,125,63,46,98,125,63,106,101,125,63,163,104,125,63,217,107,125,63,12,111,125,63,61,114,125,63,106,117,125,63,149,120,125,63,189,123,125,63,226,126,125,63,4,130,125,63,36,133,125,63,64,136,125,63,90,139,125,63,112,142,125,63,133,145,125,63,150,148,125,63,164,151,125,63,176,154,125,63,185,157,125,63,191,160,125,63,194,163,125,63,194,166,125,63,192,169,125,63,187,172,125,63,179,175,125,63,168,178,125,63,155,181,125,63,139,184,125,63,120,187,125,63,99,190,125,63,74,193,125,63,48,196,125,63,18,199,125,63,241,201,125,63,206,204,125,63,169,207,125,63,128,210,125,63,85,213,125,63,39,216,125,63,247,218,125,63,196,221,125,63,142,224,125,63,85,227,125,63,26,230,125,63,220,232,125,63,156,235,125,63,89,238,125,63,19,241,125,63,203,243,125,63,128,246,125,63,51,249,125,63,227,251,125,63,144,254,125,63,59,1,126,63,227,3,126,63,137,6,126,63,44,9,126,63,204,11,126,63,106,14,126,63,6,17,126,63,158,19,126,63,53,22,126,63,200,24,126,63,90,27,126,63,232,29,126,63,116,32,126,63,254,34,126,63,133,37,126,63,10,40,126,63,140,42,126,63,12,45,126,63,137,47,126,63,4,50,126,63,124,52,126,63,242,54,126,63,101,57,126,63,214,59,126,63,68,62,126,63,176,64,126,63,26,67,126,63,129,69,126,63,230,71,126,63,72,74,126,63,168,76,126,63,5,79,126,63,96,81,126,63,185,83,126,63,15,86,126,63,99,88,126,63,181,90,126,63,4,93,126,63,81,95,126,63,155,97,126,63,227,99,126,63,41,102,126,63,108,104,126,63,173,106,126,63,236,108,126,63,40,111,126,63,98,113,126,63,154,115,126,63,208,117,126,63,3,120,126,63,51,122,126,63,98,124,126,63,142,126,126,63,184,128,126,63,224,130,126,63,5,133,126,63,40,135,126,63,73,137,126,63,104,139,126,63,132,141,126,63,159,143,126,63,183,145,126,63,204,147,126,63,224,149,126,63,241,151,126,63,0,154,126,63,13,156,126,63,24,158,126,63,32,160,126,63,38,162,126,63,42,164,126,63,44,166,126,63,44,168,126,63,41,170,126,63,37,172,126,63,30,174,126,63,21,176,126,63,10,178,126,63,253,179,126,63,238,181,126,63,220,183,126,63,201,185,126,63,179,187,126,63,155,189,126,63,129,191,126,63,101,193,126,63,71,195,126,63,39,197,126,63,5,199,126,63,224,200,126,63,186,202,126,63,145,204,126,63,103,206,126,63,58,208,126,63,12,210,126,63,219,211,126,63,168,213,126,63,115,215,126,63,61,217,126,63,4,219,126,63,201,220,126,63,140,222,126,63,77,224,126,63,12,226,126,63,202,227,126,63,133,229,126,63,62,231,126,63,245,232,126,63,170,234,126,63,94,236,126,63,15,238,126,63,190,239,126,63,108,241,126,63,23,243,126,63,193,244,126,63,104,246,126,63,14,248,126,63,178,249,126,63,84,251,126,63,243,252,126,63,145,254,126,63,46,0,127,63,200,1,127,63,96,3,127,63,247,4,127,63,139,6,127,63,30,8,127,63,175,9,127,63,62,11,127,63,203,12,127,63,86,14,127,63,223,15,127,63,103,17,127,63,237,18,127,63,112,20,127,63,242,21,127,63,115,23,127,63,241,24,127,63,110,26,127,63,233,27,127,63,98,29,127,63,217,30,127,63,78,32,127,63,194,33,127,63,52,35,127,63,164,36,127,63,18,38,127,63,127,39,127,63,234,40,127,63,83,42,127,63,186,43,127,63,32,45,127,63,131,46,127,63,230,47,127,63,70,49,127,63,165,50,127,63,2,52,127,63,93,53,127,63,182,54,127,63,14,56,127,63,100,57,127,63,185,58,127,63,12,60,127,63,93,61,127,63,172,62,127,63,250,63,127,63,70,65,127,63,145,66,127,63,217,67,127,63,33,69,127,63,102,70,127,63,170,71,127,63,236,72,127,63,45,74,127,63,108,75,127,63,169,76,127,63,229,77,127,63,31,79,127,63,88,80,127,63,143,81,127,63,196,82,127,63,248,83,127,63,42,85,127,63,91,86,127,63,138,87,127,63,184,88,127,63,228,89,127,63,14,91,127,63,55,92,127,63,94,93,127,63,132,94,127,63,169,95,127,63,203,96,127,63,237,97,127,63,12,99,127,63,42,100,127,63,71,101,127,63,98,102,127,63,124,103,127,63,148,104,127,63,171,105,127,63,192,106,127,63,212,107,127,63,230,108,127,63,247,109,127,63,6,111,127,63,20,112,127,63,33,113,127,63,44,114,127,63,53,115,127,63,61,116,127,63,68,117,127,63,73,118,127,63,77,119,127,63,79,120,127,63,80,121,127,63,80,122,127,63,78,123,127,63,75,124,127,63,70,125,127,63,64,126,127,63,57,127,127,63,48,128,127,63,38,129,127,63,27,130,127,63,14,131,127,63,0,132,127,63,240,132,127,63,223,133,127,63,205,134,127,63,185,135,127,63,164,136,127,63,142,137,127,63,118,138,127,63,93,139,127,63,67,140,127,63,40,141,127,63,11,142,127,63,237,142,127,63,205,143,127,63,173,144,127,63,139,145,127,63,103,146,127,63,67,147,127,63,29,148,127,63,246,148,127,63,205,149,127,63,164,150,127,63,121,151,127,63,77,152,127,63,31,153,127,63,241,153,127,63,193,154,127,63,144,155,127,63,93,156,127,63,42,157,127,63,245,157,127,63,191,158,127,63,136,159,127,63,79,160,127,63,22,161,127,63,219,161,127,63,159,162,127,63,98,163,127,63,36,164,127,63,228,164,127,63,163,165,127,63,98,166,127,63,31,167,127,63,219,167,127,63,149,168,127,63,79,169,127,63,7,170,127,63,190,170,127,63,117,171,127,63,42,172,127,63,221,172,127,63,144,173,127,63,66,174,127,63,242,174,127,63,162,175,127,63,80,176,127,63,253,176,127,63,169,177,127,63,85,178,127,63,254,178,127,63,167,179,127,63,79,180,127,63,246,180,127,63,156,181,127,63,64,182,127,63,228,182,127,63,134,183,127,63,40,184,127,63,200,184,127,63,103,185,127,63,6,186,127,63,163,186,127,63,63,187,127,63,219,187,127,63,117,188,127,63,14,189,127,63,166,189,127,63,61,190,127,63,212,190,127,63,105,191,127,63,253,191,127,63,144,192,127,63,34,193,127,63,180,193,127,63,68,194,127,63,211,194,127,63,98,195,127,63,239,195,127,63,123,196,127,63,7,197,127,63,145,197,127,63,27,198,127,63,163,198,127,63,43,199,127,63,178,199,127,63,56,200,127,63,189,200,127,63,65,201,127,63,196,201,127,63,70,202,127,63,199,202,127,63,71,203,127,63,199,203,127,63,69,204,127,63,195,204,127,63,64,205,127,63,187,205,127,63,54,206,127,63,177,206,127,63,42,207,127,63,162,207,127,63,26,208,127,63,144,208,127,63,6,209,127,63,123,209,127,63,239,209,127,63,98,210,127,63,213,210,127,63,70,211,127,63,183,211,127,63,39,212,127,63,150,212,127,63,4,213,127,63,114,213,127,63,222,213,127,63,74,214,127,63,181,214,127,63,32,215,127,63,137,215,127,63,242,215,127,63,89,216,127,63,192,216,127,63,39,217,127,63,140,217,127,63,241,217,127,63,85,218,127,63,184,218,127,63,27,219,127,63,124,219,127,63,221,219,127,63,61,220,127,63,157,220,127,63,251,220,127,63,89,221,127,63,183,221,127,63,19,222,127,63,111,222,127,63,202,222,127,63,36,223,127,63,126,223,127,63,215,223,127,63,47,224,127,63,134,224,127,63,221,224,127,63,51,225,127,63,137,225,127,63,221,225,127,63,49,226,127,63,133,226,127,63,215,226,127,63,41,227,127,63,122,227,127,63,203,227,127,63,27,228,127,63,106,228,127,63,185,228,127,63,7,229,127,63,84,229,127,63,161,229,127,63,237,229,127,63,56,230,127,63,131,230,127,63,205,230,127,63,23,231,127,63,96,231,127,63,168,231,127,63,239,231,127,63,54,232,127,63,125,232,127,63,195,232,127,63,8,233,127,63,76,233,127,63,144,233,127,63,212,233,127,63,23,234,127,63,89,234,127,63,154,234,127,63,219,234,127,63,28,235,127,63,92,235,127,63,155,235,127,63,218,235,127,63,24,236,127,63,86,236,127,63,147,236,127,63,207,236,127,63,11,237,127,63,71,237,127,63,130,237,127,63,188,237,127,63,246,237,127,63,47,238,127,63,104,238,127,63,160,238,127,63,216,238,127,63,15,239,127,63,69,239,127,63,123,239,127,63,177,239,127,63,230,239,127,63,27,240,127,63,79,240,127,63,130,240,127,63,182,240,127,63,232,240,127,63,26,241,127,63,76,241,127,63,125,241,127,63,174,241,127,63,222,241,127,63,14,242,127,63,61,242,127,63,108,242,127,63,154,242,127,63,200,242,127,63,245,242,127,63,34,243,127,63,79,243,127,63,123,243,127,63,166,243,127,63,209,243,127,63,252,243,127,63,38,244,127,63,80,244,127,63,121,244,127,63,162,244,127,63,203,244,127,63,243,244,127,63,27,245,127,63,66,245,127,63,105,245,127,63,143,245,127,63,181,245,127,63,219,245,127,63,0,246,127,63,37,246,127,63,73,246,127,63,109,246,127,63,145,246,127,63,180,246,127,63,215,246,127,63,250,246,127,63,28,247,127,63,62,247,127,63,95,247,127,63,128,247,127,63,160,247,127,63,193,247,127,63,225,247,127,63,0,248,127,63,31,248,127,63,62,248,127,63,93,248,127,63,123,248,127,63,152,248,127,63,182,248,127,63,211,248,127,63,240,248,127,63,12,249,127,63,40,249,127,63,68,249,127,63,95,249,127,63,122,249,127,63,149,249,127,63,175,249,127,63,202,249,127,63,227,249,127,63,253,249,127,63,22,250,127,63,47,250,127,63,71,250,127,63,96,250,127,63,120,250,127,63,143,250,127,63,166,250,127,63,190,250,127,63,212,250,127,63,235,250,127,63,1,251,127,63,23,251,127,63,44,251,127,63,66,251,127,63,87,251,127,63,108,251,127,63,128,251,127,63,148,251,127,63,168,251,127,63,188,251,127,63,208,251,127,63,227,251,127,63,246,251,127,63,8,252,127,63,27,252,127,63,45,252,127,63,63,252,127,63,81,252,127,63,98,252,127,63,115,252,127,63,132,252,127,63,149,252,127,63,165,252,127,63,182,252,127,63,198,252,127,63,213,252,127,63,229,252,127,63,244,252,127,63,3,253,127,63,18,253,127,63,33,253,127,63,47,253,127,63,62,253,127,63,76,253,127,63,89,253,127,63,103,253,127,63,116,253,127,63,130,253,127,63,143,253,127,63,155,253,127,63,168,253,127,63,181,253,127,63,193,253,127,63,205,253,127,63,217,253,127,63,228,253,127,63,240,253,127,63,251,253,127,63,6,254,127,63,17,254,127,63,28,254,127,63,38,254,127,63,49,254,127,63,59,254,127,63,69,254,127,63,79,254,127,63,89,254,127,63,98,254,127,63,108,254,127,63,117,254,127,63,126,254,127,63,135,254,127,63,144,254,127,63,152,254,127,63,161,254,127,63,169,254,127,63,177,254,127,63,185,254,127,63,193,254,127,63,201,254,127,63,208,254,127,63,216,254,127,63,223,254,127,63,230,254,127,63,237,254,127,63,244,254,127,63,251,254,127,63,2,255,127,63,8,255,127,63,14,255,127,63,21,255,127,63,27,255,127,63,33,255,127,63,39,255,127,63,45,255,127,63,50,255,127,63,56,255,127,63,61,255,127,63,67,255,127,63,72,255,127,63,77,255,127,63,82,255,127,63,87,255,127,63,92,255,127,63,96,255,127,63,101,255,127,63,105,255,127,63,110,255,127,63,114,255,127,63,118,255,127,63,122,255,127,63,126,255,127,63,130,255,127,63,134,255,127,63,138,255,127,63,142,255,127,63,145,255,127,63,149,255,127,63,152,255,127,63,155,255,127,63,159,255,127,63,162,255,127,63,165,255,127,63,168,255,127,63,171,255,127,63,174,255,127,63,176,255,127,63,179,255,127,63,182,255,127,63,184,255,127,63,187,255,127,63,189,255,127,63,192,255,127,63,194,255,127,63,196,255,127,63,198,255,127,63,201,255,127,63,203,255,127,63,205,255,127,63,207,255,127,63,209,255,127,63,210,255,127,63,212,255,127,63,214,255,127,63,216,255,127,63,217,255,127,63,219,255,127,63,220,255,127,63,222,255,127,63,223,255,127,63,225,255,127,63,226,255,127,63,227,255,127,63,229,255,127,63,230,255,127,63,231,255,127,63,232,255,127,63,233,255,127,63,234,255,127,63,235,255,127,63,236,255,127,63,237,255,127,63,238,255,127,63,239,255,127,63,240,255,127,63,241,255,127,63,241,255,127,63,242,255,127,63,243,255,127,63,244,255,127,63,244,255,127,63,245,255,127,63,246,255,127,63,246,255,127,63,247,255,127,63,247,255,127,63,248,255,127,63,248,255,127,63,249,255,127,63,249,255,127,63,250,255,127,63,250,255,127,63,250,255,127,63,251,255,127,63,251,255,127,63,251,255,127,63,252,255,127,63,252,255,127,63,252,255,127,63,253,255,127,63,253,255,127,63,253,255,127,63,253,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,24,0,120,58,76,70,11,60,242,204,192,60,116,252,59,61,86,73,154,61,241,93,228,61,248,163,29,62,180,231,78,62,54,157,130,62,78,220,159,62,193,174,190,62,65,132,222,62,173,194,254,62,186,101,15,63,248,0,31,63,29,233,45,63,249,219,59,63,45,162,72,63,160,17,84,63,38,15,94,63,46,143,102,63,112,149,109,63,174,51,115,63,159,135,119,63,66,184,122,63,196,242,124,63,75,103,126,63,196,69,127,63,241,186,127,63,217,237,127,63,162,253,127,63,248,255,127,63,169,12,120,55,54,134,11,57,38,198,193,57,94,226,61,58,234,237,156,58,85,101,234,58,56,170,35,59,207,219,89,59,169,226,139,59,42,178,174,59,13,91,213,59,204,219,255,59,91,25,23,60,250,46,48,60,194,45,75,60,156,20,104,60,46,113,131,60,225,202,147,60,185,22,165,60,1,84,183,60,245,129,202,60,198,159,222,60,155,172,243,60,199,211,4,61,213,71,16,61,250,49,28,61,174,145,40,61,101,102,53,61,141,175,66,61,140,108,80,61,193,156,94,61,133,63,109,61,41,84,124,61,252,236,133,61,26,232,141,61,13,27,150,61,110,133,158,61,212,38,167,61,210,254,175,61,245,12,185,61,200,80,194,61,209,201,203,61,146,119,213,61,139,89,223,61,51,111,233,61,2,184,243,61,105,51,254,61,106,112,4,62,214,223,9,62,171,103,15,62,153,7,21,62,77,191,26,62,116,142,32,62,181,116,38,62,184,113,44,62,34,133,50,62,149,174,56,62,178,237,62,62,21,66,69,62,92,171,75,62,30,41,82,62,243,186,88,62,112,96,95,62,40,25,102,62,170,228,108,62,132,194,115,62,68,178,122,62,185,217,128,62,203,98,132,62,26,244,135,62,105,141,139,62,120,46,143,62,6,215,146,62,211,134,150,62,156,61,154,62,29,251,157,62,19,191,161,62,57,137,165,62,71,89,169,62,249,46,173,62,5,10,177,62,36,234,180,62,13,207,184,62,117,184,188,62,18,166,192,62,153,151,196,62,190,140,200,62,52,133,204,62,175,128,208,62,225,126,212,62,125,127,216,62,52,130,220,62,184,134,224,62,185,140,228,62,233,147,232,62,248,155,236,62,150,164,240,62,117,173,244,62,67,182,248,62,178,190,252,62,57,99,0,63,153,102,2,63,82,105,4,63,60,107,6,63,48,108,8,63,6,108,10,63,151,106,12,63,188,103,14,63,78,99,16,63,39,93,18,63,33,85,20,63,21,75,22,63,222,62,24,63,87,48,26,63,92,31,28,63,199,11,30,63,117,245,31,63,66,220,33,63,12,192,35,63,176,160,37,63,12,126,39,63,254,87,41,63,104,46,43,63,39,1,45,63,29,208,46,63,43,155,48,63,51,98,50,63,23,37,52,63,188,227,53,63,4,158,55,63,214,83,57,63,23,5,59,63,173,177,60,63,128,89,62,63,120,252,63,63,126,154,65,63,124,51,67,63,93,199,68,63,12,86,70,63,119,223,71,63,138,99,73,63,54,226,74,63,104,91,76,63,17,207,77,63,35,61,79,63,145,165,80,63,76,8,82,63,75,101,83,63,130,188,84,63,231,13,86,63,114,89,87,63,26,159,88,63,218,222,89,63,172,24,91,63,138,76,92,63,113,122,93,63,93,162,94,63,78,196,95,63,67,224,96,63,58,246,97,63,54,6,99,63,56,16,100,63,67,20,101,63,92,18,102,63,133,10,103,63,198,252,103,63,37,233,104,63,168,207,105,63,89,176,106,63,64,139,107,63,102,96,108,63,216,47,109,63,159,249,109,63,201,189,110,63,97,124,111,63,118,53,112,63,23,233,112,63,81,151,113,63,53,64,114,63,212,227,114,63,61,130,115,63,131,27,116,63,184,175,116,63,238,62,117,63,56,201,117,63,171,78,118,63,90,207,118,63,90,75,119,63,192,194,119,63,162,53,120,63,21,164,120,63,48,14,121,63,8,116,121,63,182,213,121,63,79,51,122,63,235,140,122,63,162,226,122,63,139,52,123,63,191,130,123,63,85,205,123,63,102,20,124,63,9,88,124,63,88,152,124,63,106,213,124,63,88,15,125,63,58,70,125,63,41,122,125,63,62,171,125,63,143,217,125,63,54,5,126,63,75,46,126,63,228,84,126,63,27,121,126,63,7,155,126,63,190,186,126,63,88,216,126,63,236,243,126,63,144,13,127,63,91,37,127,63,99,59,127,63,188,79,127,63,125,98,127,63,185,115,127,63,135,131,127,63,249,145,127,63,36,159,127,63,26,171,127,63,238,181,127,63,179,191,127,63,122,200,127,63,85,208,127,63,84,215,127,63,136,221,127,63,0,227,127,63,204,231,127,63,249,235,127,63,150,239,127,63,177,242,127,63,85,245,127,63,144,247,127,63,109,249,127,63,246,250,127,63,54,252,127,63,55,253,127,63,1,254,127,63,156,254,127,63,18,255,127,63,103,255,127,63,163,255,127,63,204,255,127,63,229,255,127,63,244,255,127,63,252,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,204,8,120,52,171,134,11,54,79,202,193,54,190,233,61,55,238,247,156,55,192,123,234,55,43,192,35,56,161,2,90,56,189,2,140,56,76,228,174,56,227,165,213,56,199,35,0,57,168,100,23,57,134,149,48,57,104,182,75,57,64,199,104,57,7,228,131,57,105,92,148,57,191,204,165,57,6,53,184,57,65,149,203,57,105,237,223,57,120,61,245,57,184,194,5,58,166,98,17,58,134,126,29,58,81,22,42,58,9,42,55,58,172,185,68,58,54,197,82,58,165,76,97,58,250,79,112,58,47,207,127,58,34,229,135,58,154,32,144,58,255,153,152,58,80,81,161,58,139,70,170,58,174,121,179,58,186,234,188,58,171,153,198,58,129,134,208,58,58,177,218,58,212,25,229,58,79,192,239,58,167,164,250,58,109,227,2,59,117,147,8,59,105,98,14,59,73,80,20,59,19,93,26,59,199,136,32,59,100,211,38,59,232,60,45,59,83,197,51,59,164,108,58,59,218,50,65,59,243,23,72,59,239,27,79,59,204,62,86,59,138,128,93,59,38,225,100,59,161,96,108,59,249,254,115,59,45,188,123,59,29,204,129,59,145,201,133,59,113,214,137,59,188,242,141,59,113,30,146,59,145,89,150,59,26,164,154,59,12,254,158,59,102,103,163,59,40,224,167,59,80,104,172,59,222,255,176,59,209,166,181,59,40,93,186,59,228,34,191,59,2,248,195,59,131,220,200,59,101,208,205,59,168,211,210,59,74,230,215,59,76,8,221,59,172,57,226,59,105,122,231,59,131,202,236,59,249,41,242,59,202,152,247,59,245,22,253,59,60,82,1,60,170,32,4,60,196,246,6,60,137,212,9,60,249,185,12,60,19,167,15,60,216,155,18,60,69,152,21,60,92,156,24,60,26,168,27,60,129,187,30,60,143,214,33,60,69,249,36,60,160,35,40,60,162,85,43,60,73,143,46,60,149,208,49,60,133,25,53,60,26,106,56,60,81,194,59,60,44,34,63,60,168,137,66,60,199,248,69,60,134,111,73,60,230,237,76,60,231,115,80,60,134,1,84,60,197,150,87,60,162,51,91,60,28,216,94,60,52,132,98,60,232,55,102,60,56,243,105,60,35,182,109,60,170,128,113,60,202,82,117,60,131,44,121,60,214,13,125,60,96,123,128,60,161,115,130,60,174,111,132,60,134,111,134,60,40,115,136,60,149,122,138,60,205,133,140,60,206,148,142,60,152,167,144,60,44,190,146,60,136,216,148,60,173,246,150,60,154,24,153,60,78,62,155,60,202,103,157,60,13,149,159,60,23,198,161,60,231,250,163,60,125,51,166,60,217,111,168,60,249,175,170,60,223,243,172,60,137,59,175,60,247,134,177,60,40,214,179,60,29,41,182,60,213,127,184,60,80,218,186,60,140,56,189,60,138,154,191,60,74,0,194,60,202,105,196,60,11,215,198,60,12,72,201,60,205,188,203,60,77,53,206,60,140,177,208,60,137,49,211,60,69,181,213,60,189,60,216,60,243,199,218,60,230,86,221,60,149,233,223,60,0,128,226,60,39,26,229,60,8,184,231,60,164,89,234,60,250,254,236,60,9,168,239,60,210,84,242,60,83,5,245,60,141,185,247,60,126,113,250,60,39,45,253,60,134,236,255,60,206,87,1,61,52,187,2,61,117,32,4,61,144,135,5,61,133,240,6,61,84,91,8,61,253,199,9,61,128,54,11,61,219,166,12,61,16,25,14,61,29,141,15,61,3,3,17,61,193,122,18,61,87,244,19,61,197,111,21,61,10,237,22,61,39,108,24,61,26,237,25,61,228,111,27,61,132,244,28,61,251,122,30,61,71,3,32,61,105,141,33,61,96,25,35,61,45,167,36,61,206,54,38,61,67,200,39,61,141,91,41,61,171,240,42,61,156,135,44,61,96,32,46,61,248,186,47,61,99,87,49,61,160,245,50,61,175,149,52,61,144,55,54,61,67,219,55,61,199,128,57,61,28,40,59,61,65,209,60,61,56,124,62,61,254,40,64,61,148,215,65,61,250,135,67,61,47,58,69,61,51,238,70,61,5,164,72,61,166,91,74,61,20,21,76,61,80,208,77,61,90,141,79,61,49,76,81,61,212,12,83,61,68,207,84,61,128,147,86,61,135,89,88,61,90,33,90,61,248,234,91,61,97,182,93,61,148,131,95,61,145,82,97,61,88,35,99,61,232,245,100,61,65,202,102,61,100,160,104,61,78,120,106,61,1,82,108,61,123,45,110,61,188,10,112,61,197,233,113,61,148,202,115,61,41,173,117,61,133,145,119,61,166,119,121,61,140,95,123,61,55,73,125,61,166,52,127,61,237,144,128,61,105,136,129,61,198,128,130,61,5,122,131,61,37,116,132,61,39,111,133,61,9,107,134,61,204,103,135,61,112,101,136,61,244,99,137,61,88,99,138,61,157,99,139,61,193,100,140,61,196,102,141,61,167,105,142,61,106,109,143,61,11,114,144,61,139,119,145,61,234,125,146,61,40,133,147,61,67,141,148,61,61,150,149,61,20,160,150,61,201,170,151,61,92,182,152,61,203,194,153,61,24,208,154,61,66,222,155,61,72,237,156,61,42,253,157,61,233,13,159,61,132,31,160,61,250,49,161,61,76,69,162,61,122,89,163,61,130,110,164,61,101,132,165,61,35,155,166,61,188,178,167,61,47,203,168,61,124,228,169,61,162,254,170,61,163,25,172,61,124,53,173,61,47,82,174,61,187,111,175,61,31,142,176,61,92,173,177,61,113,205,178,61,94,238,179,61,35,16,181,61,192,50,182,61,52,86,183,61,127,122,184,61,160,159,185,61,153,197,186,61,104,236,187,61,13,20,189,61,136,60,190,61,217,101,191,61,255,143,192,61,250,186,193,61,202,230,194,61,111,19,196,61,233,64,197,61,55,111,198,61,89,158,199,61,78,206,200,61,23,255,201,61,179,48,203,61,35,99,204,61,101,150,205,61,121,202,206,61,96,255,207,61,25,53,209,61,164,107,210,61,0,163,211,61,45,219,212,61,44,20,214,61,251,77,215,61,154,136,216,61,10,196,217,61,74,0,219,61,89,61,220,61,56,123,221,61,230,185,222,61,99,249,223,61,174,57,225,61,200,122,226,61,176,188,227,61,102,255,228,61,233,66,230,61,58,135,231,61,88,204,232,61,66,18,234,61,249,88,235,61,124,160,236,61,203,232,237,61,230,49,239,61,204,123,240,61,125,198,241,61,249,17,243,61,63,94,244,61,79,171,245,61,42,249,246,61,206,71,248,61,60,151,249,61,114,231,250,61,114,56,252,61,58,138,253,61,202,220,254,61,17,24,0,62,33,194,0,62,149,108,1,62,108,23,2,62,166,194,2,62,68,110,3,62,69,26,4,62,168,198,4,62,111,115,5,62,152,32,6,62,35,206,6,62,17,124,7,62,98,42,8,62,20,217,8,62,40,136,9,62,157,55,10,62,117,231,10,62,173,151,11,62,71,72,12,62,66,249,12,62,158,170,13,62,91,92,14,62,120,14,15,62,246,192,15,62,213,115,16,62,19,39,17,62,177,218,17,62,175,142,18,62,13,67,19,62,202,247,19,62,231,172,20,62,99,98,21,62,62,24,22,62,120,206,22,62,16,133,23,62,7,60,24,62,92,243,24,62,16,171,25,62,33,99,26,62,145,27,27,62,94,212,27,62,137,141,28,62,17,71,29,62,246,0,30,62,56,187,30,62,215,117,31,62,211,48,32,62,43,236,32,62,224,167,33,62,241,99,34,62,93,32,35,62,38,221,35,62,74,154,36,62,202,87,37,62,165,21,38,62,219,211,38,62,108,146,39,62,88,81,40,62,159,16,41,62,64,208,41,62,59,144,42,62,144,80,43,62,63,17,44,62,72,210,44,62,170,147,45,62,102,85,46,62,122,23,47,62,232,217,47,62,175,156,48,62,206,95,49,62,69,35,50,62,21,231,50,62,61,171,51,62,189,111,52,62,148,52,53,62,195,249,53,62,73,191,54,62,38,133,55,62,91,75,56,62,230,17,57,62,199,216,57,62,255,159,58,62,141,103,59,62,113,47,60,62,171,247,60,62,59,192,61,62,31,137,62,62,89,82,63,62,232,27,64,62,204,229,64,62,5,176,65,62,146,122,66,62,115,69,67,62,168,16,68,62,49,220,68,62,14,168,69,62,62,116,70,62,194,64,71,62,152,13,72,62,193,218,72,62,61,168,73,62,12,118,74,62,44,68,75,62,159,18,76,62,100,225,76,62,122,176,77,62,225,127,78,62,154,79,79,62,164,31,80,62,255,239,80,62,170,192,81,62,166,145,82,62,242,98,83,62,141,52,84,62,121,6,85,62,180,216,85,62,63,171,86,62,25,126,87,62,65,81,88,62,185,36,89,62,126,248,89,62,147,204,90,62,245,160,91,62,165,117,92,62,163,74,93,62,238,31,94,62,135,245,94,62,109,203,95,62,159,161,96,62,30,120,97,62,233,78,98,62,1,38,99,62,100,253,99,62,19,213,100,62,14,173,101,62,84,133,102,62,229,93,103,62,193,54,104,62,231,15,105,62,88,233,105,62,19,195,106,62,24,157,107,62,103,119,108,62,255,81,109,62,224,44,110,62,11,8,111,62,126,227,111,62,58,191,112,62,62,155,113,62,139,119,114,62,31,84,115,62,251,48,116,62,31,14,117,62,138,235,117,62,59,201,118,62,52,167,119,62,115,133,120,62,248,99,121,62,196,66,122,62,213,33,123,62,44,1,124,62,200,224,124,62,170,192,125,62,208,160,126,62,59,129,127,62,245,48,128,62,111,161,128,62,11,18,129,62,201,130,129,62,168,243,129,62,169,100,130,62,204,213,130,62,15,71,131,62,117,184,131,62,251,41,132,62,162,155,132,62,107,13,133,62,84,127,133,62,93,241,133,62,136,99,134,62,210,213,134,62,61,72,135,62,200,186,135,62,116,45,136,62,63,160,136,62,42,19,137,62,52,134,137,62,94,249,137,62,168,108,138,62,17,224,138,62,153,83,139,62,64,199,139,62,6,59,140,62,235,174,140,62,239,34,141,62,17,151,141,62,82,11,142,62,177,127,142,62,46,244,142,62,201,104,143,62,130,221,143,62,89,82,144,62,78,199,144,62,96,60,145,62,143,177,145,62,220,38,146,62,70,156,146,62,205,17,147,62,113,135,147,62,50,253,147,62,16,115,148,62,9,233,148,62,32,95,149,62,82,213,149,62,161,75,150,62,12,194,150,62,146,56,151,62,53,175,151,62,243,37,152,62,204,156,152,62,193,19,153,62,209,138,153,62,252,1,154,62,66,121,154,62,163,240,154,62,31,104,155,62,181,223,155,62,101,87,156,62,48,207,156,62,21,71,157,62,20,191,157,62,45,55,158,62,96,175,158,62,172,39,159,62,18,160,159,62,145,24,160,62,41,145,160,62,218,9,161,62,165,130,161,62,136,251,161,62,132,116,162,62,152,237,162,62,197,102,163,62,10,224,163,62,103,89,164,62,220,210,164,62,105,76,165,62,14,198,165,62,202,63,166,62,158,185,166,62,137,51,167,62,139,173,167,62,164,39,168,62,213,161,168,62,27,28,169,62,121,150,169,62,237,16,170,62,119,139,170,62,24,6,171,62,206,128,171,62,155,251,171,62,125,118,172,62,117,241,172,62,130,108,173,62,165,231,173,62,221,98,174,62,42,222,174,62,140,89,175,62,2,213,175,62,142,80,176,62,46,204,176,62,226,71,177,62,170,195,177,62,135,63,178,62,119,187,178,62,124,55,179,62,148,179,179,62,191,47,180,62,254,171,180,62,80,40,181,62,181,164,181,62,45,33,182,62,184,157,182,62,85,26,183,62,5,151,183,62,199,19,184,62,156,144,184,62,130,13,185,62,123,138,185,62,133,7,186,62,161,132,186,62,206,1,187,62,13,127,187,62,93,252,187,62,190,121,188,62,48,247,188,62,178,116,189,62,70,242,189,62,233,111,190,62,157,237,190,62,98,107,191,62,54,233,191,62,26,103,192,62,14,229,192,62,17,99,193,62,36,225,193,62,70,95,194,62,119,221,194,62,184,91,195,62,7,218,195,62,100,88,196,62,209,214,196,62,75,85,197,62,212,211,197,62,107,82,198,62,16,209,198,62,195,79,199,62,132,206,199,62,82,77,200,62,45,204,200,62,21,75,201,62,11,202,201,62,13,73,202,62,29,200,202,62,56,71,203,62,97,198,203,62,149,69,204,62,214,196,204,62,34,68,205,62,123,195,205,62,223,66,206,62,79,194,206,62,202,65,207,62,81,193,207,62,226,64,208,62,127,192,208,62,38,64,209,62,216,191,209,62,148,63,210,62,91,191,210,62,44,63,211,62,7,191,211,62,235,62,212,62,218,190,212,62,210,62,213,62,211,190,213,62,222,62,214,62,242,190,214,62,15,63,215,62,53,191,215,62,99,63,216,62,154,191,216,62,217,63,217,62,32,192,217,62,112,64,218,62,199,192,218,62,38,65,219,62,140,193,219,62,250,65,220,62,112,194,220,62,236,66,221,62,112,195,221,62,250,67,222,62,139,196,222,62,34,69,223,62,192,197,223,62,100,70,224,62,14,199,224,62,189,71,225,62,115,200,225,62,46,73,226,62,239,201,226,62,181,74,227,62,127,203,227,62,79,76,228,62,36,205,228,62,253,77,229,62,219,206,229,62,190,79,230,62,164,208,230,62,142,81,231,62,125,210,231,62,111,83,232,62,100,212,232,62,93,85,233,62,89,214,233,62,89,87,234,62,91,216,234,62,96,89,235,62,104,218,235,62,114,91,236,62,126,220,236,62,141,93,237,62,158,222,237,62,176,95,238,62,196,224,238,62,218,97,239,62,241,226,239,62,10,100,240,62,35,229,240,62,62,102,241,62,89,231,241,62,116,104,242,62,145,233,242,62,173,106,243,62,202,235,243,62,230,108,244,62,3,238,244,62,31,111,245,62,59,240,245,62,86,113,246,62,112,242,246,62,137,115,247,62,161,244,247,62,184,117,248,62,206,246,248,62,226,119,249,62,244,248,249,62,4,122,250,62,18,251,250,62,30,124,251,62,40,253,251,62,47,126,252,62,52,255,252,62,54,128,253,62,52,1,254,62,48,130,254,62,40,3,255,62,29,132,255,62,135,2,0,63,254,66,0,63,115,131,0,63,230,195,0,63,86,4,1,63,197,68,1,63,49,133,1,63,155,197,1,63,3,6,2,63,103,70,2,63,202,134,2,63,42,199,2,63,135,7,3,63,225,71,3,63,56,136,3,63,141,200,3,63,222,8,4,63,44,73,4,63,119,137,4,63,191,201,4,63,3,10,5,63,68,74,5,63,130,138,5,63,188,202,5,63,242,10,6,63,36,75,6,63,83,139,6,63,126,203,6,63,165,11,7,63,199,75,7,63,230,139,7,63,1,204,7,63,23,12,8,63,41,76,8,63,54,140,8,63,63,204,8,63,67,12,9,63,67,76,9,63,62,140,9,63,52,204,9,63,37,12,10,63,18,76,10,63,249,139,10,63,219,203,10,63,184,11,11,63,144,75,11,63,98,139,11,63,47,203,11,63,246,10,12,63,184,74,12,63,116,138,12,63,43,202,12,63,219,9,13,63,134,73,13,63,43,137,13,63,202,200,13,63,98,8,14,63,245,71,14,63,129,135,14,63,7,199,14,63,135,6,15,63,0,70,15,63,114,133,15,63,222,196,15,63,67,4,16,63,161,67,16,63,249,130,16,63,73,194,16,63,147,1,17,63,213,64,17,63,17,128,17,63,69,191,17,63,114,254,17,63,151,61,18,63,181,124,18,63,203,187,18,63,218,250,18,63,225,57,19,63,225,120,19,63,216,183,19,63,200,246,19,63,176,53,20,63,143,116,20,63,103,179,20,63,54,242,20,63,253,48,21,63,188,111,21,63,114,174,21,63,32,237,21,63,197,43,22,63,98,106,22,63,246,168,22,63,129,231,22,63,3,38,23,63,125,100,23,63,237,162,23,63,84,225,23,63,178,31,24,63,7,94,24,63,83,156,24,63,149,218,24,63,206,24,25,63,253,86,25,63,35,149,25,63,63,211,25,63,82,17,26,63,90,79,26,63,89,141,26,63,78,203,26,63,57,9,27,63,25,71,27,63,240,132,27,63,188,194,27,63,126,0,28,63,54,62,28,63,227,123,28,63,134,185,28,63,30,247,28,63,172,52,29,63,47,114,29,63,167,175,29,63,20,237,29,63,118,42,30,63,206,103,30,63,26,165,30,63,91,226,30,63,145,31,31,63,188,92,31,63,219,153,31,63,239,214,31,63,247,19,32,63,244,80,32,63,230,141,32,63,203,202,32,63,165,7,33,63,115,68,33,63,53,129,33,63,235,189,33,63,150,250,33,63,52,55,34,63,198,115,34,63,75,176,34,63,197,236,34,63,50,41,35,63,146,101,35,63,230,161,35,63,46,222,35,63,105,26,36,63,151,86,36,63,185,146,36,63,205,206,36,63,213,10,37,63,208,70,37,63,190,130,37,63,158,190,37,63,114,250,37,63,56,54,38,63,241,113,38,63,157,173,38,63,59,233,38,63,204,36,39,63,79,96,39,63,197,155,39,63,45,215,39,63,135,18,40,63,211,77,40,63,18,137,40,63,66,196,40,63,101,255,40,63,121,58,41,63,128,117,41,63,120,176,41,63,98,235,41,63,62,38,42,63,11,97,42,63,202,155,42,63,122,214,42,63,28,17,43,63,175,75,43,63,52,134,43,63,170,192,43,63,16,251,43,63,105,53,44,63,178,111,44,63,236,169,44,63,23,228,44,63,51,30,45,63,64,88,45,63,61,146,45,63,43,204,45,63,10,6,46,63,218,63,46,63,154,121,46,63,74,179,46,63,235,236,46,63,124,38,47,63,254,95,47,63,112,153,47,63,210,210,47,63,36,12,48,63,102,69,48,63,152,126,48,63,186,183,48,63,204,240,48,63,205,41,49,63,191,98,49,63,160,155,49,63,113,212,49,63,49,13,50,63,225,69,50,63,128,126,50,63,15,183,50,63,141,239,50,63,251,39,51,63,87,96,51,63,163,152,51,63,222,208,51,63,8,9,52,63,34,65,52,63,42,121,52,63,33,177,52,63,7,233,52,63,219,32,53,63,159,88,53,63,81,144,53,63,242,199,53,63,129,255,53,63,255,54,54,63,108,110,54,63,198,165,54,63,16,221,54,63,71,20,55,63,109,75,55,63,129,130,55,63,131,185,55,63,116,240,55,63,82,39,56,63,30,94,56,63,217,148,56,63,129,203,56,63,23,2,57,63,155,56,57,63,13,111,57,63,108,165,57,63,185,219,57,63,244,17,58,63,28,72,58,63,50,126,58,63,53,180,58,63,38,234,58,63,4,32,59,63,207,85,59,63,135,139,59,63,45,193,59,63,192,246,59,63,64,44,60,63,173,97,60,63,7,151,60,63,78,204,60,63,130,1,61,63,163,54,61,63,177,107,61,63,171,160,61,63,146,213,61,63,102,10,62,63,39,63,62,63,212,115,62,63,110,168,62,63,244,220,62,63,103,17,63,63,198,69,63,63,17,122,63,63,73,174,63,63,109,226,63,63,126,22,64,63,122,74,64,63,99,126,64,63,56,178,64,63,248,229,64,63,165,25,65,63,62,77,65,63,195,128,65,63,52,180,65,63,144,231,65,63,216,26,66,63,13,78,66,63,44,129,66,63,56,180,66,63,47,231,66,63,18,26,67,63,224,76,67,63,154,127,67,63,64,178,67,63,208,228,67,63,77,23,68,63,180,73,68,63,7,124,68,63,69,174,68,63,111,224,68,63,131,18,69,63,131,68,69,63,110,118,69,63,68,168,69,63,5,218,69,63,177,11,70,63,72,61,70,63,202,110,70,63,55,160,70,63,143,209,70,63,210,2,71,63,255,51,71,63,23,101,71,63,26,150,71,63,8,199,71,63,224,247,71,63,163,40,72,63,81,89,72,63,233,137,72,63,107,186,72,63,216,234,72,63,48,27,73,63,114,75,73,63,158,123,73,63,181,171,73,63,181,219,73,63,161,11,74,63,118,59,74,63,54,107,74,63,224,154,74,63,116,202,74,63,242,249,74,63,90,41,75,63,173,88,75,63,233,135,75,63,15,183,75,63,32,230,75,63,26,21,76,63,254,67,76,63,204,114,76,63,132,161,76,63,38,208,76,63,177,254,76,63,38,45,77,63,133,91,77,63,206,137,77,63,0,184,77,63,28,230,77,63,34,20,78,63,17,66,78,63,234,111,78,63,172,157,78,63,88,203,78,63,238,248,78,63,108,38,79,63,213,83,79,63,38,129,79,63,97,174,79,63,134,219,79,63,147,8,80,63,138,53,80,63,107,98,80,63,52,143,80,63,231,187,80,63,131,232,80,63,8,21,81,63,119,65,81,63,206,109,81,63,15,154,81,63,57,198,81,63,76,242,81,63,71,30,82,63,44,74,82,63,250,117,82,63,177,161,82,63,81,205,82,63,218,248,82,63,76,36,83,63,166,79,83,63,234,122,83,63,22,166,83,63,44,209,83,63,42,252,83,63,17,39,84,63,224,81,84,63,153,124,84,63,58,167,84,63,196,209,84,63,54,252,84,63,146,38,85,63,214,80,85,63,2,123,85,63,24,165,85,63,22,207,85,63,252,248,85,63,204,34,86,63,131,76,86,63,36,118,86,63,172,159,86,63,30,201,86,63,120,242,86,63,186,27,87,63,229,68,87,63,248,109,87,63,244,150,87,63,216,191,87,63,165,232,87,63,90,17,88,63,248,57,88,63,126,98,88,63,236,138,88,63,67,179,88,63,130,219,88,63,169,3,89,63,185,43,89,63,177,83,89,63,145,123,89,63,90,163,89,63,11,203,89,63,164,242,89,63,37,26,90,63,143,65,90,63,225,104,90,63,27,144,90,63,62,183,90,63,72,222,90,63,59,5,91,63,22,44,91,63,217,82,91,63,133,121,91,63,24,160,91,63,148,198,91,63,248,236,91,63,68,19,92,63,120,57,92,63,149,95,92,63,153,133,92,63,134,171,92,63,91,209,92,63,24,247,92,63,189,28,93,63,74,66,93,63,191,103,93,63,28,141,93,63,98,178,93,63,143,215,93,63,165,252,93,63,162,33,94,63,136,70,94,63,86,107,94,63,11,144,94,63,169,180,94,63,47,217,94,63,157,253,94,63,243,33,95,63,49,70,95,63,88,106,95,63,102,142,95,63,92,178,95,63,59,214,95,63,1,250,95,63,175,29,96,63,70,65,96,63,196,100,96,63,43,136,96,63,122,171,96,63,176,206,96,63,207,241,96,63,214,20,97,63,197,55,97,63,155,90,97,63,90,125,97,63,1,160,97,63,144,194,97,63,8,229,97,63,103,7,98,63,174,41,98,63,221,75,98,63,245,109,98,63,244,143,98,63,220,177,98,63,171,211,98,63,99,245,98,63,3,23,99,63,139,56,99,63,251,89,99,63,83,123,99,63,147,156,99,63,188,189,99,63,204,222,99,63,197,255,99,63,166,32,100,63,110,65,100,63,32,98,100,63,185,130,100,63,58,163,100,63,164,195,100,63,245,227,100,63,47,4,101,63,82,36,101,63,92,68,101,63,78,100,101,63,41,132,101,63,236,163,101,63,151,195,101,63,43,227,101,63,167,2,102,63,11,34,102,63,87,65,102,63,139,96,102,63,168,127,102,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+71680);
/* memory initializer */ allocate([174,158,102,63,155,189,102,63,113,220,102,63,47,251,102,63,214,25,103,63,101,56,103,63,220,86,103,63,59,117,103,63,132,147,103,63,180,177,103,63,205,207,103,63,206,237,103,63,184,11,104,63,138,41,104,63,69,71,104,63,233,100,104,63,116,130,104,63,233,159,104,63,69,189,104,63,139,218,104,63,185,247,104,63,207,20,105,63,207,49,105,63,182,78,105,63,135,107,105,63,64,136,105,63,225,164,105,63,108,193,105,63,223,221,105,63,59,250,105,63,127,22,106,63,172,50,106,63,195,78,106,63,193,106,106,63,169,134,106,63,121,162,106,63,51,190,106,63,213,217,106,63,96,245,106,63,212,16,107,63,48,44,107,63,118,71,107,63,165,98,107,63,188,125,107,63,189,152,107,63,167,179,107,63,121,206,107,63,53,233,107,63,218,3,108,63,104,30,108,63,223,56,108,63,63,83,108,63,136,109,108,63,187,135,108,63,214,161,108,63,219,187,108,63,201,213,108,63,161,239,108,63,97,9,109,63,11,35,109,63,159,60,109,63,27,86,109,63,129,111,109,63,209,136,109,63,9,162,109,63,44,187,109,63,56,212,109,63,45,237,109,63,12,6,110,63,212,30,110,63,134,55,110,63,33,80,110,63,166,104,110,63,21,129,110,63,110,153,110,63,176,177,110,63,220,201,110,63,241,225,110,63,241,249,110,63,218,17,111,63,173,41,111,63,106,65,111,63,16,89,111,63,161,112,111,63,28,136,111,63,128,159,111,63,207,182,111,63,7,206,111,63,42,229,111,63,54,252,111,63,45,19,112,63,14,42,112,63,217,64,112,63,142,87,112,63,46,110,112,63,184,132,112,63,43,155,112,63,138,177,112,63,210,199,112,63,5,222,112,63,35,244,112,63,42,10,113,63,29,32,113,63,249,53,113,63,193,75,113,63,114,97,113,63,15,119,113,63,150,140,113,63,7,162,113,63,99,183,113,63,170,204,113,63,220,225,113,63,249,246,113,63,0,12,114,63,242,32,114,63,207,53,114,63,151,74,114,63,73,95,114,63,231,115,114,63,112,136,114,63,227,156,114,63,66,177,114,63,140,197,114,63,193,217,114,63,225,237,114,63,236,1,115,63,227,21,115,63,197,41,115,63,146,61,115,63,74,81,115,63,238,100,115,63,125,120,115,63,248,139,115,63,94,159,115,63,175,178,115,63,236,197,115,63,21,217,115,63,41,236,115,63,41,255,115,63,21,18,116,63,236,36,116,63,175,55,116,63,94,74,116,63,248,92,116,63,127,111,116,63,241,129,116,63,80,148,116,63,154,166,116,63,208,184,116,63,242,202,116,63,1,221,116,63,251,238,116,63,226,0,117,63,181,18,117,63,116,36,117,63,31,54,117,63,183,71,117,63,59,89,117,63,171,106,117,63,8,124,117,63,81,141,117,63,135,158,117,63,169,175,117,63,184,192,117,63,179,209,117,63,155,226,117,63,112,243,117,63,50,4,118,63,224,20,118,63,123,37,118,63,3,54,118,63,120,70,118,63,217,86,118,63,40,103,118,63,100,119,118,63,140,135,118,63,162,151,118,63,165,167,118,63,149,183,118,63,114,199,118,63,61,215,118,63,245,230,118,63,154,246,118,63,44,6,119,63,172,21,119,63,26,37,119,63,117,52,119,63,189,67,119,63,243,82,119,63,22,98,119,63,40,113,119,63,39,128,119,63,19,143,119,63,238,157,119,63,182,172,119,63,108,187,119,63,16,202,119,63,162,216,119,63,34,231,119,63,144,245,119,63,236,3,120,63,55,18,120,63,111,32,120,63,150,46,120,63,170,60,120,63,174,74,120,63,159,88,120,63,127,102,120,63,77,116,120,63,10,130,120,63,181,143,120,63,79,157,120,63,215,170,120,63,78,184,120,63,180,197,120,63,8,211,120,63,76,224,120,63,126,237,120,63,158,250,120,63,174,7,121,63,173,20,121,63,155,33,121,63,119,46,121,63,67,59,121,63,254,71,121,63,168,84,121,63,66,97,121,63,202,109,121,63,66,122,121,63,169,134,121,63,0,147,121,63,70,159,121,63,124,171,121,63,161,183,121,63,181,195,121,63,186,207,121,63,173,219,121,63,145,231,121,63,100,243,121,63,40,255,121,63,219,10,122,63,126,22,122,63,16,34,122,63,147,45,122,63,6,57,122,63,105,68,122,63,188,79,122,63,255,90,122,63,51,102,122,63,86,113,122,63,106,124,122,63,111,135,122,63,99,146,122,63,72,157,122,63,30,168,122,63,228,178,122,63,155,189,122,63,66,200,122,63,218,210,122,63,99,221,122,63,221,231,122,63,71,242,122,63,162,252,122,63,238,6,123,63,43,17,123,63,89,27,123,63,120,37,123,63,137,47,123,63,138,57,123,63,124,67,123,63,96,77,123,63,53,87,123,63,252,96,123,63,179,106,123,63,92,116,123,63,247,125,123,63,131,135,123,63,1,145,123,63,112,154,123,63,209,163,123,63,36,173,123,63,104,182,123,63,158,191,123,63,198,200,123,63,224,209,123,63,236,218,123,63,234,227,123,63,218,236,123,63,188,245,123,63,144,254,123,63,86,7,124,63,14,16,124,63,185,24,124,63,86,33,124,63,230,41,124,63,104,50,124,63,220,58,124,63,67,67,124,63,156,75,124,63,232,83,124,63,39,92,124,63,88,100,124,63,124,108,124,63,147,116,124,63,157,124,124,63,153,132,124,63,137,140,124,63,107,148,124,63,65,156,124,63,9,164,124,63,197,171,124,63,116,179,124,63,22,187,124,63,172,194,124,63,52,202,124,63,176,209,124,63,32,217,124,63,131,224,124,63,217,231,124,63,35,239,124,63,97,246,124,63,146,253,124,63,183,4,125,63,208,11,125,63,221,18,125,63,221,25,125,63,209,32,125,63,185,39,125,63,150,46,125,63,102,53,125,63,42,60,125,63,227,66,125,63,143,73,125,63,48,80,125,63,197,86,125,63,78,93,125,63,204,99,125,63,62,106,125,63,165,112,125,63,0,119,125,63,80,125,125,63,148,131,125,63,205,137,125,63,251,143,125,63,29,150,125,63,52,156,125,63,64,162,125,63,65,168,125,63,55,174,125,63,34,180,125,63,2,186,125,63,215,191,125,63,161,197,125,63,96,203,125,63,21,209,125,63,190,214,125,63,93,220,125,63,242,225,125,63,124,231,125,63,251,236,125,63,112,242,125,63,218,247,125,63,58,253,125,63,143,2,126,63,219,7,126,63,28,13,126,63,82,18,126,63,127,23,126,63,161,28,126,63,186,33,126,63,200,38,126,63,204,43,126,63,199,48,126,63,183,53,126,63,158,58,126,63,123,63,126,63,78,68,126,63,23,73,126,63,215,77,126,63,141,82,126,63,58,87,126,63,221,91,126,63,118,96,126,63,6,101,126,63,141,105,126,63,10,110,126,63,126,114,126,63,233,118,126,63,75,123,126,63,164,127,126,63,243,131,126,63,57,136,126,63,119,140,126,63,171,144,126,63,214,148,126,63,249,152,126,63,18,157,126,63,35,161,126,63,44,165,126,63,43,169,126,63,34,173,126,63,16,177,126,63,246,180,126,63,211,184,126,63,167,188,126,63,115,192,126,63,55,196,126,63,243,199,126,63,166,203,126,63,81,207,126,63,243,210,126,63,142,214,126,63,32,218,126,63,171,221,126,63,45,225,126,63,167,228,126,63,26,232,126,63,132,235,126,63,231,238,126,63,66,242,126,63,149,245,126,63,224,248,126,63,36,252,126,63,96,255,126,63,148,2,127,63,193,5,127,63,230,8,127,63,4,12,127,63,27,15,127,63,42,18,127,63,50,21,127,63,50,24,127,63,43,27,127,63,29,30,127,63,8,33,127,63,236,35,127,63,201,38,127,63,158,41,127,63,109,44,127,63,53,47,127,63,246,49,127,63,175,52,127,63,99,55,127,63,15,58,127,63,181,60,127,63,83,63,127,63,236,65,127,63,125,68,127,63,8,71,127,63,141,73,127,63,11,76,127,63,131,78,127,63,244,80,127,63,95,83,127,63,195,85,127,63,33,88,127,63,121,90,127,63,203,92,127,63,23,95,127,63,92,97,127,63,155,99,127,63,213,101,127,63,8,104,127,63,54,106,127,63,93,108,127,63,127,110,127,63,155,112,127,63,177,114,127,63,193,116,127,63,203,118,127,63,208,120,127,63,207,122,127,63,201,124,127,63,189,126,127,63,171,128,127,63,148,130,127,63,120,132,127,63,86,134,127,63,47,136,127,63,2,138,127,63,209,139,127,63,153,141,127,63,93,143,127,63,28,145,127,63,213,146,127,63,137,148,127,63,57,150,127,63,227,151,127,63,136,153,127,63,40,155,127,63,196,156,127,63,90,158,127,63,236,159,127,63,121,161,127,63,1,163,127,63,132,164,127,63,3,166,127,63,125,167,127,63,242,168,127,63,99,170,127,63,207,171,127,63,55,173,127,63,154,174,127,63,249,175,127,63,84,177,127,63,170,178,127,63,251,179,127,63,73,181,127,63,146,182,127,63,215,183,127,63,24,185,127,63,85,186,127,63,141,187,127,63,193,188,127,63,242,189,127,63,30,191,127,63,71,192,127,63,107,193,127,63,140,194,127,63,168,195,127,63,193,196,127,63,214,197,127,63,231,198,127,63,245,199,127,63,255,200,127,63,5,202,127,63,7,203,127,63,6,204,127,63,1,205,127,63,249,205,127,63,237,206,127,63,222,207,127,63,203,208,127,63,181,209,127,63,156,210,127,63,127,211,127,63,95,212,127,63,59,213,127,63,20,214,127,63,234,214,127,63,189,215,127,63,141,216,127,63,90,217,127,63,35,218,127,63,233,218,127,63,173,219,127,63,109,220,127,63,43,221,127,63,229,221,127,63,156,222,127,63,81,223,127,63,3,224,127,63,178,224,127,63,94,225,127,63,7,226,127,63,174,226,127,63,82,227,127,63,243,227,127,63,146,228,127,63,46,229,127,63,199,229,127,63,94,230,127,63,242,230,127,63,132,231,127,63,19,232,127,63,160,232,127,63,42,233,127,63,178,233,127,63,56,234,127,63,187,234,127,63,60,235,127,63,187,235,127,63,55,236,127,63,177,236,127,63,41,237,127,63,159,237,127,63,18,238,127,63,132,238,127,63,243,238,127,63,96,239,127,63,204,239,127,63,53,240,127,63,156,240,127,63,1,241,127,63,101,241,127,63,198,241,127,63,37,242,127,63,131,242,127,63,222,242,127,63,56,243,127,63,144,243,127,63,231,243,127,63,59,244,127,63,142,244,127,63,223,244,127,63,46,245,127,63,124,245,127,63,200,245,127,63,19,246,127,63,91,246,127,63,163,246,127,63,233,246,127,63,45,247,127,63,111,247,127,63,177,247,127,63,240,247,127,63,47,248,127,63,108,248,127,63,167,248,127,63,225,248,127,63,26,249,127,63,82,249,127,63,136,249,127,63,188,249,127,63,240,249,127,63,34,250,127,63,83,250,127,63,131,250,127,63,178,250,127,63,224,250,127,63,12,251,127,63,55,251,127,63,97,251,127,63,138,251,127,63,178,251,127,63,217,251,127,63,255,251,127,63,36,252,127,63,72,252,127,63,107,252,127,63,141,252,127,63,173,252,127,63,205,252,127,63,237,252,127,63,11,253,127,63,40,253,127,63,69,253,127,63,96,253,127,63,123,253,127,63,149,253,127,63,174,253,127,63,199,253,127,63,222,253,127,63,245,253,127,63,12,254,127,63,33,254,127,63,54,254,127,63,74,254,127,63,93,254,127,63,112,254,127,63,130,254,127,63,148,254,127,63,165,254,127,63,181,254,127,63,197,254,127,63,212,254,127,63,227,254,127,63,241,254,127,63,254,254,127,63,11,255,127,63,24,255,127,63,36,255,127,63,47,255,127,63,59,255,127,63,69,255,127,63,79,255,127,63,89,255,127,63,99,255,127,63,108,255,127,63,116,255,127,63,124,255,127,63,132,255,127,63,140,255,127,63,147,255,127,63,154,255,127,63,160,255,127,63,166,255,127,63,172,255,127,63,178,255,127,63,183,255,127,63,188,255,127,63,193,255,127,63,197,255,127,63,202,255,127,63,206,255,127,63,209,255,127,63,213,255,127,63,216,255,127,63,220,255,127,63,223,255,127,63,225,255,127,63,228,255,127,63,230,255,127,63,233,255,127,63,235,255,127,63,237,255,127,63,239,255,127,63,240,255,127,63,242,255,127,63,243,255,127,63,245,255,127,63,246,255,127,63,247,255,127,63,248,255,127,63,249,255,127,63,250,255,127,63,251,255,127,63,251,255,127,63,252,255,127,63,252,255,127,63,253,255,127,63,253,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,5,12,120,56,50,131,11,58,118,186,193,58,226,203,61,59,38,207,156,59,139,32,234,59,245,102,35,60,63,100,89,60,184,127,139,60,59,23,174,60,239,114,212,60,96,140,254,60,45,46,22,61,114,237,46,61,155,127,73,61,220,223,101,61,123,4,130,61,159,250,145,61,71,207,162,61,38,127,180,61,173,6,199,61,16,98,218,61,63,141,238,61,244,193,1,62,185,160,12,62,128,224,23,62,182,126,35,62,166,120,47,62,116,203,59,62,34,116,72,62,141,111,85,62,107,186,98,62,83,81,112,62,180,48,126,62,110,42,134,62,252,92,141,62,9,174,148,62,138,27,156,62,100,163,163,62,112,67,171,62,119,249,178,62,54,195,186,62,93,158,194,62,147,136,202,62,118,127,210,62,154,128,218,62,142,137,226,62,217,151,234,62,2,169,242,62,139,186,250,62,251,100,1,63,99,106,5,63,65,108,9,63,89,105,13,63,116,96,17,63,94,80,21,63,231,55,25,63,231,21,29,63,58,233,32,63,197,176,36,63,116,107,40,63,62,24,44,63,35,182,47,63,43,68,51,63,109,193,54,63,10,45,58,63,48,134,61,63,26,204,64,63,17,254,67,63,107,27,71,63,142,35,74,63,238,21,77,63,15,242,79,63,132,183,82,63,239,101,85,63,3,253,87,63,129,124,90,63,60,228,92,63,21,52,95,63,254,107,97,63,246,139,99,63,14,148,101,63,98,132,103,63,33,93,105,63,133,30,107,63,213,200,108,63,103,92,110,63,155,217,111,63,224,64,113,63,172,146,114,63,131,207,115,63,241,247,116,63,139,12,118,63,239,13,119,63,193,252,119,63,172,217,120,63,99,165,121,63,155,96,122,63,15,12,123,63,124,168,123,63,163,54,124,63,71,183,124,63,41,43,125,63,13,147,125,63,183,239,125,63,229,65,126,63,89,138,126,63,205,201,126,63,251,0,127,63,150,48,127,63,78,89,127,63,205,123,127,63,182,152,127,63,167,176,127,63,53,196,127,63,239,211,127,63,91,224,127,63,245,233,127,63,51,241,127,63,127,246,127,63,59,250,127,63,190,252,127,63,84,254,127,63,64,255,127,63,186,255,127,63,238,255,127,63,254,255,127,63,0,0,128,63,171,15,120,53,24,135,11,55,225,201,193,55,107,233,61,56,128,247,156,56,187,122,234,56,24,191,35,57,213,0,90,57,56,1,140,57,229,225,174,57,88,162,213,57,60,33,0,58,24,97,23,58,175,144,48,58,243,175,75,58,212,190,104,58,159,222,131,58,143,85,148,58,48,196,165,58,119,42,184,58,90,136,203,58,204,221,223,58,191,42,245,58,148,183,5,59,124,85,17,59,16,111,29,59,73,4,42,59,31,21,55,59,138,161,68,59,129,169,82,59,252,44,97,59,241,43,112,59,88,166,127,59,19,206,135,59,169,6,144,59,233,124,152,59,204,48,161,59,79,34,170,59,106,81,179,59,26,190,188,59,86,104,198,59,26,80,208,59,95,117,218,59,31,216,228,59,83,120,239,59,244,85,250,59,126,184,2,60,177,100,8,60,145,47,14,60,25,25,20,60,70,33,26,60,19,72,32,60,126,141,38,60,129,241,44,60,25,116,51,60,65,21,58,60,246,212,64,60,50,179,71,60,243,175,78,60,50,203,85,60,235,4,93,60,26,93,100,60,186,211,107,60,198,104,115,60,58,28,123,60,7,119,129,60,33,111,133,60,102,118,137,60,212,140,141,60,105,178,145,60,33,231,149,60,251,42,154,60,243,125,158,60,6,224,162,60,50,81,167,60,115,209,171,60,199,96,176,60,43,255,180,60,154,172,185,60,19,105,190,60,146,52,195,60,20,15,200,60,149,248,204,60,19,241,209,60,137,248,214,60,245,14,220,60,83,52,225,60,160,104,230,60,215,171,235,60,246,253,240,60,249,94,246,60,220,206,251,60,205,166,0,61,153,109,3,61,207,59,6,61,109,17,9,61,114,238,11,61,220,210,14,61,167,190,17,61,211,177,20,61,94,172,23,61,68,174,26,61,133,183,29,61,30,200,32,61,12,224,35,61,78,255,38,61,225,37,42,61,196,83,45,61,243,136,48,61,109,197,51,61,47,9,55,61,55,84,58,61,130,166,61,61,15,0,65,61,218,96,68,61,226,200,71,61,35,56,75,61,156,174,78,61,73,44,82,61,40,177,85,61,55,61,89,61,115,208,92,61,217,106,96,61,103,12,100,61,25,181,103,61,238,100,107,61,227,27,111,61,244,217,114,61,30,159,118,61,96,107,122,61,182,62,126,61,143,12,129,61,73,253,130,61,138,241,132,61,79,233,134,61,150,228,136,61,94,227,138,61,167,229,140,61,109,235,142,61,175,244,144,61,109,1,147,61,164,17,149,61,83,37,151,61,120,60,153,61,17,87,155,61,30,117,157,61,155,150,159,61,136,187,161,61,226,227,163,61,169,15,166,61,218,62,168,61,116,113,170,61,116,167,172,61,218,224,174,61,162,29,177,61,205,93,179,61,87,161,181,61,62,232,183,61,130,50,186,61,32,128,188,61,22,209,190,61,98,37,193,61,2,125,195,61,245,215,197,61,57,54,200,61,203,151,202,61,169,252,204,61,211,100,207,61,68,208,209,61,252,62,212,61,249,176,214,61,56,38,217,61,184,158,219,61,117,26,222,61,111,153,224,61,163,27,227,61,14,161,229,61,175,41,232,61,132,181,234,61,138,68,237,61,191,214,239,61,33,108,242,61,174,4,245,61,99,160,247,61,62,63,250,61,61,225,252,61,93,134,255,61,78,23,1,62,252,108,2,62,56,196,3,62,255,28,5,62,81,119,6,62,45,211,7,62,145,48,9,62,125,143,10,62,238,239,11,62,228,81,13,62,94,181,14,62,89,26,16,62,214,128,17,62,210,232,18,62,77,82,20,62,69,189,21,62,184,41,23,62,166,151,24,62,13,7,26,62,236,119,27,62,65,234,28,62,11,94,30,62,73,211,31,62,250,73,33,62,28,194,34,62,173,59,36,62,172,182,37,62,24,51,39,62,240,176,40,62,50,48,42,62,220,176,43,62,238,50,45,62,101,182,46,62,64,59,48,62,126,193,49,62,30,73,51,62,29,210,52,62,123,92,54,62,54,232,55,62,76,117,57,62,187,3,59,62,131,147,60,62,162,36,62,62,22,183,63,62,222,74,65,62,248,223,66,62,98,118,68,62,28,14,70,62,35,167,71,62,117,65,73,62,18,221,74,62,247,121,76,62,35,24,78,62,149,183,79,62,74,88,81,62,66,250,82,62,121,157,84,62,240,65,86,62,163,231,87,62,146,142,89,62,186,54,91,62,26,224,92,62,177,138,94,62,124,54,96,62,122,227,97,62,169,145,99,62,7,65,101,62,147,241,102,62,75,163,104,62,44,86,106,62,54,10,108,62,102,191,109,62,187,117,111,62,51,45,113,62,204,229,114,62,132,159,116,62,90,90,118,62,75,22,120,62,85,211,121,62,120,145,123,62,176,80,125,62,253,16,127,62,46,105,128,62,101,74,129,62,36,44,130,62,105,14,131,62,52,241,131,62,130,212,132,62,84,184,133,62,169,156,134,62,127,129,135,62,213,102,136,62,171,76,137,62,255,50,138,62,209,25,139,62,32,1,140,62,233,232,140,62,46,209,141,62,236,185,142,62,34,163,143,62,208,140,144,62,244,118,145,62,142,97,146,62,156,76,147,62,29,56,148,62,17,36,149,62,118,16,150,62,76,253,150,62,144,234,151,62,67,216,152,62,99,198,153,62,239,180,154,62,230,163,155,62,71,147,156,62,17,131,157,62,67,115,158,62,219,99,159,62,218,84,160,62,60,70,161,62,3,56,162,62,43,42,163,62,181,28,164,62,160,15,165,62,233,2,166,62,145,246,166,62,149,234,167,62,245,222,168,62,176,211,169,62,197,200,170,62,50,190,171,62,246,179,172,62,17,170,173,62,129,160,174,62,69,151,175,62,91,142,176,62,196,133,177,62,125,125,178,62,133,117,179,62,220,109,180,62,128,102,181,62,112,95,182,62,171,88,183,62,47,82,184,62,252,75,185,62,17,70,186,62,108,64,187,62,11,59,188,62,239,53,189,62,22,49,190,62,126,44,191,62,38,40,192,62,13,36,193,62,51,32,194,62,150,28,195,62,52,25,196,62,12,22,197,62,30,19,198,62,104,16,199,62,233,13,200,62,159,11,201,62,138,9,202,62,169,7,203,62,249,5,204,62,123,4,205,62,44,3,206,62,11,2,207,62,24,1,208,62,81,0,209,62,181,255,209,62,66,255,210,62,248,254,211,62,213,254,212,62,216,254,213,62,255,254,214,62,75,255,215,62,184,255,216,62,71,0,218,62,245,0,219,62,195,1,220,62,173,2,221,62,180,3,222,62,214,4,223,62,17,6,224,62,101,7,225,62,208,8,226,62,81,10,227,62,231,11,228,62,144,13,229,62,76,15,230,62,25,17,231,62,245,18,232,62,224,20,233,62,217,22,234,62,221,24,235,62,236,26,236,62,5,29,237,62,39,31,238,62,79,33,239,62,125,35,240,62,176,37,241,62,230,39,242,62,31,42,243,62,88,44,244,62,145,46,245,62,200,48,246,62,253,50,247,62,45,53,248,62,88,55,249,62,124,57,250,62,153,59,251,62,172,61,252,62,181,63,253,62,179,65,254,62,163,67,255,62,195,34,0,63,173,163,0,63,142,36,1,63,102,165,1,63,53,38,2,63,250,166,2,63,180,39,3,63,99,168,3,63,5,41,4,63,155,169,4,63,36,42,5,63,159,170,5,63,12,43,6,63,105,171,6,63,183,43,7,63,244,171,7,63,32,44,8,63,59,172,8,63,68,44,9,63,58,172,9,63,28,44,10,63,235,171,10,63,164,43,11,63,73,171,11,63,216,42,12,63,80,170,12,63,177,41,13,63,251,168,13,63,44,40,14,63,69,167,14,63,68,38,15,63,41,165,15,63,243,35,16,63,162,162,16,63,53,33,17,63,172,159,17,63,5,30,18,63,65,156,18,63,95,26,19,63,94,152,19,63,61,22,20,63,252,147,20,63,155,17,21,63,24,143,21,63,116,12,22,63,173,137,22,63,195,6,23,63,182,131,23,63,133,0,24,63,46,125,24,63,179,249,24,63,18,118,25,63,74,242,25,63,91,110,26,63,69,234,26,63,6,102,27,63,159,225,27,63,14,93,28,63,84,216,28,63,111,83,29,63,95,206,29,63,36,73,30,63,188,195,30,63,40,62,31,63,102,184,31,63,119,50,32,63,90,172,32,63,14,38,33,63,146,159,33,63,230,24,34,63,10,146,34,63,253,10,35,63,190,131,35,63,77,252,35,63,169,116,36,63,211,236,36,63,200,100,37,63,138,220,37,63,22,84,38,63,110,203,38,63,143,66,39,63,122,185,39,63,47,48,40,63,172,166,40,63,241,28,41,63,254,146,41,63,210,8,42,63,108,126,42,63,205,243,42,63,243,104,43,63,223,221,43,63,143,82,44,63,3,199,44,63,59,59,45,63,54,175,45,63,244,34,46,63,116,150,46,63,182,9,47,63,185,124,47,63,125,239,47,63,1,98,48,63,69,212,48,63,72,70,49,63,10,184,49,63,139,41,50,63,202,154,50,63,198,11,51,63,127,124,51,63,246,236,51,63,40,93,52,63,22,205,52,63,191,60,53,63,36,172,53,63,66,27,54,63,27,138,54,63,174,248,54,63,249,102,55,63,254,212,55,63,187,66,56,63,47,176,56,63,91,29,57,63,63,138,57,63,217,246,57,63,41,99,58,63,48,207,58,63,236,58,59,63,93,166,59,63,130,17,60,63,93,124,60,63,235,230,60,63,44,81,61,63,33,187,61,63,201,36,62,63,35,142,62,63,48,247,62,63,238,95,63,63,94,200,63,63,126,48,64,63,80,152,64,63,209,255,64,63,3,103,65,63,228,205,65,63,117,52,66,63,181,154,66,63,163,0,67,63,64,102,67,63,139,203,67,63,131,48,68,63,41,149,68,63,124,249,68,63,123,93,69,63,39,193,69,63,127,36,70,63,132,135,70,63,51,234,70,63,142,76,71,63,148,174,71,63,68,16,72,63,159,113,72,63,164,210,72,63,83,51,73,63,172,147,73,63,174,243,73,63,89,83,74,63,173,178,74,63,169,17,75,63,77,112,75,63,154,206,75,63,143,44,76,63,43,138,76,63,110,231,76,63,89,68,77,63,234,160,77,63,34,253,77,63,0,89,78,63,133,180,78,63,176,15,79,63,128,106,79,63,246,196,79,63,18,31,80,63,210,120,80,63,56,210,80,63,66,43,81,63,242,131,81,63,69,220,81,63,61,52,82,63,217,139,82,63,24,227,82,63,252,57,83,63,131,144,83,63,174,230,83,63,123,60,84,63,236,145,84,63,0,231,84,63,183,59,85,63,16,144,85,63,12,228,85,63,170,55,86,63,235,138,86,63,206,221,86,63,83,48,87,63,121,130,87,63,66,212,87,63,172,37,88,63,184,118,88,63,101,199,88,63,180,23,89,63,164,103,89,63,53,183,89,63,104,6,90,63,59,85,90,63,175,163,90,63,197,241,90,63,123,63,91,63,210,140,91,63,201,217,91,63,97,38,92,63,154,114,92,63,115,190,92,63,237,9,93,63,7,85,93,63,194,159,93,63,29,234,93,63,24,52,94,63,179,125,94,63,239,198,94,63,203,15,95,63,72,88,95,63,100,160,95,63,33,232,95,63,126,47,96,63,123,118,96,63,24,189,96,63,85,3,97,63,51,73,97,63,177,142,97,63,207,211,97,63,141,24,98,63,236,92,98,63,235,160,98,63,138,228,98,63,202,39,99,63,170,106,99,63,42,173,99,63,75,239,99,63,13,49,100,63,111,114,100,63,114,179,100,63,21,244,100,63,90,52,101,63,63,116,101,63,197,179,101,63,236,242,101,63,180,49,102,63,29,112,102,63,39,174,102,63,211,235,102,63,32,41,103,63,15,102,103,63,159,162,103,63,209,222,103,63,164,26,104,63,26,86,104,63,49,145,104,63,235,203,104,63,71,6,105,63,69,64,105,63,230,121,105,63,42,179,105,63,16,236,105,63,153,36,106,63,197,92,106,63,148,148,106,63,7,204,106,63,29,3,107,63,214,57,107,63,52,112,107,63,53,166,107,63,218,219,107,63,36,17,108,63,18,70,108,63,164,122,108,63,220,174,108,63,184,226,108,63,57,22,109,63,96,73,109,63,44,124,109,63,157,174,109,63,181,224,109,63,115,18,110,63,214,67,110,63,225,116,110,63,146,165,110,63,233,213,110,63,232,5,111,63,142,53,111,63,219,100,111,63,209,147,111,63,110,194,111,63,179,240,111,63,160,30,112,63,54,76,112,63,117,121,112,63,93,166,112,63,239,210,112,63,41,255,112,63,14,43,113,63,156,86,113,63,213,129,113,63,184,172,113,63,70,215,113,63,127,1,114,63,99,43,114,63,243,84,114,63,46,126,114,63,21,167,114,63,169,207,114,63,233,247,114,63,214,31,115,63,113,71,115,63,184,110,115,63,173,149,115,63,80,188,115,63,162,226,115,63,161,8,116,63,80,46,116,63,174,83,116,63,187,120,116,63,119,157,116,63,228,193,116,63,1,230,116,63,206,9,117,63,76,45,117,63,123,80,117,63,92,115,117,63,238,149,117,63,51,184,117,63,42,218,117,63,211,251,117,63,48,29,118,63,64,62,118,63,3,95,118,63,122,127,118,63,166,159,118,63,134,191,118,63,27,223,118,63,101,254,118,63,101,29,119,63,27,60,119,63,135,90,119,63,169,120,119,63,131,150,119,63,19,180,119,63,91,209,119,63,91,238,119,63,20,11,120,63,132,39,120,63,174,67,120,63,145,95,120,63,46,123,120,63,132,150,120,63,149,177,120,63,96,204,120,63,231,230,120,63,41,1,121,63,38,27,121,63,223,52,121,63,85,78,121,63,136,103,121,63,120,128,121,63,37,153,121,63,144,177,121,63,185,201,121,63,161,225,121,63,72,249,121,63,174,16,122,63,212,39,122,63,185,62,122,63,96,85,122,63,198,107,122,63,238,129,122,63,216,151,122,63,131,173,122,63,241,194,122,63,33,216,122,63,20,237,122,63,202,1,123,63,68,22,123,63,130,42,123,63,133,62,123,63,77,82,123,63,217,101,123,63,43,121,123,63,68,140,123,63,34,159,123,63,200,177,123,63,52,196,123,63,104,214,123,63,99,232,123,63,39,250,123,63,180,11,124,63,9,29,124,63,40,46,124,63,17,63,124,63,196,79,124,63,65,96,124,63,137,112,124,63,156,128,124,63,124,144,124,63,39,160,124,63,158,175,124,63,226,190,124,63,244,205,124,63,211,220,124,63,128,235,124,63,251,249,124,63,69,8,125,63,94,22,125,63,71,36,125,63,255,49,125,63,136,63,125,63,225,76,125,63,11,90,125,63,7,103,125,63,212,115,125,63,115,128,125,63,229,140,125,63,42,153,125,63,66,165,125,63,46,177,125,63,238,188,125,63,130,200,125,63,235,211,125,63,41,223,125,63,61,234,125,63,38,245,125,63,230,255,125,63,124,10,126,63,234,20,126,63,47,31,126,63,75,41,126,63,64,51,126,63,13,61,126,63,180,70,126,63,51,80,126,63,140,89,126,63,191,98,126,63,205,107,126,63,181,116,126,63,120,125,126,63,23,134,126,63,146,142,126,63,233,150,126,63,28,159,126,63,44,167,126,63,26,175,126,63,229,182,126,63,142,190,126,63,22,198,126,63,124,205,126,63,194,212,126,63,231,219,126,63,235,226,126,63,208,233,126,63,149,240,126,63,59,247,126,63,195,253,126,63,44,4,127,63,118,10,127,63,163,16,127,63,179,22,127,63,165,28,127,63,123,34,127,63,52,40,127,63,210,45,127,63,83,51,127,63,186,56,127,63,5,62,127,63,53,67,127,63,75,72,127,63,72,77,127,63,42,82,127,63,243,86,127,63,163,91,127,63,58,96,127,63,185,100,127,63,32,105,127,63,111,109,127,63,166,113,127,63,199,117,127,63,208,121,127,63,196,125,127,63,161,129,127,63,104,133,127,63,25,137,127,63,182,140,127,63,61,144,127,63,176,147,127,63,14,151,127,63,89,154,127,63,143,157,127,63,179,160,127,63,195,163,127,63,192,166,127,63,171,169,127,63,132,172,127,63,74,175,127,63,255,177,127,63,163,180,127,63,53,183,127,63,183,185,127,63,40,188,127,63,137,190,127,63,217,192,127,63,26,195,127,63,76,197,127,63,111,199,127,63,130,201,127,63,135,203,127,63,126,205,127,63,102,207,127,63,65,209,127,63,14,211,127,63,205,212,127,63,128,214,127,63,38,216,127,63,191,217,127,63,76,219,127,63,204,220,127,63,65,222,127,63,170,223,127,63,8,225,127,63,91,226,127,63,163,227,127,63,224,228,127,63,19,230,127,63,59,231,127,63,90,232,127,63,110,233,127,63,122,234,127,63,124,235,127,63,116,236,127,63,100,237,127,63,75,238,127,63,42,239,127,63,1,240,127,63,207,240,127,63,149,241,127,63,84,242,127,63,12,243,127,63,188,243,127,63,101,244,127,63,7,245,127,63,162,245,127,63,55,246,127,63,198,246,127,63,78,247,127,63,209,247,127,63,77,248,127,63,196,248,127,63,54,249,127,63,162,249,127,63,9,250,127,63,108,250,127,63,201,250,127,63,34,251,127,63,118,251,127,63,198,251,127,63,18,252,127,63,89,252,127,63,157,252,127,63,221,252,127,63,26,253,127,63,83,253,127,63,136,253,127,63,187,253,127,63,234,253,127,63,22,254,127,63,64,254,127,63,103,254,127,63,139,254,127,63,173,254,127,63,204,254,127,63,234,254,127,63,5,255,127,63,30,255,127,63,53,255,127,63,74,255,127,63,94,255,127,63,112,255,127,63,128,255,127,63,143,255,127,63,157,255,127,63,169,255,127,63,180,255,127,63,191,255,127,63,200,255,127,63,208,255,127,63,215,255,127,63,221,255,127,63,227,255,127,63,232,255,127,63,236,255,127,63,239,255,127,63,243,255,127,63,245,255,127,63,248,255,127,63,249,255,127,63,251,255,127,63,252,255,127,63,253,255,127,63,254,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,168,9,120,57,17,119,11,59,135,139,193,59,74,113,61,60,148,82,156,60,94,8,233,60,42,83,34,61,74,118,87,61,138,227,137,61,7,140,171,61,34,154,208,61,108,239,248,61,164,52,18,62,100,112,41,62,65,21,66,62,67,11,92,62,47,56,119,62,197,191,137,62,92,97,152,62,135,112,167,62,4,220,182,62,188,145,198,62,231,126,214,62,48,144,230,62,227,177,246,62,13,104,3,63,121,107,11,63,98,89,19,63,42,40,27,63,137,206,34,63,166,67,42,63,49,127,49,63,126,121,56,63,153,43,63,63,92,143,69,63,127,159,75,63,165,87,81,63,104,180,86,63,89,179,91,63,8,83,96,63,252,146,100,63,177,115,104,63,138,246,107,63,198,29,111,63,109,236,113,63,62,102,116,63,154,143,118,63,104,109,120,63,3,5,122,63,26,92,123,63,153,120,124,63,143,96,125,63,17,26,126,63,39,171,126,63,176,25,127,63,74,107,127,63,68,165,127,63,132,204,127,63,123,229,127,63,17,244,127,63,158,251,127,63,219,254,127,63,218,255,127,63,0,0,128,63,60,12,120,54,253,134,11,56,19,201,193,56,248,231,61,57,148,245,156,57,115,118,234,57,238,186,35,58,113,249,89,58,32,251,139,58,96,216,174,58,34,148,213,58,3,23,0,59,209,82,23,59,65,125,48,59,21,150,75,59,8,157,104,59,233,200,131,59,20,58,148,59,218,161,165,59,16,0,184,59,136,84,203,59,16,159,223,59,118,223,244,59,194,138,5,60,128,32,17,60,217,48,29,60,172,187,41,60,219,192,54,60,67,64,68,60,194,57,82,60,52,173,96,60,115,154,111,60,88,1,127,60,222,112,135,60,186,157,143,60,42,7,152,60,25,173,160,60,112,143,169,60,23,174,178,60,246,8,188,60,243,159,197,60,245,114,207,60,225,129,217,60,156,204,227,60,10,83,238,60,14,21,249,60,70,9,2,61,177,165,7,61,187,95,13,61,81,55,19,61,102,44,25,61,230,62,31,61,195,110,37,61,233,187,43,61,71,38,50,61,202,173,56,61,97,82,63,61,247,19,70,61,121,242,76,61,210,237,83,61,240,5,91,61,187,58,98,61,32,140,105,61,8,250,112,61,93,132,120,61,132,21,128,61,249,246,131,61,130,230,135,61,19,228,139,61,159,239,143,61,26,9,148,61,119,48,152,61,169,101,156,61,163,168,160,61,88,249,164,61,186,87,169,61,186,195,173,61,76,61,178,61,95,196,182,61,230,88,187,61,209,250,191,61,18,170,196,61,152,102,201,61,85,48,206,61,56,7,211,61,48,235,215,61,47,220,220,61,34,218,225,61,248,228,230,61,161,252,235,61,11,33,241,61,35,82,246,61,217,143,251,61,13,109,0,62,105,24,3,62,247,201,5,62,174,129,8,62,133,63,11,62,113,3,14,62,104,205,16,62,96,157,19,62,79,115,22,62,42,79,25,62,232,48,28,62,124,24,31,62,221,5,34,62,255,248,36,62,215,241,39,62,90,240,42,62,125,244,45,62,51,254,48,62,114,13,52,62,45,34,55,62,88,60,58,62,232,91,61,62,208,128,64,62,3,171,67,62,118,218,70,62,26,15,74,62,229,72,77,62,199,135,80,62,181,203,83,62,162,20,87,62,127,98,90,62,63,181,93,62,213,12,97,62,50,105,100,62,73,202,103,62,12,48,107,62,108,154,110,62,92,9,114,62,203,124,117,62,173,244,120,62,241,112,124,62,138,241,127,62,52,187,129,62,190,127,131,62,91,70,133,62,4,15,135,62,176,217,136,62,89,166,138,62,245,116,140,62,126,69,142,62,234,23,144,62,50,236,145,62,78,194,147,62,54,154,149,62,224,115,151,62,70,79,153,62,93,44,155,62,31,11,157,62,130,235,158,62,127,205,160,62,11,177,162,62,31,150,164,62,177,124,166,62,186,100,168,62,47,78,170,62,9,57,172,62,62,37,174,62,198,18,176,62,150,1,178,62,167,241,179,62,238,226,181,62,100,213,183,62,254,200,185,62,179,189,187,62,122,179,189,62,74,170,191,62,25,162,193,62,221,154,195,62,142,148,197,62,34,143,199,62,142,138,201,62,203,134,203,62,205,131,205,62,140,129,207,62,253,127,209,62,24,127,211,62,210,126,213,62,33,127,215,62,252,127,217,62,88,129,219,62,45,131,221,62,112,133,223,62,23,136,225,62,25,139,227,62,108,142,229,62,5,146,231,62,219,149,233,62,228,153,235,62,21,158,237,62,102,162,239,62,203,166,241,62,59,171,243,62,173,175,245,62,21,180,247,62,107,184,249,62,164,188,251,62,181,192,253,62,150,196,255,62,30,228,0,63,207,229,1,63,88,231,2,63,182,232,3,63,226,233,4,63,215,234,5,63,146,235,6,63,12,236,7,63,66,236,8,63,45,236,9,63,202,235,10,63,19,235,11,63,4,234,12,63,151,232,13,63,200,230,14,63,145,228,15,63,239,225,16,63,220,222,17,63,84,219,18,63,81,215,19,63,208,210,20,63,202,205,21,63,61,200,22,63,34,194,23,63,117,187,24,63,50,180,25,63,85,172,26,63,215,163,27,63,182,154,28,63,236,144,29,63,117,134,30,63,77,123,31,63,110,111,32,63,214,98,33,63,126,85,34,63,100,71,35,63,130,56,36,63,212,40,37,63,87,24,38,63,5,7,39,63,219,244,39,63,213,225,40,63,239,205,41,63,36,185,42,63,113,163,43,63,209,140,44,63,64,117,45,63,188,92,46,63,63,67,47,63,199,40,48,63,78,13,49,63,211,240,49,63,80,211,50,63,195,180,51,63,39,149,52,63,122,116,53,63,184,82,54,63,220,47,55,63,229,11,56,63,206,230,56,63,149,192,57,63,54,153,58,63,174,112,59,63,249,70,60,63,21,28,61,63,255,239,61,63,179,194,62,63,48,148,63,63,113,100,64,63,116,51,65,63,55,1,66,63,182,205,66,63,239,152,67,63,224,98,68,63,134,43,69,63,222,242,69,63,230,184,70,63,156,125,71,63,253,64,72,63,7,3,73,63,184,195,73,63,14,131,74,63,6,65,75,63,159,253,75,63,215,184,76,63,172,114,77,63,28,43,78,63,38,226,78,63,199,151,79,63,253,75,80,63,201,254,80,63,39,176,81,63,22,96,82,63,150,14,83,63,164,187,83,63,63,103,84,63,103,17,85,63,26,186,85,63,86,97,86,63,28,7,87,63,105,171,87,63,62,78,88,63,152,239,88,63,120,143,89,63,221,45,90,63,198,202,90,63,50,102,91,63,33,0,92,63,147,152,92,63,134,47,93,63,251,196,93,63,242,88,94,63,105,235,94,63,98,124,95,63,219,11,96,63,213,153,96,63,80,38,97,63,76,177,97,63,201,58,98,63,199,194,98,63,70,73,99,63,71,206,99,63,202,81,100,63,208,211,100,63,88,84,101,63,100,211,101,63,244,80,102,63,9,205,102,63,163,71,103,63,195,192,103,63,107,56,104,63,154,174,104,63,82,35,105,63,147,150,105,63,96,8,106,63,184,120,106,63,157,231,106,63,16,85,107,63,19,193,107,63,166,43,108,63,203,148,108,63,132,252,108,63,209,98,109,63,180,199,109,63,48,43,110,63,68,141,110,63,244,237,110,63,64,77,111,63,42,171,111,63,181,7,112,63,225,98,112,63,177,188,112,63,38,21,113,63,67,108,113,63,10,194,113,63,123,22,114,63,155,105,114,63,106,187,114,63,234,11,115,63,31,91,115,63,9,169,115,63,172,245,115,63,9,65,116,63,35,139,116,63,252,211,116,63,151,27,117,63,245,97,117,63,26,167,117,63,8,235,117,63,193,45,118,63,72,111,118,63,159,175,118,63,202,238,118,63,201,44,119,63,161,105,119,63,84,165,119,63,228,223,119,63,85,25,120,63,168,81,120,63,226,136,120,63,3,191,120,63,16,244,120,63,11,40,121,63,247,90,121,63,215,140,121,63,173,189,121,63,125,237,121,63,73,28,122,63,20,74,122,63,226,118,122,63,181,162,122,63,144,205,122,63,118,247,122,63,107,32,123,63,112,72,123,63,138,111,123,63,186,149,123,63,5,187,123,63,109,223,123,63,245,2,124,63,160,37,124,63,113,71,124,63,108,104,124,63,147,136,124,63,233,167,124,63,114,198,124,63,48,228,124,63,38,1,125,63,89,29,125,63,201,56,125,63,124,83,125,63,115,109,125,63,178,134,125,63,60,159,125,63,19,183,125,63,60,206,125,63,184,228,125,63,139,250,125,63,184,15,126,63,66,36,126,63,44,56,126,63,120,75,126,63,43,94,126,63,70,112,126,63,204,129,126,63,194,146,126,63,41,163,126,63,4,179,126,63,86,194,126,63,35,209,126,63,109,223,126,63,55,237,126,63,131,250,126,63,85,7,127,63,175,19,127,63,148,31,127,63,7,43,127,63,10,54,127,63,160,64,127,63,205,74,127,63,146,84,127,63,242,93,127,63,239,102,127,63,141,111,127,63,206,119,127,63,181,127,127,63,67,135,127,63,124,142,127,63,98,149,127,63,247,155,127,63,61,162,127,63,56,168,127,63,233,173,127,63,83,179,127,63,120,184,127,63,90,189,127,63,252,193,127,63,95,198,127,63,134,202,127,63,116,206,127,63,41,210,127,63,168,213,127,63,244,216,127,63,13,220,127,63,247,222,127,63,179,225,127,63,67,228,127,63,168,230,127,63,229,232,127,63,252,234,127,63,237,236,127,63,188,238,127,63,105,240,127,63,246,241,127,63,101,243,127,63,183,244,127,63,238,245,127,63,11,247,127,63,16,248,127,63,254,248,127,63,214,249,127,63,155,250,127,63,76,251,127,63,236,251,127,63,124,252,127,63,252,252,127,63,110,253,127,63,211,253,127,63,44,254,127,63,121,254,127,63,189,254,127,63,247,254,127,63,42,255,127,63,84,255,127,63,120,255,127,63,150,255,127,63,175,255,127,63,195,255,127,63,211,255,127,63,224,255,127,63,234,255,127,63,241,255,127,63,246,255,127,63,250,255,127,63,253,255,127,63,254,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,11,0,0,0,16,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,24,0,0,0,11,0,0,0,20,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,80,0,0,0,33,0,0,0,18,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,64,0,0,0,33,0,0,0,160,0,0,0,99,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,112,75,35,0,136,252,34,0,32,188,34,0,192,126,34,0,144,70,34,0,8,21,34,0,48,226,33,0,80,190,33,0,8,155,33,0,80,127,33,0,56,65,33,0,80,16,33,0,8,246,32,0,64,219,32,0,224,191,32,0,72,168,32,0,208,142,32,0,136,118,32,0,104,95,32,0,0,76,32,0,176,23,32,0,64,246,31,0,96,225,31,0,176,206,31,0,208,185,31,0,192,166,31,0,80,148,31,0,136,130,31,0,176,114,31,0,216,101,31,0,112,59,31,0,200,34,31,0,96,21,31,0,88,7,31,0,48,247,30,0,248,232,30,0,0,0,0,0,0,0,0,0,232,75,21,0,216,72,21,0,195,7,0,0,152,71,21,0,24,69,21,0,159,9,0,0,8,68,21,0,240,65,21,0,133,10,0,0,8,65,21,0,56,63,21,0,115,11,0,0,104,62,21,0,208,60,21,0,101,12,0,0,16,60,21,0,152,58,21,0,93,12,0,0,232,57,21,0,136,56,21,0,87,12,0,0,232,55,21,0,176,54,21,0,77,13], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+81920);
/* memory initializer */ allocate([40,53,21,0,24,50,21,0,195,7,0,0,216,48,21,0,88,46,21,0,159,9,0,0,72,45,21,0,48,43,21,0,133,10,0,0,72,42,21,0,120,40,21,0,115,11,0,0,168,39,21,0,16,38,21,0,101,12,0,0,80,37,21,0,216,35,21,0,93,12,0,0,40,35,21,0,200,33,21,0,87,12,0,0,40,33,21,0,240,31,21,0,77,13,0,0,240,30,21,0,240,28,21,0,128,11,0,0,80,28,21,0,16,27,21,0,79,13,0,0,112,26,21,0,48,25,21,0,79,13,0,0,144,24,21,0,80,23,21,0,79,13,0,0,176,22,21,0,112,21,21,0,79,13,0,0,176,22,21,0,112,21,21,0,79,13,0,0,176,22,21,0,112,21,21,0,79,13,0,0,176,22,21,0,112,21,21,0,79,13,0,0,75,173,133,85,150,40,78,53,222,41,39,220,9,168,255,223,152,71,27,230,174,99,160,213,144,26,66,202,34,204,146,87,75,57,54,174,43,9,20,41,101,4,129,242,193,21,0,106,39,230,75,46,52,160,153,89,138,79,125,232,248,170,185,41,97,179,83,197,226,222,223,247,71,245,236,33,225,236,91,108,130,29,71,209,4,252,156,9,70,252,146,18,141,253,16,192,10,179,57,90,75,0,140,202,172,245,60,8,209,15,200,244,219,22,149,238,134,86,16,49,200,172,23,189,38,253,251,28,118,210,229,214,68,44,0,7,42,104,222,91,151,179,21,254,93,186,119,190,218,202,203,199,243,169,96,246,67,4,177,232,217,224,175,189,48,176,85,170,212,71,177,251,141,7,30,52,201,187,194,70,118,88,193,67,18,217,255,69,98,71,186,2,204,5,73,79,134,233,109,152,77,19,9,169,213,245,235,17,46,233,32,72,63,34,248,245,19,245,190,249,209,84,27,12,173,155,152,12,173,181,85,18,113,236,172,23,180,7,9,197,115,247,44,37,238,253,189,80,202,237,147,223,203,168,73,221,225,9,168,211,100,21,230,3,84,86,68,236,115,6,159,245,7,18,15,9,119,81,250,243,254,242,9,16,158,52,253,11,85,0,137,67,24,40,96,198,214,0,90,0,3,153,95,182,104,180,44,75,22,216,181,38,245,217,17,80,77,230,185,228,75,11,30,253,95,80,12,194,127,166,214,26,76,0,71,1,40,34,179,205,95,166,188,246,32,180,213,217,170,205,55,63,92,82,237,14,237,2,32,202,133,193,223,71,87,9,3,187,28,76,126,232,143,5,214,45,211,15,90,75,201,26,31,179,176,235,38,38,70,71,159,9,76,73,12,237,171,253,42,76,43,5,120,220,204,254,176,251,229,243,125,155,207,194,244,98,26,18,75,10,167,76,176,246,23,225,20,46,139,219,252,200,82,10,85,103,157,173,142,215,99,249,81,249,15,86,121,84,60,45,125,166,211,239,129,0,22,232,214,13,147,3,251,254,239,255,129,254,160,6,48,26,111,250,102,81,89,3,192,238,143,5,80,196,154,222,61,218,90,20,55,22,88,238,155,253,93,210,242,21,134,16,107,2,169,3,157,236,234,200,48,189,6,229,192,232,36,197,31,254,187,227,210,197,188,73,169,84,198,155,94,11,119,4,185,254,54,254,29,252,72,218,205,252,188,158,244,10,1,79,59,4,169,251,158,241,4,249,220,179,198,3,53,3,125,28,1,171,38,42,109,228,3,165,69,249,230,254,171,212,170,0,42,174,2,143,71,49,18,70,129,14,229,249,117,3,5,0,52,2,228,23,168,88,194,8,217,228,247,38,12,232,242,16,184,104,135,241,184,7,201,251,246,245,107,253,35,225,148,245,166,196,58,69,23,17,178,239,211,212,205,2,22,168,26,6,220,47,251,230,158,71,215,23,71,27,68,23,19,71,123,38,250,20,52,92,51,229,87,230,194,255,204,85,47,52,85,253,201,14,120,8,209,0,15,242,153,251,244,178,248,249,28,5,221,252,245,243,177,62,33,202,251,243,198,16,161,92,241,216,215,38,0,194,134,50,177,163,195,84,250,37,53,89,160,47,243,58,157,21,229,18,195,8,51,8,219,4,249,15,140,18,156,50,167,15,92,246,25,13,236,243,139,34,128,66,234,16,239,23,173,21,33,36,218,43,176,111,142,218,135,221,236,0,241,3,199,1,60,252,173,26,90,75,6,252,200,0,29,7,66,2,76,20,189,3,132,40,2,13,0,206,129,255,50,244,255,223,35,199,45,86,32,23,29,4,230,42,86,101,30,160,18,165,127,209,123,229,139,88,254,212,104,22,7,10,153,92,243,215,241,242,119,239,174,234,187,80,165,213,235,241,221,239,228,241,223,17,195,252,162,254,177,252,25,243,123,13,26,227,172,210,207,11,199,1,128,12,181,218,130,12,147,166,176,43,158,152,243,200,235,239,22,60,215,55,93,213,103,176,223,14,248,212,36,86,34,56,32,196,203,225,109,231,201,186,232,249,16,47,163,178,69,254,253,231,118,239,96,255,171,32,110,88,135,46,253,74,151,4,254,28,109,217,216,239,96,18,184,255,28,226,144,255,77,209,98,243,39,106,202,12,75,23,77,29,133,189,98,3,148,156,225,2,69,7,41,7,230,7,80,9,147,18,159,235,88,29,251,12,155,10,249,11,186,249,151,16,53,2,253,21,193,9,99,70,200,236,239,244,0,186,130,224,122,61,6,252,88,8,234,11,229,179,34,66,139,116,18,216,49,59,174,211,118,0,60,155,63,202,216,59,44,254,40,237,96,19,89,239,39,6,159,214,105,76,245,223,127,250,5,253,141,251,161,253,128,5,101,247,105,211,229,7,12,231,216,245,199,2,99,254,49,246,40,255,65,242,149,145,183,6,146,199,154,66,93,54,187,52,94,155,7,193,28,75,173,28,243,207,170,2,49,241,57,255,159,239,10,81,221,194,85,44,228,22,200,252,14,172,38,242,253,255,87,249,137,240,253,35,85,60,172,248,220,7,85,179,100,63,19,237,205,244,107,241,70,227,81,255,105,177,166,43,13,242,245,159,244,76,254,25,211,3,114,253,60,85,250,226,17,230,241,213,86,223,183,60,235,57,57,70,220,227,175,242,114,7,120,188,197,13,149,240,121,250,18,245,240,68,34,8,76,230,105,196,7,186,57,5,234,59,166,82,66,24,226,37,51,59,166,159,21,168,97,240,52,249,175,253,71,4,157,225,226,97,225,21,167,83,80,254,134,249,14,229,98,250,138,199,225,228,188,2,149,208,23,253,133,161,194,87,143,24,211,12,254,42,4,15,240,74,189,57,26,168,170,59,67,21,8,245,54,252,241,242,185,12,132,241,136,18,147,223,30,89,32,216,26,95,22,174,134,77,219,3,74,209,123,231,66,15,11,179,4,51,183,249,209,72,42,29,215,152,235,167,177,63,222,7,223,42,112,70,129,228,47,18,30,198,51,73,173,61,16,5,94,36,111,249,75,57,2,243,167,103,179,209,96,22,29,23,88,52,36,39,68,247,128,159,205,6,185,229,151,49,7,170,240,15,74,21,195,245,177,36,151,82,174,154,166,243,31,246,192,80,206,73,141,201,78,27,188,223,195,61,246,162,175,43,185,202,92,46,173,62,70,10,185,71,20,216,61,3,88,3,14,252,157,0,64,56,186,237,33,20,22,204,214,148,236,212,109,84,248,43,45,68,180,29,74,51,28,254,7,0,212,4,61,2,118,16,200,21,247,243,148,3,124,220,5,5,2,221,161,4,229,143,83,84,143,92,172,74,187,244,54,200,10,223,118,91,239,231,178,50,245,11,121,219,188,8,2,244,80,227,84,177,156,22,70,2,217,253,103,240,59,1,163,225,32,32,78,146,79,207,198,53,3,196,5,75,112,175,243,50,209,180,193,14,79,255,93,31,23,252,148,69,42,20,116,227,25,239,80,185,148,253,186,250,84,58,164,57,59,251,237,205,182,197,221,253,245,105,186,8,172,6,204,10,40,21,50,31,181,157,57,11,52,14,152,15,224,20,158,39,11,83,134,4,3,21,252,1,238,214,34,1,177,249,90,4,213,96,191,64,176,157,214,254,240,244,173,251,0,232,130,248,145,225,101,244,20,165,176,15,41,42,165,67,10,239,10,174,201,242,114,238,49,255,33,217,9,242,11,31,130,4,104,226,181,31,33,201,86,66,167,152,108,148,196,196,224,62,52,190,74,221,88,163,34,62,90,97,48,22,174,248,164,1,132,0,117,0,6,254,146,180,58,255,156,1,201,254,240,2,142,248,141,15,248,225,182,64,165,180,126,198,113,254,39,253,33,241,156,239,149,207,215,29,40,13,26,9,132,35,134,92,206,215,87,249,180,243,36,10,206,224,10,57,57,237,243,64,121,31,201,5,49,0,53,67,37,97,50,29,152,180,255,253,129,46,42,9,212,21,37,13,57,236,204,170,106,44,144,42,17,19,5,1,186,18,97,80,245,19,119,232,143,224,15,250,189,31,92,198,159,80,186,197,133,93,190,241,163,48,101,5,29,14,239,33,62,162,240,18,70,26,147,41,102,39,129,98,185,157,215,251,161,25,153,54,95,11,233,84,81,64,62,154,16,249,15,10,106,179,96,190,216,11,23,26,164,58,10,186,10,223,206,171,25,150,32,46,120,13,100,252,215,193,145,251,6,20,123,175,40,30,178,8,55,68,58,21,14,113,144,68,222,4,254,60,33,210,42,96,125,187,200,12,143,12,30,70,223,10,46,253,112,167,91,23,210,233,144,243,25,154,178,101,183,25,230,12,86,79,29,242,101,245,68,254,49,250,246,5,96,175,46,170,81,208,63,155,159,34,244,251,224,69,58,2,26,193,137,32,7,246,171,59,139,245,222,38,169,248,93,64,38,206,177,142,136,255,83,247,219,0,97,0,109,1,35,0,246,4,50,253,200,5,127,245,138,7,153,226,104,7,46,34,114,7,59,71,108,206,226,231,107,241,145,53,102,217,168,193,160,250,22,228,152,214,48,33,95,62,168,221,108,29,215,79,225,11,111,203,8,4,184,150,155,22,152,97,18,238,228,223,150,219,32,232,165,188,145,100,112,186,58,27,168,14,114,2,142,255,130,8,97,17,2,237,142,27,228,234,130,18,245,244,58,19,117,253,251,73,118,217,80,3,94,7,176,254,222,234,66,28,220,79,145,218,168,253,13,3,238,179,152,206,234,25,134,5,194,1,185,242,126,190,99,43,144,51,134,234,159,84,63,243,251,18,183,232,106,29,171,213,182,109,110,40,155,205,99,100,40,100,129,253,95,1,139,4,75,73,166,234,17,197,111,255,159,250,115,199,93,106,105,133,115,128,191,83,178,244,60,60,135,73,112,86,198,75,55,88,19,53,78,214,214,41,225,19,108,237,141,3,232,174,108,205,76,175,242,28,162,10,99,13,65,45,175,251,198,71,19,77,78,218,170,87,178,76,216,254,114,229,171,198,99,84,84,77,151,83,106,180,179,226,102,99,88,51,140,33,46,157,20,12,134,214,160,81,33,36,2,243,4,7,213,252,169,5,34,12,140,18,41,47,74,200,16,175,195,55,20,239,18,155,107,233,99,173,244,235,58,41,60,201,122,169,24,11,214,253,189,99,240,68,38,58,174,173,155,9,54,98,102,219,4,249,194,205,18,233,45,155,241,212,42,26,51,3,73,40,166,0,189,107,11,2,101,0,68,180,85,13,166,37,64,0,38,3,74,245,245,185,240,245,34,89,105,33,102,4,156,11,99,59,0,7,90,99,160,233,143,188,117,250,68,6,46,17,188,44,195,6,235,92,240,235,17,18,99,214,77,109,169,38,50,246,224,214,127,146,183,11,6,250,192,252,194,252,131,212,33,207,190,86,181,227,230,163,62,171,39,66,124,170,69,7,122,218,216,36,82,74,37,40,44,37,191,104,218,7,177,236,136,220,171,21,94,247,190,55,60,196,140,180,30,7,14,237,241,252,1,221,252,243,168,177,131,243,40,32,22,245,168,186,252,51,157,12,33,252,51,208,75,230,75,40,176,218,212,8,88,175,168,228,153,21,127,226,190,226,154,215,230,215,57,14,23,76,172,232,103,181,118,183,5,50,3,5,188,239,102,16,199,144,62,246,74,7,175,62,202,104,3,205,84,231,217,3,195,249,109,254,112,53,57,25,238,97,244,105,26,175,106,185,2,249,102,158,65,23,70,252,232,103,96,161,233,195,212,96,161,7,144,251,187,0,15,247,217,48,254,174,120,252,148,71,10,83,98,10,4,232,51,63,4,87,212,253,106,8,57,232,126,54,174,155,191,147,209,15,69,237,52,172,105,103,235,75,92,220,127,3,47,1,72,169,191,153,118,232,153,96,114,166,186,220,60,200,146,193,180,92,189,166,52,36,255,240,42,115,163,85,187,231,143,6,245,247,160,251,77,254,74,38,205,240,71,48,64,239,229,181,56,77,170,255,163,9,198,7,3,252,22,235,250,81,177,221,47,235,246,163,134,237,113,10,25,236,229,21,235,237,206,74,181,101,29,208,204,3,202,26,199,17,45,109,71,240,32,247,187,23,68,243,131,236,139,254,221,249,110,241,168,227,64,205,140,221,11,236,14,90,190,19,152,3,55,10,232,30,71,227,215,236,218,78,6,255,78,21,68,12,16,27,221,182,253,247,197,215,236,238,152,76,15,19,107,253,163,248,224,57,101,222,153,178,247,23,38,173,28,55,87,209,81,247,154,19,116,46,213,88,150,1,128,204,203,245,56,204,95,168,62,207,68,223,170,66,179,98,31,247,192,19,170,254,145,0,209,32,237,186,168,74,119,41,3,180,187,66,85,81,188,233,10,48,2,156,151,40,12,30,198,17,163,61,186,67,77,180,96,237,182,4,213,225,84,42,228,149,81,211,179,26,16,249,238,9,127,12,90,17,105,68,129,241,110,252,224,81,122,190,74,233,79,43,186,255,177,89,233,12,103,11,112,24,64,237,26,174,98,243,36,23,93,191,135,8,173,10,118,13,246,164,83,232,62,255,228,201,37,213,32,76,5,4,115,17,180,232,196,181,239,5,153,254,87,3,211,249,73,226,54,86,196,210,208,216,206,66,132,207,249,9,228,16,228,87,119,22,138,47,217,157,76,70,16,231,156,4,158,4,150,37,166,91,233,222,216,238,147,245,214,29,61,190,121,234,185,244,251,213,109,174,78,28,29,4,143,10,134,175,126,226,92,29,196,225,236,22,190,80,141,85,201,1,121,58,7,187,111,209,19,14,197,249,127,247,99,255,213,255,93,2,209,9,250,34,31,41,31,88,28,193,87,193,114,23,87,19,139,26,2,237,128,168,161,73,166,29,99,249,144,159,180,242,89,55,190,4,210,238,249,229,42,229,157,216,236,159,37,36,228,40,87,69,188,225,147,0,86,231,67,17,59,63,83,191,233,239,206,16,201,29,33,21,231,12,175,10,34,29,66,178,50,247,138,241,227,247,105,84,22,58,1,49,63,232,28,249,70,18,220,45,43,11,41,27,127,7,225,240,194,13,163,170,91,246,43,215,205,73,10,214,175,14,49,216,254,236,157,245,89,186,38,251,143,58,135,36,94,46,219,249,16,237,21,88,37,37,240,149,238,41,115,81,183,153,42,186,254,227,144,250,217,179,202,49,6,32,60,248,91,7,254,109,178,252,189,227,249,0,233,0,224,227,157,2,141,254,124,244,194,90,253,233,69,12,32,1,151,12,22,251,158,255,41,148,221,67,61,165,246,19,65,212,242,245,33,211,192,236,238,5,176,234,158,2,154,184,159,7,94,40,103,178,215,237,105,1,96,255,101,252,44,73,184,55,173,243,195,226,0,243,71,23,226,241,85,82,108,28,208,13,185,31,8,250,26,223,244,1,18,181,241,73,24,103,241,251,23,61,68,100,183,32,111,7,153,7,53,209,100,245,61,13,226,104,21,238,11,7,22,0,153,4,113,253,209,4,176,247,164,30,231,6,7,253,17,32,166,180,15,238,131,7,169,254,79,253,54,242,61,243,36,241,63,245,134,72,194,247,170,7,183,250,3,65,205,10,194,165,79,254,41,19,46,1,216,50,61,62,239,232,131,12,30,16,173,43,136,234,31,246,120,251,189,251,187,230,121,250,50,22,244,254,71,2,67,219,140,179,72,24,122,6,225,3,181,255,97,249,104,238,15,247,8,240,100,230,63,191,152,18,132,252,106,213,116,25,135,94,133,232,3,255,232,3,63,0,175,255,141,255,130,254,203,250,160,94,70,253,197,237,15,245,56,181,148,252,62,143,143,170,133,49,56,231,163,12,207,65,153,82,196,153,145,243,116,254,230,0,120,71,146,225,199,205,89,253,63,250,5,0,8,215,165,44,205,100,158,251,121,5,74,254,198,14,251,226,96,104,159,68,57,75,254,48,188,24,22,253,245,49,100,36,242,167,22,235,90,13,56,167,98,105,127,71,52,4,188,3,77,149,84,244,152,3,235,0,185,8,81,0,55,24,176,20,221,62,176,57,19,223,168,251,224,230,44,75,193,38,75,243,254,4,70,252,149,94,1,8,109,166,25,10,150,246,136,239,70,36,202,55,233,178,111,240,216,246,4,4,96,177,73,70,14,219,228,89,169,189,177,33,16,229,6,175,178,14,7,68,69,87,80,74,74,3,117,94,230,97,49,233,178,255,169,3,147,253,10,77,116,161,86,248,250,197,200,255,238,88,1,236,213,67,60,93,232,179,98,230,146,247,82,68,69,172,12,13,237,205,185,176,107,218,173,67,203,2,217,8,229,239,20,254,196,35,147,50,167,106,73,173,72,232,15,219,148,204,27,165,74,201,168,239,66,27,2,0,170,3,187,203,192,13,23,161,118,89,133,76,209,236,194,178,52,77,162,219,150,206,235,14,170,234,103,239,181,228,140,231,137,201,194,157,125,36,129,40,218,201,208,229,28,88,249,253,251,25,80,73,9,237,26,49,138,57,31,216,201,252,199,70,142,1,210,249,140,255,149,254,233,228,106,206,24,145,104,33,49,27,17,255,214,245,160,237,3,252,223,7,9,20,118,92,241,206,2,224,60,158,112,72,99,55,127,6,229,14,44,82,108,218,69,236,248,248,193,251,215,169,35,65,112,58,243,36,226,10,95,66,72,154,138,180,242,230,80,4,166,22,137,185,55,249,249,96,177,40,177,212,128,3,103,235,193,248,141,45,13,245,233,96,69,172,176,178,79,164,167,190,106,233,11,22,76,10,76,19,68,249,36,17,207,151,129,202,74,41,217,154,254,59,216,179,130,102,195,183,200,6,118,31,52,22,154,81,251,15,100,181,4,199,28,215,108,67,93,192,11,58,209,186,26,181,147,48,207,149,227,206,87,26,206,253,208,3,255,254,107,48,86,222,24,169,125,178,5,43,82,30,215,14,77,46,26,148,231,222,65,4,41,250,45,16,122,247,160,151,33,253,250,252,189,5,53,12,194,53,254,17,73,114,83,73,26,217,199,187,27,219,102,187,30,246,221,230,114,241,50,249,255,16,71,229,195,178,155,37,98,214,83,28,197,13,83,42,225,21,110,98,204,164,196,215,90,186,119,2,120,45,252,7,114,174,151,252,202,222,217,251,198,194,59,214,86,58,171,193,233,109,148,20,221,1,227,251,134,4,41,250,146,221,124,233,123,158,132,101,227,30,242,251,142,255,252,246,217,250,176,230,192,5,31,19,23,186,6,155,181,20,68,255,45,6,128,12,73,67,250,16,85,86,145,183,12,86,246,215,33,2,76,213,228,8,90,146,182,31,239,59,25,9,100,36,57,80,60,58,29,82,185,24,242,23,68,160,69,3,67,222,44,233,218,28,11,254,7,41,163,78,171,44,109,237,71,245,110,94,198,219,169,59,59,223,53,233,176,11,208,244,160,23,207,226,167,45,228,177,141,252,78,209,8,217,187,170,172,238,214,149,130,13,170,76,0,5,37,10,137,77,135,20,61,235,189,74,74,199,14,221,181,53,184,250,210,72,247,68,249,42,161,26,14,184,192,24,95,249,196,8,224,237,108,15,166,205,103,235,204,79,46,41,74,16,12,252,239,75,187,84,129,244,233,178,144,239,40,5,141,3,63,221,135,36,126,224,198,245,123,205,214,103,179,13,233,37,156,167,119,32,231,31,19,204,232,21,150,12,165,14,28,250,165,0,204,255,60,255,102,0,40,167,128,221,135,3,99,211,186,198,136,255,110,23,53,77,89,52,44,14,77,20,80,33,195,22,214,251,6,3,217,255,90,255,195,36,252,218,109,37,52,205,136,95,68,97,214,69,187,8,121,171,254,79,108,18,234,227,78,246,39,37,75,6,73,170,150,55,247,250,72,36,13,247,175,90,132,242,166,213,11,0,24,37,225,11,10,20,206,240,29,173,195,167,182,55,146,217,227,78,195,54,91,0,208,188,97,183,212,3,17,0,53,3,120,0,194,253,253,47,187,180,174,53,245,63,95,255,137,23,220,242,250,5,91,240,150,9,136,213,225,162,105,0,221,19,252,254,158,22,180,253,226,74,25,16,73,16,127,52,52,57,163,81,10,29,81,255,45,51,136,241,193,90,67,15,122,39,43,232,171,91,84,20,195,250,63,6,118,51,111,243,90,242,13,59,61,223,14,210,114,237,122,4,67,18,78,180,69,58,29,236,249,0,254,171,152,39,167,191,7,204,206,71,103,222,116,2,143,9,16,13,58,12,5,236,119,0,236,69,106,168,31,187,207,85,91,192,4,226,223,65,150,94,236,21,238,240,215,252,238,14,13,247,107,39,200,246,235,157,54,251,56,1,141,11,248,43,121,104,46,204,129,242,152,251,206,178,108,245,252,17,211,24,102,6,157,99,119,179,183,225,87,12,171,255,23,254,193,248,46,3,222,48,133,74,183,237,206,245,62,250,144,164,173,181,201,31,166,77,232,30,230,254,71,3,60,179,151,46,142,106,117,243,218,8,180,15,170,251,34,32,6,251,186,81,228,97,208,103,69,1,11,222,24,255,86,247,69,253,227,211,152,239,13,7,239,229,100,166,197,250,43,248,242,193,233,251,217,147,77,204,34,56,199,169,157,7,119,51,216,194,202,248,119,31,223,11,249,46,220,27,200,159,157,1,213,246,16,162,50,255,171,48,2,230,95,254,149,216,3,71,120,163,221,175,244,191,62,28,251,2,27,22,35,236,54,54,79,163,187,212,125,179,76,44,245,1,208,97,192,29,54,179,69,6,230,151,174,34,48,41,161,1,19,5,5,1,124,56,105,44,65,243,6,39,2,32,191,70,75,5,154,174,20,220,68,193,145,222,38,253,130,248,55,174,139,184,99,246,165,245,220,16,6,245,201,95,12,213,135,155,52,1,46,251,141,220,128,188,215,248,98,141,107,161,9,191,229,244,181,39,37,235,184,244,98,85,164,172,40,194,1,58,28,163,64,20,129,39,97,175,177,179,159,211,221,32,206,5,150,163,129,233,168,226,3,4,198,174,164,53,180,77,82,170,156,208,146,228,25,181,120,221,109,86,150,191,145,7,90,20,82,231,20,163,85,51,74,43,51,255,148,23,132,254,210,33,23,255,116,109,109,234,53,29,211,29,43,92,35,38,226,245,154,84,103,145,242,243,212,254,248,251,208,6,176,168,6,65,208,0,9,26,8,188,44,244,50,72,120,36,79,245,84,180,151,1,219,238,207,236,38,188,131,73,10,187,104,52,128,59,69,30,224,24,95,90,2,185,160,29,104,239,47,250,133,230,74,2,83,216,116,58,224,99,4,15,244,231,33,19,11,205,2,168,15,22,213,222,199,247,58,159,137,3,146,219,176,5,32,244,60,250,142,4,180,238,228,43,244,35,69,13,85,250,30,53,31,194,220,95,187,22,35,33,79,244,43,84,236,189,61,30,210,93,172,197,50,163,44,235,248,229,111,238,211,51,179,75,116,50,162,247,31,253,108,82,171,169,65,13,235,237,103,22,31,182,199,228,127,10,124,4,237,192,71,172,65,146,138,253,143,199,132,28,160,2,98,72,212,187,91,216,95,1,92,44,34,213,60,67,16,18,145,0,127,69,57,253,105,242,66,247,15,62,235,7,0,0,112,146,2,7,175,253,58,245,164,170,15,45,29,179,73,19,244,85,19,84,180,243,254,6,45,3,39,32,73,10,205,46,29,244,185,86,248,34,72,159,78,253,25,58,194,246,4,235,214,32,193,234,238,254,126,253,111,255,10,3,51,230,90,28,44,81,45,164,63,183,254,88,144,166,112,156,36,39,178,249,228,5,143,250,183,29,151,1,154,159,255,191,244,248,165,237,160,214,61,181,222,40,93,241,17,34,249,228,210,50,172,20,170,231,236,236,88,174,251,248,251,65,54,202,47,254,143,75,11,214,97,205,105,98,49,198,207,233,247,253,191,254,69,251,5,27,235,243,215,78,233,150,6,209,15,5,49,1,200,7,1,76,39,252,25,0,247,253,51,26,142,241,173,32,17,222,161,85,226,149,60,18,109,23,205,27,176,45,81,95,214,213,232,2,56,219,181,77,171,7,242,30,160,217,102,13,34,83,56,249,92,42,117,34,135,105,147,221,241,5,26,162,115,6,158,30,72,251,71,15,43,212,201,12,3,207,0,28,226,71,138,84,157,35,240,210,120,235,165,27,78,9,100,0,233,14,199,229,220,4,238,5,191,254,10,31,18,183,171,41,254,236,215,2,8,3,245,193,42,224,217,247,211,88,31,6,102,242,28,17,81,245,21,33,143,228,96,211,37,5,90,105,41,17,241,29,153,68,54,253,138,2,193,192,189,252,173,32,3,7,22,200,169,63,152,17,192,216,238,29,190,151,236,187,20,10,48,0,112,240,52,2,17,233,98,10,30,183,35,49,96,154,230,194,112,10,189,250,137,252,170,236,112,16,101,229,9,10,115,175,46,222,212,248,30,198,61,234,230,164,48,198,11,101,58,21,21,146,203,246,189,244,198,253,127,9,40,51,45,245,162,97,48,207,109,159,255,251,212,233,13,239,116,7,196,72,181,172,214,67,12,108,7,147,207,195,156,5,56,228,63,247,83,31,7,15,248,95,43,254,202,37,187,41,121,252,91,216,9,7,244,172,187,18,209,221,98,4,146,218,65,10,7,89,188,3,114,3,196,30,131,74,84,217,54,161,72,29,61,36,212,3,116,151,246,234,20,21,62,4,112,6,166,112,10,251,65,254,5,0,83,254,236,255,77,196,244,23,28,89,228,4,21,217,255,1,83,3,245,30,55,254,78,208,165,16,155,29,78,238,4,33,34,251,165,56,137,158,128,233,106,186,25,214,159,38,135,162,136,203,86,7,55,197,181,39,107,64,245,198,64,210,92,173,11,243,72,3,205,233,141,87,202,7,74,2,118,90,100,233,61,197,124,215,201,219,45,203,251,252,219,218,103,240,56,161,15,33,172,22,159,222,65,253,104,207,111,240,222,157,13,146,237,190,129,62,186,10,75,6,233,19,237,251,41,0,243,227,191,77,67,123,19,130,103,54,230,233,77,3,26,206,73,22,55,65,170,255,162,20,27,58,146,105,132,82,160,61,19,215,120,57,192,76,33,211,207,203,28,177,131,196,149,33,78,220,142,253,139,42,129,232,202,24,48,250,8,251,57,250,233,250,136,241,147,234,214,242,207,69,52,230,98,97,30,101,201,243,224,32,135,108,151,250,230,20,92,239,25,78,56,22,106,1,94,67,225,14,82,243,64,4,151,255,89,140,187,10,119,59,89,255,138,14,174,13,133,243,154,33,92,30,226,249,109,252,21,254,185,12,137,246,146,21,126,80,156,255,132,201,152,211,241,195,150,170,184,222,189,47,152,253,120,9,25,248,46,17,35,241,172,31,220,227,51,82,219,82,77,219,65,180,128,3,151,233,200,196,206,172,170,66,18,252,146,254,117,24,168,12,95,209,171,192,52,194,181,25,173,243,220,96,173,10,23,251,149,252,195,249,11,176,86,43,7,94,229,220,56,55,172,8,230,200,183,46,33,168,39,16,225,251,212,234,33,3,161,245,60,0,52,235,234,252,49,23,52,227,28,249,95,168,52,154,203,84,82,16,173,233,8,230,196,197,45,5,20,162,213,5,120,232,56,207,122,93,134,11,65,6,149,4,123,74,222,68,9,70,98,214,176,42,162,236,159,12,44,243,200,106,78,16,109,249,241,1,170,39,197,28,221,65,249,72,147,166,204,241,197,245,52,241,103,234,184,235,207,220,182,176,49,234,240,166,49,83,100,27,233,2,208,2,172,1,77,250,109,0,246,243,105,1,45,223,225,31,129,87,241,0,219,6,150,252,248,244,116,4,99,49,2,9,247,86,198,157,107,187,207,245,51,13,97,40,238,178,148,195,120,162,56,240,4,206,84,155,40,51,65,15,35,5,16,18,9,163,40,53,229,98,105,251,125,8,159,255,179,53,254,235,215,90,118,16,127,169,222,26,190,254,88,71,170,252,116,209,35,253,128,67,131,206,35,218,11,92,144,192,227,250,170,22,152,236,70,76,54,173,210,159,73,255,219,22,247,192,125,59,232,218,254,249,121,1,16,55,225,97,107,52,98,32,24,91,178,65,163,227,118,0,5,194,153,74,53,38,235,254,64,239,85,84,24,204,125,192,249,64,2,237,45,19,239,180,115,91,113,57,46,253,125,0,6,76,132,237,120,248,249,210,34,81,49,21,86,148,191,244,21,239,128,1,201,247,87,5,246,254,41,220,65,21,221,102,124,248,125,16,102,244,54,177,200,170,74,21,254,226,224,20,35,255,216,229,91,2,76,220,28,5,142,148,149,37,68,223,81,248,187,36,141,249,33,89,142,29,126,235,187,239,105,5,34,252,48,2,18,251,162,96,143,181,245,41,161,29,70,228,195,1,162,78,35,217,129,232,116,247,78,250,233,86,164,36,136,35,207,42,195,246,116,241,236,72,118,253,46,251,84,43,254,29,81,23,7,75,51,250,204,251,37,253,84,253,43,0,147,236,118,52,171,78,60,0,220,1,89,252,195,177,6,34,195,9,248,3,122,251,79,1,211,152,166,72,103,247,99,253,81,13,25,3,138,237,171,34,225,159,82,218,59,14,229,254,247,51,100,172,149,241,96,251,78,248,76,6,173,0,60,0,151,3,205,4,30,27,103,253,249,63,95,66,221,20,65,201,0,247,90,176,246,98,143,214,171,46,27,226,37,231,234,54,121,93,53,204,198,227,87,252,234,0,69,255,167,24,171,248,218,48,169,248,63,73,211,164,109,2,45,25,26,13,46,161,214,32,195,20,31,243,86,236,160,237,40,236,126,155,227,20,5,251,17,204,59,252,234,164,190,4,147,102,148,231,51,39,119,177,197,59,55,193,16,20,90,37,185,240,202,179,137,18,254,86,181,239,42,31,112,179,200,54,143,233,137,174,235,34,7,0,57,240,223,3,79,232,52,0,33,180,157,13,153,11,52,30,106,30,224,98,62,24,65,252,244,205,208,248,41,167,156,28,78,42,178,237,142,6,68,216,171,235,198,16,9,251,49,15,22,5,26,29,126,2,150,79,195,243,48,207,93,220,31,72,201,207,186,227,120,72,215,231,201,33,9,229,129,252,213,66,220,64,88,217,163,111,29,11,104,6,109,11,214,254,120,58,124,154,30,58,52,162,23,7,182,230,251,101,46,20,233,82,1,62,113,84,233,57,76,171,54,64,24,80,246,199,54,228,190,239,231,111,90,0,220,249,21,3,122,252,181,255,57,250,167,9,35,240,28,14,64,247,162,42,168,33,83,68,103,67,208,187,126,66,27,192,14,175,91,183,186,98,56,69,11,242,159,6,27,252,241,23,97,231,242,43,161,211,229,178,182,255,95,240,208,249,72,52,162,0,112,255,239,253,76,82,243,30,124,211,166,1,230,255,190,27,37,203,169,177,69,10,78,255,83,254,241,35,88,5,34,169,63,10,237,175,57,97,80,254,19,26,246,254,19,34,80,0,120,109,37,76,220,243,211,219,118,7,239,170,225,20,255,54,31,211,60,49,191,23,165,77,35,5,195,42,109,38,76,183,126,61,184,18,93,2,15,249,174,14,9,240,192,84,136,23,192,253,239,13,6,242,251,63,120,10,40,249,204,2,71,236,137,250,58,238,116,253,199,186,218,242,205,241,236,238,134,230,120,169,214,28,178,5,210,47,246,74,14,22,121,225,191,176,96,83,172,226,240,77,246,91,231,217,37,22,58,248,29,247,78,60,155,42,41,186,97,25,14,53,234,193,226,194,148,237,131,23,186,94,221,231,255,247,56,229,72,251,150,3,71,69,187,255,119,241,139,35,63,193,187,163,93,23,216,246,182,30,42,221,225,93,164,99,231,212,27,253,212,206,12,76,57,57,91,60,22,173,147,4,54,8,123,4,229,10,0,16,131,8,46,34,218,184,162,186,130,215,173,235,214,251,43,242,253,244,10,178,111,209,144,23,123,32,134,40,138,220,204,247,231,75,239,255,220,2,79,253,80,199,232,180,73,228,39,73,78,7,122,89,72,15,147,2,253,99,90,240,147,37,109,3,56,10,167,88,118,233,0,70,228,14,252,78,1,10,223,104,131,235,100,213,208,8,251,253,146,236,198,0,33,170,232,241,158,86,20,182,60,83,69,251,200,74,51,65,204,249,126,44,2,249,119,15,96,242,91,27,61,228,141,81,36,232,221,185,222,182,187,96,124,64,139,12,238,79,101,158,119,176,132,17,9,236,34,254,22,231,50,248,11,216,207,253,233,169,189,168,231,11,94,182,162,29,151,57,106,178,207,24,73,236,125,5,56,218,31,4,135,170,162,43,153,13,29,218,126,25,241,190,29,89,147,85,118,183,93,68,72,57,11,5,162,19,220,76,6,63,158,178,196,189,237,185,219,189,168,22,224,223,44,19,231,34,224,8,140,251,79,165,36,6,193,10,194,249,95,8,238,242,90,170,152,217,220,251,86,147,190,4,121,28,150,0,98,0,2,6,23,2,21,68,98,165,123,252,92,83,78,177,225,12,48,249,241,223,42,172,186,239,231,237,18,186,102,21,5,5,136,0,25,73,11,82,242,96,157,44,2,5,246,237,49,242,212,29,247,254,93,8,195,252,13,248,144,243,1,77,215,10,254,255,66,4,104,0,141,229,39,177,122,11,179,247,220,255,244,4,88,37,214,36,114,37,84,86,3,54,152,24,233,253,206,177,180,16,180,248,64,254,225,188,224,160,164,55,177,202,208,173,223,8,35,45,170,245,77,60,19,238,206,72,53,239,146,253,160,177,73,16,195,70,132,250,154,53,223,248,25,192,120,35,232,2,5,86,125,0,42,42,172,37,241,198,209,183,134,198,166,43,238,174,186,254,46,163,0,24,229,30,90,2,4,6,6,230,234,25,117,206,148,83,49,81,73,229,156,16,205,173,252,21,255,72,52,93,136,32,66,70,72,22,131,235,83,185,213,253,147,12,203,23,152,55,3,236,208,187,4,180,127,210,174,171,38,44,74,60,246,99,121,26,197,151,107,83,204,223,245,22,44,242,191,23,249,245,43,10,105,246,45,21,2,208,100,181,198,21,71,249,231,152,144,163,120,89,163,254,203,14,141,8,77,251,220,20,177,12,167,167,104,0,128,249,244,212,215,244,13,175,15,162,188,77,89,89,79,227,207,183,232,198,48,223,91,205,193,14,118,15,47,32,14,80,177,228,79,251,96,255,179,249,231,252,23,222,61,2,8,3,201,16,54,241,149,79,194,23,55,235,32,184,57,73,159,9,2,49,187,225,202,225,121,247,66,43,144,237,103,86,33,7,225,160,240,15,223,5,22,181,223,249,13,0,199,254,119,1,62,1,193,253,240,9,178,0,102,0,40,0,132,193,239,150,144,19,248,12,174,2,135,4,155,100,6,105,62,2,214,232,180,240,127,5,68,220,15,226,197,244,64,223,25,183,32,103,235,226,136,185,36,184,98,34,52,247,130,170,171,30,253,45,93,107,209,205,126,250,134,76,192,8,59,23,239,43,108,62,157,230,216,94,169,84,173,183,43,38,150,25,86,245,78,1,203,239,40,6,254,212,89,0,147,160,178,233,40,30,198,5,164,83,63,158,63,223,9,0,112,246,234,39,44,206,49,193,137,4,220,172,203,221,163,199,122,166,36,198,69,10,20,54,172,227,27,11,89,218,66,11,223,198,177,95,94,253,126,230,158,1,219,164,161,172,198,1,56,8,88,231,135,42,167,70,81,251,175,0,19,254,206,253,77,245,118,0,206,251,93,0,229,216,21,240,89,146,164,86,229,58,132,253,227,237,232,191,213,220,62,176,168,210,60,174,207,18,20,62,174,94,190,202,254,243,221,251,188,229,2,18,172,182,77,196,211,190,180,93,245,59,94,253,158,241,175,84,123,17,200,208,148,18,33,10,234,20,113,23,215,58,122,103,249,162,157,188,32,27,122,1,182,2,158,2,96,91,121,221,135,198,120,29,148,252,80,43,56,14,8,13,65,88,89,242,232,246,143,255,28,1,2,27,25,12,187,39,238,25,67,183,168,9,88,23,46,43,96,209,165,253,105,253,47,63,57,64,108,51,53,240,59,18,7,29,138,75,174,60,123,230,145,6,7,237,152,66,131,66,20,2,136,181,95,250,246,235,61,4,183,206,55,187,14,8,12,157,65,74,7,193,72,39,248,173,190,202,123,244,7,60,222,77,120,253,187,249,62,39,200,249,240,51,96,77,226,251,248,41,26,2,106,97,158,37,164,220,141,216,226,11,12,158,12,162,147,54,100,0,147,25,251,26,119,27,108,40,223,92,34,186,247,166,64,248,143,250,254,242,51,36,237,55,246,199,129,240,226,11,126,63,105,188,174,37,111,172,76,92,133,65,204,2,103,10,114,0,184,181,34,244,38,6,11,255,183,5,231,252,138,87,145,91,211,198,238,253,158,67,49,53,194,210,255,30,126,201,169,91,204,159,182,103,235,251,95,14,86,247,76,41,7,82,138,241,103,195,197,0,78,65,229,159,81,19,5,0,29,42,239,16,166,104,157,220,232,192,232,244,203,62,220,161,163,240,79,229,101,49,139,228,48,8,28,156,78,223,158,26,11,0,154,4,184,209,185,253,71,221,193,175,25,215,132,254,73,246,201,96,121,171,115,180,124,6,36,253,9,9,111,53,245,15,229,95,115,96,69,173,194,246,8,254,222,239,182,214,116,92,169,7,155,79,145,69,222,218,149,14,246,181,108,231,240,240,162,65,95,252,170,176,181,186,141,26,143,48,190,23,248,211,142,199,1,27,180,91,212,29,137,249,233,89,223,41,156,223,70,3,145,222,45,251,80,185,57,15,221,62,210,5,254,241,84,32,61,59,49,241,99,173,205,6,111,238,235,84,62,9,234,254,72,237,189,60,174,165,116,202,244,29,104,63,56,94,177,58,181,177,21,50,64,177,51,65,121,210,47,193,199,206,15,79,168,13,11,246,167,229,182,209,89,17,132,30,47,81,184,66,3,45,85,218,190,96,46,33,254,164,66,243,93,43,48,228,133,216,57,226,120,169,129,184,21,104,78,37,51,156,221,1,194,30,254,249,99,4,88,255,214,1,106,38,165,254,137,93,115,215,5,219,0,240,26,218,56,229,216,171,109,81,6,28,250,20,20,38,43,163,90,251,0,2,254,249,18,252,194,216,151,206,34,75,2,249,134,252,4,59,68,92,226,194,38,246,77,251,211,250,18,227,211,245,71,4,9,255,39,254,177,0,153,31,4,0,136,48,244,168,165,40,208,225,180,86,23,42,77,236,178,2,22,2,44,255,175,243,118,250,61,190,250,71,205,61,172,89,49,22,75,247,124,12,170,242,199,170,41,198,19,0,19,3,8,4,170,0,153,223,123,253,142,252,241,246,31,150,176,1,216,238,219,5,182,250,213,209,180,255,100,176,203,215,64,44,211,0,111,237,189,237,235,228,30,203,143,56,155,23,140,20,53,254,50,254,143,0,191,255,244,245,88,28,11,243,252,35,112,165,250,216,206,158,196,218,186,73,213,23,125,9,110,199,122,32,229,8,112,55,184,13,25,101,240,85,208,0,250,78,231,254,54,159,193,255,97,251,71,4,110,232,146,10,81,170,161,245,51,2,23,0,214,232,243,0,227,220,225,20,78,80,150,195,155,49,64,16,79,43,141,80,80,215,3,82,171,255,236,222,194,0,235,3,213,218,75,179,249,242,255,200,246,13,171,164,101,253,228,247,161,13,136,243,89,180,27,2,6,250,184,28,147,196,68,88,169,75,19,4,243,64,176,248,99,254,211,4,100,235,34,242,143,85,251,30,40,248,72,66,113,229,209,114,85,246,235,202,197,32,172,163,181,169,158,200,39,200,201,210,134,177,184,62,200,248,105,61,148,17,9,15,59,191,193,78,93,173,98,30,88,46,109,230,7,251,107,182,46,212,116,45,20,4,224,9,221,229,3,186,158,211,226,236,16,252,217,4,164,16,15,9,223,23,157,13,241,78,198,11,24,244,196,20,69,238,95,81,254,33,2,249,165,198,22,1,132,54,175,216,205,214,52,167,235,224,126,251,253,53,52,250,33,251,107,227,153,253,38,51,239,73,169,38,172,5,248,9,222,246,96,13,234,237,116,43,128,179,139,212,183,175,153,213,225,213,225,174,177,26,216,3,9,197,143,22,37,98,1,21,169,178,5,2,216,51,222,226,81,249,132,80,131,232,87,172,195,51,197,174,137,52,129,67,48,51,61,194,136,192,53,90,59,240,253,223,103,3,70,2,27,49,119,173,82,198,29,220,53,22,222,16,16,249,161,44,157,186,63,217,65,2,125,23,190,65,247,68,90,155,208,238,34,242,80,202,99,191,52,14,254,242,157,173,242,193,165,25,117,212,201,33,198,204,49,91,3,203,18,246,170,220,122,226,56,114,117,14,129,254,140,214,163,97,101,7,238,223,184,81,174,192,156,20,86,65,163,41,228,77,65,237,132,180,236,253,172,219,208,108,101,19,15,255,24,2,3,253,30,175,172,242,182,73,205,10,140,5,13,244,148,10,178,181,181,254,209,13,116,0,190,242,238,178,147,11,118,37,52,18,217,76,207,194,251,230,7,69,20,15,216,223,27,180,115,17,156,1,47,186,155,224,179,2,101,188,252,13,59,9,230,26,179,14,235,24,214,175,178,188,203,200,140,250,125,162,181,32,7,207,119,224,35,172,234,194,142,12,169,31,179,232,247,16,49,20,123,10,74,190,230,235,82,191,204,24,84,214,195,50,100,156,182,169,251,15,192,244,82,223,176,232,250,188,178,245,92,90,25,236,55,200,157,168,237,84,105,14,145,11,117,246,181,186,67,98,147,10,58,6,7,0,53,184,50,35,174,16,219,2,86,254,128,253,113,163,156,96,10,22,100,2,204,254,60,252,1,253,244,4,225,0,99,6,173,0,148,3,79,21,93,25,38,19,64,41,1,90,12,189,67,67,194,173,228,182,72,19,164,242,29,13,146,250,128,60,70,170,237,198,59,5,30,2,46,229,50,247,218,208,253,243,243,177,114,175,245,248,255,45,63,5,213,34,181,2,177,95,150,171,246,36,73,18,38,36,121,225,32,62,73,234,54,244,47,220,189,250,237,167,68,50,146,254,212,19,65,249,203,79,229,254,149,244,162,248,87,231,85,252,223,247,137,250,185,13,167,243,231,253,45,236,4,44,196,75,221,3,41,9,57,16,137,22,79,239,233,0,113,254,122,170,142,251,166,191,14,23,112,21,117,243,23,39,14,207,141,73,196,81,122,251,254,6,115,251,150,19,81,251,15,25,30,223,210,173,100,7,50,242,231,14,42,233,43,64,64,79,152,245,149,210,205,239,121,184,74,167,0,58,104,67,179,40,84,30,8,47,12,74,221,9,85,172,3,183,111,213,16,17,117,228,187,17,218,249,2,8,128,22,180,96,111,62,14,69,230,253,173,166,59,43,61,40,129,1,16,2,239,222,47,244,27,192,59,165,107,64,70,14,208,22,63,2,114,46,155,7,69,98,253,25,225,25,68,242,84,248,10,15,122,254,140,255,85,70,164,81,243,55,59,226,86,213,26,46,7,237,140,244,234,203,121,225,118,84,219,8,189,253,41,219,20,253,183,172,79,48,73,32,131,223,95,5,73,186,105,11,102,35,30,86,222,71,187,33,33,250,142,246,137,184,114,198,85,244,25,59,253,242,28,87,54,54,185,202,242,22,174,181,227,60,86,44,254,174,179,7,45,6,213,228,64,172,151,9,65,0,158,1,3,2,140,238,103,253,192,237,125,0,234,180,247,83,179,176,176,248,122,248,45,255,2,252,69,20,38,208,17,249,2,164,62,238,181,22,65,1,69,231,54,57,63,27,19,249,99,3,10,202,108,12,247,30,188,1,96,76,74,12,252,229,220,47,76,248,0,68,40,161,100,205,23,253,20,56,173,251,190,92,97,218,88,184,108,71,27,225,149,226,174,74,41,30,141,206,134,7,253,58,208,205,105,8,127,84,72,7,174,247,120,91,160,66,19,195,248,249,87,0,122,32,208,209,245,56,145,175,211,30,205,247,144,76,30,89,104,188,8,248,29,1,233,240,234,223,110,184,228,41,80,202,99,203,126,249,15,56,16,19,190,177,196,3,131,239,76,255,234,159,5,191,12,77,37,23,169,18,62,17,65,246,197,91,243,192,102,11,242,251,38,248,30,74,20,246,31,52,125,5,206,231,144,251,185,9,102,53,110,88,113,227,127,255,24,245,118,201,135,65,228,89,216,2,69,13,162,0,222,11,225,3,70,34,47,170,47,230,142,3,100,207,142,168,190,245,81,235,64,76,144,38,137,248,158,184,182,183,142,197,152,18,207,27,106,32,94,244,30,101,236,29,39,225,252,3,244,23,23,59,69,73,206,160,127,230,29,230,244,30,93,47], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+92160);
/* memory initializer */ allocate([13,219,102,162,126,21,169,3,96,189,3,235,218,9,71,1,105,4,122,254,158,61,243,77,116,215,164,43,221,243,5,58,128,209,101,224,248,185,241,168,171,188,109,229,194,205,132,247,147,230,39,23,170,48,173,168,15,254,66,1,14,4,13,230,228,234,87,79,59,4,56,166,210,222,98,47,6,253,63,10,203,19,0,77,147,248,226,255,187,254,85,0,219,3,58,233,116,16,186,220,161,35,50,158,68,225,116,28,252,207,114,50,168,171,205,81,162,249,242,225,117,247,179,222,28,234,148,157,244,229,132,1,249,167,246,5,122,35,193,0,69,225,220,168,43,20,106,1,176,3,253,254,240,14,182,209,167,29,120,165,254,98,219,92,248,214,27,16,137,173,181,82,167,87,186,252,141,237,35,85,40,24,134,255,106,6,51,253,184,95,175,77,5,248,218,3,7,0,201,255,79,149,121,255,133,9,3,1,89,0,51,1,126,95,223,240,241,234,204,252,173,246,105,1,153,21,152,22,250,72,242,0,120,170,93,240,32,87,131,17,210,2,46,208,146,29,88,60,225,33,193,11,213,79,116,82,148,173,248,243,148,251,145,10,223,248,44,21,239,252,100,72,36,66,51,203,131,191,246,197,153,176,115,200,171,8,100,5,226,83,152,251,71,1,83,0,127,247,13,84,240,240,156,200,52,255,113,247,185,3,46,219,2,62,42,214,97,243,38,82,91,254,159,250,128,2,209,223,16,174,126,8,213,16,82,72,116,220,113,184,98,195,120,14,201,232,193,1,61,223,51,4,62,169,128,236,137,11,244,49,109,71,150,5,89,58,227,84,159,244,145,1,125,237,119,177,163,6,133,251,121,13,121,20,149,34,118,86,133,226,171,5,150,247,136,33,200,70,2,195,119,75,153,232,173,13,25,11,9,23,253,24,182,33,234,89,163,9,140,11,123,1,71,22,225,169,115,247,189,189,174,253,134,73,81,235,104,6,6,3,80,11,112,250,2,14,12,247,198,77,226,248,113,183,227,82,79,201,227,206,82,64,123,2,50,248,142,180,113,191,176,47,64,191,82,225,54,218,244,3,115,171,67,11,88,206,17,9,19,252,215,1,211,241,109,31,177,212,189,99,45,16,32,172,143,245,244,2,105,253,245,253,90,25,83,33,89,75,5,74,204,23,125,219,69,66,23,96,200,54,88,39,232,253,58,215,45,224,97,8,12,166,79,189,75,21,207,238,231,197,40,80,129,184,11,218,147,209,89,186,14,247,216,200,22,8,195,87,135,6,213,2,166,222,37,57,193,13,159,175,17,26,8,32,24,79,58,17,170,250,183,253,205,4,111,246,43,29,20,228,99,53,202,223,120,87,88,188,116,248,35,15,152,220,28,241,190,3,9,1,209,238,143,11,217,193,142,76,90,19,175,251,89,70,61,217,39,185,234,240,170,43,189,22,252,198,53,251,188,37,115,84,220,43,55,210,47,253,92,249,109,0,162,247,61,0,140,229,213,159,8,168,232,21,91,248,31,249,12,252,80,163,157,238,128,245,169,198,86,239,191,38,47,33,130,252,214,79,4,202,141,188,139,0,236,25,15,238,93,55,111,188,117,191,96,3,74,14,12,88,104,0,29,249,172,255,6,0,76,84,105,186,142,227,217,249,226,247,192,254,71,247,33,39,88,245,90,58,184,202,5,187,228,249,182,186,39,181,167,53,197,10,135,11,168,17,134,21,225,28,47,42,31,75,54,202,143,1,160,11,181,251,149,19,121,251,79,86,40,14,201,246,72,18,66,247,174,88,181,14,151,239,163,223,102,229,154,207,18,184,22,60,178,235,43,229,193,216,84,223,106,193,174,175,114,255,113,167,144,254,39,17,48,254,243,255,46,3,162,251,191,251,253,169,74,0,17,6,174,249,22,75,22,187,78,203,74,3,251,246,81,18,106,64,77,81,229,195,188,239,128,240,20,243,206,43,26,203,31,53,239,179,202,53,25,7,86,3,233,82,58,252,149,249,244,254,229,245,149,255,70,177,120,1,150,4,208,254,153,244,197,1,242,234,238,2,238,169,46,252,188,181,199,65,16,39,4,242,163,8,179,5,83,5,158,245,223,255,29,240,141,4,31,170,112,222,56,245,144,187,143,193,49,58,43,5,140,2,141,219,181,12,226,198,149,47,236,76,39,231,141,22,221,195,139,67,206,64,150,244,107,253,167,253,73,6,82,88,224,3,235,251,97,19,147,35,217,43,149,30,192,63,195,72,144,170,103,250,138,0,190,5,157,248,60,255,213,179,229,184,48,43,252,253,239,9,55,247,84,251,90,187,182,78,198,44,111,254,59,10,30,18,38,224,115,46,113,194,207,68,149,197,173,255,22,1,67,1,55,0,102,255,232,0,108,30,182,5,219,71,192,59,109,194,149,251,0,0,0,0,0,0,0,0,0,0,0,0,212,216,43,81,230,42,48,238,30,3,188,255,42,43,10,80,39,230,34,235,251,248,161,249,137,15,226,253,206,27,114,251,156,73,86,57,32,239,160,255,129,227,20,254,222,169,75,239,132,10,224,22,154,21,102,85,212,227,51,235,121,255,161,164,194,3,179,31,124,253,126,1,229,249,72,13,29,243,85,18,20,229,126,87,207,13,214,11,128,28,70,24,252,79,189,208,57,0,89,229,56,7,179,168,225,232,167,26,203,252,185,241,125,254,147,231,57,249,155,168,98,232,50,6,54,182,200,199,254,35,193,2,172,233,8,1,212,185,26,57,241,30,175,254,146,255,108,0,8,0,74,0,167,255,206,255,212,25,19,250,183,84,134,249,243,224,10,255,163,84,65,231,158,223,155,255,187,250,234,255,13,170,180,230,38,31,136,2,6,8,181,254,215,208,96,2,149,228,78,2,160,15,101,3,36,26,73,61,222,231,233,219,182,255,133,0,63,7,35,252,116,80,152,244,133,238,225,0,86,251,195,240,203,252,90,230,149,252,182,176,54,245,147,243,2,240,9,234,207,189,37,38,11,6,183,26,188,7,9,79,209,251,134,236,77,24,5,186,116,234,122,24,102,1,138,4,169,14,214,251,187,16,101,243,56,62,202,39,255,27,131,18,82,4,173,16,172,40,212,18,186,233,141,243,109,199,144,250,21,248,81,3,121,2,55,24,97,27,21,206,254,246,180,245,68,250,137,228,168,29,121,41,198,232,10,244,10,0,0,0,10,0,0,0,10,0,0,0,5,0,0,0,5,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,40,232,34,0,108,0,0,0,48,115,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,253,255,32,64,38,1,253,0,254,254,29,63,41,2,253,0,254,254,26,63,43,4,252,0,254,253,24,62,46,5,252,0,254,253,21,60,49,7,252,0,255,252,18,59,51,9,252,0,255,252,16,57,53,12,252,255,255,252,14,55,55,14,252,255,255,252,12,53,57,16,252,255,0,252,9,51,59,18,252,255,0,252,7,49,60,21,253,254,0,252,5,46,62,24,253,254,0,252,4,43,63,26,254,254,0,253,2,41,63,29,254,254,0,253,1,38,64,32,255,253,0,1,251,126,8,253,1,0,255,3,246,122,18,250,2,0,255,4,243,118,27,247,3,255,255,4,240,112,37,245,4,255,255,5,238,105,48,242,4,255,255,5,237,97,58,240,5,255,255,6,237,88,68,238,5,255,255,6,237,78,78,237,6,255,255,5,238,68,88,237,6,255,255,5,240,58,97,237,5,255,255,4,242,48,105,238,5,255,255,4,245,37,112,240,4,255,255,3,247,27,118,243,4,255,0,2,250,18,122,246,3,255,0,1,253,8,126,251,1,0,255,3,249,127,8,253,1,0,254,5,243,125,17,250,3,255,253,7,239,121,27,246,5,254,252,9,236,115,37,243,6,254,252,10,233,108,48,240,8,253,252,10,232,100,59,237,9,253,252,11,232,90,70,235,10,252,252,11,233,80,80,233,11,252,252,10,235,70,90,232,11,252,253,9,237,59,100,232,10,252,253,8,240,48,108,233,10,252,254,6,243,37,115,236,9,252,254,5,246,27,121,239,7,253,255,3,250,17,125,243,5,254,0,1,253,8,127,249,3,255,1,2,3,4,5,6,0,255,254,253,252,251,250,249,0,0,0,170,1,0,240,215,1,0,128,153,1,0,0,170,1,0,128,168,1,0,112,214,1,0,0,152,1,0,128,168,1,0,96,194,1,0,80,216,1,0,224,153,1,0,96,194,1,0,96,170,1,0,96,170,1,0,96,170,1,0,96,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,64,170,1,0,48,216,1,0,192,153,1,0,64,170,1,0,128,169,1,0,112,215,1,0,0,153,1,0,128,169,1,0,96,198,1,0,80,220,1,0,224,157,1,0,96,198,1,0,96,186,1,0,96,186,1,0,96,186,1,0,96,186,1,0,64,170,1,0,64,170,1,0,64,170,1,0,64,170,1,0,0,0,0,0,8,0,8,0,0,0,0,0,1,0,1,0,16,0,16,0,1,0,1,0,9,0,9,0,24,0,24,0,2,0,2,0,17,0,17,0,2,0,2,0,32,0,32,0,10,0,10,0,3,0,3,0,25,0,25,0,18,0,18,0,11,0,11,0,3,0,3,0,40,0,40,0,33,0,33,0,26,0,26,0,4,0,4,0,19,0,19,0,48,0,48,0,12,0,12,0,4,0,4,0,34,0,34,0,27,0,27,0,5,0,5,0,41,0,41,0,20,0,20,0,5,0,5,0,13,0,13,0,35,0,35,0,28,0,28,0,6,0,6,0,42,0,42,0,21,0,21,0,49,0,49,0,6,0,6,0,36,0,36,0,14,0,14,0,29,0,29,0,43,0,43,0,7,0,7,0,50,0,50,0,22,0,22,0,15,0,15,0,37,0,37,0,44,0,44,0,30,0,30,0,51,0,51,0,23,0,23,0,38,0,38,0,45,0,45,0,31,0,31,0,52,0,52,0,39,0,39,0,53,0,53,0,46,0,46,0,54,0,54,0,47,0,47,0,55,0,55,0,0,0,0,0,0,0,8,0,16,0,1,0,9,0,24,0,2,0,17,0,32,0,10,0,25,0,3,0,40,0,18,0,11,0,33,0,26,0,19,0,4,0,48,0,41,0,34,0,12,0,27,0,56,0,20,0,5,0,42,0,35,0,13,0,49,0,28,0,6,0,21,0,43,0,36,0,14,0,50,0,29,0,57,0,7,0,44,0,22,0,37,0,51,0,15,0,58,0,30,0,23,0,45,0,52,0,38,0,59,0,31,0,46,0,53,0,39,0,60,0,47,0,61,0,54,0,62,0,55,0,63,0,0,0,0,0,0,0,0,0,4,0,4,0,1,0,1,0,8,0,8,0,5,0,5,0,1,0,1,0,2,0,2,0,9,0,9,0,2,0,2,0,6,0,6,0,3,0,3,0,10,0,10,0,7,0,7,0,11,0,11,0,0,0,0,0,0,0,4,0,1,0,8,0,5,0,12,0,9,0,2,0,6,0,13,0,3,0,10,0,7,0,14,0,11,0,15,0,0,0,0,0,16,0,16,0,0,0,0,0,32,0,32,0,1,0,1,0,48,0,48,0,17,0,17,0,1,0,1,0,64,0,64,0,2,0,2,0,33,0,33,0,80,0,80,0,18,0,18,0,2,0,2,0,49,0,49,0,3,0,3,0,96,0,96,0,34,0,34,0,65,0,65,0,19,0,19,0,3,0,3,0,112,0,112,0,50,0,50,0,4,0,4,0,81,0,81,0,35,0,35,0,66,0,66,0,4,0,4,0,128,0,128,0,20,0,20,0,51,0,51,0,97,0,97,0,82,0,82,0,5,0,5,0,36,0,36,0,144,0,144,0,67,0,67,0,113,0,113,0,21,0,21,0,52,0,52,0,5,0,5,0,98,0,98,0,160,0,160,0,83,0,83,0,37,0,37,0,6,0,6,0,68,0,68,0,129,0,129,0,22,0,22,0,53,0,53,0,114,0,114,0,6,0,6,0,99,0,99,0,176,0,176,0,84,0,84,0,38,0,38,0,7,0,7,0,69,0,69,0,145,0,145,0,130,0,130,0,115,0,115,0,23,0,23,0,54,0,54,0,192,0,192,0,100,0,100,0,7,0,7,0,85,0,85,0,161,0,161,0,39,0,39,0,70,0,70,0,8,0,8,0,146,0,146,0,131,0,131,0,116,0,116,0,55,0,55,0,208,0,208,0,101,0,101,0,24,0,24,0,86,0,86,0,8,0,8,0,132,0,132,0,40,0,40,0,71,0,71,0,177,0,177,0,147,0,147,0,224,0,224,0,117,0,117,0,162,0,162,0,9,0,9,0,102,0,102,0,56,0,56,0,25,0,25,0,87,0,87,0,148,0,148,0,9,0,9,0,133,0,133,0,72,0,72,0,118,0,118,0,193,0,193,0,163,0,163,0,41,0,41,0,103,0,103,0,178,0,178,0,10,0,10,0,57,0,57,0,149,0,149,0,134,0,134,0,88,0,88,0,26,0,26,0,119,0,119,0,10,0,10,0,164,0,164,0,104,0,104,0,73,0,73,0,209,0,209,0,179,0,179,0,42,0,42,0,11,0,11,0,194,0,194,0,135,0,135,0,165,0,165,0,150,0,150,0,58,0,58,0,27,0,27,0,89,0,89,0,11,0,11,0,120,0,120,0,74,0,74,0,43,0,43,0,225,0,225,0,105,0,105,0,12,0,12,0,180,0,180,0,151,0,151,0,195,0,195,0,136,0,136,0,28,0,28,0,166,0,166,0,121,0,121,0,59,0,59,0,12,0,12,0,210,0,210,0,90,0,90,0,106,0,106,0,44,0,44,0,181,0,181,0,75,0,75,0,152,0,152,0,13,0,13,0,167,0,167,0,137,0,137,0,13,0,13,0,60,0,60,0,196,0,196,0,122,0,122,0,29,0,29,0,91,0,91,0,14,0,14,0,182,0,182,0,76,0,76,0,211,0,211,0,153,0,153,0,14,0,14,0,107,0,107,0,138,0,138,0,45,0,45,0,226,0,226,0,168,0,168,0,197,0,197,0,123,0,123,0,30,0,30,0,61,0,61,0,15,0,15,0,92,0,92,0,154,0,154,0,183,0,183,0,169,0,169,0,108,0,108,0,212,0,212,0,77,0,77,0,139,0,139,0,198,0,198,0,46,0,46,0,124,0,124,0,227,0,227,0,62,0,62,0,31,0,31,0,184,0,184,0,93,0,93,0,170,0,170,0,155,0,155,0,185,0,185,0,78,0,78,0,47,0,47,0,199,0,199,0,213,0,213,0,140,0,140,0,63,0,63,0,109,0,109,0,125,0,125,0,94,0,94,0,200,0,200,0,171,0,171,0,156,0,156,0,228,0,228,0,186,0,186,0,214,0,214,0,201,0,201,0,79,0,79,0,141,0,141,0,110,0,110,0,229,0,229,0,95,0,95,0,126,0,126,0,215,0,215,0,172,0,172,0,111,0,111,0,142,0,142,0,202,0,202,0,157,0,157,0,216,0,216,0,230,0,230,0,217,0,217,0,187,0,187,0,127,0,127,0,231,0,231,0,158,0,158,0,173,0,173,0,143,0,143,0,203,0,203,0,188,0,188,0,232,0,232,0,218,0,218,0,233,0,233,0,159,0,159,0,174,0,174,0,204,0,204,0,189,0,189,0,234,0,234,0,219,0,219,0,175,0,175,0,205,0,205,0,235,0,235,0,220,0,220,0,190,0,190,0,236,0,236,0,206,0,206,0,191,0,191,0,221,0,221,0,207,0,207,0,237,0,237,0,222,0,222,0,238,0,238,0,223,0,223,0,239,0,239,0,0,0,0,0,0,0,16,0,32,0,1,0,48,0,17,0,64,0,33,0,2,0,80,0,18,0,49,0,96,0,34,0,3,0,65,0,19,0,112,0,50,0,81,0,35,0,4,0,128,0,66,0,20,0,97,0,51,0,82,0,5,0,144,0,36,0,67,0,113,0,98,0,21,0,52,0,160,0,83,0,129,0,37,0,68,0,6,0,114,0,176,0,99,0,53,0,22,0,84,0,145,0,38,0,69,0,130,0,7,0,115,0,192,0,100,0,54,0,23,0,85,0,161,0,146,0,131,0,39,0,70,0,208,0,116,0,8,0,101,0,177,0,55,0,86,0,24,0,162,0,147,0,132,0,71,0,224,0,117,0,40,0,102,0,9,0,148,0,56,0,87,0,193,0,163,0,240,0,133,0,178,0,25,0,118,0,72,0,41,0,103,0,164,0,10,0,149,0,88,0,134,0,209,0,179,0,57,0,119,0,194,0,26,0,73,0,165,0,150,0,104,0,42,0,135,0,11,0,180,0,120,0,89,0,225,0,195,0,58,0,27,0,210,0,151,0,181,0,166,0,74,0,43,0,105,0,12,0,136,0,90,0,59,0,241,0,121,0,28,0,196,0,167,0,211,0,152,0,44,0,182,0,137,0,75,0,13,0,226,0,106,0,122,0,60,0,197,0,91,0,168,0,29,0,183,0,153,0,14,0,76,0,212,0,138,0,45,0,107,0,15,0,198,0,92,0,227,0,169,0,30,0,123,0,154,0,61,0,242,0,184,0,213,0,139,0,46,0,77,0,31,0,108,0,170,0,199,0,185,0,124,0,228,0,93,0,155,0,214,0,62,0,140,0,243,0,78,0,47,0,200,0,109,0,186,0,171,0,201,0,94,0,63,0,215,0,229,0,156,0,79,0,125,0,141,0,110,0,216,0,187,0,172,0,244,0,202,0,230,0,217,0,95,0,157,0,126,0,245,0,111,0,142,0,231,0,188,0,127,0,158,0,218,0,173,0,232,0,246,0,233,0,203,0,143,0,247,0,174,0,189,0,159,0,219,0,204,0,248,0,234,0,249,0,175,0,190,0,220,0,205,0,250,0,235,0,191,0,221,0,251,0,236,0,206,0,252,0,222,0,207,0,237,0,223,0,253,0,238,0,254,0,239,0,255,0,0,1,255,2,254,253,0,0,0,1,255,2,254,253,0,0,0,1,255,2,254,253,0,0,0,1,255,2,3,4,254,253,5,6,252,251,250,7,8,9,249,248,247,246,0,0,0,0,6,86,128,11,87,42,91,52,3,86,128,6,86,23,88,29,6,86,128,11,87,42,91,52,9,86,129,17,88,61,94,76,12,86,129,22,88,77,97,93,15,87,129,28,89,93,100,110,17,87,129,33,90,105,103,123,20,88,130,38,91,118,106,136,23,88,130,43,91,128,108,146,26,89,131,48,92,139,111,156,28,89,131,53,93,147,114,163,31,90,131,58,94,156,117,171,34,90,131,62,94,163,119,177,37,90,132,66,95,171,122,184,39,90,132,70,96,177,124,189,42,91,132,75,97,183,127,194,44,91,132,79,97,188,129,198,47,92,133,83,98,193,132,202,49,92,133,86,99,197,134,205,52,93,133,90,100,201,137,208,54,93,133,94,100,204,139,211,57,94,134,98,101,208,142,214,59,94,134,101,102,211,144,216,62,94,135,105,103,214,146,218,64,94,135,108,103,216,148,220,66,95,135,111,104,219,151,222,68,95,135,114,105,221,153,223,71,96,136,117,106,224,155,225,73,96,136,120,106,225,157,226,76,97,136,123,107,227,159,228,78,97,136,126,108,229,160,229,80,98,137,129,109,231,162,231,82,98,137,131,109,232,164,232,84,98,138,134,110,234,166,233,86,98,138,137,111,235,168,234,89,99,138,140,112,236,170,235,91,99,138,142,112,237,171,235,93,100,139,145,113,238,173,236,95,100,139,147,114,239,174,237,97,101,140,149,115,240,176,238,99,101,140,151,115,241,177,238,101,102,140,154,116,242,179,239,103,102,140,156,117,242,180,239,105,103,141,158,118,243,182,240,107,103,141,160,118,243,183,240,109,104,141,162,119,244,185,241,111,104,141,164,119,244,186,241,113,104,142,166,120,245,187,242,114,104,142,168,121,245,188,242,116,105,143,170,122,246,190,243,118,105,143,171,122,246,191,243,120,106,143,173,123,247,192,244,121,106,143,175,124,247,193,244,123,107,144,177,125,248,195,244,125,107,144,178,125,248,196,244,127,108,145,180,126,249,197,245,128,108,145,181,127,249,198,245,130,109,145,183,128,249,199,245,132,109,145,184,128,249,200,245,134,110,146,186,129,250,201,246,135,110,146,187,130,250,202,246,137,111,147,189,131,251,203,246,138,111,147,190,131,251,204,246,140,112,147,192,132,251,205,247,141,112,147,193,132,251,206,247,143,113,148,194,133,251,207,247,144,113,148,195,134,251,207,247,146,114,149,197,135,252,208,248,147,114,149,198,135,252,209,248,149,115,149,199,136,252,210,248,150,115,149,200,137,252,210,248,152,115,150,201,138,252,211,248,153,115,150,202,138,252,212,248,155,116,151,204,139,253,213,249,156,116,151,205,139,253,213,249,158,117,151,206,140,253,214,249,159,117,151,207,141,253,215,249,161,118,152,208,142,253,216,249,162,118,152,209,142,253,216,249,163,119,153,210,143,253,217,249,164,119,153,211,143,253,217,249,166,120,153,212,144,254,218,250,167,120,153,212,145,254,219,250,168,121,154,213,146,254,220,250,169,121,154,214,146,254,220,250,171,122,155,215,147,254,221,250,172,122,155,216,147,254,221,250,173,123,155,217,148,254,222,250,174,123,155,217,149,254,222,250,176,124,156,218,150,254,223,250,177,124,156,219,150,254,223,250,178,125,157,220,151,254,224,251,179,125,157,220,151,254,224,251,180,126,157,221,152,254,225,251,181,126,157,221,152,254,225,251,183,127,158,222,153,254,226,251,184,127,158,223,154,254,226,251,185,128,159,224,155,255,227,251,186,128,159,224,155,255,227,251,187,129,160,225,156,255,228,251,188,130,160,225,156,255,228,251,189,131,160,226,157,255,228,251,190,131,160,226,158,255,228,251,191,132,161,227,159,255,229,251,192,132,161,227,159,255,229,251,193,133,162,228,160,255,230,252,194,133,162,229,160,255,230,252,195,134,163,230,161,255,231,252,196,134,163,230,161,255,231,252,197,135,163,231,162,255,231,252,198,135,163,231,162,255,231,252,199,136,164,232,163,255,232,252,200,136,164,232,164,255,232,252,201,137,165,233,165,255,233,252,201,137,165,233,165,255,233,252,202,138,166,233,166,255,233,252,203,138,166,233,166,255,233,252,204,139,166,234,167,255,234,252,205,139,166,234,167,255,234,252,206,140,167,235,168,255,235,252,206,140,167,235,168,255,235,252,207,141,168,236,169,255,235,252,208,141,168,236,170,255,235,252,209,142,169,237,171,255,236,252,209,143,169,237,171,255,236,252,210,144,169,237,172,255,236,252,211,144,169,237,172,255,236,252,212,145,170,238,173,255,237,252,213,145,170,238,173,255,237,252,214,146,171,239,174,255,237,253,214,146,171,239,174,255,237,253,215,147,172,240,175,255,238,253,215,147,172,240,175,255,238,253,216,148,173,240,176,255,238,253,217,148,173,240,176,255,238,253,218,149,173,241,177,255,239,253,218,149,173,241,178,255,239,253,219,150,174,241,179,255,239,253,219,151,174,241,179,255,239,253,220,152,175,242,180,255,240,253,221,152,175,242,180,255,240,253,222,153,176,242,181,255,240,253,222,153,176,242,181,255,240,253,223,154,177,243,182,255,240,253,223,154,177,243,182,255,240,253,224,155,178,244,183,255,241,253,224,155,178,244,183,255,241,253,225,156,178,244,184,255,241,253,225,157,178,244,184,255,241,253,226,158,179,244,185,255,242,253,227,158,179,244,185,255,242,253,228,159,180,245,186,255,242,253,228,159,180,245,186,255,242,253,229,160,181,245,187,255,242,253,229,160,181,245,187,255,242,253,230,161,182,246,188,255,243,253,230,162,182,246,188,255,243,253,231,163,183,246,189,255,243,253,231,163,183,246,189,255,243,253,232,164,184,247,190,255,243,253,232,164,184,247,190,255,243,253,233,165,185,247,191,255,244,253,233,165,185,247,191,255,244,253,234,166,185,247,192,255,244,253,234,167,185,247,192,255,244,253,235,168,186,248,193,255,244,253,235,168,186,248,193,255,244,253,236,169,187,248,194,255,244,253,236,169,187,248,194,255,244,253,236,170,188,248,195,255,245,253,236,170,188,248,195,255,245,253,237,171,189,249,196,255,245,254,237,172,189,249,196,255,245,254,238,173,190,249,197,255,245,254,238,173,190,249,197,255,245,254,239,174,191,249,198,255,245,254,239,174,191,249,198,255,245,254,240,175,192,249,199,255,246,254,240,176,192,249,199,255,246,254,240,177,193,250,200,255,246,254,240,177,193,250,200,255,246,254,241,178,194,250,201,255,246,254,241,178,194,250,201,255,246,254,242,179,195,250,202,255,246,254,242,180,195,250,202,255,246,254,242,181,196,250,203,255,247,254,242,181,196,250,203,255,247,254,243,182,197,251,204,255,247,254,243,183,197,251,204,255,247,254,244,184,198,251,205,255,247,254,244,184,198,251,205,255,247,254,244,185,199,251,206,255,247,254,244,185,199,251,206,255,247,254,245,186,200,251,207,255,247,254,245,187,200,251,207,255,247,254,246,188,201,252,207,255,248,254,246,188,201,252,207,255,248,254,246,189,202,252,208,255,248,254,246,190,202,252,208,255,248,254,247,191,203,252,209,255,248,254,247,191,203,252,209,255,248,254,247,192,204,252,210,255,248,254,247,193,204,252,210,255,248,254,248,194,205,252,211,255,248,254,248,194,205,252,211,255,248,254,248,195,206,252,212,255,249,254,248,196,206,252,212,255,249,254,249,197,207,253,213,255,249,254,249,197,207,253,213,255,249,254,249,198,208,253,214,255,249,254,249,199,209,253,214,255,249,254,250,200,210,253,215,255,249,254,250,200,210,253,215,255,249,254,250,201,211,253,215,255,249,254,250,202,211,253,215,255,249,254,250,203,212,253,216,255,249,254,250,203,212,253,216,255,249,254,251,204,213,253,217,255,250,254,251,205,213,253,217,255,250,254,251,206,214,254,218,255,250,254,251,206,215,254,218,255,250,254,252,207,216,254,219,255,250,254,252,208,216,254,219,255,250,254,252,209,217,254,220,255,250,254,252,210,217,254,220,255,250,254,252,211,218,254,221,255,250,254,252,212,218,254,221,255,250,254,253,213,219,254,222,255,250,254,253,213,220,254,222,255,250,254,253,214,221,254,223,255,250,254,253,215,221,254,223,255,250,254,253,216,222,254,224,255,251,254,253,217,223,254,224,255,251,254,253,218,224,254,225,255,251,254,253,219,224,254,225,255,251,254,254,220,225,254,225,255,251,254,254,221,226,254,225,255,251,254,254,222,227,255,226,255,251,254,254,223,227,255,226,255,251,254,254,224,228,255,227,255,251,254,254,225,229,255,227,255,251,254,254,226,230,255,228,255,251,254,254,227,230,255,229,255,251,254,255,228,231,255,230,255,251,254,255,229,232,255,230,255,251,254,255,230,233,255,231,255,252,254,255,231,234,255,231,255,252,254,255,232,235,255,232,255,252,254,255,233,236,255,232,255,252,254,255,235,237,255,233,255,252,254,255,236,238,255,234,255,252,254,255,238,240,255,235,255,252,255,255,239,241,255,235,255,252,254,255,241,243,255,236,255,252,254,255,243,245,255,237,255,252,254,255,246,247,255,239,255,253,255,254,1,247,2,0,3,4,6,255,5,252,251,253,7,249,8,250,248,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,1,246,2,245,243,0,0,0,1,255,254,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,8,0,1,0,8,0,8,0,9,0,2,0,2,0,2,0,16,0,9,0,16,0,16,0,17,0,10,0,10,0,3,0,3,0,3,0,24,0,17,0,24,0,24,0,18,0,11,0,11,0,4,0,25,0,18,0,4,0,4,0,32,0,25,0,19,0,12,0,26,0,19,0,32,0,32,0,12,0,5,0,33,0,26,0,5,0,5,0,40,0,33,0,27,0,20,0,20,0,13,0,34,0,27,0,41,0,34,0,40,0,40,0,13,0,6,0,6,0,6,0,35,0,28,0,28,0,21,0,42,0,35,0,48,0,48,0,48,0,41,0,21,0,14,0,14,0,7,0,36,0,29,0,49,0,42,0,43,0,36,0,56,0,49,0,29,0,22,0,22,0,15,0,50,0,43,0,44,0,37,0,57,0,50,0,37,0,30,0,30,0,23,0,51,0,44,0,58,0,51,0,38,0,31,0,45,0,38,0,52,0,45,0,59,0,52,0,46,0,39,0,53,0,46,0,60,0,53,0,54,0,47,0,61,0,54,0,62,0,55,0,0,0,0,0,0,0,1,0,8,0,2,0,9,0,16,0,10,0,3,0,17,0,24,0,18,0,11,0,4,0,25,0,32,0,19,0,12,0,26,0,5,0,33,0,20,0,27,0,40,0,13,0,34,0,6,0,41,0,28,0,21,0,35,0,42,0,48,0,14,0,7,0,36,0,29,0,43,0,56,0,49,0,22,0,15,0,37,0,50,0,44,0,57,0,30,0,23,0,51,0,45,0,58,0,38,0,31,0,52,0,59,0,39,0,46,0,53,0,60,0,47,0,54,0,61,0,55,0,62,0,63,0,0,0,0,0,0,0,0,0,4,0,1,0,1,0,1,0,4,0,4,0,2,0,2,0,5,0,2,0,8,0,8,0,8,0,5,0,6,0,3,0,9,0,6,0,12,0,9,0,10,0,7,0,13,0,10,0,14,0,11,0,0,0,0,0,0,0,1,0,4,0,5,0,2,0,8,0,3,0,6,0,12,0,9,0,7,0,10,0,13,0,11,0,14,0,15,0,0,0,0,0,0,0,0,0,1,0,1,0,32,0,1,0,32,0,32,0,2,0,2,0,33,0,2,0,64,0,33,0,3,0,3,0,64,0,64,0,34,0,3,0,65,0,34,0,4,0,4,0,35,0,4,0,96,0,65,0,66,0,35,0,96,0,96,0,97,0,66,0,67,0,36,0,36,0,5,0,5,0,5,0,128,0,97,0,98,0,67,0,6,0,6,0,128,0,128,0,68,0,37,0,37,0,6,0,129,0,98,0,99,0,68,0,160,0,129,0,130,0,99,0,38,0,7,0,69,0,38,0,7,0,7,0,100,0,69,0,161,0,130,0,131,0,100,0,160,0,160,0,70,0,39,0,39,0,8,0,8,0,8,0,101,0,70,0,162,0,131,0,132,0,101,0,192,0,161,0,71,0,40,0,192,0,192,0,102,0,71,0,40,0,9,0,163,0,132,0,9,0,9,0,193,0,162,0,133,0,102,0,164,0,133,0,72,0,41,0,103,0,72,0,134,0,103,0,224,0,193,0,41,0,10,0,194,0,163,0,10,0,10,0,224,0,224,0,165,0,134,0,225,0,194,0,195,0,164,0,73,0,42,0,104,0,73,0,135,0,104,0,42,0,11,0,11,0,11,0,166,0,135,0,196,0,165,0,226,0,195,0,0,1,225,0,74,0,43,0,105,0,74,0,136,0,105,0,227,0,196,0,43,0,12,0,197,0,166,0,167,0,136,0,1,1,226,0,0,1,0,1,12,0,12,0,228,0,197,0,75,0,44,0,106,0,75,0,198,0,167,0,137,0,106,0,2,1,227,0,168,0,137,0,32,1,1,1,44,0,13,0,229,0,198,0,3,1,228,0,199,0,168,0,107,0,76,0,13,0,13,0,169,0,138,0,138,0,107,0,32,1,32,1,33,1,2,1,76,0,45,0,230,0,199,0,4,1,229,0,45,0,14,0,200,0,169,0,139,0,108,0,34,1,3,1,108,0,77,0,231,0,200,0,64,1,33,1,5,1,230,0,170,0,139,0,77,0,46,0,35,1,4,1,14,0,14,0,65,1,34,1,201,0,170,0,6,1,231,0,64,1,64,1,171,0,140,0,36,1,5,1,232,0,201,0,140,0,109,0,66,1,35,1,109,0,78,0,46,0,15,0,202,0,171,0,7,1,232,0,233,0,202,0,37,1,6,1,96,1,65,1,67,1,36,1,15,0,15,0,78,0,47,0,203,0,172,0,8,1,233,0,38,1,7,1,68,1,37,1,172,0,141,0,97,1,66,1,141,0,110,0,234,0,203,0,96,1,96,1,47,0,16,0,39,1,8,1,110,0,79,0,9,1,234,0,98,1,67,1,69,1,38,1,79,0,48,0,16,0,16,0,204,0,173,0,235,0,204,0,173,0,142,0,99,1,68,1,128,1,97,1,70,1,39,1,142,0,111,0,40,1,9,1,10,1,235,0,100,1,69,1,129,1,98,1,111,0,80,0,48,0,17,0,71,1,40,1,41,1,10,1,205,0,174,0,128,1,128,1,236,0,205,0,101,1,70,1,130,1,99,1,80,0,49,0,174,0,143,0,17,0,17,0,72,1,41,1,102,1,71,1,131,1,100,1,42,1,11,1,73,1,42,1,132,1,101,1,112,0,81,0,160,1,129,1,237,0,206,0,103,1,72,1,49,0,18,0,206,0,175,0,161,1,130,1,133,1,102,1,74,1,43,1,18,0,18,0,160,1,160,1,104,1,73,1,81,0,50,0,162,1,131,1,134,1,103,1,238,0,207,0,50,0,19,0,105,1,74,1,163,1,132,1,113,0,82,0,192,1,161,1,192,1,192,1,164,1,133,1,82,0,51,0,106,1,75,1,193,1,162,1,165,1,134,1,224,1,224,1,194,1,163,1,166,1,135,1,114,0,83,0,195,1,164,1,224,1,193,1,196,1,165,1,225,1,194,1,197,1,166,1,0,2,0,2,226,1,195,1,198,1,167,1,0,2,225,1,227,1,196,1,1,2,226,1,228,1,197,1,2,2,227,1,229,1,198,1,32,2,1,2,32,2,32,2,230,1,199,1,33,2,2,2,34,2,3,2,64,2,64,2,64,2,33,2,65,2,34,2,66,2,35,2,96,2,65,2,97,2,66,2,98,2,67,2,19,0,19,0,143,0,112,0,11,1,236,0,135,1,104,1,3,2,228,1,96,2,96,2,20,0,20,0,51,0,20,0,144,0,113,0,175,0,144,0,12,1,237,0,43,1,12,1,136,1,105,1,167,1,136,1,4,2,229,1,35,2,4,2,128,2,97,2,128,2,128,2,21,0,21,0,52,0,21,0,83,0,52,0,145,0,114,0,176,0,145,0,207,0,176,0,13,1,238,0,44,1,13,1,75,1,44,1,137,1,106,1,168,1,137,1,199,1,168,1,5,2,230,1,36,2,5,2,67,2,36,2,129,2,98,2,160,2,129,2,160,2,160,2,22,0,22,0,53,0,22,0,84,0,53,0,115,0,84,0,146,0,115,0,177,0,146,0,208,0,177,0,239,0,208,0,14,1,239,0,45,1,14,1,76,1,45,1,107,1,76,1,138,1,107,1,169,1,138,1,200,1,169,1,231,1,200,1,6,2,231,1,37,2,6,2,68,2,37,2,99,2,68,2,130,2,99,2,161,2,130,2,192,2,161,2,192,2,192,2,54,0,23,0,85,0,54,0,116,0,85,0,178,0,147,0,209,0,178,0,240,0,209,0,46,1,15,1,77,1,46,1,108,1,77,1,170,1,139,1,201,1,170,1,232,1,201,1,38,2,7,2,69,2,38,2,100,2,69,2,162,2,131,2,193,2,162,2,224,2,193,2,86,0,55,0,117,0,86,0,210,0,179,0,241,0,210,0,78,1,47,1,109,1,78,1,202,1,171,1,233,1,202,1,70,2,39,2,101,2,70,2,194,2,163,2,225,2,194,2,118,0,87,0,242,0,211,0,110,1,79,1,234,1,203,1,102,2,71,2,226,2,195,2,23,0,23,0,147,0,116,0,15,1,240,0,139,1,108,1,7,2,232,1,131,2,100,2,224,2,224,2,24,0,24,0,55,0,24,0,148,0,117,0,179,0,148,0,16,1,241,0,47,1,16,1,140,1,109,1,171,1,140,1,8,2,233,1,39,2,8,2,132,2,101,2,163,2,132,2,0,3,225,2,0,3,0,3,25,0,25,0,56,0,25,0,87,0,56,0,149,0,118,0,180,0,149,0,211,0,180,0,17,1,242,0,48,1,17,1,79,1,48,1,141,1,110,1,172,1,141,1,203,1,172,1,9,2,234,1,40,2,9,2,71,2,40,2,133,2,102,2,164,2,133,2,195,2,164,2,1,3,226,2,32,3,1,3,32,3,32,3,26,0,26,0,57,0,26,0,88,0,57,0,119,0,88,0,150,0,119,0,181,0,150,0,212,0,181,0,243,0,212,0,18,1,243,0,49,1,18,1,80,1,49,1,111,1,80,1,142,1,111,1,173,1,142,1,204,1,173,1,235,1,204,1,10,2,235,1,41,2,10,2,72,2,41,2,103,2,72,2,134,2,103,2,165,2,134,2,196,2,165,2,227,2,196,2,2,3,227,2,33,3,2,3,64,3,33,3,64,3,64,3,58,0,27,0,89,0,58,0,120,0,89,0,182,0,151,0,213,0,182,0,244,0,213,0,50,1,19,1,81,1,50,1,112,1,81,1,174,1,143,1,205,1,174,1,236,1,205,1,42,2,11,2,73,2,42,2,104,2,73,2,166,2,135,2,197,2,166,2,228,2,197,2,34,3,3,3,65,3,34,3,96,3,65,3,90,0,59,0,121,0,90,0,214,0,183,0,245,0,214,0,82,1,51,1,113,1,82,1,206,1,175,1,237,1,206,1,74,2,43,2,105,2,74,2,198,2,167,2,229,2,198,2,66,3,35,3,97,3,66,3,122,0,91,0,246,0,215,0,114,1,83,1,238,1,207,1,106,2,75,2,230,2,199,2,98,3,67,3,27,0,27,0,151,0,120,0,19,1,244,0,143,1,112,1,11,2,236,1,135,2,104,2,3,3,228,2,96,3,96,3,28,0,28,0,59,0,28,0,152,0,121,0,183,0,152,0,20,1,245,0,51,1,20,1,144,1,113,1,175,1,144,1,12,2,237,1,43,2,12,2,136,2,105,2,167,2,136,2,4,3,229,2,35,3,4,3,128,3,97,3,128,3,128,3,29,0,29,0,60,0,29,0,91,0,60,0,153,0,122,0,184,0,153,0,215,0,184,0,21,1,246,0,52,1,21,1,83,1,52,1,145,1,114,1,176,1,145,1,207,1,176,1,13,2,238,1,44,2,13,2,75,2,44,2,137,2,106,2,168,2,137,2,199,2,168,2,5,3,230,2,36,3,5,3,67,3,36,3,129,3,98,3,160,3,129,3,160,3,160,3,30,0,30,0,61,0,30,0,92,0,61,0,123,0,92,0,154,0,123,0,185,0,154,0,216,0,185,0,247,0,216,0,22,1,247,0,53,1,22,1,84,1,53,1,115,1,84,1,146,1,115,1,177,1,146,1,208,1,177,1,239,1,208,1,14,2,239,1,45,2,14,2,76,2,45,2,107,2,76,2,138,2,107,2,169,2,138,2,200,2,169,2,231,2,200,2,6,3,231,2,37,3,6,3,68,3,37,3,99,3,68,3,130,3,99,3,161,3,130,3,192,3,161,3,192,3,192,3,62,0,31,0,93,0,62,0,124,0,93,0,186,0,155,0,217,0,186,0,248,0,217,0,54,1,23,1,85,1,54,1,116,1,85,1,178,1,147,1,209,1,178,1,240,1,209,1,46,2,15,2,77,2,46,2,108,2,77,2,170,2,139,2,201,2,170,2,232,2,201,2,38,3,7,3,69,3,38,3,100,3,69,3,162,3,131,3,193,3,162,3,224,3,193,3,94,0,63,0,125,0,94,0,218,0,187,0,249,0,218,0,86,1,55,1,117,1,86,1,210,1,179,1,241,1,210,1,78,2,47,2,109,2,78,2,202,2,171,2,233,2,202,2,70,3,39,3,101,3,70,3,194,3,163,3,225,3,194,3,126,0,95,0,250,0,219,0,118,1,87,1,242,1,211,1,110,2,79,2,234,2,203,2,102,3,71,3,226,3,195,3,155,0,124,0,23,1,248,0,147,1,116,1,15,2,240,1,139,2,108,2,7,3,232,2,131,3,100,3,156,0,125,0,187,0,156,0,24,1,249,0,55,1,24,1,148,1,117,1,179,1,148,1,16,2,241,1,47,2,16,2,140,2,109,2,171,2,140,2,8,3,233,2,39,3,8,3,132,3,101,3,163,3,132,3,157,0,126,0,188,0,157,0,219,0,188,0,25,1,250,0,56,1,25,1,87,1,56,1,149,1,118,1,180,1,149,1,211,1,180,1,17,2,242,1,48,2,17,2,79,2,48,2,141,2,110,2,172,2,141,2,203,2,172,2,9,3,234,2,40,3,9,3,71,3,40,3,133,3,102,3,164,3,133,3,195,3,164,3,158,0,127,0,189,0,158,0,220,0,189,0,251,0,220,0,26,1,251,0,57,1,26,1,88,1,57,1,119,1,88,1,150,1,119,1,181,1,150,1,212,1,181,1,243,1,212,1,18,2,243,1,49,2,18,2,80,2,49,2,111,2,80,2,142,2,111,2,173,2,142,2,204,2,173,2,235,2,204,2,10,3,235,2,41,3,10,3,72,3,41,3,103,3,72,3,134,3,103,3,165,3,134,3,196,3,165,3,227,3,196,3,190,0,159,0,221,0,190,0,252,0,221,0,58,1,27,1,89,1,58,1,120,1,89,1,182,1,151,1,213,1,182,1,244,1,213,1,50,2,19,2,81,2,50,2,112,2,81,2,174,2,143,2,205,2,174,2,236,2,205,2,42,3,11,3,73,3,42,3,104,3,73,3,166,3,135,3,197,3,166,3,228,3,197,3,222,0,191,0,253,0,222,0,90,1,59,1,121,1,90,1,214,1,183,1,245,1,214,1,82,2,51,2,113,2,82,2,206,2,175,2,237,2,206,2,74,3,43,3,105,3,74,3,198,3,167,3,229,3,198,3,254,0,223,0,122,1,91,1,246,1,215,1,114,2,83,2,238,2,207,2,106,3,75,3,230,3,199,3,27,1,252,0,151,1,120,1,19,2,244,1,143,2,112,2,11,3,236,2,135,3,104,3,28,1,253,0,59,1,28,1,152,1,121,1,183,1,152,1,20,2,245,1,51,2,20,2,144,2,113,2,175,2,144,2,12,3,237,2,43,3,12,3,136,3,105,3,167,3,136,3,29,1,254,0,60,1,29,1,91,1,60,1,153,1,122,1,184,1,153,1,215,1,184,1,21,2,246,1,52,2,21,2,83,2,52,2,145,2,114,2,176,2,145,2,207,2,176,2,13,3,238,2,44,3,13,3,75,3,44,3,137,3,106,3,168,3,137,3,199,3,168,3,30,1,255,0,61,1,30,1,92,1,61,1,123,1,92,1,154,1,123,1,185,1,154,1,216,1,185,1,247,1,216,1,22,2,247,1,53,2,22,2,84,2,53,2,115,2,84,2,146,2,115,2,177,2,146,2,208,2,177,2,239,2,208,2,14,3,239,2,45,3,14,3,76,3,45,3,107,3,76,3,138,3,107,3,169,3,138,3,200,3,169,3,231,3,200,3,62,1,31,1,93,1,62,1,124,1,93,1,186,1,155,1,217,1,186,1,248,1,217,1,54,2,23,2,85,2,54,2,116,2,85,2,178,2,147,2,209,2,178,2,240,2,209,2,46,3,15,3,77,3,46,3,108,3,77,3,170,3,139,3,201,3,170,3,232,3,201,3,94,1,63,1,125,1,94,1,218,1,187,1,249,1,218,1,86,2,55,2,117,2,86,2,210,2,179,2,241,2,210,2,78,3,47,3,109,3,78,3,202,3,171,3,233,3,202,3,126,1,95,1,250,1,219,1,118,2,87,2,242,2,211,2,110,3,79,3,234,3,203,3,155,1,124,1,23,2,248,1,147,2,116,2,15,3,240,2,139,3,108,3,156,1,125,1,187,1,156,1,24,2,249,1,55,2,24,2,148,2,117,2,179,2,148,2,16,3,241,2,47,3,16,3,140,3,109,3,171,3,140,3,157,1,126,1,188,1,157,1,219,1,188,1,25,2,250,1,56,2,25,2,87,2,56,2,149,2,118,2,180,2,149,2,211,2,180,2,17,3,242,2,48,3,17,3,79,3,48,3,141,3,110,3,172,3,141,3,203,3,172,3,158,1,127,1,189,1,158,1,220,1,189,1,251,1,220,1,26,2,251,1,57,2,26,2,88,2,57,2,119,2,88,2,150,2,119,2,181,2,150,2,212,2,181,2,243,2,212,2,18,3,243,2,49,3,18,3,80,3,49,3,111,3,80,3,142,3,111,3,173,3,142,3,204,3,173,3,235,3,204,3,190,1,159,1,221,1,190,1,252,1,221,1,58,2,27,2,89,2,58,2,120,2,89,2,182,2,151,2,213,2,182,2,244,2,213,2,50,3,19,3,81,3,50,3,112,3,81,3,174,3,143,3,205,3,174,3,236,3,205,3,222,1,191,1,253,1,222,1,90,2,59,2,121,2,90,2,214,2,183,2,245,2,214,2,82,3,51,3,113,3,82,3,206,3,175,3,237,3,206,3,254,1,223,1,122,2,91,2,246,2,215,2,114,3,83,3,238,3,207,3,27,2,252,1,151,2,120,2,19,3,244,2,143,3,112,3,28,2,253,1,59,2,28,2,152,2,121,2,183,2,152,2,20,3,245,2,51,3,20,3,144,3,113,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+102400);
/* memory initializer */ allocate([175,3,144,3,29,2,254,1,60,2,29,2,91,2,60,2,153,2,122,2,184,2,153,2,215,2,184,2,21,3,246,2,52,3,21,3,83,3,52,3,145,3,114,3,176,3,145,3,207,3,176,3,30,2,255,1,61,2,30,2,92,2,61,2,123,2,92,2,154,2,123,2,185,2,154,2,216,2,185,2,247,2,216,2,22,3,247,2,53,3,22,3,84,3,53,3,115,3,84,3,146,3,115,3,177,3,146,3,208,3,177,3,239,3,208,3,62,2,31,2,93,2,62,2,124,2,93,2,186,2,155,2,217,2,186,2,248,2,217,2,54,3,23,3,85,3,54,3,116,3,85,3,178,3,147,3,209,3,178,3,240,3,209,3,94,2,63,2,125,2,94,2,218,2,187,2,249,2,218,2,86,3,55,3,117,3,86,3,210,3,179,3,241,3,210,3,126,2,95,2,250,2,219,2,118,3,87,3,242,3,211,3,155,2,124,2,23,3,248,2,147,3,116,3,156,2,125,2,187,2,156,2,24,3,249,2,55,3,24,3,148,3,117,3,179,3,148,3,157,2,126,2,188,2,157,2,219,2,188,2,25,3,250,2,56,3,25,3,87,3,56,3,149,3,118,3,180,3,149,3,211,3,180,3,158,2,127,2,189,2,158,2,220,2,189,2,251,2,220,2,26,3,251,2,57,3,26,3,88,3,57,3,119,3,88,3,150,3,119,3,181,3,150,3,212,3,181,3,243,3,212,3,190,2,159,2,221,2,190,2,252,2,221,2,58,3,27,3,89,3,58,3,120,3,89,3,182,3,151,3,213,3,182,3,244,3,213,3,222,2,191,2,253,2,222,2,90,3,59,3,121,3,90,3,214,3,183,3,245,3,214,3,254,2,223,2,122,3,91,3,246,3,215,3,27,3,252,2,151,3,120,3,28,3,253,2,59,3,28,3,152,3,121,3,183,3,152,3,29,3,254,2,60,3,29,3,91,3,60,3,153,3,122,3,184,3,153,3,215,3,184,3,30,3,255,2,61,3,30,3,92,3,61,3,123,3,92,3,154,3,123,3,185,3,154,3,216,3,185,3,247,3,216,3,62,3,31,3,93,3,62,3,124,3,93,3,186,3,155,3,217,3,186,3,248,3,217,3,94,3,63,3,125,3,94,3,218,3,187,3,249,3,218,3,126,3,95,3,250,3,219,3,155,3,124,3,156,3,125,3,187,3,156,3,157,3,126,3,188,3,157,3,219,3,188,3,158,3,127,3,189,3,158,3,220,3,189,3,251,3,220,3,190,3,159,3,221,3,190,3,252,3,221,3,222,3,191,3,253,3,222,3,254,3,223,3,0,0,0,0,0,0,1,0,32,0,2,0,33,0,64,0,3,0,34,0,65,0,4,0,96,0,35,0,66,0,5,0,36,0,97,0,67,0,128,0,98,0,68,0,37,0,6,0,129,0,99,0,7,0,160,0,69,0,38,0,130,0,100,0,161,0,131,0,39,0,70,0,8,0,101,0,162,0,132,0,192,0,71,0,40,0,9,0,102,0,163,0,133,0,193,0,72,0,224,0,103,0,41,0,164,0,10,0,194,0,134,0,165,0,73,0,104,0,135,0,225,0,42,0,195,0,11,0,0,1,166,0,226,0,196,0,74,0,105,0,136,0,43,0,12,0,167,0,197,0,227,0,1,1,75,0,106,0,137,0,228,0,44,0,198,0,168,0,2,1,32,1,13,0,229,0,76,0,107,0,199,0,138,0,3,1,169,0,33,1,45,0,230,0,4,1,200,0,108,0,14,0,170,0,139,0,64,1,34,1,77,0,231,0,5,1,46,0,201,0,140,0,35,1,109,0,232,0,65,1,6,1,171,0,78,0,36,1,15,0,66,1,202,0,7,1,96,1,172,0,37,1,233,0,141,0,67,1,110,0,47,0,203,0,8,1,234,0,38,1,97,1,68,1,16,0,79,0,204,0,9,1,39,1,69,1,173,0,98,1,142,0,235,0,128,1,48,0,40,1,111,0,10,1,99,1,70,1,80,0,17,0,205,0,236,0,174,0,100,1,129,1,71,1,143,0,41,1,11,1,101,1,130,1,112,0,49,0,72,1,42,1,206,0,160,1,237,0,102,1,131,1,81,0,175,0,18,0,73,1,103,1,132,1,43,1,74,1,133,1,113,0,161,1,238,0,104,1,50,0,207,0,162,1,134,1,75,1,19,0,192,1,105,1,82,0,163,1,135,1,239,0,51,0,106,1,164,1,114,0,193,1,224,1,165,1,83,0,107,1,194,1,166,1,0,2,195,1,167,1,115,0,196,1,225,1,197,1,226,1,198,1,32,2,227,1,199,1,1,2,228,1,2,2,229,1,3,2,230,1,33,2,64,2,231,1,34,2,35,2,96,2,65,2,66,2,67,2,97,2,98,2,99,2,20,0,144,0,12,1,136,1,4,2,128,2,21,0,52,0,145,0,176,0,13,1,44,1,137,1,168,1,5,2,36,2,129,2,160,2,22,0,53,0,84,0,146,0,177,0,208,0,14,1,45,1,76,1,138,1,169,1,200,1,6,2,37,2,68,2,130,2,161,2,192,2,23,0,54,0,85,0,116,0,147,0,178,0,209,0,240,0,15,1,46,1,77,1,108,1,139,1,170,1,201,1,232,1,7,2,38,2,69,2,100,2,131,2,162,2,193,2,224,2,55,0,86,0,117,0,179,0,210,0,241,0,47,1,78,1,109,1,171,1,202,1,233,1,39,2,70,2,101,2,163,2,194,2,225,2,87,0,118,0,211,0,242,0,79,1,110,1,203,1,234,1,71,2,102,2,195,2,226,2,119,0,243,0,111,1,235,1,103,2,227,2,24,0,148,0,16,1,140,1,8,2,132,2,0,3,25,0,56,0,149,0,180,0,17,1,48,1,141,1,172,1,9,2,40,2,133,2,164,2,1,3,32,3,26,0,57,0,88,0,150,0,181,0,212,0,18,1,49,1,80,1,142,1,173,1,204,1,10,2,41,2,72,2,134,2,165,2,196,2,2,3,33,3,64,3,27,0,58,0,89,0,120,0,151,0,182,0,213,0,244,0,19,1,50,1,81,1,112,1,143,1,174,1,205,1,236,1,11,2,42,2,73,2,104,2,135,2,166,2,197,2,228,2,3,3,34,3,65,3,96,3,59,0,90,0,121,0,183,0,214,0,245,0,51,1,82,1,113,1,175,1,206,1,237,1,43,2,74,2,105,2,167,2,198,2,229,2,35,3,66,3,97,3,91,0,122,0,215,0,246,0,83,1,114,1,207,1,238,1,75,2,106,2,199,2,230,2,67,3,98,3,123,0,247,0,115,1,239,1,107,2,231,2,99,3,28,0,152,0,20,1,144,1,12,2,136,2,4,3,128,3,29,0,60,0,153,0,184,0,21,1,52,1,145,1,176,1,13,2,44,2,137,2,168,2,5,3,36,3,129,3,160,3,30,0,61,0,92,0,154,0,185,0,216,0,22,1,53,1,84,1,146,1,177,1,208,1,14,2,45,2,76,2,138,2,169,2,200,2,6,3,37,3,68,3,130,3,161,3,192,3,31,0,62,0,93,0,124,0,155,0,186,0,217,0,248,0,23,1,54,1,85,1,116,1,147,1,178,1,209,1,240,1,15,2,46,2,77,2,108,2,139,2,170,2,201,2,232,2,7,3,38,3,69,3,100,3,131,3,162,3,193,3,224,3,63,0,94,0,125,0,187,0,218,0,249,0,55,1,86,1,117,1,179,1,210,1,241,1,47,2,78,2,109,2,171,2,202,2,233,2,39,3,70,3,101,3,163,3,194,3,225,3,95,0,126,0,219,0,250,0,87,1,118,1,211,1,242,1,79,2,110,2,203,2,234,2,71,3,102,3,195,3,226,3,127,0,251,0,119,1,243,1,111,2,235,2,103,3,227,3,156,0,24,1,148,1,16,2,140,2,8,3,132,3,157,0,188,0,25,1,56,1,149,1,180,1,17,2,48,2,141,2,172,2,9,3,40,3,133,3,164,3,158,0,189,0,220,0,26,1,57,1,88,1,150,1,181,1,212,1,18,2,49,2,80,2,142,2,173,2,204,2,10,3,41,3,72,3,134,3,165,3,196,3,159,0,190,0,221,0,252,0,27,1,58,1,89,1,120,1,151,1,182,1,213,1,244,1,19,2,50,2,81,2,112,2,143,2,174,2,205,2,236,2,11,3,42,3,73,3,104,3,135,3,166,3,197,3,228,3,191,0,222,0,253,0,59,1,90,1,121,1,183,1,214,1,245,1,51,2,82,2,113,2,175,2,206,2,237,2,43,3,74,3,105,3,167,3,198,3,229,3,223,0,254,0,91,1,122,1,215,1,246,1,83,2,114,2,207,2,238,2,75,3,106,3,199,3,230,3,255,0,123,1,247,1,115,2,239,2,107,3,231,3,28,1,152,1,20,2,144,2,12,3,136,3,29,1,60,1,153,1,184,1,21,2,52,2,145,2,176,2,13,3,44,3,137,3,168,3,30,1,61,1,92,1,154,1,185,1,216,1,22,2,53,2,84,2,146,2,177,2,208,2,14,3,45,3,76,3,138,3,169,3,200,3,31,1,62,1,93,1,124,1,155,1,186,1,217,1,248,1,23,2,54,2,85,2,116,2,147,2,178,2,209,2,240,2,15,3,46,3,77,3,108,3,139,3,170,3,201,3,232,3,63,1,94,1,125,1,187,1,218,1,249,1,55,2,86,2,117,2,179,2,210,2,241,2,47,3,78,3,109,3,171,3,202,3,233,3,95,1,126,1,219,1,250,1,87,2,118,2,211,2,242,2,79,3,110,3,203,3,234,3,127,1,251,1,119,2,243,2,111,3,235,3,156,1,24,2,148,2,16,3,140,3,157,1,188,1,25,2,56,2,149,2,180,2,17,3,48,3,141,3,172,3,158,1,189,1,220,1,26,2,57,2,88,2,150,2,181,2,212,2,18,3,49,3,80,3,142,3,173,3,204,3,159,1,190,1,221,1,252,1,27,2,58,2,89,2,120,2,151,2,182,2,213,2,244,2,19,3,50,3,81,3,112,3,143,3,174,3,205,3,236,3,191,1,222,1,253,1,59,2,90,2,121,2,183,2,214,2,245,2,51,3,82,3,113,3,175,3,206,3,237,3,223,1,254,1,91,2,122,2,215,2,246,2,83,3,114,3,207,3,238,3,255,1,123,2,247,2,115,3,239,3,28,2,152,2,20,3,144,3,29,2,60,2,153,2,184,2,21,3,52,3,145,3,176,3,30,2,61,2,92,2,154,2,185,2,216,2,22,3,53,3,84,3,146,3,177,3,208,3,31,2,62,2,93,2,124,2,155,2,186,2,217,2,248,2,23,3,54,3,85,3,116,3,147,3,178,3,209,3,240,3,63,2,94,2,125,2,187,2,218,2,249,2,55,3,86,3,117,3,179,3,210,3,241,3,95,2,126,2,219,2,250,2,87,3,118,3,211,3,242,3,127,2,251,2,119,3,243,3,156,2,24,3,148,3,157,2,188,2,25,3,56,3,149,3,180,3,158,2,189,2,220,2,26,3,57,3,88,3,150,3,181,3,212,3,159,2,190,2,221,2,252,2,27,3,58,3,89,3,120,3,151,3,182,3,213,3,244,3,191,2,222,2,253,2,59,3,90,3,121,3,183,3,214,3,245,3,223,2,254,2,91,3,122,3,215,3,246,3,255,2,123,3,247,3,28,3,152,3,29,3,60,3,153,3,184,3,30,3,61,3,92,3,154,3,185,3,216,3,31,3,62,3,93,3,124,3,155,3,186,3,217,3,248,3,63,3,94,3,125,3,187,3,218,3,249,3,95,3,126,3,219,3,250,3,127,3,251,3,156,3,157,3,188,3,158,3,189,3,220,3,159,3,190,3,221,3,252,3,191,3,222,3,253,3,223,3,254,3,255,3,0,0,0,0,0,0,0,0,1,0,1,0,16,0,1,0,16,0,16,0,2,0,2,0,17,0,2,0,32,0,17,0,32,0,32,0,3,0,3,0,33,0,18,0,18,0,3,0,48,0,33,0,19,0,4,0,4,0,4,0,34,0,19,0,48,0,48,0,49,0,34,0,35,0,20,0,64,0,49,0,20,0,5,0,5,0,5,0,50,0,35,0,64,0,64,0,65,0,50,0,36,0,21,0,21,0,6,0,51,0,36,0,6,0,6,0,80,0,65,0,66,0,51,0,37,0,22,0,81,0,66,0,52,0,37,0,22,0,7,0,80,0,80,0,67,0,52,0,7,0,7,0,82,0,67,0,96,0,81,0,53,0,38,0,38,0,23,0,68,0,53,0,96,0,96,0,23,0,8,0,97,0,82,0,83,0,68,0,69,0,54,0,54,0,39,0,8,0,8,0,39,0,24,0,84,0,69,0,98,0,83,0,112,0,97,0,112,0,112,0,24,0,9,0,113,0,98,0,99,0,84,0,70,0,55,0,85,0,70,0,55,0,40,0,9,0,9,0,40,0,25,0,114,0,99,0,100,0,85,0,128,0,113,0,115,0,100,0,71,0,56,0,86,0,71,0,25,0,10,0,129,0,114,0,128,0,128,0,101,0,86,0,56,0,41,0,10,0,10,0,41,0,26,0,116,0,101,0,130,0,115,0,144,0,129,0,87,0,72,0,102,0,87,0,26,0,11,0,72,0,57,0,131,0,116,0,117,0,102,0,145,0,130,0,57,0,42,0,144,0,144,0,11,0,11,0,42,0,27,0,132,0,117,0,146,0,131,0,103,0,88,0,88,0,73,0,118,0,103,0,160,0,145,0,73,0,58,0,147,0,132,0,133,0,118,0,27,0,12,0,161,0,146,0,58,0,43,0,12,0,12,0,160,0,160,0,119,0,104,0,148,0,133,0,89,0,74,0,134,0,119,0,104,0,89,0,162,0,147,0,43,0,28,0,74,0,59,0,176,0,161,0,163,0,148,0,28,0,13,0,149,0,134,0,120,0,105,0,135,0,120,0,177,0,162,0,164,0,149,0,13,0,13,0,105,0,90,0,59,0,44,0,90,0,75,0,150,0,135,0,44,0,29,0,178,0,163,0,176,0,176,0,136,0,121,0,165,0,150,0,121,0,106,0,75,0,60,0,179,0,164,0,151,0,136,0,29,0,14,0,60,0,45,0,14,0,14,0,106,0,91,0,166,0,151,0,180,0,165,0,192,0,177,0,91,0,76,0,192,0,192,0,45,0,30,0,137,0,122,0,122,0,107,0,152,0,137,0,193,0,178,0,76,0,61,0,167,0,152,0,181,0,166,0,30,0,15,0,194,0,179,0,208,0,193,0,182,0,167,0,107,0,92,0,138,0,123,0,61,0,46,0,153,0,138,0,46,0,31,0,195,0,180,0,92,0,77,0,168,0,153,0,209,0,194,0,196,0,181,0,208,0,208,0,123,0,108,0,183,0,168,0,210,0,195,0,77,0,62,0,108,0,93,0,169,0,154,0,154,0,139,0,62,0,47,0,197,0,182,0,211,0,196,0,184,0,169,0,224,0,209,0,224,0,224,0,139,0,124,0,93,0,78,0,198,0,183,0,124,0,109,0,78,0,63,0,212,0,197,0,225,0,210,0,170,0,155,0,185,0,170,0,155,0,140,0,213,0,198,0,199,0,184,0,109,0,94,0,226,0,211,0,140,0,125,0,94,0,79,0,240,0,225,0,214,0,199,0,227,0,212,0,200,0,185,0,125,0,110,0,241,0,226,0,186,0,171,0,171,0,156,0,156,0,141,0,228,0,213,0,110,0,95,0,215,0,200,0,242,0,227,0,141,0,126,0,201,0,186,0,229,0,214,0,126,0,111,0,216,0,201,0,243,0,228,0,172,0,157,0,187,0,172,0,230,0,215,0,157,0,142,0,202,0,187,0,142,0,127,0,244,0,229,0,217,0,202,0,231,0,216,0,188,0,173,0,245,0,230,0,158,0,143,0,173,0,158,0,232,0,217,0,246,0,231,0,218,0,203,0,203,0,188,0,174,0,159,0,189,0,174,0,247,0,232,0,233,0,218,0,204,0,189,0,219,0,204,0,248,0,233,0,190,0,175,0,234,0,219,0,220,0,205,0,249,0,234,0,205,0,190,0,221,0,206,0,250,0,235,0,235,0,220,0,206,0,191,0,236,0,221,0,222,0,207,0,251,0,236,0,237,0,222,0,252,0,237,0,238,0,223,0,253,0,238,0,254,0,239,0,0,0,0,0,0,0,1,0,16,0,2,0,17,0,32,0,3,0,18,0,33,0,48,0,4,0,34,0,19,0,49,0,20,0,5,0,35,0,64,0,50,0,36,0,65,0,21,0,6,0,51,0,80,0,66,0,37,0,22,0,52,0,7,0,81,0,67,0,38,0,82,0,53,0,23,0,96,0,68,0,8,0,83,0,97,0,54,0,39,0,69,0,112,0,24,0,98,0,84,0,70,0,55,0,9,0,40,0,85,0,99,0,113,0,128,0,25,0,114,0,100,0,71,0,86,0,56,0,10,0,41,0,115,0,101,0,129,0,116,0,72,0,87,0,26,0,130,0,144,0,102,0,57,0,11,0,42,0,117,0,131,0,145,0,88,0,103,0,27,0,73,0,132,0,118,0,146,0,58,0,160,0,12,0,43,0,133,0,147,0,104,0,89,0,119,0,161,0,74,0,148,0,134,0,28,0,162,0,59,0,13,0,176,0,120,0,149,0,90,0,135,0,105,0,163,0,44,0,75,0,177,0,164,0,29,0,150,0,121,0,136,0,178,0,165,0,14,0,106,0,60,0,91,0,151,0,45,0,179,0,192,0,137,0,166,0,122,0,76,0,180,0,152,0,30,0,61,0,15,0,107,0,167,0,181,0,193,0,92,0,208,0,46,0,138,0,123,0,153,0,194,0,77,0,168,0,182,0,31,0,195,0,209,0,183,0,108,0,139,0,62,0,154,0,47,0,196,0,93,0,169,0,210,0,197,0,224,0,124,0,184,0,211,0,78,0,109,0,170,0,155,0,63,0,198,0,212,0,185,0,225,0,240,0,140,0,94,0,199,0,125,0,79,0,213,0,226,0,171,0,186,0,156,0,214,0,200,0,110,0,227,0,141,0,95,0,241,0,215,0,228,0,201,0,126,0,242,0,187,0,172,0,157,0,229,0,111,0,216,0,243,0,142,0,202,0,230,0,127,0,217,0,244,0,173,0,188,0,231,0,158,0,203,0,143,0,245,0,218,0,232,0,189,0,246,0,159,0,174,0,233,0,247,0,219,0,204,0,175,0,190,0,248,0,234,0,205,0,220,0,249,0,191,0,235,0,221,0,250,0,206,0,222,0,251,0,236,0,207,0,237,0,223,0,252,0,238,0,253,0,239,0,254,0,255,0,65,32,18,144,162,194,41,51,98,132,68,18,165,217,196,45,40,78,173,80,19,176,240,193,64,35,46,221,135,38,194,248,121,96,85,29,48,12,154,155,139,90,34,117,119,67,6,25,204,243,158,13,21,96,120,7,76,176,208,126,28,54,103,97,5,44,131,176,139,48,68,97,83,5,42,156,111,152,26,49,152,80,5,58,178,74,83,33,62,145,86,5,32,154,192,168,14,22,163,77,7,64,116,132,122,37,126,120,85,5,32,156,216,148,19,29,73,101,21,107,181,192,103,19,67,125,235,162,36,255,34,3,149,144,2,173,34,7,145,85,7,166,63,7,94,66,8,64,46,17,81,31,25,29,30,9,102,187,225,239,183,119,96,41,33,16,77,74,142,142,172,170,238,247,50,126,123,221,226,3,136,37,5,52,13,20,152,15,101,100,66,192,128,64,32,64,96,128,224,144,192,168,192,176,192,198,198,245,216,136,140,148,160,176,192,224,234,234,240,128,128,64,96,112,64,64,96,64,160,128,128,216,128,176,160,176,176,192,198,198,208,208,136,140,148,160,176,192,224,234,234,240,128,128,64,96,112,64,64,96,64,160,128,222,34,30,72,16,44,58,32,12,10,7,6,177,58,59,68,26,63,52,79,25,17,14,12,174,73,87,92,41,83,82,99,50,53,39,39,199,122,141,147,63,159,148,133,118,121,104,114,0,43,46,168,134,107,128,69,142,92,44,29,68,159,201,177,50,57,77,63,36,126,146,123,158,60,90,96,58,38,76,114,97,172,78,133,92,46,41,76,140,63,184,69,112,57,38,32,85,140,46,112,54,151,133,39,27,61,131,110,175,44,75,136,47,35,80,100,74,143,64,163,74,52,30,74,113,130,175,51,64,58,36,61,116,114,128,162,80,125,82,55,44,68,166,179,192,57,57,108,42,26,11,199,241,228,23,15,85,82,26,26,171,208,204,44,32,105,68,42,19,131,160,199,55,52,83,58,50,25,139,115,232,39,52,118,50,35,33,153,104,162,64,59,131,44,24,16,150,177,202,33,19,156,53,49,21,110,116,168,59,80,76,55,27,12,153,203,218,26,27,49,38,72,19,168,203,212,50,50,107,92,45,102,136,116,180,74,90,100,73,32,19,187,222,215,46,34,100,137,30,42,148,151,207,70,52,91,91,30,32,116,121,186,93,86,94,72,35,36,149,68,206,68,63,105,73,31,28,138,57,124,55,122,151,67,23,21,140,126,197,40,37,171,74,32,27,107,86,160,63,134,102,86,27,28,128,154,212,45,43,53,59,67,44,140,161,202,78,67,119,59,38,83,112,103,162,98,136,90,62,30,23,158,200,207,59,57,50,103,26,36,129,132,201,83,80,93,67,30,29,84,86,191,102,91,59,60,32,33,112,71,220,64,89,104,53,26,34,130,56,149,84,120,103,53,21,23,133,109,210,56,77,172,61,29,29,93,97,165,83,175,162,77,19,29,112,142,228,55,66,36,47,47,43,114,137,181,100,99,95,53,40,55,139,69,183,61,80,110,40,29,19,161,180,207,43,24,91,69,23,29,128,83,199,46,44,101,60,34,19,105,61,198,53,64,89,52,31,22,158,40,209,58,62,89,44,31,29,147,46,158,56,102,198,35,19,12,135,87,209,41,45,167,51,38,25,113,58,164,70,93,97,55,25,21,118,95,215,38,39,66,47,54,34,146,108,203,72,103,151,46,27,80,150,55,124,55,121,135,36,23,27,165,149,166,54,64,118,64,19,37,156,66,138,49,95,133,53,21,36,131,63,163,60,109,81,40,26,35,154,40,185,51,97,123,35,19,34,179,19,97,48,129,124,36,20,26,136,62,164,33,77,154,45,26,28,129,45,129,49,147,123,45,18,32,130,90,157,40,79,91,38,44,51,136,74,162,57,97,121,56,39,58,133,117,173,48,53,187,35,21,12,161,212,207,20,23,145,75,17,22,136,138,185,32,34,166,56,29,19,117,109,181,55,68,112,47,29,17,153,64,220,59,51,114,46,16,24,136,76,147,41,64,172,34,17,11,108,152,187,13,15,209,55,30,18,122,79,179,44,88,116,51,24,14,115,133,209,32,26,104,37,49,25,129,168,164,41,54,148,48,34,86,101,92,146,78,179,134,47,22,24,138,187,178,68,69,59,78,23,39,111,117,170,74,124,94,56,25,33,105,112,187,95,177,129,48,31,27,114,63,183,82,116,56,43,28,37,121,63,123,61,192,169,42,17,24,109,97,177,56,76,122,46,23,32,74,86,150,67,183,88,58,18,28,105,139,182,70,92,63,36,38,48,92,122,165,88,137,91,62,44,61,123,105,189,48,57,64,47,25,17,175,222,220,24,30,86,82,22,32,127,143,213,39,41,70,68,36,17,106,102,206,59,74,74,57,39,23,151,68,216,55,63,58,49,30,35,141,70,168,82,40,115,51,25,15,136,129,202,38,35,139,59,39,19,114,75,180,77,104,42,68,26,16,111,141,215,29,28,28,40,61,26,126,152,206,61,59,93,44,78,115,132,119,173,71,112,93,39,38,21,184,227,206,42,32,64,65,70,60,155,159,199,61,60,81,58,47,36,124,137,193,80,82,78,49,50,35,144,95,205,63,78,59,41,53,52,148,71,142,65,128,51,40,36,28,143,143,202,40,55,137,42,44,44,104,105,164,64,130,80,52,34,29,129,183,227,42,35,43,43,81,53,140,169,204,68,84,72,0,0,0,0,118,15,123,148,131,101,44,93,131,113,12,23,188,226,142,26,32,125,144,11,54,157,195,130,46,58,108,120,11,50,123,163,135,64,77,103,113,9,36,155,111,157,32,44,161,116,9,55,176,76,96,37,61,149,115,9,28,141,161,167,21,25,193,116,12,64,120,140,125,49,115,121,120,12,32,145,195,142,32,38,86,102,19,66,162,182,122,35,59,128,0,0,0,0,0,0,174,35,49,68,11,27,57,15,9,12,3,3,150,40,39,78,12,26,67,33,11,24,7,5,149,53,53,94,20,48,83,53,24,52,18,18,158,97,94,93,24,99,85,119,44,62,59,67,195,29,183,84,49,136,8,42,71,0,0,0,0,0,0,0,0,0,31,107,169,35,99,159,17,82,140,8,66,114,2,44,76,1,19,32,40,132,201,29,114,187,13,91,157,7,75,127,3,58,95,1,28,47,69,142,221,42,122,201,15,91,159,6,67,121,1,42,77,1,17,31,102,148,228,67,117,204,17,82,154,6,59,114,2,39,75,1,15,29,156,57,233,119,57,212,58,48,163,29,40,124,12,30,81,3,12,31,191,107,226,124,117,204,25,99,155,0,0,0,0,0,0,0,0,0,29,148,210,37,126,194,8,93,157,2,68,118,1,39,69,1,17,33,41,151,213,27,123,193,3,82,144,1,58,105,1,32,60,1,13,26,59,159,220,23,126,198,4,88,151,1,66,114,1,38,71,1,18,34,114,136,232,51,114,207,11,83,155,3,56,105,1,33,65,1,17,34,149,65,234,121,57,215,61,49,166,28,36,114,12,25,76,3,16,42,214,49,220,132,63,188,42,65,137,0,0,0,0,0,0,0,0,0,85,137,221,104,131,216,49,111,192,21,87,155,2,49,87,1,16,28,89,163,230,90,137,220,29,100,183,10,70,135,2,42,81,1,17,33,108,167,237,55,133,222,15,97,179,4,72,135,1,45,85,1,19,38,124,146,240,66,124,224,17,88,175,4,58,122,1,36,75,1,18,37,141,79,241,126,70,227,66,58,182,30,44,136,12,34,96,2,20,47,229,99,249,143,111,235,46,109,192,0,0,0,0,0,0,0,0,0,82,158,236,94,146,224,25,117,191,9,87,149,3,56,99,1,33,57,83,167,237,68,145,222,10,103,177,2,72,131,1,41,79,1,20,39,99,167,239,47,141,224,10,104,178,2,73,133,1,44,85,1,22,47,127,145,243,71,129,228,17,93,177,3,61,124,1,41,84,1,21,52,157,78,244,140,72,231,69,58,184,31,44,137,14,38,105,8,23,61,125,34,187,52,41,133,6,31,56,0,0,0,0,0,0,0,0,0,37,109,153,51,102,147,23,87,128,8,67,101,1,41,63,1,19,29,31,154,185,17,127,175,6,96,145,2,73,114,1,51,82,1,28,45,23,163,200,10,131,185,2,93,148,1,67,111,1,41,69,1,14,24,29,176,217,12,145,201,3,101,156,1,69,111,1,39,63,1,14,23,57,192,233,25,154,215,6,109,167,3,78,118,1,48,69,1,21,29,202,105,245,108,106,216,18,90,144,0,0,0,0,0,0,0,0,0,33,172,219,64,149,206,14,117,177,5,90,141,2,61,95,1,37,57,33,179,220,11,140,198,1,89,148,1,60,104,1,33,57,1,12,21,30,181,221,8,141,198,1,87,145,1,58,100,1,31,55,1,12,20,32,186,224,7,142,198,1,86,143,1,58,100,1,31,55,1,12,22,57,192,227,20,143,204,3,96,154,1,68,112,1,42,69,1,19,32,212,35,215,113,47,169,29,48,105,0,0,0,0,0,0,0,0,0,74,129,203,106,120,203,49,107,178,19,84,144,4,50,84,1,15,25,71,172,217,44,141,209,15,102,173,6,76,133,2,51,89,1,24,42,64,185,231,31,148,216,8,103,175,3,74,131,1,46,81,1,18,30,65,196,235,25,157,221,5,105,174,1,67,120,1,38,69,1,15,30,65,204,238,30,156,224,7,107,177,2,70,124,1,42,73,1,18,34,225,86,251,144,104,235,42,99,181,0,0,0,0,0,0,0,0,0,85,175,239,112,165,229,29,136,200,12,103,162,6,77,123,2,53,84,75,183,239,30,155,221,3,106,171,1,74,128,1,44,76,1,17,28,73,185,240,27,159,222,2,107,172,1,75,127,1,42,73,1,17,29,62,190,238,21,159,222,2,107,172,1,72,122,1,40,71,1,18,32,61,199,240,27,161,226,4,113,180,1,76,129,1,46,80,1,23,41,7,27,153,5,30,95,1,16,30,0,0,0,0,0,0,0,0,0,50,75,127,57,75,124,27,67,108,10,54,86,1,33,52,1,12,18,43,125,151,26,108,148,7,83,122,2,59,89,1,38,60,1,17,27,23,144,163,13,112,154,2,75,117,1,50,81,1,31,51,1,14,23,18,162,185,6,123,171,1,78,125,1,51,86,1,31,54,1,14,23,15,199,227,3,150,204,1,91,146,1,55,95,1,30,53,1,11,20,19,55,240,19,59,196,3,52,105,0,0,0,0,0,0,0,0,0,41,166,207,104,153,199,31,123,181,14,101,152,5,72,106,1,36,52,35,176,211,12,131,190,2,88,144,1,60,101,1,36,60,1,16,28,28,183,213,8,134,191,1,86,142,1,56,96,1,30,53,1,12,20,20,190,215,4,135,192,1,84,139,1,53,91,1,28,49,1,11,20,13,196,216,2,137,192,1,86,143,1,57,99,1,32,56,1,13,24,211,29,217,96,47,156,22,43,87,0,0,0,0,0,0,0,0,0,78,120,193,111,116,186,46,102,164,15,80,128,2,49,76,1,18,28,71,161,203,42,132,192,10,98,150,3,69,109,1,44,70,1,18,29,57,186,211,30,140,196,4,93,146,1,62,102,1,38,65,1,16,27,47,199,217,14,145,196,1,88,142,1,57,98,1,36,62,1,15,26,26,219,229,5,155,207,1,94,151,1,60,104,1,36,62,1,16,28,233,29,248,146,47,220,43,52,140,0,0,0,0,0,0,0,0,0,100,163,232,179,161,222,63,142,204,37,113,174,26,89,137,18,68,97,85,181,230,32,146,209,7,100,164,3,71,121,1,45,77,1,18,30,65,187,230,20,148,207,2,97,159,1,68,116,1,40,70,1,14,29,40,194,227,8,147,204,1,94,155,1,65,112,1,39,66,1,14,26,16,208,228,3,151,207,1,98,160,1,67,117,1,41,74,1,17,31,17,38,140,7,34,80,1,17,29,0,0,0,0,0,0,0,0,0,37,75,128,41,76,128,26,66,116,12,52,94,2,32,55,1,10,16,50,127,154,37,109,152,16,82,121,5,59,85,1,35,54,1,13,20,40,142,167,17,110,157,2,71,112,1,44,72,1,27,45,1,11,17,30,175,188,9,124,169,1,74,116,1,48,78,1,30,49,1,11,18,10,222,223,2,150,194,1,83,128,1,48,79,1,27,45,1,11,17,36,41,235,29,36,193,10,27,111,0,0,0,0,0,0,0,0,0,85,165,222,177,162,215,110,135,195,57,113,168,23,83,120,10,49,61,85,190,223,36,139,200,5,90,146,1,60,103,1,38,65,1,18,30,72,202,223,23,141,199,2,86,140,1,56,97,1,36,61,1,16,27,55,218,225,13,145,200,1,86,141,1,57,99,1,35,61,1,13,22,15,235,212,1,132,184,1,84,139,1,57,97,1,34,56,1,14,23,181,21,201,61,37,123,10,38,71,0,0,0,0,0,0,0,0,0,47,106,172,95,104,173,42,93,159,18,77,131,4,50,81,1,17,23,62,147,199,44,130,189,28,102,154,18,75,115,2,44,65,1,12,19,55,153,210,24,130,194,3,93,146,1,61,97,1,31,50,1,10,16,49,186,223,17,148,204,1,96,142,1,53,83,1,26,44,1,11,17,13,217,212,2,136,180,1,78,124,1,50,83,1,29,49,1,14,23,197,13,247,82,17,222,25,17,162,0,0,0,0,0,0,0,0,0,126,186,247,234,191,243,176,177,234,104,158,220,66,128,186,55,90,137,111,197,242,46,158,219,9,104,171,2,65,125,1,44,80,1,17,91,104,208,245,39,168,224,3,109,162,1,79,124,1,50,102,1,43,102,84,220,246,31,177,231,2,115,180,1,79,134,1,55,77,1,60,79,43,243,240,8,180,217,1,115,166,1,84,121,1,51,67,1,16,6,4,0,8,0,8,0,9,0,10,0,11,0,12,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,38,0,39,0,40,0,41,0,42,0,43,0,43,0,44,0,45,0,46,0,47,0,48,0,48,0,49,0,50,0,51,0,52,0,53,0,53,0,54,0,55,0,56,0,57,0,57,0,58,0,59,0,60,0,61,0,62,0,62,0,63,0,64,0,65,0,66,0,66,0,67,0,68,0,69,0,70,0,70,0,71,0,72,0,73,0,74,0,74,0,75,0,76,0,77,0,78,0,78,0,79,0,80,0,81,0,81,0,82,0,83,0,84,0,85,0,85,0,87,0,88,0,90,0,92,0,93,0,95,0,96,0,98,0,99,0,101,0,102,0,104,0,105,0,107,0,108,0,110,0,111,0,113,0,114,0,116,0,117,0,118,0,120,0,121,0,123,0,125,0,127,0,129,0,131,0,134,0,136,0,138,0,140,0,142,0,144,0,146,0,148,0,150,0,152,0,154,0,156,0,158,0,161,0,164,0,166,0,169,0,172,0,174,0,177,0,180,0,182,0,185,0,187,0,190,0,192,0,195,0,199,0,202,0,205,0,208,0,211,0,214,0,217,0,220,0,223,0,226,0,230,0,233,0,237,0,240,0,243,0,247,0,250,0,253,0,1,1,5,1,9,1,13,1,16,1,20,1,24,1,28,1,32,1,36,1,40,1,44,1,48,1,53,1,57,1,61,1,66,1,70,1,74,1,79,1,84,1,88,1,93,1,98,1,103,1,108,1,113,1,118,1,123,1,128,1,133,1,139,1,144,1,150,1,155,1,161,1,167,1,173,1,179,1,185,1,191,1,198,1,205,1,211,1,219,1,226,1,233,1,241,1,249,1,1,2,10,2,18,2,27,2,37,2,47,2,57,2,67,2,78,2,90,2,102,2,114,2,128,2,142,2,156,2,172,2,188,2,205,2,224,2,243,2,7,3,28,3,51,3,75,3,101,3,128,3,157,3,187,3,220,3,254,3,34,4,74,4,115,4,160,4,208,4,2,5,56,5,0,0,0,0,1,0,1,0,0,0,0,0,2,0,2,0,8,0,8,0,3,0,3,0,9,0,9,0,8,0,8,0,4,0,4,0,10,0,10,0,16,0,16,0,11,0,11,0,17,0,17,0,5,0,5,0,16,0,16,0,18,0,18,0,12,0,12,0,24,0,24,0,6,0,6,0,25,0,25,0,19,0,19,0,24,0,24,0,13,0,13,0,26,0,26,0,20,0,20,0,32,0,32,0,27,0,27,0,33,0,33,0,14,0,14,0,21,0,21,0,34,0,34,0,32,0,32,0,28,0,28,0,40,0,40,0,35,0,35,0,22,0,22,0,29,0,29,0,41,0,41,0,36,0,36,0,40,0,40,0,42,0,42,0,30,0,30,0,43,0,43,0,48,0,48,0,37,0,37,0,49,0,49,0,48,0,48,0,44,0,44,0,38,0,38,0,50,0,50,0,56,0,56,0,51,0,51,0,45,0,45,0,57,0,57,0,52,0,52,0,58,0,58,0,46,0,46,0,59,0,59,0,53,0,53,0,60,0,60,0,54,0,54,0,61,0,61,0,62,0,62,0,0,0,0,0,0,0,1,0,2,0,8,0,3,0,9,0,4,0,10,0,16,0,5,0,11,0,17,0,12,0,18,0,6,0,24,0,19,0,13,0,25,0,7,0,26,0,20,0,32,0,14,0,27,0,21,0,33,0,28,0,34,0,15,0,22,0,35,0,40,0,29,0,41,0,36,0,23,0,30,0,42,0,37,0,48,0,43,0,31,0,44,0,49,0,38,0,50,0,56,0,45,0,39,0,51,0,57,0,52,0,46,0,58,0,53,0,59,0,47,0,60,0,54,0,61,0,55,0,62,0,63,0,0,0,0,0,1,0,1,0,0,0,0,0,2,0,2,0,4,0,4,0,5,0,5,0,4,0,4,0,6,0,6,0,8,0,8,0,9,0,9,0,8,0,8,0,12,0,12,0,10,0,10,0,13,0,13,0,14,0,14,0,0,0,0,0,0,0,1,0,2,0,4,0,3,0,5,0,6,0,8,0,7,0,9,0,10,0,12,0,13,0,11,0,14,0,15,0,0,0,0,0,1,0,1,0,2,0,2,0,0,0,0,0,3,0,3,0,16,0,16,0,4,0,4,0,17,0,17,0,5,0,5,0,18,0,18,0,16,0,16,0,19,0,19,0,6,0,6,0,32,0,32,0,20,0,20,0,33,0,33,0,7,0,7,0,34,0,34,0,21,0,21,0,32,0,32,0,35,0,35,0,8,0,8,0,48,0,48,0,22,0,22,0,49,0,49,0,36,0,36,0,9,0,9,0,37,0,37,0,50,0,50,0,23,0,23,0,48,0,48,0,51,0,51,0,10,0,10,0,64,0,64,0,38,0,38,0,24,0,24,0,52,0,52,0,65,0,65,0,53,0,53,0,39,0,39,0,66,0,66,0,11,0,11,0,64,0,64,0,25,0,25,0,67,0,67,0,54,0,54,0,80,0,80,0,40,0,40,0,68,0,68,0,12,0,12,0,26,0,26,0,81,0,81,0,55,0,55,0,69,0,69,0,82,0,82,0,41,0,41,0,13,0,13,0,83,0,83,0,80,0,80,0,70,0,70,0,27,0,27,0,56,0,56,0,84,0,84,0,96,0,96,0,14,0,14,0,71,0,71,0,97,0,97,0,42,0,42,0,85,0,85,0,57,0,57,0,98,0,98,0,28,0,28,0,86,0,86,0,99,0,99,0,96,0,96,0,72,0,72,0,43,0,43,0,100,0,100,0,58,0,58,0,29,0,29,0,112,0,112,0,87,0,87,0,113,0,113,0,73,0,73,0,112,0,112,0,101,0,101,0,44,0,44,0,30,0,30,0,114,0,114,0,59,0,59,0,102,0,102,0,88,0,88,0,115,0,115,0,74,0,74,0,128,0,128,0,116,0,116,0,45,0,45,0,103,0,103,0,89,0,89,0,60,0,60,0,129,0,129,0,117,0,117,0,130,0,130,0,131,0,131,0,104,0,104,0,75,0,75,0,46,0,46,0,118,0,118,0,128,0,128,0,90,0,90,0,61,0,61,0,132,0,132,0,105,0,105,0,144,0,144,0,119,0,119,0,145,0,145,0,133,0,133,0,76,0,76,0,146,0,146,0,120,0,120,0,91,0,91,0,134,0,134,0,147,0,147,0,62,0,62,0,106,0,106,0,135,0,135,0,121,0,121,0,92,0,92,0,148,0,148,0,144,0,144,0,77,0,77,0,149,0,149,0,136,0,136,0,107,0,107,0,160,0,160,0,161,0,161,0,150,0,150,0,122,0,122,0,78,0,78,0,137,0,137,0,162,0,162,0,151,0,151,0,93,0,93,0,163,0,163,0,108,0,108,0,164,0,164,0,152,0,152,0,123,0,123,0,138,0,138,0,160,0,160,0,165,0,165,0,94,0,94,0,176,0,176,0,166,0,166,0,109,0,109,0,153,0,153,0,177,0,177,0,124,0,124,0,178,0,178,0,139,0,139,0,167,0,167,0,154,0,154,0,110,0,110,0,179,0,179,0,176,0,176,0,180,0,180,0,168,0,168,0,140,0,140,0,125,0,125,0,181,0,181,0,192,0,192,0,193,0,193,0,155,0,155,0,182,0,182,0,169,0,169,0,194,0,194,0,126,0,126,0,141,0,141,0,195,0,195,0,183,0,183,0,192,0,192,0,196,0,196,0,156,0,156,0,170,0,170,0,142,0,142,0,184,0,184,0,197,0,197,0,208,0,208,0,198,0,198,0,209,0,209,0,171,0,171,0,157,0,157,0,185,0,185,0,210,0,210,0,208,0,208,0,211,0,211,0,199,0,199,0,224,0,224,0,158,0,158,0,212,0,212,0,224,0,224,0,186,0,186,0,200,0,200,0,172,0,172,0,225,0,225,0,213,0,213,0,214,0,214,0,226,0,226,0,201,0,201,0,227,0,227,0,187,0,187,0,240,0,240,0,215,0,215,0,173,0,173,0,228,0,228,0,241,0,241,0,202,0,202,0,242,0,242,0,216,0,216,0,229,0,229,0,174,0,174,0,188,0,188,0,243,0,243,0,230,0,230,0,203,0,203,0,217,0,217,0,231,0,231,0,244,0,244,0,218,0,218,0,245,0,245,0,189,0,189,0,232,0,232,0,204,0,204,0,190,0,190,0,246,0,246,0,233,0,233,0,247,0,247,0,219,0,219,0,205,0,205,0,248,0,248,0,234,0,234,0,220,0,220,0,206,0,206,0,249,0,249,0,235,0,235,0,221,0,221,0,250,0,250,0,222,0,222,0,236,0,236,0,237,0,237,0,251,0,251,0,238,0,238,0,252,0,252,0,253,0,253,0,254,0,254,0,0,0,0,0,0,0,1,0,2,0,3,0,16,0,4,0,17,0,5,0,18,0,6,0,19,0,32,0,20,0,7,0,33,0,21,0,34,0,8,0,35,0,22,0,48,0,36,0,9,0,49,0,23,0,50,0,37,0,10,0,38,0,51,0,24,0,64,0,52,0,11,0,65,0,39,0,25,0,53,0,66,0,54,0,40,0,67,0,12,0,80,0,26,0,68,0,55,0,81,0,41,0,69,0,13,0,27,0,82,0,56,0,70,0,83,0,42,0,14,0,84,0,96,0,71,0,28,0,57,0,85,0,97,0,15,0,72,0,98,0,43,0,86,0,58,0,99,0,29,0,87,0,100,0,112,0,73,0,44,0,101,0,59,0,30,0,113,0,88,0,114,0,74,0,128,0,102,0,45,0,31,0,115,0,60,0,103,0,89,0,116,0,75,0,129,0,117,0,46,0,104,0,90,0,61,0,130,0,118,0,131,0,132,0,105,0,76,0,47,0,119,0,144,0,91,0,62,0,133,0,106,0,145,0,120,0,146,0,134,0,77,0,147,0,121,0,92,0,135,0,148,0,63,0,107,0,136,0,122,0,93,0,149,0,160,0,78,0,150,0,137,0,108,0,161,0,162,0,151,0,123,0,79,0,138,0,163,0,152,0,94,0,164,0,109,0,165,0,153,0,124,0,139,0,176,0,166,0,95,0,177,0,167,0,110,0,154,0,178,0,125,0,179,0,140,0,168,0,155,0,111,0,180,0,192,0,181,0,169,0,141,0,126,0,182,0,193,0,194,0,156,0,183,0,170,0,195,0,127,0,142,0,196,0,184,0,208,0,197,0,157,0,171,0,143,0,185,0,198,0,209,0,199,0,210,0,172,0,158,0,186,0,211,0,224,0,212,0,200,0,240,0,159,0,213,0,225,0,187,0,201,0,173,0,226,0,214,0,215,0,227,0,202,0,228,0,188,0,241,0,216,0,174,0,229,0,242,0,203,0,243,0,217,0,230,0,175,0,189,0,244,0,231,0,204,0,218,0,232,0,245,0,219,0,246,0,190,0,233,0,205,0,191,0,247,0,234,0,248,0,220,0,206,0,249,0,235,0,221,0,207,0,250,0,236,0,222,0,251,0,223,0,237,0,238,0,252,0,239,0,253,0,254,0,255,0,4,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,104,0,106,0,108,0,110,0,112,0,114,0,116,0,118,0,120,0,122,0,124,0,126,0,128,0,130,0,132,0,134,0,136,0,138,0,140,0,142,0,144,0,146,0,148,0,150,0,152,0,155,0,158,0,161,0,164,0,167,0,170,0,173,0,176,0,179,0,182,0,185,0,188,0,191,0,194,0,197,0,200,0,203,0,207,0,211,0,215,0,219,0,223,0,227,0,231,0,235,0,239,0,243,0,247,0,251,0,255,0,4,1,9,1,14,1,19,1,24,1,29,1,34,1,39,1,44,1,49,1,55,1,61,1,67,1,73,1,79,1,85,1,91,1,97,1,103,1,110,1,117,1,124,1,131,1,138,1,145,1,152,1,160,1,168,1,176,1,184,1,192,1,200,1,209,1,218,1,227,1,236,1,245,1,254,1,8,2,18,2,28,2,38,2,48,2,59,2,70,2,81,2,92,2,103,2,115,2,127,2,139,2,151,2,164,2,177,2,190,2,203,2,217,2,231,2,245,2,3,3,18,3,33,3,48,3,64,3,80,3,96,3,113,3,130,3,147,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+112640);
/* memory initializer */ allocate([165,3,183,3,201,3,220,3,239,3,2,4,22,4,42,4,63,4,84,4,105,4,127,4,149,4,172,4,195,4,219,4,243,4,12,5,37,5,63,5,89,5,116,5,143,5,171,5,199,5,228,5,1,6,31,6,61,6,92,6,124,6,156,6,189,6,223,6,1,7,36,7,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,176,246,255,255,255,255,255,255,255,255,255,223,241,252,255,255,255,255,255,255,255,255,249,253,253,255,255,255,255,255,255,255,255,255,244,252,255,255,255,255,255,255,255,255,234,254,254,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,246,254,255,255,255,255,255,255,255,255,239,253,254,255,255,255,255,255,255,255,255,254,255,254,255,255,255,255,255,255,255,255,255,248,254,255,255,255,255,255,255,255,255,251,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,254,255,255,255,255,255,255,255,255,251,254,254,255,255,255,255,255,255,255,255,254,255,254,255,255,255,255,255,255,255,255,255,254,253,255,254,255,255,255,255,255,255,250,255,254,255,254,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,217,255,255,255,255,255,255,255,255,255,255,225,252,241,253,255,255,254,255,255,255,255,234,250,241,250,253,255,253,254,255,255,255,255,254,255,255,255,255,255,255,255,255,255,223,254,254,255,255,255,255,255,255,255,255,238,253,254,254,255,255,255,255,255,255,255,255,248,254,255,255,255,255,255,255,255,255,249,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,247,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,254,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,253,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,186,251,250,255,255,255,255,255,255,255,255,234,251,244,254,255,255,255,255,255,255,255,251,251,243,253,254,255,254,255,255,255,255,255,253,254,255,255,255,255,255,255,255,255,236,253,254,255,255,255,255,255,255,255,255,251,253,253,254,254,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,254,254,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,250,254,252,254,255,255,255,255,255,255,255,248,254,249,253,255,255,255,255,255,255,255,255,253,253,255,255,255,255,255,255,255,255,246,253,253,255,255,255,255,255,255,255,255,252,254,251,254,254,255,255,255,255,255,255,255,254,252,255,255,255,255,255,255,255,255,248,254,253,255,255,255,255,255,255,255,255,253,255,254,254,255,255,255,255,255,255,255,255,251,254,255,255,255,255,255,255,255,255,245,251,254,255,255,255,255,255,255,255,255,253,253,254,255,255,255,255,255,255,255,255,255,251,253,255,255,255,255,255,255,255,255,252,253,254,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,249,255,254,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,253,136,254,255,228,219,128,128,128,128,128,189,129,242,255,227,213,255,219,128,128,128,106,126,227,252,214,209,255,255,128,128,128,1,98,248,255,236,226,255,255,128,128,128,181,133,238,254,221,234,255,154,128,128,128,78,134,202,247,198,180,255,219,128,128,128,1,185,249,255,243,255,128,128,128,128,128,184,150,247,255,236,224,128,128,128,128,128,77,110,216,255,236,230,128,128,128,128,128,1,101,251,255,241,255,128,128,128,128,128,170,139,241,252,236,209,255,255,128,128,128,37,116,196,243,228,255,255,255,128,128,128,1,204,254,255,245,255,128,128,128,128,128,207,160,250,255,238,128,128,128,128,128,128,102,103,231,255,211,171,128,128,128,128,128,1,152,252,255,240,255,128,128,128,128,128,177,135,243,255,234,225,128,128,128,128,128,80,129,211,255,194,224,128,128,128,128,128,1,1,255,128,128,128,128,128,128,128,128,246,1,255,128,128,128,128,128,128,128,128,255,128,128,128,128,128,128,128,128,128,128,198,35,237,223,193,187,162,160,145,155,62,131,45,198,221,172,176,220,157,252,221,1,68,47,146,208,149,167,221,162,255,223,128,1,149,241,255,221,224,255,255,128,128,128,184,141,234,253,222,220,255,199,128,128,128,81,99,181,242,176,190,249,202,255,255,128,1,129,232,253,214,197,242,196,255,255,128,99,121,210,250,201,198,255,202,128,128,128,23,91,163,242,170,187,247,210,255,255,128,1,200,246,255,234,255,128,128,128,128,128,109,178,241,255,231,245,255,255,128,128,128,44,130,201,253,205,192,255,255,128,128,128,1,132,239,251,219,209,255,165,128,128,128,94,136,225,251,218,190,255,255,128,128,128,22,100,174,245,186,161,255,199,128,128,128,1,182,249,255,232,235,128,128,128,128,128,124,143,241,255,227,234,128,128,128,128,128,35,77,181,251,193,211,255,205,128,128,128,1,157,247,255,236,231,255,255,128,128,128,121,141,235,255,225,227,255,255,128,128,128,45,99,188,251,195,217,255,224,128,128,128,1,1,251,255,213,255,128,128,128,128,128,203,1,248,255,255,128,128,128,128,128,128,137,1,177,255,224,255,128,128,128,128,128,253,9,248,251,207,208,255,192,128,128,128,175,13,224,243,193,185,249,198,255,255,128,73,17,171,221,161,179,236,167,255,234,128,1,95,247,253,212,183,255,255,128,128,128,239,90,244,250,211,209,255,255,128,128,128,155,77,195,248,188,195,255,255,128,128,128,1,24,239,251,218,219,255,205,128,128,128,201,51,219,255,196,186,128,128,128,128,128,69,46,190,239,201,218,255,228,128,128,128,1,191,251,255,255,128,128,128,128,128,128,223,165,249,255,213,255,128,128,128,128,128,141,124,248,255,255,128,128,128,128,128,128,1,16,248,255,255,128,128,128,128,128,128,190,36,230,255,236,255,128,128,128,128,128,149,1,255,128,128,128,128,128,128,128,128,1,226,255,128,128,128,128,128,128,128,128,247,192,255,128,128,128,128,128,128,128,128,240,128,255,128,128,128,128,128,128,128,128,1,134,252,255,255,128,128,128,128,128,128,213,62,250,255,255,128,128,128,128,128,128,55,93,255,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,202,24,213,235,186,191,220,160,240,175,255,126,38,182,232,169,184,228,174,255,187,128,61,46,138,219,151,178,240,170,255,216,128,1,112,230,250,199,191,247,159,255,255,128,166,109,228,252,211,215,255,174,128,128,128,39,77,162,232,172,180,245,178,255,255,128,1,52,220,246,198,199,249,220,255,255,128,124,74,191,243,183,193,250,221,255,255,128,24,71,130,219,154,170,243,182,255,255,128,1,182,225,249,219,240,255,224,128,128,128,149,150,226,252,216,205,255,171,128,128,128,28,108,170,242,183,194,254,223,255,255,128,1,81,230,252,204,203,255,192,128,128,128,123,102,209,247,188,196,255,233,128,128,128,20,95,153,243,164,173,255,203,128,128,128,1,222,248,255,216,213,128,128,128,128,128,168,175,246,252,235,205,255,255,128,128,128,47,116,215,255,211,212,255,255,128,128,128,1,121,236,253,212,214,255,255,128,128,128,141,84,213,252,201,202,255,219,128,128,128,42,80,160,240,162,185,255,205,128,128,128,1,1,255,128,128,128,128,128,128,128,128,244,1,255,128,128,128,128,128,128,128,128,238,1,255,128,128,128,128,128,128,128,128,147,136,18,106,145,1,179,121,1,223,1,34,208,1,1,0,0,1,254,2,255,253,0,0,142,114,183,0,0,0,0,0,162,101,204,0,0,0,0,0,254,1,247,2,0,3,4,6,255,5,252,251,253,7,249,8,250,248,0,0,0,0,0,0,39,53,200,87,26,21,43,232,171,56,34,51,104,114,102,29,93,77,88,88,147,150,42,46,45,196,205,107,54,32,26,51,1,81,43,31,39,28,85,171,58,165,90,98,64,34,22,116,206,23,34,43,166,73,34,19,21,102,132,188,16,76,124,68,25,106,22,64,171,36,225,114,62,18,78,95,85,57,50,48,51,43,97,183,117,85,38,35,179,61,112,113,77,85,179,255,38,120,114,40,42,1,196,245,209,10,25,109,193,101,35,159,215,111,89,46,111,100,80,8,43,154,1,51,26,71,88,43,29,140,166,213,37,43,154,61,63,30,155,67,45,68,1,209,41,40,5,102,211,183,4,1,221,142,78,78,16,255,128,34,197,171,51,50,17,168,209,192,23,25,82,60,148,31,172,219,228,21,18,111,175,69,143,80,85,82,72,155,103,56,58,10,171,218,189,17,13,152,231,120,48,89,115,113,120,152,112,144,71,10,38,171,213,144,34,26,114,26,17,163,44,195,21,10,173,121,24,80,195,26,62,44,64,85,63,20,8,114,114,208,12,9,226,170,46,55,19,136,160,33,206,71,81,40,11,96,182,84,29,16,36,152,179,64,126,170,118,46,70,95,75,79,123,47,51,128,81,171,1,57,17,5,71,102,57,53,41,49,125,98,42,88,104,85,117,175,82,115,21,2,10,102,255,166,23,6,38,33,13,121,57,73,26,1,85,41,10,67,138,77,110,90,47,114,57,18,10,102,102,213,34,20,43,101,29,16,10,85,128,101,196,26,117,20,15,36,163,128,68,1,26,95,84,53,89,128,100,113,101,45,63,59,90,180,59,166,93,73,154,40,40,21,116,143,209,34,39,175,138,31,36,171,27,166,38,44,229,57,46,22,24,128,1,54,17,37,47,15,16,183,34,223,49,45,183,46,17,33,183,6,98,15,32,183,40,3,9,115,51,192,18,6,223,65,32,73,115,28,128,23,128,205,87,37,9,115,59,77,64,21,47,67,87,58,169,82,115,26,59,179,54,57,112,184,5,41,38,166,213,30,34,26,133,152,116,10,32,134,104,55,44,218,9,54,53,130,226,75,32,12,51,192,255,160,43,51,39,19,53,221,26,114,32,73,255,31,9,65,234,2,15,1,118,73,56,21,23,111,59,205,45,37,192,88,31,35,67,102,85,55,186,85,55,38,70,124,73,102,1,34,98,64,90,70,205,40,41,23,26,57,86,40,64,135,148,224,45,183,128,22,26,17,131,240,154,14,1,209,164,50,31,137,154,133,25,35,218,83,12,13,54,192,255,68,47,28,45,16,21,91,64,222,7,1,197,56,21,39,155,60,138,23,102,213,18,11,7,63,144,171,4,4,246,85,26,85,85,128,128,32,146,171,35,27,10,146,174,171,12,26,128,51,103,44,131,131,123,31,6,158,68,45,128,34,1,47,11,245,171,62,17,19,70,146,85,55,62,70,102,61,71,37,34,53,31,243,192,75,15,9,9,64,255,184,119,16,37,43,37,154,100,163,85,160,1,63,9,92,136,28,64,32,201,85,56,8,17,132,137,255,55,116,128,86,6,28,5,64,255,25,248,1,58,15,20,82,135,57,26,121,40,69,60,71,38,73,119,28,222,37,101,75,128,139,118,146,116,128,85,56,41,15,176,236,85,37,9,62,190,80,35,99,180,80,126,54,45,146,36,19,30,171,255,97,27,20,71,30,17,119,118,255,17,18,138,101,38,60,138,55,70,43,26,142,32,41,20,117,151,142,20,21,163,138,45,61,62,219,1,81,188,64,112,19,12,61,195,128,48,4,24,85,126,47,87,176,51,41,20,32,66,102,167,99,74,62,40,234,128,41,53,9,178,241,141,26,8,107,134,183,89,137,98,101,106,165,148,104,79,12,27,217,255,87,17,7,74,43,26,146,73,166,49,23,157,65,38,105,160,51,52,31,115,128,47,41,14,110,182,183,21,17,194,87,68,71,44,114,51,15,186,23,66,45,25,102,197,189,23,18,22,72,187,100,130,157,111,32,75,80,0,0,0,0,120,90,79,133,87,85,80,111,151,0,0,0,0,0,0,0,2,1,0,9,0,0,0,0,252,1,2,3,0,254,255,253,0,1,2,3,254,255,253,252,145,156,163,128,0,0,0,0,237,246,253,253,254,254,254,254,254,254,254,254,254,254,250,250,252,254,254,231,243,245,253,254,254,254,254,254,254,254,254,254,254,251,251,254,254,254,0,0,162,128,225,146,172,147,214,39,156,128,129,132,75,145,178,206,239,254,254,164,128,204,170,119,235,140,230,228,128,130,130,74,148,180,203,236,254,254,0,0,7,0,0,0,1,0,0,0,1,0,0,0,143,0,0,0,14,0,0,0,18,0,0,0,14,0,0,0,107,0,0,0,135,0,0,0,64,0,0,0,57,0,0,0,68,0,0,0,60,0,0,0,56,0,0,0,128,0,0,0,65,0,0,0,159,0,0,0,134,0,0,0,128,0,0,0,34,0,0,0,234,0,0,0,188,0,0,0,128,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,2,2,3,3,2,2,3,3,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,4,16,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,10,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,254,254,243,230,196,177,153,140,133,130,129,0,0,0,0,0,180,157,141,134,130,0,0,0,176,155,140,135,0,0,0,0,173,148,140,0,0,0,0,0,4,5,6,7,8,9,10,10,11,12,13,14,15,16,17,17,18,19,20,20,21,21,22,22,23,23,24,25,25,26,27,28,29,30,31,32,33,34,35,36,37,37,38,39,40,41,42,43,44,45,46,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,76,77,78,79,80,81,82,83,84,85,86,87,88,89,91,93,95,96,98,100,101,102,104,106,108,110,112,114,116,118,122,124,126,128,130,132,134,136,138,140,143,145,148,151,154,157,0,255,0,0,0,0,0,0,0,0,1,255,0,0,0,0,0,0,0,0,2,255,0,0,0,0,0,0,0,0,3,255,0,0,0,0,0,0,0,0,5,255,0,0,0,0,0,0,0,0,6,255,0,0,0,0,0,0,0,0,4,7,8,9,10,11,12,13,14,255,15,255,0,0,0,0,0,0,0,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,60,0,62,0,64,0,66,0,68,0,70,0,72,0,74,0,76,0,78,0,80,0,82,0,84,0,86,0,88,0,90,0,92,0,94,0,96,0,98,0,100,0,102,0,104,0,106,0,108,0,110,0,112,0,114,0,116,0,119,0,122,0,125,0,128,0,131,0,134,0,137,0,140,0,143,0,146,0,149,0,152,0,155,0,158,0,161,0,164,0,167,0,170,0,173,0,177,0,181,0,185,0,189,0,193,0,197,0,201,0,205,0,209,0,213,0,217,0,221,0,225,0,229,0,234,0,239,0,245,0,249,0,254,0,3,1,8,1,13,1,18,1,23,1,28,1,237,246,231,243,0,0,0,0,219,246,238,249,232,239,249,255,248,253,239,244,241,248,198,232,251,253,219,241,253,255,248,249,244,238,251,255,0,0,0,0,227,246,230,247,244,255,255,255,255,255,255,255,255,209,231,231,249,249,253,255,255,255,255,255,225,242,241,251,253,255,255,255,255,255,255,241,253,252,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,255,248,255,255,255,255,255,255,255,255,255,255,240,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,206,203,227,239,247,255,253,255,255,255,255,207,199,220,236,243,252,252,255,255,255,255,212,219,230,243,244,253,252,255,255,255,255,236,237,247,252,253,255,255,255,255,255,255,240,240,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,230,233,249,255,255,255,255,255,255,255,255,238,238,250,255,255,255,255,255,255,255,255,248,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,225,239,227,231,244,253,243,255,255,253,255,232,234,224,228,242,249,242,252,251,251,255,235,249,238,240,251,255,249,255,253,253,255,249,253,251,250,255,255,255,255,255,255,255,251,250,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,243,244,250,250,255,255,255,255,255,255,255,249,248,250,253,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,253,253,254,254,254,254,254,245,253,254,254,254,254,254,0,0,8,0,4,1,2,2,255,0,254,0,2,3,253,0,252,0,8,4,4,5,2,6,251,0,250,0,2,7,249,0,248,0,0,0,0,0,0,0,0,0,0,1,2,7,6,5,4,0,10,13,11,12,0,1,2,3,14,8,15,16,4,5,6,7,13,14,11,0,1,15,16,18,2,17,3,4,19,20,5,6,21,22,7,8,9,10,0,0,254,254,254,254,254,250,250,252,254,254,254,254,254,251,251,254,198,197,196,146,198,204,169,142,130,136,149,149,191,249,135,201,181,154,98,117,132,126,146,169,184,240,246,254,0,0,0,0,225,146,172,147,214,39,156,204,170,119,235,140,230,228,0,0,247,210,135,68,138,220,239,246,244,184,201,44,173,221,239,253,0,0,1,1,1,2,2,2,2,2,2,3,3,4,4,4,5,5,5,5,6,6,7,7,7,7,7,8,8,9,9,9,9,9,9,10,10,11,11,11,11,11,11,12,12,12,12,12,12,13,13,13,13,13,14,14,14,14,15,15,15,15,15,15,146,255,181,207,232,243,238,251,244,250,249,179,255,214,240,250,255,244,255,255,255,255,0,0,122,0,0,0,133,0,0,0,0,0,0,0,1,0,0,0,78,0,0,0,171,0,0,0,139,0,0,0,117,0,0,0,168,0,0,0,79,0,0,0,133,0,0,0,51,0,0,0,0,0,0,0,1,0,0,0,169,0,0,0,71,0,0,0,214,0,0,0,44,0,0,0,210,0,0,0,38,0,0,0,142,0,0,0,240,255,255,255,0,0,0,0,1,0,0,0,221,0,0,0,226,255,255,255,246,0,0,0,253,255,255,255,203,0,0,0,17,0,0,0,4,4,4,4,8,8,0,0,255,132,132,159,153,151,161,170,164,162,136,110,103,114,129,118,124,125,132,136,114,110,142,135,134,123,143,126,153,183,166,161,171,180,179,164,203,218,225,217,215,206,203,217,229,241,248,243,253,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,1,1,1,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,0,0,128,0,0,0,0,0,253,255,122,0,9,0,0,0,252,255,109,0,24,0,255,255,251,255,91,0,45,0,253,255,252,255,68,0,68,0,252,255,253,255,45,0,91,0,251,255,255,255,24,0,109,0,252,255,0,0,9,0,122,0,253,255,0,0,128,0,0,0,0,0,252,255,124,0,9,0,255,255,251,255,110,0,25,0,254,255,250,255,91,0,46,0,253,255,251,255,69,0,69,0,251,255,253,255,46,0,91,0,250,255,254,255,25,0,110,0,251,255,255,255,9,0,124,0,252,255,0,0,128,0,0,0,0,0,252,255,123,0,10,0,255,255,250,255,110,0,26,0,254,255,249,255,92,0,47,0,252,255,250,255,70,0,70,0,250,255,252,255,47,0,92,0,249,255,254,255,26,0,110,0,250,255,255,255,10,0,123,0,252,255,0,0,128,0,0,0,0,0,251,255,124,0,10,0,255,255,249,255,110,0,27,0,254,255,249,255,91,0,48,0,252,255,250,255,70,0,70,0,250,255,252,255,48,0,92,0,248,255,254,255,27,0,110,0,249,255,255,255,10,0,124,0,251,255,0,0,128,0,0,0,0,0,250,255,124,0,11,0,255,255,248,255,111,0,28,0,253,255,248,255,92,0,49,0,251,255,249,255,71,0,71,0,249,255,251,255,49,0,92,0,248,255,253,255,28,0,111,0,248,255,255,255,11,0,124,0,250,255,0,0,128,0,0,0,0,0,250,255,123,0,12,0,255,255,247,255,111,0,29,0,253,255,247,255,93,0,50,0,250,255,248,255,72,0,72,0,248,255,250,255,50,0,93,0,247,255,253,255,29,0,111,0,247,255,255,255,12,0,123,0,250,255,0,0,128,0,0,0,0,0,249,255,124,0,12,0,255,255,246,255,111,0,30,0,253,255,246,255,93,0,51,0,250,255,247,255,73,0,73,0,247,255,250,255,51,0,93,0,246,255,253,255,30,0,111,0,246,255,255,255,12,0,124,0,249,255,0,0,128,0,0,0,0,0,249,255,123,0,13,0,255,255,245,255,112,0,31,0,252,255,245,255,94,0,52,0,249,255,246,255,74,0,74,0,246,255,249,255,52,0,94,0,245,255,252,255,31,0,112,0,245,255,255,255,13,0,123,0,249,255,0,0,128,0,0,0,0,0,248,255,124,0,13,0,255,255,244,255,112,0,32,0,252,255,244,255,94,0,53,0,249,255,246,255,74,0,74,0,246,255,249,255,53,0,94,0,244,255,252,255,32,0,112,0,244,255,255,255,13,0,124,0,248,255,0,0,128,0,0,0,0,0,247,255,124,0,14,0,255,255,243,255,112,0,33,0,252,255,243,255,95,0,54,0,248,255,245,255,75,0,75,0,245,255,248,255,54,0,95,0,243,255,252,255,33,0,112,0,243,255,255,255,14,0,124,0,247,255,0,0,128,0,0,0,0,0,247,255,123,0,15,0,255,255,242,255,113,0,34,0,251,255,242,255,95,0,55,0,248,255,244,255,76,0,76,0,244,255,248,255,55,0,95,0,242,255,251,255,34,0,112,0,243,255,255,255,15,0,123,0,247,255,0,0,128,0,0,0,0,0,246,255,124,0,15,0,255,255,242,255,113,0,34,0,251,255,241,255,96,0,56,0,247,255,243,255,77,0,77,0,243,255,247,255,56,0,96,0,241,255,251,255,34,0,113,0,242,255,255,255,15,0,124,0,246,255,0,0,128,0,0,0,0,0,246,255,123,0,16,0,255,255,241,255,113,0,35,0,251,255,240,255,98,0,56,0,246,255,242,255,78,0,78,0,242,255,246,255,56,0,98,0,240,255,251,255,35,0,113,0,241,255,255,255,16,0,123,0,246,255,0,0,128,0,0,0,0,0,245,255,124,0,17,0,254,255,240,255,113,0,36,0,251,255,239,255,98,0,57,0,246,255,242,255,78,0,78,0,242,255,246,255,57,0,98,0,239,255,251,255,36,0,113,0,240,255,254,255,17,0,124,0,245,255,0,0,128,0,0,0,0,0,244,255,125,0,17,0,254,255,239,255,114,0,37,0,250,255,238,255,99,0,58,0,245,255,241,255,79,0,79,0,241,255,245,255,58,0,99,0,238,255,250,255,37,0,114,0,239,255,254,255,17,0,125,0,244,255,0,0,128,0,0,0,0,0,244,255,124,0,18,0,254,255,238,255,114,0,38,0,250,255,237,255,99,0,59,0,245,255,240,255,80,0,80,0,240,255,245,255,59,0,99,0,237,255,250,255,38,0,114,0,238,255,254,255,18,0,124,0,244,255,0,0,128,0,0,0,0,0,252,255,118,0,16,0,254,255,249,255,106,0,34,0,251,255,248,255,90,0,53,0,249,255,248,255,72,0,72,0,248,255,249,255,53,0,90,0,248,255,251,255,34,0,106,0,249,255,254,255,16,0,118,0,252,255,243,220,251,253,237,232,241,245,247,251,253,235,211,246,249,234,231,248,249,252,252,254,0,0,227,246,230,247,244,254,254,254,254,254,254,202,254,209,231,231,249,249,253,254,254,254,206,254,225,242,241,251,253,254,254,254,254,235,254,241,253,252,254,254,254,254,254,254,234,254,248,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,240,254,248,254,254,254,254,254,254,254,254,238,254,240,253,254,254,254,254,254,254,254,244,254,251,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,206,203,227,239,247,254,253,254,254,254,254,207,199,220,236,243,252,252,254,254,254,254,212,219,230,243,244,253,252,254,254,254,254,236,237,247,252,253,254,254,254,254,254,254,240,240,248,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,230,233,249,254,254,254,254,254,254,254,254,238,238,250,254,254,254,254,254,254,254,254,248,251,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,225,239,227,231,244,253,243,254,254,253,254,232,234,224,228,242,249,242,252,251,251,254,235,249,238,240,251,254,249,254,253,253,254,249,253,251,250,254,254,254,254,254,254,254,251,250,249,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,243,244,250,250,254,254,254,254,254,254,254,249,248,250,253,254,254,254,254,254,254,254,253,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,0,0,0,0,20,1,0,0,238,0,0,0,195,0,0,0,156,0,0,0,113,0,0,0,18,1,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,192,0,59,0,182,0,50,0,141,0,48,0,110,0,40,0,92,0,19,0,125,0,128,0,169,0,87,0,169,0,83,0,184,0,62,0,220,0,16,0,184,0,0,0,8,1,0,0,212,0,40,0,212,0,36,0,169,0,49,0,174,0,27,0,8,0,120,0,182,0,71,0,3,1,10,0,197,0,19,0,143,0,22,0,123,0,16,0,110,0,8,0,133,0,88,0,0,0,1,0,0,1,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,207,0,46,0,187,0,50,0,97,0,83,0,23,0,100,0,41,0,56,0,56,0,188,0,166,0,90,0,146,0,108,0,161,0,88,0,136,0,95,0,174,0,0,0,10,1,0,0,8,1,7,0,243,0,18,0,184,0,43,0,242,255,154,0,20,0,112,0,20,0,199,0,230,0,26,0,197,0,22,0,159,0,20,0,146,0,12,0,136,0,4,0,54,0,162,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,192,0,59,0,156,0,72,0,84,0,101,0,49,0,101,0,79,0,47,0,79,0,167,0,138,0,115,0,136,0,116,0,166,0,80,0,238,0,0,0,195,0,0,0,5,1,0,0,225,0,33,0,205,0,42,0,159,0,61,0,79,0,96,0,92,0,66,0,28,0,195,0,200,0,37,0,197,0,18,0,159,0,13,0,143,0,7,0,102,0,5,0,123,0,126,0,197,0,3,0,220,0,247,255,210,0,244,255,187,0,250,255,151,0,254,255,174,0,80,0,200,0,53,0,187,0,47,0,159,0,40,0,118,0,38,0,100,0,18,0,141,0,111,0,179,0,78,0,166,0,86,0,197,0,50,0,207,0,27,0,187,0,0,0,115,0,139,0,218,0,34,0,220,0,29,0,174,0,46,0,128,0,61,0,54,0,89,0,187,0,65,0,238,0,14,0,197,0,18,0,125,0,26,0,90,0,25,0,82,0,13,0,161,0,86,0,189,0,1,0,205,0,254,255,156,0,252,255,143,0,252,255,146,0,252,255,172,0,72,0,230,0,31,0,192,0,45,0,102,0,76,0,38,0,85,0,56,0,41,0,64,0,173,0,166,0,91,0,141,0,111,0,128,0,116,0,118,0,109,0,177,0,0,0,23,0,222,0,253,0,14,0,236,0,21,0,174,0,49,0,33,0,118,0,44,0,93,0,23,0,187,0,218,0,28,0,179,0,28,0,118,0,35,0,95,0,30,0,72,0,24,0,128,0,108,0,187,0,1,0,174,0,255,255,125,0,255,255,110,0,255,255,108,0,255,255,202,0,52,0,197,0,53,0,146,0,75,0,46,0,118,0,33,0,103,0,64,0,50,0,118,0,126,0,138,0,114,0,128,0,122,0,161,0,86,0,243,0,250,255,195,0,0,0,38,0,210,0,215,0,39,0,179,0,58,0,97,0,101,0,95,0,85,0,87,0,70,0,69,0,152,0,236,0,24,0,205,0,18,0,172,0,12,0,154,0,6,0,125,0,1,0,169,0,75,0,187,0,4,0,230,0,254,255,228,0,252,255,236,0,252,255,241,0,254,255,192,0,66,0,200,0,46,0,187,0,42,0,159,0,34,0,136,0,25,0,105,0,10,0,179,0,62,0,207,0,55,0,192,0,63,0,192,0,54,0,195,0,36,0,177,0,1,0,143,0,98,0,225,0,27,0,207,0,34,0,200,0,30,0,131,0,57,0,97,0,60,0,197,0,45,0,15,1,8,0,218,0,13,0,133,0,19,0,90,0,19,0,72,0,7,0,182,0,51,0,179,0,1,0,225,0,255,255,154,0,254,255,110,0,255,255,92,0,0,0,195,0,41,0,241,0,26,0,189,0,40,0,82,0,64,0,33,0,60,0,67,0,17,0,120,0,94,0,192,0,68,0,151,0,94,0,146,0,90,0,143,0,72,0,161,0,0,0,113,0,128,0,0,1,12,0,218,0,29,0,166,0,48,0,44,0,99,0,31,0,87,0,148,0,78,0,238,0,20,0,184,0,22,0,113,0,27,0,90,0,22,0,74,0,9,0,192,0,37,0,184,0,0,0,215,0,255,255,141,0,255,255,97,0,0,0,49,0,0,0,8,1,13,0,182,0,51,0,138,0,61,0,95,0,63,0,54,0,59,0,64,0,25,0,200,0,45,0,179,0,75,0,156,0,87,0,174,0,65,0,177,0,44,0,174,0,0,0,164,0,85,0,195,0,45,0,148,0,65,0,105,0,79,0,95,0,72,0,87,0,60,0,169,0,63,0,146,197,181,207,232,243,238,251,244,250,249,179,219,214,240,250,254,244,254,254,254,254,0,0,154,0,61,0,141,0,54,0,90,0,45,0,54,0,34,0,54,0,13,0,128,0,109,0,136,0,54,0,148,0,45,0,92,0,41,0,54,0,33,0,51,0,15,0,87,0,113,0,87,0,44,0,97,0,40,0,67,0,36,0,46,0,29,0,41,0,15,0,64,0,80,0,59,0,33,0,61,0,31,0,51,0,28,0,44,0,22,0,33,0,12,0,49,0,63,0,69,0,12,0,59,0,16,0,46,0,14,0,31,0,13,0,26,0,6,0,92,0,26,0,128,0,108,0,77,0,119,0,54,0,84,0,26,0,71,0,87,0,19,0,95,0,155,0,154,0,4,0,182,0,0,0,159,0,248,255,128,0,251,255,143,0,251,255,187,0,55,0,182,0,0,0,228,0,253,255,187,0,249,255,174,0,247,255,189,0,245,255,169,0,79,0,161,0,247,255,192,0,248,255,187,0,247,255,169,0,246,255,136,0,247,255,184,0,40,0,164,0,245,255,179,0,246,255,174,0,246,255,161,0,246,255,115,0,249,255,197,0,20,0,195,0,245,255,195,0,245,255,146,0,246,255,110,0,250,255,95,0,252,255,195,0,39,0,182,0,55,0,172,0,77,0,177,0,37,0,169,0,29,0,172,0,52,0,92,0,162,0,174,0,80,0,164,0,80,0,95,0,80,0,46,0,66,0,56,0,24,0,36,0,193,0,164,0,80,0,166,0,77,0,105,0,76,0,49,0,68,0,46,0,31,0,49,0,186,0,97,0,78,0,110,0,74,0,72,0,72,0,44,0,60,0,33,0,30,0,69,0,131,0,61,0,61,0,69,0,63,0,51,0,57,0,31,0,48,0,26,0,27,0,64,0,89,0,67,0,23,0,51,0,32,0,36,0,33,0,26,0,28,0,20,0,12,0,44,0,68,0,26,0,197,0,41,0,189,0,61,0,129,0,28,0,103,0,49,0,52,0,244,255,245,0,102,0,141,0,79,0,166,0,72,0,162,0,97,0,125,0,179,0,4,0,51,1,0,0,72,0,168,0,69,0,175,0,84,0,160,0,105,0,127,0,148,0,34,0,54,1,0,0,84,0,151,0,82,0,161,0,87,0,153,0,87,0,135,0,115,0,51,0,61,1,0,0,97,0,125,0,102,0,131,0,105,0,125,0,87,0,122,0,84,0,64,0,54,0,184,0,166,0,18,0,146,0,43,0,125,0,51,0,90,0,64,0,95,0,7,0,38,0,154,0,38,1,0,0,13,0,225,0,10,0,225,0,67,0,168,0,0,0,167,0,161,0,94,0,172,0,76,0,172,0,75,0,136,0,80,0,64,0,98,0,74,0,67,0,59,1,0,0,169,0,76,0,207,0,56,0,164,0,66,0,97,0,80,0,67,0,72,0,72,1,0,0,136,0,80,0,187,0,53,0,154,0,62,0,72,0,85,0,254,255,105,0,49,1,0,0,74,0,91,0,128,0,64,0,113,0,64,0,61,0,77,0,41,0,75,0,3,1,0,0,46,0,84,0,51,0,81,0,28,0,89,0,31,0,78,0,23,0,77,0,202,0,0,0,67,1,0,0,67,1,0,0,44,1,0,0,236,0,0,0,195,0,0,0,72,1,0,0,2,2,2,2,4,4,0,0,255,0,1,1,2,1,1,2,2,1,1,2,2,2,1,2,2,2,2,2,1,1,2,2,3,3,4,3,4,4,4,3,3,3,3,3,4,3,3,3,4,4,4,4,4,3,3,4,4,4,3,4,4,4,4,4,4,4,5,5,5,5,5,5,16,0,11,0,10,0,16,0,24,0,40,0,51,0,61,0,12,0,12,0,14,0,19,0,26,0,58,0,60,0,55,0,14,0,13,0,16,0,24,0,40,0,57,0,69,0,56,0,14,0,17,0,22,0,29,0,51,0,87,0,80,0,62,0,18,0,22,0,37,0,58,0,68,0,109,0,103,0,77,0,24,0,35,0,55,0,64,0,81,0,104,0,113,0,92,0,49,0,64,0,78,0,87,0,103,0,121,0,120,0,101,0,72,0,92,0,95,0,98,0,112,0,100,0,103,0,99,0,17,0,18,0,24,0,47,0,99,0,99,0,99,0,99,0,18,0,21,0,26,0,66,0,99,0,99,0,99,0,99,0,24,0,26,0,56,0,99,0,99,0,99,0,99,0,99,0,47,0,66,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,16,0,16,0,16,0,20,0,24,0,28,0,32,0,40,0,16,0,16,0,20,0,24,0,28,0,32,0,40,0,48,0,16,0,20,0,24,0,28,0,32,0,40,0,48,0,64,0,20,0,24,0,28,0,32,0,40,0,48,0,64,0,64,0,24,0,28,0,32,0,40,0,48,0,64,0,64,0,64,0,28,0,32,0,40,0,48,0,64,0,64,0,64,0,96,0,32,0,40,0,48,0,64,0,64,0,64,0,96,0,128,0,40,0,48,0,64,0,64,0,64,0,96,0,128,0,128,0,30,25,20,20,15,15,14,14,13,13,12,12,11,11,10,10,9,9,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,3,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,200,0,190,0,180,0,170,0,170,0,160,0,160,0,150,0,150,0,140,0,140,0,130,0,130,0,120,0,120,0,110,0,110,0,100,0,100,0,90,0,90,0,90,0,80,0,80,0,80,0,70,0,70,0,70,0,60,0,60,0,60,0,60,0,50,0,50,0,50,0,50,0,40,0,40,0,40,0,40,0,40,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,20,0,20,0,20,0,20,0,20,0,20,0,20,0,20,0,10,0,10,0,10,0,10,0,10,0,10,0,10,0,244,1,0,0,194,1,0,0,144,1,0,0,114,1,0,0,84,1,0,0,54,1,0,0,29,1,0,0,9,1,0,0,245,0,0,0,225,0,0,0,210,0,0,0,195,0,0,0,185,0,0,0,180,0,0,0,170,0,0,0,160,0,0,0,150,0,0,0,145,0,0,0,135,0,0,0,130,0,0,0,125,0,0,0,115,0,0,0,110,0,0,0,107,0,0,0,100,0,0,0,96,0,0,0,93,0,0,0,89,0,0,0,85,0,0,0,82,0,0,0,75,0,0,0,74,0,0,0,70,0,0,0,68,0,0,0,64,0,0,0,60,0,0,0,57,0,0,0,56,0,0,0,52,0,0,0,50,0,0,0,49,0,0,0,45,0,0,0,44,0,0,0,43,0,0,0,40,0,0,0,38,0,0,0,37,0,0,0,35,0,0,0,33,0,0,0,32,0,0,0,30,0,0,0,29,0,0,0,28,0,0,0,25,0,0,0,24,0,0,0,22,0,0,0,21,0,0,0,19,0,0,0,18,0,0,0,17,0,0,0,15,0,0,0,13,0,0,0,12,0,0,0,10,0,0,0,0,1,128,0,86,0,64,0,160,200,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,200,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,6,31,0,96,30,33,0,48,0,0,0,5,0,0,0,104,253,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,248,227,32,0,152,200,32,0,40,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,8,0,1,0,248,227,32,0,136,111,29,0,0,175,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,248,227,32,0,112,25,29,0,184,152,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,248,227,32,0,168,200,28,0,136,128,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,248,227,32,0,96,102,32,0,240,81,32,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,96,102,32,0,176,46,32,0,200,254,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,96,102,32,0,208,232,31,0,56,213,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,96,102,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,6,31,0,108,0,0,0,24,5,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,234,33,0,108,0,0,0,96,73,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,0,32,0,48,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,176,0,192,0,208,0,224,0,240,0,0,1,16,1,32,1,48,1,64,1,80,1,96,1,112,1,128,1,144,1,160,1,176,1,192,1,208,1,224,1,240,1,0,2,8,2,16,2,24,2,32,2,40,2,48,2,56,2,64,2,72,2,80,2,88,2,96,2,104,2,112,2,120,2,128,2,136,2,144,2,152,2,160,2,168,2,176,2,184,2,192,2,200,2,208,2,216,2,224,2,232,2,240,2,248,2,0,3,8,3,16,3,24,3,32,3,40,3,48,3,56,3,64,3,72,3,80,3,88,3,96,3,104,3,112,3,120,3,128,3,136,3,144,3,152,3,160,3,168,3,176,3,184,3,192,3,200,3,208,3,216,3,224,3,232,3,240,3,248,3,0,4,64,4,128,4,192,4,0,5,64,5,128,5,192,5,0,6,64,6,128,6,192,6,0,7,64,7,128,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+122880);
/* memory initializer */ allocate([192,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,20,0,24,0,28,0,32,0,48,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,253,3,254,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,7,250,6,251,5,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,241,15,242,14,243,13,244,12,245,11,246,10,247,9,248,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,225,31,226,30,227,29,228,28,229,27,230,26,231,25,232,24,233,23,234,22,235,21,236,20,237,19,238,18,239,17,240,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,193,63,194,62,195,61,196,60,197,59,198,58,199,57,200,56,201,55,202,54,203,53,204,52,205,51,206,50,207,49,208,48,209,47,210,46,211,45,212,44,213,43,214,42,215,41,216,40,217,39,218,38,219,37,220,36,221,35,222,34,223,33,224,32,129,127,130,126,131,125,132,124,133,123,134,122,135,121,136,120,137,119,138,118,139,117,140,116,141,115,142,114,143,113,144,112,145,111,146,110,147,109,148,108,149,107,150,106,151,105,152,104,153,103,154,102,155,101,156,100,157,99,158,98,159,97,160,96,161,95,162,94,163,93,164,92,165,91,166,90,167,89,168,88,169,87,170,86,171,85,172,84,173,83,174,82,175,81,176,80,177,79,178,78,179,77,180,76,181,75,182,74,183,73,184,72,185,71,186,70,187,69,188,68,189,67,190,66,191,65,192,64,24,0,1,4,5,7,3,2,6,8,0,0,0,0,0,0,5,4,3,3,3,3,3,3,3,5,0,0,0,0,0,0,60,6,0,1,3,2,4,12,28,0,0,0,0,0,0,0,6,3,3,2,2,3,4,5,6,0,0,0,0,0,0,0,234,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,3,234,0,42,0,26,0,6,0,1,0,0,0,2,0,10,0,106,0,234,1,234,7,12,0,0,0,0,0,0,0,0,0,0,0,11,9,7,5,3,1,2,4,6,8,10,12,100,6,0,0,0,0,0,0,0,0,0,0,100,0,228,0,164,0,104,0,4,0,8,0,20,0,24,0,0,0,1,0,2,0,3,0,12,0,40,0,36,0,100,1,0,0,100,2,11,0,0,0,0,0,10,8,8,7,6,6,5,5,4,2,2,2,4,7,8,9,0,11,20,87,12,0,2,0,1,0,0,0,4,0,52,0,84,0,148,0,20,0,20,1,20,2,20,3,20,6,20,14,20,15,20,39,20,7,20,23,20,55,15,4,2,1,3,5,6,7,8,10,10,11,11,12,12,12,14,14,15,14,0,0,0,0,31,0,1,3,7,15,0,0,5,1,2,3,4,5,0,0,124,3,4,0,60,0,76,0,58,0,44,0,28,0,26,0,36,0,20,0,1,0,2,0,0,0,3,0,7,0,5,0,6,0,8,0,9,0,10,0,12,0,252,0,124,0,124,1,10,6,7,7,6,6,6,6,6,5,4,4,4,3,3,3,3,4,4,5,7,8,9,10,130,82,22,0,0,0,54,1,4,0,0,0,7,0,10,0,14,0,3,0,1,0,13,0,6,0,9,0,18,0,5,0,37,0,34,0,21,0,2,0,118,0,53,0,66,0,194,0,130,1,182,0,54,0,194,3,130,4,194,1,130,6,130,8,130,10,130,0,130,2,130,18,130,50,130,34,0,0,0,0,15,6,0,9,3,3,3,4,4,3,4,4,5,4,5,6,6,6,6,8,7,6,8,9,9,8,9,10,11,10,11,12,12,12,14,15,14,14,0,0,234,51,5,0,0,0,12,0,0,0,6,0,3,0,8,0,2,0,1,0,4,0,7,0,26,0,15,0,28,0,44,0,10,0,29,0,45,0,42,0,13,0,76,0,140,0,106,0,205,0,77,0,234,0,12,2,12,3,12,1,234,1,234,7,234,11,234,3,234,19,0,0,14,4,0,10,4,3,3,4,4,3,4,4,5,4,5,6,6,5,6,7,7,7,8,8,8,8,9,10,10,10,10,11,12,13,14,0,0,0,0,0,96,23,1,0,0,0,130,0,12,0,6,0,3,0,7,0,8,0,4,0,16,0,18,0,34,0,26,0,0,0,32,0,10,0,64,0,74,0,106,0,42,0,66,0,2,0,96,0,170,0,224,0,194,0,194,1,96,1,96,3,96,7,96,15,13,2,0,8,4,3,3,3,4,4,5,5,6,5,7,7,7,7,7,7,8,8,8,9,8,8,9,9,10,11,13,12,164,7,1,0,32,0,18,0,28,0,8,0,6,0,16,0,0,0,20,0,4,0,50,0,112,0,12,0,2,0,58,0,26,0,44,0,42,0,34,0,36,0,10,0,100,0,48,0,98,0,164,0,164,1,164,3,11,1,6,6,5,4,3,6,6,5,6,6,7,6,6,6,6,6,6,7,8,6,7,7,7,9,10,11,0,0,0,0,142,3,1,0,0,0,34,0,10,0,6,0,18,0,2,0,30,0,62,0,86,0,22,0,14,0,50,0,114,0,66,0,142,0,78,0,242,0,46,0,54,0,194,0,142,1,0,0,10,1,2,6,4,5,6,7,6,6,7,7,8,7,8,8,9,7,8,6,6,8,10,0,87,28,4,0,0,0,1,0,3,0,2,0,15,0,14,0,7,0,22,0,55,0,39,0,38,0,102,0,6,0,151,0,70,0,198,1,23,0,134,7,134,0,87,2,215,0,87,3,198,0,134,3,134,1,0,0,87,1,87,12,87,0,0,0,134,11,0,0,87,20,0,0,87,4,0,0,0,0,0,0,13,3,3,2,3,3,4,4,6,5,6,6,7,7,8,8,8,9,8,11,9,10,8,10,9,12,10,0,10,13,11,0,12,0,13,0,13,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,36,0,0,0,44,0,0,0,52,0,0,0,60,0,0,0,76,0,0,0,92,0,0,0,108,0,0,0,124,0,0,0,156,0,0,0,188,0,0,0,220,0,0,0,252,0,0,0,60,1,0,0,124,1,0,0,188,1,0,0,252,1,0,0,124,2,0,0,252,2,0,0,124,3,0,0,252,3,0,0,252,4,0,0,252,5,0,0,252,6,0,0,252,7,0,0,252,9,0,0,252,11,0,0,252,13,0,0,252,15,0,0,252,19,0,0,252,23,0,0,252,27,0,0,252,31,0,0,252,39,0,0,252,47,0,0,252,55,0,0,252,63,0,0,252,79,0,0,252,95,0,0,252,111,0,0,252,127,0,0,252,159,0,0,252,191,0,0,252,223,0,0,252,255,0,0,252,63,1,0,252,127,1,0,252,191,1,0,0,0,128,2,160,4,212,6,250,8,122,9,250,9,250,11,250,13,10,16,10,18,76,20,76,22,0,0,0,0,0,0,0,0,0,0,128,2,0,0,132,4,0,0,196,6,0,0,4,9,0,0,36,11,0,0,68,13,0,0,84,15,0,0,100,17,0,0,100,20,0,0,228,22,0,0,228,25,0,0,100,28,0,0,228,30,0,0,232,32,0,0,232,34,0,0,40,37,0,0,0,0,0,0,0,0,8,2,40,2,104,2,104,4,136,4,200,4,204,6,236,6,44,7,108,7,132,9,170,11,234,11,26,14,58,16,122,16,138,18,206,20,14,21,14,23,154,25,234,29,150,32,88,36,4,39,134,41,226,43,142,47,206,50,248,52,152,55,194,57,72,60,222,63,114,68,148,79,58,85,58,87,122,87,126,90,126,92,190,92,244,96,244,98,52,99,92,103,100,105,168,105,200,107,208,107,216,107,224,107,232,107,64,110,98,110,130,110,130,112,162,112,194,112,194,114,228,114,4,115,8,117,42,117,74,117,74,119,108,119,140,119,144,121,178,121,210,121,226,123,2,124,34,124,50,126,84,126,116,126,0,0,0,0,32,173,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,28,35,0,0,216,34,0,20,0,0,0,5,0,0,0,72,156,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,192,95,34,0,0,216,34,0,20,0,0,0,5,0,0,0,72,156,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,48,40,34,0,64,248,33,0,36,0,0,0,5,0,0,0,24,207,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,232,167,33,0,48,138,33,0,52,0,0,0,5,0,0,0,88,97,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,56,35,33,0,24,0,33,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,56,35,33,0,240,229,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,56,35,33,0,240,202,32,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,56,35,33,0,200,176,32,0,240,154,32,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,200,176,32,0,112,130,32,0,112,104,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,176,32,0,64,83,32,0,88,51,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,176,32,0,80,1,32,0,96,234,31,0,148,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,224,214,31,0,24,196,31,0,152,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,173,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,2,0,0,0,0,0,0,0,0,0,0,2,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,213,31,0,108,0,0,0,160,16,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,136,88,34,0,208,2,0,0,224,1,0,0,16,84,34,0,208,2,0,0,64,2,0,0,200,79,34,0,96,1,0,0,240,0,0,0,32,76,34,0,96,1,0,0,32,1,0,0,128,71,34,0,128,2,0,0,224,1,0,0,152,67,34,0,0,3,0,0,64,2,0,0,200,62,34,0,96,1,0,0,240,0,0,0,200,46,34,0,96,1,0,0,240,0,0,0,184,40,34,0,128,0,0,0,96,0,0,0,248,37,34,0,176,0,0,0,144,0,0,0,0,35,34,0,96,1,0,0,32,1,0,0,176,31,34,0,192,2,0,0,64,2,0,0,216,28,34,0,128,5,0,0,128,4,0,0,248,25,34,0,160,0,0,0,120,0,0,0,248,21,34,0,64,1,0,0,240,0,0,0,160,18,34,0,128,2,0,0,224,1,0,0,0,14,34,0,32,3,0,0,88,2,0,0,184,255,33,0,0,4,0,0,0,3,0,0,16,249,33,0,64,6,0,0,176,4,0,0,184,245,33,0,0,8,0,0,0,6,0,0,128,241,33,0,0,5,0,0,0,4,0,0,120,237,33,0,0,10,0,0,0,8,0,0,184,233,33,0,0,20,0,0,0,16,0,0,120,229,33,0,84,3,0,0,224,1,0,0,0,227,33,0,86,5,0,0,0,3,0,0,240,224,33,0,64,6,0,0,0,4,0,0,72,222,33,0,128,7,0,0,176,4,0,0,232,209,33,0,0,10,0,0,64,6,0,0,184,207,33,0,128,12,0,0,0,8,0,0,248,204,33,0,0,15,0,0,96,9,0,0,248,202,33,0,0,25,0,0,0,16,0,0,40,200,33,0,0,30,0,0,192,18,0,0,176,196,33,0,64,1,0,0,200,0,0,0,56,193,33,0,128,2,0,0,94,1,0,0,232,190,33,0,84,3,0,0,224,1,0,0,56,189,33,0,0,5,0,0,208,2,0,0,240,185,33,0,128,7,0,0,56,4,0,0,24,172,33,0,0,8,0,0,56,4,0,0,80,168,33,0,206,7,0,0,56,4,0,0,112,166,33,0,0,8,0,0,90,3,0,0,240,164,33,0,0,16,0,0,112,8,0,0,8,163,33,0,156,15,0,0,112,8,0,0,48,160,33,0,0,16,0,0,180,6,0,0,224,157,33,0,128,2,0,0,104,1,0,0,136,155,33,0,240,0,0,0,160,0,0,0,184,153,33,0,144,1,0,0,240,0,0,0,184,151,33,0,176,1,0,0,240,0,0,0,56,141,33,0,224,1,0,0,64,1,0,0,128,138,33,0,192,3,0,0,28,2,0,0,0,0,0,0,136,88,34,0,48,117,0,0,233,3,0,0,16,84,34,0,25,0,0,0,1,0,0,0,200,79,34,0,48,117,0,0,233,3,0,0,32,76,34,0,25,0,0,0,1,0,0,0,128,71,34,0,48,117,0,0,233,3,0,0,152,67,34,0,25,0,0,0,1,0,0,0,200,62,34,0,24,0,0,0,1,0,0,0,200,46,34,0,192,93,0,0,233,3,0,0,8,0,0,0,7,0,0,0,7,0,0,0,10,0,0,0,9,0,0,0,9,0,0,0,6,0,0,0,0,0,0,0,191,0,0,0,97,0,0,0,48,0,0,0,95,2,0,0,246,0,0,0,230,0,0,0,32,0,0,0,0,0,0,0,1,2,18,18,2,3,254,18,2,4,7,5,3,6,8,255,18,2,0,0,1,18,18,255,18,2,3,4,6,5,7,18,253,8,2,255,3,0,1,2,1,18,254,4,18,2,3,6,255,7,5,254,18,8,2,4,0,0,1,17,17,2,3,4,18,255,5,6,7,18,2,8,17,3,254,0,1,1,18,18,2,18,3,2,18,4,255,3,18,2,6,8,17,5,0,0,2,18,17,2,3,254,5,18,253,2,4,7,3,6,8,5,17,0,1,1,18,254,2,253,18,5,254,18,2,3,6,2,17,4,7,255,0,1,1,17,8,18,3,254,2,5,4,18,6,3,8,7,2,5,4,0,0,2,18,17,254,2,18,3,2,5,253,4,7,18,3,8,6,2,0,1,1,3,6,5,5,1,3,7,4,2,6,4,18,3,7,5,6,0,1,2,1,18,3,2,254,1,5,4,6,2,7,1,8,3,255,1,0,0,1,18,18,2,3,6,3,5,254,2,4,18,3,254,255,6,7,0,0,1,254,18,2,18,7,2,6,254,3,4,18,18,2,253,8,5,0,0,2,18,18,18,2,4,3,18,5,3,6,254,2,4,18,8,7,0,0,1,254,1,18,2,254,18,255,5,7,2,3,4,18,2,6,2,0,1,1,17,18,3,2,1,7,255,2,4,3,5,6,254,18,7,8,0,1,1,18,18,2,18,3,4,6,254,18,5,8,2,3,7,4,255,0,0,1,18,18,18,255,2,3,4,6,8,18,3,5,2,6,7,4,0,1,1,17,254,18,18,2,5,3,8,2,255,6,1,3,4,7,5,0,0,1,17,17,18,2,3,6,254,8,1,7,5,2,3,1,4,8,0,1,1,17,17,3,2,7,1,4,3,6,2,5,254,8,7,18,6,0,0,1,18,17,254,2,18,3,253,7,6,5,2,4,255,8,3,17,0,1,1,2,18,18,254,2,4,255,5,18,3,8,6,2,7,17,4,0,0,1,17,3,6,8,5,4,3,8,1,18,7,2,4,5,6,3,0,1,2,17,18,4,8,3,2,5,7,6,8,2,7,254,18,3,4,0,1,1,6,5,5,3,4,7,3,2,4,6,3,7,1,5,2,4,0,1,1,1,18,255,2,1,3,8,254,2,5,6,3,8,7,18,4,0,0,1,1,17,255,18,3,2,5,4,6,7,8,3,4,2,1,254,0,0,1,18,2,18,18,2,18,6,254,18,7,5,4,3,2,18,254,0,0,3,1,4,18,3,2,4,1,5,2,3,6,18,8,7,2,4,0,0,1,17,254,1,253,2,18,3,254,4,18,3,6,7,253,2,8,0,1,1,17,18,18,4,2,3,7,6,18,8,5,255,4,2,3,17,0,1,2,18,255,17,18,2,3,254,18,5,8,2,4,3,7,6,255,0,1,1,18,18,18,254,4,2,3,18,5,8,2,4,6,7,254,3,0,1,2,18,18,254,18,255,3,2,5,18,254,7,2,3,4,6,8,0,0,1,17,18,255,2,4,18,8,3,6,5,7,253,2,4,3,17,0,1,1,18,18,17,2,255,18,3,2,18,6,5,4,18,7,2,255,0,0,2,1,18,255,18,3,2,4,6,253,7,255,5,1,2,3,8,0,1,1,1,17,254,2,253,6,3,5,1,2,7,6,8,254,4,1,0,0,1,17,255,5,1,4,3,6,2,254,18,3,2,4,5,8,255,0,0,2,18,18,17,2,3,254,5,18,2,4,7,8,6,17,3,5,0,1,1,1,5,1,3,4,3,7,5,1,3,6,1,2,4,3,8,0,1,2,1,255,3,2,18,7,254,5,2,6,4,3,255,18,8,7,0,0,2,18,17,3,18,2,5,4,3,6,2,7,8,18,3,4,5,0,1,1,3,6,17,8,7,5,18,255,1,2,3,4,2,6,8,1,0,0,2,18,18,3,253,18,2,6,5,3,7,18,4,254,8,2,3,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,1,7,2,3,18,254,3,6,4,2,7,8,5,3,17,0,1,1,3,6,5,5,1,3,7,4,2,6,4,18,3,7,5,6,0,0,1,18,18,18,2,4,255,18,8,255,2,3,4,6,254,1,7,0,1,1,18,254,17,18,2,6,3,254,5,4,7,1,253,8,2,6,0,0,1,17,18,18,4,2,7,3,6,254,18,8,4,5,2,7,17,0,1,1,18,18,5,4,6,4,1,5,4,3,2,5,6,1,4,5,0,0,1,18,18,254,18,2,253,3,8,5,18,6,4,3,255,7,2,0,1,1,18,2,254,253,18,5,2,3,254,4,6,1,253,2,7,8,0,0,1,18,3,5,8,2,6,7,3,1,5,2,255,8,6,7,4,0,1,1,4,3,8,1,5,6,2,5,8,254,2,7,3,18,5,4,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,3,18,18,7,2,4,18,6,2,3,255,8,5,18,253,0,0,1,3,17,18,2,18,6,7,253,18,2,5,6,3,8,7,255,0,1,1,18,18,2,18,18,2,255,7,3,18,5,2,6,4,255,18,0,0,3,18,3,4,1,5,2,18,4,2,3,18,7,6,1,2,4,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,1,18,2,3,6,4,5,7,18,3,8,2,4,254,17,0,1,2,18,17,2,3,5,18,6,254,7,3,2,4,18,8,255,5,0,0,2,1,18,255,18,3,2,4,6,253,7,255,5,1,2,3,8,0,1,1,1,18,255,8,2,6,3,254,1,2,5,4,253,8,6,3,0,0,1,18,18,2,18,2,18,7,6,18,2,254,3,5,4,18,8,0,1,2,18,17,2,3,18,255,2,3,6,18,5,4,3,7,2,8,0,1,2,18,18,3,254,4,18,5,7,6,2,4,253,8,5,18,3,0,1,1,17,254,18,18,2,5,3,8,2,255,6,1,3,4,7,5,0,1,1,3,17,18,5,7,2,4,6,1,8,255,3,7,4,1,2,0,0,2,1,254,2,18,3,5,2,4,7,255,2,3,5,18,254,4,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,1,2,254,6,18,253,2,7,3,254,5,6,1,8,2,4,0,0,1,18,18,18,3,254,6,18,2,4,3,5,8,7,6,2,254,0,1,1,1,5,1,3,4,3,7,5,1,3,6,1,2,4,3,8,0,0,1,3,17,18,2,5,18,6,7,5,254,2,4,18,3,6,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,17,255,18,2,4,255,8,3,18,7,253,4,5,1,2,254,0,0,1,255,18,18,2,18,3,5,18,2,18,8,6,4,5,7,255,0,1,1,18,18,3,6,4,8,254,2,5,3,7,18,6,8,4,2,0,1,1,17,18,18,254,5,2,3,1,4,255,8,6,5,3,2,18,0,1,1,17,17,1,2,4,5,2,6,255,3,1,1,254,4,2,7,0,1,1,17,1,7,2,3,18,254,3,6,4,2,7,8,5,3,17,0,0,1,18,17,254,253,1,2,3,2,5,4,7,253,6,254,2,1,0,1,1,1,3,5,18,1,2,7,3,6,2,5,8,255,1,4,7,0,1,1,17,3,6,8,1,4,5,3,254,7,2,8,5,6,18,3,0,1,1,17,18,2,4,8,254,3,1,5,6,7,1,2,3,4,7,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,3,1,8,18,5,2,3,18,6,7,254,4,3,2,8,18,0,0,1,18,17,2,18,3,4,255,18,7,6,2,8,4,18,18,5,0,0,1,18,18,2,18,18,2,7,254,6,5,4,3,18,3,2,17,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,8,18,3,2,1,5,4,6,255,3,253,8,18,7,2,0,1,2,18,17,18,2,3,5,254,18,6,255,2,3,7,4,8,17,0,0,1,255,18,18,2,18,3,5,18,2,18,8,6,4,5,7,255,0,1,2,18,18,254,17,2,18,3,4,18,8,7,255,2,4,5,17,0,0,2,17,253,17,3,2,254,18,8,4,253,2,18,5,3,254,6,0,0,1,18,18,2,18,18,2,7,254,6,5,4,3,18,3,2,17,0,0,2,1,18,255,3,5,2,253,18,7,3,255,6,4,2,17,5,0,1,1,17,254,17,2,253,1,5,255,4,6,3,2,8,7,254,5,0,1,1,1,18,1,3,5,8,6,2,3,255,7,1,4,8,5,253,0,0,2,3,18,18,2,18,254,6,5,7,2,4,18,3,6,253,5,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,3,6,17,8,7,5,18,255,1,2,3,4,2,6,8,1,0,0,4,18,2,17,3,18,254,2,6,18,2,7,3,5,4,8,18,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,18,18,2,3,6,3,5,254,2,4,18,3,254,255,6,7,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,1,2,5,3,254,1,4,3,7,6,253,2,1,1,2,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,18,18,254,18,254,2,3,6,18,4,255,2,3,8,1,4,0,1,1,17,254,17,2,253,1,5,255,4,6,3,2,8,7,254,5,0,0,1,17,17,18,3,2,18,18,6,8,2,254,3,5,4,17,18,0,1,1,1,5,1,3,4,3,7,5,1,3,6,1,2,4,3,8,0,1,1,1,3,253,18,18,6,5,18,2,255,3,8,7,253,4,17,0,1,1,18,1,2,1,3,8,7,4,1,5,2,255,253,18,6,2,0,0,1,18,3,5,2,6,8,18,5,7,2,3,255,6,7,8,5,0,0,2,18,3,254,7,8,2,5,4,253,8,3,2,18,5,4,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,3,1,1,2,5,2,7,4,3,255,18,254,8,2,1,6,7,0,0,1,3,17,18,5,2,6,7,18,4,5,3,6,18,2,7,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,1,18,1,2,3,5,1,2,6,7,4,3,8,1,17,5,0,1,2,17,255,18,254,2,3,5,18,2,4,6,7,3,255,5,8,0,1,1,18,18,253,18,254,2,3,254,18,6,4,5,8,3,17,253,0,1,1,18,7,6,5,5,3,1,4,2,7,3,4,253,6,18,8,0,0,2,18,18,2,3,5,18,2,4,3,6,18,7,8,255,5,2,0,0,1,18,17,255,2,18,3,2,18,4,3,18,2,6,5,8,17,0,0,2,18,17,2,3,18,5,255,6,7,8,2,3,4,5,18,6,0,1,2,18,253,18,2,3,254,253,5,18,7,6,2,4,3,8,254,0,1,1,17,18,18,254,2,3,5,4,8,18,255,5,3,6,254,7,0,1,2,18,17,2,254,18,3,255,4,18,2,7,5,3,8,6,4,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,1,5,1,3,4,3,7,5,1,3,6,1,2,4,3,8,0,0,2,18,18,3,3,254,2,5,18,6,3,255,4,7,255,1,2,0,0,1,254,1,18,2,254,5,7,18,3,2,6,2,255,4,254,17,0,0,2,18,18,18,2,3,254,18,5,4,2,6,8,3,254,4,18,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,18,255,3,2,5,1,3,2,8,4,7,6,2,255,5,0,1,1,17,18,18,4,2,3,7,6,18,8,5,255,4,2,3,17,0,0,1,18,18,254,18,2,3,4,5,6,18,8,2,3,7,254,4,0,0,1,18,254,18,18,253,254,2,3,5,8,1,2,6,4,7,255,0,0,1,18,17,2,18,3,254,2,7,6,4,18,3,8,7,4,2,0,1,1,17,18,18,4,2,3,7,6,18,8,5,255,4,2,3,17,0,1,1,18,17,18,2,5,3,254,18,6,2,3,4,8,7,5,255,0,0,1,2,255,18,255,2,4,253,18,5,3,6,18,2,4,7,8,0,1,1,17,18,8,3,6,4,255,5,2,7,3,8,6,5,18,4,0,0,2,18,3,254,7,8,2,5,4,253,8,3,2,18,5,4,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,1,18,255,8,2,6,3,254,1,2,5,4,253,8,6,3,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,17,18,18,4,2,7,3,6,254,18,8,4,5,2,7,17,0,1,2,18,255,18,3,254,18,2,5,3,6,7,2,255,18,8,4,0,1,2,1,18,254,4,18,2,3,6,255,7,5,254,18,8,2,4,0,1,2,1,18,253,2,3,18,255,5,6,2,8,3,4,1,254,7,0,0,1,1,17,255,18,3,2,5,4,6,7,8,3,4,2,1,254,0,1,1,18,17,18,4,3,5,1,2,6,3,4,7,1,8,5,2,0,0,1,18,254,7,1,3,2,253,4,6,254,7,8,1,5,4,3,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,18,18,18,254,2,5,3,7,18,2,4,253,5,6,3,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,3,3,18,255,5,2,7,18,6,5,2,4,3,255,7,18,6,0,0,2,18,18,18,4,3,2,6,4,8,18,5,3,2,7,254,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,18,18,18,2,3,254,18,5,4,2,6,8,3,254,4,18,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,8,18,3,2,1,5,4,6,255,3,253,8,18,7,2,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,18,2,4,6,254,2,8,3,4,18,7,255,6,0,0,1,18,1,254,2,4,1,3,255,2,5,7,1,6,8,254,17,0,0,1,17,17,18,2,5,4,18,3,8,7,4,6,8,1,5,2,0,1,2,18,18,5,4,6,3,4,18,8,4,255,7,5,3,6,2,0,0,1,18,18,253,18,3,6,2,5,7,18,3,8,255,4,5,2,0,1,1,18,2,254,253,18,5,2,254,4,3,6,18,8,255,2,7,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,1,7,2,3,18,254,3,6,4,2,7,8,5,3,17,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,17,18,3,18,2,5,4,7,253,6,3,2,18,4,7,3,0,1,1,1,7,4,5,3,4,5,1,3,6,3,2,4,8,254,7,0,0,1,1,18,255,254,18,3,2,255,6,7,4,5,3,18,2,253,0,1,1,18,18,255,3,6,18,5,4,8,2,3,6,18,7,4,254,0,0,2,18,18,2,6,18,2,18,5,3,18,2,4,7,8,3,18,0,1,1,3,18,18,5,18,6,2,4,7,254,18,5,8,6,3,2,0,0,1,18,254,7,1,3,2,253,4,6,254,7,8,1,5,4,3,0,1,1,18,254,18,2,5,18,3,254,4,7,2,255,8,6,5,1,0,1,1,17,17,5,18,4,1,2,8,6,4,254,3,5,255,1,8,0,0,2,1,2,17,3,7,18,2,255,4,5,18,2,7,3,6,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,3,6,17,8,7,5,18,255,1,2,3,4,2,6,8,1,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,18,18,18,2,254,3,6,4,8,18,2,5,7,4,3,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,18,1,8,3,5,6,4,255,8,3,7,18,2,5,8,4,0,1,1,17,18,5,2,4,3,1,6,254,1,3,2,4,5,255,17,0,1,1,18,17,2,18,3,253,7,2,6,4,3,5,18,8,2,254,0,1,1,18,17,18,4,3,5,255,18,2,7,8,4,6,3,18,5,0,0,1,18,17,18,254,2,253,3,4,8,5,2,18,6,3,7,254,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,18,8,3,4,6,18,5,254,3,8,5,2,4,7,6,0,0,1,18,254,3,5,1,7,3,2,6,253,4,1,5,8,3,254,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,3,17,18,5,255,18,2,6,7,18,5,3,253,255,6,2,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,3,18,17,254,3,255,18,2,5,3,7,6,2,4,8,18,5,0,0,1,18,255,18,2,18,3,5,18,2,8,18,5,4,255,6,2,0,1,2,18,254,18,18,2,3,4,253,2,5,18,7,4,3,8,6,0,0,2,17,255,18,2,255,1,7,3,8,5,254,4,1,2,253,6,0,0,1,18,17,2,18,2,18,6,7,4,3,18,5,2,254,17,8,0,0,3,18,17,2,3,253,255,18,2,4,5,18,7,3,2,253,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,3,18,18,18,2,6,5,18,7,2,4,6,18,5,3,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,18,18,3,6,3,254,2,18,5,255,7,3,4,254,2,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,18,17,18,18,254,2,3,253,18,6,4,2,254,8,3,7,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,18,18,18,4,2,7,8,18,3,2,254,4,7,6,17,5,0,1,1,18,18,255,254,8,3,18,6,3,5,8,2,4,7,1,6,0,1,1,1,253,3,18,18,2,255,3,6,5,18,4,7,254,8,3,0,1,1,1,18,4,2,5,18,1,3,255,6,1,4,8,2,5,1,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,10,10,10,10,16,16,16,28,16,16,29,42,49,20,49,59,25,26,26,27,31,33,33,33,34,34,37,67,38,39,39,40,40,41,79,43,44,45,45,48,48,64,50,51,52,88,52,53,74,55,57,58,58,74,60,101,61,62,84,66,66,68,69,87,82,71,97,73,73,82,75,111,77,94,78,87,81,83,97,85,83,94,86,99,89,90,99,111,92,93,134,95,98,105,98,105,110,102,108,102,118,103,106,106,113,109,112,114,112,116,125,115,116,117,117,126,119,125,121,121,123,145,124,126,131,127,129,165,130,132,138,133,135,145,136,137,139,146,141,143,142,144,148,147,155,151,149,151,150,152,157,153,154,156,168,158,162,161,160,172,163,169,164,166,184,167,170,177,174,171,173,182,176,180,178,175,189,179,181,186,183,192,185,200,187,191,188,190,197,193,196,197,194,195,196,198,202,199,201,210,203,207,204,205,206,208,214,209,211,221,212,213,215,224,216,217,218,219,220,222,228,223,225,226,224,227,229,240,230,231,232,233,234,235,236,238,239,237,242,241,243,242,244,245,246,247,248,249,250,251,252,252,253,254,255,4,2,3,1,4,1,2,3,25,0,39,0,242,0,186,3,48,9,103,18,49,0,48,0,151,0,33,2,139,5,36,1,235,0,212,1,216,3,132,5,100,3,95,4,102,15,49,9,205,36,47,0,57,0,232,0,195,2,138,7,55,0,41,0,132,0,177,1,237,0,134,0,249,0,171,3,235,1,188,8,30,1,243,0,32,2,138,5,236,0,142,0,43,1,234,1,25,1,176,4,177,4,184,3,145,6,101,3,237,1,154,4,169,14,168,14,189,8,204,36,38,0,53,0,219,0,196,2,178,7,56,0,43,0,127,0,179,1,244,0,145,0,22,1,187,3,21,2,50,9,45,0,42,0,138,0,222,1,40,0,32,0,92,0,144,0,104,0,238,1,233,0,141,0,42,1,135,0,93,0,24,1,73,3,239,1,227,1,185,8,240,0,211,0,20,2,155,4,218,0,137,0,37,1,23,2,45,1,144,6,148,0,125,0,31,1,126,0,89,0,39,1,165,1,17,1,248,0,93,4,185,3,89,2,128,5,193,2,223,1,133,5,22,2,99,1,176,1,196,3,184,8,139,7,85,7,129,5,103,15,0,0,0,0,5,6,8,10,12,13,6,6,8,10,11,9,8,9,10,11,10,11,12,12,14,6,6,8,10,11,6,6,8,9,8,8,8,10,9,12,9,8,10,11,8,8,9,9,9,11,11,10,11,10,9,11,12,12,12,14,6,6,8,10,11,6,6,7,9,8,8,9,10,10,12,6,6,8,9,6,6,7,8,7,9,8,8,9,8,7,9,10,9,9,12,8,8,10,11,8,8,9,10,9,11,8,7,9,7,7,9,9,9,8,11,10,10,11,10,9,11,10,9,9,10,12,11,11,11,12,1,0,85,0,28,0,26,0,43,0,40,0,103,0,139,0,57,0,112,1,13,1,165,2,71,0,100,4,151,6,35,5,203,8,27,0,14,0,0,0,16,0,18,0,54,0,72,0,76,0,194,0,155,0,113,1,59,0,36,2,74,3,214,2,25,0,15,0,2,0,20,0,23,0,6,0,93,0,84,0,199,0,180,0,146,1,14,1,51,2,67,0,44,0,15,0,19,0,6,0,47,0,44,0,104,0,119,0,223,0,17,1,164,1,106,1,164,2,39,0,17,0,24,0,45,0,15,0,74,0,64,0,151,0,31,0,27,1,34,0,109,1,102,0,53,0,5,0,43,0,73,0,9,0,117,0,203,0,170,0,135,1,6,1,138,0,71,0,96,0,110,0,29,0,116,0,196,0,30,0,24,1,167,1,56,0,66,0,83,0,118,0,168,0,202,0,130,0,16,1,141,1,45,1,185,0,200,0,222,0,28,0,171,0,19,1,140,1,15,1,154,0,165,0,183,0,26,1,134,1,166,1,89,2,83,1,138,1,147,1,32,0,12,1,70,0,58,0,7,1,73,1,108,1,215,2,37,2,88,2,22,3,150,6,23,3,66,0,34,5,144,2,202,8,1,0,0,0,0,0,0,0,7,6,6,6,7,7,8,9,9,10,10,11,11,11,12,12,6,4,5,5,6,6,7,8,8,9,9,10,10,10,11,6,4,5,5,6,7,7,8,8,9,9,10,10,11,6,5,5,6,6,7,7,8,8,9,9,10,10,7,6,6,6,7,7,8,8,9,9,10,10,7,6,7,7,7,8,8,8,9,9,10,8,7,7,7,8,8,8,9,9,9,9,8,8,8,8,8,9,9,9,9,8,8,8,9,9,9,9,10,9,9,9,9,9,9,10,9,9,9,10,10,11,10,10,10,10,11,10,10,10,11,10,11,12,11,12,3,0,0,0,0,0,0,0,26,0,3,0,23,0,16,0,12,0,9,0,5,0,0,0,13,0,10,0,9,0,12,0,15,0,2,0,4,0,7,0,11,0,15,0,28,0,6,0,16,0,21,0,28,0,34,0,59,0,14,0,25,0,35,0,52,0,54,0,58,0,71,0,8,0,10,0,30,0,49,0,55,0,80,0,83,0,107,0,111,0,140,0,232,0,234,0,235,0,22,0,62,0,63,0,108,0,137,0,138,0,163,0,164,0,212,0,221,0,236,0,238,0,26,1,210,1,36,0,37,0,46,0,39,0,194,0,192,0,218,0,219,0,17,1,68,1,22,1,74,1,69,1,184,1,171,1,218,1,222,1,219,1,223,1,54,2,55,2,166,3,167,3,77,0,76,0,94,0,95,0,131,1,130,1,134,1,33,2,135,1,32,2,46,2,47,2,150,2,84,3,151,2,85,3,114,3,115,3,22,0,0,0,0,0,0,0,7,6,5,5,5,5,5,5,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,5,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,144,197,33,0,108,0,0,0,96,73,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,12,0,0,0,255,37,15,4,3,1,0,0,0,0,255,36,14,6,3,1,0,0,0,0,255,26,13,3,1,0,0,0,0,0,255,43,15,3,1,0,0,0,0,0,255,20,6,1,0,0,0,0,0,0,255,40,1,0,0,0,0,0,0,0,255,16,14,2,0,0,0,0,0,0,255,30,28,3,0,0,0,0,0,0,6,5,4,4,3,2,2,2,2,2,2,2,2,2,2,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+133120);
/* memory initializer */ allocate([1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,9,5,4,4,3,3,3,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,4,4,3,3,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,4,3,3,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,8,3,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,4,3,3,2,2,2,2,2,2,2,2,2,2,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,119,0,0,0,99,0,0,0,85,0,0,0,81,0,0,0,67,0,0,0,58,0,0,0,126,0,0,0,109,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,2,9,2,10,2,11,2,12,3,1,3,2,3,3,3,4,3,5,3,6,3,7,3,8,3,9,3,10,3,11,4,1,4,2,4,3,4,4,4,5,4,6,5,1,5,2,5,3,5,4,5,5,6,1,6,2,6,3,6,4,7,1,7,2,7,3,7,4,8,1,8,2,8,3,8,4,9,1,9,2,9,3,9,4,10,1,10,2,10,3,11,1,11,2,11,3,12,1,12,2,12,3,13,1,13,2,13,3,14,1,14,2,14,3,15,1,15,2,15,3,16,1,16,2,17,1,17,2,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,0,1,0,2,0,3,0,4,0,5,0,6,1,1,1,2,1,3,1,4,1,5,2,1,2,2,2,3,2,4,3,1,3,2,3,3,3,4,4,1,4,2,4,3,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,3,1,3,2,3,3,3,4,3,5,3,6,3,7,4,1,4,2,4,3,4,4,4,5,5,1,5,2,5,3,5,4,5,5,6,1,6,2,6,3,6,4,7,1,7,2,7,3,7,4,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,10,3,11,1,11,2,11,3,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,16,2,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,1,1,1,2,1,3,1,4,1,5,2,1,2,2,2,3,2,4,3,1,3,2,3,3,3,4,4,1,4,2,4,3,5,1,5,2,5,3,6,1,6,2,6,3,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,3,1,3,2,3,3,3,4,3,5,3,6,3,7,4,1,4,2,4,3,4,4,4,5,5,1,5,2,5,3,5,4,6,1,6,2,6,3,6,4,7,1,7,2,7,3,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,10,3,11,1,11,2,11,3,12,1,12,2,12,3,13,1,13,2,13,3,14,1,14,2,15,1,15,2,16,1,17,1,18,1,19,1,20,1,0,1,0,2,0,3,0,4,1,1,1,2,1,3,1,4,2,1,2,2,2,3,3,1,3,2,3,3,4,1,4,2,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,2,1,2,2,2,3,2,4,2,5,3,1,3,2,3,3,3,4,4,1,4,2,4,3,4,4,5,1,5,2,5,3,5,4,6,1,6,2,6,3,7,1,7,2,7,3,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,10,3,11,1,11,2,11,3,12,1,12,2,12,3,13,1,13,2,14,1,14,2,15,1,15,2,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,0,1,0,2,0,3,0,4,0,5,1,1,1,2,1,3,1,4,2,1,2,2,2,3,3,1,3,2,3,3,4,1,4,2,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,2,1,2,2,2,3,2,4,2,5,3,1,3,2,3,3,3,4,4,1,4,2,4,3,5,1,5,2,5,3,6,1,6,2,6,3,7,1,7,2,7,3,8,1,8,2,9,1,9,2,10,1,11,1,12,1,13,1,14,1,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,1,1,1,2,1,3,2,1,2,2,3,1,3,2,4,1,4,2,5,1,5,2,6,1,6,2,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,1,1,1,2,1,3,1,4,1,5,1,6,2,1,2,2,2,3,2,4,3,1,3,2,3,3,4,1,4,2,4,3,5,1,5,2,5,3,6,1,6,2,6,3,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,0,1,0,2,0,3,1,1,1,2,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,2,9,2,10,3,1,3,2,3,3,3,4,3,5,3,6,3,7,4,1,4,2,4,3,4,4,4,5,4,6,5,1,5,2,5,3,5,4,5,5,6,1,6,2,6,3,6,4,7,1,7,2,7,3,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,0,1,0,2,0,3,0,4,1,1,1,2,1,3,2,1,2,2,2,3,3,1,3,2,4,1,4,2,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,3,1,3,2,3,3,3,4,3,5,3,6,4,1,4,2,4,3,4,4,4,5,5,1,5,2,5,3,5,4,6,1,6,2,6,3,6,4,7,1,7,2,7,3,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,16,2,17,1,17,2,18,1,18,2,19,1,19,2,20,1,20,2,21,1,21,2,22,1,22,2,23,1,24,1,0,1,0,2,0,3,0,4,1,1,1,2,1,3,2,1,2,2,2,3,3,1,3,2,3,3,4,1,4,2,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,16,2,17,1,17,2,18,1,18,2,19,1,19,2,20,1,20,2,21,1,21,2,22,1,22,2,23,1,23,2,24,1,24,2,25,1,25,2,26,1,26,2,27,1,27,2,28,1,28,2,29,1,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,4,0,2,85,1,0,1,205,0,171,0,146,0,128,0,114,0,102,0,93,0,85,0,79,0,73,0,68,0,64,0,60,0,57,0,54,0,51,0,49,0,47,0,45,0,43,0,41,0,39,0,38,0,37,0,35,0,34,0,33,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,208,157,33,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,30,17,15,9,5,4,3,3,3,3,3,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,26,16,11,7,5,3,3,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,20,15,13,6,4,3,3,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,29,15,12,5,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,14,9,7,3,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,26,10,6,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,14,13,9,6,5,4,3,2,2,2,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,24,22,9,6,4,3,2,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,15,12,11,6,5,4,4,4,4,3,3,3,3,3,3,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,23,11,8,7,5,5,4,4,3,3,3,3,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,0,0,0,0,16,11,8,7,5,4,4,3,3,3,3,3,3,3,2,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,14,9,5,4,4,4,3,3,3,3,3,3,3,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,27,10,5,4,3,3,3,3,2,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,6,4,3,3,3,3,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,56,20,10,7,6,5,4,3,3,3,2,2,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,13,8,6,5,4,4,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,5,0,0,0,3,0,0,0,13,0,0,0,4,0,0,0,18,0,0,0,5,0,0,0,14,0,0,0,6,0,0,0,21,0,0,0,7,0,0,0,19,0,0,0,8,0,0,0,63,0,0,0,8,0,0,0,75,0,0,0,9,0,0,0,31,1,0,0,9,0,0,0,184,0,0,0,10,0,0,0,227,3,0,0,10,0,0,0,114,1,0,0,11,0,0,0,77,2,0,0,12,0,0,0,218,3,0,0,12,0,0,0,221,2,0,0,13,0,0,0,85,31,0,0,13,0,0,0,185,5,0,0,14,0,0,0,174,62,0,0,14,0,0,0,0,0,0,0,4,0,0,0,16,0,0,0,5,0,0,0,8,0,0,0,7,0,0,0,32,0,0,0,8,0,0,0,41,0,0,0,9,0,0,0,244,1,0,0,9,0,0,0,51,2,0,0,10,0,0,0,224,1,0,0,11,0,0,0,42,1,0,0,12,0,0,0,221,3,0,0,12,0,0,0,10,5,0,0,13,0,0,0,41,31,0,0,13,0,0,0,66,10,0,0,14,0,0,0,114,18,0,0,15,0,0,0,55,23,0,0,15,0,0,0,3,0,0,0,5,0,0,0,17,0,0,0,7,0,0,0,196,0,0,0,8,0,0,0,75,0,0,0,10,0,0,0,180,0,0,0,11,0,0,0,212,7,0,0,11,0,0,0,69,3,0,0,12,0,0,0,215,2,0,0,13,0,0,0,191,7,0,0,13,0,0,0,56,9,0,0,14,0,0,0,187,11,0,0,14,0,0,0,94,9,0,0,15,0,0,0,19,0,0,0,5,0,0,0,120,0,0,0,7,0,0,0,105,0,0,0,9,0,0,0,50,2,0,0,10,0,0,0,97,4,0,0,11,0,0,0,236,3,0,0,12,0,0,0,32,5,0,0,13,0,0,0,42,31,0,0,13,0,0,0,80,62,0,0,14,0,0,0,81,62,0,0,14,0,0,0,134,20,0,0,15,0,0,0,12,0,0,0,6,0,0,0,36,0,0,0,9,0,0,0,148,0,0,0,11,0,0,0,192,8,0,0,12,0,0,0,9,15,0,0,14,0,0,0,240,30,0,0,15,0,0,0,61,0,0,0,6,0,0,0,83,0,0,0,9,0,0,0,160,1,0,0,11,0,0,0,214,2,0,0,13,0,0,0,8,15,0,0,14,0,0,0,19,0,0,0,7,0,0,0,124,0,0,0,9,0,0,0,193,7,0,0,11,0,0,0,172,4,0,0,14,0,0,0,27,0,0,0,7,0,0,0,160,0,0,0,10,0,0,0,68,3,0,0,12,0,0,0,121,15,0,0,14,0,0,0,121,0,0,0,7,0,0,0,225,3,0,0,10,0,0,0,212,2,0,0,13,0,0,0,6,35,0,0,14,0,0,0,33,0,0,0,8,0,0,0,60,2,0,0,10,0,0,0,174,15,0,0,12,0,0,0,222,35,0,0,14,0,0,0,53,0,0,0,8,0,0,0,117,1,0,0,11,0,0,0,179,7,0,0,13,0,0,0,197,0,0,0,8,0,0,0,116,1,0,0,11,0,0,0,133,7,0,0,13,0,0,0,72,0,0,0,9,0,0,0,163,1,0,0,11,0,0,0,158,4,0,0,13,0,0,0,44,0,0,0,9,0,0,0,250,0,0,0,10,0,0,0,214,7,0,0,11,0,0,0,146,0,0,0,10,0,0,0,204,5,0,0,13,0,0,0,241,30,0,0,15,0,0,0,163,0,0,0,10,0,0,0,237,3,0,0,12,0,0,0,62,9,0,0,14,0,0,0,226,1,0,0,11,0,0,0,115,18,0,0,15,0,0,0,196,7,0,0,11,0,0,0,135,20,0,0,15,0,0,0,145,2,0,0,12,0,0,0,147,2,0,0,12,0,0,0,138,15,0,0,12,0,0,0,9,5,0,0,13,0,0,0,8,5,0,0,13,0,0,0,141,7,0,0,13,0,0,0,190,7,0,0,13,0,0,0,140,7,0,0,13,0,0,0,174,4,0,0,14,0,0,0,186,11,0,0,14,0,0,0,7,35,0,0,14,0,0,0,154,11,0,0,14,0,0,0,54,23,0,0,15,0,0,0,14,0,0,0,4,0,0,0,69,0,0,0,7,0,0,0,243,1,0,0,9,0,0,0,122,4,0,0,11,0,0,0,220,5,0,0,13,0,0,0,223,35,0,0,14,0,0,0,25,0,0,0,5,0,0,0,40,0,0,0,9,0,0,0,118,1,0,0,11,0,0,0,157,4,0,0,13,0,0,0,221,35,0,0,14,0,0,0,48,0,0,0,6,0,0,0,162,0,0,0,10,0,0,0,239,2,0,0,12,0,0,0,184,5,0,0,14,0,0,0,63,0,0,0,6,0,0,0,165,0,0,0,10,0,0,0,219,3,0,0,12,0,0,0,63,9,0,0,14,0,0,0,68,0,0,0,7,0,0,0,203,7,0,0,11,0,0,0,95,9,0,0,15,0,0,0,99,0,0,0,7,0,0,0,195,3,0,0,12,0,0,0,21,0,0,0,8,0,0,0,246,8,0,0,12,0,0,0,23,0,0,0,8,0,0,0,152,4,0,0,13,0,0,0,44,0,0,0,8,0,0,0,178,7,0,0,13,0,0,0,47,0,0,0,8,0,0,0,84,31,0,0,13,0,0,0,141,0,0,0,8,0,0,0,189,7,0,0,13,0,0,0,142,0,0,0,8,0,0,0,130,17,0,0,13,0,0,0,251,0,0,0,8,0,0,0,11,5,0,0,13,0,0,0,45,0,0,0,8,0,0,0,192,7,0,0,11,0,0,0,121,0,0,0,9,0,0,0,95,31,0,0,13,0,0,0,122,0,0,0,9,0,0,0,86,31,0,0,13,0,0,0,49,2,0,0,10,0,0,0,228,3,0,0,10,0,0,0,161,1,0,0,11,0,0,0,67,1,0,0,11,0,0,0,247,1,0,0,11,0,0,0,111,1,0,0,12,0,0,0,146,2,0,0,12,0,0,0,231,2,0,0,12,0,0,0,108,1,0,0,12,0,0,0,109,1,0,0,12,0,0,0,220,3,0,0,12,0,0,0,139,15,0,0,12,0,0,0,153,4,0,0,13,0,0,0,216,3,0,0,12,0,0,0,142,7,0,0,13,0,0,0,213,2,0,0,13,0,0,0,94,31,0,0,13,0,0,0,43,31,0,0,13,0,0,0,143,7,0,0,13,0,0,0,173,4,0,0,14,0,0,0,175,62,0,0,14,0,0,0,220,35,0,0,14,0,0,0,74,0,0,0,9,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,11,0,0,0,5,0,0,0,20,0,0,0,6,0,0,0,63,0,0,0,6,0,0,0,93,0,0,0,7,0,0,0,162,0,0,0,8,0,0,0,172,0,0,0,9,0,0,0,110,1,0,0,9,0,0,0,10,2,0,0,10,0,0,0,226,2,0,0,10,0,0,0,50,4,0,0,11,0,0,0,201,5,0,0,11,0,0,0,39,8,0,0,12,0,0,0,84,11,0,0,12,0,0,0,230,4,0,0,13,0,0,0,95,16,0,0,13,0,0,0,42,23,0,0,13,0,0,0,178,32,0,0,14,0,0,0,78,45,0,0,14,0,0,0,240,57,0,0,14,0,0,0,117,65,0,0,15,0,0,0,158,90,0,0,15,0,0,0,4,0,0,0,4,0,0,0,30,0,0,0,5,0,0,0,66,0,0,0,7,0,0,0,182,0,0,0,8,0,0,0,115,1,0,0,9,0,0,0,149,3,0,0,10,0,0,0,46,7,0,0,11,0,0,0,148,11,0,0,12,0,0,0,164,22,0,0,13,0,0,0,179,32,0,0,14,0,0,0,69,46,0,0,14,0,0,0,5,0,0,0,5,0,0,0,64,0,0,0,7,0,0,0,73,0,0,0,9,0,0,0,143,2,0,0,10,0,0,0,203,5,0,0,11,0,0,0,138,4,0,0,13,0,0,0,221,9,0,0,14,0,0,0,226,115,0,0,15,0,0,0,24,0,0,0,5,0,0,0,37,0,0,0,8,0,0,0,138,0,0,0,10,0,0,0,27,5,0,0,11,0,0,0,95,14,0,0,12,0,0,0,201,9,0,0,14,0,0,0,156,19,0,0,15,0,0,0,41,0,0,0,6,0,0,0,79,0,0,0,9,0,0,0,18,4,0,0,11,0,0,0,141,4,0,0,13,0,0,0,65,46,0,0,14,0,0,0,56,0,0,0,6,0,0,0,14,1,0,0,9,0,0,0,168,5,0,0,11,0,0,0,92,16,0,0,13,0,0,0,242,57,0,0,14,0,0,0,88,0,0,0,7,0,0,0,31,2,0,0,10,0,0,0,126,14,0,0,12,0,0,0,255,57,0,0,14,0,0,0,35,0,0,0,8,0,0,0,227,2,0,0,10,0,0,0,229,4,0,0,13,0,0,0,64,46,0,0,14,0,0,0,161,0,0,0,8,0,0,0,190,5,0,0,11,0,0,0,200,9,0,0,14,0,0,0,131,0,0,0,8,0,0,0,58,1,0,0,11,0,0,0,33,23,0,0,13,0,0,0,68,0,0,0,9,0,0,0,118,2,0,0,12,0,0,0,246,57,0,0,14,0,0,0,139,0,0,0,10,0,0,0,239,4,0,0,13,0,0,0,155,90,0,0,15,0,0,0,8,2,0,0,10,0,0,0,254,28,0,0,13,0,0,0,153,3,0,0,10,0,0,0,180,28,0,0,13,0,0,0,158,3,0,0,10,0,0,0,243,57,0,0,14,0,0,0,171,5,0,0,11,0,0,0,227,115,0,0,15,0,0,0,55,7,0,0,11,0,0,0,159,90,0,0,15,0,0,0,45,8,0,0,12,0,0,0,105,14,0,0,12,0,0,0,104,14,0,0,12,0,0,0,51,4,0,0,11,0,0,0,123,11,0,0,12,0,0,0,248,45,0,0,14,0,0,0,86,46,0,0,14,0,0,0,87,46,0,0,14,0,0,0,247,57,0,0,14,0,0,0,165,81,0,0,15,0,0,0,3,0,0,0,3,0,0,0,42,0,0,0,6,0,0,0,228,0,0,0,8,0,0,0,142,2,0,0,10,0,0,0,53,7,0,0,11,0,0,0,88,16,0,0,13,0,0,0,250,28,0,0,13,0,0,0,249,45,0,0,14,0,0,0,116,65,0,0,15,0,0,0,9,0,0,0,4,0,0,0,84,0,0,0,8,0,0,0,152,3,0,0,10,0,0,0,139,4,0,0,13,0,0,0,157,19,0,0,15,0,0,0,13,0,0,0,4,0,0,0,173,0,0,0,9,0,0,0,38,8,0,0,12,0,0,0,76,45,0,0,14,0,0,0,17,0,0,0,5,0,0,0,107,1,0,0,9,0,0,0,127,11,0,0,12,0,0,0,164,81,0,0,15,0,0,0,25,0,0,0,5,0,0,0,27,2,0,0,10,0,0,0,253,22,0,0,13,0,0,0,29,0,0,0,5,0,0,0,148,3,0,0,10,0,0,0,211,40,0,0,14,0,0,0,43,0,0,0,6,0,0,0,188,5,0,0,11,0,0,0,154,90,0,0,15,0,0,0,47,0,0,0,6,0,0,0,71,2,0,0,12,0,0,0,16,0,0,0,7,0,0,0,53,10,0,0,12,0,0,0,62,0,0,0,6,0,0,0,122,11,0,0,12,0,0,0,89,0,0,0,7,0,0,0,94,16,0,0,13,0,0,0,38,0,0,0,8,0,0,0,207,9,0,0,14,0,0,0,85,0,0,0,8,0,0,0,181,28,0,0,13,0,0,0,87,0,0,0,8,0,0,0,91,14,0,0,12,0,0,0,160,0,0,0,8,0,0,0,104,20,0,0,13,0,0,0,112,1,0,0,9,0,0,0,144,0,0,0,10,0,0,0,206,1,0,0,9,0,0,0,26,2,0,0,10,0,0,0,24,2,0,0,10,0,0,0,104,1,0,0,9,0,0,0,30,2,0,0,10,0,0,0,68,2,0,0,12,0,0,0,54,7,0,0,11,0,0,0,56,1,0,0,11,0,0,0,25,5,0,0,11,0,0,0,94,14,0,0,12,0,0,0,44,7,0,0,11,0,0,0,85,11,0,0,12,0,0,0,220,9,0,0,14,0,0,0,187,32,0,0,14,0,0,0,140,4,0,0,13,0,0,0,35,23,0,0,13,0,0,0,68,46,0,0,14,0,0,0,165,22,0,0,13,0,0,0,24,5,0,0,11,0,0,0,254,57,0,0,14,0,0,0,105,1,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,15,0,0,0,4,0,0,0,22,0,0,0,5,0,0,0,32,0,0,0,6,0,0,0,24,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,154,0,0,0,8,0,0,0,86,0,0,0,9,0,0,0,62,1,0,0,9,0,0,0,240,0,0,0,10,0,0,0,165,3,0,0,10,0,0,0,119,0,0,0,11,0,0,0,239,1,0,0,11,0,0,0,154,0,0,0,12,0,0,0,93,0,0,0,13,0,0,0,1,0,0,0,4,0,0,0,17,0,0,0,5,0,0,0,2,0,0,0,7,0,0,0,11,0,0,0,8,0,0,0,18,0,0,0,9,0,0,0,214,1,0,0,9,0,0,0,126,2,0,0,10,0,0,0,145,1,0,0,11,0,0,0,234,0,0,0,12,0,0,0,220,3,0,0,12,0,0,0,59,1,0,0,13,0,0,0,4,0,0,0,5,0,0,0,20,0,0,0,7,0,0,0,158,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,172,1,0,0,11,0,0,0,226,1,0,0,11,0,0,0,202,3,0,0,12,0,0,0,95,0,0,0,13,0,0,0,23,0,0,0,5,0,0,0,78,0,0,0,7,0,0,0,94,0,0,0,9,0,0,0,243,0,0,0,10,0,0,0,173,1,0,0,11,0,0,0,236,0,0,0,12,0,0,0,240,5,0,0,13,0,0,0,14,0,0,0,6,0,0,0,225,0,0,0,8,0,0,0,164,3,0,0,10,0,0,0,156,0,0,0,12,0,0,0,61,1,0,0,13,0,0,0,59,0,0,0,6,0,0,0,28,0,0,0,9,0,0,0,20,0,0,0,11,0,0,0,190,9,0,0,12,0,0,0,6,0,0,0,7,0,0,0,122,0,0,0,9,0,0,0,144,1,0,0,11,0,0,0,55,1,0,0,13,0,0,0,27,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,92,7,0,0,11,0,0,0,113,0,0,0,7,0,0,0,215,0,0,0,10,0,0,0,191,9,0,0,12,0,0,0,7,0,0,0,8,0,0,0,175,0,0,0,10,0,0,0,204,4,0,0,11,0,0,0,52,0,0,0,8,0,0,0,101,2,0,0,10,0,0,0,159,0,0,0,12,0,0,0,224,0,0,0,8,0,0,0,22,0,0,0,11,0,0,0,39,3,0,0,12,0,0,0,21,0,0,0,9,0,0,0,125,1,0,0,11,0,0,0,187,14,0,0,12,0,0,0,20,0,0,0,9,0,0,0,246,0,0,0,10,0,0,0,228,1,0,0,11,0,0,0,203,0,0,0,10,0,0,0,157,9,0,0,12,0,0,0,202,0,0,0,10,0,0,0,252,2,0,0,12,0,0,0,127,1,0,0,11,0,0,0,205,4,0,0,11,0,0,0,253,2,0,0,12,0,0,0,254,4,0,0,11,0,0,0,58,1,0,0,13,0,0,0,10,0,0,0,4,0,0,0,66,0,0,0,7,0,0,0,211,1,0,0,9,0,0,0,221,4,0,0,11,0,0,0,18,0,0,0,5,0,0,0,232,0,0,0,8,0,0,0,76,0,0,0,11,0,0,0,54,1,0,0,13,0,0,0,57,0,0,0,6,0,0,0,100,2,0,0,10,0,0,0,186,14,0,0,12,0,0,0,0,0,0,0,7,0,0,0,174,0,0,0,10,0,0,0,156,9,0,0,12,0,0,0,31,0,0,0,7,0,0,0,222,4,0,0,11,0,0,0,67,0,0,0,7,0,0,0,220,4,0,0,11,0,0,0,3,0,0,0,8,0,0,0,203,3,0,0,12,0,0,0,6,0,0,0,8,0,0,0,158,9,0,0,12,0,0,0,42,0,0,0,8,0,0,0,241,5,0,0,13,0,0,0,15,0,0,0,8,0,0,0,254,9,0,0,12,0,0,0,51,0,0,0,8,0,0,0,255,9,0,0,12,0,0,0,152,0,0,0,8,0,0,0,159,9,0,0,12,0,0,0,234,0,0,0,8,0,0,0,60,1,0,0,13,0,0,0,46,0,0,0,8,0,0,0,146,1,0,0,11,0,0,0,54,1,0,0,9,0,0,0,106,0,0,0,9,0,0,0,21,0,0,0,11,0,0,0,175,3,0,0,10,0,0,0,227,1,0,0,11,0,0,0,116,0,0,0,11,0,0,0,235,0,0,0,12,0,0,0,249,2,0,0,12,0,0,0,92,0,0,0,13,0,0,0,237,0,0,0,12,0,0,0,221,3,0,0,12,0,0,0,38,3,0,0,12,0,0,0,94,0,0,0,13,0,0,0,22,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,3,0,0,0,20,0,0,0,5,0,0,0,23,0,0,0,7,0,0,0,127,0,0,0,8,0,0,0,84,1,0,0,9,0,0,0,242,1,0,0,10,0,0,0,191,0,0,0,11,0,0,0,101,0,0,0,12,0,0,0,170,10,0,0,12,0,0,0,48,6,0,0,13,0,0,0,151,21,0,0,13,0,0,0,183,3,0,0,14,0,0,0,34,43,0,0,14,0,0,0,230,11,0,0,15,0,0,0,11,0,0,0,4,0,0,0,55,0,0,0,7,0,0,0,98,0,0,0,9,0,0,0,7,0,0,0,11,0,0,0,102,1,0,0,12,0,0,0,206,0,0,0,13,0,0,0,144,21,0,0,13,0,0,0,246,5,0,0,14,0,0,0,231,11,0,0,15,0,0,0,7,0,0,0,5,0,0,0,109,0,0,0,8,0,0,0,3,0,0,0,11,0,0,0,31,3,0,0,12,0,0,0,242,5,0,0,14,0,0,0,2,0,0,0,6,0,0,0,97,0,0,0,9,0,0,0,85,0,0,0,12,0,0,0,223,1,0,0,14,0,0,0,26,0,0,0,6,0,0,0,30,0,0,0,10,0,0,0,201,10,0,0,12,0,0,0,35,43,0,0,14,0,0,0,30,0,0,0,6,0,0,0,31,0,0,0,10,0,0,0,195,10,0,0,12,0,0,0,43,43,0,0,14,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,11,0,0,0,248,2,0,0,13,0,0,0,25,0,0,0,7,0,0,0,6,0,0,0,11,0,0,0,61,6,0,0,13,0,0,0,87,0,0,0,7,0,0,0,130,1,0,0,11,0,0,0,162,42,0,0,14,0,0,0,4,0,0,0,8,0,0,0,128,1,0,0,11,0,0,0,156,5,0,0,14,0,0,0,125,0,0,0,8,0,0,0,100,1,0,0,12,0,0,0,109,7,0,0,15,0,0,0,2,0,0,0,9,0,0,0,141,1,0,0,11,0,0,0,129,21,0,0,13,0,0,0,173,0,0,0,8,0,0,0,96,0,0,0,12,0,0,0,103,12,0,0,14,0,0,0,28,0,0,0,9,0,0,0,238,0,0,0,13,0,0,0,3,0,0,0,9,0,0,0,207,2,0,0,13,0,0,0,217,0,0,0,9,0,0,0,128,21,0,0,13,0,0,0,2,0,0,0,11,0,0,0,131,1,0,0,11,0,0,0,87,0,0,0,12,0,0,0,97,0,0,0,12,0,0,0,49,0,0,0,11,0,0,0,102,0,0,0,12,0,0,0,49,6,0,0,13,0,0,0,50,6,0,0,13,0,0,0,172,0,0,0,13,0,0,0,29,3,0,0,12,0,0,0,118,0,0,0,12,0,0,0,58,0,0,0,11,0,0,0,101,1,0,0,12,0,0,0,102,12,0,0,14,0,0,0,3,0,0,0,2,0,0,0,84,0,0,0,7,0,0,0,171,2,0,0,10,0,0,0,22,0,0,0,13,0,0,0,247,5,0,0,14,0,0,0,5,0,0,0,4,0,0,0,248,0,0,0,9,0,0,0,169,10,0,0,12,0,0,0,95,0,0,0,15,0,0,0,4,0,0,0,4,0,0,0,28,0,0,0,10,0,0,0,80,21,0,0,13,0,0,0,4,0,0,0,5,0,0,0,119,0,0,0,11,0,0,0,108,7,0,0,15,0,0,0,14,0,0,0,5,0,0,0,10,0,0,0,12,0,0,0,12,0,0,0,5,0,0,0,98,5,0,0,11,0,0,0,4,0,0,0,6,0,0,0,28,3,0,0,12,0,0,0,6,0,0,0,6,0,0,0,200,0,0,0,13,0,0,0,13,0,0,0,6,0,0,0,218,1,0,0,13,0,0,0,7,0,0,0,6,0,0,0,201,0,0,0,13,0,0,0,1,0,0,0,7,0,0,0,46,0,0,0,14,0,0,0,20,0,0,0,7,0,0,0,150,21,0,0,13,0,0,0,10,0,0,0,7,0,0,0,194,10,0,0,12,0,0,0,22,0,0,0,7,0,0,0,91,1,0,0,14,0,0,0,21,0,0,0,7,0,0,0,90,1,0,0,14,0,0,0,15,0,0,0,8,0,0,0,94,0,0,0,15,0,0,0,126,0,0,0,8,0,0,0,171,0,0,0,8,0,0,0,45,0,0,0,9,0,0,0,216,0,0,0,9,0,0,0,11,0,0,0,9,0,0,0,20,0,0,0,10,0,0,0,179,2,0,0,10,0,0,0,243,1,0,0,10,0,0,0,58,0,0,0,10,0,0,0,0,0,0,0,10,0,0,0,88,0,0,0,10,0,0,0,46,0,0,0,9,0,0,0,94,0,0,0,10,0,0,0,99,5,0,0,11,0,0,0,236,0,0,0,12,0,0,0,84,0,0,0,12,0,0,0,193,10,0,0,12,0,0,0,86,21,0,0,13,0,0,0,250,2,0,0,13,0,0,0,129,1,0,0,11,0,0,0,87,21,0,0,13,0,0,0,157,5,0,0,14,0,0,0,163,42,0,0,14,0,0,0,42,43,0,0,14,0,0,0,222,1,0,0,14,0,0,0,60,6,0,0,13,0,0,0,207,0,0,0,13,0,0,0,148,21,0,0,13,0,0,0,13,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,15,0,0,0,4,0,0,0,13,0,0,0,5,0,0,0,12,0,0,0,5,0,0,0,21,0,0,0,6,0,0,0,19,0,0,0,6,0,0,0,18,0,0,0,6,0,0,0,23,0,0,0,7,0,0,0,31,0,0,0,8,0,0,0,30,0,0,0,8,0,0,0,29,0,0,0,8,0,0,0,37,0,0,0,9,0,0,0,36,0,0,0,9,0,0,0,35,0,0,0,9], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+143360);
/* memory initializer */ allocate([33,0,0,0,9,0,0,0,33,0,0,0,10,0,0,0,32,0,0,0,10,0,0,0,15,0,0,0,10,0,0,0,14,0,0,0,10,0,0,0,7,0,0,0,11,0,0,0,6,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,33,0,0,0,11,0,0,0,80,0,0,0,12,0,0,0,81,0,0,0,12,0,0,0,82,0,0,0,12,0,0,0,14,0,0,0,4,0,0,0,20,0,0,0,6,0,0,0,22,0,0,0,7,0,0,0,28,0,0,0,8,0,0,0,32,0,0,0,9,0,0,0,31,0,0,0,9,0,0,0,13,0,0,0,10,0,0,0,34,0,0,0,11,0,0,0,83,0,0,0,12,0,0,0,85,0,0,0,12,0,0,0,11,0,0,0,5,0,0,0,21,0,0,0,7,0,0,0,30,0,0,0,9,0,0,0,12,0,0,0,10,0,0,0,86,0,0,0,12,0,0,0,17,0,0,0,6,0,0,0,27,0,0,0,8,0,0,0,29,0,0,0,9,0,0,0,11,0,0,0,10,0,0,0,16,0,0,0,6,0,0,0,34,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,13,0,0,0,6,0,0,0,28,0,0,0,9,0,0,0,8,0,0,0,10,0,0,0,18,0,0,0,7,0,0,0,27,0,0,0,9,0,0,0,84,0,0,0,12,0,0,0,20,0,0,0,7,0,0,0,26,0,0,0,9,0,0,0,87,0,0,0,12,0,0,0,25,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,24,0,0,0,8,0,0,0,35,0,0,0,11,0,0,0,23,0,0,0,8,0,0,0,25,0,0,0,9,0,0,0,24,0,0,0,9,0,0,0,7,0,0,0,10,0,0,0,88,0,0,0,12,0,0,0,7,0,0,0,4,0,0,0,12,0,0,0,6,0,0,0,22,0,0,0,8,0,0,0,23,0,0,0,9,0,0,0,6,0,0,0,10,0,0,0,5,0,0,0,11,0,0,0,4,0,0,0,11,0,0,0,89,0,0,0,12,0,0,0,15,0,0,0,6,0,0,0,22,0,0,0,9,0,0,0,5,0,0,0,10,0,0,0,14,0,0,0,6,0,0,0,4,0,0,0,10,0,0,0,17,0,0,0,7,0,0,0,36,0,0,0,11,0,0,0,16,0,0,0,7,0,0,0,37,0,0,0,11,0,0,0,19,0,0,0,7,0,0,0,90,0,0,0,12,0,0,0,21,0,0,0,8,0,0,0,91,0,0,0,12,0,0,0,20,0,0,0,8,0,0,0,19,0,0,0,8,0,0,0,26,0,0,0,8,0,0,0,21,0,0,0,9,0,0,0,20,0,0,0,9,0,0,0,19,0,0,0,9,0,0,0,18,0,0,0,9,0,0,0,17,0,0,0,9,0,0,0,38,0,0,0,11,0,0,0,39,0,0,0,11,0,0,0,92,0,0,0,12,0,0,0,93,0,0,0,12,0,0,0,94,0,0,0,12,0,0,0,95,0,0,0,12,0,0,0,3,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,15,0,0,0,4,0,0,0,21,0,0,0,6,0,0,0,23,0,0,0,7,0,0,0,31,0,0,0,8,0,0,0,37,0,0,0,9,0,0,0,36,0,0,0,9,0,0,0,33,0,0,0,10,0,0,0,32,0,0,0,10,0,0,0,7,0,0,0,11,0,0,0,6,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,6,0,0,0,3,0,0,0,20,0,0,0,6,0,0,0,30,0,0,0,8,0,0,0,15,0,0,0,10,0,0,0,33,0,0,0,11,0,0,0,80,0,0,0,12,0,0,0,14,0,0,0,4,0,0,0,29,0,0,0,8,0,0,0,14,0,0,0,10,0,0,0,81,0,0,0,12,0,0,0,13,0,0,0,5,0,0,0,35,0,0,0,9,0,0,0,13,0,0,0,10,0,0,0,12,0,0,0,5,0,0,0,34,0,0,0,9,0,0,0,82,0,0,0,12,0,0,0,11,0,0,0,5,0,0,0,12,0,0,0,10,0,0,0,83,0,0,0,12,0,0,0,19,0,0,0,6,0,0,0,11,0,0,0,10,0,0,0,84,0,0,0,12,0,0,0,18,0,0,0,6,0,0,0,10,0,0,0,10,0,0,0,17,0,0,0,6,0,0,0,9,0,0,0,10,0,0,0,16,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,22,0,0,0,7,0,0,0,85,0,0,0,12,0,0,0,21,0,0,0,7,0,0,0,20,0,0,0,7,0,0,0,28,0,0,0,8,0,0,0,27,0,0,0,8,0,0,0,33,0,0,0,9,0,0,0,32,0,0,0,9,0,0,0,31,0,0,0,9,0,0,0,30,0,0,0,9,0,0,0,29,0,0,0,9,0,0,0,28,0,0,0,9,0,0,0,27,0,0,0,9,0,0,0,26,0,0,0,9,0,0,0,34,0,0,0,11,0,0,0,35,0,0,0,11,0,0,0,86,0,0,0,12,0,0,0,87,0,0,0,12,0,0,0,7,0,0,0,4,0,0,0,25,0,0,0,9,0,0,0,5,0,0,0,11,0,0,0,15,0,0,0,6,0,0,0,4,0,0,0,11,0,0,0,14,0,0,0,6,0,0,0,13,0,0,0,6,0,0,0,12,0,0,0,6,0,0,0,19,0,0,0,7,0,0,0,18,0,0,0,7,0,0,0,17,0,0,0,7,0,0,0,16,0,0,0,7,0,0,0,26,0,0,0,8,0,0,0,25,0,0,0,8,0,0,0,24,0,0,0,8,0,0,0,23,0,0,0,8,0,0,0,22,0,0,0,8,0,0,0,21,0,0,0,8,0,0,0,20,0,0,0,8,0,0,0,19,0,0,0,8,0,0,0,24,0,0,0,9,0,0,0,23,0,0,0,9,0,0,0,22,0,0,0,9,0,0,0,21,0,0,0,9,0,0,0,20,0,0,0,9,0,0,0,19,0,0,0,9,0,0,0,18,0,0,0,9,0,0,0,17,0,0,0,9,0,0,0,7,0,0,0,10,0,0,0,6,0,0,0,10,0,0,0,5,0,0,0,10,0,0,0,4,0,0,0,10,0,0,0,36,0,0,0,11,0,0,0,37,0,0,0,11,0,0,0,38,0,0,0,11,0,0,0,39,0,0,0,11,0,0,0,88,0,0,0,12,0,0,0,89,0,0,0,12,0,0,0,90,0,0,0,12,0,0,0,91,0,0,0,12,0,0,0,92,0,0,0,12,0,0,0,93,0,0,0,12,0,0,0,94,0,0,0,12,0,0,0,95,0,0,0,12,0,0,0,3,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,13,0,0,0,4,0,0,0,5,0,0,0,4,0,0,0,28,0,0,0,5,0,0,0,22,0,0,0,5,0,0,0,63,0,0,0,6,0,0,0,58,0,0,0,6,0,0,0,46,0,0,0,6,0,0,0,34,0,0,0,6,0,0,0,123,0,0,0,7,0,0,0,103,0,0,0,7,0,0,0,95,0,0,0,7,0,0,0,71,0,0,0,7,0,0,0,38,0,0,0,7,0,0,0,239,0,0,0,8,0,0,0,205,0,0,0,8,0,0,0,193,0,0,0,8,0,0,0,169,0,0,0,8,0,0,0,79,0,0,0,8,0,0,0,242,1,0,0,9,0,0,0,221,1,0,0,9,0,0,0,153,1,0,0,9,0,0,0,133,1,0,0,9,0,0,0,93,1,0,0,9,0,0,0,27,1,0,0,9,0,0,0,239,3,0,0,10,0,0,0,225,3,0,0,10,0,0,0,200,3,0,0,10,0,0,0,49,3,0,0,10,0,0,0,3,3,0,0,10,0,0,0,241,2,0,0,10,0,0,0,160,2,0,0,10,0,0,0,51,2,0,0,10,0,0,0,38,1,0,0,10,0,0,0,192,7,0,0,11,0,0,0,111,7,0,0,11,0,0,0,108,7,0,0,11,0,0,0,97,6,0,0,11,0,0,0,4,6,0,0,11,0,0,0,114,5,0,0,11,0,0,0,81,5,0,0,11,0,0,0,106,4,0,0,11,0,0,0,116,2,0,0,11,0,0,0,39,15,0,0,12,0,0,0,36,15,0,0,12,0,0,0,219,14,0,0,12,0,0,0,142,12,0,0,12,0,0,0,11,12,0,0,12,0,0,0,10,12,0,0,12,0,0,0,227,10,0,0,12,0,0,0,214,8,0,0,12,0,0,0,144,4,0,0,12,0,0,0,149,4,0,0,12,0,0,0,25,31,0,0,13,0,0,0,181,29,0,0,13,0,0,0,9,0,0,0,4,0,0,0,16,0,0,0,5,0,0,0,41,0,0,0,6,0,0,0,98,0,0,0,7,0,0,0,243,0,0,0,8,0,0,0,173,0,0,0,8,0,0,0,229,1,0,0,9,0,0,0,121,1,0,0,9,0,0,0,156,0,0,0,9,0,0,0,177,3,0,0,10,0,0,0,174,2,0,0,10,0,0,0,39,1,0,0,10,0,0,0,110,7,0,0,11,0,0,0,112,5,0,0,11,0,0,0,117,2,0,0,11,0,0,0,37,15,0,0,12,0,0,0,192,14,0,0,12,0,0,0,160,10,0,0,12,0,0,0,215,8,0,0,12,0,0,0,76,30,0,0,13,0,0,0,8,0,0,0,5,0,0,0,99,0,0,0,7,0,0,0,175,0,0,0,8,0,0,0,123,1,0,0,9,0,0,0,179,3,0,0,10,0,0,0,221,7,0,0,11,0,0,0,64,6,0,0,11,0,0,0,141,15,0,0,12,0,0,0,193,11,0,0,12,0,0,0,145,4,0,0,12,0,0,0,40,0,0,0,6,0,0,0,195,0,0,0,8,0,0,0,81,1,0,0,9,0,0,0,161,2,0,0,10,0,0,0,115,5,0,0,11,0,0,0,195,14,0,0,12,0,0,0,53,31,0,0,13,0,0,0,101,0,0,0,7,0,0,0,218,1,0,0,9,0,0,0,175,2,0,0,10,0,0,0,119,2,0,0,11,0,0,0,201,8,0,0,12,0,0,0,129,23,0,0,13,0,0,0,37,0,0,0,7,0,0,0,24,1,0,0,9,0,0,0,70,6,0,0,11,0,0,0,166,10,0,0,12,0,0,0,128,23,0,0,13,0,0,0,201,0,0,0,8,0,0,0,33,3,0,0,10,0,0,0,155,15,0,0,12,0,0,0,30,25,0,0,13,0,0,0,72,0,0,0,8,0,0,0,204,7,0,0,11,0,0,0,161,10,0,0,12,0,0,0,128,1,0,0,9,0,0,0,101,4,0,0,11,0,0,0,5,25,0,0,13,0,0,0,226,3,0,0,10,0,0,0,193,14,0,0,12,0,0,0,155,60,0,0,14,0,0,0,244,2,0,0,10,0,0,0,200,8,0,0,12,0,0,0,193,7,0,0,11,0,0,0,40,9,0,0,13,0,0,0,225,5,0,0,11,0,0,0,13,50,0,0,14,0,0,0,194,14,0,0,12,0,0,0,24,100,0,0,15,0,0,0,52,31,0,0,13,0,0,0,120,0,0,0,7,0,0,0,85,1,0,0,9,0,0,0,82,5,0,0,11,0,0,0,31,25,0,0,13,0,0,0,250,0,0,0,8,0,0,0,220,7,0,0,11,0,0,0,7,25,0,0,13,0,0,0,172,0,0,0,8,0,0,0,73,2,0,0,11,0,0,0,177,19,0,0,14,0,0,0,246,1,0,0,9,0,0,0,226,10,0,0,12,0,0,0,220,1,0,0,9,0,0,0,237,4,0,0,12,0,0,0,132,1,0,0,9,0,0,0,4,25,0,0,13,0,0,0,86,1,0,0,9,0,0,0,217,9,0,0,13,0,0,0,231,3,0,0,10,0,0,0,41,9,0,0,13,0,0,0,178,3,0,0,10,0,0,0,104,59,0,0,14,0,0,0,245,2,0,0,10,0,0,0,176,19,0,0,14,0,0,0,34,3,0,0,10,0,0,0,105,59,0,0,14,0,0,0,52,2,0,0,10,0,0,0,53,121,0,0,15,0,0,0,199,7,0,0,11,0,0,0,51,200,0,0,16,0,0,0,96,6,0,0,11,0,0,0,52,121,0,0,15,0,0,0,75,2,0,0,11,0,0,0,50,200,0,0,16,0,0,0,167,10,0,0,12,0,0,0,24,31,0,0,13,0,0,0,122,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,3,0,0,0,30,0,0,0,5,0,0,0,4,0,0,0,5,0,0,0,18,0,0,0,6,0,0,0,112,0,0,0,7,0,0,0,26,0,0,0,7,0,0,0,95,0,0,0,8,0,0,0,71,0,0,0,8,0,0,0,211,1,0,0,9,0,0,0,181,0,0,0,9,0,0,0,87,0,0,0,9,0,0,0,181,3,0,0,10,0,0,0,109,1,0,0,10,0,0,0,98,1,0,0,10,0,0,0,206,7,0,0,11,0,0,0,25,7,0,0,11,0,0,0,145,6,0,0,11,0,0,0,198,2,0,0,11,0,0,0,86,1,0,0,11,0,0,0,146,15,0,0,12,0,0,0,46,13,0,0,12,0,0,0,32,13,0,0,12,0,0,0,158,5,0,0,12,0,0,0,104,4,0,0,12,0,0,0,166,2,0,0,12,0,0,0,162,29,0,0,13,0,0,0,96,28,0,0,13,0,0,0,67,26,0,0,13,0,0,0,29,11,0,0,13,0,0,0,192,8,0,0,13,0,0,0,93,5,0,0,13,0,0,0,3,0,0,0,3,0,0,0,10,0,0,0,5,0,0,0,119,0,0,0,7,0,0,0,229,0,0,0,8,0,0,0,217,1,0,0,9,0,0,0,229,3,0,0,10,0,0,0,102,1,0,0,10,0,0,0,148,6,0,0,11,0,0,0,82,1,0,0,11,0,0,0,159,5,0,0,12,0,0,0,60,31,0,0,13,0,0,0,75,26,0,0,13,0,0,0,94,5,0,0,13,0,0,0,12,0,0,0,4,0,0,0,125,0,0,0,7,0,0,0,68,0,0,0,8,0,0,0,224,3,0,0,10,0,0,0,105,7,0,0,11,0,0,0,49,14,0,0,12,0,0,0,38,31,0,0,13,0,0,0,92,5,0,0,13,0,0,0,27,0,0,0,5,0,0,0,226,0,0,0,8,0,0,0,165,3,0,0,10,0,0,0,201,2,0,0,11,0,0,0,35,31,0,0,13,0,0,0,71,59,0,0,14,0,0,0,7,0,0,0,5,0,0,0,216,1,0,0,9,0,0,0,216,2,0,0,11,0,0,0,39,31,0,0,13,0,0,0,148,52,0,0,14,0,0,0,53,0,0,0,6,0,0,0,225,3,0,0,10,0,0,0,156,5,0,0,12,0,0,0,195,56,0,0,14,0,0,0,12,0,0,0,6,0,0,0,101,1,0,0,10,0,0,0,35,29,0,0,13,0,0,0,56,22,0,0,14,0,0,0,104,0,0,0,7,0,0,0,147,6,0,0,11,0,0,0,69,58,0,0,14,0,0,0,32,0,0,0,7,0,0,0,144,15,0,0,12,0,0,0,246,124,0,0,15,0,0,0,232,0,0,0,8,0,0,0,143,5,0,0,12,0,0,0,239,44,0,0,15,0,0,0,69,0,0,0,8,0,0,0,58,11,0,0,13,0,0,0,241,1,0,0,9,0,0,0,70,59,0,0,14,0,0,0,167,1,0,0,9,0,0,0,118,22,0,0,14,0,0,0,86,0,0,0,9,0,0,0,42,105,0,0,15,0,0,0,141,3,0,0,10,0,0,0,9,227,0,0,16,0,0,0,170,0,0,0,10,0,0,0,17,198,1,0,17,0,0,0,223,2,0,0,11,0,0,0,185,179,0,0,17,0,0,0,200,2,0,0,11,0,0,0,32,140,3,0,18,0,0,0,176,1,0,0,11,0,0,0,144,99,1,0,18,0,0,0,159,15,0,0,12,0,0,0,113,103,1,0,18,0,0,0,208,14,0,0,12,0,0,0,67,24,7,0,19,0,0,0,42,13,0,0,12,0,0,0,140,158,15,0,20,0,0,0,97,4,0,0,12,0,0,0,142,158,15,0,20,0,0,0,103,11,0,0,13,0,0,0,95,5,0,0,13,0,0,0,63,0,0,0,6,0,0,0,109,0,0,0,9,0,0,0,144,14,0,0,12,0,0,0,78,5,0,0,13,0,0,0,19,0,0,0,6,0,0,0,25,1,0,0,10,0,0,0,102,11,0,0,13,0,0,0,11,0,0,0,6,0,0,0,53,2,0,0,11,0,0,0,245,124,0,0,15,0,0,0,117,0,0,0,7,0,0,0,36,13,0,0,12,0,0,0,233,249,0,0,16,0,0,0,46,0,0,0,7,0,0,0,34,31,0,0,13,0,0,0,33,0,0,0,7,0,0,0,79,5,0,0,13,0,0,0,20,0,0,0,7,0,0,0,68,58,0,0,14,0,0,0,228,0,0,0,8,0,0,0,247,124,0,0,15,0,0,0,94,0,0,0,8,0,0,0,133,113,0,0,15,0,0,0,55,0,0,0,8,0,0,0,115,44,0,0,15,0,0,0,219,1,0,0,9,0,0,0,221,89,0,0,16,0,0,0,199,1,0,0,9,0,0,0,43,105,0,0,15,0,0,0,166,1,0,0,9,0,0,0,229,88,0,0,16,0,0,0,180,0,0,0,9,0,0,0,208,243,1,0,17,0,0,0,176,0,0,0,9,0,0,0,201,177,0,0,17,0,0,0,230,3,0,0,10,0,0,0,112,103,1,0,18,0,0,0,110,1,0,0,10,0,0,0,162,231,3,0,18,0,0,0,27,1,0,0,10,0,0,0,141,158,15,0,20,0,0,0,217,0,0,0,10,0,0,0,143,158,15,0,20,0,0,0,168,0,0,0,10,0,0,0,35,199,2,0,19,0,0,0,73,7,0,0,11,0,0,0,132,48,14,0,20,0,0,0,150,6,0,0,11,0,0,0,69,142,5,0,20,0,0,0,222,2,0,0,11,0,0,0,136,28,11,0,21,0,0,0,49,2,0,0,11,0,0,0,10,97,28,0,21,0,0,0,177,1,0,0,11,0,0,0,45,132,113,0,23,0,0,0,43,13,0,0,12,0,0,0,23,194,56,0,22,0,0,0,47,13,0,0,12,0,0,0,19,57,22,0,22,0,0,0,178,5,0,0,12,0,0,0,18,57,22,0,22,0,0,0,105,4,0,0,12,0,0,0,44,132,113,0,23,0,0,0,66,26,0,0,13,0,0,0,193,8,0,0,13,0,0,0,115,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,96,6,0,255,204,204,0,240,136,136,15,0,17,17,200,254,239,140,127,19,49,247,0,200,140,0,19,0,0,49,0,204,204,0,51,0,0,51,240,15,102,102,240,0,0,15,34,34,68,68,0,246,200,140,111,0,49,19,140,49,19,200,204,51,0,102,192,12,102,0,48,3,0,249,140,200,159,0,19,49,0,96,128,8,6,0,16,1,136,204,0,252,207,0,204,136,63,0,51,17,17,51,0,243,246,111,3,6,198,8,99,140,49,198,16,99,96,192,54,1,108,19,200,54,128,108,76,50,24,111,35,0,112,22,35,0,168,209,34,0,184,150,34,0,176,90,34,0,24,37,34,0,104,244,33,0,56,204,33,0,24,166,33,0,112,136,33,0,176,91,33,0,240,6,31,0,0,0,0,0,0,0,0,0,24,219,31,0,88,17,31,0,224,98,30,0,128,221,29,0,184,113,29,0,80,27,29,0,0,0,0,0,0,0,0,0,192,214,34,0,8,155,34,0,64,94,34,0,72,39,34,0,72,247,33,0,96,206,33,0,0,0,0,0,0,0,0,0,48,108,30,0,104,227,29,0,40,119,29,0,200,31,29,0,136,206,28,0,40,203,35,0,40,119,35,0,0,0,0,0,112,193,29,0,72,121,29,0,216,185,29,0,8,33,29,0,72,178,29,0,224,170,29,0,128,155,29,0,128,127,29,0,224,119,29,0,144,112,29,0,208,105,29,0,176,98,29,0,40,93,29,0,232,86,29,0,160,80,29,0,0,0,0,0,152,113,30,0,88,231,29,0,8,122,29,0,240,33,29,0,32,210,28,0,104,205,35,0,152,121,35,0,176,30,35,0,240,217,34,0,176,157,34,0,104,97,34,0,120,41,34,0,0,0,0,0,0,0,0,0,112,1,33,0,144,34,31,0,8,231,32,0,176,34,29,0,24,204,32,0,56,177,32,0,184,155,32,0,208,130,32,0,232,205,35,0,80,218,34,0,104,105,32,0,64,84,32,0,248,53,32,0,48,2,32,0,40,235,31,0,0,0,0,0,0,232,29,0,208,122,29,0,216,34,29,0,32,211,28,0,48,206,35,0,32,123,35,0,216,31,35,0,120,218,34,0,104,158,34,0,0,98,34,0,96,16,33,0,136,246,31,0,104,42,34,0,192,251,33,0,80,208,33,0,0,0,0,0,160,107,31,0,136,84,31,0,112,212,28,0,8,44,31,0,168,27,31,0,240,206,35,0,32,15,31,0,0,0,0,0,16,125,29,0,88,36,29,0,16,213,28,0,112,207,35,0,72,126,35,0,0,0,0,0,24,158,32,0,8,132,32,0,232,106,32,0,160,85,32,0,248,60,32,0,144,5,32,0,128,237,31,0,216,216,31,0,144,46,31,0,64,129,29,0,80,162,34,0,88,131,35,0,192,40,33,0,0,0,0,0,24,58,33,0,0,0,0,0,40,6,33,0,16,59,31,0,160,235,32,0,248,46,29,0,176,64,33,0,248,208,32,0,56,248,29,0,160,181,32,0,120,160,32,0,88,134,32,0,40,109,32,0,144,87,32,0,152,63,32,0,232,217,35,0,48,230,34,0,248,7,32,0,72,239,31,0,160,218,31,0,0,0,0,0,0,0,0,0,72,73,33,0,0,28,32,0,80,63,31,0,0,141,30,0,80,251,29,0,136,141,29,0,24,49,29,0,72,225,28,0,48,221,35,0,224,141,35,0,24,46,35,0,56,232,34,0,0,0,0,0,0,0,0,0,232,54,34,0,80,6,34,0,24,216,33,0,136,179,33,0,208,67,31,0,136,146,33,0,240,112,33,0,0,0,0,0,120,56,34,0,240,7,34,0,32,217,33,0,168,180,33,0,24,147,33,0,208,113,33,0,80,49,33,0,216,8,33,0,224,238,32,0,112,211,32,0,168,4,30,0,56,184,32,0,72,162,32,0,192,137,32,0,200,112,32,0,8,90,32,0,0,66,32,0,8,10,32,0,160,240,31,0,8,220,31,0,0,0,0,0,0,0,0,0,104,53,35,0,184,7,30,0,208,237,34,0,0,0,0,0,168,60,29,0,64,236,28,0,88,230,35,0,88,151,35,0,112,56,35,0,200,239,34,0,88,177,34,0,96,116,34,0,184,60,34,0,216,11,34,0,112,220,33,0,224,183,33,0,0,150,33,0,168,116,33,0,8,53,33,0,152,11,33,0,224,241,32,0,40,214,32,0,56,187,32,0,192,164,32,0,48,140,32,0,24,115,32,0,96,92,32,0,88,68,32,0,240,12,32,0,232,242,31,0,144,222,31,0,16,204,31,0,176,182,31,0,56,163,31,0,136,145,31,0,184,127,31,0,104,112,31,0,224,93,31,0,224,51,31,0,104,32,31,0,192,10,30,0,0,0,0,0,232,130,30,0,216,113,30,0,24,101,30,0,0,0,0,0,104,248,29,0,88,138,29,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,137,30,0,108,0,0,0,16,116,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,9,0,0,40,9,0,0,68,9,0,0,66,9,0,0,72,9,0,0,148,0,0,0,152,0,0,0,40,9,0,0,76,9,0,0,0,0,0,0,173,171,68,36,47,37,77,199,146,255,41,189,0,0,0,0,255,255,255,255,0,0,0,0,1,0,128,184,0,0,64,58,255,255,3,187,1,0,136,59,1,0,238,187,251,255,62,60,0,128,145,188,2,0,215,60,0,128,30,189,1,192,112,61,0,0,202,189,255,255,108,62,0,84,111,63,3,0,28,190,0,0,161,61,0,64,74,189,255,127,7,61,255,127,184,188,252,255,118,60,0,0,32,188,0,0,192,59,255,255,79,187,3,0,184,58,255,255,191,185,254,255,127,185,2,0,192,58,1,0,120,187,255,255,247,59,2,0,85,188,254,255,168,60,0,0,255,188,1,0,60,61,0,224,138,189,250,127,213,61,3,224,57,190,255,107,0,63,0,64,65,63,3,128,86,190,252,31,235,61,0,128,150,189,1,0,75,61,1,0,10,189,1,0,184,60,254,255,106,188,0,0,11,60,255,255,145,187,3,0,240,58,0,0,224,185,0,0,224,185,3,0,240,58,255,255,145,187,0,0,11,60,254,255,106,188,1,0,184,60,1,0,10,189,1,0,75,61,0,128,150,189,252,31,235,61,3,128,86,190,0,64,65,63,255,107,0,63,3,224,57,190,250,127,213,61,0,224,138,189,1,0,60,61,0,0,255,188,254,255,168,60,2,0,85,188,255,255,247,59,1,0,120,187,2,0,192,58,254,255,127,185,255,255,191,185,3,0,184,58,255,255,79,187,0,0,192,59,0,0,32,188,252,255,118,60,255,127,184,188,255,127,7,61,0,64,74,189,0,0,161,61,3,0,28,190,0,84,111,63,255,255,108,62,0,0,202,189,1,192,112,61,0,128,30,189,2,0,215,60,0,128,145,188,251,255,62,60,1,0,238,187,1,0,136,59,255,255,3,187,0,0,64,58,1,0,128,184,7,0,0,0,20,0,0,0,33,0,0,0,46,0,0,0,59,0,0,0,72,0,0,0,85,0,0,0,98,0,0,0,111,0,0,0,124,0,0,0,137,0,0,0,150,0,0,0,163,0,0,0,176,0,0,0,189,0,0,0,202,0,0,0,215,0,0,0,228,0,0,0,241,0,0,0,254,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,123,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,164,0,0,0,165,0,0,0,166,0,0,0,167,0,0,0,168,0,0,0,169,0,0,0,170,0,0,0,171,0,0,0,172,0,0,0,173,0,0,0,174,0,0,0,175,0,0,0,177,0,0,0,178,0,0,0,179,0,0,0,180,0,0,0,181,0,0,0,182,0,0,0,183,0,0,0,184,0,0,0,185,0,0,0,186,0,0,0,187,0,0,0,188,0,0,0,190,0,0,0,191,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,196,0,0,0,197,0,0,0,198,0,0,0,199,0,0,0,200,0,0,0,201,0,0,0,203,0,0,0,204,0,0,0,205,0,0,0,206,0,0,0,207,0,0,0,208,0,0,0,209,0,0,0,210,0,0,0,211,0,0,0,212,0,0,0,213,0,0,0,214,0,0,0,216,0,0,0,217,0,0,0,218,0,0,0,219,0,0,0,220,0,0,0,221,0,0,0,222,0,0,0,223,0,0,0,224,0,0,0,225,0,0,0,226,0,0,0,227,0,0,0,229,0,0,0,230,0,0,0,231,0,0,0,232,0,0,0,233,0,0,0,234,0,0,0,235,0,0,0,236,0,0,0,237,0,0,0,238,0,0,0,239,0,0,0,240,0,0,0,242,0,0,0,243,0,0,0,244,0,0,0,245,0,0,0,246,0,0,0,247,0,0,0,248,0,0,0,249,0,0,0,250,0,0,0,251,0,0,0,252,0,0,0,253,0,0,0,152,233,31,0,32,26,31,0,4,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,128,108,30,0,32,26,31,0,4,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,136,227,29,0,72,119,29,0,8,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,208,31,29,0,72,119,29,0,8,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,144,206,28,0,80,203,35,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,80,119,35,0,80,203,35,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,216,28,35,0,16,216,34,0,12,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,80,156,34,0,16,216,34,0,12,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,224,95,34,0,56,40,34,0,16,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,104,248,33,0,56,40,34,0,16,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,32,207,33,0,248,167,33,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,88,138,33,0,248,167,33,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,120,97,33,0,80,35,33,0,76,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,225,31,0,108,0,0,0,88,122,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,8,0,0,0,10,0,0,0,0,0,0,0,1,0,255,255,6,10,43,52,1,1,1,5,1,1,13,0,19,0,0,0,252,255,255,255,254,255,255,255,252,255,255,255,255,255,255,255,252,255,255,255,0,0,0,0,252,255,255,255,1,0,0,0,252,255,255,255,2,0,0,0,4,0,0,0,254,255,255,255,4,0,0,0,255,255,255,255,4,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,254,255,255,255,3,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,3,0,0,0,254,255,255,255,253,255,255,255,0,0,0,0,252,255,255,255,2,0,0,0,253,255,255,255,16,19,23,26,30,33,37,40,44,47,51,54,58,61,65,68,72,75,79,82,86,89,92,96,99,103,106,110,113,117,120,124,127,131,134,138,141,145,148,152,155,159,162,165,169,172,176,179,183,186,190,193,197,200,204,207,211,214,218,221,225,228,232,235,0,1,1,2,0,1,2,3,0,2,3,4,0,1,3,4,0,1,2,4,0,2,3,5,0,2,4,5,0,1,4,5,0,1,3,5,0,2,4,6,0,3,5,6,0,1,5,6,0,1,3,6,0,6,6,6,0,0,6,6,0,0,0,6,0,3,4,7,0,3,6,7,0,1,6,7,0,1,4,7,0,3,5,8,0,4,6,8,0,2,6,8,0,2,4,8,0,8,8,8,0,0,8,8,0,0,0,8,0,4,7,11,0,5,9,11,0,2,9,11,0,2,6,11,0,11,11,11,0,0,11,11,0,0,0,11,0,5,9,14,0,7,11,14,0,3,11,14,0,3,7,14,0,14,14,14,0,0,14,14,0,0,0,14,0,6,11,17,0,8,13,17,0,4,13,17,0,4,9,17,0,17,17,17,0,0,17,17,0,0,0,17,0,7,13,20,0,10,15,20,0,5,15,20,0,5,10,20,0,20,20,20,0,0,20,20,0,0,0,20,0,11,18,23,0,5,18,23,0,5,12,23,0,23,23,23,0,0,23,23,0,0,0,23,0,13,20,26,0,6,20,26,0,6,13,26,0,26,26,26,0,0,26,26,0,0,0,26,0,14,22,29,0,7,22,29,0,7,15,29,0,29,29,29,0,0,29,29,0,0,0,29,0,16,24,32,0,8,24,32,0,8,16,32,0,32,32,32,0,0,32,32,0,0,0,32,0,35,35,35,0,0,35,35,0,0,0,35,0,18,27,36,0,9,27,36,0,9,18,36,0,40,40,40,0,0,40,40,0,0,0,40,0,46,46,46,0,0,46,46,0,0,0,46,1,2,2,3,1,2,3,4,1,3,4,5,1,2,4,5,1,2,3,5,1,3,4,6,1,3,5,6,1,2,5,6,1,2,4,6,1,3,5,7,1,4,6,7,1,2,6,7,1,2,4,7,1,7,7,7,1,1,7,7,1,1,1,7,1,4,5,8,1,4,7,8,1,2,7,8,1,2,5,8,1,4,6,9,1,5,7,9,1,3,7,9,1,3,5,9,1,9,9,9,1,1,9,9,1,1,1,9,1,5,8,12,1,6,10,12,1,3,10,12,1,3,7,12,1,12,12,12,1,1,12,12,1,1,1,12,1,6,10,15], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+153600);
/* memory initializer */ allocate([1,8,12,15,1,4,12,15,1,4,8,15,1,15,15,15,1,1,15,15,1,1,1,15,1,7,12,18,1,9,14,18,1,5,14,18,1,5,10,18,1,18,18,18,1,1,18,18,1,1,1,18,1,8,14,21,1,11,16,21,1,6,16,21,1,6,11,21,1,21,21,21,1,1,21,21,1,1,1,21,1,12,19,24,1,6,19,24,1,6,13,24,1,24,24,24,1,1,24,24,1,1,1,24,1,14,21,27,1,7,21,27,1,7,14,27,1,27,27,27,1,1,27,27,1,1,1,27,1,15,23,30,1,8,23,30,1,8,16,30,1,30,30,30,1,1,30,30,1,1,1,30,1,17,25,33,1,9,25,33,1,9,17,33,1,33,33,33,1,1,33,33,1,1,1,33,1,36,36,36,1,1,36,36,1,1,1,36,1,19,28,37,1,10,28,37,1,10,19,37,1,41,41,41,1,1,41,41,1,1,1,41,1,47,47,47,1,1,47,47,1,1,1,47,2,3,3,4,2,3,4,5,2,4,5,6,2,3,5,6,2,3,4,6,2,4,5,7,2,4,6,7,2,3,6,7,2,3,5,7,2,4,6,8,2,5,7,8,2,3,7,8,2,3,5,8,2,8,8,8,2,2,8,8,2,2,2,8,2,5,6,9,2,5,8,9,2,3,8,9,2,3,6,9,2,5,7,10,2,6,8,10,2,4,8,10,2,4,6,10,2,10,10,10,2,2,10,10,2,2,2,10,2,6,9,13,2,7,11,13,2,4,11,13,2,4,8,13,2,13,13,13,2,2,13,13,2,2,2,13,2,7,11,16,2,9,13,16,2,5,13,16,2,5,9,16,2,16,16,16,2,2,16,16,2,2,2,16,2,8,13,19,2,10,15,19,2,6,15,19,2,6,11,19,2,19,19,19,2,2,19,19,2,2,2,19,2,9,15,22,2,12,17,22,2,7,17,22,2,7,12,22,2,22,22,22,2,2,22,22,2,2,2,22,2,13,20,25,2,7,20,25,2,7,14,25,2,25,25,25,2,2,25,25,2,2,2,25,2,15,22,28,2,8,22,28,2,8,15,28,2,28,28,28,2,2,28,28,2,2,2,28,2,16,24,31,2,9,24,31,2,9,17,31,2,31,31,31,2,2,31,31,2,2,2,31,2,18,26,34,2,10,26,34,2,10,18,34,2,34,34,34,2,2,34,34,2,2,2,34,2,37,37,37,2,2,37,37,2,2,2,37,2,20,29,38,2,11,29,38,2,11,20,38,2,42,42,42,2,2,42,42,2,2,2,42,2,48,48,48,2,2,48,48,2,2,2,48,3,4,4,5,3,4,5,6,3,5,6,7,3,4,6,7,3,4,5,7,3,5,6,8,3,5,7,8,3,4,7,8,3,4,6,8,3,5,7,9,3,6,8,9,3,4,8,9,3,4,6,9,3,9,9,9,3,3,9,9,3,3,3,9,3,6,7,10,3,6,9,10,3,4,9,10,3,4,7,10,3,6,8,11,3,7,9,11,3,5,9,11,3,5,7,11,3,11,11,11,3,3,11,11,3,3,3,11,3,7,10,14,3,8,12,14,3,5,12,14,3,5,9,14,3,14,14,14,3,3,14,14,3,3,3,14,3,8,12,17,3,10,14,17,3,6,14,17,3,6,10,17,3,17,17,17,3,3,17,17,3,3,3,17,3,9,14,20,3,11,16,20,3,7,16,20,3,7,12,20,3,20,20,20,3,3,20,20,3,3,3,20,3,10,16,23,3,13,18,23,3,8,18,23,3,8,13,23,3,23,23,23,3,3,23,23,3,3,3,23,3,14,21,26,3,8,21,26,3,8,15,26,3,26,26,26,3,3,26,26,3,3,3,26,3,16,23,29,3,9,23,29,3,9,16,29,3,29,29,29,3,3,29,29,3,3,3,29,3,17,25,32,3,10,25,32,3,10,18,32,3,32,32,32,3,3,32,32,3,3,3,32,3,19,27,35,3,11,27,35,3,11,19,35,3,35,35,35,3,3,35,35,3,3,3,35,3,38,38,38,3,3,38,38,3,3,3,38,3,21,30,39,3,12,30,39,3,12,21,39,3,43,43,43,3,3,43,43,3,3,3,43,3,49,49,49,3,3,49,49,3,3,3,49,4,5,5,6,4,5,6,7,4,6,7,8,4,5,7,8,4,5,6,8,4,6,7,9,4,6,8,9,4,5,8,9,4,5,7,9,4,6,8,10,4,7,9,10,4,5,9,10,4,5,7,10,4,10,10,10,4,4,10,10,4,4,4,10,4,7,8,11,4,7,10,11,4,5,10,11,4,5,8,11,4,7,9,12,4,8,10,12,4,6,10,12,4,6,8,12,4,12,12,12,4,4,12,12,4,4,4,12,4,8,11,15,4,9,13,15,4,6,13,15,4,6,10,15,4,15,15,15,4,4,15,15,4,4,4,15,4,9,13,18,4,11,15,18,4,7,15,18,4,7,11,18,4,18,18,18,4,4,18,18,4,4,4,18,4,10,15,21,4,12,17,21,4,8,17,21,4,8,13,21,4,21,21,21,4,4,21,21,4,4,4,21,4,11,17,24,4,14,19,24,4,9,19,24,4,9,14,24,4,24,24,24,4,4,24,24,4,4,4,24,4,15,22,27,4,9,22,27,4,9,16,27,4,27,27,27,4,4,27,27,4,4,4,27,4,17,24,30,4,10,24,30,4,10,17,30,4,30,30,30,4,4,30,30,4,4,4,30,4,18,26,33,4,11,26,33,4,11,19,33,4,33,33,33,4,4,33,33,4,4,4,33,4,20,28,36,4,12,28,36,4,12,20,36,4,36,36,36,4,4,36,36,4,4,4,36,4,39,39,39,4,4,39,39,4,4,4,39,4,22,31,40,4,13,31,40,4,13,22,40,4,44,44,44,4,4,44,44,4,4,4,44,4,50,50,50,4,4,50,50,4,4,4,50,5,6,6,7,5,6,7,8,5,7,8,9,5,6,8,9,5,6,7,9,5,7,8,10,5,7,9,10,5,6,9,10,5,6,8,10,5,7,9,11,5,8,10,11,5,6,10,11,5,6,8,11,5,11,11,11,5,5,11,11,5,5,5,11,5,8,9,12,5,8,11,12,5,6,11,12,5,6,9,12,5,8,10,13,5,9,11,13,5,7,11,13,5,7,9,13,5,13,13,13,5,5,13,13,5,5,5,13,5,9,12,16,5,10,14,16,5,7,14,16,5,7,11,16,5,16,16,16,5,5,16,16,5,5,5,16,5,10,14,19,5,12,16,19,5,8,16,19,5,8,12,19,5,19,19,19,5,5,19,19,5,5,5,19,5,11,16,22,5,13,18,22,5,9,18,22,5,9,14,22,5,22,22,22,5,5,22,22,5,5,5,22,5,12,18,25,5,15,20,25,5,10,20,25,5,10,15,25,5,25,25,25,5,5,25,25,5,5,5,25,5,16,23,28,5,10,23,28,5,10,17,28,5,28,28,28,5,5,28,28,5,5,5,28,5,18,25,31,5,11,25,31,5,11,18,31,5,31,31,31,5,5,31,31,5,5,5,31,5,19,27,34,5,12,27,34,5,12,20,34,5,34,34,34,5,5,34,34,5,5,5,34,5,21,29,37,5,13,29,37,5,13,21,37,5,37,37,37,5,5,37,37,5,5,5,37,5,40,40,40,5,5,40,40,5,5,5,40,5,23,32,41,5,14,32,41,5,14,23,41,5,45,45,45,5,5,45,45,5,5,5,45,5,51,51,51,5,5,51,51,5,5,5,51,6,7,7,8,6,7,8,9,6,8,9,10,6,7,9,10,6,7,8,10,6,8,9,11,6,8,10,11,6,7,10,11,6,7,9,11,6,8,10,12,6,9,11,12,6,7,11,12,6,7,9,12,6,12,12,12,6,6,12,12,6,6,6,12,6,9,10,13,6,9,12,13,6,7,12,13,6,7,10,13,6,9,11,14,6,10,12,14,6,8,12,14,6,8,10,14,6,14,14,14,6,6,14,14,6,6,6,14,6,10,13,17,6,11,15,17,6,8,15,17,6,8,12,17,6,17,17,17,6,6,17,17,6,6,6,17,6,11,15,20,6,13,17,20,6,9,17,20,6,9,13,20,6,20,20,20,6,6,20,20,6,6,6,20,6,12,17,23,6,14,19,23,6,10,19,23,6,10,15,23,6,23,23,23,6,6,23,23,6,6,6,23,6,13,19,26,6,16,21,26,6,11,21,26,6,11,16,26,6,26,26,26,6,6,26,26,6,6,6,26,6,17,24,29,6,11,24,29,6,11,18,29,6,29,29,29,6,6,29,29,6,6,6,29,6,19,26,32,6,12,26,32,6,12,19,32,6,32,32,32,6,6,32,32,6,6,6,32,6,20,28,35,6,13,28,35,6,13,21,35,6,35,35,35,6,6,35,35,6,6,6,35,6,22,30,38,6,14,30,38,6,14,22,38,6,38,38,38,6,6,38,38,6,6,6,38,6,41,41,41,6,6,41,41,6,6,6,41,6,24,33,42,6,15,33,42,6,15,24,42,6,46,46,46,6,6,46,46,6,6,6,46,6,52,52,52,6,6,52,52,6,6,6,52,7,8,8,9,7,8,9,10,7,9,10,11,7,8,10,11,7,8,9,11,7,9,10,12,7,9,11,12,7,8,11,12,7,8,10,12,7,9,11,13,7,10,12,13,7,8,12,13,7,8,10,13,7,13,13,13,7,7,13,13,7,7,7,13,7,10,11,14,7,10,13,14,7,8,13,14,7,8,11,14,7,10,12,15,7,11,13,15,7,9,13,15,7,9,11,15,7,15,15,15,7,7,15,15,7,7,7,15,7,11,14,18,7,12,16,18,7,9,16,18,7,9,13,18,7,18,18,18,7,7,18,18,7,7,7,18,7,12,16,21,7,14,18,21,7,10,18,21,7,10,14,21,7,21,21,21,7,7,21,21,7,7,7,21,7,13,18,24,7,15,20,24,7,11,20,24,7,11,16,24,7,24,24,24,7,7,24,24,7,7,7,24,7,14,20,27,7,17,22,27,7,12,22,27,7,12,17,27,7,27,27,27,7,7,27,27,7,7,7,27,7,18,25,30,7,12,25,30,7,12,19,30,7,30,30,30,7,7,30,30,7,7,7,30,7,20,27,33,7,13,27,33,7,13,20,33,7,33,33,33,7,7,33,33,7,7,7,33,7,21,29,36,7,14,29,36,7,14,22,36,7,36,36,36,7,7,36,36,7,7,7,36,7,23,31,39,7,15,31,39,7,15,23,39,7,39,39,39,7,7,39,39,7,7,7,39,7,42,42,42,7,7,42,42,7,7,7,42,7,25,34,43,7,16,34,43,7,16,25,43,7,47,47,47,7,7,47,47,7,7,7,47,7,53,53,53,7,7,53,53,7,7,7,53,8,9,9,10,8,9,10,11,8,10,11,12,8,9,11,12,8,9,10,12,8,10,11,13,8,10,12,13,8,9,12,13,8,9,11,13,8,10,12,14,8,11,13,14,8,9,13,14,8,9,11,14,8,14,14,14,8,8,14,14,8,8,8,14,8,11,12,15,8,11,14,15,8,9,14,15,8,9,12,15,8,11,13,16,8,12,14,16,8,10,14,16,8,10,12,16,8,16,16,16,8,8,16,16,8,8,8,16,8,12,15,19,8,13,17,19,8,10,17,19,8,10,14,19,8,19,19,19,8,8,19,19,8,8,8,19,8,13,17,22,8,15,19,22,8,11,19,22,8,11,15,22,8,22,22,22,8,8,22,22,8,8,8,22,8,14,19,25,8,16,21,25,8,12,21,25,8,12,17,25,8,25,25,25,8,8,25,25,8,8,8,25,8,15,21,28,8,18,23,28,8,13,23,28,8,13,18,28,8,28,28,28,8,8,28,28,8,8,8,28,8,19,26,31,8,13,26,31,8,13,20,31,8,31,31,31,8,8,31,31,8,8,8,31,8,21,28,34,8,14,28,34,8,14,21,34,8,34,34,34,8,8,34,34,8,8,8,34,8,22,30,37,8,15,30,37,8,15,23,37,8,37,37,37,8,8,37,37,8,8,8,37,8,24,32,40,8,16,32,40,8,16,24,40,8,40,40,40,8,8,40,40,8,8,8,40,8,43,43,43,8,8,43,43,8,8,8,43,8,26,35,44,8,17,35,44,8,17,26,44,8,48,48,48,8,8,48,48,8,8,8,48,8,54,54,54,8,8,54,54,8,8,8,54,9,10,10,11,9,10,11,12,9,11,12,13,9,10,12,13,9,10,11,13,9,11,12,14,9,11,13,14,9,10,13,14,9,10,12,14,9,11,13,15,9,12,14,15,9,10,14,15,9,10,12,15,9,15,15,15,9,9,15,15,9,9,9,15,9,12,13,16,9,12,15,16,9,10,15,16,9,10,13,16,9,12,14,17,9,13,15,17,9,11,15,17,9,11,13,17,9,17,17,17,9,9,17,17,9,9,9,17,9,13,16,20,9,14,18,20,9,11,18,20,9,11,15,20,9,20,20,20,9,9,20,20,9,9,9,20,9,14,18,23,9,16,20,23,9,12,20,23,9,12,16,23,9,23,23,23,9,9,23,23,9,9,9,23,9,15,20,26,9,17,22,26,9,13,22,26,9,13,18,26,9,26,26,26,9,9,26,26,9,9,9,26,9,16,22,29,9,19,24,29,9,14,24,29,9,14,19,29,9,29,29,29,9,9,29,29,9,9,9,29,9,20,27,32,9,14,27,32,9,14,21,32,9,32,32,32,9,9,32,32,9,9,9,32,9,22,29,35,9,15,29,35,9,15,22,35,9,35,35,35,9,9,35,35,9,9,9,35,9,23,31,38,9,16,31,38,9,16,24,38,9,38,38,38,9,9,38,38,9,9,9,38,9,25,33,41,9,17,33,41,9,17,25,41,9,41,41,41,9,9,41,41,9,9,9,41,9,44,44,44,9,9,44,44,9,9,9,44,9,27,36,45,9,18,36,45,9,18,27,45,9,49,49,49,9,9,49,49,9,9,9,49,9,55,55,55,9,9,55,55,9,9,9,55,10,11,11,12,10,11,12,13,10,12,13,14,10,11,13,14,10,11,12,14,10,12,13,15,10,12,14,15,10,11,14,15,10,11,13,15,10,12,14,16,10,13,15,16,10,11,15,16,10,11,13,16,10,16,16,16,10,10,16,16,10,10,10,16,10,13,14,17,10,13,16,17,10,11,16,17,10,11,14,17,10,13,15,18,10,14,16,18,10,12,16,18,10,12,14,18,10,18,18,18,10,10,18,18,10,10,10,18,10,14,17,21,10,15,19,21,10,12,19,21,10,12,16,21,10,21,21,21,10,10,21,21,10,10,10,21,10,15,19,24,10,17,21,24,10,13,21,24,10,13,17,24,10,24,24,24,10,10,24,24,10,10,10,24,10,16,21,27,10,18,23,27,10,14,23,27,10,14,19,27,10,27,27,27,10,10,27,27,10,10,10,27,10,17,23,30,10,20,25,30,10,15,25,30,10,15,20,30,10,30,30,30,10,10,30,30,10,10,10,30,10,21,28,33,10,15,28,33,10,15,22,33,10,33,33,33,10,10,33,33,10,10,10,33,10,23,30,36,10,16,30,36,10,16,23,36,10,36,36,36,10,10,36,36,10,10,10,36,10,24,32,39,10,17,32,39,10,17,25,39,10,39,39,39,10,10,39,39,10,10,10,39,10,26,34,42,10,18,34,42,10,18,26,42,10,42,42,42,10,10,42,42,10,10,10,42,10,45,45,45,10,10,45,45,10,10,10,45,10,28,37,46,10,19,37,46,10,19,28,46,10,50,50,50,10,10,50,50,10,10,10,50,10,56,56,56,10,10,56,56,10,10,10,56,11,12,12,13,11,12,13,14,11,13,14,15,11,12,14,15,11,12,13,15,11,13,14,16,11,13,15,16,11,12,15,16,11,12,14,16,11,13,15,17,11,14,16,17,11,12,16,17,11,12,14,17,11,17,17,17,11,11,17,17,11,11,11,17,11,14,15,18,11,14,17,18,11,12,17,18,11,12,15,18,11,14,16,19,11,15,17,19,11,13,17,19,11,13,15,19,11,19,19,19,11,11,19,19,11,11,11,19,11,15,18,22,11,16,20,22,11,13,20,22,11,13,17,22,11,22,22,22,11,11,22,22,11,11,11,22,11,16,20,25,11,18,22,25,11,14,22,25,11,14,18,25,11,25,25,25,11,11,25,25,11,11,11,25,11,17,22,28,11,19,24,28,11,15,24,28,11,15,20,28,11,28,28,28,11,11,28,28,11,11,11,28,11,18,24,31,11,21,26,31,11,16,26,31,11,16,21,31,11,31,31,31,11,11,31,31,11,11,11,31,11,22,29,34,11,16,29,34,11,16,23,34,11,34,34,34,11,11,34,34,11,11,11,34,11,24,31,37,11,17,31,37,11,17,24,37,11,37,37,37,11,11,37,37,11,11,11,37,11,25,33,40,11,18,33,40,11,18,26,40,11,40,40,40,11,11,40,40,11,11,11,40,11,27,35,43,11,19,35,43,11,19,27,43,11,43,43,43,11,11,43,43,11,11,11,43,11,46,46,46,11,11,46,46,11,11,11,46,11,29,38,47,11,20,38,47,11,20,29,47,11,51,51,51,11,11,51,51,11,11,11,51,11,57,57,57,11,11,57,57,11,11,11,57,12,13,13,14,12,13,14,15,12,14,15,16,12,13,15,16,12,13,14,16,12,14,15,17,12,14,16,17,12,13,16,17,12,13,15,17,12,14,16,18,12,15,17,18,12,13,17,18,12,13,15,18,12,18,18,18,12,12,18,18,12,12,12,18,12,15,16,19,12,15,18,19,12,13,18,19,12,13,16,19,12,15,17,20,12,16,18,20,12,14,18,20,12,14,16,20,12,20,20,20,12,12,20,20,12,12,12,20,12,16,19,23,12,17,21,23,12,14,21,23,12,14,18,23,12,23,23,23,12,12,23,23,12,12,12,23,12,17,21,26,12,19,23,26,12,15,23,26,12,15,19,26,12,26,26,26,12,12,26,26,12,12,12,26,12,18,23,29,12,20,25,29,12,16,25,29,12,16,21,29,12,29,29,29,12,12,29,29,12,12,12,29,12,19,25,32,12,22,27,32,12,17,27,32,12,17,22,32,12,32,32,32,12,12,32,32,12,12,12,32,12,23,30,35,12,17,30,35,12,17,24,35,12,35,35,35,12,12,35,35,12,12,12,35,12,25,32,38,12,18,32,38,12,18,25,38,12,38,38,38,12,12,38,38,12,12,12,38,12,26,34,41,12,19,34,41,12,19,27,41,12,41,41,41,12,12,41,41,12,12,12,41,12,28,36,44,12,20,36,44,12,20,28,44,12,44,44,44,12,12,44,44,12,12,12,44,12,47,47,47,12,12,47,47,12,12,12,47,12,30,39,48,12,21,39,48,12,21,30,48,12,52,52,52,12,12,52,52,12,12,12,52,12,58,58,58,12,12,58,58,12,12,12,58,13,14,14,15,13,14,15,16,13,15,16,17,13,14,16,17,13,14,15,17,13,15,16,18,13,15,17,18,13,14,17,18,13,14,16,18,13,15,17,19,13,16,18,19,13,14,18,19,13,14,16,19,13,19,19,19,13,13,19,19,13,13,13,19,13,16,17,20,13,16,19,20,13,14,19,20,13,14,17,20,13,16,18,21,13,17,19,21,13,15,19,21,13,15,17,21,13,21,21,21,13,13,21,21,13,13,13,21,13,17,20,24,13,18,22,24,13,15,22,24,13,15,19,24,13,24,24,24,13,13,24,24,13,13,13,24,13,18,22,27,13,20,24,27,13,16,24,27,13,16,20,27,13,27,27,27,13,13,27,27,13,13,13,27,13,19,24,30,13,21,26,30,13,17,26,30,13,17,22,30,13,30,30,30,13,13,30,30,13,13,13,30,13,20,26,33,13,23,28,33,13,18,28,33,13,18,23,33,13,33,33,33,13,13,33,33,13,13,13,33,13,24,31,36,13,18,31,36,13,18,25,36,13,36,36,36,13,13,36,36,13,13,13,36,13,26,33,39,13,19,33,39,13,19,26,39,13,39,39,39,13,13,39,39,13,13,13,39,13,27,35,42,13,20,35,42,13,20,28,42,13,42,42,42,13,13,42,42,13,13,13,42,13,29,37,45,13,21,37,45,13,21,29,45,13,45,45,45,13,13,45,45,13,13,13,45,13,48,48,48,13,13,48,48,13,13,13,48,13,31,40,49,13,22,40,49,13,22,31,49,13,53,53,53,13,13,53,53,13,13,13,53,13,59,59,59,13,13,59,59,13,13,13,59,14,15,15,16,14,15,16,17,14,16,17,18,14,15,17,18,14,15,16,18,14,16,17,19,14,16,18,19,14,15,18,19,14,15,17,19,14,16,18,20,14,17,19,20,14,15,19,20,14,15,17,20,14,20,20,20,14,14,20,20,14,14,14,20,14,17,18,21,14,17,20,21,14,15,20,21,14,15,18,21,14,17,19,22,14,18,20,22,14,16,20,22,14,16,18,22,14,22,22,22,14,14,22,22,14,14,14,22,14,18,21,25,14,19,23,25,14,16,23,25,14,16,20,25,14,25,25,25,14,14,25,25,14,14,14,25,14,19,23,28,14,21,25,28,14,17,25,28,14,17,21,28,14,28,28,28,14,14,28,28,14,14,14,28,14,20,25,31,14,22,27,31,14,18,27,31,14,18,23,31,14,31,31,31,14,14,31,31,14,14,14,31,14,21,27,34,14,24,29,34,14,19,29,34,14,19,24,34,14,34,34,34,14,14,34,34,14,14,14,34,14,25,32,37,14,19,32,37,14,19,26,37,14,37,37,37,14,14,37,37,14,14,14,37,14,27,34,40,14,20,34,40,14,20,27,40,14,40,40,40,14,14,40,40,14,14,14,40,14,28,36,43,14,21,36,43,14,21,29,43,14,43,43,43,14,14,43,43,14,14,14,43,14,30,38,46,14,22,38,46,14,22,30,46,14,46,46,46,14,14,46,46,14,14,14,46,14,49,49,49,14,14,49,49,14,14,14,49,14,32,41,50,14,23,41,50,14,23,32,50,14,54,54,54,14,14,54,54,14,14,14,54,14,60,60,60,14,14,60,60,14,14,14,60,15,16,16,17,15,16,17,18,15,17,18,19,15,16,18,19,15,16,17,19,15,17,18,20,15,17,19,20,15,16,19,20,15,16,18,20,15,17,19,21,15,18,20,21,15,16,20,21,15,16,18,21,15,21,21,21,15,15,21,21,15,15,15,21,15,18,19,22,15,18,21,22,15,16,21,22,15,16,19,22,15,18,20,23,15,19,21,23,15,17,21,23,15,17,19,23,15,23,23,23,15,15,23,23,15,15,15,23,15,19,22,26,15,20,24,26,15,17,24,26,15,17,21,26,15,26,26,26,15,15,26,26,15,15,15,26,15,20,24,29,15,22,26,29,15,18,26,29,15,18,22,29,15,29,29,29,15,15,29,29,15,15,15,29,15,21,26,32,15,23,28,32,15,19,28,32,15,19,24,32,15,32,32,32,15,15,32,32,15,15,15,32,15,22,28,35,15,25,30,35,15,20,30,35,15,20,25,35,15,35,35,35,15,15,35,35,15,15,15,35,15,26,33,38,15,20,33,38,15,20,27,38,15,38,38,38,15,15,38,38,15,15,15,38,15,28,35,41,15,21,35,41,15,21,28,41,15,41,41,41,15,15,41,41,15,15,15,41,15,29,37,44,15,22,37,44,15,22,30,44,15,44,44,44,15,15,44,44,15,15,15,44,15,31,39,47,15,23,39,47,15,23,31,47,15,47,47,47,15,15,47,47,15,15,15,47,15,50,50,50,15,15,50,50,15,15,15,50,15,33,42,51,15,24,42,51,15,24,33,51,15,55,55,55,15,15,55,55,15,15,15,55,15,61,61,61,15,15,61,61,15,15,15,61,16,17,17,18,16,17,18,19,16,18,19,20,16,17,19,20,16,17,18,20,16,18,19,21,16,18,20,21,16,17,20,21,16,17,19,21,16,18,20,22,16,19,21,22,16,17,21,22,16,17,19,22,16,22,22,22,16,16,22,22,16,16,16,22,16,19,20,23,16,19,22,23,16,17,22,23,16,17,20,23,16,19,21,24,16,20,22,24,16,18,22,24,16,18,20,24,16,24,24,24,16,16,24,24,16,16,16,24,16,20,23,27,16,21,25,27,16,18,25,27,16,18,22,27,16,27,27,27,16,16,27,27,16,16,16,27,16,21,25,30,16,23,27,30,16,19,27,30,16,19,23,30,16,30,30,30,16,16,30,30,16,16,16,30,16,22,27,33,16,24,29,33,16,20,29,33,16,20,25,33,16,33,33,33,16,16,33,33,16,16,16,33,16,23,29,36,16,26,31,36,16,21,31,36,16,21,26,36,16,36,36,36,16,16,36,36,16,16,16,36,16,27,34,39,16,21,34,39,16,21,28,39,16,39,39,39,16,16,39,39,16,16,16,39,16,29,36,42,16,22,36,42,16,22,29,42,16,42,42,42,16,16,42,42,16,16,16,42,16,30,38,45,16,23,38,45,16,23,31,45,16,45,45,45,16,16,45,45,16,16,16,45,16,32,40,48,16,24,40,48,16,24,32,48,16,48,48,48,16,16,48,48,16,16,16,48,16,51,51,51,16,16,51,51,16,16,16,51,16,34,43,52,16,25,43,52,16,25,34,52,16,56,56,56,16,16,56,56,16,16,16,56,16,62,62,62,16,16,62,62,16,16,16,62,17,18,18,19,17,18,19,20,17,19,20,21,17,18,20,21,17,18,19,21,17,19,20,22,17,19,21,22,17,18,21,22,17,18,20,22,17,19,21,23,17,20,22,23,17,18,22,23,17,18,20,23,17,23,23,23,17,17,23,23,17,17,17,23,17,20,21,24,17,20,23,24,17,18,23,24,17,18,21,24,17,20,22,25,17,21,23,25,17,19,23,25,17,19,21,25,17,25,25,25,17,17,25,25,17,17,17,25,17,21,24,28,17,22,26,28,17,19,26,28,17,19,23,28,17,28,28,28,17,17,28,28,17,17,17,28,17,22,26,31,17,24,28,31,17,20,28,31,17,20,24,31,17,31,31,31,17,17,31,31,17,17,17,31,17,23,28,34,17,25,30,34,17,21,30,34,17,21,26,34,17,34,34,34,17,17,34,34,17,17,17,34,17,24,30,37,17,27,32,37,17,22,32,37,17,22,27,37,17,37,37,37,17,17,37,37,17,17,17,37,17,28,35,40,17,22,35,40,17,22,29,40,17,40,40,40,17,17,40,40,17,17,17,40,17,30,37,43,17,23,37,43,17,23,30,43,17,43,43,43,17,17,43,43,17,17,17,43,17,31,39,46,17,24,39,46,17,24,32,46,17,46,46,46,17,17,46,46,17,17,17,46,17,33,41,49,17,25,41,49,17,25,33,49,17,49,49,49,17,17,49,49,17,17,17,49,17,52,52,52,17,17,52,52,17,17,17,52,17,35,44,53,17,26,44,53,17,26,35,53,17,57,57,57,17,17,57,57,17,17,17,57,17,63,63,63,17,17,63,63,17,17,17,63,18,19,19,20,18,19,20,21,18,20,21,22,18,19,21,22,18,19,20,22,18,20,21,23,18,20,22,23,18,19,22,23,18,19,21,23,18,20,22,24,18,21,23,24,18,19,23,24,18,19,21,24,18,24,24,24,18,18,24,24,18,18,18,24,18,21,22,25,18,21,24,25,18,19,24,25,18,19,22,25,18,21,23,26,18,22,24,26,18,20,24,26,18,20,22,26,18,26,26,26,18,18,26,26,18,18,18,26,18,22,25,29,18,23,27,29,18,20,27,29,18,20,24,29,18,29,29,29,18,18,29,29,18,18,18,29,18,23,27,32,18,25,29,32,18,21,29,32,18,21,25,32,18,32,32,32,18,18,32,32,18,18,18,32,18,24,29,35,18,26,31,35,18,22,31,35,18,22,27,35,18,35,35,35,18,18,35,35,18,18,18,35,18,25,31,38,18,28,33,38,18,23,33,38,18,23,28,38,18,38,38,38,18,18,38,38,18,18,18,38,18,29,36,41,18,23,36,41,18,23,30,41,18,41,41,41,18,18,41,41,18,18,18,41,18,31,38,44,18,24,38,44,18,24,31,44,18,44,44,44,18,18,44,44,18,18,18,44,18,32,40,47,18,25,40,47,18,25,33,47,18,47,47,47,18,18,47,47,18,18,18,47,18,34,42,50,18,26,42,50,18,26,34,50,18,50,50,50,18,18,50,50,18,18,18,50,18,53,53,53,18,18,53,53,18,18,18,53,18,36,45,54,18,27,45,54,18,27,36,54,18,58,58,58,18,18,58,58,18,18,18,58,19,20,20,21,19,20,21,22,19,21,22,23,19,20,22,23,19,20,21,23,19,21,22,24,19,21,23,24,19,20,23,24,19,20,22,24,19,21,23,25,19,22,24,25,19,20,24,25,19,20,22,25,19,25,25,25,19,19,25,25,19,19,19,25,19,22,23,26,19,22,25,26,19,20,25,26,19,20,23,26,19,22,24,27,19,23,25,27,19,21,25,27,19,21,23,27,19,27,27,27,19,19,27,27,19,19,19,27,19,23,26,30,19,24,28,30,19,21,28,30,19,21,25,30,19,30,30,30,19,19,30,30,19,19,19,30,19,24,28,33,19,26,30,33,19,22,30,33,19,22,26,33,19,33,33,33,19,19,33,33,19,19,19,33,19,25,30,36,19,27,32,36,19,23,32,36,19,23,28,36,19,36,36,36,19,19,36,36,19,19,19,36,19,26,32,39,19,29,34,39,19,24,34,39,19,24,29,39,19,39,39,39,19,19,39,39,19,19,19,39,19,30,37,42,19,24,37,42,19,24,31,42,19,42,42,42,19,19,42,42,19,19,19,42,19,32,39,45,19,25,39,45,19,25,32,45,19,45,45,45,19,19,45,45,19,19,19,45,19,33,41,48,19,26,41,48,19,26,34,48,19,48,48,48,19,19,48,48,19,19,19,48,19,35,43,51,19,27,43,51,19,27,35,51,19,51,51,51,19,19,51,51,19,19,19,51,19,54,54,54,19,19,54,54,19,19,19,54,19,37,46,55,19,28,46,55,19,28,37,55,19,59,59,59,19,19,59,59,19,19,19,59,20,21,21,22,20,21,22,23,20,22,23,24,20,21,23,24,20,21,22,24,20,22,23,25,20,22,24,25,20,21,24,25,20,21,23,25,20,22,24,26,20,23,25,26,20,21,25,26,20,21,23,26,20,26,26,26,20,20,26,26,20,20,20,26,20,23,24,27,20,23,26,27,20,21,26,27,20,21,24,27,20,23,25,28,20,24,26,28,20,22,26,28,20,22,24,28,20,28,28,28,20,20,28,28,20,20,20,28,20,24,27,31,20,25,29,31,20,22,29,31,20,22,26,31,20,31,31,31,20,20,31,31,20,20,20,31,20,25,29,34,20,27,31,34,20,23,31,34,20,23,27,34,20,34,34,34,20,20,34,34,20,20,20,34,20,26,31,37,20,28,33,37,20,24,33,37,20,24,29,37,20,37,37,37,20,20,37,37,20,20,20,37,20,27,33,40,20,30,35,40,20,25,35,40,20,25,30,40,20,40,40,40,20,20,40,40,20,20,20,40,20,31,38,43,20,25,38,43,20,25,32,43,20,43,43,43,20,20,43,43,20,20,20,43,20,33,40,46,20,26,40,46,20,26,33,46,20,46,46,46,20,20,46,46,20,20,20,46,20,34,42,49,20,27,42,49,20,27,35,49,20,49,49,49,20,20,49,49,20,20,20,49,20,36,44,52,20,28,44,52,20,28,36,52,20,52,52,52,20,20,52,52,20,20,20,52,20,55,55,55,20,20,55,55,20,20,20,55,20,38,47,56,20,29,47,56,20,29,38,56,20,60,60,60,20,20,60,60,20,20,20,60,21,22,22,23,21,22,23,24,21,23,24,25,21,22,24,25,21,22,23,25,21,23,24,26,21,23,25,26,21,22,25,26,21,22,24,26,21,23,25,27,21,24,26,27,21,22,26,27,21,22,24,27,21,27,27,27,21,21,27,27,21,21,21,27,21,24,25,28,21,24,27,28,21,22,27,28,21,22,25,28,21,24,26,29,21,25,27,29,21,23,27,29,21,23,25,29,21,29,29,29,21,21,29,29,21,21,21,29,21,25,28,32,21,26,30,32,21,23,30,32,21,23,27,32,21,32,32,32,21,21,32,32,21,21,21,32,21,26,30,35,21,28,32,35,21,24,32,35,21,24,28,35,21,35,35,35,21,21,35,35,21,21,21,35,21,27,32,38,21,29,34,38,21,25,34,38,21,25,30,38,21,38,38,38,21,21,38,38,21,21,21,38,21,28,34,41,21,31,36,41,21,26,36,41,21,26,31,41,21,41,41,41,21,21,41,41,21,21,21,41,21,32,39,44,21,26,39,44,21,26,33,44,21,44,44,44,21,21,44,44,21,21,21,44,21,34,41,47,21,27,41,47,21,27,34,47,21,47,47,47,21,21,47,47,21,21,21,47,21,35,43,50,21,28,43,50,21,28,36,50,21,50,50,50,21,21,50,50,21,21,21,50,21,37,45,53,21,29,45,53,21,29,37,53,21,53,53,53,21,21,53,53,21,21,21,53,21,56,56,56,21,21,56,56,21,21,21,56,21,39,48,57,21,30,48,57,21,30,39,57,21,61,61,61,21,21,61,61,21,21,21,61,22,23,23,24,22,23,24,25,22,24,25,26,22,23,25,26,22,23,24,26,22,24,25,27,22,24,26,27,22,23,26,27,22,23,25,27,22,24,26,28,22,25,27,28,22,23,27,28,22,23,25,28,22,28,28,28,22,22,28,28,22,22,22,28,22,25,26,29,22,25,28,29,22,23,28,29,22,23,26,29,22,25,27,30,22,26,28,30,22,24,28,30,22,24,26,30,22,30,30,30,22,22,30,30,22,22,22,30,22,26,29,33,22,27,31,33,22,24,31,33,22,24,28,33,22,33,33,33,22,22,33,33,22,22,22,33,22,27,31,36,22,29,33,36,22,25,33,36,22,25,29,36,22,36,36,36,22,22,36,36,22,22,22,36,22,28,33,39,22,30,35,39,22,26,35,39,22,26,31,39,22,39,39,39,22,22,39,39,22,22,22,39,22,29,35,42,22,32,37,42,22,27,37,42,22,27,32,42,22,42,42,42,22,22,42,42,22,22,22,42,22,33,40,45,22,27,40,45,22,27,34,45,22,45,45,45,22,22,45,45,22,22,22,45,22,35,42,48,22,28,42,48,22,28,35,48,22,48,48,48,22,22,48,48,22,22,22,48,22,36,44,51,22,29,44,51,22,29,37,51,22,51,51,51,22,22,51,51,22,22,22,51,22,38,46,54,22,30,46,54,22,30,38,54,22,54,54,54,22,22,54,54,22,22,22,54,22,57,57,57,22,22,57,57,22,22,22,57,22,40,49,58,22,31,49,58,22,31,40,58,22,62,62,62,22,22,62,62,22,22,22,62,23,24,24,25,23,24,25,26,23,25,26,27,23,24,26,27,23,24,25,27,23,25,26,28,23,25,27,28,23,24,27,28,23,24,26,28,23,25,27,29,23,26,28,29,23,24,28,29,23,24,26,29,23,29,29,29,23,23,29,29,23,23,23,29,23,26,27,30,23,26,29,30,23,24,29,30,23,24,27,30,23,26,28,31,23,27,29,31,23,25,29,31,23,25,27,31,23,31,31,31,23,23,31,31,23,23,23,31,23,27,30,34,23,28,32,34,23,25,32,34,23,25,29,34,23,34,34,34,23,23,34,34,23,23,23,34,23,28,32,37,23,30,34,37,23,26,34,37,23,26,30,37,23,37,37,37,23,23,37,37,23,23,23,37,23,29,34,40,23,31,36,40,23,27,36,40,23,27,32,40,23,40,40,40,23,23,40,40,23,23,23,40,23,30,36,43,23,33,38,43,23,28,38,43,23,28,33,43,23,43,43,43,23,23,43,43,23,23,23,43,23,34,41,46,23,28,41,46,23,28,35,46,23,46,46,46,23,23,46,46,23,23,23,46,23,36,43,49,23,29,43,49,23,29,36,49,23,49,49,49,23,23,49,49,23,23,23,49,23,37,45,52,23,30,45,52,23,30,38,52,23,52,52,52,23,23,52,52,23,23,23,52,23,39,47,55,23,31,47,55,23,31,39,55,23,55,55,55,23,23,55,55,23,23,23,55,23,58,58,58,23,23,58,58,23,23,23,58,23,41,50,59,23,32,50,59,23,32,41,59,23,63,63,63,23,23,63,63,23,23,23,63,24,25,25,26,24,25,26,27,24,26,27,28,24,25,27,28,24,25,26,28,24,26,27,29,24,26,28,29,24,25,28,29,24,25,27,29,24,26,28,30,24,27,29,30,24,25,29,30,24,25,27,30,24,30,30,30,24,24,30,30,24,24,24,30,24,27,28,31,24,27,30,31,24,25,30,31,24,25,28,31,24,27,29,32,24,28,30,32,24,26,30,32,24,26,28,32,24,32,32,32,24,24,32,32,24,24,24,32,24,28,31,35,24,29,33,35,24,26,33,35,24,26,30,35,24,35,35,35,24,24,35,35,24,24,24,35,24,29,33,38,24,31,35,38,24,27,35,38,24,27,31,38,24,38,38,38,24,24,38,38,24,24,24,38,24,30,35,41,24,32,37,41,24,28,37,41,24,28,33,41,24,41,41,41,24,24,41,41,24,24,24,41,24,31,37,44,24,34,39,44,24,29,39,44,24,29,34,44,24,44,44,44,24,24,44,44,24,24,24,44,24,35,42,47,24,29,42,47,24,29,36,47,24,47,47,47,24,24,47,47,24,24,24,47,24,37,44,50,24,30,44,50,24,30,37,50,24,50,50,50,24,24,50,50,24,24,24,50,24,38,46,53,24,31,46,53,24,31,39,53,24,53,53,53,24,24,53,53,24,24,24,53,24,40,48,56,24,32,48,56,24,32,40,56,24,56,56,56,24,24,56,56,24,24,24,56,24,59,59,59,24,24,59,59,24,24,24,59,24,42,51,60,24,33,51,60,24,33,42,60,25,26,26,27,25,26,27,28,25,27,28,29,25,26,28,29,25,26,27,29,25,27,28,30,25,27,29,30,25,26,29,30,25,26,28,30,25,27,29,31,25,28,30,31,25,26,30,31,25,26,28,31,25,31,31,31,25,25,31,31,25,25,25,31,25,28,29,32,25,28,31,32,25,26,31,32,25,26,29,32,25,28,30,33,25,29,31,33,25,27,31,33,25,27,29,33,25,33,33,33,25,25,33,33,25,25,25,33,25,29,32,36,25,30,34,36,25,27,34,36,25,27,31,36,25,36,36,36,25,25,36,36,25,25,25,36,25,30,34,39,25,32,36,39,25,28,36,39,25,28,32,39,25,39,39,39,25,25,39,39,25,25,25,39,25,31,36,42,25,33,38,42,25,29,38,42,25,29,34,42,25,42,42,42,25,25,42,42,25,25,25,42,25,32,38,45,25,35,40,45,25,30,40,45,25,30,35,45,25,45,45,45,25,25,45,45,25,25,25,45,25,36,43,48,25,30,43,48,25,30,37,48,25,48,48,48,25,25,48,48,25,25,25,48,25,38,45,51,25,31,45,51,25,31,38,51,25,51,51,51,25,25,51,51,25,25,25,51,25,39,47,54,25,32,47,54,25,32,40,54,25,54,54,54,25,25,54,54,25,25,25,54,25,41,49,57,25,33,49,57,25,33,41,57,25,57,57,57,25,25,57,57,25,25,25,57,25,60,60,60,25,25,60,60,25,25,25,60,25,43,52,61,25,34,52,61,25,34,43,61,26,27,27,28,26,27,28,29,26,28,29,30,26,27,29,30,26,27,28,30,26,28,29,31,26,28,30,31,26,27,30,31,26,27,29,31,26,28,30,32,26,29,31,32,26,27,31,32,26,27,29,32,26,32,32,32,26,26,32,32,26,26,26,32,26,29,30,33,26,29,32,33,26,27,32,33,26,27,30,33,26,29,31,34,26,30,32,34,26,28,32,34,26,28,30,34,26,34,34,34,26,26,34,34,26,26,26,34,26,30,33,37,26,31,35,37,26,28,35,37,26,28,32,37,26,37,37,37,26,26,37,37,26,26,26,37,26,31,35,40,26,33,37,40,26,29,37,40,26,29,33,40,26,40,40,40,26,26,40,40,26,26,26,40,26,32,37,43,26,34,39,43,26,30,39,43,26,30,35,43,26,43,43,43,26,26,43,43,26,26,26,43,26,33,39,46,26,36,41,46,26,31,41,46,26,31,36,46,26,46,46,46,26,26,46,46,26,26,26,46,26,37,44,49,26,31,44,49,26,31,38,49,26,49,49,49,26,26,49,49,26,26,26,49,26,39,46,52,26,32,46,52,26,32,39,52,26,52,52,52,26,26,52,52,26,26,26,52,26,40,48,55,26,33,48,55,26,33,41,55,26,55,55,55,26,26,55,55,26,26,26,55,26,42,50,58,26,34,50,58,26,34,42,58,26,58,58,58,26,26,58,58,26,26,26,58,26,61,61,61,26,26,61,61,26,26,26,61,26,44,53,62,26,35,53,62,26,35,44,62,27,28,28,29,27,28,29,30,27,29,30,31,27,28,30,31,27,28,29,31,27,29,30,32,27,29,31,32,27,28,31,32,27,28,30,32,27,29,31,33,27,30,32,33,27,28,32,33,27,28,30,33,27,33,33,33,27,27,33,33,27,27,27,33,27,30,31,34,27,30,33,34,27,28,33,34,27,28,31,34,27,30,32,35,27,31,33,35,27,29,33,35,27,29,31,35,27,35,35,35,27,27,35,35,27,27,27,35,27,31,34,38,27,32,36,38,27,29,36,38,27,29,33,38,27,38,38,38,27,27,38,38,27,27,27,38,27,32,36,41,27,34,38,41,27,30,38,41,27,30,34,41,27,41,41,41,27,27,41,41,27,27,27,41,27,33,38,44,27,35,40,44,27,31,40,44,27,31,36,44,27,44,44,44,27,27,44,44,27,27,27,44,27,34,40,47,27,37,42,47,27,32,42,47,27,32,37,47,27,47,47,47,27,27,47,47,27,27,27,47,27,38,45,50,27,32,45,50,27,32,39,50,27,50,50,50,27,27,50,50,27,27,27,50,27,40,47,53,27,33,47,53,27,33,40,53,27,53,53,53,27,27,53,53,27,27,27,53,27,41,49,56,27,34,49,56,27,34,42,56,27,56,56,56,27,27,56,56,27,27,27,56,27,43,51,59,27,35,51,59,27,35,43,59,27,59,59,59,27,27,59,59,27,27,27,59,27,62,62,62,27,27,62,62,27,27,27,62,27,45,54,63,27,36,54,63,27,36,45,63,28,29,29,30,28,29,30,31,28,30,31,32,28,29,31,32,28,29,30,32,28,30,31,33,28,30,32,33,28,29,32,33,28,29,31,33,28,30,32,34,28,31,33,34,28,29,33,34,28,29,31,34,28,34,34,34,28,28,34,34,28,28,28,34,28,31,32,35,28,31,34,35,28,29,34,35,28,29,32,35,28,31,33,36,28,32,34,36,28,30,34,36,28,30,32,36,28,36,36,36,28,28,36,36,28,28,28,36,28,32,35,39,28,33,37,39,28,30,37,39,28,30,34,39,28,39,39,39,28,28,39,39,28,28,28,39,28,33,37,42,28,35,39,42,28,31,39,42,28,31,35,42,28,42,42,42,28,28,42,42,28,28,28,42,28,34,39,45,28,36,41,45,28,32,41,45,28,32,37,45,28,45,45,45,28,28,45,45,28,28,28,45,28,35,41,48,28,38,43,48,28,33,43,48,28,33,38,48,28,48,48,48,28,28,48,48,28,28,28,48,28,39,46,51,28,33,46,51,28,33,40,51,28,51,51,51,28,28,51,51,28,28,28,51,28,41,48,54,28,34,48,54,28,34,41,54,28,54,54,54,28,28,54,54,28,28,28,54,28,42,50,57,28,35,50,57,28,35,43,57,28,57,57,57,28,28,57,57,28,28,28,57,28,44,52,60,28,36,52,60,28,36,44,60,28,60,60,60,28,28,60,60,28,28,28,60,28,63,63,63,28,28,63,63,28,28,28,63,29,30,30,31,29,30,31,32,29,31,32,33,29,30,32,33,29,30,31,33,29,31,32,34,29,31,33,34,29,30,33,34,29,30,32,34,29,31,33,35,29,32,34,35,29,30,34,35,29,30,32,35,29,35,35,35,29,29,35,35,29,29,29,35,29,32,33,36,29,32,35,36,29,30,35,36,29,30,33,36,29,32,34,37,29,33,35,37,29,31,35,37,29,31,33,37,29,37,37,37,29,29,37,37,29,29,29,37,29,33,36,40,29,34,38,40,29,31,38,40,29,31,35,40,29,40,40,40,29,29,40,40,29,29,29,40,29,34,38,43,29,36,40,43,29,32,40,43,29,32,36,43,29,43,43,43,29,29,43,43,29,29,29,43,29,35,40,46,29,37,42,46,29,33,42,46,29,33,38,46,29,46,46,46,29,29,46,46,29,29,29,46,29,36,42,49,29,39,44,49,29,34,44,49,29,34,39,49,29,49,49,49,29,29,49,49,29,29,29,49,29,40,47,52,29,34,47,52,29,34,41,52,29,52,52,52,29,29,52,52,29,29,29,52,29,42,49,55,29,35,49,55,29,35,42,55,29,55,55,55,29,29,55,55,29,29,29,55,29,43,51,58,29,36,51,58,29,36,44,58,29,58,58,58,29,29,58,58,29,29,29,58,29,45,53,61,29,37,53,61,29,37,45,61,29,61,61,61,29,29,61,61,29,29,29,61,30,31,31,32,30,31,32,33,30,32,33,34,30,31,33,34,30,31,32,34,30,32,33,35,30,32,34,35,30,31,34,35,30,31,33,35,30,32,34,36,30,33,35,36,30,31,35,36,30,31,33,36,30,36,36,36,30,30,36,36,30,30,30,36,30,33,34,37,30,33,36,37,30,31,36,37], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+163840);
/* memory initializer */ allocate([30,31,34,37,30,33,35,38,30,34,36,38,30,32,36,38,30,32,34,38,30,38,38,38,30,30,38,38,30,30,30,38,30,34,37,41,30,35,39,41,30,32,39,41,30,32,36,41,30,41,41,41,30,30,41,41,30,30,30,41,30,35,39,44,30,37,41,44,30,33,41,44,30,33,37,44,30,44,44,44,30,30,44,44,30,30,30,44,30,36,41,47,30,38,43,47,30,34,43,47,30,34,39,47,30,47,47,47,30,30,47,47,30,30,30,47,30,37,43,50,30,40,45,50,30,35,45,50,30,35,40,50,30,50,50,50,30,30,50,50,30,30,30,50,30,41,48,53,30,35,48,53,30,35,42,53,30,53,53,53,30,30,53,53,30,30,30,53,30,43,50,56,30,36,50,56,30,36,43,56,30,56,56,56,30,30,56,56,30,30,30,56,30,44,52,59,30,37,52,59,30,37,45,59,30,59,59,59,30,30,59,59,30,30,30,59,30,46,54,62,30,38,54,62,30,38,46,62,30,62,62,62,30,30,62,62,30,30,30,62,31,32,32,33,31,32,33,34,31,33,34,35,31,32,34,35,31,32,33,35,31,33,34,36,31,33,35,36,31,32,35,36,31,32,34,36,31,33,35,37,31,34,36,37,31,32,36,37,31,32,34,37,31,37,37,37,31,31,37,37,31,31,31,37,31,34,35,38,31,34,37,38,31,32,37,38,31,32,35,38,31,34,36,39,31,35,37,39,31,33,37,39,31,33,35,39,31,39,39,39,31,31,39,39,31,31,31,39,31,35,38,42,31,36,40,42,31,33,40,42,31,33,37,42,31,42,42,42,31,31,42,42,31,31,31,42,31,36,40,45,31,38,42,45,31,34,42,45,31,34,38,45,31,45,45,45,31,31,45,45,31,31,31,45,31,37,42,48,31,39,44,48,31,35,44,48,31,35,40,48,31,48,48,48,31,31,48,48,31,31,31,48,31,38,44,51,31,41,46,51,31,36,46,51,31,36,41,51,31,51,51,51,31,31,51,51,31,31,31,51,31,42,49,54,31,36,49,54,31,36,43,54,31,54,54,54,31,31,54,54,31,31,31,54,31,44,51,57,31,37,51,57,31,37,44,57,31,57,57,57,31,31,57,57,31,31,31,57,31,45,53,60,31,38,53,60,31,38,46,60,31,60,60,60,31,31,60,60,31,31,31,60,31,47,55,63,31,39,55,63,31,39,47,63,31,63,63,63,31,31,63,63,31,31,31,63,32,33,33,34,32,33,34,35,32,34,35,36,32,33,35,36,32,33,34,36,32,34,35,37,32,34,36,37,32,33,36,37,32,33,35,37,32,34,36,38,32,35,37,38,32,33,37,38,32,33,35,38,32,38,38,38,32,32,38,38,32,32,32,38,32,35,36,39,32,35,38,39,32,33,38,39,32,33,36,39,32,35,37,40,32,36,38,40,32,34,38,40,32,34,36,40,32,40,40,40,32,32,40,40,32,32,32,40,32,36,39,43,32,37,41,43,32,34,41,43,32,34,38,43,32,43,43,43,32,32,43,43,32,32,32,43,32,37,41,46,32,39,43,46,32,35,43,46,32,35,39,46,32,46,46,46,32,32,46,46,32,32,32,46,32,38,43,49,32,40,45,49,32,36,45,49,32,36,41,49,32,49,49,49,32,32,49,49,32,32,32,49,32,39,45,52,32,42,47,52,32,37,47,52,32,37,42,52,32,52,52,52,32,32,52,52,32,32,32,52,32,43,50,55,32,37,50,55,32,37,44,55,32,55,55,55,32,32,55,55,32,32,32,55,32,45,52,58,32,38,52,58,32,38,45,58,32,58,58,58,32,32,58,58,32,32,32,58,32,46,54,61,32,39,54,61,32,39,47,61,32,61,61,61,32,32,61,61,32,32,32,61,33,34,34,35,33,34,35,36,33,35,36,37,33,34,36,37,33,34,35,37,33,35,36,38,33,35,37,38,33,34,37,38,33,34,36,38,33,35,37,39,33,36,38,39,33,34,38,39,33,34,36,39,33,39,39,39,33,33,39,39,33,33,33,39,33,36,37,40,33,36,39,40,33,34,39,40,33,34,37,40,33,36,38,41,33,37,39,41,33,35,39,41,33,35,37,41,33,41,41,41,33,33,41,41,33,33,33,41,33,37,40,44,33,38,42,44,33,35,42,44,33,35,39,44,33,44,44,44,33,33,44,44,33,33,33,44,33,38,42,47,33,40,44,47,33,36,44,47,33,36,40,47,33,47,47,47,33,33,47,47,33,33,33,47,33,39,44,50,33,41,46,50,33,37,46,50,33,37,42,50,33,50,50,50,33,33,50,50,33,33,33,50,33,40,46,53,33,43,48,53,33,38,48,53,33,38,43,53,33,53,53,53,33,33,53,53,33,33,33,53,33,44,51,56,33,38,51,56,33,38,45,56,33,56,56,56,33,33,56,56,33,33,33,56,33,46,53,59,33,39,53,59,33,39,46,59,33,59,59,59,33,33,59,59,33,33,33,59,33,47,55,62,33,40,55,62,33,40,48,62,33,62,62,62,33,33,62,62,33,33,33,62,34,35,35,36,34,35,36,37,34,36,37,38,34,35,37,38,34,35,36,38,34,36,37,39,34,36,38,39,34,35,38,39,34,35,37,39,34,36,38,40,34,37,39,40,34,35,39,40,34,35,37,40,34,40,40,40,34,34,40,40,34,34,34,40,34,37,38,41,34,37,40,41,34,35,40,41,34,35,38,41,34,37,39,42,34,38,40,42,34,36,40,42,34,36,38,42,34,42,42,42,34,34,42,42,34,34,34,42,34,38,41,45,34,39,43,45,34,36,43,45,34,36,40,45,34,45,45,45,34,34,45,45,34,34,34,45,34,39,43,48,34,41,45,48,34,37,45,48,34,37,41,48,34,48,48,48,34,34,48,48,34,34,34,48,34,40,45,51,34,42,47,51,34,38,47,51,34,38,43,51,34,51,51,51,34,34,51,51,34,34,34,51,34,41,47,54,34,44,49,54,34,39,49,54,34,39,44,54,34,54,54,54,34,34,54,54,34,34,34,54,34,45,52,57,34,39,52,57,34,39,46,57,34,57,57,57,34,34,57,57,34,34,34,57,34,47,54,60,34,40,54,60,34,40,47,60,34,60,60,60,34,34,60,60,34,34,34,60,34,48,56,63,34,41,56,63,34,41,49,63,34,63,63,63,34,34,63,63,34,34,34,63,35,36,36,37,35,36,37,38,35,37,38,39,35,36,38,39,35,36,37,39,35,37,38,40,35,37,39,40,35,36,39,40,35,36,38,40,35,37,39,41,35,38,40,41,35,36,40,41,35,36,38,41,35,41,41,41,35,35,41,41,35,35,35,41,35,38,39,42,35,38,41,42,35,36,41,42,35,36,39,42,35,38,40,43,35,39,41,43,35,37,41,43,35,37,39,43,35,43,43,43,35,35,43,43,35,35,35,43,35,39,42,46,35,40,44,46,35,37,44,46,35,37,41,46,35,46,46,46,35,35,46,46,35,35,35,46,35,40,44,49,35,42,46,49,35,38,46,49,35,38,42,49,35,49,49,49,35,35,49,49,35,35,35,49,35,41,46,52,35,43,48,52,35,39,48,52,35,39,44,52,35,52,52,52,35,35,52,52,35,35,35,52,35,42,48,55,35,45,50,55,35,40,50,55,35,40,45,55,35,55,55,55,35,35,55,55,35,35,35,55,35,46,53,58,35,40,53,58,35,40,47,58,35,58,58,58,35,35,58,58,35,35,35,58,35,48,55,61,35,41,55,61,35,41,48,61,35,61,61,61,35,35,61,61,35,35,35,61,36,37,37,38,36,37,38,39,36,38,39,40,36,37,39,40,36,37,38,40,36,38,39,41,36,38,40,41,36,37,40,41,36,37,39,41,36,38,40,42,36,39,41,42,36,37,41,42,36,37,39,42,36,42,42,42,36,36,42,42,36,36,36,42,36,39,40,43,36,39,42,43,36,37,42,43,36,37,40,43,36,39,41,44,36,40,42,44,36,38,42,44,36,38,40,44,36,44,44,44,36,36,44,44,36,36,36,44,36,40,43,47,36,41,45,47,36,38,45,47,36,38,42,47,36,47,47,47,36,36,47,47,36,36,36,47,36,41,45,50,36,43,47,50,36,39,47,50,36,39,43,50,36,50,50,50,36,36,50,50,36,36,36,50,36,42,47,53,36,44,49,53,36,40,49,53,36,40,45,53,36,53,53,53,36,36,53,53,36,36,36,53,36,43,49,56,36,46,51,56,36,41,51,56,36,41,46,56,36,56,56,56,36,36,56,56,36,36,36,56,36,47,54,59,36,41,54,59,36,41,48,59,36,59,59,59,36,36,59,59,36,36,36,59,36,49,56,62,36,42,56,62,36,42,49,62,36,62,62,62,36,36,62,62,36,36,36,62,37,38,38,39,37,38,39,40,37,39,40,41,37,38,40,41,37,38,39,41,37,39,40,42,37,39,41,42,37,38,41,42,37,38,40,42,37,39,41,43,37,40,42,43,37,38,42,43,37,38,40,43,37,43,43,43,37,37,43,43,37,37,37,43,37,40,41,44,37,40,43,44,37,38,43,44,37,38,41,44,37,40,42,45,37,41,43,45,37,39,43,45,37,39,41,45,37,45,45,45,37,37,45,45,37,37,37,45,37,41,44,48,37,42,46,48,37,39,46,48,37,39,43,48,37,48,48,48,37,37,48,48,37,37,37,48,37,42,46,51,37,44,48,51,37,40,48,51,37,40,44,51,37,51,51,51,37,37,51,51,37,37,37,51,37,43,48,54,37,45,50,54,37,41,50,54,37,41,46,54,37,54,54,54,37,37,54,54,37,37,37,54,37,44,50,57,37,47,52,57,37,42,52,57,37,42,47,57,37,57,57,57,37,37,57,57,37,37,37,57,37,48,55,60,37,42,55,60,37,42,49,60,37,60,60,60,37,37,60,60,37,37,37,60,37,50,57,63,37,43,57,63,37,43,50,63,37,63,63,63,37,37,63,63,37,37,37,63,38,39,39,40,38,39,40,41,38,40,41,42,38,39,41,42,38,39,40,42,38,40,41,43,38,40,42,43,38,39,42,43,38,39,41,43,38,40,42,44,38,41,43,44,38,39,43,44,38,39,41,44,38,44,44,44,38,38,44,44,38,38,38,44,38,41,42,45,38,41,44,45,38,39,44,45,38,39,42,45,38,41,43,46,38,42,44,46,38,40,44,46,38,40,42,46,38,46,46,46,38,38,46,46,38,38,38,46,38,42,45,49,38,43,47,49,38,40,47,49,38,40,44,49,38,49,49,49,38,38,49,49,38,38,38,49,38,43,47,52,38,45,49,52,38,41,49,52,38,41,45,52,38,52,52,52,38,38,52,52,38,38,38,52,38,44,49,55,38,46,51,55,38,42,51,55,38,42,47,55,38,55,55,55,38,38,55,55,38,38,38,55,38,45,51,58,38,48,53,58,38,43,53,58,38,43,48,58,38,58,58,58,38,38,58,58,38,38,38,58,38,49,56,61,38,43,56,61,38,43,50,61,38,61,61,61,38,38,61,61,38,38,38,61,39,40,40,41,39,40,41,42,39,41,42,43,39,40,42,43,39,40,41,43,39,41,42,44,39,41,43,44,39,40,43,44,39,40,42,44,39,41,43,45,39,42,44,45,39,40,44,45,39,40,42,45,39,45,45,45,39,39,45,45,39,39,39,45,39,42,43,46,39,42,45,46,39,40,45,46,39,40,43,46,39,42,44,47,39,43,45,47,39,41,45,47,39,41,43,47,39,47,47,47,39,39,47,47,39,39,39,47,39,43,46,50,39,44,48,50,39,41,48,50,39,41,45,50,39,50,50,50,39,39,50,50,39,39,39,50,39,44,48,53,39,46,50,53,39,42,50,53,39,42,46,53,39,53,53,53,39,39,53,53,39,39,39,53,39,45,50,56,39,47,52,56,39,43,52,56,39,43,48,56,39,56,56,56,39,39,56,56,39,39,39,56,39,46,52,59,39,49,54,59,39,44,54,59,39,44,49,59,39,59,59,59,39,39,59,59,39,39,39,59,39,50,57,62,39,44,57,62,39,44,51,62,39,62,62,62,39,39,62,62,39,39,39,62,40,41,41,42,40,41,42,43,40,42,43,44,40,41,43,44,40,41,42,44,40,42,43,45,40,42,44,45,40,41,44,45,40,41,43,45,40,42,44,46,40,43,45,46,40,41,45,46,40,41,43,46,40,46,46,46,40,40,46,46,40,40,40,46,40,43,44,47,40,43,46,47,40,41,46,47,40,41,44,47,40,43,45,48,40,44,46,48,40,42,46,48,40,42,44,48,40,48,48,48,40,40,48,48,40,40,40,48,40,44,47,51,40,45,49,51,40,42,49,51,40,42,46,51,40,51,51,51,40,40,51,51,40,40,40,51,40,45,49,54,40,47,51,54,40,43,51,54,40,43,47,54,40,54,54,54,40,40,54,54,40,40,40,54,40,46,51,57,40,48,53,57,40,44,53,57,40,44,49,57,40,57,57,57,40,40,57,57,40,40,40,57,40,47,53,60,40,50,55,60,40,45,55,60,40,45,50,60,40,60,60,60,40,40,60,60,40,40,40,60,40,51,58,63,40,45,58,63,40,45,52,63,40,63,63,63,40,40,63,63,40,40,40,63,41,42,42,43,41,42,43,44,41,43,44,45,41,42,44,45,41,42,43,45,41,43,44,46,41,43,45,46,41,42,45,46,41,42,44,46,41,43,45,47,41,44,46,47,41,42,46,47,41,42,44,47,41,47,47,47,41,41,47,47,41,41,41,47,41,44,45,48,41,44,47,48,41,42,47,48,41,42,45,48,41,44,46,49,41,45,47,49,41,43,47,49,41,43,45,49,41,49,49,49,41,41,49,49,41,41,41,49,41,45,48,52,41,46,50,52,41,43,50,52,41,43,47,52,41,52,52,52,41,41,52,52,41,41,41,52,41,46,50,55,41,48,52,55,41,44,52,55,41,44,48,55,41,55,55,55,41,41,55,55,41,41,41,55,41,47,52,58,41,49,54,58,41,45,54,58,41,45,50,58,41,58,58,58,41,41,58,58,41,41,41,58,41,48,54,61,41,51,56,61,41,46,56,61,41,46,51,61,41,61,61,61,41,41,61,61,41,41,41,61,42,43,43,44,42,43,44,45,42,44,45,46,42,43,45,46,42,43,44,46,42,44,45,47,42,44,46,47,42,43,46,47,42,43,45,47,42,44,46,48,42,45,47,48,42,43,47,48,42,43,45,48,42,48,48,48,42,42,48,48,42,42,42,48,42,45,46,49,42,45,48,49,42,43,48,49,42,43,46,49,42,45,47,50,42,46,48,50,42,44,48,50,42,44,46,50,42,50,50,50,42,42,50,50,42,42,42,50,42,46,49,53,42,47,51,53,42,44,51,53,42,44,48,53,42,53,53,53,42,42,53,53,42,42,42,53,42,47,51,56,42,49,53,56,42,45,53,56,42,45,49,56,42,56,56,56,42,42,56,56,42,42,42,56,42,48,53,59,42,50,55,59,42,46,55,59,42,46,51,59,42,59,59,59,42,42,59,59,42,42,42,59,42,49,55,62,42,52,57,62,42,47,57,62,42,47,52,62,42,62,62,62,42,42,62,62,42,42,42,62,43,44,44,45,43,44,45,46,43,45,46,47,43,44,46,47,43,44,45,47,43,45,46,48,43,45,47,48,43,44,47,48,43,44,46,48,43,45,47,49,43,46,48,49,43,44,48,49,43,44,46,49,43,49,49,49,43,43,49,49,43,43,43,49,43,46,47,50,43,46,49,50,43,44,49,50,43,44,47,50,43,46,48,51,43,47,49,51,43,45,49,51,43,45,47,51,43,51,51,51,43,43,51,51,43,43,43,51,43,47,50,54,43,48,52,54,43,45,52,54,43,45,49,54,43,54,54,54,43,43,54,54,43,43,43,54,43,48,52,57,43,50,54,57,43,46,54,57,43,46,50,57,43,57,57,57,43,43,57,57,43,43,43,57,43,49,54,60,43,51,56,60,43,47,56,60,43,47,52,60,43,60,60,60,43,43,60,60,43,43,43,60,43,50,56,63,43,53,58,63,43,48,58,63,43,48,53,63,43,63,63,63,43,43,63,63,43,43,43,63,44,45,45,46,44,45,46,47,44,46,47,48,44,45,47,48,44,45,46,48,44,46,47,49,44,46,48,49,44,45,48,49,44,45,47,49,44,46,48,50,44,47,49,50,44,45,49,50,44,45,47,50,44,50,50,50,44,44,50,50,44,44,44,50,44,47,48,51,44,47,50,51,44,45,50,51,44,45,48,51,44,47,49,52,44,48,50,52,44,46,50,52,44,46,48,52,44,52,52,52,44,44,52,52,44,44,44,52,44,48,51,55,44,49,53,55,44,46,53,55,44,46,50,55,44,55,55,55,44,44,55,55,44,44,44,55,44,49,53,58,44,51,55,58,44,47,55,58,44,47,51,58,44,58,58,58,44,44,58,58,44,44,44,58,44,50,55,61,44,52,57,61,44,48,57,61,44,48,53,61,44,61,61,61,44,44,61,61,44,44,44,61,45,46,46,47,45,46,47,48,45,47,48,49,45,46,48,49,45,46,47,49,45,47,48,50,45,47,49,50,45,46,49,50,45,46,48,50,45,47,49,51,45,48,50,51,45,46,50,51,45,46,48,51,45,51,51,51,45,45,51,51,45,45,45,51,45,48,49,52,45,48,51,52,45,46,51,52,45,46,49,52,45,48,50,53,45,49,51,53,45,47,51,53,45,47,49,53,45,53,53,53,45,45,53,53,45,45,45,53,45,49,52,56,45,50,54,56,45,47,54,56,45,47,51,56,45,56,56,56,45,45,56,56,45,45,45,56,45,50,54,59,45,52,56,59,45,48,56,59,45,48,52,59,45,59,59,59,45,45,59,59,45,45,45,59,45,51,56,62,45,53,58,62,45,49,58,62,45,49,54,62,45,62,62,62,45,45,62,62,45,45,45,62,46,47,47,48,46,47,48,49,46,48,49,50,46,47,49,50,46,47,48,50,46,48,49,51,46,48,50,51,46,47,50,51,46,47,49,51,46,48,50,52,46,49,51,52,46,47,51,52,46,47,49,52,46,52,52,52,46,46,52,52,46,46,46,52,46,49,50,53,46,49,52,53,46,47,52,53,46,47,50,53,46,49,51,54,46,50,52,54,46,48,52,54,46,48,50,54,46,54,54,54,46,46,54,54,46,46,46,54,46,50,53,57,46,51,55,57,46,48,55,57,46,48,52,57,46,57,57,57,46,46,57,57,46,46,46,57,46,51,55,60,46,53,57,60,46,49,57,60,46,49,53,60,46,60,60,60,46,46,60,60,46,46,46,60,46,52,57,63,46,54,59,63,46,50,59,63,46,50,55,63,46,63,63,63,46,46,63,63,46,46,46,63,47,48,48,49,47,48,49,50,47,49,50,51,47,48,50,51,47,48,49,51,47,49,50,52,47,49,51,52,47,48,51,52,47,48,50,52,47,49,51,53,47,50,52,53,47,48,52,53,47,48,50,53,47,53,53,53,47,47,53,53,47,47,47,53,47,50,51,54,47,50,53,54,47,48,53,54,47,48,51,54,47,50,52,55,47,51,53,55,47,49,53,55,47,49,51,55,47,55,55,55,47,47,55,55,47,47,47,55,47,51,54,58,47,52,56,58,47,49,56,58,47,49,53,58,47,58,58,58,47,47,58,58,47,47,47,58,47,52,56,61,47,54,58,61,47,50,58,61,47,50,54,61,47,61,61,61,47,47,61,61,47,47,47,61,48,49,49,50,48,49,50,51,48,50,51,52,48,49,51,52,48,49,50,52,48,50,51,53,48,50,52,53,48,49,52,53,48,49,51,53,48,50,52,54,48,51,53,54,48,49,53,54,48,49,51,54,48,54,54,54,48,48,54,54,48,48,48,54,48,51,52,55,48,51,54,55,48,49,54,55,48,49,52,55,48,51,53,56,48,52,54,56,48,50,54,56,48,50,52,56,48,56,56,56,48,48,56,56,48,48,48,56,48,52,55,59,48,53,57,59,48,50,57,59,48,50,54,59,48,59,59,59,48,48,59,59,48,48,48,59,48,53,57,62,48,55,59,62,48,51,59,62,48,51,55,62,48,62,62,62,48,48,62,62,48,48,48,62,49,50,50,51,49,50,51,52,49,51,52,53,49,50,52,53,49,50,51,53,49,51,52,54,49,51,53,54,49,50,53,54,49,50,52,54,49,51,53,55,49,52,54,55,49,50,54,55,49,50,52,55,49,55,55,55,49,49,55,55,49,49,49,55,49,52,53,56,49,52,55,56,49,50,55,56,49,50,53,56,49,52,54,57,49,53,55,57,49,51,55,57,49,51,53,57,49,57,57,57,49,49,57,57,49,49,49,57,49,53,56,60,49,54,58,60,49,51,58,60,49,51,55,60,49,60,60,60,49,49,60,60,49,49,49,60,49,54,58,63,49,56,60,63,49,52,60,63,49,52,56,63,49,63,63,63,49,49,63,63,49,49,49,63,50,51,51,52,50,51,52,53,50,52,53,54,50,51,53,54,50,51,52,54,50,52,53,55,50,52,54,55,50,51,54,55,50,51,53,55,50,52,54,56,50,53,55,56,50,51,55,56,50,51,53,56,50,56,56,56,50,50,56,56,50,50,50,56,50,53,54,57,50,53,56,57,50,51,56,57,50,51,54,57,50,53,55,58,50,54,56,58,50,52,56,58,50,52,54,58,50,58,58,58,50,50,58,58,50,50,50,58,50,54,57,61,50,55,59,61,50,52,59,61,50,52,56,61,50,61,61,61,50,50,61,61,50,50,50,61,51,52,52,53,51,52,53,54,51,53,54,55,51,52,54,55,51,52,53,55,51,53,54,56,51,53,55,56,51,52,55,56,51,52,54,56,51,53,55,57,51,54,56,57,51,52,56,57,51,52,54,57,51,57,57,57,51,51,57,57,51,51,51,57,51,54,55,58,51,54,57,58,51,52,57,58,51,52,55,58,51,54,56,59,51,55,57,59,51,53,57,59,51,53,55,59,51,59,59,59,51,51,59,59,51,51,51,59,51,55,58,62,51,56,60,62,51,53,60,62,51,53,57,62,51,62,62,62,51,51,62,62,51,51,51,62,52,53,53,54,52,53,54,55,52,54,55,56,52,53,55,56,52,53,54,56,52,54,55,57,52,54,56,57,52,53,56,57,52,53,55,57,52,54,56,58,52,55,57,58,52,53,57,58,52,53,55,58,52,58,58,58,52,52,58,58,52,52,52,58,52,55,56,59,52,55,58,59,52,53,58,59,52,53,56,59,52,55,57,60,52,56,58,60,52,54,58,60,52,54,56,60,52,60,60,60,52,52,60,60,52,52,52,60,52,56,59,63,52,57,61,63,52,54,61,63,52,54,58,63,52,63,63,63,52,52,63,63,52,52,52,63,53,54,54,55,53,54,55,56,53,55,56,57,53,54,56,57,53,54,55,57,53,55,56,58,53,55,57,58,53,54,57,58,53,54,56,58,53,55,57,59,53,56,58,59,53,54,58,59,53,54,56,59,53,59,59,59,53,53,59,59,53,53,53,59,53,56,57,60,53,56,59,60,53,54,59,60,53,54,57,60,53,56,58,61,53,57,59,61,53,55,59,61,53,55,57,61,53,61,61,61,53,53,61,61,53,53,53,61,54,55,55,56,54,55,56,57,54,56,57,58,54,55,57,58,54,55,56,58,54,56,57,59,54,56,58,59,54,55,58,59,54,55,57,59,54,56,58,60,54,57,59,60,54,55,59,60,54,55,57,60,54,60,60,60,54,54,60,60,54,54,54,60,54,57,58,61,54,57,60,61,54,55,60,61,54,55,58,61,54,57,59,62,54,58,60,62,54,56,60,62,54,56,58,62,54,62,62,62,54,54,62,62,54,54,54,62,55,56,56,57,55,56,57,58,55,57,58,59,55,56,58,59,55,56,57,59,55,57,58,60,55,57,59,60,55,56,59,60,55,56,58,60,55,57,59,61,55,58,60,61,55,56,60,61,55,56,58,61,55,61,61,61,55,55,61,61,55,55,55,61,55,58,59,62,55,58,61,62,55,56,61,62,55,56,59,62,55,58,60,63,55,59,61,63,55,57,61,63,55,57,59,63,55,63,63,63,55,55,63,63,55,55,55,63,56,57,57,58,56,57,58,59,56,58,59,60,56,57,59,60,56,57,58,60,56,58,59,61,56,58,60,61,56,57,60,61,56,57,59,61,56,58,60,62,56,59,61,62,56,57,61,62,56,57,59,62,56,62,62,62,56,56,62,62,56,56,56,62,56,59,60,63,56,59,62,63,56,57,62,63,56,57,60,63,57,58,58,59,57,58,59,60,57,59,60,61,57,58,60,61,57,58,59,61,57,59,60,62,57,59,61,62,57,58,61,62,57,58,60,62,57,59,61,63,57,60,62,63,57,58,62,63,57,58,60,63,57,63,63,63,57,57,63,63,57,57,57,63,58,59,59,60,58,59,60,61,58,60,61,62,58,59,61,62,58,59,60,62,58,60,61,63,58,60,62,63,58,59,62,63,58,59,61,63,59,60,60,61,59,60,61,62,59,61,62,63,59,60,62,63,59,60,61,63,60,61,61,62,60,61,62,63,61,62,62,63,96,103,109,115,122,128,134,141,147,153,160,166,172,179,185,192,240,141,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,62,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,50,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,90,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,76,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,116,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,104,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,4,8,1,1,2,4,8,4,8,4,0,0,0,1,100,2,4,8,1,1,2,4,8,4,8,4,0,0,0,1,100,2,4,8,1,1,2,4,8,4,8,4,0,0,0,1,100,2,4,8,1,1,2,4,8,4,8,4,0,0,0,0,128,191,154,6,28,191,171,170,170,190,137,98,13,190,0,0,0,0,137,98,13,62,171,170,170,62,154,6,28,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,32,191,85,85,149,190,0,0,0,0,0,0,128,62,0,0,0,63,0,0,64,63,0,0,128,63,144,34,30,0,108,0,0,0,16,60,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,168,34,0,108,0,0,0,128,113,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,63,1,0,0,0,0,0,0,207,6,0,0,0,0,0,0,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,143,2,93,3,106,4,215,3,11,5,159,6,31,5,185,6,212,8,102,6,103,8,9,11,174,7,22,10,62,13,246,8,196,11,115,15,61,10,114,13,168,17,133,11,32,15,221,19,205,12,207,16,18,22,20,14,125,18,71,24,92,15,43,20,124,26,164,16,217,21,177,28,236,17,136,23,230,30,0,0,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,35,0,3,0,49,0,33,0,17,0,83,0,19,0,1,0,9,0,41,0,51,0,25,0,11,0,5,0,7,0,0,0,48,0,34,0,40,0,32,0,8,0,0,0,50,0,114,0,16,0,2,0,18,0,24,0,10,0,4,0,6,0,1,0,50,0,56,0,32,0,8,0,2,0,24,0,114,0,0,0,40,0,34,0,18,0,16,0,10,0,4,0,6,0,1,0,50,0,16,0,114,0,48,0,34,0,56,0,8,0,40,0,24,0,2,0,18,0,0,0,10,0,4,0,6,0,1,0,18,0,82,0,0,0,32,0,24,0,34,0,8,0,40,0,56,0,2,0,50,0,16,0,10,0,4,0,6,0,1,0,22,0,150,0,6,0,70,0,86,0,2,0,54,0,118,0,18,0,34,0,50,0,38,0,10,0,14,0,0,0,1,0,26,0,154,0,50,0,114,0,90,0,122,0,58,0,2,0,18,0,34,0,10,0,42,0,6,0,14,0,0,0,1,0,42,0,170,0,2,0,66,0,106,0,58,0,122,0,34,0,50,0,18,0,10,0,26,0,6,0,14,0,0,0,1,0,66,0,194,0,2,0,10,0,74,0,58,0,122,0,34,0,18,0,50,0,42,0,26,0,6,0,14,0,0,0,1,0,186,0,186,1,58,0,18,0,82,0,122,0,2,0,34,0,50,0,10,0,42,0,26,0,0,0,4,0,6,0,1,0,170,0,170,1,42,0,34,0,98,0,106,0,2,0,18,0,50,0,10,0,26,0,58,0,0,0,4,0,6,0,1,0,170,0,170,1,42,0,34,0,98,0,106,0,2,0,18,0,50,0,10,0,58,0,26,0,0,0,4,0,6,0,1,0,138,0,138,1,10,0,34,0,98,0,74,0,2,0,18,0,50,0,42,0,26,0,58,0,0,0,4,0,6,0,1,0,6,6,6,6,6,7,7,6,6,6,6,5,4,3,3,1,6,6,6,6,6,6,7,7,6,6,6,5,4,3,3,1,7,6,6,6,6,6,7,6,6,6,6,5,4,3,3,1,7,6,7,6,6,6,6,6,6,6,6,5,4,3,3,1,7,7,6,6,6,6,6,6,6,6,6,5,4,3,3,1,8,8,7,7,7,6,7,7,6,6,6,6,4,4,2,1,8,8,7,7,7,7,7,6,6,6,6,6,4,4,2,1,8,8,7,7,7,7,7,6,6,6,6,6,4,4,2,1,8,8,7,7,7,7,7,6,6,6,6,6,4,4,2,1,9,9,8,7,7,7,6,6,6,6,6,6,3,3,3,1,9,9,8,7,7,7,6,6,6,6,6,6,3,3,3,1,9,9,8,7,7,7,6,6,6,6,6,6,3,3,3,1,9,9,8,7,7,7,6,6,6,6,6,6,3,3,3,1,0,1,255,0,254,0,253,0,252,0,251,0,250,0,249,0,248,0,247,0,246,0,245,0,244,0,243,0,242,0,241,0,240,0,239,0,238,0,237,0,236,0,235,0,234,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,0,10,0,0,0,6,0,46,0,2,0,14,0,26,0,126,0,78,0,90,0,226,0,190,1,186,1,186,0,114,0,34,0,190,2,190,0,58,3,242,3,242,1,162,3,34,1,34,3,162,1,114,1,114,3,58,1,206,0,206,2,254,2,254,0,162,0,242,0,58,0,206,1,254,1,98,0,218,0,62,0,50,0,122,0,18,0,30,0,22,0,4,0,1,0,0,0,5,3,5,6,6,7,7,8,8,8,8,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,9,9,9,9,9,8,8,8,7,7,6,6,5,3,1,0,208,102,28,0,112,99,28,0,40,96,28,0,240,92,28,0,88,90,28,0,192,87,28,0,40,85,28,0,168,82,28,0,56,80,28,0,240,77,28,0,192,75,28,0,184,73,28,0,216,71,28,0,0,0,0,0,172,0,0,0,169,0,0,0,165,0,0,0,162,0,0,0,131,0,0,0,132,0,0,0,130,0,0,0,125,0,0,0,121,0,0,0,114,0,0,0,110,0,0,0,101,0,0,0,96,0,0,0,0,0,0,0,40,104,28,0,200,100,28,0,120,97,28,0,56,94,28,0,96,91,28,0,200,88,28,0,48,86,28,0,168,83,28,0,48,81,28,0,216,78,28,0,160,76,28,0,136,74,28,0,152,72,28,0,0,0,0,0,128,105,28,0,32,102,28,0,200,98,28,0,128,95,28,0,104,92,28,0,208,89,28,0,56,87,28,0,168,84,28,0,40,82,28,0,192,79,28,0,128,77,28,0,88,75,28,0,88,73,28,0,0,0,0,0,70,14,204,12,109,11,40,10,252,8,232,7,235,6,4,6,50,5,116,4,201,3,48,3,168,2,48,2,199,1,108,1,30,1,220,0,165,0,120,0,84,0,56,0,35,0,20,0,10,0,4,0,1,0,0,0,0,0,0,0,150,1,122,1,95,1,69,1,44,1,20,1,253,0,231,0,210,0,190,0,171,0,153,0,136,0,120,0,105,0,91,0,78,0,66,0,55,0,45,0,36,0,28,0,21,0,15,0,10,0,6,0,3,0,1,0,0,0,0,0,29,0,28,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,6,0,254,255,250,255,4,0,12,0,252,255,244,255,6,0,18,0,250,255,238,255,10,0,30,0,246,255,226,255,16,0,48,0,240,255,208,255,25,0,75,0,231,255,181,255,40,0,120,0,216,255,136,255,64,0,192,0,192,255,64,255,101,0,47,1,155,255,209,254,161,0,227,1,95,255,29,254,0,1,0,3,0,255,0,253,150,1,194,4,106,254,62,251,133,2,143,7,123,253,113,248,0,4,0,12,0,252,0,244,89,6,11,19,167,249,245,236,20,10,60,30,236,245,196,225,47,237,57,82,241,84,169,228,32,38,62,238,214,9,64,44,181,239,224,43,225,63,57,51,47,68,254,230,88,68,223,249,49,242,219,67,176,61,5,247,123,79,251,254,173,38,220,12,194,51,57,7,190,18,162,67,223,27,62,31,17,2,150,7,235,42,63,22,13,5,56,58,30,13,120,13,15,21,70,51,164,56,125,11,93,45,223,31,183,25,34,40,153,13,18,31,76,25,230,12,0,0,0,0,240,206,249,228,187,246,70,6,245,20,255,35,111,53,141,74,80,181,37,200,128,217,151,233,131,248,82,7,17,24,24,46,27,213,46,241,46,4,199,19,96,34,27,49,222,64,133,83,231,171,168,187,28,200,38,211,14,221,212,229,34,238,24,246,40,254,79,6,183,14,184,23,170,33,139,45,162,59,249,77,84,198,242,222,170,239,148,253,106,9,63,20,123,30,44,40,118,49,137,58,159,67,162,76,127,85,80,94,24,103,141,111,248,150,180,163,69,175,83,186,177,196,204,206,111,216,30,226,243,235,64,246,247,0,32,12,129,24,154,38,107,55,96,77,101,159,107,181,131,197,113,211,24,224,180,235,28,246,89,255,91,8,6,17,82,25,74,33,201,40,248,47,230,54,146,61,223,67,187,73,70,79,103,84,48,89,163,93,236,97,249,101,212,105,90,109,158,112,173,115,107,118,240,120,90,123,165,125,64,130,100,131,206,132,93,134,5,136,222,137,215,139,244,141,81,144,226,146,222,149,15,153,129,156,121,160,76,165,210,170,138,177,10,185,36,193,204,201,57,211,211,221,214,233,147,248,111,9,202,26,236,41,31,56,249,69,106,84,195,99,181,115,192,48,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,38,32,0,64,70,31,0,16,0,0,0,32,82,85,68,255,255,255,255,255,255,255,127,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,240,147,30,0,144,1,30,0,24,0,0,0,32,82,85,68,255,255,255,255,255,255,255,127,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,24,148,29,0,176,53,29,0,72,0,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,152,229,28,0,144,1,30,0,80,0,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,40,224,35,0,168,145,35,0,8,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,0,184,32,0,208,161,32,0,32,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,48,136,32,0,136,111,32,0,40,0,0,0,2,0,0,0,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,232,55,34,0,40,7,34,0,56,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,176,216,33,0,0,180,33,0,64,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,208,146,33,0,40,113,33,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,48,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,224,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,29,34,0,108,0,0,0,160,200,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,201,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,56,153,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,32,129,32,0,136,102,32,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,32,129,32,0,112,82,32,0,40,48,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,8,255,31,0,72,233,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,152,213,31,0,120,194,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,144,172,31,0,168,154,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,88,137,31,0,240,195,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,72,106,31,0,240,195,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,96,181,30,0,120,155,30,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,48,121,30,0,120,155,30,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,15,31,0,108,0,0,0,88,203,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,255,32,0,56,234,31,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,64,16,0,1,0,208,255,32,0,104,26,31,0,176,108,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,255,32,0,200,227,29,0,120,119,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,255,32,0,240,31,29,0,184,206,28,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,255,32,0,144,203,35,0,136,119,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,255,32,0,40,29,35,0,128,216,34,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,40,29,35,0,112,156,34,0,248,95,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,40,29,35,0,120,40,34,0,136,248,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,40,29,35,0,48,207,33,0,24,168,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,40,29,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,230,31,0,108,0,0,0,200,205,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,2,0,0,200,0,0,0,1,0,0,0,254,1,0,0,200,0,0,0,0,0,0,0,142,0,0,0,200,0,0,0,0,0,0,0,138,0,0,0,200,2,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+174080);
/* memory initializer */ allocate([150,0,0,0,4,0,0,0,1,0,0,0,158,1,0,0,204,0,0,0,1,0,0,0,24,3,0,0,186,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,0,0,200,0,0,0,1,0,0,0,202,2,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,200,0,0,0,0,0,0,0,140,0,0,0,200,0,0,0,0,0,0,0,160,1,0,0,204,0,0,0,0,0,0,0,26,3,0,0,186,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,90,90,88,85,82,78,73,67,61,54,46,38,31,22,13,4,252,243,234,225,218,210,202,195,189,183,178,174,171,168,166,166,90,87,80,70,57,43,25,9,247,231,213,199,186,176,169,166,166,169,176,186,199,213,231,247,9,25,43,57,70,80,87,90,90,82,67,46,22,252,225,202,183,171,166,168,178,195,218,243,13,38,61,78,88,90,85,73,54,31,4,234,210,189,174,166,89,75,50,18,238,206,181,167,167,181,206,238,18,50,75,89,89,75,50,18,238,206,181,167,167,181,206,238,18,50,75,89,88,67,31,243,202,174,166,178,210,252,38,73,90,85,61,22,234,195,171,166,183,218,4,46,78,90,82,54,13,225,189,168,87,57,9,213,176,166,186,231,25,70,90,80,43,247,199,169,169,199,247,43,80,90,70,25,231,186,166,176,213,9,57,87,85,46,243,189,166,183,234,38,82,88,54,252,195,166,178,225,31,78,90,61,4,202,168,174,218,22,73,90,67,13,210,171,83,36,220,173,173,220,36,83,83,36,220,173,173,220,36,83,83,36,220,173,173,220,36,83,83,36,220,173,173,220,36,83,82,22,202,166,195,13,78,85,31,210,166,189,4,73,88,38,218,168,183,252,67,90,46,225,171,178,243,61,90,54,234,174,80,9,186,169,231,57,90,43,213,166,199,25,87,70,247,176,176,247,70,87,25,199,166,213,43,90,57,231,169,186,9,80,78,252,174,183,13,85,67,234,168,195,31,90,54,218,166,210,46,90,38,202,166,225,61,88,22,189,171,243,73,82,4,178,75,238,167,206,50,89,18,181,181,18,89,50,206,167,238,75,75,238,167,206,50,89,18,181,181,18,89,50,206,167,238,75,73,225,166,234,78,67,218,166,243,82,61,210,168,252,85,54,202,171,4,88,46,195,174,13,90,38,189,178,22,90,31,183,70,213,169,9,90,25,176,199,57,80,231,166,247,87,43,186,186,43,87,247,166,231,80,57,199,176,25,90,9,169,213,70,67,202,178,38,85,234,166,4,90,13,168,225,82,46,183,195,61,73,210,174,31,88,243,166,252,90,22,171,218,78,54,189,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,61,183,210,82,31,168,243,90,252,166,22,85,218,178,54,67,189,202,78,38,171,234,90,4,166,13,88,225,174,46,73,195,57,176,231,90,247,169,43,70,186,213,87,9,166,25,80,199,199,80,25,166,9,87,213,186,70,43,169,247,90,231,176,57,54,171,252,88,210,195,82,13,166,38,67,178,234,90,225,183,73,31,166,22,78,189,218,90,243,174,61,46,168,4,85,202,50,167,18,75,181,238,89,206,206,89,238,181,75,18,167,50,50,167,18,75,181,238,89,206,206,89,238,181,75,18,167,50,46,166,38,54,166,31,61,168,22,67,171,13,73,174,4,78,178,252,82,183,243,85,189,234,88,195,225,90,202,218,90,210,43,166,57,25,169,70,9,176,80,247,186,87,231,199,90,213,213,90,199,231,87,186,247,80,176,9,70,169,25,57,166,43,38,168,73,252,189,90,210,225,85,178,13,61,166,54,22,174,82,234,202,90,195,243,78,171,31,46,166,67,4,183,88,218,36,173,83,220,220,83,173,36,36,173,83,220,220,83,173,36,36,173,83,220,220,83,173,36,36,173,83,220,220,83,173,36,31,178,90,195,4,54,168,82,218,234,73,166,67,243,210,85,171,46,13,189,90,183,22,38,174,88,202,252,61,166,78,225,25,186,90,176,43,9,199,87,169,57,247,213,80,166,70,231,231,70,166,80,213,247,57,169,87,199,9,43,176,90,186,25,22,195,85,166,73,218,252,46,178,90,174,54,243,225,67,168,88,189,31,13,202,82,166,78,210,4,38,183,90,171,61,234,18,206,75,167,89,181,50,238,238,50,181,89,167,75,206,18,18,206,75,167,89,181,50,238,238,50,181,89,167,75,206,18,13,218,61,178,88,166,85,183,54,225,4,22,210,67,174,90,166,82,189,46,234,252,31,202,73,171,90,168,78,195,38,243,9,231,43,199,70,176,87,166,90,169,80,186,57,213,25,247,247,25,213,57,186,80,169,90,166,87,176,70,199,43,231,9,4,243,22,225,38,210,54,195,67,183,78,174,85,168,90,166,90,166,88,171,82,178,73,189,61,202,46,218,31,234,13,252,0,2,0,3,0,2,0,3,1,3,2,4,1,4,1,4,1,3,3,4,4,5,5,6,6,7,7,8,8,9,9,9,3,3,3,3,3,4,4,4,4,5,5,6,6,6,6,0,4,3,3,3,4,4,3,3,4,5,5,6,5,6,0,0,5,3,4,4,3,3,3,4,3,4,5,5,5,0,0,0,4,4,4,3,3,3,3,3,4,5,4,5,0,0,0,0,6,5,3,3,3,3,3,3,4,3,6,0,0,0,0,0,6,5,3,3,3,2,3,4,3,6,0,0,0,0,0,0,6,4,5,3,2,2,3,3,6,0,0,0,0,0,0,0,6,6,4,2,2,3,2,5,0,0,0,0,0,0,0,0,5,5,3,2,2,2,4,0,0,0,0,0,0,0,0,0,4,4,3,3,1,3,0,0,0,0,0,0,0,0,0,0,4,4,2,1,3,0,0,0,0,0,0,0,0,0,0,0,3,3,1,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,2,3,2,3,2,3,2,3,2,3,2,3,2,1,7,6,5,4,3,5,4,3,2,3,2,3,2,1,0,0,5,7,6,5,4,3,4,3,2,3,2,1,1,0,0,0,3,7,5,4,6,5,4,3,3,2,2,1,0,0,0,0,5,4,3,7,6,5,4,3,2,1,1,0,0,0,0,0,1,1,7,6,5,4,3,2,1,1,0,0,0,0,0,0,1,1,5,4,3,3,2,1,1,0,0,0,0,0,0,0,1,1,1,3,3,2,2,1,0,0,0,0,0,0,0,0,1,0,1,3,2,1,1,1,0,0,0,0,0,0,0,0,1,0,1,3,2,1,1,0,0,0,0,0,0,0,0,0,0,1,1,2,1,3,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,1,5,255,255,5,7,7,4,1,255,255,4,6,6,0,0,0,0,0,206,230,84,190,201,63,208,190,24,121,22,191,81,119,44,63,66,196,6,63,171,244,184,62,213,40,60,62,0,0,0,0,2,38,222,190,186,141,36,63,68,29,175,62,0,0,0,0,206,230,84,190,201,63,208,190,24,121,22,191,189,62,62,191,215,179,93,191,113,120,115,191,253,152,126,191,111,232,126,63,52,58,118,63,108,41,101,63,219,74,76,63,81,119,44,63,66,196,6,63,171,244,184,62,213,40,60,62,0,0,0,0,2,38,222,190,28,38,72,191,224,148,121,191,92,28,124,63,215,179,93,63,186,141,36,63,68,29,175,62,64,215,2,0,0,215,2,0,240,214,2,0,208,214,2,0,0,0,2,0,6,0,7,0,2,0,6,0,7,0,0,0,6,0,7,0,0,0,2,0,0,0,1,0,2,0,3,0,1,2,3,3,2,3,3,1,3,3,1,2,2,2,2,2,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,0,0,0,0,116,0,105,0,109,0,101,0,108,0,105,0,110,0,101,0,46,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,104,0,101,0,97,0,100,0,101,0,114,0,46,0,69,0,118,0,101,0,110,0,116,0,115,0,0,0,0,0,136,40,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,3,0,0,70,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,26,31,0,224,108,30,0,4,0,0,0,69,90,73,83,208,227,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,144,119,29,0,248,31,29,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,216,206,28,0,160,203,35,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,64,16,0,1,0,0,0,0,0,192,119,35,0,64,29,35,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,64,16,0,1,0,0,0,0,0,200,216,34,0,160,156,34,0,96,0,0,0,82,76,79,67,24,96,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,40,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,233,31,0,108,0,0,0,120,216,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,141,35,0,108,0,0,0,224,113,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,227,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,26,31,0,240,108,30,0,8,0,0,0,1,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,227,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,3,0,0,0,0,0,0,0,0,0,0,252,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,238,31,0,108,0,0,0,232,218,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,4,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,64,0,0,0,0,0,0,64,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,1,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,8,0,0,0,208,229,28,0,108,0,0,0,16,75,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,2,29,0,108,0,0,0,16,75,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,169,34,0,108,0,0,0,48,115,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,167,33,0,216,137,33,0,4,0,0,0,69,90,73,83,112,96,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,96,34,33,0,216,137,33,0,4,0,0,0,69,90,73,83,112,96,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,255,32,0,120,229,32,0,24,0,0,0,84,65,82,86,40,202,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,176,32,0,120,229,32,0,24,0,0,0,84,65,82,86,40,202,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,154,32,0,200,129,32,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,96,103,32,0,200,129,32,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,240,82,32,0,160,50,32,0,48,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,200,233,31,0,56,214,31,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,64,16,0,1,0,0,0,0,0,136,195,31,0,56,214,31,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,225,29,0,108,0,0,0,48,221,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,208,248,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,109,30,0,8,228,29,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,120,29,0,48,32,29,0,224,206,28,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,120,29,0,200,203,35,0,224,206,28,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,120,29,0,232,119,35,0,144,29,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,120,29,0,232,216,34,0,144,29,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,120,29,0,200,156,34,0,32,96,34,0,8,0,0,0,5,0,0,0,144,40,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,248,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,176,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,246,31,0,108,0,0,0,192,223,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,246,31,0,108,0,0,0,0,0,0,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,227,33,0,64,191,33,0,8,0,0,0,2,0,0,0,152,58,0,0,0,0,0,0,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,22,34,0,108,0,0,0,232,225,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,6,6,7,8,9,10,11,13,14,16,18,20,22,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,7,8,8,8,9,9,9,0,1,3,4,6,7,9,10,11,0,0,0,0,0,0,0,10,6,10,6,10,10,10,10,1,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,1,255,0,0,1,255,0,0,1,255,0,0,1,255,0,1,1,255,0,1,1,255,1,1,1,255,1,1,1,255,1,1,1,255,1,1,1,255,1,1,2,255,1,1,2,255,1,1,2,255,1,1,2,255,1,2,3,255,1,2,3,255,2,2,3,255,2,2,4,255,2,3,4,255,2,3,4,255,3,3,5,255,3,4,6,255,3,4,6,255,4,5,7,255,4,5,8,255,4,6,9,255,5,7,10,255,6,8,11,255,6,8,13,255,7,10,14,255,8,11,16,255,9,12,18,255,10,13,20,255,11,15,23,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,74,44,25,13,7,3,68,42,24,13,7,3,58,39,23,13,7,3,126,70,37,19,10,5,132,70,37,20,10,5,124,70,38,20,10,5,120,69,37,20,11,5,116,67,37,20,11,5,108,66,36,20,10,5,102,62,36,20,10,5,88,58,34,19,10,5,162,89,49,25,13,7,156,87,49,26,14,7,150,86,47,26,14,7,142,84,47,26,14,7,131,79,46,26,14,7,0,1,1,2,3,3,4,5,0,0,0,0,0,0,0,0,71,80,83,86,101,114,115,105,111,110,73,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,80,83,76,97,116,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,80,83,76,97,116,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,80,83,76,111,110,103,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,71,80,83,76,111,110,103,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,71,80,83,65,108,116,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,71,80,83,65,108,116,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,71,80,83,84,105,109,101,83,116,97,109,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,71,80,83,83,97,116,101,108,108,105,116,101,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,80,83,83,116,97,116,117,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,71,80,83,77,101,97,115,117,114,101,77,111,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,71,80,83,68,79,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,71,80,83,83,112,101,101,100,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,71,80,83,83,112,101,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,71,80,83,84,114,97,99,107,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,71,80,83,84,114,97,99,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,71,80,83,73,109,103,68,105,114,101,99,116,105,111,110,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,71,80,83,73,109,103,68,105,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,71,80,83,77,97,112,68,97,116,117,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,71,80,83,68,101,115,116,76,97,116,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,71,80,83,68,101,115,116,76,97,116,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,71,80,83,68,101,115,116,76,111,110,103,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,71,80,83,68,101,115,116,76,111,110,103,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,71,80,83,68,101,115,116,66,101,97,114,105,110,103,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,71,80,83,68,101,115,116,66,101,97,114,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,71,80,83,68,101,115,116,68,105,115,116,97,110,99,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,71,80,83,68,101,115,116,68,105,115,116,97,110,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,71,80,83,80,114,111,99,101,115,115,105,110,103,77,101,116,104,111,100,0,0,0,0,0,0,0,0,0,0,0,0,0,27,0,71,80,83,65,114,101,97,73,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,71,80,83,68,97,116,101,83,116,97,109,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,0,71,80,83,68,105,102,102,101,114,101,110,116,105,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,73,109,97,103,101,87,105,100,116,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,73,109,97,103,101,76,101,110,103,116,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,66,105,116,115,80,101,114,83,97,109,112,108,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,67,111,109,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,80,104,111,116,111,109,101,116,114,105,99,73,110,116,101,114,112,114,101,116,97,116,105,111,110,0,0,0,0,0,0,0,6,1,79,114,105,101,110,116,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,1,83,97,109,112,108,101,115,80,101,114,80,105,120,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,1,80,108,97,110,97,114,67,111,110,102,105,103,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,28,1,89,67,98,67,114,83,117,98,83,97,109,112,108,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,2,89,67,98,67,114,80,111,115,105,116,105,111,110,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,2,88,82,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,1,89,82,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,1,82,101,115,111,108,117,116,105,111,110,85,110,105,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,83,116,114,105,112,79,102,102,115,101,116,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,82,111,119,115,80,101,114,83,116,114,105,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,83,116,114,105,112,66,121,116,101,67,111,117,110,116,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,74,80,69,71,73,110,116,101,114,99,104,97,110,103,101,70,111,114,109,97,116,0,0,0,0,0,0,0,0,0,0,0,1,2,74,80,69,71,73,110,116,101,114,99,104,97,110,103,101,70,111,114,109,97,116,76,101,110,103,116,104,0,0,0,0,0,2,2,84,114,97,110,115,102,101,114,70,117,110,99,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,1,87,104,105,116,101,80,111,105,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,1,80,114,105,109,97,114,121,67,104,114,111,109,97,116,105,99,105,116,105,101,115,0,0,0,0,0,0,0,0,0,0,0,63,1,89,67,98,67,114,67,111,101,102,102,105,99,105,101,110,116,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,2,82,101,102,101,114,101,110,99,101,66,108,97,99,107,87,104,105,116,101,0,0,0,0,0,0,0,0,0,0,0,0,0,20,2,68,97,116,101,84,105,109,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,1,73,109,97,103,101,68,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,1,77,97,107,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,1,77,111,100,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,83,111,102,116,119,97,114,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,1,65,114,116,105,115,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,1,67,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,130,69,120,105,102,86,101,114,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,70,108,97,115,104,112,105,120,86,101,114,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,67,111,108,111,114,83,112,97,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,160,67,111,109,112,111,110,101,110,116,115,67,111,110,102,105,103,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,0,1,145,67,111,109,112,114,101,115,115,101,100,66,105,116,115,80,101,114,80,105,120,101,108,0,0,0,0,0,0,0,0,0,0,2,145,80,105,120,101,108,88,68,105,109,101,110,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,160,80,105,120,101,108,89,68,105,109,101,110,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,160,77,97,107,101,114,78,111,116,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,146,85,115,101,114,67,111,109,109,101,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,146,82,101,108,97,116,101,100,83,111,117,110,100,70,105,108,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,160,68,97,116,101,84,105,109,101,79,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,144,68,97,116,101,84,105,109,101,68,105,103,105,116,105,122,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,144,83,117,98,83,101,99,84,105,109,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,146,83,117,98,83,101,99,84,105,109,101,79,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,146,83,117,98,83,101,99,84,105,109,101,68,105,103,105,116,105,122,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,146,146,73,109,97,103,101,85,110,105,113,117,101,73,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,164,69,120,112,111,115,117,114,101,84,105,109,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,130,70,78,117,109,98,101,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,157,130,69,120,112,111,115,117,114,101,80,114,111,103,114,97,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,136,83,112,101,99,116,114,97,108,83,101,110,115,105,116,105,118,105,116,121,0,0,0,0,0,0,0,0,0,0,0,0,0,36,136,73,83,79,83,112,101,101,100,82,97,116,105,110,103,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,136,79,69,67,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,136,83,104,117,116,116,101,114,83,112,101,101,100,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,146,65,112,101,114,116,117,114,101,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,146,66,114,105,103,104,116,110,101,115,115,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,146,69,120,112,111,115,117,114,101,66,105,97,115,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,146,77,97,120,65,112,101,114,116,117,114,101,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,146,83,117,98,106,101,99,116,68,105,115,116,97,110,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,146,77,101,116,101,114,105,110,103,77,111,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,146,76,105,103,104,116,83,111,117,114,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,146,70,108,97,115,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,146,70,111,99,97,108,76,101,110,103,116,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,146,83,117,98,106,101,99,116,65,114,101,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,146,70,108,97,115,104,69,110,101,114,103,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,162,83,112,97,116,105,97,108,70,114,101,113,117,101,110,99,121,82,101,115,112,111,110,115,101,0,0,0,0,0,0,0,0,12,162,70,111,99,97,108,80,108,97,110,101,88,82,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,14,162,70,111,99,97,108,80,108,97,110,101,89,82,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,15,162,70,111,99,97,108,80,108,97,110,101,82,101,115,111,108,117,116,105,111,110,85,110,105,116,0,0,0,0,0,0,0,0,16,162,83,117,98,106,101,99,116,76,111,99,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,162,69,120,112,111,115,117,114,101,73,110,100,101,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,162,83,101,110,115,105,110,103,77,101,116,104,111,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,162,70,105,108,101,83,111,117,114,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,83,99,101,110,101,84,121,112,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,163,67,70,65,80,97,116,116,101,114,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,163,67,117,115,116,111,109,82,101,110,100,101,114,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,164,69,120,112,111,115,117,114,101,77,111,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,164,87,104,105,116,101,66,97,108,97,110,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,164,68,105,103,105,116,97,108,90,111,111,109,82,97,116,105,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,164,70,111,99,97,108,76,101,110,103,116,104,73,110,51,53,109,109,70,105,108,109,0,0,0,0,0,0,0,0,0,0,0,5,164,83,99,101,110,101,67,97,112,116,117,114,101,84,121,112,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,164,71,97,105,110,67,111,110,116,114,111,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,164,67,111,110,116,114,97,115,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,164,83,97,116,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,164,83,104,97,114,112,110,101,115,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,164,68,101,118,105,99,101,83,101,116,116,105,110,103,68,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,0,0,0,11,164,83,117,98,106,101,99,116,68,105,115,116,97,110,99,101,82,97,110,103,101,0,0,0,0,0,0,0,0,0,0,0,0,12,164,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,64,67,3,0,5,0,0,0,64,67,3,0,15,0,0,0,16,69,3,0,5,0,0,0,64,67,3,0,25,0,0,0,168,71,3,0,15,0,0,0,16,69,3,0,35,0,0,0,136,67,3,0,5,0,0,0,64,67,3,0,45,0,0,0,120,65,3,0,25,0,0,0,168,71,3,0,55,0,0,0,184,69,3,0,15,0,0,0,16,69,3,0,104,22,36,0,104,18,36,0,4,0,0,0,96,18,36,0,96,16,36,0,2,0,0,0,104,22,36,0,104,18,36,0,4,0,0,0,0,0,0,0,184,7,9,0,184,4,9,0,160,1,9,0,0,0,0,0,0,0,0,0,26,7,0,0,38,14,0,0,48,16,0,0,90,18,0,0,114,20,0,0,172,22,0,0,236,22,0,0,12,23,0,0,44,23,0,0,108,23,0,0,108,24,0,0,172,24,0,0,204,24,0,0,236,24,0,0,250,29,0,0,240,34,0,0,34,40,0,0,148,45,0,0,218,47,0,0,236,54,0,0,230,61,0,0,244,63,0,0,66,66,0,0,104,68,0,0,228,70,0,0,4,71,0,0,36,71,0,0,68,71,0,0,132,71,0,0,132,72,0,0,196,72,0,0,228,72,0,0,4,73,0,0,68,78,0,0,66,83,0,0,120,88,0,0,160,93,0,0,38,96,0,0,16,103,0,0,30,110,0,0,64,112,0,0,182,114,0,0,242,116,0,0,144,119,0,0,176,119,0,0,208,119,0,0,240,119,0,0,48,120,0,0,48,121,0,0,112,121,0,0,144,121,0,0,208,121,0,0,58,127,0,0,106,132,0,0,164,137,0,0,36,143,0,0,166,145,0,0,108,152,0,0,98,159,0,0,152,161,0,0,68,164,0,0,196,166,0,0,84,169,0,0,116,169,0,0,148,169,0,0,180,169,0,0,212,169,0,0,84,170,0,0,148,170,0,0,180,170,0,0,212,170,0,0,44,176,0,0,94,181,0,0,162,186,0,0,8,192,0,0,138,194,0,0,94,201,0,0,92,208,0,0,212,210,0,0,120,213,0,0,52,216,0,0,186,218,0,0,58,219], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+184320);
/* memory initializer */ allocate([90,219,0,0,122,219,0,0,154,219,0,0,26,220,0,0,90,220,0,0,122,220,0,0,154,220,0,0,22,226,0,0,154,231,0,0,220,236,0,0,84,242,0,0,218,244,0,0,204,251,0,0,12,252,0,0,76,252,0,0,204,252,0,0,76,253,0,0,28,2,1,0,138,7,1,0,138,9,1,0,190,11,1,0,200,13,1,0,16,16,1,0,152,18,1,0,74,25,1,0,138,25,1,0,202,25,1,0,10,26,1,0,138,26,1,0,100,31,1,0,184,36,1,0,190,38,1,0,254,40,1,0,22,43,1,0,120,45,1,0,254,47,1,0,222,54,1,0,30,55,1,0,62,55,1,0,126,55,1,0,254,55,1,0,28,61,1,0,104,66,1,0,120,68,1,0,216,70,1,0,18,73,1,0,198,75,1,0,72,78,1,0,88,85,1,0,152,85,1,0,184,85,1,0,248,85,1,0,120,86,1,0,150,91,1,0,228,96,1,0,22,99,1,0,206,101,1,0,22,104,1,0,174,106,1,0,48,109,1,0,14,116,1,0,46,116,1,0,78,116,1,0,142,116,1,0,14,117,1,0,110,122,1,0,218,127,1,0,32,130,1,0,214,132,1,0,138,135,1,0,20,138,1,0,148,140,1,0,152,147,1,0,184,147,1,0,216,147,1,0,248,147,1,0,56,148,1,0,170,153,1,0,238,158,1,0,158,161,1,0,64,164,1,0,226,166,1,0,102,169,1,0,232,171,1,0,6,179,1,0,38,179,1,0,70,179,1,0,102,179,1,0,134,179,1,0,238,184,1,0,144,190,1,0,44,193,1,0,204,195,1,0,86,198,1,0,214,200,1,0,88,203,1,0,3,5,1,2,1,3,1,1,1,6,1,5,2,5,0,0,212,0,0,0,8,0,0,0,197,33,0,0,14,0,0,0,138,241,0,0,16,0,0,0,188,213,0,0,16,0,0,0,121,8,0,0,12,0,0,0,77,53,0,0,14,0,0,0,63,14,1,0,17,0,0,0,84,15,1,0,17,0,0,0,102,8,0,0,12,0,0,0,110,53,0,0,14,0,0,0,85,15,1,0,17,0,0,0,62,14,1,0,17,0,0,0,206,16,0,0,13,0,0,0,132,60,0,0,14,0,0,0,189,213,0,0,16,0,0,0,139,241,0,0,16,0,0,0,104,8,0,0,12,0,0,0,140,67,0,0,15,0,0,0,171,135,0,0,16,0,0,0,11,121,0,0,15,0,0,0,16,15,0,0,12,0,0,0,61,67,0,0,15,0,0,0,211,106,0,0,15,0,0,0,10,121,0,0,15,0,0,0,167,26,0,0,13,0,0,0,212,67,0,0,15,0,0,0,30,135,0,0,16,0,0,0,223,106,0,0,15,0,0,0,124,13,0,0,12,0,0,0,148,60,0,0,14,0,0,0,141,67,0,0,15,0,0,0,210,106,0,0,15,0,0,0,188,6,0,0,11,0,0,0,233,33,0,0,14,0,0,0,218,106,0,0,15,0,0,0,153,106,0,0,15,0,0,0,247,16,0,0,13,0,0,0,137,67,0,0,15,0,0,0,219,106,0,0,15,0,0,0,196,120,0,0,15,0,0,0,86,13,0,0,12,0,0,0,247,53,0,0,14,0,0,0,142,67,0,0,15,0,0,0,152,106,0,0,15,0,0,0,82,13,0,0,12,0,0,0,149,60,0,0,14,0,0,0,136,67,0,0,15,0,0,0,60,67,0,0,15,0,0,0,84,13,0,0,12,0,0,0,75,30,0,0,13,0,0,0,99,60,0,0,14,0,0,0,131,60,0,0,14,0,0,0,97,8,0,0,12,0,0,0,235,33,0,0,14,0,0,0,108,53,0,0,14,0,0,0,246,53,0,0,14,0,0,0,99,8,0,0,12,0,0,0,159,33,0,0,14,0,0,0,104,53,0,0,14,0,0,0,130,60,0,0,14,0,0,0,174,1,0,0,9,0,0,0,192,16,0,0,13,0,0,0,17,15,0,0,12,0,0,0,250,26,0,0,13,0,0,0,0,0,0,0,1,0,0,0,240,0,0,0,8,0,0,0,173,1,0,0,9,0,0,0,193,16,0,0,13,0,0,0,10,0,0,0,4,0,0,0,197,3,0,0,10,0,0,0,137,7,0,0,11,0,0,0,181,26,0,0,13,0,0,0,9,0,0,0,4,0,0,0,53,4,0,0,11,0,0,0,147,7,0,0,11,0,0,0,64,30,0,0,13,0,0,0,29,0,0,0,5,0,0,0,203,3,0,0,10,0,0,0,120,8,0,0,12,0,0,0,175,26,0,0,13,0,0,0,11,0,0,0,4,0,0,0,199,3,0,0,10,0,0,0,145,7,0,0,11,0,0,0,171,26,0,0,13,0,0,0,31,0,0,0,5,0,0,0,54,4,0,0,11,0,0,0,191,6,0,0,11,0,0,0,25,15,0,0,12,0,0,0,61,0,0,0,6,0,0,0,81,13,0,0,12,0,0,0,196,16,0,0,13,0,0,0,232,33,0,0,14,0,0,0,54,0,0,0,6,0,0,0,55,4,0,0,11,0,0,0,175,6,0,0,11,0,0,0,197,16,0,0,13,0,0,0,12,0,0,0,4,0,0,0,50,4,0,0,11,0,0,0,148,7,0,0,11,0,0,0,48,30,0,0,13,0,0,0,66,0,0,0,7,0,0,0,112,8,0,0,12,0,0,0,36,15,0,0,12,0,0,0,67,30,0,0,13,0,0,0,32,0,0,0,6,0,0,0,62,4,0,0,11,0,0,0,149,7,0,0,11,0,0,0,170,26,0,0,13,0,0,0,55,0,0,0,6,0,0,0,172,6,0,0,11,0,0,0,174,6,0,0,11,0,0,0,246,16,0,0,13,0,0,0,52,0,0,0,6,0,0,0,58,4,0,0,11,0,0,0,80,13,0,0,12,0,0,0,174,26,0,0,13,0,0,0,57,0,0,0,6,0,0,0,63,4,0,0,11,0,0,0,141,7,0,0,11,0,0,0,210,16,0,0,13,0,0,0,56,0,0,0,6,0,0,0,59,4,0,0,11,0,0,0,189,6,0,0,11,0,0,0,211,16,0,0,13,0,0,0,17,0,0,0,5,0,0,0,172,1,0,0,9,0,0,0,243,0,0,0,8,0,0,0,57,4,0,0,11,0,0,0,161,2,0,0,10,0,0,0,64,87,0,0,15,0,0,0,191,160,1,0,18,0,0,0,25,93,1,0,17,0,0,0,20,21,0,0,13,0,0,0,30,70,0,0,15,0,0,0,118,81,1,0,17,0,0,0,119,81,1,0,17,0,0,0,173,17,0,0,13,0,0,0,46,104,0,0,16,0,0,0,249,130,6,0,20,0,0,0,125,65,3,0,19,0,0,0,54,26,0,0,14,0,0,0,45,42,0,0,14,0,0,0,94,208,0,0,17,0,0,0,36,104,0,0,16,0,0,0,21,21,0,0,13,0,0,0,92,84,0,0,15,0,0,0,233,48,2,0,18,0,0,0,250,26,1,0,17,0,0,0,215,21,0,0,13,0,0,0,71,87,0,0,15,0,0,0,121,141,0,0,16,0,0,0,37,104,0,0,16,0,0,0,162,43,0,0,14,0,0,0,186,168,0,0,16,0,0,0,246,53,2,0,18,0,0,0,24,93,1,0,17,0,0,0,174,17,0,0,13,0,0,0,111,52,0,0,15,0,0,0,59,140,0,0,16,0,0,0,110,52,0,0,15,0,0,0,26,13,0,0,13,0,0,0,31,70,0,0,15,0,0,0,248,130,6,0,20,0,0,0,117,24,1,0,17,0,0,0,161,43,0,0,14,0,0,0,97,141,0,0,16,0,0,0,247,53,2,0,18,0,0,0,232,48,2,0,18,0,0,0,19,21,0,0,13,0,0,0,123,141,0,0,16,0,0,0,244,26,1,0,17,0,0,0,245,26,1,0,17,0,0,0,133,17,0,0,13,0,0,0,191,70,0,0,15,0,0,0,96,141,0,0,16,0,0,0,124,141,0,0,16,0,0,0,18,21,0,0,13,0,0,0,28,70,0,0,15,0,0,0,141,174,0,0,16,0,0,0,120,141,0,0,16,0,0,0,14,13,0,0,13,0,0,0,19,52,0,0,15,0,0,0,177,70,0,0,15,0,0,0,22,52,0,0,15,0,0,0,234,10,0,0,12,0,0,0,44,42,0,0,14,0,0,0,65,87,0,0,15,0,0,0,47,42,0,0,14,0,0,0,88,1,0,0,9,0,0,0,210,8,0,0,12,0,0,0,76,5,0,0,11,0,0,0,134,6,0,0,12,0,0,0,0,0,0,0,2,0,0,0,105,0,0,0,8,0,0,0,107,0,0,0,8,0,0,0,140,6,0,0,12,0,0,0,7,0,0,0,3,0,0,0,94,1,0,0,9,0,0,0,163,2,0,0,10,0,0,0,233,10,0,0,12,0,0,0,6,0,0,0,3,0,0,0,49,2,0,0,10,0,0,0,184,2,0,0,10,0,0,0,8,26,0,0,14,0,0,0,16,0,0,0,5,0,0,0,169,1,0,0,10,0,0,0,66,3,0,0,11,0,0,0,136,10,0,0,12,0,0,0,4,0,0,0,4,0,0,0,162,1,0,0,10,0,0,0,164,2,0,0,10,0,0,0,132,17,0,0,13,0,0,0,18,0,0,0,5,0,0,0,50,2,0,0,10,0,0,0,178,2,0,0,10,0,0,0,128,6,0,0,12,0,0,0,27,0,0,0,6,0,0,0,106,4,0,0,11,0,0,0,142,6,0,0,12,0,0,0,89,35,0,0,14,0,0,0,22,0,0,0,5,0,0,0,95,1,0,0,9,0,0,0,160,2,0,0,10,0,0,0,77,5,0,0,11,0,0,0,5,0,0,0,4,0,0,0,51,2,0,0,10,0,0,0,185,2,0,0,10,0,0,0,214,21,0,0,13,0,0,0,34,0,0,0,6,0,0,0,104,4,0,0,11,0,0,0,131,6,0,0,12,0,0,0,10,26,0,0,14,0,0,0,19,0,0,0,5,0,0,0,54,2,0,0,10,0,0,0,187,2,0,0,10,0,0,0,134,17,0,0,13,0,0,0,23,0,0,0,5,0,0,0,171,1,0,0,10,0,0,0,167,2,0,0,10,0,0,0,211,8,0,0,12,0,0,0,20,0,0,0,5,0,0,0,55,2,0,0,10,0,0,0,96,4,0,0,11,0,0,0,15,13,0,0,13,0,0,0,25,0,0,0,6,0,0,0,170,1,0,0,10,0,0,0,179,2,0,0,10,0,0,0,129,6,0,0,12,0,0,0,24,0,0,0,6,0,0,0,168,1,0,0,10,0,0,0,165,2,0,0,10,0,0,0,143,6,0,0,12,0,0,0,7,0,0,0,4,0,0,0,85,0,0,0,7,0,0,0,71,0,0,0,7,0,0,0,173,0,0,0,8,0,0,0,167,0,0,0,14,0,0,0,184,178,1,0,18,0,0,0,142,178,1,0,18,0,0,0,117,101,3,0,19,0,0,0,172,108,0,0,16,0,0,0,105,10,0,0,18,0,0,0,52,41,0,0,20,0,0,0,107,82,0,0,21,0,0,0,161,108,0,0,16,0,0,0,185,178,1,0,18,0,0,0,173,41,0,0,20,0,0,0,83,147,2,0,24,0,0,0,167,108,0,0,16,0,0,0,171,108,0,0,16,0,0,0,187,178,1,0,18,0,0,0,155,2,0,0,16,0,0,0,68,217,0,0,17,0,0,0,106,10,0,0,18,0,0,0,168,73,1,0,23,0,0,0,31,101,3,0,19,0,0,0,175,108,0,0,16,0,0,0,76,10,0,0,18,0,0,0,30,101,3,0,19,0,0,0,72,10,0,0,18,0,0,0,156,41,0,0,20,0,0,0,159,41,0,0,20,0,0,0,82,147,2,0,24,0,0,0,172,41,0,0,20,0,0,0,150,2,0,0,16,0,0,0,70,217,0,0,17,0,0,0,104,10,0,0,18,0,0,0,152,2,0,0,16,0,0,0,39,5,0,0,17,0,0,0,77,217,0,0,17,0,0,0,215,20,0,0,19,0,0,0,116,101,3,0,19,0,0,0,92,10,0,0,18,0,0,0,153,178,1,0,18,0,0,0,157,41,0,0,20,0,0,0,158,41,0,0,20,0,0,0,37,5,0,0,17,0,0,0,102,10,0,0,18,0,0,0,213,164,0,0,22,0,0,0,155,20,0,0,19,0,0,0,149,2,0,0,16,0,0,0,173,108,0,0,16,0,0,0,73,10,0,0,18,0,0,0,33,5,0,0,17,0,0,0,170,108,0,0,16,0,0,0,69,217,0,0,17,0,0,0,152,178,1,0,18,0,0,0,47,5,0,0,17,0,0,0,84,54,0,0,15,0,0,0,160,108,0,0,16,0,0,0,50,5,0,0,17,0,0,0,145,2,0,0,16,0,0,0,82,54,0,0,15,0,0,0,32,5,0,0,17,0,0,0,93,10,0,0,18,0,0,0,148,2,0,0,16,0,0,0,155,0,0,0,11,0,0,0,226,6,0,0,12,0,0,0,40,0,0,0,12,0,0,0,176,1,0,0,10,0,0,0,1,0,0,0,3,0,0,0,16,0,0,0,8,0,0,0,47,0,0,0,6,0,0,0,76,0,0,0,10,0,0,0,13,0,0,0,4,0,0,0,0,0,0,0,10,0,0,0,6,0,0,0,9,0,0,0,52,1,0,0,12,0,0,0,12,0,0,0,4,0,0,0,7,0,0,0,10,0,0,0,7,0,0,0,9,0,0,0,225,6,0,0,12,0,0,0,14,0,0,0,5,0,0,0,218,0,0,0,9,0,0,0,34,0,0,0,9,0,0,0,100,3,0,0,11,0,0,0,15,0,0,0,4,0,0,0,6,0,0,0,10,0,0,0,15,0,0,0,9,0,0,0,53,1,0,0,12,0,0,0,20,0,0,0,5,0,0,0,221,0,0,0,9,0,0,0,4,0,0,0,9,0,0,0,21,0,0,0,11,0,0,0,26,0,0,0,6,0,0,0,179,1,0,0,10,0,0,0,5,0,0,0,10,0,0,0,227,6,0,0,12,0,0,0,12,0,0,0,5,0,0,0,185,0,0,0,8,0,0,0,4,0,0,0,8,0,0,0,219,0,0,0,9,0,0,0,14,0,0,0,4,0,0,0,11,0,0,0,10,0,0,0,35,0,0,0,9,0,0,0,203,6,0,0,12,0,0,0,5,0,0,0,6,0,0,0,177,1,0,0,10,0,0,0,1,0,0,0,10,0,0,0,224,6,0,0,12,0,0,0,17,0,0,0,5,0,0,0,223,0,0,0,9,0,0,0,14,0,0,0,9,0,0,0,115,3,0,0,11,0,0,0,3,0,0,0,5,0,0,0,184,0,0,0,8,0,0,0,6,0,0,0,8,0,0,0,117,1,0,0,9,0,0,0,21,0,0,0,5,0,0,0,116,1,0,0,9,0,0,0,39,0,0,0,9,0,0,0,114,3,0,0,11,0,0,0,16,0,0,0,5,0,0,0,187,0,0,0,8,0,0,0,5,0,0,0,8,0,0,0,222,0,0,0,9,0,0,0,15,0,0,0,5,0,0,0,1,0,0,0,9,0,0,0,18,0,0,0,8,0,0,0,4,0,0,0,10,0,0,0,2,0,0,0,3,0,0,0,22,0,0,0,5,0,0,0,9,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,3,5,2,3,3,3,2,4,3,4,2,2,3,2,1,6,2,6,3,6,2,5,0,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,114,0,101,0,100,0,105,0,114,0,101,0,99,0,116,0,111,0,114,0,46,0,108,0,101,0,103,0,97,0,99,0,121,0,95,0,97,0,116,0,116,0,114,0,105,0,98,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,104,0,101,0,97,0,100,0,101,0,114,0,46,0,116,0,105,0,109,0,101,0,0,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,104,0,101,0,97,0,100,0,101,0,114,0,46,0,108,0,101,0,103,0,97,0,99,0,121,0,95,0,97,0,116,0,116,0,114,0,105,0,98,0,0,0,3,0,3,0,4,0,11,0,5,0,20,0,6,0,63,0,6,0,93,0,7,0,162,0,8,0,172,0,9,0,110,1,9,0,10,2,10,0,226,2,10,0,50,4,11,0,201,5,11,0,39,8,12,0,84,11,12,0,230,4,13,0,95,16,13,0,42,23,13,0,178,32,14,0,78,45,14,0,240,57,14,0,117,65,15,0,158,90,15,0,4,0,4,0,30,0,5,0,66,0,7,0,182,0,8,0,115,1,9,0,149,3,10,0,46,7,11,0,148,11,12,0,164,22,13,0,179,32,14,0,69,46,14,0,5,0,5,0,64,0,7,0,73,0,9,0,143,2,10,0,203,5,11,0,138,4,13,0,221,9,14,0,226,115,15,0,24,0,5,0,37,0,8,0,138,0,10,0,27,5,11,0,95,14,12,0,201,9,14,0,156,19,15,0,41,0,6,0,79,0,9,0,18,4,11,0,141,4,13,0,65,46,14,0,56,0,6,0,14,1,9,0,168,5,11,0,92,16,13,0,242,57,14,0,88,0,7,0,31,2,10,0,126,14,12,0,255,57,14,0,35,0,8,0,227,2,10,0,229,4,13,0,64,46,14,0,161,0,8,0,190,5,11,0,200,9,14,0,131,0,8,0,58,1,11,0,33,23,13,0,68,0,9,0,118,2,12,0,246,57,14,0,139,0,10,0,239,4,13,0,155,90,15,0,8,2,10,0,254,28,13,0,153,3,10,0,180,28,13,0,158,3,10,0,243,57,14,0,171,5,11,0,227,115,15,0,55,7,11,0,159,90,15,0,45,8,12,0,105,14,12,0,104,14,12,0,51,4,11,0,123,11,12,0,248,45,14,0,86,46,14,0,87,46,14,0,247,57,14,0,165,81,15,0,3,0,3,0,42,0,6,0,228,0,8,0,142,2,10,0,53,7,11,0,88,16,13,0,250,28,13,0,249,45,14,0,116,65,15,0,9,0,4,0,84,0,8,0,152,3,10,0,139,4,13,0,157,19,15,0,13,0,4,0,173,0,9,0,38,8,12,0,76,45,14,0,17,0,5,0,107,1,9,0,127,11,12,0,164,81,15,0,25,0,5,0,27,2,10,0,253,22,13,0,29,0,5,0,148,3,10,0,211,40,14,0,43,0,6,0,188,5,11,0,154,90,15,0,47,0,6,0,71,2,12,0,16,0,7,0,53,10,12,0,62,0,6,0,122,11,12,0,89,0,7,0,94,16,13,0,38,0,8,0,207,9,14,0,85,0,8,0,181,28,13,0,87,0,8,0,91,14,12,0,160,0,8,0,104,20,13,0,112,1,9,0,144,0,10,0,206,1,9,0,26,2,10,0,24,2,10,0,104,1,9,0,30,2,10,0,68,2,12,0,54,7,11,0,56,1,11,0,25,5,11,0,94,14,12,0,44,7,11,0,85,11,12,0,220,9,14,0,187,32,14,0,140,4,13,0,35,23,13,0,68,46,14,0,165,22,13,0,24,5,11,0,254,57,14,0,105,1,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4,4,4,4,4,5,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,13,13,14,14,15,15,16,16,17,18,19,20,21,22,23,24,25,26,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,1,2,3,4,5,6,7,8,9,10,11,1,2,3,4,5,6,7,8,1,2,3,4,5,6,7,1,2,3,4,5,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,2,3,4,5,6,7,8,9,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,2,0,5,0,3,0,13,0,4,0,18,0,5,0,14,0,6,0,21,0,7,0,19,0,8,0,63,0,8,0,75,0,9,0,31,1,9,0,184,0,10,0,227,3,10,0,114,1,11,0,77,2,12,0,218,3,12,0,221,2,13,0,85,31,13,0,185,5,14,0,174,62,14,0,0,0,4,0,16,0,5,0,8,0,7,0,32,0,8,0,41,0,9,0,244,1,9,0,51,2,10,0,224,1,11,0,42,1,12,0,221,3,12,0,10,5,13,0,41,31,13,0,66,10,14,0,114,18,15,0,55,23,15,0,3,0,5,0,17,0,7,0,196,0,8,0,75,0,10,0,180,0,11,0,212,7,11,0,69,3,12,0,215,2,13,0,191,7,13,0,56,9,14,0,187,11,14,0,94,9,15,0,19,0,5,0,120,0,7,0,105,0,9,0,50,2,10,0,97,4,11,0,236,3,12,0,32,5,13,0,42,31,13,0,80,62,14,0,81,62,14,0,134,20,15,0,12,0,6,0,36,0,9,0,148,0,11,0,192,8,12,0,9,15,14,0,240,30,15,0,61,0,6,0,83,0,9,0,160,1,11,0,214,2,13,0,8,15,14,0,19,0,7,0,124,0,9,0,193,7,11,0,172,4,14,0,27,0,7,0,160,0,10,0,68,3,12,0,121,15,14,0,121,0,7,0,225,3,10,0,212,2,13,0,6,35,14,0,33,0,8,0,60,2,10,0,174,15,12,0,222,35,14,0,53,0,8,0,117,1,11,0,179,7,13,0,197,0,8,0,116,1,11,0,133,7,13,0,72,0,9,0,163,1,11,0,158,4,13,0,44,0,9,0,250,0,10,0,214,7,11,0,146,0,10,0,204,5,13,0,241,30,15,0,163,0,10,0,237,3,12,0,62,9,14,0,226,1,11,0,115,18,15,0,196,7,11,0,135,20,15,0,145,2,12,0,147,2,12,0,138,15,12,0,9,5,13,0,8,5,13,0,141,7,13,0,190,7,13,0,140,7,13,0,174,4,14,0,186,11,14,0,7,35,14,0,154,11,14,0,54,23,15,0,14,0,4,0,69,0,7,0,243,1,9,0,122,4,11,0,220,5,13,0,223,35,14,0,25,0,5,0,40,0,9,0,118,1,11,0,157,4,13,0,221,35,14,0,48,0,6,0,162,0,10,0,239,2,12,0,184,5,14,0,63,0,6,0,165,0,10,0,219,3,12,0,63,9,14,0,68,0,7,0,203,7,11,0,95,9,15,0,99,0,7,0,195,3,12,0,21,0,8,0,246,8,12,0,23,0,8,0,152,4,13,0,44,0,8,0,178,7,13,0,47,0,8,0,84,31,13,0,141,0,8,0,189,7,13,0,142,0,8,0,130,17,13,0,251,0,8,0,11,5,13,0,45,0,8,0,192,7,11,0,121,0,9,0,95,31,13,0,122,0,9,0,86,31,13,0,49,2,10,0,228,3,10,0,161,1,11,0,67,1,11,0,247,1,11,0,111,1,12,0,146,2,12,0,231,2,12,0,108,1,12,0,109,1,12,0,220,3,12,0,139,15,12,0,153,4,13,0,216,3,12,0,142,7,13,0,213,2,13,0,94,31,13,0,43,31,13,0,143,7,13,0,173,4,14,0,175,62,14,0,220,35,14,0,74,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,5,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,11,11,11,12,12,12,13,13,13,14,14,14,15,15,15,16,16,17,17,18,19,20,21,22,23,24,25,26,27,28,29,30,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,1,2,3,4,5,6,7,8,9,10,11,12,1,2,3,4,5,6,7,8,9,10,11,1,2,3,4,5,6,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,4,5,6,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,4,0,3,0,20,0,5,0,23,0,7,0,127,0,8,0,84,1,9,0,242,1,10,0,191,0,11,0,101,0,12,0,170,10,12,0,48,6,13,0,151,21,13,0,183,3,14,0,34,43,14,0,230,11,15,0,11,0,4,0,55,0,7,0,98,0,9,0,7,0,11,0,102,1,12,0,206,0,13,0,144,21,13,0,246,5,14,0,231,11,15,0,7,0,5,0,109,0,8,0,3,0,11,0,31,3,12,0,242,5,14,0,2,0,6,0,97,0,9,0,85,0,12,0,223,1,14,0,26,0,6,0,30,0,10,0,201,10,12,0,35,43,14,0,30,0,6,0,31,0,10,0,195,10,12,0,43,43,14,0,6,0,7,0,4,0,11,0,248,2,13,0,25,0,7,0,6,0,11,0,61,6,13,0,87,0,7,0,130,1,11,0,162,42,14,0,4,0,8,0,128,1,11,0,156,5,14,0,125,0,8,0,100,1,12,0,109,7,15,0,2,0,9,0,141,1,11,0,129,21,13,0,173,0,8,0,96,0,12,0,103,12,14,0,28,0,9,0,238,0,13,0,3,0,9,0,207,2,13,0,217,0,9,0,128,21,13,0,2,0,11,0,131,1,11,0,87,0,12,0,97,0,12,0,49,0,11,0,102,0,12,0,49,6,13,0,50,6,13,0,172,0,13,0,29,3,12,0,118,0,12,0,58,0,11,0,101,1,12,0,102,12,14,0,3,0,2,0,84,0,7,0,171,2,10,0,22,0,13,0,247,5,14,0,5,0,4,0,248,0,9,0,169,10,12,0,95,0,15,0,4,0,4,0,28,0,10,0,80,21,13,0,4,0,5,0,119,0,11,0,108,7,15,0,14,0,5,0,10,0,12,0,12,0,5,0,98,5,11,0,4,0,6,0,28,3,12,0,6,0,6,0,200,0,13,0,13,0,6,0,218,1,13,0,7,0,6,0,201,0,13,0,1,0,7,0,46,0,14,0,20,0,7,0,150,21,13,0,10,0,7,0,194,10,12,0,22,0,7,0,91,1,14,0,21,0,7,0,90,1,14,0,15,0,8,0,94,0,15,0,126,0,8,0,171,0,8,0,45,0,9,0,216,0,9,0,11,0,9,0,20,0,10,0,179,2,10,0,243,1,10,0,58,0,10,0,0,0,10,0,88,0,10,0,46,0,9,0,94,0,10,0,99,5,11,0,236,0,12,0,84,0,12,0,193,10,12,0,86,21,13,0,250,2,13,0,129,1,11,0,87,21,13,0,157,5,14,0,163,42,14,0,42,43,14,0,222,1,14,0,60,6,13,0,207,0,13,0,148,21,13,0,13,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,12,13,13,14,14,15,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,0,0,0,0,0,1,1,1,1,2,2,2,3,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,0,0,0,0,32,32,31,31,32,33,31,33,33,32,32,30,34,31,32,29,33,30,32,33,31,35,34,30,34,31,33,29,29,31,33,35,30,30,35,32,32,34,34,28,25,32,36,27,32,32,32,37,39,3,32,30,31,26,31,32,32,38,29,29,32,34,31,31,34,35,33,33,28,33,1,33,27,29,30,31,28,29,37,35,31,33,35,27,36,37,25,25,61,35,4,5,32,33,36,30,23,30,28,34,31,32,32,39,32,34,21,39,32,59,32,28,32,36,60,33,24,36,32,32,41,2,32,38,26,22,33,30,31,32,32,30,31,32,29,3,40,38,32,32,33,26,31,34,28,38,34,31,3,31,35,38,27,35,33,28,29,27,29,27,43,29,37,63,31,33,34,30,31,30,37,30,35,35,26,41,37,31,33,28,26,30,42,24,7,27,33,29,36,28,34,57,23,41,36,23,35,34,25,30,25,33,25,25,29,24,33,39,33,33,0,37,31,36,21,32,61,24,35,61,31,5,31,59,39,21,32,30,34,22,40,32,29,16,31,5,62,2,20,39,39,32,33,1,31,24,36,32,36,32,28,26,6,31,38,34,58,35,32,33,33,17,43,26,31,40,31,34,32,32,31,19,30,32,29,33,38,38,32,59,40,18,38,32,35,34,32,17,1,15,30,28,31,28,34,29,32,27,35,27,49,22,37,34,37,26,32,32,22,28,45,29,30,31,43,46,41,30,26,13,34,32,27,38,42,42,33,47,33,60,27,42,25,32,22,32,48,32,45,33,33,41,27,25,19,31,35,19,36,42,27,17,31,44,28,33,33,31,23,31,40,33,31,34,30,32,33,36,35,47,37,41,31,23,41,29,30,35,32,25,32,28,58,2,37,33,14,33,49,20,39,36,21,9,23,33,35,24,39,37,11,33,30,31,31,28,51,40,35,29,25,33,46,35,37,30,30,8,63,28,15,40,33,45,49,25,32,4,47,51,36,39,53,10,24,29,30,31,25,40,38,38,33,56,23,27,32,37,26,29,43,36,33,24,55,43,9,29,34,34,24,33,18,33,33,30,31,50,24,60,30,39,34,30,39,28,22,38,2,26,63,32,57,21,39,33,28,18,30,34,22,33,29,41,30,34,35,21,13,34,35,39,30,46,32,42,32,31,33,26,11,33,22,31,25,31,53,27,43,25,40,50,21,36,38,30,12,31,34,20,15,29,32,62,30,13,17,32,19,31,20,31,30,7,1,17,34,37,31,31,44,34,26,40,16,37,52,48,30,20,18,33,38,29,7,25,30,54,45,47,46,41,29,29,16,30,14,26,38,34,34,29,34,30,29,30,57,30,4,46,33,29,39,44,30,31,50,33,31,32,19,32,40,31,37,47,1,35,16,31,0,35,33,1,17,34,9,34,33,31,49,43,42,51,34,29,23,29,14,30,45,49,11,24,31,28,35,41,30,44,18,29,34,35,36,25,26,21,31,30,34,19,34,44,36,38,25,31,28,23,37,3,55,41,30,22,41,24,33,26,35,35,30,55,51,47,48,38,24,15,21,50,25,46,30,29,10,34,42,45,29,42,22,3,33,27,34,1,34,28,34,36,35,23,23,13,58,3,26,63,25,31,34,61,38,39,25,61,29,37,30,41,26,48,28,33,50,35,30,37,29,29,40,6,39,28,28,19,8,22,45,34,35,10,58,17,37,39,30,18,54,14,29,16,59,30,35,23,35,30,47,36,29,55,20,12,31,35,14,29,18,34,34,24,29,26,22,2,27,23,8,30,55,38,60,31,4,34,49,34,27,34,33,30,31,54,42,35,38,46,44,26,27,9,39,25,21,29,28,42,13,0,5,34,37,28,24,29,63,26,22,27,29,25,33,25,61,0,35,25,36,15,27,40,53,33,3,10,16,37,38,18,30,46,27,9,6,29,62,8,42,28,29,3,25,16,26,29,35,28,27,51,61,48,37,9,34,7,49,45,20,29,21,5,5,29,28,34,29,24,10,24,35,36,38,55,11,36,38,53,54,26,30,49,20,27,30,39,33,41,49,22,38,38,4,30,8,9,3,24,22,50,37,36,31,27,2,9,42,63,25,19,44,1,28,28,48,30,34,41,41,38,12,27,15,0,16,34,35,38,28,29,40,42,51,52,45,54,59,59,42,44,37,26,46,24,15,39,22,46,19,35,38,17,37,23,52,55,50,37,26,11,37,12,24,30,16,13,22,13,36,35,40,41,34,41,26,53,51,5,21,30,2,63,41,20,1,56,21,24,25,5,28,35,26,28,30,18,29,23,40,34,20,42,39,34,28,61,38,27,62,9,36,17,9,49,24,25,54,34,39,37,3,1,25,38,38,44,35,36,12,60,36,38,40,25,43,39,53,28,39,57,46,10,52,27,35,42,45,59,15,60,38,24,23,39,12,29,24,0,20,16,28,43,35,28,1,49,4,21,42,39,29,3,44,21,53,55,11,5,3,39,53,28,25,19,34,28,21,0,0,0,0,0,32,31,32,31,33,32,33,33,31,34,30,32,32,34,35,32,34,33,29,30,30,32,31,31,33,35,35,33,31,29,29,33,34,30,31,28,36,30,34,32,32,37,32,32,25,27,39,32,32,32,38,35,36,32,37,61,26,32,34,35,3,35,27,28,29,34,28,37,31,36,32,27,31,30,29,39,33,29,33,35,25,25,29,33,31,31,31,33,32,30,32,32,41,39,33,36,32,28,34,36,38,24,60,31,23,28,32,33,59,32,40,30,5,34,32,38,32,30,43,4,32,32,42,31,31,32,26,38,26,22,21,37,61,63,37,31,32,33,2,1,23,33,41,27,35,30,38,23,33,3,28,34,34,27,41,29,39,35,36,29,32,27,30,32,24,61,37,26,59,25,35,27,36,37,30,31,34,40,3,28,34,39,32,31,32,30,24,28,35,36,26,32,31,33,29,33,39,25,30,24,35,59,29,34,25,30,21,35,43,40,32,29,5,28,31,62,33,33,25,31,21,31,43,31,34,33,20,40,39,31,31,57,38,32,42,33,32,31,32,29,30,44,5,31,22,34,36,17,38,58,38,35,32,60,35,24,32,38,16,45,42,32,31,29,4,30,17,40,46,48,63,32,42,19,41,22,28,36,45,33,33,32,29,7,41,42,18,33,33,32,22,37,1,26,22,23,49,28,26,27,32,33,27,23,28,36,15,6,34,27,31,26,23,2,33,32,34,41,28,32,41,0,36,38,34,31,47,32,17,31,39,33,37,51,30,47,32,50,32,19,63,30,25,27,33,62,24,31,27,30,37,31,45,32,39,20,46,47,35,19,34,1,49,21,21,14,51,26,23,31,36,35,58,29,29,21,20,42,13,28,12,40,31,33,39,60,32,44,33,31,28,37,29,32,30,49,43,28,39,25,32,48,2,15,20,25,31,28,21,24,25,15,31,17,37,43,18,32,33,24,33,36,13,33,31,39,11,31,33,32,39,37,32,32,29,17,44,46,36,35,26,37,58,32,34,38,8,38,38,22,29,25,16,35,32,35,33,43,18,46,38,50,33,18,53,60,13,32,36,33,51,36,43,45,27,42,29,24,30,25,31,52,31,35,38,9,22,34,4,17,28,55,42,25,17,20,47,34,33,16,40,25,16,30,53,29,10,11,14,26,33,4,35,44,26,16,31,26,34,38,29,31,30,24,22,61,32,9,45,34,31,19,9,31,46,31,35,54,29,57,30,50,3,31,63,34,47,41,51,18,31,14,37,38,31,24,32,31,50,33,31,54,27,9,33,23,19,32,29,29,33,28,47,49,30,47,33,27,25,54,44,45,50,58,51,48,33,59,33,34,57,13,26,33,13,48,30,11,7,56,34,55,26,0,26,35,1,51,33,53,31,45,12,29,29,51,31,48,2,6,34,30,28,33,60,40,27,46,31,9,35,29,31,39,55,46,19,37,62,34,30,16,19,49,41,41,39,37,14,5,13,35,55,30,40,40,42,8,20,25,45,35,33,36,54,38,27,37,62,40,15,59,49,31,29,34,34,39,24,29,25,29,21,29,10,61,33,49,35,34,3,38,39,29,7,41,1,35,4,23,15,23,11,37,28,35,30,30,24,1,43,56,8,34,42,24,45,30,20,23,8,38,22,33,17,52,34,22,53,43,44,1,27,31,41,43,41,30,31,36,30,5,55,31,33,30,40,23,15,29,34,34,59,34,30,11,13,38,5,0,30,42,5,30,29,34,10,44,30,63,35,12,3,26,15,17,25,34,43,39,34,56,29,23,30,12,30,10,35,9,24,58,10,12,54,33,37,20,41,35,29,18,61,30,40,24,39,53,62,26,29,33,34,53,49,21,27,11,63,20,26,23,7,13,6,47,29,30,9,51,22,34,21,25,33,56,57,30,38,51,51,38,63,28,40,35,33,18,33,33,24,58,58,34,49,29,43,4,1,4,42,35,35,30,17,5,56,61,25,37,36,55,28,35,29,50,48,52,2,42,34,40,46,46,43,35,29,48,20,29,31,41,7,30,35,19,14,21,8,39,39,40,46,55,34,6,30,34,37,25,37,33,22,44,52,17,35,29,36,35,40,37,28,30,50,14,28,55,6,23,19,14,30,3,30,28,28,61,61,47,45,48,40,40,34,34,25,30,29,35,4,26,53,50,26,41,27,59,27,38,39,3,50,43,47,23,33,55,35,21,23,35,61,33,46,52,35,34,24,30,43,16,37,21,2,24,45,34,30,55,55,1,29,29,26,28,25,31,36,22,17,30,52,2,44,44,57,26,62,41,39,57,26,46,49,11,16,19,5,59,38,39,58,38,25,49,50,22,28,59,9,59,7,28,55,17,4,35,50,21,29,44,47,18,24,19,25,42,35,3,51,35,16,35,30,63,57,39,39,25,35,38,9,16,36,45,31,60,14,34,42,24,0,37,18,61,57,37,28,53,20,46,14,47,38,38,38,9,34,39,43,17,39,59,5,27,0,12,27,0,0,0,0,0,0,0,7,0,9,0,15,0,10,0,17,0,26,0,28,0,17,0,49,0,37,0,45,0,47,0,111,0,117,0,65,0,76,0,78,0,92,0,96,0,98,0,102,0,104,0,105,0,107,0,166,0,193,0,203,0,204,0,206,0,218,0,232,0,238,0,135,0,144,0,158,0,159,0,186,0,202,0,216,0,219,0,223,0,4,1,9,1,12,1,67,1,69,1,74,1,86,1,92,1,179,1,211,1,218,1,3,1,9,1,11,1,34,1,39,1,52,1,97,1,100,1,118,1,132,1,141,1,142,1,143,1,144,1,147,1,150,1,157,1,158,1,159,1,169,1,178,1,180,1,186,1,187,1,188,1,1,2,2,2,5,2,7,2,13,2,16,2,17,2,21,2,27,2,31,2,129,2,133,2,144,2,156,2,157,2,162,2,167,2,168,2,170,2,176,2,177,2,180,2,188,2,191,2,32,3,38,3,39,3,41,3,42,3,54,3,96,3,98,3,99,3,114,3,178,3,188,3,189,3,3,2,5,2,26,2,73,2,74,2,76,2,199,2,202,2,206,2,239,2,13,3,34,3,37,3,56,3,115,3,122,3,9,4,21,4,22,4,24,4,40,4,45,4,47,4,52,4,8,5,9,5,16,5,17,5,28,5,30,5,36,5,65,5,67,5,70,5,71,5,77,5,87,5,95,5,106,5,108,5,109,5,111,5,118,5,119,5,122,5,123,5,124,5,125,5,0,6,1,6,3,6,20,6,22,6,23,6,28,6,31,6,66,6,72,6,73,6,74,6,75,6,87,6,104,6,105,6,107,6,110,6,127,6,194,6,200,6,203,6,222,6,223,6,226,6,227,6,239,6,72,7,75,7,110,7,111,7,124,7,9,4,35,4,40,4,41,4,42,4,43,4,50,4,51,4,150,4,154,4,213,4,219,4,129,5,130,5,139,5,140,5,141,5,152,5,153,5,154,5,158,5,221,5,25,6,50,6,51,6,72,6,114,6,161,6,162,6,163,6,175,6,226,6,227,6,228,6,0,8,1,8,2,8,3,8,26,8,27,8,41,8,47,8,50,8,62,8,63,8,82,8,83,8,88,8,107,8,119,8,120,8,121,8,122,8,123,8,0,10,1,10,13,10,14,10,15,10,36,10,55,10,58,10,59,10,62,10,70,10,71,10,74,10,75,10,95,10,121,10,122,10,123,10,128,10,129,10,132,10,133,10,153,10,165,10,166,10,184,10,186,10,187,10,188,10,189,10,200,10,206,10,207,10,215,10,220,10,235,10,4,12,37,12,38,12,39,12,42,12,43,12,58,12,59,12,60,12,61,12,160,12,173,12,212,12,213,12,252,12,253,12,134,13,146,13,147,13,148,13,149,13,176,13,184,13,185,13,186,13,187,13,192,13,194,13,195,13,218,13,219,13,220,13,221,13,146,14,147,14,148,14,149,14,199,14,204,14,206,14,207,14,216,14,217,14,218,14,219,14,8,8,9,8,10,8,16,8,17,8,68,8,69,8,97,8,98,8,99,8,108,8,34,9,35,9,46,9,47,9,54,9,55,9,177,9,178,9,179,9,180,9,181,9,184,9,185,9,186,9,187,9,188,9,189,9,190,9,191,9,0,11,21,11,44,11,45,11,46,11,47,11,54,11,185,11,40,12,42,12,43,12,44,12,45,12,46,12,47,12,48,12,49,12,56,12,96,12,97,12,98,12,99,12,141,12,142,12,143,12,146,12,190,12,191,12,230,12,231,12,64,13,65,13,87,13,88,13,89,13,90,13,91,13,92,13,93,13,152,13,153,13,154,13,155,13,156,13,157,13,173,13,174,13,175,13,192,13,193,13,194,13,195,13,202,13,203,13,236,13,237,13,238,13,239,13,24,16,34,16,35,16,48,16,49,16,50,16,51,16,80,16,81,16,92,16,116,16,117,16,118,16,119,16,120,16,121,16,122,16,123,16,178,16,179,16,184,16,185,16,186,16,187,16,212,16,234,16,235,16,236,16,237,16,4,20,5,20,6,20,7,20,16,20,17,20,18,20,19,20,20,20,21,20,22,20,23,20,24,20,25,20,102,20,103,20,104,20,105,20,106,20,107,20,108,20,109,20,126,20,127,20,136,20,137,20,138,20,139,20,182,20,183,20,184,20,185,20,186,20,187,20,188,20,189,20,240,20,241,20,248,20,249,20,250,20,251,20,252,20,253,20,254,20,255,20,42,21,43,21,44,21,45,21,46,21,47,21,48,21,49,21,72,21,73,21,78,21,79,21,88,21,89,21,90,21,91,21,114,21,154,21,155,21,172,21,186,21,187,21,208,21,209,21,210,21,211,21,212,21,213,21,29,24,30,24,31,24,64,24,65,24,66,24,67,24,68,24,69,24,70,24,71,24,72,24,73,24,97,24,98,24,99,24,100,24,101,24,102,24,103,24,104,24,105,24,106,24,107,24,108,24,109,24,110,24,27,25,28,25,29,25,30,25,31,25,66,25,67,25,68,25,69,25,70,25,71,25,88,25,89,25,237,25,238,25,239,25,240,25,241,25,242,25,243,25,244,25,245,25,246,25,247,25,14,27,15,27,98,27,99,27,100,27,101,27,102,27,103,27,104,27,105,27,106,27,107,27,108,27,109,27,110,27,111,27,130,27,168,27,169,27,170,27,171,27,172,27,173,27,174,27,175,27,176,27,177,27,178,27,179,27,128,29,129,29,130,29,131,29,132,29,133,29,134,29,135,29,136,29,137,29,138,29,139,29,140,29,141,29,7,16,8,16,9,16,10,16,11,16,12,16,13,16,14,16,15,16,22,16,128,16,129,16,130,16,131,16,132,16,133,16,134,16,135,16,192,16,58,18,59,18,60,18,61,18,62,18,63,18,64,18,65,18,66,18,67,18,80,19,82,19,83,19,88,19,89,19,90,19,91,19,92,19,93,19,94,19,95,19,96,19,97,19,2,22,3,22,12,22,13,22,14,22,15,22,32,22,33,22,34,22,35,22,36,22,37,22,38,22,39,22,40,22,41,22,110,22,111,22,124,22,125,22,126,22,127,22,112,23,113,23,82,24,83,24,114,24,115,24,116,24,117,24,118,24,119,24,120,24,121,24,122,24,123,24,124,24,125,24,126,24,127,24,24,25,25,25,38,25,39,25,112,25,113,25,114,25,115,25,116,25,117,25,118,25,119,25,120,25,121,25,122,25,123,25,160,26,161,26,162,26,163,26,164,26,165,26,166,26,167,26,168,26,169,26,170,26,171,26,172,26,173,26,60,27,61,27,62,27,63,27,80,27,81,27,82,27,83,27,84,27,85,27,86,27,87,27,88,27], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+194560);
/* memory initializer */ allocate([89,27,50,32,51,32,52,32,53,32,54,32,55,32,56,32,57,32,58,32,59,32,60,32,61,32,62,32,63,32,64,32,65,32,66,32,67,32,186,32,187,32,204,32,205,32,206,32,207,32,224,32,225,32,226,32,227,32,228,32,229,32,230,32,231,32,170,33,171,33,192,33,193,33,194,33,195,33,196,33,197,33,198,33,199,33,200,33,201,33,202,33,203,33,204,33,205,33,206,33,207,33,208,33,209,33,210,33,211,33,148,40,149,40,150,40,151,40,152,40,153,40,154,40,155,40,156,40,157,40,158,40,159,40,192,40,193,40,194,40,195,40,196,40,197,40,198,40,199,40,200,40,201,40,202,40,203,40,48,41,49,41,50,41,51,41,52,41,53,41,54,41,55,41,56,41,57,41,58,41,59,41,60,41,61,41,62,41,63,41,96,41,97,41,98,41,99,41,100,41,101,41,102,41,103,41,104,41,105,41,106,41,107,41,64,42,65,42,66,42,67,42,68,42,69,42,70,42,71,42,72,42,73,42,74,42,75,42,76,42,77,42,78,42,79,42,80,42,81,42,82,42,83,42,230,42,231,42,36,43,37,43,38,43,39,43,40,43,41,43,42,43,43,43,44,43,45,43,46,43,47,43,48,43,49,43,50,43,51,43,90,43,91,43,20,48,21,48,22,48,23,48,32,48,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,42,48,43,48,44,48,45,48,46,48,47,48,48,48,49,48,50,48,51,48,52,48,53,48,54,48,55,48,56,48,57,48,192,48,193,48,222,48,223,48,24,50,25,50,26,50,27,50,28,50,29,50,30,50,31,50,32,50,33,50,34,50,35,50,36,50,37,50,38,50,39,50,40,50,41,50,42,50,43,50,44,50,45,50,46,50,47,50,48,50,49,50,50,50,51,50,52,50,53,50,120,51,121,51,122,51,123,51,124,51,125,51,126,51,127,51,192,51,193,51,194,51,195,51,196,51,197,51,198,51,199,51,200,51,201,51,202,51,203,51,204,51,205,51,206,51,207,51,208,51,209,51,210,51,211,51,212,51,213,51,214,51,215,51,216,51,217,51,6,55,7,55,48,55,49,55,50,55,51,55,52,55,53,55,54,55,55,55,56,55,57,55,58,55,59,55,60,55,61,55,62,55,63,55,64,55,65,55,66,55,67,55,68,55,69,55,70,55,71,55,72,55,73,55,74,55,75,55,76,55,77,55,78,55,79,55,52,59,53,59,54,59,55,59,232,59,233,59,234,59,235,59,236,59,237,59,238,59,239,59,240,59,241,59,242,59,243,59,244,59,245,59,246,59,247,59,248,59,249,59,250,59,251,59,252,59,253,59,254,59,255,59,0,32,1,32,2,32,3,32,4,32,5,32,6,32,7,32,8,32,9,32,10,32,11,32,12,32,13,32,46,32,47,32,130,33,131,33,180,33,181,33,182,33,183,33,184,33,185,33,186,33,187,33,188,33,189,33,190,33,191,33,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,106,36,107,36,108,36,109,36,110,36,111,36,112,36,113,36,114,36,115,36,162,38,163,38,11,0,2,4,4,4,5,5,5,5,6,6,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,4,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,1,2,3,4,5,6,7,8,9,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,4,5,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,1,0,2,0,6,0,3,0,15,0,4,0,22,0,5,0,32,0,6,0,24,0,7,0,8,0,8,0,154,0,8,0,86,0,9,0,62,1,9,0,240,0,10,0,165,3,10,0,119,0,11,0,239,1,11,0,154,0,12,0,93,0,13,0,1,0,4,0,17,0,5,0,2,0,7,0,11,0,8,0,18,0,9,0,214,1,9,0,126,2,10,0,145,1,11,0,234,0,12,0,220,3,12,0,59,1,13,0,4,0,5,0,20,0,7,0,158,0,8,0,9,0,10,0,172,1,11,0,226,1,11,0,202,3,12,0,95,0,13,0,23,0,5,0,78,0,7,0,94,0,9,0,243,0,10,0,173,1,11,0,236,0,12,0,240,5,13,0,14,0,6,0,225,0,8,0,164,3,10,0,156,0,12,0,61,1,13,0,59,0,6,0,28,0,9,0,20,0,11,0,190,9,12,0,6,0,7,0,122,0,9,0,144,1,11,0,55,1,13,0,27,0,7,0,8,0,10,0,92,7,11,0,113,0,7,0,215,0,10,0,191,9,12,0,7,0,8,0,175,0,10,0,204,4,11,0,52,0,8,0,101,2,10,0,159,0,12,0,224,0,8,0,22,0,11,0,39,3,12,0,21,0,9,0,125,1,11,0,187,14,12,0,20,0,9,0,246,0,10,0,228,1,11,0,203,0,10,0,157,9,12,0,202,0,10,0,252,2,12,0,127,1,11,0,205,4,11,0,253,2,12,0,254,4,11,0,58,1,13,0,10,0,4,0,66,0,7,0,211,1,9,0,221,4,11,0,18,0,5,0,232,0,8,0,76,0,11,0,54,1,13,0,57,0,6,0,100,2,10,0,186,14,12,0,0,0,7,0,174,0,10,0,156,9,12,0,31,0,7,0,222,4,11,0,67,0,7,0,220,4,11,0,3,0,8,0,203,3,12,0,6,0,8,0,158,9,12,0,42,0,8,0,241,5,13,0,15,0,8,0,254,9,12,0,51,0,8,0,255,9,12,0,152,0,8,0,159,9,12,0,234,0,8,0,60,1,13,0,46,0,8,0,146,1,11,0,54,1,9,0,106,0,9,0,21,0,11,0,175,3,10,0,227,1,11,0,116,0,11,0,235,0,12,0,249,2,12,0,92,0,13,0,237,0,12,0,221,3,12,0,38,3,12,0,94,0,13,0,22,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,12,13,13,13,14,14,15,15,16,17,18,19,20,0,0,0,0,1,1,1,1,2,2,2,3,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,15,16,17,18,19,20,21,22,23,24,25,26,0,0,0,0,32,31,32,33,32,31,31,33,33,34,32,30,32,35,34,31,32,29,33,30,32,34,33,31,30,35,31,31,29,33,35,30,29,33,34,34,30,32,32,36,29,32,35,32,28,32,32,27,35,37,34,29,30,36,35,34,25,30,29,35,33,31,31,32,31,28,39,28,29,37,31,33,27,36,28,36,37,33,33,31,27,32,31,38,26,25,25,33,39,31,34,30,32,32,32,34,36,32,28,33,30,38,37,27,33,28,32,37,35,38,29,34,27,29,29,32,32,34,35,3,26,36,31,38,30,26,35,34,37,26,25,32,32,39,23,37,32,32,29,32,29,36,29,30,41,31,30,21,39,25,34,38,32,35,39,32,33,33,32,27,29,25,28,27,26,31,30,35,24,24,31,34,32,30,35,40,28,38,5,35,29,36,36,32,38,30,33,31,35,26,23,38,32,41,28,25,37,40,37,39,32,36,33,39,25,26,28,31,28,42,23,31,33,31,39,1,59,22,27,4,33,34,33,24,41,3,35,41,41,28,36,36,28,33,35,21,23,21,22,37,27,27,43,29,60,39,27,25,59,34,27,27,26,40,37,27,61,26,39,33,31,22,37,25,30,25,24,61,31,34,25,38,32,32,30,3,61,43,29,23,28,32,28,32,31,34,5,33,32,33,33,42,37,23,38,31,40,26,32,26,37,38,36,24,29,30,20,22,29,24,32,41,2,34,25,33,29,31,39,35,36,24,32,30,33,27,44,60,30,36,19,34,31,24,16,35,32,38,21,33,31,31,21,35,5,17,29,38,38,18,58,19,43,41,30,41,43,39,29,7,29,17,28,19,28,31,25,19,40,26,21,33,39,23,40,30,39,34,35,32,32,24,33,30,40,47,39,37,32,33,24,23,45,47,27,23,42,32,32,33,36,37,37,17,18,22,40,38,32,31,35,24,17,25,17,23,33,34,51,42,31,36,36,29,21,22,37,44,43,25,47,33,45,27,31,58,31,32,31,38,43,20,47,45,54,1,26,34,38,14,22,24,33,34,32,32,37,21,23,49,35,23,28,39,39,23,55,33,30,30,63,16,42,28,13,33,33,35,19,46,43,17,19,36,39,24,31,32,33,26,28,62,33,63,33,39,19,49,17,31,43,13,15,29,25,35,33,23,49,41,28,29,34,38,7,61,11,50,13,41,19,47,25,26,15,42,41,29,45,27,17,35,32,29,32,24,13,26,26,31,24,33,28,30,31,11,45,46,33,33,35,57,32,32,35,45,34,11,37,42,39,37,31,49,21,27,29,47,53,40,51,16,26,1,40,30,41,44,34,25,27,31,35,35,31,15,49,1,35,40,5,58,21,29,22,59,45,31,9,26,9,29,11,32,30,3,13,20,18,20,11,3,29,40,31,53,30,17,20,37,31,42,47,47,54,38,9,34,13,37,21,25,27,43,42,45,40,25,27,46,22,25,53,20,2,14,39,15,22,44,34,21,38,33,27,48,34,52,35,47,49,54,2,13,23,52,29,45,22,49,54,21,40,42,31,30,29,34,0,25,23,51,24,59,28,38,29,31,2,13,31,8,31,33,12,45,41,7,14,30,25,18,43,20,43,35,44,1,49,42,42,18,41,38,41,44,53,11,20,25,45,46,47,48,39,52,46,49,63,55,44,38,13,13,57,22,51,16,12,28,35,57,25,20,26,28,28,29,32,31,62,34,35,35,19,49,48,39,40,18,43,46,11,6,48,19,49,41,10,23,58,17,21,23,34,30,60,0,44,34,26,37,46,43,49,59,4,34,59,37,22,25,28,46,6,40,59,42,36,61,28,30,31,43,10,22,23,47,20,52,55,36,25,16,1,11,27,29,5,63,18,41,31,34,38,1,5,13,28,31,17,38,39,41,36,37,22,39,33,43,43,15,17,49,30,21,22,20,10,17,25,54,57,3,34,8,36,25,31,14,15,19,29,25,18,39,53,22,27,20,29,33,41,42,35,62,50,29,53,50,35,55,42,61,63,4,7,42,21,46,47,49,27,46,17,55,41,50,63,4,56,18,8,10,18,51,63,36,55,18,5,55,9,29,17,21,30,27,1,59,7,11,12,15,5,42,24,41,43,7,27,22,25,31,30,37,22,39,53,29,36,37,48,0,5,13,17,31,32,26,46,28,44,45,46,53,49,51,3,41,3,22,42,33,5,45,7,22,40,53,24,14,25,27,10,12,34,16,17,53,20,26,39,45,18,45,35,33,31,49,4,39,42,11,51,5,13,26,27,17,52,30,0,22,12,34,62,36,38,41,47,30,63,38,41,43,59,33,45,37,38,40,47,24,48,49,30,1,10,22,49,15,39,59,31,32,33,18,13,15,31,21,27,44,42,39,46,17,26,32,30,31,0,30,34,9,12,13,25,31,32,55,43,35,61,33,35,46,25,47,48,62,63,38,61,1,2,5,7,9,46,10,34,35,36,55,51,7,40,23,34,37,5,13,42,18,25,27,28,0,0,0,0,0,32,32,31,32,33,31,33,31,33,32,34,32,30,32,31,34,35,32,34,33,29,33,30,30,31,31,35,29,33,35,33,34,31,29,30,34,30,36,28,32,34,37,30,27,32,25,39,32,34,32,35,35,35,31,35,29,32,29,30,29,37,27,36,38,37,33,32,31,29,31,28,36,33,30,34,33,33,28,27,25,31,26,39,32,32,31,33,39,31,38,28,36,21,23,43,36,34,41,30,25,28,31,30,34,38,35,61,34,28,30,37,37,35,27,36,3,59,38,37,32,31,29,26,33,37,33,27,27,35,34,34,40,42,33,32,29,4,5,28,24,25,35,39,38,32,23,27,32,30,35,26,34,60,36,29,22,26,41,7,30,38,30,36,29,30,41,26,25,32,34,24,39,1,25,39,32,28,29,32,38,26,36,28,63,28,39,23,21,26,35,31,35,57,31,29,29,28,30,27,35,2,38,40,34,37,29,38,43,26,32,33,42,24,40,28,32,32,32,36,32,43,25,21,31,30,31,41,29,33,37,26,37,27,59,23,33,35,31,31,37,38,39,32,23,32,27,37,36,31,40,25,27,38,31,36,28,31,36,25,45,3,34,38,39,40,38,30,32,19,24,25,26,45,20,24,33,33,31,41,34,39,47,40,58,59,41,33,3,17,61,42,30,26,29,36,61,33,37,62,28,25,38,25,38,17,23,34,33,21,33,49,27,32,23,27,22,24,22,39,43,27,37,6,42,47,26,30,31,41,39,33,22,45,36,32,45,19,22,30,5,5,17,29,22,31,31,43,37,27,32,32,32,33,34,43,35,29,26,22,32,19,32,25,31,41,49,28,34,28,39,34,19,37,38,29,21,36,42,24,48,16,28,49,22,34,31,38,39,44,11,35,30,33,33,23,28,33,46,15,13,24,41,24,34,34,30,26,24,14,60,21,29,39,23,35,37,63,45,33,34,47,41,22,42,35,35,23,32,35,43,32,7,31,41,20,31,16,13,63,25,30,32,35,30,30,31,42,47,39,38,40,40,51,55,56,18,21,39,39,33,17,41,23,24,43,25,31,20,19,45,1,34,31,22,35,15,46,46,35,31,28,29,29,23,41,27,14,53,53,27,24,32,57,32,17,42,37,29,33,1,25,32,32,63,26,40,44,36,31,39,20,20,44,23,33,34,35,33,33,28,41,23,41,41,29,25,26,49,29,24,37,49,50,51,51,26,39,25,26,15,39,18,42,17,4,31,32,32,60,1,42,32,0,12,19,35,21,41,17,26,20,45,46,32,37,22,47,29,31,27,29,30,21,33,35,18,25,33,50,51,42,2,15,51,53,33,25,29,55,37,38,33,38,59,38,33,39,13,32,40,61,61,32,9,44,3,31,29,25,31,27,23,9,25,9,29,20,30,30,42,18,28,25,28,28,21,29,43,29,43,26,44,44,21,38,21,24,45,45,35,39,22,35,36,34,34,45,34,29,31,46,25,46,16,17,31,20,32,47,47,47,32,49,49,49,31,1,27,28,39,39,21,36,23,51,2,40,51,32,53,24,30,24,30,21,40,57,57,31,41,58,32,12,4,32,34,59,31,32,13,9,35,26,35,37,61,37,63,26,29,41,38,23,20,41,26,41,42,42,42,26,26,26,26,1,26,37,37,37,23,34,42,27,43,34,27,31,24,33,16,3,31,24,33,24,4,44,44,11,44,31,13,13,44,45,13,25,22,38,26,38,38,39,32,30,39,30,22,32,26,30,47,47,47,19,47,30,31,35,8,23,47,47,27,35,47,31,48,35,19,36,49,49,33,31,39,27,39,49,49,50,50,50,39,31,51,51,39,28,33,33,21,40,31,52,53,40,53,9,33,31,53,54,54,54,55,55,34,15,56,25,56,21,21,40,40,25,40,58,36,5,41,41,12,60,41,41,37,22,61,18,29,29,30,61,30,61,62,62,30,30,63,18,13,30,23,19,20,20,41,13,2,5,5,1,5,32,6,32,35,20,35,27,35,35,36,36,13,36,41,41,41,3,30,42,27,20,30,27,28,30,21,33,33,14,24,30,42,24,33,25,42,43,14,43,43,14,43,7,36,37,37,37,37,7,14,25,43,43,44,15,37,7,7,3,1,8,15,15,8,44,44,44,45,45,45,45,8,8,45,21,45,28,28,28,21,28,28,22,37,46,46,37,8,29,37,29,22,46,37,22,29,47,47,38,38,16,38,38,33,38,22,47,47,29,25,16,0,48,1,34,48,48,34,25,26,26,49,49,26,1,49,4,26,4,49,1,9,49,49,49,10,49,17,38,17,17,50,38,50,50,22,38,51,38,38,51,39,39,18,22,39,51,22,52,52,52,39,53,53,10,23,18,29,10,53,29,54,11,54,11,11,55,1,18,55,55,55,55,55,55,29,34,18,29,56,56,34,57,34,34,29,29,57,57,35,35,35,35,35,39,35,59,59,18,59,39,30,18,40,60,60,61,30,18,61,61,19,19,0,0,0,0,0,1,0,3,0,5,0,7,0,3,0,8,0,12,0,1,0,2,0,27,0,6,0,11,0,21,0,2,0,14,0,15,0,20,0,32,0,34,0,37,0,39,0,41,0,45,0,75,0,77,0,3,0,34,0,35,0,37,0,39,0,66,0,72,0,73,0,80,0,92,0,145,0,159,0,14,0,67,0,76,0,84,0,86,0,140,0,152,0,154,0,155,0,177,0,178,0,32,1,33,1,38,1,51,1,57,1,161,1,164,1,165,1,166,1,167,1,174,1,175,1,11,0,25,0,133,0,144,0,155,0,170,0,175,0,12,1,14,1,28,1,30,1,51,1,68,1,96,1,116,1,117,1,119,1,120,1,73,2,75,2,82,2,97,2,101,2,112,2,82,3,83,3,85,3,89,3,16,0,17,0,19,0,52,0,53,0,54,0,55,0,61,0,62,0,9,1,38,1,86,1,26,2,30,2,58,2,62,2,142,2,143,2,207,2,145,4,148,4,159,4,160,4,163,4,166,4,167,4,173,4,174,4,192,4,196,4,198,4,200,4,201,4,245,4,246,4,247,4,128,6,130,6,131,6,136,6,137,6,141,6,142,6,143,6,162,6,163,6,169,6,176,6,177,6,180,6,181,6,36,0,96,0,99,0,120,0,121,0,17,2,68,2,69,2,71,2,72,2,73,2,74,2,75,2,107,2,175,2,184,2,187,2,54,4,118,4,119,4,126,4,200,4,201,4,202,4,20,5,134,5,135,5,152,5,157,5,217,5,218,5,32,9,33,9,59,9,60,9,61,9,66,9,67,9,68,9,69,9,89,9,94,9,95,9,130,9,131,9,142,9,143,9,196,9,231,9,232,9,233,9,2,13,23,13,24,13,25,13,65,13,66,13,67,13,80,13,95,13,109,13,110,13,111,13,82,0,83,0,84,0,85,0,86,0,87,0,194,0,195,0,196,0,197,0,30,4,31,4,32,4,33,4,140,4,141,4,211,4,212,4,213,4,92,5,93,5,114,5,115,5,116,5,117,5,222,8,223,8,254,8,255,8,150,9,54,10,55,10,8,11,9,11,10,11,11,11,50,11,51,11,52,11,53,11,54,11,55,11,56,11,57,11,176,11,247,11,248,11,249,11,250,11,251,11,252,11,253,11,254,11,255,11,84,18,85,18,86,18,87,18,112,18,113,18,114,18,115,18,116,18,117,18,171,18,172,18,173,18,174,18,175,18,176,18,177,18,21,19,22,19,23,19,191,19,192,19,193,19,194,19,195,19,196,19,197,19,198,19,199,19,200,19,201,19,202,19,203,19,204,19,205,19,6,26,7,26,40,26,41,26,42,26,43,26,44,26,45,26,128,26,187,26,188,26,189,26,216,26,217,26,148,0,149,0,150,0,151,0,160,0,161,0,162,0,163,0,49,8,50,8,51,8,52,8,53,8,54,8,55,8,56,8,57,8,58,8,59,8,57,9,58,9,59,9,60,9,61,9,62,9,63,9,160,9,161,9,162,9,163,9,164,9,165,9,172,17,173,17,174,17,175,17,176,17,177,17,178,17,179,17,180,17,181,17,182,17,183,17,184,17,185,17,186,17,187,17,47,19,84,20,85,20,86,20,87,20,88,20,89,20,90,20,91,20,92,20,93,20,94,20,95,20,96,20,97,20,98,20,99,20,100,20,101,20,102,20,103,20,104,20,105,20,106,20,107,20,222,23,223,23,224,23,225,23,226,23,227,23,228,23,229,23,230,23,231,23,232,23,233,23,234,23,235,23,236,23,237,23,64,37,65,37,66,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,75,37,76,37,77,37,78,37,79,37,80,37,81,37,82,37,83,37,84,37,85,37,40,38,102,39,103,39,104,39,105,39,106,39,107,39,108,39,109,39,110,39,111,39,112,39,113,39,114,39,115,39,116,39,117,39,118,39,119,39,120,39,121,39,122,39,123,39,124,39,125,39,3,53,68,53,69,53,70,53,71,53,96,53,97,53,98,53,99,53,100,53,101,53,102,53,103,53,104,53,105,53,106,53,107,53,108,53,109,53,110,53,111,53,112,53,113,53,114,53,115,53,116,53,117,53,240,3,61,16,62,16,63,16,64,16,65,16,66,16,67,16,68,16,69,16,70,16,71,16,72,16,73,16,74,16,75,16,76,16,77,16,78,16,79,16,80,16,81,16,82,16,83,16,84,16,85,16,86,16,87,16,88,16,89,16,90,16,91,16,92,16,93,16,94,16,95,16,96,16,97,16,112,18,113,18,184,33,185,33,186,33,187,33,188,33,189,33,190,33,191,33,240,33,241,33,242,33,243,33,244,33,245,33,246,33,247,33,248,33,249,33,250,33,251,33,252,33,253,33,254,33,255,33,64,35,65,35,66,35,67,35,68,35,69,35,70,35,71,35,72,35,73,35,74,35,75,35,76,35,77,35,78,35,79,35,80,35,81,35,82,35,83,35,84,35,85,35,86,35,87,35,92,38,136,47,137,47,138,47,139,47,140,47,141,47,142,47,143,47,144,47,145,47,146,47,147,47,148,47,149,47,150,47,151,47,152,47,153,47,154,47,155,47,156,47,157,47,158,47,159,47,160,47,161,47,162,47,163,47,164,47,165,47,166,47,167,47,168,47,169,47,170,47,171,47,172,47,173,47,174,47,175,47,176,47,177,47,178,47,179,47,180,47,181,47,182,47,183,47,184,47,185,47,186,47,187,47,82,76,83,76,40,78,41,78,42,78,43,78,44,78,45,78,46,78,47,78,48,78,49,78,50,78,51,78,52,78,53,78,54,78,55,78,56,78,57,78,58,78,59,78,60,78,61,78,62,78,63,78,128,78,129,78,130,78,131,78,132,78,133,78,134,78,135,78,136,78,137,78,138,78,139,78,140,78,141,78,142,78,143,78,144,78,145,78,146,78,147,78,148,78,149,78,150,78,151,78,152,78,153,78,154,78,155,78,156,78,157,78,158,78,159,78,160,78,161,78,162,78,163,78,164,78,165,78,166,78,167,78,168,78,169,78,170,78,171,78,172,78,173,78,174,78,175,78,176,78,177,78,178,78,179,78,180,78,181,78,182,78,183,78,184,78,185,78,186,78,187,78,188,78,189,78,190,78,191,78,192,78,193,78,194,78,195,78,196,78,197,78,198,78,199,78,200,78,201,78,202,78,203,78,4,106,5,106,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,234,7,235,7,236,7,237,7,238,7,239,7,240,7,241,7,242,7,243,7,244,7,245,7,246,7,247,7,248,7,249,7,250,7,251,7,252,7,253,7,254,7,255,7,0,32,1,32,2,32,3,32,4,32,5,32,6,32,7,32,8,32,9,32,10,32,11,32,12,32,13,32,14,32,15,32,16,32,17,32,18,32,19,32,20,32,21,32,22,32,23,32,24,32,25,32,26,32,27,32,28,32,29,32,30,32,31,32,32,32,33,32,34,32,35,32,36,32,37,32,38,32,39,32,40,32,41,32,42,32,43,32,44,32,45,32,46,32,47,32,48,32,49,32,50,32,51,32,52,32,53,32,54,32,55,32,56,32,57,32,58,32,59,32,60,32,61,32,62,32,63,32,64,32,65,32,66,32,67,32,68,32,69,32,70,32,71,32,72,32,73,32,74,32,75,32,76,32,77,32,78,32,79,32,80,32,81,32,82,32,83,32,84,32,85,32,86,32,87,32,88,32,89,32,90,32,91,32,92,32,93,32,94,32,95,32,96,32,97,32,98,32,99,32,100,32,101,32,102,32,103,32,104,32,105,32,106,32,107,32,108,32,109,32,110,32,111,32,112,32,113,32,114,32,115,32,116,32,117,32,118,32,119,32,120,32,121,32,186,76,187,76,136,93,137,93,138,93,139,93,140,93,141,93,142,93,143,93,176,93,177,93,178,93,179,93,180,93,181,93,182,93,183,93,184,93,185,93,186,93,187,93,188,93,189,93,190,93,191,93,64,94,65,94,66,94,67,94,68,94,69,94,70,94,71,94,72,94,73,94,74,94,75,94,76,94,77,94,78,94,79,94,80,94,81,94,82,94,83,94,84,94,85,94,86,94,87,94,88,94,89,94,90,94,91,94,92,94,93,94,94,94,95,94,96,94,97,94,98,94,99,94,100,94,101,94,102,94,103,94,104,94,105,94,106,94,107,94,108,94,109,94,110,94,111,94,112,94,113,94,114,94,115,94,116,94,117,94,118,94,119,94,120,94,121,94,122,94,123,94,124,94,125,94,126,94,127,94,128,94,129,94,130,94,131,94,132,94,133,94,134,94,135,94,136,94,137,94,138,94,139,94,140,94,141,94,142,94,143,94,144,94,145,94,146,94,147,94,148,94,149,94,150,94,151,94,152,94,153,94,154,94,155,94,156,94,157,94,158,94,159,94,160,94,161,94,162,94,163,94,164,94,165,94,166,94,167,94,168,94,169,94,170,94,171,94,172,94,173,94,174,94,175,94,176,94,177,94,178,94,179,94,180,94,181,94,182,94,183,94,184,94,185,94,186,94,187,94,188,94,189,94,190,94,191,94,192,94,193,94,194,94,195,94,196,94,197,94,198,94,199,94,200,94,201,94,202,94,203,94,204,94,205,94,206,94,207,94,208,94,209,94,210,94,211,94,212,94,213,94,214,94,215,94,216,94,217,94,218,94,219,94,220,94,221,94,222,94,223,94,224,94,225,94,226,94,227,94,228,94,229,94,230,94,231,94,232,94,233,94,234,94,235,94,236,94,237,94,238,94,239,94,240,94,241,94,242,94,243,94,244,94,245,94,246,94,247,94,248,94,249,94,250,94,251,94,252,94,253,94,254,94,255,94,0,95,1,95,2,95,3,95,4,95,5,95,6,95,7,95,8,95,9,95,10,95,11,95,12,95,13,95,14,95,15,95,0,0,1,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,8,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,1,2,3,4,5,6,7,8,9,10,11,1,2,3,4,5,6,7,8,1,2,3,4,5,6,7,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,1,1,1,1,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,1,163,100,0,0,0,0,0,2,163,100,1,0,0,0,0,3,163,100,0,0,0,0,0,4,163,100,1,0,0,0,100,163,1,0,1,0,0,0,100,163,2,0,0,0,0,0,100,163,3,0,1,0,0,0,4,0,179,5,54,11,144,16,196,21,211,26,191,31,139,36,56,41,199,45,58,50,147,54,209,58,248,62,6,67,255,70,226,74,177,78,108,82,20,86,170,89,46,93,162,96,5,100,89,103,158,106,212,109,252,112,23,116,36,119,37,122,25,125,1,128,0,0,0,0,0,0,255,127,226,127,105,127,165,126,145,125,49,124,132,122,140,120,72,118,189,115,233,112,209,109,116,106,214,102,248,98,221,94,136,90,251,85,57,81,69,76,34,71,211,65,91,60,190,54,255,48,35,43,43,37,29,31,251,24,202,18,142,12,73,6,1,0,185,249,117,243,56,237,7,231,230,224,215,218,224,212,3,207,68,201,167,195,48,190,225,184,189,179,201,174,7,170,122,165,37,161,10,157,44,153,142,149,49,146,24,143,69,140,185,137,118,135,125,133,208,131,112,130,93,129,152,128,32,128,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,0,1,1,1,0,0,0,1,0,0,1,0,0,0,0,1,1,0,1,0,0,1,1,1,0,0,0,1,0,0,1,0,0,0,0,1,1,0,1,0,0,1,1,1,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,0,1,1,0,0,1,1,0,0,0,1,0,0,1,0,1,1,0,1,1,0,1,1,0,1,1,0,1,1,0,1,1,0,0,1,0,0,1,0,0,1,0,0,1,0,0,1,1,1,0,0,0,1,1,1,0,0,0,0,1,1,1,0,0,0,1,1,1,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,1,1,1,1,1,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+204800);
/* memory initializer */ allocate([1,1,1,1,1,1,1,1,1,1,1,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,0,1,0,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,0,1,1,0,0,1,1,0,0,1,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,0,0,1,1,1,1,0,0,0,0,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,0,0,1,0,1,0,0,0,0,0,0,0,168,87,138,62,37,117,2,63,134,201,36,63,56,103,68,63,39,194,118,63,167,232,136,63,154,153,161,63,101,25,202,63,23,217,246,63,79,64,15,64,91,211,32,64,63,53,54,64,14,45,50,62,45,67,188,62,255,178,27,63,11,181,86,63,13,224,141,63,249,160,175,63,0,111,209,63,75,200,239,63,147,24,4,64,95,7,22,64,241,244,38,64,11,181,54,64,82,73,29,62,130,226,167,62,42,169,3,63,36,151,47,63,204,238,121,63,138,31,163,63,119,190,199,63,18,165,237,63,222,113,6,64,123,20,22,64,72,225,38,64,215,163,56,64,225,122,84,62,240,22,232,62,180,89,69,63,91,211,132,63,100,204,165,63,138,176,193,63,61,44,228,63,20,63,2,64,117,147,16,64,114,249,31,64,238,124,43,64,185,252,55,64,169,164,14,62,236,47,123,62,110,52,192,62,200,152,11,63,188,150,80,63,204,127,144,63,224,45,184,63,119,45,225,63,91,66,2,64,117,147,20,64,68,250,37,64,148,246,54,64,0,0,0,62,208,179,185,62,143,228,66,63,252,169,145,63,82,73,181,63,100,59,199,63,117,147,216,63,98,16,232,63,18,20,239,63,153,187,2,64,156,162,27,64,125,174,54,64,176,3,103,62,181,55,216,62,212,43,37,63,104,34,92,63,73,157,136,63,16,233,167,63,134,56,198,63,181,21,235,63,140,219,4,64,204,93,19,64,78,209,33,64,90,100,51,64,250,237,107,62,28,124,225,62,220,104,48,63,120,122,101,63,248,83,147,63,29,201,181,63,127,251,210,63,242,210,237,63,243,142,7,64,36,151,23,64,50,230,38,64,81,107,58,64,29,90,100,62,19,97,195,62,223,79,13,63,236,47,27,63,108,120,74,63,122,165,140,63,139,108,183,63,198,109,228,63,46,144,4,64,243,31,22,64,11,181,38,64,48,187,55,64,163,146,122,62,225,122,20,63,165,44,83,63,104,145,125,63,95,7,150,63,111,18,179,63,230,174,213,63,234,4,244,63,100,93,8,64,100,59,27,64,178,157,43,64,75,89,58,64,58,35,74,62,165,44,195,62,253,135,20,63,98,161,70,63,104,145,109,63,54,205,147,63,66,96,181,63,240,133,209,63,193,202,241,63,138,142,16,64,163,1,36,64,199,186,52,64,107,154,247,61,18,131,128,62,245,219,247,62,95,7,78,63,84,82,143,63,61,155,173,63,2,188,205,63,184,64,242,63,215,163,8,64,74,123,23,64,45,67,40,64,6,129,57,64,69,216,112,62,0,145,222,62,204,127,40,63,87,91,81,63,198,109,116,63,212,43,149,63,242,65,191,63,41,203,240,63,50,230,10,64,131,47,24,64,108,9,41,64,63,198,56,64,79,30,86,62,206,25,209,62,186,73,44,63,254,67,106,63,126,29,144,63,236,192,169,63,93,254,203,63,27,13,232,63,77,132,1,64,147,58,21,64,173,250,36,64,2,43,55,64,105,0,239,61,217,95,118,62,139,108,231,62,44,212,58,63,218,27,124,63,155,85,159,63,236,192,193,63,134,201,228,63,193,202,1,64,248,83,19,64,127,217,37,64,23,72,56,64,236,192,153,62,91,66,254,62,121,233,38,63,94,186,89,63,225,122,148,63,241,244,178,63,211,77,202,63,44,212,234,63,69,216,4,64,81,218,19,64,47,221,36,64,195,100,54,64,127,251,122,62,70,37,213,62,117,147,24,63,217,206,71,63,19,97,115,63,215,52,159,63,123,131,199,63,57,214,237,63,57,180,4,64,154,119,20,64,111,129,36,64,166,155,52,64,155,85,159,62,54,60,13,63,234,4,52,63,26,81,90,63,40,15,147,63,86,125,182,63,135,167,215,63,153,42,248,63,194,23,10,64,199,75,27,64,60,189,42,64,41,237,57,64,48,76,102,62,194,134,199,62,118,79,14,63,14,79,63,63,188,5,130,63,57,214,173,63,204,127,216,63,160,26,255,63,146,203,11,64,27,158,22,64,220,70,35,64,178,157,51,64,184,30,133,62,85,48,234,62,104,34,60,63,240,22,120,63,116,181,149,63,32,65,177,63,135,22,209,63,3,120,243,63,123,131,7,64,69,71,22,64,214,197,37,64,45,178,53,64,139,253,101,62,122,165,172,62,213,120,233,62,217,95,6,63,52,162,52,63,145,126,131,63,156,196,176,63,35,74,219,63,230,174,253,63,62,121,16,64,190,159,34,64,168,87,54,64,60,78,17,62,52,128,247,62,14,45,98,63,49,153,146,63,214,86,164,63,52,17,182,63,36,151,199,63,91,211,228,63,88,57,8,64,74,12,26,64,218,172,38,64,108,120,54,64,92,32,65,62,45,67,188,62,146,203,15,63,155,85,79,63,121,88,144,63,48,42,177,63,140,74,202,63,11,36,232,63,253,246,1,64,182,243,17,64,185,141,34,64,196,66,53,64,14,190,112,62,253,135,212,62,72,225,42,63,132,13,95,63,111,240,133,63,58,35,170,63,1,77,212,63,251,203,246,63,8,172,8,64,53,94,22,64,32,210,39,64,110,52,56,64,113,61,138,62,57,214,229,62,164,223,30,63,48,76,54,63,52,17,70,63,218,27,124,63,137,210,174,63,116,36,223,63,189,227,0,64,238,90,14,64,39,194,30,64,236,81,52,64,127,217,125,62,92,143,226,62,221,36,38,63,59,223,95,63,93,220,142,63,103,68,177,63,196,177,214,63,222,113,250,63,219,138,9,64,144,49,23,64,78,98,36,64,250,237,51,64,78,98,80,62,191,125,189,62,228,131,14,63,200,152,75,63,179,12,129,63,106,77,163,63,63,198,196,63,33,31,228,63,184,30,1,64,122,165,16,64,37,117,30,64,2,188,49,64,237,13,62,62,5,52,177,62,126,140,25,63,25,115,103,63,157,128,158,63,154,8,187,63,109,86,213,63,160,26,247,63,75,89,10,64,233,72,26,64,235,115,41,64,254,101,55,64,190,193,87,62,63,53,190,62,254,101,7,63,254,67,42,63,80,141,87,63,77,243,142,63,50,85,184,63,68,139,220,63,153,187,254,63,97,50,17,64,143,228,34,64,90,100,55,64,71,114,249,61,126,140,153,62,65,130,34,63,60,189,114,63,209,34,163,63,122,54,203,63,232,217,244,63,247,6,15,64,94,186,25,64,52,128,31,64,122,165,40,64,28,124,53,64,175,148,37,62,97,84,178,62,20,63,22,63,9,249,80,63,79,175,132,63,210,0,158,63,197,254,186,63,161,248,217,63,245,74,249,63,241,244,14,64,181,166,33,64,95,7,54,64,137,65,128,62,163,146,250,62,137,65,64,63,140,74,106,63,229,208,138,63,66,207,174,63,243,142,211,63,44,212,234,63,37,6,1,64,139,253,17,64,199,41,34,64,6,18,52,64,19,242,193,61,141,40,237,61,177,191,108,61,3,9,10,189,208,68,216,187,195,100,42,60,89,23,55,189,23,217,78,189,155,85,159,189,142,6,240,188,132,158,205,60,140,74,106,188,77,243,14,61,90,245,185,188,199,41,186,189,134,56,86,61,184,30,5,61,158,239,39,189,25,4,214,189,126,29,184,189,250,237,107,186,143,194,245,59,31,133,107,189,160,26,175,189,134,90,83,188,31,133,107,61,253,135,116,61,82,39,32,61,43,246,23,61,153,187,150,188,185,252,7,188,67,28,235,60,140,74,106,60,112,206,136,60,166,155,68,60,39,160,137,188,163,35,57,61,125,174,182,60,224,45,16,189,56,248,66,60,95,41,75,189,203,161,197,189,112,95,135,189,250,237,235,187,64,19,225,61,122,165,172,61,114,138,14,188,239,201,67,189,23,183,81,188,166,155,68,188,23,183,209,185,116,181,149,61,244,108,214,61,37,6,129,61,46,144,160,60,85,193,40,188,47,110,35,189,204,238,201,189,17,199,186,189,119,190,31,189,168,87,202,188,150,33,142,189,44,101,153,189,208,68,216,187,125,174,182,60,220,215,129,61,40,126,12,61,172,139,91,188,189,227,148,61,93,109,197,60,208,68,216,59,197,254,50,61,35,219,121,61,43,24,21,61,95,41,203,60,5,163,18,189,40,126,140,189,195,100,42,188,86,125,46,61,224,45,16,60,247,117,96,188,2,43,135,188,186,107,137,61,121,233,166,61,14,190,176,189,38,228,131,189,224,45,16,188,153,187,22,59,93,109,69,61,105,111,240,61,74,12,2,62,106,77,115,61,2,43,135,60,238,90,194,61,211,222,224,61,247,117,96,60,191,125,253,62,229,242,255,62,127,217,253,62,8,61,251,62,73,46,255,62,63,53,254,62,127,217,253,62,146,203,255,62,155,85,255,62,127,217,253,62,128,72,255,62,137,210,254,62,142,117,145,62,174,216,95,62,7,240,22,62,177,191,44,62,83,5,99,62,39,194,134,62,21,140,138,62,75,89,134,62,136,99,93,62,236,47,123,62,109,231,123,62,83,150,129,62,21,246,53,243,117,245,239,242,229,244,125,21,170,1,215,27,107,255,39,12,81,244,7,247,215,246,142,10,55,252,78,252,21,11,90,4,8,7,247,4,217,47,22,247,251,246,30,6,183,244,52,244,221,247,2,14,215,34,91,10,15,16,206,248,204,249,108,250,179,12,154,255,156,0,192,254,210,2,175,6,85,80,4,244,93,247,164,243,174,242,188,242,190,244,46,248,194,6,237,15,120,245,98,249,233,244,132,11,77,245,180,246,52,247,225,250,243,254,108,7,20,245,68,254,76,244,35,246,74,20,179,5,178,19,191,251,146,3,20,16,220,29,191,243,172,243,188,15,149,242,88,243,231,245,166,21,255,19,157,38,77,244,175,243,135,242,227,243,33,242,115,242,108,247,9,251,29,15,37,21,16,245,58,248,43,13,18,247,2,252,118,12,218,253,187,6,200,3,124,7,67,245,6,250,93,247,85,244,227,242,66,243,238,251,37,40,107,0,102,10,91,38,63,245,173,16,51,243,53,12,197,243,98,244,77,243,66,25,12,37,14,248,109,245,136,246,158,243,197,245,26,247,113,255,151,249,80,46,87,23,254,250,187,245,164,246,196,246,36,248,195,251,240,245,138,246,98,247,163,53,43,247,191,10,24,249,178,9,215,251,165,254,119,255,31,0,107,2,129,1,47,247,89,247,94,249,130,245,116,17,253,245,209,251,177,250,77,30,148,14,216,244,58,35,2,248,42,250,70,247,95,247,189,255,60,5,129,9,149,11,94,245,153,247,106,244,36,245,84,245,27,250,219,247,4,250,22,27,32,251,112,248,101,247,237,252,11,249,129,252,58,248,85,18,230,248,223,249,162,7,21,247,157,246,18,41,223,243,206,251,234,244,255,255,168,4,89,4,237,12,55,247,109,246,132,249,231,9,97,250,254,13,187,251,174,253,164,7,246,2,229,20,36,246,240,246,145,248,249,247,211,19,83,252,47,253,232,253,149,8,251,246,45,244,76,250,161,244,80,44,86,246,191,249,43,249,188,12,243,9,235,14,33,251,87,250,19,11,162,251,116,253,252,253,133,254,19,2,184,1,199,253,210,245,15,246,113,246,107,249,230,33,180,248,45,248,32,252,0,23,143,33,200,248,38,248,108,247,255,247,110,253,145,13,214,0,137,3,61,1,254,247,197,251,223,245,50,34,70,247,111,246,104,249,146,8,196,8,198,9,133,249,68,245,232,17,61,244,118,14,253,246,161,248,88,248,212,251,73,11,50,244,83,244,9,247,22,245,255,11,204,249,213,255,67,10,254,4,239,7,159,247,9,246,227,246,123,243,91,243,56,245,122,35,58,254,243,16,240,6,78,245,177,18,128,247,152,248,100,8,70,5,0,3,249,0,233,3,219,5,29,3,122,247,93,250,27,255,224,255,59,3,145,1,14,1,69,2,124,1,190,246,184,246,137,245,229,243,50,249,131,251,58,18,75,253,85,4,123,29,64,246,9,244,254,244,195,245,32,248,90,22,68,19,193,4,113,8,145,9,97,247,118,244,185,14,248,244,239,248,126,244,99,249,135,254,29,6,4,16,125,244,247,11,10,244,153,244,235,243,40,246,80,249,79,9,25,5,75,7,161,39,160,244,21,243,95,29,82,242,217,251,34,245,147,33,18,253,33,250,187,243,74,246,107,11,242,245,222,248,36,251,209,13,190,9,23,10,24,6,94,245,212,12,197,8,22,251,110,253,118,254,227,1,207,2,97,4,49,4,123,244,11,252,24,244,85,2,225,243,50,246,78,248,39,28,187,33,125,7,20,249,29,254,242,246,188,248,60,246,165,11,141,249,38,2,184,2,103,2,183,247,249,247,173,249,178,247,36,12,89,13,27,254,209,255,80,3,72,6,180,245,85,249,70,12,214,14,223,1,168,251,85,2,189,254,19,6,251,5,142,244,58,8,162,246,246,246,213,248,0,0,104,11,128,3,52,9,235,4,161,244,144,243,81,2,14,242,195,242,65,243,172,28,216,29,218,26,149,25,136,248,202,250,43,249,200,253,74,249,107,254,161,250,128,13,0,252,145,248,168,36,95,245,75,246,183,246,46,244,125,252,195,243,40,244,108,246,35,30,188,9,110,246,71,249,166,247,39,250,201,255,248,2,78,9,159,4,81,4,34,245,133,1,8,250,97,252,152,2,237,253,125,5,107,1,70,2,220,254,114,249,98,245,53,245,188,243,17,245,126,247,101,245,224,245,52,252,54,251,206,12,107,251,100,11,244,249,66,254,39,251,47,255,123,1,177,2,26,2,38,12,41,11,57,249,36,251,179,253,99,254,65,0,215,1,10,2,67,1,5,248,44,255,29,5,41,254,204,253,240,255,122,1,192,254,75,254,228,0,110,247,179,245,47,246,146,245,185,248,70,252,222,247,162,246,34,247,187,21,113,244,116,246,22,245,56,249,161,249,212,250,202,5,31,254,13,9,190,5,201,244,41,248,190,2,68,248,21,254,110,255,73,253,111,255,1,11,244,4,189,242,128,242,3,244,151,242,198,244,51,255,38,3,222,11,222,14,63,10,118,244,187,248,56,253,249,3,186,254,44,0,163,255,142,3,7,3,90,1,191,245,246,245,98,244,216,246,104,245,118,248,91,247,193,13,195,250,231,16,115,255,67,3,161,251,200,250,188,251,157,248,164,252,41,253,59,1,2,10,23,16,178,245,232,245,97,248,106,245,61,246,231,249,72,252,5,11,201,9,172,246,193,248,146,244,206,6,253,245,161,245,246,248,10,12,247,11,152,9,24,243,146,245,157,247,32,250,203,254,141,5,125,6,10,6,48,2,103,2,226,245,199,249,13,250,233,7,95,12,183,252,156,254,120,253,53,1,141,4,110,244,164,247,138,247,82,250,154,249,180,251,189,252,174,2,210,3,38,2,162,249,3,252,112,250,181,248,162,251,38,254,66,0,216,23,136,3,91,2,195,252,37,254,168,250,81,251,87,28,134,252,47,254,114,0,118,0,224,0,107,246,1,251,0,32,247,250,60,254,209,255,180,0,68,1,115,2,209,0,46,245,206,43,167,252,72,249,129,252,237,253,221,254,248,254,232,0,110,254,117,245,255,245,127,246,211,247,221,250,86,0,106,10,127,6,71,5,45,9,28,245,224,17,96,14,171,250,29,252,255,253,46,0,44,0,10,2,142,0,77,245,138,249,98,248,221,17,109,253,232,253,29,1,72,0,107,3,115,2,70,12,105,0,83,252,221,4,23,254,17,254,27,255,44,0,20,255,197,251,224,246,87,251,172,249,189,248,197,250,113,253,205,0,8,4,205,21,171,4,181,245,52,249,96,10,184,7,204,255,16,3,160,255,91,255,163,1,26,254,146,34,144,253,232,252,5,250,3,253,94,253,38,253,195,252,106,255,229,255,207,8,103,251,167,10,106,250,225,2,122,252,244,252,39,253,169,0,22,1,145,14,179,14,224,255,211,249,205,253,195,253,77,0,140,254,192,255,35,254,60,246,14,2,110,249,184,5,194,252,132,255,220,253,49,2,202,0,91,4,110,249,240,249,34,248,177,247,162,250,19,253,48,253,64,0,49,8,32,27,45,245,65,19,112,249,92,247,106,250,223,252,114,0,123,3,152,4,87,3,243,13,117,247,226,249,98,249,84,0,210,255,164,3,18,3,253,2,88,3,242,251,14,254,139,255,210,249,157,250,118,251,149,24,145,254,82,2,132,0,73,246,71,8,151,247,43,249,65,3,65,4,251,1,133,0,81,1,167,1,39,245,203,9,21,1,81,250,5,252,19,7,127,2,173,253,136,0,230,251,131,244,122,17,80,255,71,4,89,4,33,254,182,0,217,254,27,255,163,253,13,248,143,249,109,251,51,0,0,0,125,0,28,11,202,254,174,255,128,253,53,247,166,247,34,247,225,249,212,8,92,0,112,1,95,0,153,5,66,5,52,3,221,246,226,248,129,252,187,255,158,0,190,0,143,3,240,3,252,2,172,2,36,249,11,252,167,249,182,249,174,23,13,254,244,251,117,255,105,4,232,1,12,2,103,253,154,252,165,254,180,255,123,0,91,0,244,255,14,0,205,244,29,248,42,11,145,248,115,251,53,1,31,1,226,4,255,2,8,3,32,245,114,246,123,251,204,1,29,10,181,1,227,254,199,2,213,254,146,1,133,245,33,247,78,249,1,250,221,253,22,16,254,1,134,4,188,2,119,2,220,247,44,251,253,1,15,252,2,254,63,255,205,251,231,252,215,2,102,8,94,245,200,3,53,4,213,249,126,250,130,252,145,1,19,4,171,1,182,0,192,246,220,246,57,249,151,248,43,250,216,3,246,11,10,11,25,4,164,0,157,4,58,248,215,248,72,249,176,250,24,0,205,5,131,7,204,1,255,1,69,0,78,0,159,254,253,255,177,14,32,254,254,249,217,251,28,2,192,255,246,249,36,252,234,5,113,251,182,250,205,253,155,5,112,3,99,4,182,0,61,247,195,247,182,246,103,247,45,250,188,252,132,255,93,2,15,24,52,14,46,245,113,244,116,244,53,244,150,247,120,253,13,7,90,18,113,11,30,8,49,252,152,254,129,252,145,253,175,253,145,252,167,254,237,16,236,1,200,255,202,247,243,252,36,254,244,4,94,2,98,253,150,6,151,255,114,1,205,1,35,255,156,252,155,250,41,1,128,0,190,253,215,252,86,252,56,15,234,1,192,15,115,10,84,253,172,251,45,251,109,252,150,252,105,252,222,252,240,251,212,250,240,255,108,8,151,7,116,253,102,253,209,255,37,250,168,0,46,255,117,16,153,248,58,249,25,249,124,250,157,252,185,255,73,1,87,3,14,5,199,248,41,17,224,250,195,249,204,253,178,1,58,254,13,1,124,3,225,255,110,251,67,0,114,1,136,251,192,254,122,14,213,252,66,255,133,255,90,255,109,253,247,251,235,252,122,252,165,254,232,254,148,255,199,254,196,1,117,14,31,250,206,245,58,245,10,246,14,248,175,250,92,253,201,2,215,8,94,32,63,247,52,246,20,246,71,249,182,0,155,7,50,1,237,6,196,4,93,11,196,255,73,0,21,255,161,249,234,250,76,253,75,16,194,252,49,0,68,255,41,254,96,247,39,247,18,250,60,255,179,11,11,10,189,253,188,255,37,3,242,250,250,4,198,16,180,250,66,253,236,253,47,254,133,255,112,254,49,253,80,1,21,12,98,6,118,252,185,255,10,254,86,252,42,252,26,253,93,251,35,249,74,11,201,249,23,5,216,0,201,254,108,254,227,255,245,1,225,253,70,250,51,6,53,1,190,253,83,255,34,0,92,4,6,5,96,251,106,251,81,255,36,253,149,253,180,13,176,255,191,0,221,251,82,255,83,254,42,254,16,39,91,252,25,250,191,249,221,249,91,250,215,251,129,250,227,251,92,252,159,4,195,30,52,254,183,249,174,249,138,250,126,251,53,251,12,252,86,250,20,0,28,0,21,255,146,255,203,0,105,0,252,0,102,255,205,255,198,255,124,11,22,254,17,0,205,255,131,0,150,255,242,253,202,253,202,252,103,251,201,250,189,10,96,2,217,249,214,250,185,250,111,0,129,2,161,5,247,255,221,2,49,255,239,254,103,253,138,253,180,253,178,255,254,0,48,1,250,2,155,245,139,245,42,251,174,255,9,10,185,11,164,3,248,251,211,0,188,254,40,0,115,5,188,252,161,251,133,253,111,250,22,250,145,251,229,5,147,11,159,20,77,4,174,50,248,21,237,7,13,15,30,23,236,5,167,244,32,255,164,255,205,252,35,3,67,4,19,12,229,242,152,0,66,251,107,227,30,253,243,220,34,2,3,47,87,252,168,8,65,8,190,4,79,230,214,7,131,249,95,253,8,233,240,1,198,1,72,13,164,2,190,254,124,44,122,2,111,251,12,49,84,233,212,225,76,2,111,229,56,4,98,1,111,249,82,252,134,7,25,254,188,253,156,0,79,0,149,59,155,2,131,4,143,2,49,253,207,7,239,252,214,0,6,11,252,3,81,248,73,0,125,254,119,255,135,196,240,249,155,254,14,11,92,8,254,11,8,246,106,9,206,4,35,16,231,3,248,0,19,2,115,252,108,15,58,50,136,224,157,8,235,244,85,255,159,249,127,255,163,255,60,7,128,248,157,0,175,37,172,255,106,255,171,250,14,250,115,204,24,24,133,243,2,23,68,249,249,230,196,250,245,226,147,253,156,233,177,244,145,0,134,15,216,2,112,38,18,254,189,28,118,254,210,202,0,255,118,248,212,1,246,254,65,31,103,255,147,254,228,29,135,0,120,5,227,240,67,4,185,236,188,244,235,4,163,26,1,4,245,229,55,4,190,217,171,26,186,239,84,4,125,4,173,73,81,2,79,255,213,251,124,253,140,247,119,18,85,0,155,255,203,213,9,255,214,34,213,8,99,21,244,2,202,11,121,230,149,7,103,1,123,239,182,4,190,3,146,252,42,2,164,182,241,8,42,19,12,227,251,225,252,30,197,3,156,9,71,17,205,253,172,241,102,242,235,12,55,249,203,3,200,226,246,41,186,7,61,9,20,0,215,241,210,1,8,8,54,230,180,36,73,12,90,12,65,7,138,253,7,229,124,6,48,244,145,247,85,4,2,5,207,10,210,0,101,247,27,12,47,225,13,7,197,204,220,3,165,231,30,6,137,250,116,218,29,7,249,253,199,255,100,13,56,201,117,4,18,246,76,219,239,255,184,1,113,222,223,8,125,225,99,7,89,252,22,239,233,250,106,1,170,1,63,1,152,4,104,12,154,8,28,200,149,253,130,244,33,247,237,253,116,253,89,1,17,69,173,5,231,249,85,1,227,247,165,3,177,1,249,5,207,1,185,251,48,19,184,252,138,63,205,3,196,6,50,253,46,26,181,241,197,15,64,253,109,245,143,5,11,5,252,8,149,0,91,252,198,250,227,7,29,24,225,1,89,58,148,254,56,15,69,254,224,3,128,252,122,1,30,255,31,250,12,1,84,254,194,245,223,254,235,247,232,40,216,240,46,235,129,1,237,11,222,237,245,5,235,249,204,2,200,9,80,3,62,254,30,248,54,254,63,253,48,228,225,253,166,247,244,9,161,254,225,2,106,50,12,252,63,0,253,59,76,1,187,252,31,255,237,250,27,11,54,5,99,253,35,8,61,253,147,4,27,32,142,8,71,41,90,5,160,250,153,244,60,8,114,39,124,254,90,17,164,0,234,1,156,29,26,0,200,248,153,244,128,2,150,18,148,255,2,32,211,250,246,246,191,1,58,20,185,251,174,38,75,253,216,241,33,255,178,2,255,40,8,3,105,252,171,249,254,7,213,1,174,5,97,14,190,251,16,249,177,5,212,0,6,8,30,252,186,2,16,254,75,87,145,253,254,0,192,3,23,240,19,2,244,245,199,199,2,252,2,1,173,241,226,3,138,59,214,19,222,241,133,7,51,251,38,249,179,6,6,17,6,5,200,246,18,238,32,7,184,30,143,5,158,247,53,245,117,214,218,1,195,252,135,4,99,255,202,255,98,255,227,255,202,0,129,254,29,1,254,255,94,3,148,254,159,1,133,255,111,255,251,217,143,4,215,39,128,250,80,244,83,8,100,254,135,18,176,11,227,13,151,253,134,37,241,244,53,9,180,20,113,2,90,253,12,254,128,255,200,255,73,231,158,251,249,245,112,7,244,248,197,2,122,12,108,255,165,250,122,230,44,249,46,250,79,55,186,5,115,5,77,4,91,245,247,1,68,0,50,250,0,0,211,0,62,251,253,255,184,81,173,6,48,255,185,252,222,17,60,232,99,230,153,255,40,252,137,254,217,32,179,6,134,247,117,236,32,243,170,52,187,4,193,239,168,13,16,4,13,27,213,0,138,250,185,1,49,251,210,252,74,3,38,6,121,4,79,5,181,1,15,249,86,80,3,1,35,238,124,250,98,255,160,39,245,4,125,5,169,206,176,251,153,253,236,193,99,1,45,241,122,251,169,12,252,0,232,0,77,255,151,253,10,248,29,1,10,252,32,251,43,7,234,249,242,4,33,216,117,2,200,254,112,44,154,0,224,254,27,23,159,254,60,0,135,10,171,252,153,255,43,61,99,9,96,251,3,0,20,36,55,213,82,17,61,3,3,10,92,255,176,252,122,253,79,28,127,3,190,6,16,253,45,252,29,4,53,252,62,1,132,8,159,3,36,3,250,254,190,1,189,12,194,236,85,238,223,4,247,7,226,49,89,251,226,250,58,234,155,18,145,2,213,239,69,42,219,252,171,251,139,243,71,249,167,0,218,216,171,248,75,8,72,1,120,228,174,247,127,9,242,5,137,12,0,223,18,7,220,234,87,38,163,241,175,25,163,231,95,252,78,254,185,246,238,202,169,13,140,251,203,4,46,231,5,254,73,1,102,249,55,4,144,252,97,241,75,240,219,237,91,232,190,3,242,17,158,251,148,210,1,6,166,242,38,251,133,0,137,219,75,6,80,254,237,41,139,252,44,254,102,203,178,2,214,0,8,35,113,13,75,21,37,255,116,21,135,254,153,1,228,14,146,9,252,1,142,25,240,14,135,241,254,253,186,223,1,6,33,31,178,3,203,244,58,34,161,1,230,19,56,8,38,26,170,254,235,4,85,237,91,250,17,250,77,1,33,17,140,2,126,254,188,253,156,248,151,252,70,7,144,10,13,54,217,234,73,248,249,22,238,27,80,32,244,230,192,2,62,7,1,1,94,241,195,217,94,218,100,252,113,5,91,243,3,1,200,255,38,17,38,19,148,4,250,19,200,245,199,238,100,251,83,18,232,28,143,253,169,34,190,26,56,251,43,255,80,235,80,242,109,255,164,69,189,250,179,12,166,6,160,5,196,246,21,254,29,255,229,6,66,254,238,217,29,248,23,44,61,255,169,218,200,254,120,3,157,22,39,249,195,212,233,9,247,254,30,249,245,252,203,222,204,254,167,255,181,7,56,14,192,67,46,5,79,253,114,254,20,241,119,8,229,0,132,253,94,8,69,230,17,253,187,51,209,1,198,232,54,255,56,252,220,251,16,255,126,214,77,13,22,5,17,251,204,3,87,44,100,0,218,8,94,252,196,247,230,20,142,243,122,43,25,8,16,234,138,2,208,7,24,4,252,21,237,253,162,2,5,33,6,4,128,4,63,47,96,1,153,1,251,251,44,251,66,255,164,233,179,253,222,13,166,7,255,200,173,254,136,6,133,249,166,17,181,255,130,253,125,21,21,1,190,253,119,247,157,0,18,8,186,33,157,246,81,6,57,207,167,248,81,32,179,0,152,247,242,250,0,254,97,254,200,1,115,255,131,255,107,254,132,0,49,0,70,248,115,181,61,254,56,250,68,1,235,234,235,0,63,251,90,1,22,251,212,13,91,39,51,40,196,19,247,247,12,24,32,252,128,36,122,241,200,16,127,3,240,222,85,1,146,5,136,2,214,5,79,11,80,241,155,39,171,60,40,252,242,249,217,250,250,249,137,255,251,253,71,255,216,242,193,219,129,242,95,239,68,4,120,216,208,19,27,12,218,3,254,245,220,208,140,7,89,25,182,3,143,246,82,5,201,253,79,2,53,253,253,253,178,13,42,253,175,24,214,0,148,254,27,14,103,7,43,248,239,254,233,5,75,9,219,1,9,237,241,253,27,211,27,0,247,16,166,246,129,253,24,253,215,245,165,42,118,7,145,9,214,4,129,247,202,20,42,240,216,255,178,16,172,2,216,31,198,3,130,42,243,255,157,16,225,254,136,243,36,2,228,7,189,0,18,229,29,3,112,8,67,2,244,15,231,6,85,240,128,253,17,30,23,3,177,3,206,4,91,25,228,5,78,241,79,254,76,44,127,255,149,251,255,235,76,12,8,6,32,226,74,7,188,37,61,9,194,247,14,3,174,255,82,14,67,253,47,1,42,1,114,248,131,255,109,250,75,187,92,251,175,0,122,228,24,254,97,4,62,230,233,1,241,249,13,56,219,5,224,253,236,66,198,0,212,9,175,9,46,252,42,255,185,242,57,251,46,8,130,0,4,252,25,4,58,253,1,50,14,254,41,1,171,250,69,255,159,243,133,255,59,35,190,3,221,0,154,55,178,253,193,3,20,12,8,0,255,0,22,238,253,6,218,9,223,206,165,255,202,252,219,252,54,253,178,20,19,5,234,12,248,250,120,51,235,0,218,6,189,255,120,7,164,253,168,12,0,248,56,255,4,3,83,255,28,252,88,5,76,9,38,1,251,2,209,76,60,255,16,2,182,0,166,246,155,3,237,2,246,202,87,3,77,2,175,218,0,0,105,22,159,40,187,35,137,249,105,241,222,4,131,246,133,251,105,247,119,244,102,2,132,250,63,254,180,222,33,247,137,19,211,218,124,11,52,255,41,14,254,254,32,0,241,5,213,254,6,249,236,244,243,5,123,9,189,252,67,12,59,255,23,13,233,254,82,198,13,251,49,20,241,251,41,213,58,0,129,2,1,253,87,251,177,253,52,253,190,252,173,31,109,252,57,253,69,215,112,249,130,253,83,10,174,252,254,254,212,40,106,1,238,234,163,254,121,198,113,253,16,4,186,6,231,215,39,2,229,254,160,38,152,1,112,254,92,23,86,7,13,3,101,252,101,253,235,252,164,254,112,2,252,254,179,56,220,252,185,6,254,255,236,20,10,7,194,4,242,1,79,7,36,252,167,63,67,16,218,246,62,239,49,12,197,12,112,0,92,242,100,4,40,250,71,7,110,250,190,251,62,6,59,255,136,4,132,249,186,251,221,1,248,239,116,254,69,6,22,102,234,2,180,205,16,9,102,249,178,33,39,0,61,5,26,251,158,248,251,9,84,201,62,251,243,14,192,4,115,252,76,255,184,6,169,255,113,255,221,3,84,1,110,250,67,240,69,12,48,219,210,1,221,223,166,1,45,227,246,7,145,1,98,0,18,14,57,251,78,252,165,9,135,4,215,2,244,254,211,1,203,0,185,212,10,15,115,242,83,248,191,248,121,250,83,246,101,12,184,28,11,37,91,234,68,24,94,7,228,240,168,10,65,2,63,236,65,1,204,3,179,255,47,0,227,0,218,255,243,251,34,255,165,254,171,254,155,4,76,252,80,2,195,226,170,8,189,232,138,10,22,46,197,0,116,24,175,6,230,3,8,0,177,231,96,251,121,4,11,249,96,5,114,5,132,1,79,253,231,8,111,25,238,9,217,236,77,15,234,252,23,2,145,248,160,238,120,16,234,255,197,229,84,20,199,18,121,12,216,251,27,21,151,17,126,246,56,239,103,5,22,250,249,239,235,2,88,15,171,11,41,37,188,9,13,222,31,252,149,245,216,255,86,255,212,243,99,2,63,9,169,63,24,251,132,250,122,242,210,1,244,253,88,21,235,1,194,2,189,226,235,7,117,1,10,240,84,6,147,225,192,2,138,19,170,6,133,32,173,252,101,217,0,244,123,17,136,10,155,222,96,0,208,206,101,207,169,1,182,0,56,254,171,254,181,252,103,2,177,2,214,3,190,5,250,253,231,0,230,253,26,1,153,1,168,253,209,254,227,255,51,0,252,255,141,255,79,0,229,255,194,1,87,252,51,254,214,253,97,255,170,1,198,2,78,142,156,247,99,0,98,13,46,7,139,48,73,2,224,247,36,246,38,254,36,6,206,2,66,2,168,254,188,0,72,1,93,47,112,0,142,2,48,251,148,249,32,1,41,2,233,5,198,3,244,3,49,0,119,2,145,255,18,255,140,255,74,255,235,255,210,255,78,1,5,43,58,254,251,254,12,0,21,0,52,0,40,176,217,254,10,254,252,253,183,254,26,255,209,1,59,0,14,1,203,3,129,255,249,1,62,255,43,0,226,255,44,1,38,0,153,2,155,253,33,0,84,255,103,255,67,1,90,255,54,0,143,1,109,0,186,0,27,249,34,255,138,0,16,0,204,0,159,117,208,0,204,253,156,253,156,0,110,255,167,254,65,1,118,255,202,0,72,255,93,0,198,2,183,193,167,203,234,0,167,251,146,0,247,255,56,0,140,253,190,252,12,251,104,3,61,0,96,251,130,255,51,255,145,0,147,255,200,223,113,0,110,255,8,5,182,35,89,3,242,252,82,253,0,255,118,253,37,4,54,255,12,0,59,253,168,255,17,1,241,1,150,0,197,255,153,221,240,0,20,2,16,0,202,5,4,43,68,254,126,7,6,249,142,7,172,0,86,2,212,250,6,22,162,243,236,1,223,253,254,252,43,4,0,0,156,254,91,254,148,6,17,1,10,254,60,1,92,4,39,3,239,253,193,252,189,203,92,254,236,0,214,1,226,245,63,255,209,255,68,2,179,249,30,3,27,0,240,255,32,206,131,252,0,1,0,0,123,6,183,5,32,2,196,0,20,137,58,1,91,254,252,1,236,254,83,255,158,1,132,254,141,254,216,255,135,255,119,1,176,1,74,254,1,0,162,254,232,254,174,4,139,254,196,1,100,0,188,255,93,35,165,0,2,3,73,0,35,1,205,2,3,2,84,2,189,254,252,255,254,255,35,3,226,2,45,10,30,0,73,0,199,1,16,44,254,5,229,254,222,5,90,220,104,237,198,253,227,1,77,255,76,222,153,249,66,1,200,255,5,24,254,242,114,0,246,17,72,248,222,255,200,255,72,3,241,2,4,48,68,228,20,254,64,1,100,254,140,3,162,4,188,1,146,25,236,252,18,21,185,2,49,51,194,0,118,254,38,1,79,10,12,0,15,252,110,250,220,255,58,8,4,255,21,131,190,255,85,1,228,3,42,1,105,0,6,0,10,0,106,0,14,254,12,255,151,255,194,253,16,0,50,255,24,0,237,247,131,254,25,40,153,255,6,253,239,252,12,248,105,209,16,0,58,253,221,255,242,254,157,255,4,0,4,3,240,254,70,255,184,254,168,197,199,255,179,250,81,255,162,253,220,0,150,3,245,255,142,1,67,255,234,254,138,0,173,1,253,1,67,253,213,255,214,255,138,253,208,253,216,45,240,253,46,40,135,253,154,252,167,1,38,2,136,252,41,1,86,255,2,1,186,8,230,1,36,1,66,254,174,209,24,39,52,0,179,4,92,255,42,3,9,250,164,253,141,252,180,253,160,255,76,1,148,0,76,255,223,0,100,1,29,1,178,1,199,255,84,255,248,253,80,254,184,255,38,1,163,255,122,255,60,1,183,119,161,254,22,1,84,0,73,254,77,2,105,0,233,3,41,1,148,2,196,0,171,0,178,0,166,255,201,255,148,4,108,82,227,0,224,254,116,1,162,0,202,1,213,253,207,250,124,1,110,1,152,255,105,0,162,2,134,254,48,5,27,1,120,248,37,2,250,2,198,1,55,0,94,2,211,48,24,0,179,1,23,0,29,0,26,24,105,4,161,255,97,0,57,2,132,0,235,1,164,0,224,254,13,252,122,255,210,4,85,254,2,255,244,253,226,0,222,200,72,1,186,255,130,6,67,255,208,246,73,4,107,2,120,2,43,252,233,2,75,2,229,255,56,255,153,252,50,0,214,1,10,255,50,10,69,2,254,0,165,38,182,253,112,3,138,209,130,1,111,4,117,0,48,4,116,0,194,252,96,255,22,252,69,253,190,255,26,255,252,254,112,0,106,0,221,0,41,1,209,255,218,29,170,0,182,254,169,253,205,255,36,254,33,0,219,1,112,2,55,24,162,254,106,254,184,0,138,3,240,253,126,1,145,1,92,1,26,0,70,255,33,0,126,255,194,255,206,255,244,4,124,255,147,255,140,4,158,254,163,2,3,0,110,254,12,255,132,2,136,2,124,255,252,255,45,0,162,79,120,255,56,2,126,0,120,1,140,56,136,254,11,1,206,52,252,254,111,0,246,3,246,2,183,1,39,2,92,255,207,0,128,0,96,254,104,2,178,2,12,219,192,248,99,4,58,3,247,254,6,253,60,6,136,253,52,0,146,253,130,252,111,1,79,254,156,255,81,7,244,2,228,187,168,0,227,253,38,2,145,0,20,234,223,251,192,250,112,253,62,255,216,0,12,254,11,255,246,0,64,0,176,2,215,2,250,48,140,234,252,0,116,252,88,254,236,253,109,253,235,254,26,255,32,253,73,255,35,0,28,255,200,0,244,255,8,255,196,255,19,254,177,1,190,1,110,1,124,253,92,0,188,254,29,0,65,3,218,171,47,252,94,0,123,1,49,0,222,251,248,0,78,255,85,0,63,252,82,251,208,255,211,1,14,255,38,216,20,6,255,43,52,253,46,3,106,249,10,14,229,255,182,2,222,252,134,1,48,16,105,253,44,0,222,253,56,1,228,255,28,254,213,3,205,254,240,1,152,1,203,0,255,48,40,1,40,251,159,0,78,3,67,252,43,250,150,253,57,6,92,46,56,10,162,7,156,1,102,252,216,250,253,12,2,255,156,248,95,2,81,247,215,221,50,250,17,0,87,1,206,255,206,253,251,85,162,254,21,254,186,255,196,255,105,2,0,3,166,254,131,1,148,2,129,5,222,0,104,2,173,0,213,250,177,15,49,255,243,253,69,204,11,0,184,1,154,253,232,254,37,2,98,253,177,255,203,1,48,2,154,255,42,255,202,255,79,251,230,0,242,253,89,3,20,4,143,254,166,9,254,212,214,206,243,0,51,255,70,3,104,252,92,1,30,253,39,5,86,0,178,255,84,254,139,248,101,255,2,0,252,1,199,2,220,254,163,6,225,0,155,255,93,255,28,2,220,37,235,0,73,255,218,255,198,0,46,254,52,255,3,221,110,252,213,254,193,0,10,0,211,2,131,2,235,253,118,250,67,1,20,0,78,1,138,252,181,254,112,1,130,0,231,137,104,255,242,255,125,2,132,0,24,255,107,255,82,254,64,0,13,255,136,254,114,1,132,1,196,0,182,251,117,0,230,252,240,255,238,254,92,1,208,1,4,146,184,0,66,1,155,255,2,0,229,255,73,255,98,2,0,1,96,255,195,253,30,255,76,2,77,6,4,4,46,37,153,247,190,249,240,253,156,254,140,255,9,211,36,7,98,247,209,255,11,253,57,250,107,250,131,198,150,6,253,0,34,3,206,1,219,255,108,252,223,254,111,254,71,52,97,1,182,255,114,0,67,255,124,2,178,1,129,253,245,3,234,0,232,45,219,0,184,5,124,255,218,205,125,0,176,253,216,255,94,255,20,249,250,1,223,1,166,1,36,0,15,0,64,252,31,3,5,2,31,5,103,254,236,2,217,2,190,1,21,43,17,205,233,4,117,253,243,255,26,253,136,5,124,254,238,254,229,252,163,0,196,253,74,0,174,1,166,255,130,255,182,255,170,253,140,0,125,0,236,255,148,176,208,0,37,0,19,0,82,255,47,255,49,1,28,0,110,254,28,0,197,254,255,255,122,255,184,1,192,252,79,0,133,253,208,254,8,0,0,128,113,2,214,1,56,251,161,254,34,2,109,251,62,253,140,2,31,0,60,29,64,254,148,3,220,4,133,254,212,254,68,0,100,3,95,2,247,0,70,0,40,252,234,55,21,0,162,254,174,255,112,1,200,1,26,253,216,1,34,0,14,3,14,254,145,252,188,2,161,1,216,0,159,1,95,255,75,255,160,253,34,6,94,3,160,255,142,255,159,31,230,255,168,0,149,254,220,252,220,255,254,252,139,0,85,255,245,25,111,250,218,18,88,235,78,5,29,210,192,255,138,2,122,243,100,249,21,3,1,248,233,254,148,3,144,249,140,4,252,7,112,255,51,253,120,254,40,255,116,1,92,1,28,4,81,255,156,2,52,1,241,255,184,113,106,254,250,252,109,1,18,252,242,253,52,4,59,0,96,253,169,255,150,255,174,0,96,0,103,2,206,1,213,255,16,254,112,0,149,0,200,255,74,255,244,254,0,128,51,255,92,253,165,0,70,251,187,254,28,31,212,255,34,2,69,253,29,1,94,254,99,1,238,0,38,2,67,0,169,1,128,1,74,252,182,254,48,255,60,254,212,0,90,45,66,255,37,0,117,252,127,212,42,252,73,2,241,252,160,252,164,0,232,255,254,253,45,255,2,0,2,254,188,253,83,2,128,0,100,0,27,255,201,255,34,1,229,253,40,0,150,225,242,254,39,1,4,254,50,2,84,251,218,0,33,0,204,14,6,221,198,251,41,1,118,252,190,254,123,0,138,4,169,254,121,210,88,0,228,255,149,4,9,0,157,255,36,0,45,209,100,1,86,49,255,2,73,255,41,252,209,253,186,0,124,4,18,2,72,254,206,4,56,254,123,255,88,254,35,0,155,254,162,1,177,5,81,253,228,2,14,255,191,69,144,254,223,251,250,254,122,253,150,1,56,253,222,251,172,255,198,1,214,3,230,255,47,253,103,1,253,1,234,51,87,9,215,2,69,1,72,1,13,1,100,255,90,1,14,255,225,255,156,254,229,2,140,1,158,255,108,0,35,0,19,255,12,140,196,0,187,255,206,1,173,254,24,0,59,251,96,1,110,253,140,1,243,0,134,249,54,254,127,251,5,0,106,253,209,255,18,0,196,253,201,253,220,247,44,252,46,255,150,0,116,254,244,57,46,255,0,0,94,255,229,253,76,2,156,252,248,0,128,222,252,3,14,2,32,4,6,1,107,255,50,3,183,250,160,251,255,2,30,253,134,253,106,198,151,255,43,3,182,6,140,255,192,255,51,1,152,3,36,251,84,9,229,39,103,238,6,255,105,2,67,249,123,253,234,4,122,4,178,253,195,2,244,255,116,1,2,7,244,3,107,255,148,1,46,252,206,254,168,0,0,250,89,0,142,0,170,3,77,178,205,3,31,254,93,254,120,252,57,254,227,248,175,249,142,2,26,248,114,7,15,254,174,211,182,254,97,210,242,255,1,0,23,2,135,254,33,4,42,255,43,255,174,1,243,255,205,242,14,212,143,3,52,253,16,255,246,255,4,1,132,0,157,253,192,255,174,253,164,222,69,3,123,241,126,251,138,3,127,41,10,254,89,255,67,0,119,0,189,52,67,250,213,0,232,251,133,250,176,1,201,251,45,0,26,255,38,253,53,255,173,253,130,251,52,254,159,255,139,1,208,254,168,108,212,254,240,255,153,0,97,253,39,2,180,1,68,252,74,255,194,0,113,0,128,234,194,0,7,1,180,254,251,253,12,255,116,254,28,2,56,0,141,254,190,1,147,0,190,255,7,0,206,254,160,5,204,254,71,1,133,2,85,2,14,230,72,0,136,1,118,255,206,255,112,255,250,254,248,1,26,255,114,0,28,8,239,31,164,4,34,1,152,252,202,0,69,0,82,0,231,254,130,255,221,254,98,255,104,255,211,255,239,0,153,0,252,253,90,254,77,253,33,3,28,0,240,1,214,254,146,212,190,40,29,255,173,252,214,0,223,252,26,2,66,3,119,255,174,3,61,2,149,1,28,5,186,8,44,1,245,4,73,48,16,253,129,8,25,253,60,0,208,1,178,3,46,1,90,254,116,0,80,251,146,255,181,252,28,1,190,253,220,2,204,254,153,0,192,255,156,0,225,0,208,141,60,254,46,254,126,255,120,3,240,0,49,1,173,255,236,0,208,0,161,1,250,5,38,1,82,2,95,1,252,1,137,0,150,227,72,255,201,0,44,0,133,253,133,252,116,253,172,253,124,1,116,253,34,222,180,255,94,241,36,253,6,1,188,248,250,251,86,5,233,254,188,1,143,3,209,0,74,1,251,0,48,255,21,253,65,0,86,216,52,255,160,50,187,254,91,1,47,254,38,253,41,253,129,1,167,255,5,253,85,254,100,3,217,255,165,252,34,0,227,255,124,254,212,250,38,255,3,8,199,249,135,21,11,41,188,222,206,8,215,22,62,250,202,7,96,18,172,248,112,3,30,241,23,254,78,252,55,251,176,251,125,0,139,0,100,253,184,8,231,253,179,0,41,255,63,0,144,0,72,0,174,4,22,38,248,0,59,253,52,1,56,41,78,254,50,254,1,53,72,4,21,254,250,254,36,3,193,249,167,2,57,2,92,2,46,5,213,0,22,248,68,1,204,245,139,254,238,205,236,255,38,0,85,255,60,1,156,60,50,1,251,2,97,0,91,0,192,252,23,0,75,254,122,254,249,1,54,251,214,9,106,0,239,247,59,1,86,0,11,2,172,0,12,252,229,201,30,13,50,10,131], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+215057);
/* memory initializer */ allocate([254,62,255,176,4,246,239,238,250,203,241,2,250,12,3,87,5,224,253,254,252,154,6,23,4,202,255,88,8,214,48,32,0,33,26,194,2,108,251,78,3,11,237,98,8,244,9,217,255,47,254,172,253,177,0,213,0,165,1,28,0,124,254,11,0,69,0,31,0,173,255,228,255,90,255,106,255,132,178,189,254,3,0,147,2,15,3,134,1,139,0,118,255,31,0,145,255,197,1,176,255,176,1,249,253,253,254,174,2,167,44,163,0,133,204,42,2,40,0,133,254,136,255,76,253,84,1,169,0,120,0,36,254,131,2,10,3,245,1,128,255,31,2,251,4,122,255,88,80,201,0,145,1,0,2,150,254,46,255,243,254,212,252,112,0,75,0,149,0,221,253,18,254,94,254,156,255,203,202,22,252,152,4,98,6,117,254,63,239,5,250,209,255,82,3,178,251,246,52,109,254,171,2,92,255,89,247,100,251,42,249,88,1,118,2,56,252,157,2,28,2,26,0,174,253,192,0,239,255,176,254,189,76,109,4,18,0,200,255,162,1,86,254,1,250,153,1,220,2,186,0,12,1,58,176,234,255,62,0,147,253,210,2,184,1,96,0,205,254,128,255,224,1,5,0,87,0,156,2,151,254,169,253,234,255,140,2,80,255,142,255,214,0,55,208,70,253,232,0,96,2,130,255,54,253,24,254,28,255,161,3,210,249,123,178,245,0,52,254,124,0,57,0,72,1,76,254,98,255,236,0,60,255,234,253,209,0,69,0,229,0,210,0,5,255,76,4,71,2,159,1,210,0,189,0,37,255,218,4,26,76,151,255,190,0,138,254,213,255,24,255,253,0,49,2,215,254,136,254,203,251,204,254,174,52,82,207,64,0,66,255,214,254,125,253,204,1,232,0,37,252,34,254,60,6,168,0,46,253,104,2,151,252,158,255,76,252,231,0,178,251,139,46,234,2,17,254,224,4,179,4,59,43,224,255,160,0,162,255,232,255,103,255,47,255,83,250,221,251,199,254,102,252,119,4,230,253,188,250,189,254,167,2,202,255,24,255,42,254,27,8,65,181,116,2,250,252,35,0,247,0,170,255,209,2,0,2,25,5,82,3,32,38,248,0,156,246,36,255,6,0,183,255,166,250,55,2,152,5,31,246,28,250,22,56,32,252,169,251,84,252,145,255,200,3,238,253,64,2,102,0,235,251,197,1,180,0,162,255,0,225,202,254,0,2,228,3,224,255,218,251,106,255,230,255,225,229,75,255,176,254,26,250,104,2,70,0,180,254,81,255,112,2,222,253,171,0,108,1,243,3,68,0,228,254,144,254,199,2,46,0,73,0,222,255,93,254,148,1,110,110,27,1,188,254,79,1,125,255,60,1,212,0,229,255,170,254,218,251,214,1,245,4,198,1,30,1,120,248,118,249,29,253,123,254,49,4,228,231,195,254,182,253,62,255,74,255,22,205,176,252,244,17,109,253,197,2,138,253,202,254,144,1,88,1,236,254,174,1,108,3,1,248,12,252,120,249,76,255,64,0,245,85,32,253,61,3,10,1,182,0,180,1,144,255,220,255,131,0,252,0,193,255,154,0,112,1,107,0,93,0,214,255,0,128,0,0,200,0,26,255,15,1,16,249,233,16,218,3,215,253,225,1,96,7,46,245,80,3,95,231,8,1,212,47,74,6,128,253,68,5,74,245,226,247,139,3,165,251,114,1,101,191,221,249,80,255,24,0,253,253,234,0,186,3,93,2,101,2,102,255,207,1,23,2,96,255,172,2,214,1,59,3,218,40,150,0,99,253,228,229,83,1,226,253,38,253,161,254,216,3,212,0,116,0,249,255,62,0,158,3,127,8,71,255,216,253,233,1,47,255,127,20,38,0,110,1,53,0,16,0,7,1,114,255,233,253,32,255,82,1,82,255,131,255,113,0,50,206,144,1,102,254,25,1,244,255,232,2,83,255,230,1,129,208,149,255,73,255,28,254,2,0,150,0,1,0,17,255,7,0,113,254,160,253,151,252,186,2,169,249,189,2,251,252,16,1,192,252,162,255,103,252,117,3,20,53,178,0,192,0,148,0,66,5,44,0,59,0,237,254,242,255,184,254,212,0,133,0,33,255,44,1,118,254,237,254,213,255,180,255,209,255,66,1,48,255,209,84,228,1,73,1,68,7,40,0,108,252,246,1,130,0,221,1,218,6,247,1,48,31,174,254,189,254,26,255,98,1,160,3,174,1,167,255,162,255,108,0,225,253,109,1,126,255,70,0,134,3,125,255,58,0,213,1,68,2,27,135,36,0,232,0,102,254,61,254,104,0,6,222,113,0,110,249,214,255,233,254,164,255,232,254,35,254,126,254,237,253,64,3,80,0,102,197,200,255,93,0,164,0,47,253,196,32,100,254,164,246,72,2,236,3,202,254,75,247,208,254,129,254,19,1,38,4,242,4,41,1,186,255,115,252,123,3,131,0,234,251,27,2,246,126,232,3,235,255,27,255,138,0,248,5,81,255,34,2,70,1,168,0,192,254,204,2,221,254,214,254,29,255,70,4,197,255,239,206,143,50,18,3,88,2,50,255,121,3,7,253,54,0,76,1,27,251,171,253,101,1,156,251,206,255,88,255,148,4,218,8,75,0,82,255,71,2,152,1,99,255,74,57,122,1,46,1,251,255,48,0,109,0,28,0,235,255,20,4,17,2,165,252,98,251,54,255,192,7,52,1,146,1,66,0,141,251,35,10,132,254,95,4,53,1,226,1,47,214,100,0,17,238,126,45,172,250,147,254,49,37,194,254,233,255,52,4,121,255,74,245,191,252,78,0,142,3,96,0,236,255,169,253,46,0,87,3,15,251,140,18,90,9,6,255,120,220,62,252,191,0,166,254,92,1,86,1,117,7,226,59,10,1,28,2,15,1,170,11,76,5,6,6,5,252,129,252,225,2,25,1,172,2,230,253,174,40,102,252,31,1,167,2,204,0,122,212,239,246,166,254,220,249,6,255,197,254,164,253,56,5,55,1,37,5,169,251,153,1,152,255,35,255,211,200,25,250,34,252,193,2,216,252,75,2,164,2,92,1,192,226,209,250,132,235,255,247,104,241,211,255,190,1,22,6,13,253,92,232,146,23,26,239,228,2,164,254,81,48,67,8,106,253,83,253,64,230,192,39,127,33,245,251,64,245,155,238,229,254,11,6,168,18,140,244,188,2,97,13,191,240,49,4,52,9,74,228,87,249,77,254,232,18,104,248,164,4,12,3,133,240,230,231,66,249,151,18,252,238,180,247,106,249,65,1,123,252,134,5,101,252,138,245,82,251,71,198,10,248,56,242,123,0,208,43,112,7,134,248,164,29,184,10,87,239,234,236,54,242,41,250,83,249,31,233,245,14,148,8,22,237,207,252,150,252,239,233,123,247,225,240,190,14,168,250,66,1,154,251,28,252,223,240,130,53,103,219,176,252,213,14,101,253,197,251,125,9,233,242,120,249,22,242,202,249,77,242,40,2,210,25,215,239,179,216,180,234,2,232,82,250,190,6,238,250,129,238,238,23,90,6,25,245,48,6,20,5,94,22,24,10,101,43,184,2,240,242,142,246,69,35,250,16,30,242,113,5,144,0,3,8,212,34,30,24,50,20,120,1,50,38,6,247,233,239,149,14,221,255,143,245,174,8,103,5,254,7,43,11,253,192,101,6,85,251,106,253,240,10,63,247,217,14,58,236,46,252,38,22,183,234,177,255,151,13,94,2,182,14,211,250,247,254,139,3,23,253,237,3,64,199,125,239,141,240,230,227,106,14,118,8,40,246,35,45,1,254,12,23,124,254,242,240,144,242,88,8,156,252,86,244,210,2,6,5,69,240,142,40,146,249,73,20,235,9,215,4,139,30,189,255,54,13,31,243,210,255,32,241,62,3,33,5,116,247,6,239,34,23,223,251,106,231,237,55,209,7,200,3,54,16,231,239,132,5,210,254,47,223,148,250,153,41,215,218,18,4,72,3,2,238,50,8,142,4,192,5,222,252,6,245,164,1,207,253,187,254,92,10,206,244,54,5,14,19,190,3,83,0,200,1,179,4,86,226,254,56,70,251,154,8,94,248,110,248,171,242,184,251,148,23,117,249,216,250,123,238,87,214,42,39,76,246,55,243,145,18,237,254,42,242,156,3,238,4,180,28,113,244,19,253,104,254,242,17,12,19,21,254,81,13,8,18,110,0,45,2,158,250,176,249,76,238,163,6,132,5,67,2,18,254,204,2,197,0,206,164,20,247,156,0,72,4,105,255,221,248,176,2,190,254,67,9,27,225,212,250,109,249,181,30,162,27,61,254,2,1,128,35,108,7,212,33,72,3,163,13,53,243,213,11,37,254,182,247,163,233,36,222,75,232,126,242,144,16,65,244,169,234,179,36,130,245,110,18,51,253,42,0,246,248,50,12,131,243,164,235,220,249,13,255,61,254,21,32,105,247,212,242,14,16,16,224,227,214,81,234,216,16,170,2,21,8,193,7,127,241,132,229,169,4,15,11,76,247,230,1,173,241,235,252,101,249,215,17,208,1,190,247,220,246,167,248,129,7,66,6,242,71,255,5,201,253,228,0,113,219,117,232,245,254,44,14,255,127,143,5,182,255,255,244,64,8,128,255,20,250,114,246,137,6,252,10,210,249,77,8,106,2,9,10,154,10,82,249,84,1,183,12,80,3,51,13,243,246,199,246,225,248,156,1,64,246,12,185,56,251,248,9,32,244,144,0,171,253,36,30,52,19,205,244,132,247,72,8,40,245,163,2,47,209,156,6,152,250,252,241,214,16,252,3,137,239,5,255,78,228,132,248,122,7,12,245,45,24,180,229,166,250,136,241,194,1,164,245,153,25,218,255,108,40,220,4,58,247,111,241,146,247,196,250,53,9,46,12,162,36,65,249,78,12,229,240,253,4,241,255,1,3,208,246,101,254,148,5,48,201,251,251,12,11,154,248,196,23,220,255,6,2,103,51,71,4,95,251,121,243,213,253,72,243,180,255,44,15,66,13,242,3,154,7,160,0,1,237,106,18,81,228,111,240,226,21,22,13,142,30,159,233,235,225,80,36,251,11,254,13,136,20,61,53,84,240,98,247,229,240,104,253,152,255,45,17,74,225,36,0,187,3,218,255,51,252,130,13,140,19,108,1,100,220,52,245,136,247,156,248,48,226,30,237,100,233,19,242,35,251,64,238,152,25,249,17,38,9,225,25,16,4,106,8,183,228,206,22,136,248,145,242,165,4,138,246,213,253,214,12,232,197,248,252,204,4,130,9,120,0,105,53,136,3,182,250,133,2,242,249,159,250,160,248,136,5,89,253,107,249,195,6,100,9,102,233,213,12,63,255,133,255,181,7,79,14,148,250,143,197,243,241,179,21,116,250,28,1,247,5,241,245,149,7,103,3,60,15,136,247,37,206,154,11,104,254,197,243,230,230,100,7,14,3,112,26,228,254,10,4,57,38,141,23,223,240,250,239,3,239,244,9,154,241,10,234,161,18,161,254,242,31,171,227,103,14,112,2,222,238,188,15,36,245,110,248,35,240,176,248,16,251,132,28,248,2,82,33,203,252,150,252,111,200,137,251,232,234,174,252,23,246,222,1,132,6,36,251,150,254,109,3,153,13,198,250,158,235,43,8,156,15,191,253,134,1,178,33,52,3,181,0,36,252,228,21,222,37,88,4,8,244,246,254,210,4,26,254,240,4,131,247,153,202,145,14,116,243,244,9,209,6,109,219,129,31,129,14,241,242,17,237,248,10,148,237,129,247,25,0,170,233,216,15,63,7,55,18,20,9,114,251,31,2,2,0,91,15,132,243,211,10,104,252,165,244,22,253,39,251,206,254,233,10,234,255,174,245,232,11,184,12,12,7,226,250,212,69,232,248,56,0,98,249,47,254,234,253,30,247,251,23,57,247,45,246,203,251,233,12,239,5,17,1,104,4,155,249,1,10,2,250,106,3,232,166,161,251,9,246,152,215,75,247,74,242,194,0,34,10,201,6,105,18,199,53,204,13,201,254,161,31,12,252,183,252,248,238,25,3,245,254,50,255,105,50,133,245,232,230,196,0,186,27,102,249,78,253,212,4,190,244,148,245,28,248,99,32,102,245,1,238,101,252,227,247,194,244,151,6,39,215,217,249,124,8,122,240,163,22,212,6,196,248,233,235,155,18,23,236,232,244,197,248,74,10,82,23,180,0,2,243,137,249,202,4,119,1,17,20,138,245,130,235,231,16,170,241,228,38,72,248,141,8,136,11,127,229,71,253,105,4,120,233,69,233,132,25,66,14,81,249,17,15,47,0,110,218,107,248,220,9,36,251,74,28,126,45,192,255,0,9,201,0,133,241,68,253,149,0,132,10,219,252,138,15,178,10,47,252,20,252,112,233,235,49,30,29,159,254,133,237,230,240,164,27,146,0,26,243,249,11,163,7,169,254,77,250,86,254,238,232,218,250,244,1,10,252,22,252,214,247,148,244,215,175,50,10,45,6,141,1,204,242,187,244,254,1,133,251,70,13,122,7,99,0,137,255,144,0,200,243,141,9,255,6,141,1,150,14,176,255,174,242,42,241,138,251,21,250,201,245,252,249,73,20,139,8,172,3,105,19,226,246,51,191,69,1,118,247,41,238,1,20,130,252,64,229,142,232,40,7,200,253,67,32,65,3,92,13,149,238,20,253,114,13,6,17,31,244,37,216,87,36,25,250,43,237,158,7,58,252,245,13,197,1,193,2,110,63,123,252,93,255,206,244,152,255,25,249,13,249,31,251,179,12,183,7,230,4,186,252,122,254,178,243,252,3,222,9,23,248,150,2,255,244,198,250,169,252,142,242,125,173,241,0,122,255,72,252,180,253,12,10,32,8,217,31,114,0,4,38,138,229,110,235,98,246,238,8,169,253,86,254,116,5,117,228,52,251,56,1,113,238,35,246,41,18,231,250,174,251,194,246,184,8,225,15,14,183,241,250,69,243,20,252,240,235,206,0,153,4,246,235,90,9,214,9,155,250,4,10,118,255,245,16,92,66,242,9,126,26,151,242,82,3,54,252,1,255,28,5,180,8,168,6,253,250,172,5,208,245,207,5,34,12,37,247,74,244,98,229,118,6,203,82,19,6,200,3,154,0,124,0,22,251,202,2,105,254,44,0,247,0,224,3,180,8,8,11,155,5,171,254,188,4,180,249,238,23,100,6,80,223,66,2,214,234,217,0,65,255,204,0,21,228,246,19,182,14,191,19,165,232,27,26,112,1,243,241,13,238,206,29,229,241,176,246,89,5,83,27,29,243,203,255,244,7,210,237,163,16,146,37,12,252,108,244,45,17,192,247,109,46,144,249,82,252,110,242,224,253,126,250,90,248,1,250,165,11,201,249,109,190,79,1,1,18,58,248,237,14,123,253,50,7,192,255,99,242,130,12,138,254,198,255,126,250,136,28,90,248,162,247,108,211,27,246,1,2,251,231,233,229,104,8,81,12,238,19,168,8,175,250,212,8,255,18,137,228,2,6,126,235,49,246,96,0,11,13,137,242,132,241,0,28,184,239,70,3,194,243,156,12,5,250,34,234,45,55,208,0,154,247,51,3,195,251,250,47,58,26,38,245,220,219,3,236,33,230,81,249,99,239,94,231,244,250,166,250,253,251,116,252,209,244,216,248,37,18,46,253,228,254,95,255,14,236,198,27,50,207,22,250,179,234,20,243,192,13,77,4,184,251,235,246,22,253,223,255,85,10,150,238,227,252,84,253,234,5,180,6,196,231,180,25,157,242,118,253,3,215,4,19,201,22,175,246,238,254,250,5,52,15,108,248,121,250,171,246,21,211,240,247,169,3,179,254,81,5,209,249,82,21,8,247,65,243,104,223,116,239,43,231,188,246,213,243,56,5,120,247,194,0,90,239,98,225,34,27,183,17,237,2,164,28,67,0,185,254,17,1,139,12,223,248,155,254,127,27,18,13,138,24,232,1,156,240,212,39,63,25,71,1,55,17,141,3,121,3,177,236,146,253,47,240,228,9,78,7,140,2,242,6,151,2,247,11,12,252,146,250,66,16,6,80,170,255,94,12,69,1,136,248,255,1,134,253,238,4,145,237,46,250,111,26,14,243,131,255,138,17,162,215,10,21,204,38,13,3,34,1,150,8,159,6,206,14,170,248,80,30,212,254,229,7,132,21,152,8,232,0,226,27,90,5,60,243,168,13,110,54,50,251,1,247,190,3,141,0,20,13,205,244,37,252,97,36,222,2,210,25,211,241,12,209,197,20,12,255,190,248,2,0,236,248,170,230,124,3,158,3,20,255,248,3,31,251,43,254,18,255,140,248,158,214,160,237,117,252,190,225,7,15,52,2,188,232,67,13,115,1,240,235,161,15,156,4,1,3,213,253,176,248,129,244,48,249,172,33,205,5,173,38,144,250,97,13,252,224,151,0,120,1,192,7,215,11,231,14,50,252,25,2,130,228,172,7,7,234,105,17,26,216,5,249,48,245,190,222,176,0,148,241,41,25,76,12,90,2,48,248,201,53,24,245,80,4,237,247,181,231,235,5,224,254,168,12,142,234,69,45,158,14,217,246,40,249,117,14,101,29,116,249,77,3,239,26,68,11,212,13,150,9,242,3,150,9,127,233,243,7,41,13,100,218,162,252,108,228,10,7,44,22,92,9,197,10,3,23,67,253,136,209,35,240,252,30,240,254,2,10,83,0,48,2,196,235,81,247,156,254,241,242,58,11,166,250,68,226,237,6,214,7,94,239,192,20,86,1,4,32,75,19,7,2,240,13,68,17,208,10,160,209,51,244,101,7,154,6,149,234,63,224,116,29,140,255,240,247,135,238,117,4,138,7,144,2,208,225,74,245,52,243,222,10,44,11,62,232,78,20,113,237,26,254,235,252,220,189,202,253,252,19,172,4,64,3,186,16,78,0,16,12,208,10,77,8,3,4,176,6,54,1,40,3,197,249,150,255,102,12,246,17,127,244,15,6,248,225,108,2,152,249,83,1,186,17,11,13,20,2,161,254,4,1,249,0,169,247,225,253,70,184,120,253,225,240,138,21,10,249,219,211,138,254,226,247,74,6,50,0,169,238,14,246,14,244,71,3,251,219,58,10,254,6,103,0,219,251,149,254,29,1,42,242,247,1,75,254,30,0,102,5,75,0,220,244,252,251,23,12,222,16,244,246,227,2,33,3,19,167,114,8,145,3,162,6,149,0,1,8,199,254,221,252,65,13,60,250,44,17,93,240,86,3,192,250,38,4,25,39,188,24,182,222,200,245,80,217,122,254,182,243,121,244,126,16,162,21,239,1,192,14,140,202,79,18,117,247,119,252,133,19,65,24,167,18,46,251,164,7,1,238,190,11,142,254,98,253,96,207,86,233,215,31,140,0,205,5,60,231,91,8,207,4,22,0,44,255,42,8,92,253,62,9,67,253,239,239,109,1,154,11,191,253,150,3,156,28,59,253,243,7,42,20,64,28,25,204,69,243,116,252,148,248,97,239,226,245,62,1,27,19,184,2,216,255,145,249,36,6,59,251,32,19,121,20,49,0,221,247,52,236,221,29,18,35,92,6,79,11,190,236,124,224,218,8,233,7,180,248,178,12,82,10,239,252,21,199,251,38,153,13,58,247,130,4,86,10,56,10,15,248,136,244,236,250,186,9,111,3,43,251,52,251,44,253,12,249,12,2,37,230,245,242,34,246,205,13,76,3,130,11,160,8,62,242,133,207,10,244,76,9,192,1,92,2,156,237,99,9,122,7,198,255,149,0,136,241,29,248,150,16,148,228,131,243,56,253,85,247,52,39,40,245,162,243,88,10,131,11,58,13,45,25,51,6,244,254,232,253,103,7,211,220,39,42,42,252,23,32,14,25,46,20,143,18,160,0,234,11,159,252,72,24,93,251,91,228,104,6,214,19,2,17,226,6,227,240,150,4,107,255,54,4,92,7,29,20,243,58,80,254,119,246,178,251,86,251,54,4,1,250,97,32,114,245,167,15,182,2,72,0,173,2,0,11,188,51,90,254,74,228,176,1,252,7,28,209,236,254,126,8,116,252,80,237,93,22,6,255,22,0,252,19,254,255,126,10,187,3,195,222,239,225,105,241,160,2,78,251,203,16,188,16,64,48,198,246,125,22,37,5,197,16,252,1,234,11,244,253,73,4,18,13,231,253,120,246,196,249,229,233,92,16,143,253,123,6,245,11,231,10,176,6,81,244,198,3,249,189,98,2,14,243,64,16,90,241,68,2,177,242,172,254,203,209,248,253,167,249,89,11,162,2,109,255,92,235,74,239,99,236,27,18,155,24,159,8,35,10,125,225,188,255,11,16,218,16,252,249,220,212,90,247,221,252,232,0,78,226,161,255,106,4,127,19,151,254,139,6,135,17,23,14,208,231,126,255,137,0,96,250,10,11,178,0,246,201,40,252,125,4,206,4,51,6,35,6,214,12,173,20,45,247,229,7,189,231,72,226,106,245,198,9,219,16,229,253,174,222,22,253,114,253,93,240,227,232,112,241,170,17,146,215,14,251,210,0,214,19,84,244,230,240,79,15,201,3,217,251,100,231,24,238,140,246,210,247,140,252,34,9,178,243,85,21,135,251,34,253,108,6,135,8,170,74,136,251,247,246,108,254,212,4,255,13,134,0,10,7,8,240,21,245,169,2,154,14,39,7,187,64,149,3,14,247,192,241,204,249,98,255,240,253,232,252,138,1,248,226,142,9,146,1,121,254,183,255,138,250,6,5,153,230,96,20,70,4,85,252,137,6,10,248,226,61,77,248,64,16,128,249,63,28,130,2,138,22,113,16,209,248,220,0,246,254,165,0,7,8,102,20,240,242,112,230,36,21,234,5,74,2,55,6,104,196,101,245,173,3,28,5,46,220,209,244,71,19,159,244,245,250,231,10,31,31,14,0,179,251,190,14,252,13,80,3,57,5,114,4,233,244,20,242,76,235,141,48,14,0,186,5,54,228,174,4,110,242,19,255,239,245,231,250,189,1,45,4,82,255,148,6,62,15,229,0,210,22,78,253,210,3,14,253,158,4,165,252,86,82,71,255,198,2,29,3,149,247,111,1,136,247,234,3,221,14,100,252,212,1,238,246,250,241,72,6,59,13,18,0,0,6,166,252,130,2,228,224,25,69,115,38,242,236,69,244,205,28,46,23,190,16,244,40,193,255,235,237,206,3,77,247,42,10,226,14,113,7,124,249,174,247,228,7,200,246,37,11,100,2,206,19,32,251,156,252,15,254,150,13,111,248,66,244,123,253,5,14,203,11,35,243,85,64,133,235,154,244,252,6,247,245,133,14,98,218,184,250,226,240,96,254,162,239,97,221,24,229,14,254,210,252,241,252,239,237,209,22,26,6,131,247,225,1,24,1,48,3,134,18,22,217,23,46,19,248,100,246,108,19,168,253,84,250,147,248,182,247,58,12,126,10,205,252,194,246,98,3,211,247,28,4,198,255,28,1,246,14,126,237,238,239,215,250,27,5,252,244,51,19,75,210,10,2,66,248,112,27,211,32,226,6,210,255,20,2,233,19,149,19,153,253,14,12,41,8,243,26,173,251,49,240,169,244,236,20,62,237,59,252,50,26,55,15,62,35,108,5,219,42,39,23,118,244,59,252,111,242,199,235,162,245,90,13,61,235,201,190,69,230,96,254,148,1,206,4,230,245,36,243,110,5,14,0,31,254,162,238,55,5,109,0,36,4,118,15,251,4,233,233,229,4,149,246,207,0,250,206,64,24,113,246,169,242,199,9,80,3,22,12,120,36,87,10,151,9,190,8,52,9,172,247,227,20,147,3,179,8,153,255,200,22,56,246,138,29,96,37,44,232,251,15,108,10,70,249,31,1,107,26,218,15,125,254,244,247,146,21,112,12,158,18,98,255,138,2,236,211,65,46,86,24,120,239,188,20,102,12,62,19,102,244,103,237,44,252,117,0,152,7,74,248,148,234,134,25,246,254,202,227,156,3,162,245,180,253,137,37,223,246,100,7,194,247,224,19,64,7,28,31,67,240,84,252,149,5,37,3,159,237,174,250,124,3,67,255,94,223,187,12,194,0,255,2,195,244,187,239,34,252,153,47,96,255,46,248,152,250,244,234,188,249,226,0,47,231,195,239,237,6,56,9,252,238,38,253,170,234,42,240,203,194,8,250,118,254,5,16,53,255,232,10,237,252,63,13,213,254,240,24,162,249,238,227,35,206,10,18,166,3,111,254,230,10,236,8,188,236,20,251,135,232,226,245,19,247,247,250,38,13,160,239,146,238,255,127,193,243,160,248,67,0,198,244,150,0,152,18,221,249,72,2,117,247,102,1,59,249,250,250,35,238,45,248,80,7,172,3,106,248,1,255,104,221,216,250,236,242,246,18,3,254,20,11,242,255,186,9,255,249,114,3,164,4,196,243,151,196,159,249,212,255,245,244,112,1,181,251,207,251,45,254,174,24,231,22,24,11,176,235,57,2,88,244,187,25,124,37,196,236,201,1,15,19,159,238,200,13,76,7,202,240,191,240,60,60,226,245,169,253,145,236,52,15,82,250,152,253,98,7,116,245,60,243,150,250,215,251,250,243,106,246,146,248,118,18,222,255,134,239,83,6,254,243,164,21,8,231,14,242,127,10,218,221,77,1,150,255,22,9,55,249,65,241,141,1,31,242,24,230,78,232,95,37,88,11,135,252,112,4,15,5,190,75,244,254,201,243,76,255,160,6,210,252,249,252,206,236,56,254,10,253,158,252,78,4,100,241,138,254,213,1,10,229,160,5,253,215,179,231,67,237,254,243,138,251,41,1,205,19,245,249,98,21,204,2,58,254,222,14,4,16,85,11,135,247,24,253,168,19,46,234,86,244,238,8,110,9,180,30,144,245,210,255,194,216,228,20,6,252,248,3,182,35,191,17,211,21,180,8,132,245,14,238,103,246,198,248,189,241,242,248,218,18,90,210,148,7,55,242,54,4,142,235,140,246,173,255,238,246,242,235,249,252,165,2,215,219,160,252,109,252,142,17,155,1,44,237,111,23,120,17,191,22,11,238,49,12,180,248,253,249,34,9,103,239,130,4,146,203,23,3,45,251,40,251,108,1,177,0,28,250,33,246,123,244,242,247,118,0,213,243,37,1,121,248,212,72,180,251,152,0,32,246,122,7,156,250,168,249,46,1,193,252,104,252,64,1,145,252,28,251,45,3,245,255,48,27,246,253,20,12,137,255,206,5,252,11,34,26,249,243,249,51,198,24,169,3,96,6,254,251,104,7,225,246,135,240,134,21,222,10,187,0,112,246,29,251,244,2,16,194,107,12,125,251,40,3,44,249,63,230,214,5,206,243,158,255,32,241,235,1,216,6,116,12,110,8,124,248,251,2,141,4,148,0,167,243,252,250,162,70,61,255,155,251,77,3,32,183,51,254,236,0,158,251,228,252,155,255,83,3,92,241,94,5,155,222,218,242,54,250,2,4,254,7,42,17,247,253,232,0,26,254,136,249,255,127,162,7,97,251,126,255,136,1,194,0,156,252,67,11,88,255,118,249,114,252,222,255,51,3,175,251,92,6,249,236,183,253,110,251,196,253,195,1,71,15,18,42,221,255,226,239,212,27,198,27,164,252,182,240,34,243,16,1,121,253,220,0,189,46,206,242,166,10,198,7,88,6,151,241,156,38,90,9,24,12,250,253,49,20,78,240,36,12,168,0,232,4,102,254,245,240,88,212,17,215,250,7,141,5,208,5,32,252,230,249,115,253,89,251,198,8,211,1,124,18,154,0,217,2,76,28,238,255,33,5,205,255,224,248,194,4,193,5,149,229,250,211,57,239,22,16,19,4,106,233,90,5,46,0,237,212,246,15,35,250,245,255,147,253,208,1,13,3,112,53,1,1,42,2,47,12,238,2,191,248,22,4,28,251,0,254,227,2,219,57,98,49,1,15,8,11,163,0,84,6,39,0,158,18,131,5,107,247,13,2,146,2,163,1,5,0,92,0,8,6,34,1,10,248,107,41,124,233,249,242,27,230,237,245,180,15,221,243,219,10,81,3,46,22,4,1,244,10,99,0,59,5,32,2,158,5,62,254,170,253,252,2,32,6,246,251,48,238,44,10,227,184,108,6,235,3,93,253,145,12,178,254,192,252,84,250,66,1,96,2,44,1,88,237,212,252,220,255,115,2,118,6,8,255,186,252,67,84,167,255,166,249,18,2,129,251,224,36,10,2,6,232,165,8,145,216,206,253,232,3,173,19,134,255,253,255,152,27,141,1,186,247,106,1,175,61,233,251,94,197,9,250,180,250,11,245,208,253,180,243,10,1,211,255,44,5,16,243,20,249,78,9,189,0,137,25,124,0,8,251,156,0,76,2,138,245,222,243,12,11,156,241,177,2,44,15,42,18,192,0,189,254,206,234,46,253,222,44,161,253,7,14,203,16,69,8,106,1,102,220,180,45,193,242,53,9,215,29,149,8,254,16,154,11,35,246,169,0,32,232,91,0,240,5,237,255,22,6,20,238,187,252,29,224,129,3,200,224,32,8,226,243,6,3,160,214,198,254,119,255,244,253,87,0,225,252,145,255,74,0,32,5,94,3,10,1,243,0,199,0,224,254,181,4,195,252,114,6,64,11,56,159,27,15,211,204,85,2,206,217,220,247,239,243,168,251,36,2,130,253,143,14,66,254,13,19,51,8,68,0,80,245,206,236,65,228,7,1,244,219,242,252,195,247,64,4,167,248,112,250,226,255,183,250,74,2,245,15,11,242,111,209,62,9,4,2,252,251,66,3,22,255,102,8,235,193,1,9,221,241,249,245,82,223,98,2,130,11,177,246,245,8,178,3,34,242,142,229,55,250,10,253,160,252,24,255,39,11,40,0,230,246,21,8,167,254,9,7,179,253,39,251,135,2,76,27,191,245,228,55,241,10,247,2,76,245,88,253,196,3,109,1,6,254,252,86,230,6,54,255,65,245,219,254,170,14,0,5,247,253,229,242,7,18,82,2,9,249,217,255,210,255,48,0,178,245,217,253,244,9,168,248,146,14,66,249,171,3,167,254,249,255,162,249,147,164,22,252,23,22,52,8,184,1,146,6,252,3,174,253,88,1,231,5,250,250,142,21,217,1,122,211,56,238,208,2,93,18,46,30,126,0,95,248,28,254,144,249,26,249,53,6,228,3,80,253,131,254,142,6,218,5,240,253,164,252,101,253,201,252,255,127,49,254,13,255,38,251,50,4,156,9,125,250,53,254,3,250,182,5,213,245,240,252,121,254,82,1,116,13,122,8,100,252,181,3,180,7,240,5,10,244,97,253,108,50,76,10,245,10,210,2,16,209,230,255,104,2,168,4,169,4,252,251,128,255,190,166,191,0,152,1,223,243,176,253,72,254,240,4,236,245,79,3,82,3,252,8,234,254,126,0,166,8,123,245,235,255,62,255,174,253,235,253,45,0,58,2,38,0,124,2,252,4,171,0,150,116,136,2,143,3,154,254,44,1,90,2,157,1,73,216,202,255,183,250,42,0,22,249,235,1,134,208,240,248,26,0,169,1,217,7,142,3,58,224,106,1,209,7,142,255,230,245,231,251,7,255,200,254,160,0,141,6,163,105,212,255,160,0,66,3,243,0,162,253,240,254,45,252,187,249,105,0,21,254,242,2,26,255,138,9,24,0,237,235,117,254,22,242,100,56,72,251,96,243,251,9,76,205,118,252,173,1,217,0,80,254,17,251,12,255,31,255,144,3,192,255,12,3,77,4,86,3,16,255,52,1,42,144,6,2,32,0,208,3,62,222,31,244,9,7,26,253,23,250,128,0,139,243,89,3,59,200,246,248,205,4,188,255,203,253,65,0,254,15,78,6,194,223,127,251,128,253,97,63,180,13,153,250,214,240,165,254,66,5,5,15,105,10,36,9,186,248,58,235,122,5,184,250,78,171,74,253,98,251,30,1,218,252,85,8,56,7,236,253,90,241,140,29,30,4,28,1,98,241,255,9,188,10,80,13,248,249,170,254,206,167,201,4,190,3,255,9,11,1,122,1,232,241,132,250,123,249,243,255,111,4,153,0,143,253,156,5,211,0,44,2,227,2,70,4,212,40,82,3,8,20,205,44,121,0,73,19,197,241,91,5,139,254,226,229,229,0,72,243,181,255,24,5,1,252,60,254,32,1,165,49,4,53,11,254,48,7,236,251,34,248,19,240,90,245,14,252,14,241,139,253,46,254,101,252,177,252,152,22,130,3,252,208,229,4,51,249,10,6,130,241,222,10,154,242,238,248,7,1,194,223,54,12,55,0,136,254,202,0,200,3,106,249,176,3,60,196,152,245,113,5,15,3,184,212,178,6,126,249,216,251,5,237,216,246,78,1,33,5,71,251,109,3,220,248,174,247,15,244,84,1,94,31,106,243,102,45,12,234,189,5,12,13,46,11,151,240,156,252,95,1,222,250,229,8,214,246,96,48,228,3,100,246,18,7,191,2,146,247,96,12,97,217,50,34,175,13,122,250,189,1,82,3,226,255,85,9,151,253,199,12,186,249,255,233,177,11,25,39,72,22,187,210,182,16,24,5,142,246,223,1,44,191,195,207,99,11,71,1,127,3,254,4,132,5,202,254,115,253,249,250,112,3,58,239,38,0,131,8,230,247,238,248,198,0,248,249,184,224,152,9,251,244,105,243,127,241,243,45,223,247,115,255,225,18,116,6,14,14,39,2,137,249,126,251,196,255,210,254,227,2,42,250,35,10,18,252,105,10,82,42,250,211,76,244,132,253,66,254,24,7,253,249,53,16,72,255,156,255,201,255,9,1,159,8,127,2,94,255,94,247,142,253,93,2,99,173,115,8,54,252,182,254,209,237,68,13,236,243,224,253,118,253,208,254,93,0,52,250,136,252,234,220,79,7,165,6,113,250,135,6,245,255,249,250,44,200,80,2,16,4,146,253,146,51,108,253,55,206,236,244,216,248,153,13,10,6,235,0,122,253,84,8,166,253,87,9,254,5,15,14,188,236,216,254,193,248,229,247,170,245,37,255,248,215,137,4,67,23,42,27,149,35,170,13,212,232,5,249,117,1,210,4,220,4,211,252,180,255,123,35,0,236,13,254,18,249,154,247,105,41,86,255,136,4,214,3,171,253,95,0,151,0,234,253,154,25,72,3,66,252,48,253,18,8,206,255,195,244,182,255,236,247,72,159,43,253,155,254,249,4,149,7,221,9,46,0,205,252,26,255,6,4,243,8,225,254,68,4,245,246,171,1,237,255,192,1,162,6,69,38,210,42,218,11,62,10,164,245,152,251,62,255,76,255,104,251,254,248,24,169,244,0,253,255,192,248,226,251,65,245,53,254,194,255,79,254,30,247,2,249,64,255,48,253,91,254,55,0,47,253,168,7,70,4,196,9,207,246,32,254,240,252,59,251,7,254,202,6,24,217,236,213,167,202,122,0,131,1,101,253,58,254,220,3,60,120,11,253,241,246,110,3,194,3,241,2,26,5,204,2,253,252,27,2,63,253,252,1,123,7,66,8,169,3,191,1,167,3,104,250,137,251,83,17,239,45,118,246,203,255,151,214,187,7,43,21,8,247,84,255,157,232,112,251,36,248,209,8,85,250,97,0,27,251,172,21,116,3,144,199,62,12,245,9,172,0,28,21,101,3,173,255,85,2,128,207,250,2,245,251,219,252,167,250,220,252,152,2,172,37,23,239,106,4,10,250,172,244,116,2,108,2,220,230,190,246,59,8,196,209,37,0,96,3,57,8,58,1,216,0,239,253,42,3,69,12,132,14,107,27,163,245,186,5,164,197,72,51,194,4,239,8,111,255,69,254,101,252,220,1,107,9,52,21,157,253,164,8,170,5,30,244,114,237,234,13,75,2,238,195,209,196,88,2,5,4,207,246,90,252,194,7,164,5,133,247,252,3,68,253,28,250,195,0,94,246,226,252,76,64,140,247,8,2,151,10,248,201,24,248,153,252,108,235,228,13,117,0,96,254,248,255,80,8,222,249,4,8,159,243,108,64,217,254,252,9,23,5,72,254,160,29,233,12,162,242,84,251,239,248,94,8,244,250,24,4,58,1,153,7,66,2,56,4,1,255,85,4,105,2,61,6,198,0,103,142,13,255,54,0,223,255,76,0,94,254,52,5,219,1,215,5,18,6,242,252,52,1,250,250,20,4,44,1,8,6,134,2,225,36,17,10,124,212,141,5,83,4,29,254,178,253,113,2,96,33,190,1,234,248,178,6,173,2,148,37,139,236,228,243,44,253,247,32,227,246,250,1,229,13,120,251,105,247,109,253,11,16,172,33,130,250,95,241,193,6,4,42,100,3,174,255,24,10,188,243,48,14,57,10,40,15,105,251,93,255,72,7,44,252,39,2,201,0,79,254,72,250,196,2,134,7,233,222,30,15,184,246,207,60,64,8,241,2,110,246,72,0,107,4,116,11,117,255,248,24,11,6,3,0,113,2,201,252,42,249,43,3,47,252,147,250,20,5,160,4,143,1,76,18,196,0,95,14,120,249,38,255,241,212,98,0,236,1,232,15,189,4,44,248,18,14,5,249,8,5,30,219,61,16,85,239,181,13,197,20,194,253,170,212,54,4,96,24,57,6,27,206,152,1,120,15,92,4,237,5,208,252,191,253,72,253,42,2,109,6,88,252,83,0,225,176,14,253,180,5,86,4,132,5,11,253,121,1,69,9,184,249,122,250,252,251,176,243,254,5,207,239,226,8,226,254,110,228,238,8,173,15,211,9,121,10,30,234,0,0,52,249,1,1,244,2,232,44,186,3,161,17,128,15,243,18,22,1,1,254,61,3,37,11,241,217,117,241,242,249,68,254,160,16,89,253,109,211,62,239,66,250,161,239,72,252,17,255,58,255,81,5,55,37,201,5,43,252,123,5,223,3,1,255,110,36,40,7,112,248,121,255,99,4,196,10,140,7,239,9,27,3,68,49,125,9,14,254,127,204,228,14,164,249,196,0,30,7,237,16,200,10,92,253,170,244,220,4,74,248,122,228,72,208,223,5,128,247,124,7,109,1,124,2,172,211,90,236,9,243,46,241,8,252,133,4,194,239,96,13,88,1,142,17,44,3,254,243,4,17,37,1,121,242,208,4,210,6,136,10,179,223,63,252,36,239,130,0,74,239,73,201,209,11,113,245,179,0,64,216,231,5,76,250,180,251,109,251,217,249,220,245,22,248,120,211,129,10,200,5,231,2,123,249,168,10,230,2,196,255,188,44,84,0,106,253,144,5,1,197,102,254,93,8,128,249,158,250,134,255,97,0,154,254,204,252,126,1,231,240,118,1,162,6,235,255,16,253,83,2,189,221,37,253,152,36,162,6,230,245,122,229,53,246,16,249,129,19,229,240,9,245,66,255,129,56,142,201,23,12,82,251,118,1,146,6,96,7,30,1,192,253,210,247,198,1,78,253,116,5,141,251,90,254,149,1,238,0,182,6,0,8,136,52,105,255,9,255,202,0,124,252,2,234,49,12,20,213,177,249,163,7,195,240,32,13,149,5,88,15,159,7,181,251,77,254,36,6,220,5,232,74,219,2,73,254,102,14,33,244,244,0,82,239,222,255,9,5,40,1,106,254,168,8,136,250,102,248,8,1,0,6,176,11,54,0,124,3,75,255,247,249,22,1,91,97,221,3,21,5,1,251,68,255,58,255,107,253,100,2,16,250,51,9,84,205,74,253,208,253,84,5,84,244,164,231,251,9,26,230,143,5,184,1,170,253,188,251,48,1,31,246,94,249,115,252,0,10,76,3,0,3,84,244,107,253,0,72,134,4,129,253,206,19,7,43,242,255,9,9,244,2,107,248,22,213,22,254,141,235,86,10,102,9,170,0,222,253,81,1,99,25,158,238,222,21,43,1,8,254,242,55,52,252,140,36,248,247,108,34,193,249,117,248,36,8,119,0,41,252,207,254,157,5,147,1,91,10,97,255,229,0,209,0,158,5,3,249,121,251,249,3,160,1,152,1,198,1,90,3,116,253,238,249,174,4,102,71,122,0,177,1,91,255,162,0,220,214,43,45,146,18,26,248,150,16,140,250,143,246,252,248,40,250,1,251,37,15,63,251,254,252,215,3,159,253,230,6,72,255,224,233,34,2,12,31,186,7,6,255,254,16,170,13,237,10,34,3,78,3,172,206,188,251,16,255,13,3,12,212,69,252,216,38,34,255,153,4,238,4,234,253,254,6,28,227,172,5,155,16,47,1,126,241,9,247,222,254,29,255,160,2,162,88,146,253,46,254,63,6,16,254,70,1,103,3,100,248,148,0,193,1,214,0,129,247,201,2,138,1,129,7,212,143,238,252,59,4,127,253,208,4,10,255,36,6,39,6,145,252,110,244,199,255,113,1,97,6,79,250,170,4,58,251,48,1,69,252,104,0,31,251,89,252,135,0,10,253,155,13,90,251,177,5,106,4,252,250,131,241,122,70,6,0,25,0,209,4,184,254,91,1,0,254,23,8,72,1,139,185,230,17,1,15,78,254,23,253,76,1,192,253,190,11,80,1,15,211,122,253,181,13,28,252,246,4,249,7,73,5,169,4,160,11,49,45,163,243,170,5,255,16,218,9,218,216,250,255,58,49,106,3,6,2,219,1,227,4,38,243,142,245,194,18,238,209,78,252,86,254,226,244,83,6,81,4,2,252,255,255,223,6,134,2,107,40,135,244,193,52,80,4,102,2,125,4,224,252,73,9,141,255,24,3,76,252,129,246,13,249,138,251,41,3,198,243,191,1,100,195,57,1,227,43,190,250,134,246,79,245,54,249,188,8,70,4,34,3,43,5,28,14,43,255,103,5,240,10,154,40,186,4,200,246,37,216,57,248,154,255,147,245,255,8,120,247,38,7,122,251,255,233,13,240,4,255,55,1,100,2,181,254,30,245,123,207,10,39,138,232,124,236,70,252,246,3,133,251,92,3,228,4,90,4,235,247,10,1,26,255,177,253,166,238,230,0,123,80,106,5,106,4,68,250,240,241,120,8,68,3,38,249,1,254,226,253,216,0,26,0,148,13,141,4,59,239,26,12,11,255,189,253,38,7,200,8,206,20,75,184,141,1,90,21,222,2,80,15,162,241,63,1,218,251,158,253,171,226,216,251,176,5,159,233,64,4,139,35,218,8,241,0,201,0,223,216,247,249,17,245,211,5,218,105,196,255,56,249,107,5,91,3,62,250,177,255,158,251,53,252,234,250,138,3,147,251,157,245,216,254,64,5,118,245,64,254,60,250,44,255,207,249,30,5,17,56,139,247,75,247,112,253,99,20,62,243,198,248,6,31,133,19,9,247,7,2,96,2,230,218,92,249,234,6,52,196,6,5,158,244,204,8,51,253,88,8,174,9,93,241,58,9,251,255,19,255,30,9,189,2,250,252,96,253,236,255,169,253,111,2,68,253,55,253,45,252,26,139,190,251,80,3,115,255,249,4,57,253,246,6,35,255,153,255,170,0,71,255,221,251,250,11,41,5,158,4,57,14,39,255,167,7,30,46,86,9,184,215,241,245,76,6,84,2,160,254,149,8,7,248,81,9,126,252,109,219,136,251,112,213,20,0,94,225,233,251,103,14,99,8,24,10,7,255,184,255,255,127,144,7,190,1,135,252,179,252,128,252,245,4,192,1,71,1,173,242,4,0,190,2,148,248,122,253,31,3,254,252,150,2,113,252,168,252,31,1,131,6,148,255,192,255,16,0,42,6,245,247,65,149,112,0,68,255,200,9,76,253,250,0,104,1,52,2,100,3,51,16,60,5,160,70,0,242,189,1,108,1,193,245,100,254,154,244,140,255,51,10,164,246,212,255,182,42,24,250,114,251,239,0,145,3,190,0,167,198,1,253,50,10,115,11,171,246,6,14,112,249,143,24,237,253,152,253,37,5,246,251,124,252,103,3,183,254,211,1,176,4,134,248,84,4,78,12,34,229,32,2,181,199,247,10,51,21,49,52,168,5,39,249,12,2,37,233,187,5,182,248,232,26,218,221,92,5,21,250,19,19,56,247,238,251,20,18,16,42,149,0,154,254,249,250,247,250,255,127,143,251,173,3,192,247,195,1,100,250,174,0,38,1,219,1,173,241,74,6,105,6,169,253,114,2,10,8,159,2,90,6,39,252,133,255,248,7,165,1,5,7,16,72,234,9,153,254,78,236,24,12,144,251,192,254,31,7,30,0,30,209,239,250,174,252,94,254,39,250,31,249,209,19,192,42,212,0,151,237,178,249,40,249,169,247,227,1,19,4,59,248,219,254,39,0,231,251,67,0,198,226,200,2,18,235,128,3,172,48,48,249,255,248,2,6,249,13,250,255,162,1,184,255,48,4,87,5,56,4,236,13,188,5,226,1,238,250,214,230,213,254,122,205,11,253,153,239,2,15,189,211,64,251,50,255,62,6,145,251,88,243,222,12,226,254,228,253,9,3,164,4,91,251,164,17,78,10,23,8,230,37,124,252,234,3,19,73,63,253,192,248,161,4,32,237,98,249,82,242,236,246,246,244,8,238,204,7,218,243,110,0,117,0,149,1,42,190,2,254,123,198,163,6,130,7,187,247,98,245,45,0,40,4,251,1,11,249,58,8,250,246,215,4,228,22,50,9,80,31,240,48,77,252,164,254,224,6,6,8,136,240,179,247,6,242,92,15,111,6,12,243,165,23,136,1,200,243,137,12,115,246,207,1,237,244,237,249,235,4,40,1,71,250,47,7,53,237,164,1,41,255,213,1,11,252,240,254,185,0,75,150,126,251,8,0,42,1,3,1,71,252,213,253,216,1,105,2,153,251,95,253,214,3,114,254,111,249,72,1,114,3,102,2,32,3,175,1,84,0,112,3,16,255,142,61,12,200,21,5,42,6,164,3,74,253,80,250,131,9,141,249,184,5,227,0,247,5,15,2,128,255,186,2,101,9,42,253,209,5,248,3,146,7,151,248,58,250,18,255,164,3,203,9,249,253,133,251,45,2,30,9,188,2,142], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+225297);
/* memory initializer */ allocate([205,13,58,158,0,255,0,171,4,141,252,31,13,235,251,47,8,8,2,249,0,158,3,21,3,112,5,71,255,138,249,134,3,9,0,138,247,132,248,31,2,178,247,26,11,180,254,76,5,168,254,180,1,108,254,82,255,23,254,90,3,2,1,229,0,211,255,71,1,196,254,104,251,58,254,115,0,36,255,54,254,62,255,15,1,238,253,36,6,194,253,20,158,167,0,89,2,253,251,87,249,184,243,121,239,156,249,12,252,22,252,249,253,199,252,54,254,177,3,34,2,193,0,11,186,100,255,213,251,58,3,82,1,128,4,50,2,6,254,80,3,239,0,188,0,144,2,97,0,82,255,197,255,242,0,154,7,189,255,233,2,251,7,168,1,64,255,62,2,244,253,17,6,54,2,200,5,21,253,231,1,113,175,104,3,191,251,10,4,77,5,151,3,153,0,154,0,242,1,54,0,43,2,35,252,195,2,171,255,235,255,188,2,112,250,90,0,143,2,113,254,123,0,59,253,117,0,182,1,74,1,48,253,190,0,44,3,118,255,204,1,0,128,94,255,102,254,185,254,134,255,72,251,214,253,10,254,78,255,203,254,117,1,199,16,79,252,130,234,64,245,41,230,39,251,254,4,221,250,253,225,38,252,93,254,206,255,80,9,224,237,154,231,228,209,204,254,66,254,158,13,40,237,200,6,178,253,192,3,195,0,81,2,164,0,27,13,119,6,209,4,66,0,237,252,165,254,73,202,74,0,71,251,212,252,254,239,154,255,142,3,133,249,12,248,181,243,229,247,211,245,40,251,147,17,191,6,244,218,37,2,216,2,83,13,166,7,169,238,216,251,58,22,192,249,64,248,159,6,180,253,207,18,118,255,204,242,0,254,17,6,186,7,214,16,38,253,110,254,60,3,76,8,136,55,34,255,197,10,18,222,11,2,212,9,249,3,22,3,120,255,42,254,4,255,51,253,40,3,167,251,198,53,142,255,98,251,237,11,138,235,73,247,184,6,1,254,37,252,56,6,23,251,238,245,241,6,51,4,63,9,29,255,26,9,96,253,196,245,87,250,74,8,106,1,225,4,58,5,185,254,129,171,252,249,24,0,204,246,112,253,189,7,164,255,49,255,116,247,34,0,55,254,245,250,207,4,52,254,128,255,116,254,81,2,97,253,23,250,136,0,177,254,48,2,159,251,234,1,240,3,180,3,181,33,240,242,211,1,113,3,157,233,96,4,212,254,104,250,203,4,22,6,222,3,202,251,214,0,102,252,175,255,96,4,30,195,104,251,179,4,137,248,151,0,204,5,19,6,91,254,92,254,84,254,6,253,36,1,197,255,51,4,119,253,183,252,238,1,194,0,27,0,0,253,156,254,54,0,163,0,183,255,37,1,75,249,120,254,238,2,234,0,239,2,145,255,234,104,143,3,123,254,195,1,186,1,4,1,139,255,14,1,19,0,131,246,106,2,62,252,122,1,10,0,94,248,200,250,13,2,254,254,75,253,197,239,25,40,108,11,175,250,125,12,215,39,214,26,208,245,96,233,107,2,54,248,13,248,67,253,38,10,209,1,193,253,55,1,175,0,162,0,89,251,162,0,99,255,109,255,69,1,39,2,24,2,68,255,222,254,91,255,87,1,14,0,244,254,23,150,22,1,127,0,23,255,188,255,94,2,125,0,153,2,182,1,70,254,206,9,32,3,57,248,127,253,126,254,218,249,78,0,178,3,189,0,106,0,55,247,244,254,84,249,88,251,218,3,4,12,15,7,21,0,4,233,60,252,0,1,212,193,216,250,205,244,22,242,235,1,174,13,175,254,250,249,240,1,146,243,140,6,189,246,88,239,251,247,6,56,214,233,208,6,21,7,109,241,79,241,70,5,247,6,74,254,104,252,62,9,158,5,81,253,0,2,114,248,67,1,170,243,239,6,172,7,170,229,178,39,83,30,189,5,175,7,83,3,182,10,245,28,246,242,230,2,62,7,54,1,64,255,88,252,22,249,249,252,48,252,4,250,100,250,98,253,64,240,170,4,200,250,239,238,76,1,92,2,194,3,85,148,52,252,74,3,25,253,19,1,201,2,5,255,225,252,90,251,116,1,43,255,89,254,202,0,165,4,225,255,60,4,50,252,244,2,108,255,123,249,128,2,219,253,173,254,30,250,144,255,170,253,154,252,154,1,5,204,85,51,137,248,4,9,164,255,248,252,221,0,223,5,42,6,35,3,204,254,120,249,108,254,173,255,67,242,209,250,162,253,134,246,195,255,255,253,62,1,243,248,1,8,95,7,247,252,244,4,226,253,140,255,222,13,104,182,86,244,45,252,93,10,197,244,102,252,232,214,36,3,107,0,162,12,10,251,160,253,18,4,15,14,197,3,170,254,208,247,245,254,168,6,157,240,23,3,132,8,39,252,48,3,52,253,155,245,99,0,243,5,126,46,10,249,7,3,27,207,172,12,78,241,254,7,234,254,3,6,79,11,135,246,246,255,222,3,204,5,159,250,185,242,40,252,99,12,233,5,184,2,239,252,155,0,208,251,158,1,224,7,116,248,204,243,154,251,68,0,15,15,80,5,234,15,188,68,178,6,172,253,160,15,120,6,230,0,254,254,218,8,75,3,72,249,16,18,54,253,86,3,184,2,124,2,179,250,94,1,24,251,245,253,168,0,51,217,2,253,198,0,120,10,124,31,120,8,27,245,81,200,164,5,248,253,169,0,8,4,198,5,38,1,124,253,192,254,88,3,2,5,40,255,24,252,99,252,2,0,134,252,167,2,139,253,128,4,207,250,139,201,255,191,230,251,2,252,106,0,129,251,215,255,59,253,235,6,142,252,39,253,116,250,8,6,136,255,130,1,186,252,72,245,23,6,136,3,17,1,131,239,215,251,200,254,234,251,234,0,62,3,131,1,172,0,68,252,180,254,104,1,152,1,125,0,90,0,92,1,147,3,248,254,143,3,7,1,124,0,148,253,156,253,220,0,164,0,202,0,124,0,212,137,97,255,238,3,192,254,27,1,151,249,224,250,159,220,149,21,96,29,188,244,94,208,211,10,116,251,50,7,237,4,186,253,254,2,194,9,137,1,185,3,151,253,12,253,189,254,186,248,171,4,210,250,76,254,59,252,110,1,185,229,54,251,54,35,144,1,22,251,212,252,233,254,108,254,85,6,86,0,86,6,240,255,96,0,253,253,255,254,217,255,122,255,51,7,218,254,21,254,116,252,136,255,48,253,118,251,237,249,149,1,122,255,16,2,44,92,179,255,183,0,68,254,29,8,187,3,137,2,198,8,164,12,223,2,78,251,18,31,224,36,246,23,157,227,28,0,186,242,244,1,101,19,50,251,50,1,101,1,126,11,118,252,131,237,135,3,151,240,95,17,22,4,155,251,209,1,159,4,90,206,6,252,218,211,57,20,37,255,168,231,16,6,13,8,164,250,246,250,202,252,39,1,46,3,69,244,241,253,154,253,168,252,34,3,167,0,154,4,18,254,167,249,242,2,242,249,170,2,250,250,32,254,74,253,86,0,189,255,107,250,45,251,209,253,201,254,66,1,204,254,200,255,40,1,98,255,232,255,20,253,59,255,74,105,30,4,209,0,30,255,165,0,169,2,125,255,85,1,85,1,230,5,103,2,139,3,248,254,75,5,132,1,198,0,251,255,162,1,241,252,123,111,82,0,209,253,53,254,168,254,23,1,142,255,198,3,239,253,89,254,30,1,94,254,2,253,42,0,186,0,205,1,162,1,80,253,121,11,233,10,146,0,173,6,103,253,230,7,37,1,14,250,76,245,202,193,168,253,33,250,60,249,245,244,253,251,166,6,252,0,125,253,214,1,209,252,90,3,94,248,166,4,55,7,240,255,10,1,29,0,230,1,129,101,139,0,220,0,177,1,182,254,168,0,150,254,206,253,180,0,138,3,130,1,179,252,152,2,40,4,152,253,38,250,177,254,92,255,94,252,170,252,155,252,155,255,52,255,67,3,117,0,94,193,130,238,74,10,93,6,175,248,124,251,139,254,242,253,233,9,199,3,127,246,167,252,240,4,122,249,113,0,77,3,230,29,193,250,125,20,187,249,188,8,90,251,208,255,12,13,67,248,186,249,167,250,29,255,41,253,198,253,112,4,76,7,155,2,92,0,112,255,19,2,181,3,194,251,18,2,228,6,46,1,190,0,124,146,182,0,57,3,229,0,112,253,73,2,188,1,200,0,85,251,193,248,125,254,243,252,132,4,180,2,116,251,251,253,48,254,237,254,184,254,218,0,54,252,174,0,128,254,207,253,218,255,48,253,116,255,253,3,241,254,199,255,207,1,31,157,170,254,216,255,26,0,159,0,170,252,148,3,4,250,247,251,9,1,105,0,49,253,180,253,96,0,77,254,216,254,30,255,224,0,101,1,30,0,64,2,190,255,171,138,184,255,118,1,32,0,0,1,48,1,172,252,62,253,248,0,27,253,133,254,212,3,117,2,64,5,18,15,93,247,103,255,182,240,65,241,34,6,206,2,238,251,198,250,199,238,58,5,254,19,66,20,35,14,94,8,121,35,32,245,73,16,14,14,221,25,210,17,86,255,154,253,172,4,106,251,160,19,209,2,185,255,11,1,4,0,254,99,143,254,100,1,75,1,75,4,121,1,156,254,86,252,137,4,161,252,83,4,124,255,222,0,148,0,130,5,140,3,60,0,121,1,0,5,212,1,178,2,198,1,247,0,56,238,234,23,245,254,157,11,212,232,232,230,137,236,159,239,198,242,155,6,69,5,139,5,110,241,44,1,118,47,145,244,52,6,222,255,125,246,241,254,63,252,48,249,89,7,183,255,59,254,236,252,226,252,206,35,184,10,90,3,86,1,223,3,225,254,54,3,219,255,132,4,43,250,211,2,209,200,37,249,237,7,91,252,4,251,120,2,127,235,208,1,240,254,125,4,222,254,85,18,40,253,61,250,73,3,10,0,229,254,92,0,244,254,217,254,102,1,160,0,149,1,2,0,131,254,167,2,204,2,66,255,128,0,19,1,255,0,123,0,100,254,59,254,239,254,26,0,82,255,172,254,132,2,136,254,192,107,231,255,66,0,35,12,85,249,143,3,244,1,251,251,5,4,235,249,60,35,114,254,48,246,186,253,107,4,200,190,83,254,252,250,253,255,16,9,236,253,210,254,82,255,110,255,99,254,104,8,241,3,42,0,146,1,65,250,157,0,110,22,242,252,27,255,75,9,134,2,26,11,16,249,49,254,67,245,223,241,82,249,7,208,202,253,7,1,154,243,223,246,118,37,130,251,161,9,225,17,16,8,120,253,129,247,171,248,94,253,134,253,174,254,87,1,44,250,110,3,238,253,48,4,102,53,66,238,234,2,232,37,164,239,92,228,155,4,28,253,179,253,148,252,12,1,200,251,38,252,24,238,132,10,216,11,237,247,230,0,51,242,176,3,170,236,140,248,172,5,1,255,70,253,180,5,162,253,6,255,102,255,225,168,79,252,90,6,180,253,30,254,243,249,127,255,210,3,137,253,46,253,70,4,235,6,201,254,20,2,4,254,184,2,152,251,246,4,86,3,172,255,194,16,158,1,23,13,37,4,163,3,136,244,122,218,221,255,210,9,185,251,55,2,60,254,184,222,197,15,81,254,184,10,28,247,87,10,92,251,58,254,112,254,142,241,197,254,38,45,101,253,0,2,162,0,117,254,41,205,245,255,104,248,134,252,234,199,246,240,56,239,30,5,188,253,8,255,25,5,146,1,231,251,115,0,37,8,251,248,108,251,191,254,105,252,199,254,0,254,125,255,83,6,64,2,243,1,24,248,130,0,14,0,180,255,76,231,239,1,141,9,139,190,212,246,110,245,142,248,73,9,52,247,149,253,237,245,131,2,107,253,4,251,167,3,125,3,224,3,100,247,109,246,117,254,4,254,139,4,40,255,22,205,50,253,6,252,117,249,70,253,198,2,255,254,98,10,154,4,254,7,34,247,228,245,150,199,138,251,254,251,199,8,232,253,58,1,123,0,105,251,95,253,40,6,216,245,5,0,196,3,107,2,78,249,37,198,34,250,146,249,129,251,163,255,124,210,34,255,87,1,101,247,161,254,96,252,223,254,119,10,53,8,230,2,235,2,59,247,146,0,220,248,88,245,34,4,24,4,230,11,242,0,80,17,246,0,94,1,149,203,0,3,219,252,27,7,252,55,36,5,142,254,135,1,115,250,110,250,157,254,212,252,192,255,196,0,155,244,73,4,242,249,34,251,180,1,194,255,211,252,70,5,43,2,68,247,203,249,212,3,53,250,138,39,126,246,68,28,135,196,233,5,42,8,56,251,173,255,251,244,152,2,146,2,86,243,249,251,229,5,107,10,96,255,221,250,36,4,123,3,176,1,225,250,57,246,24,5,15,5,209,6,46,253,64,246,199,238,224,242,40,245,23,245,199,236,72,49,249,251,69,254,215,5,144,246,224,237,156,17,128,244,48,10,43,5,118,254,97,254,193,247,239,247,6,4,204,241,198,250,100,11,65,244,160,241,176,243,141,255,65,2,182,10,17,3,179,238,103,248,208,254,237,236,123,255,192,243,121,248,192,253,106,2,244,6,8,10,202,247,98,255,110,240,93,251,24,1,143,2,162,0,184,250,158,233,12,60,222,250,17,6,18,1,199,244,125,16,2,18,209,239,125,202,200,10,25,251,18,255,207,5,47,6,142,5,32,247,126,18,32,231,27,3,106,254,218,5,52,6,12,254,72,245,149,252,32,8,109,7,192,3,88,1,211,3,254,254,184,3,222,9,247,209,125,3,157,2,81,5,6,2,168,250,14,15,235,9,111,2,213,248,175,239,126,10,116,244,12,245,97,4,70,221,97,5,101,4,106,240,140,0,10,14,221,6,223,8,110,1,187,6,102,8,245,52,24,249,103,250,24,230,190,253,194,12,205,9,230,27,168,2,252,5,38,5,157,251,36,22,3,5,100,254,228,234,77,11,169,245,121,245,124,250,84,1,118,253,95,3,103,7,51,11,128,1,114,2,88,3,252,1,85,5,217,254,192,3,32,154,234,0,252,255,239,0,100,254,250,255,3,253,224,2,226,255,136,0,144,3,26,2,232,252,157,1,103,3,75,254,49,1,30,0,62,255,81,4,167,251,222,13,10,237,193,1,219,253,54,226,122,14,142,241,242,6,161,5,192,8,73,0,1,2,201,242,214,246,164,250,115,15,157,11,151,4,57,232,207,19,169,247,104,33,97,19,79,251,78,250,189,245,38,253,3,2,12,253,220,1,176,251,67,8,4,251,242,1,80,1,61,254,41,3,250,251,44,2,45,255,186,255,163,255,89,0,13,253,40,1,104,3,230,254,124,1,214,254,214,10,148,2,59,5,223,253,173,1,254,202,240,219,95,253,11,1,205,252,97,6,223,255,111,2,174,252,232,238,145,251,231,3,250,254,136,7,183,2,41,249,23,245,4,3,200,19,122,251,24,1,160,247,33,5,120,3,78,246,213,1,180,11,130,250,237,48,80,251,78,251,171,3,253,255,79,3,50,3,100,252,135,0,228,250,32,209,224,253,176,253,182,240,185,1,44,13,116,12,34,5,212,248,62,253,180,252,217,250,5,4,38,249,172,0,164,9,121,252,135,252,246,198,250,247,174,45,68,248,38,253,131,249,214,0,219,4,175,254,122,253,161,255,152,5,170,252,20,255,88,0,254,255,2,2,149,249,172,255,233,13,46,1,2,3,32,251,224,1,152,2,226,2,192,6,9,249,77,247,66,253,2,242,255,190,177,6,226,5,148,2,89,246,13,8,208,255,167,243,161,6,132,3,59,250,46,2,31,1,117,234,255,3,76,248,231,3,192,248,50,244,28,255,199,2,246,4,84,10,120,253,40,4,59,15,75,251,14,253,56,4,238,4,18,0,92,3,226,8,143,2,238,1,35,255,225,194,54,5,39,254,144,249,171,254,213,13,37,12,121,249,127,2,69,246,185,0,221,1,124,254,78,20,208,233,44,3,188,2,132,8,232,253,244,179,52,246,32,10,85,11,32,0,115,251,220,5,90,254,234,252,134,248,203,3,111,0,202,4,234,250,29,2,234,240,192,252,130,2,49,1,226,240,217,34,58,2,180,0,198,6,220,249,133,252,8,69,12,253,190,2,180,10,121,253,74,8,102,0,165,250,205,1,198,1,204,0,205,254,32,251,230,246,73,5,9,249,109,248,167,253,0,2,70,8,126,247,254,0,166,4,28,251,155,3,142,4,104,1,64,1,64,1,186,4,114,255,96,254,236,4,51,255,123,5,255,251,52,75,72,1,58,0,21,0,236,251,250,6,105,8,185,2,76,254,175,249,155,252,19,254,141,246,226,243,203,7,239,5,249,248,103,255,129,10,103,253,165,250,109,252,54,72,173,3,204,245,223,251,52,4,233,242,208,255,58,250,63,2,216,2,130,0,88,255,40,0,130,3,93,8,238,5,59,252,138,248,128,3,70,3,196,4,160,1,42,250,124,5,130,255,224,83,92,2,204,6,102,0,212,252,228,252,34,253,58,4,5,254,44,254,60,249,147,4,252,0,103,1,180,1,3,253,23,3,214,2,214,252,46,7,250,248,30,22,198,246,251,4,243,244,55,240,118,5,121,10,224,1,172,53,16,253,204,8,26,5,254,251,42,7,54,0,9,39,47,2,90,5,199,2,126,7,35,249,134,2,16,0,66,243,116,10,215,6,221,245,174,18,230,251,97,9,229,196,76,4,130,1,196,2,153,254,199,1,231,255,74,252,241,0,30,254,12,1,23,9,50,245,114,255,56,248,202,253,220,255,222,3,98,231,173,12,142,250,213,249,248,2,11,253,189,247,162,222,127,244,224,252,69,240,226,243,217,250,59,248,5,249,86,254,78,2,7,4,211,1,31,0,114,10,150,6,240,199,150,4,90,250,211,252,13,251,103,11,4,8,218,249,15,253,41,13,190,251,246,14,250,7,112,44,116,4,127,3,106,4,48,253,252,250,27,247,49,0,44,253,141,1,145,51,39,252,63,6,147,254,237,5,16,254,210,3,104,8,111,5,241,6,216,11,88,252,24,1,183,6,57,238,10,19,83,252,96,255,188,3,92,253,27,255,220,253,183,0,34,191,169,252,151,242,224,4,190,253,206,8,236,253,9,12,130,250,189,248,163,253,17,7,23,252,142,255,58,251,50,15,159,253,42,12,130,246,162,247,184,1,244,6,70,6,141,239,23,4,56,254,88,32,9,0,234,22,74,249,92,252,7,205,206,253,25,12,185,253,235,255,76,248,230,4,84,255,15,2,234,8,200,19,241,234,50,4,101,1,53,7,24,0,28,252,100,0,206,255,74,4,89,11,95,254,87,252,73,254,247,0,70,72,180,246,216,247,110,254,188,253,83,0,230,254,186,255,201,3,28,2,37,255,148,251,91,249,61,255,42,244,68,245,74,248,232,250,139,248,56,4,18,4,100,4,128,255,184,22,255,8,24,11,140,246,35,0,166,64,209,2,225,247,47,250,255,3,114,253,233,7,199,5,71,255,111,246,244,1,218,11,103,10,71,15,179,4,230,3,82,2,235,253,93,255,250,254,227,2,13,0,86,254,182,0,138,1,94,1,153,138,141,254,150,0,82,254,147,0,158,251,43,0,122,254,42,1,63,3,62,255,158,0,142,255,255,254,190,250,183,253,206,0,56,254,222,1,10,254,82,249,73,249,187,253,232,253,45,0,163,252,57,3,69,4,1,255,83,253,38,0,236,255,163,1,174,253,10,0,128,250,242,253,9,181,196,0,40,250,255,0,52,7,201,221,19,242,15,252,98,252,206,252,85,251,236,0,82,11,74,255,8,56,152,250,40,4,157,4,202,248,31,2,185,253,170,0,23,243,93,251,154,246,216,255,229,251,209,251,228,255,202,5,220,251,223,251,212,11,25,248,145,3,28,4,212,3,218,235,34,18,13,201,80,15,170,5,111,238,201,249,74,3,82,247,120,254,214,255,38,242,254,254,18,242,35,10,225,0,120,245,16,18,235,8,203,5,30,250,116,8,151,0,124,1,121,243,194,251,158,214,213,7,75,9,249,245,99,252,149,254,19,251,118,51,183,255,144,4,167,8,71,249,214,2,13,2,24,4,66,1,197,252,69,8,50,15,66,5,72,242,195,8,126,2,211,8,165,250,44,247,94,41,83,3,33,251,130,252,79,7,142,252,93,248,238,14,186,241,62,249,138,3,26,8,220,253,117,3,59,246,220,250,53,243,58,214,239,7,53,4,197,11,175,251,135,11,115,7,194,4,194,0,68,7,130,249,178,0,147,3,68,4,41,3,61,254,158,253,40,253,31,3,127,255,155,255,119,252,254,255,166,9,12,5,119,255,32,2,149,182,199,251,212,254,197,255,26,1,183,254,224,253,212,250,107,8,110,36,206,1,124,254,209,254,132,244,160,253,172,202,20,2,186,250,254,251,50,5,183,21,179,254,97,19,195,2,216,248,46,4,179,9,32,248,197,254,149,8,81,3,164,254,123,1,125,247,181,194,135,3,120,12,48,15,140,1,2,18,189,12,227,245,217,236,125,253,20,14,156,250,244,5,149,247,213,1,56,242,234,252,173,1,234,240,5,7,152,255,60,9,118,251,233,249,243,3,57,7,21,255,96,248,216,247,156,5,198,9,234,240,88,249,245,197,209,244,198,2,112,2,21,17,98,231,152,253,217,252,215,249,68,246,148,253,107,252,180,3,93,19,176,252,161,252,2,2,94,247,114,8,15,253,192,196,236,247,184,48,205,245,45,253,237,10,131,222,34,247,210,3,219,245,167,8,84,253,231,9,42,12,251,254,78,255,81,9,251,236,137,4,224,255,67,250,26,8,129,250,154,12,32,252,194,17,170,243,20,4,207,1,91,235,4,0,140,250,141,250,234,6,25,249,164,252,250,255,62,247,244,249,101,253,75,2,42,252,58,247,224,250,14,6,226,253,182,20,52,253,135,0,233,193,54,13,34,254,255,4,103,2,37,13,84,6,187,206,26,255,29,12,158,12,229,250,44,11,116,2,135,2,245,241,42,255,161,249,223,10,236,2,64,4,199,255,130,232,192,9,103,1,207,2,196,5,18,253,148,249,179,247,73,15,52,241,53,2,162,251,125,250,97,5,4,252,10,255,163,73,98,250,130,251,44,250,87,253,226,252,248,252,192,3,143,3,87,250,80,1,166,251,193,247,147,252,236,253,156,2,250,3,74,4,152,1,240,7,161,253,112,253,147,232,17,12,158,9,64,184,253,251,78,0,30,240,183,1,179,252,196,5,34,1,234,1,60,254,102,6,203,242,80,0,163,6,202,1,4,1,191,4,252,253,91,7,194,255,35,0,20,246,89,249,238,251,215,6,90,254,198,4,207,0,152,255,88,4,151,0,39,254,246,253,58,103,50,2,116,3,103,247,231,254,238,0,185,252,13,4,180,253,81,0,147,255,254,255,224,255,75,0,142,2,233,1,12,2,124,254,128,250,118,252,87,251,88,252,239,254,216,255,156,255,106,253,246,253,111,255,119,0,102,2,102,252,15,157,76,255,100,253,194,253,161,0,64,254,173,0,238,2,159,253,212,252,131,255,46,3,60,2,42,10,148,79,244,0,28,7,212,2,3,2,164,3,246,250,56,253,34,252,207,254,243,255,5,253,123,251,225,1,4,253,64,1,112,2,148,253,130,2,42,250,200,253,167,253,113,253,234,252,188,250,78,1,234,250,126,1,14,3,158,251,127,253,3,164,180,0,207,1,134,253,102,253,87,2,156,254,209,251,48,3,192,253,184,4,144,3,135,254,112,2,25,4,42,0,161,255,114,1,140,7,89,255,237,254,142,0,97,255,102,254,83,2,206,253,136,253,236,2,168,4,102,2,215,255,238,255,100,255,195,255,0,5,82,253,107,1,247,2,244,2,94,180,154,253,103,8,95,251,169,0,71,1,214,5,14,3,223,250,122,255,73,3,218,0,180,255,92,244,202,0,80,0,25,1,89,0,195,255,114,249,59,0,131,255,195,0,64,1,226,250,200,255,38,3,47,0,191,255,249,0,0,72,102,253,6,254,52,255,62,255,208,253,96,254,199,241,74,1,244,254,74,3,104,41,80,255,168,1,48,249,231,241,110,249,180,252,203,254,230,253,179,1,171,55,255,250,117,1,188,10,66,253,178,250,2,253,152,13,89,253,199,15,17,2,190,233,218,255,211,252,179,4,126,18,62,1,236,251,11,236,139,8,110,242,159,1,132,9,51,244,164,249,56,254,85,250,78,13,250,248,233,3,56,222,212,1,164,4,241,1,20,18,76,252,23,240,138,209,66,245,30,253,240,5,26,240,214,252,133,233,166,250,162,11,108,17,149,3,197,4,188,254,114,251,35,9,59,251,0,248,202,2,228,26,24,12,86,27,13,0,237,254,217,240,22,3,104,0,103,5,8,8,165,7,0,220,82,254,57,255,5,1,252,2,147,255,46,255,27,3,116,3,178,254,10,6,240,254,221,255,226,2,244,254,243,255,64,254,133,2,97,0,76,0,4,5,169,254,114,253,112,0,131,2,62,89,122,2,171,253,147,253,240,252,132,254,183,3,60,254,83,253,140,0,176,2,254,252,247,0,89,253,28,255,24,151,55,1,222,253,68,254,94,2,69,0,61,255,18,0,36,255,178,254,214,255,31,2,228,255,236,1,254,2,208,0,74,251,214,253,213,0,168,251,117,249,160,253,126,1,219,7,213,19,222,187,87,5,66,253,168,252,96,254,64,249,61,248,150,11,96,248,38,0,152,0,200,2,210,0,179,253,213,11,91,251,32,248,121,224,250,41,161,247,212,253,84,248,162,0,8,254,227,3,214,3,251,245,134,253,39,252,124,249,188,1,206,247,101,254,232,1,117,5,146,251,96,7,104,252,233,254,209,58,11,253,22,251,32,244,134,252,151,255,98,253,22,254,18,255,141,246,234,250,147,3,240,252,95,252,117,6,167,255,52,4,189,1,234,9,112,250,231,74,165,255,181,1,240,2,254,0,167,3,86,3,126,249,170,255,225,253,29,4,152,2,101,255,27,254,102,240,206,255,50,0,198,255,190,245,9,7,198,254,76,193,217,248,241,3,40,9,42,244,86,252,225,6,253,250,106,255,87,254,252,229,124,252,94,5,35,3,37,2,133,245,69,3,227,1,113,253,2,18,235,4,211,255,66,3,79,4,78,243,236,241,190,244,97,246,45,235,48,44,139,249,79,242,193,248,158,236,131,33,66,9,86,246,245,1,254,250,217,3,100,252,124,13,200,1,14,255,38,15,209,247,178,11,164,27,53,254,14,10,244,62,85,32,168,255,60,2,218,255,0,0,128,6,215,253,28,7,208,247,52,4,159,1,92,254,108,7,96,249,126,255,42,1,237,249,201,0,108,254,217,248,92,252,76,3,134,37,15,254,80,192,206,12,150,3,245,253,219,249,184,9,211,252,147,0,4,6,211,14,110,5,37,4,178,255,246,255,62,2,60,10,137,251,0,254,186,253,40,250,224,2,29,239,18,3,199,244,194,250,92,15,172,56,91,49,125,252,194,6,95,253,130,1,92,253,227,10,36,245,112,244,119,1,219,1,116,247,202,8,83,3,20,3,12,1,240,4,157,11,162,255,38,4,238,3,71,253,157,2,133,253,38,252,16,237,50,250,250,255,182,240,123,24,232,249,8,0,9,254,153,20,39,242,69,0,42,59,215,8,46,250,220,253,204,6,100,6,132,252,129,252,1,3,41,254,226,0,97,25,94,246,11,248,212,251,51,4,122,252,100,53,67,251,136,48,61,242,132,255,190,251,204,3,146,251,18,254,248,245,113,3,247,243,113,1,2,255,150,253,110,252,187,1,26,251,146,2,42,5,34,2,242,255,10,3,140,255,134,254,222,252,244,254,48,0,116,4,86,101,247,1,131,253,153,252,26,4,42,1,69,255,131,1,106,254,87,1,212,0,110,0,211,2,183,2,209,255,206,255,200,253,190,255,91,1,204,249,20,0,189,2,27,254,158,255,237,252,150,17,22,4,164,249,34,246,185,0,248,3,0,255,68,253,109,254,102,255,103,0,16,253,79,253,36,8,73,250,246,8,104,1,182,68,70,253,18,251,20,3,116,0,243,2,239,2,72,254,158,253,43,254,211,4,246,246,216,4,204,254,41,2,41,4,122,95,35,253,155,2,4,0,28,254,93,0,249,254,151,254,234,254,12,250,176,0,31,5,25,6,179,1,76,254,201,251,4,1,146,254,216,1,231,251,135,2,158,0,46,1,93,252,220,255,34,252,224,2,68,254,53,4,232,249,5,255,148,0,232,3,72,4,212,254,32,255,205,254,18,187,39,0,206,0,74,0,249,1,21,244,251,250,231,252,44,253,206,2,68,1,35,3,106,3,174,23,69,247,7,243,218,253,48,36,155,13,180,239,72,240,41,254,90,3,122,10,202,251,126,248,40,8,111,4,146,252,33,2,157,8,68,3,192,251,35,2,173,48,174,8,196,252,255,240,189,18,200,246,50,246,67,240,91,247,168,53,8,4,66,252,103,7,8,1,37,250,238,247,15,255,44,5,32,255,232,252,8,3,82,8,40,10,28,247,113,239,188,12,74,6,172,249,60,251,64,245,211,3,20,248,170,76,158,247,172,2,39,253,21,255,223,254,76,2,168,253,245,0,145,252,208,252,157,1,169,255,122,251,10,255,69,0,202,3,145,255,244,1,73,4,63,4,118,255,180,250,30,0,78,254,60,254,238,166,177,0,236,1,206,0,255,254,170,252,165,5,37,0,104,5,97,0,254,254,43,3,34,255,53,0,36,2,208,6,124,0,249,251,52,4,186,0,197,1,83,255,156,4,69,247,71,2,120,254,250,249,42,253,121,11,205,241,168,252,166,5,116,30,37,245,62,252,27,247,115,6,168,7,76,250,3,251,190,217,224,254,155,9,46,9,39,246,84,0,66,2,238,8,224,1,84,6,21,25,56,255,170,0,233,5,198,0,23,252,21,254,24,252,161,0,30,254,95,2,214,0,231,2,220,254,118,254,64,255,92,0,73,0,97,254,196,254,81,2,214,255,166,254,200,1,44,0,182,3,129,0,67,255,38,3,35,255,143,246,15,18,100,11,95,239,120,0,173,215,174,4,244,215,139,255,63,34,88,12,19,9,138,4,118,253,189,8,181,239,82,9,176,1,91,6,169,227,38,0,124,0,182,241,234,249,65,210,10,0,210,31,164,6,73,248,165,190,93,9,32,4,58,246,156,245,85,245,83,246,208,5,196,4,16,19,124,251,13,7,253,255,63,244,167,231,88,247,112,13,246,243,76,8,70,0,99,246,101,4,127,7,173,46,54,246,146,253,161,8,66,253,125,10,223,35,2,254,10,245,151,251,225,248,46,249,240,241,250,8,224,242,41,42,78,249,126,6,194,255,139,1,62,55,251,254,112,255,88,217,217,44,140,252,107,247,96,1,186,254,59,254,64,248,235,7,70,250,218,12,94,0,153,13,229,9,49,17,116,21,219,14,247,0,128,252,104,249,162,243,106,4,155,251,75,248,66,1,99,3,112,248,202,2,144,252,8,0,9,9,122,91,110,249,91,253,128,1,164,247,126,254,152,3,37,246,17,254,42,250,211,11,61,253,148,4,133,250,129,8,167,247,139,252,245,251,155,249,119,1,148,9,131,241,109,251,21,8,71,4,111,248,82,253,68,252,242,7,82,13,253,243,153,254,170,253,220,247,118,72,245,6,211,255,120,5,212,249,132,204,159,253,160,250,183,243,8,255,29,22,230,26,181,240,62,255,148,38,41,4,39,15,66,249,187,252,108,253,213,226,17,244,188,13,27,1,188,249,143,253,141,4,207,11,5,250,223,248,150,5,207,253,143,252,66,5,127,255,231,248,83,3,0,128,218,254,68,255,140,255,122,253,152,4,118,2,135,3,161,1,73,246,96,1,235,252,59,2,129,255,250,247,192,247,162,1,95,6,10,1,242,254,106,1,51,245,82,251,74,255,2,14,8,251,190,5,190,255,48,184,50,251,55,3,147,4,70,5,77,4,130,5,110,241,255,5,155,255,94,243,11,9,222,255,54,254,81,5,143,191,34,252,158,5,238,9,87,251,74,2,84,249,129,10,181,10,122,23,113,16,170,232,140,253,20,6,190,8,246,23,32,244,135,244,140,8,132,249,113,4,36,5,166,245,137,3,10,254,163,255,103,251,36,131,110,251,224,5,252,250,152,255,168,0,55,0,150,13,95,255,2,11,28,254,224,255,0,250,194,4,170,252,161,254,113,17,26,66,169,2,102,16,163,1,98,254,168,26,190,240,78,45,75,0,40,19,94,5,64,0,124,245,81,241,249,11,139,250,54,255,165,254,94,246,96,0,11,4,3,253,254,254,127,14,157,5,182,184,54,2,208,3,179,9,4,0,184,251,114,7,161,14,195,245,60,245,72,7,208,253,98,0,53,3,2,240,229,20,89,5,131,235,134,247,116,11,228,251,92,15,99,254,112,254,230,121,101,4,95,6,43,0,4,253,130,6,12,3,244,7,204,253,64,0,31,5,54,255,75,3,18,248,88,3,230,6,165,243,122,251,142,253,60,1,127,0,247,6,126,7,56,13,185,244,3,233,227,6,46,19,8,255,204,66,50,244,168,248,145,244,249,250,20,243,25,249,194,245,76,250,6,255,13,14,82,238,178,3,3,250,35,4,248,255,217,252,253,250,156,5,80,212,131,2,142,1,227,249,191,7,196,255,122,217,195,4,66,1,60,12,5,248,114,4,114,24,44,242,22,3,101,252,172,237,135,250,173,10,42,221,41,19,37,24,192,0,82,0,186,251,4,0,134,253,213,250,207,244,12,4,204,5,99,246,87,252,158,1,221,0,131,8,74,254,249,4,126,245,10,72,221,10,252,6,216,8,50,251,188,16,156,237,166,4,54,237,49,252,230,0,112,241,200,9,18,14,160,13,88,0,42,5,231,1,149,11,109,241,219,246,49,23,97,33,180,6,140,28,57,35,26,25,215,2,152,15,24,238,132,1,130,14,140,4,18,0,189,1,229,4,142,1,59,248,200,252,82,254,233,2,185,234,128,8,62,248,133,240,45,11,194,0,75,69,99,7,8,235,76,16,125,0,18,2,50,245,155,4,145,1,223,6,183,249,2,122,142,3,76,4,12,4,76,252,179,251,154,253,232,6,168,254,72,3,72,253,182,252,64,1,92,250,0,246,129,243,58,0,132,247,95,5,70,244,203,252,161,252,192,208,76,246,91,253,174,247,98,17,240,13,136,243,166,251,110,243,49,12,9,254,194,21,207,253,56,15,70,41,7,244,48,245,118,5,183,6,108,245,160,7,114,255,169,18,46,252,190,8,108,233,82,254,204,4,238,250,149,244,1,17,171,249,192,246,164,244,180,224,46,17,10,254,6,2,204,228,110,2,135,254,174,14,198,25,86,17,193,26,240,225,214,1,1,14,210,1,184,198,110,13,114,57,104,248,16,246,239,252,69,14,250,4,187,1,74,253,176,7,85,242,39,11,166,240,70,251,240,253,139,7,9,15,252,252,157,245,147,17,216,241,228,253,147,249,75,252,130,254,211,3,83,2,165,0,173,1,176,255,12,176,16,4,32,2,241,9,110,236,182,247,232,244,177,254,107,254,148,1,206,255,76,244,202,4,7,2,234,251,161,14,243,246,67,24,92,199,26,38,86,233,110,20,216,243,226,5,157,14,152,2,122,252,197,0,172,9,222,241,248,7,214,251,34,9,255,254,236,245,219,254,180,10,192,253,2,8,159,252,174,241,214,247,217,248,200,130,146,2,13,6,66,6,192,6,234,253,134,1,19,250,141,253,71,240,227,252,209,246,199,10,154,255,14,10,200,255,28,3,24,255,138,252,103,6,43,245,239,3,62,3,248,22,84,247,250,2,6,241,207,244,97,254,72,2,86,242,62,238,20,193,88,1,24,240,39,2,197,234,215,7,118,250,254,14,130,249,189,7,217,13,144,5,1,3,87,8,169,6,28,197,132,253,27,1,58,13,97,0,232,251,163,240,204,0,88,222,212,253,136,244,145,16,236,19,241,6,98,0,207,2,58,24,40,250,196,2,112,8,164,246,220,15,233,5,205,8,210,255,225,248,124,255,197,2,12,253,80,252,63,2,46,4,209,249,75,2,1,160,59,248,106,3,200,253,16,4,92,4,94,240,124,12,10,11,117,0,54,6,152,9,170,3,112,0,86,252,12,251,192,19,221,244,179,11,255,9,191,204,74,223,9,14,228,229,79,14,254,2,235,2,248,3,103,252,193,8,106,248,173,16,16,243,12,252,36,9,221,10,215,240,228,9,72,248,100,250,109,243,164,1,72,86,26,253,128,253,198,12,166,5,143,7,255,4,121,7,97,5,31,243,17,253,113,16,228,251,77,9,122,11,206,250,106,8,224,10,140,246,246,4,30,9,242,253,200,5,77,254,158,8,252,0,2,254,6,252,67,250,242,250,74,252,168,1,34,4,243,246,178,252,255,174,171,248,88,0,81,254,12,251,116,0,134,254,234,246,43,12,10,255,30,0,139,237,136,2,36,8,206,55,207,252,192,9,101,248,251,236,25,218,225,5,84,246,196,247,235,2,63,254,186,11,168,234,254,253,13,7,255,9,190,9,238,49,48,251,59,47,70,8,156,15,32,10,34,4,254,1,152,250,22,244,229,9,104,254,99,20,228,11,170,12,71,255,94,10,117,241,16,0,69,249,31,7,0,24,58,237,182,0,236,6,233,18,6,64,160,255,201,9,223,225,132,235,12,243,136,229,168,5,66,250,142,16,38,1,121,3,188,246,119,231,137,246,47,21,71,8,81,11,98,5,49,3,31,252,193,249,186,198,198,11,187,242,218,231,11,255,33,19,252,19,237,8,209,244,150,4,159,1,135,229,23,15,135,232,142,237,137,255,94,2,57,247,95,17,40,4,113,248,145,10,187,245,136,251,52,209,221,14,114,3,98,6,70,21,52,239,131,2,108,13,208,29,80,2,230,3,162,2,169,245,36,18,58,229,88,5,110,255,189,242,103,41,89,5,12,15,153,6,133,9,159,240,77,13,213,9,103,7,244,200,138,251,10,10,179,39,72,6,115,246,82,3,114,249,40,12,119,242,66,12,61,17,75,248,201,239,139,4,30,7,21,241,224,249,105,254,174,245,168,1,109,1,241,241,164,0,88,250,38,4,0,6,54,6,66,248,200,0,140,72,26,255,130,253,27,251,114,6,232,8,81,19,175,17,207,246,136,239,168,14,33,241,102,14,48,237,78,9,15,198,26,5,94,67,29,253,220,7,193,13,193,5,100,250,234,5,114,255,51,254,14,4,158,9,203,3,74,5,248,4,251,6,116,9,102,252,36,13,202,8,241,1,69,5,235,10,0,128,169,1,82,7,184,255,157,9,133,1,206,254,100,251,122,253,251,0,43,1,81,245,65,2,31,4,34,7,84,6,66,251,142,5,123,252,7,251,193,246,39,251,110,1,9,2,79,254,55,0,160,15,219,11,146,250,201,9,250,6,219,195,157,1,228,232,22,255,231,13,136,229,52,236,203,8,36,0,76,255,84,2,112,22,110,246,4,251,78,237,176,248,24,0,252,0,208,1,17,11,120,255,0,156,223,255,105,3,86,10,191,5,200,250,206,250,236,254,242,6,14,255,73,252,44,6,177,255,166,252,97,252,42,239,164,253,144,29,79,249,76,252,192,0,252,254,202,250,164,251,63,253,126,2,132,0,162,4,72,252,133,4,172,1,247,7,32,6,242,6,181,87,114,247,128,8,138,6,100,240,14,5,138,4,18,1,159,1,195,244,208,1,249,1,206,248,214,251,63,247,7,253,221,254,8,0,37,252,152,255,28,3,0,128,22,5,215,252,59,2,190,4,199,1,174,2,144,2,40,249,118,3,234,252,132,2,166,251,54,9,188,44,210,238,54,5,39,51,158,12,230,248,213,15,58,248,187,251,110,3,212,14,152,10,13,250,51,251,53,4,192,3,226,4,181,255,95,243,202,225,223,10,238,32,185,254,108,250,105,249,4,240,13,1,89,12,199,253,13,251,238,6,212,10,15,248,171,0,248,253,15,6,135,14,220,242,36,255,112,7,254,250,40,248,206,252,165,16,138,252,255,180,130,242,34,254,171,245,215,245,180,247,119,240,144,11,27,6,80,254,35,252,122,10,198,6,131,220,6,18,154,238,231,9,223,227,36,255,218,216,81,254,29,225,121,3,70,218,253,25,250,2,221,248,254,22,94,3,212,248,82,254,21,192,77,22,83,3,22,7,48,1,181,19,149,6,20,252,244,19,208,232,185,243,172,3,40,7,242,254,94,253,161,5,15,255,150,12,217,253,78,254,187,255,0,242,93,1,182,250,208,208,55,14,99,20,159,29,1,252,30,8,191,12,81,233,151,252,245,15,223,235,217,241,76,254,147,237,245,248,126,231,255,247,9,255,212,9,130,7,220,39,146,8,218,249,233,253,144,2,102,6,237,243,132,4,97,5,60,251,92,19,35,255,120,19,126,251,251,17,174,249,233,233,233,245,182,52,118,246,128,240,14,12,74,4,167,249,43,202,230,205,99,10,20,14,66,253,148,248,76,242,117,231,16,9,187,7,249,244,230,236,64,249,2,0,206,238,75,254,140,7,56,243,37,11,54,244,72,3,136,253,221,229,28,254,107,37,240,3,157,45,2,245,19,248,112,31,110,251,58,227,152,245,21,13,39,5,120,251,184,248,94,2,32,6,52,21,101,237,90,246,97,8,6,7,10,254,254,249,104,241,160,250,50,5,17,242,178,255,222,1,25,253,122,3,224,252,212,255,216,248,31,249,2,252,28,252,178,252,164,4,238,251,126,243,121,246,66,6,17,14,52,2,162,71,239,255,47,5,125,254,50,248,20,251,24,13,81,3,84,237,140,7,200,255,65,10,1,42,116,249,216,214,164,11,6,6,153,4,215,243,165,252,10,2,20,12,116,37,66,11,68,238,130,250,193,235,50,0,107,239,65,14,92,254,228,241,86,235,129,248,223,56,211,245,145,4,39,248,8,42,188,246,83,1,22,246,124,17,185,11,38,238,170,243,119,242,57,11,138,2,205,247,76,0,142,4,67,250,47,245,121,254,119,16,138,253,88,250,252,248,219,249,26,23,39,3,212,249,24,8,99,0,68,2,73,244,55,4,54,255,20,70,47,251,211,236,55,4,134,1,133,252,42,7,149,247,174,245,89,249,64,7,211,200,33,8,106,12,80,246,10,239,41,209,254,247,22,4,108,9,180,1,22,4,13,247,74,249,241,243,174,6,61,252,134,248,161,242,46,24,42,251,19,239,115,0,202,214,74,245,105,252,15,237,222,5,18,244,24,243,252,8,198,248,33,9,13,230,203,7,1,251,18,255,226,2,132,255,25,53,252,0,112,250,91,255,226,10,75,249,186,252,20,212,37,213,122,252,254,242,236,245,81,245,85,255,201,15,155,247,198,9,70,26,30,253,117,239,112,1,0,24,74,249,84,222,160,248,112,0,230,254,237,255,30,16,45,42,98,2,231,243,103,30,98,244,246,247,26,242,214,1,230,232,82,40,236,255,85,0,140,249,223,23,138,250,53,10,149,14,124,241,138,7,27,239,81,251,103,252,66,254,71,4,238,3,142,3,237,246,161,254,40,3,0,128,18,1,66,5,105,0,56,9,96,251,201,8,54,252,153,0,108,12,27,5,159,8,62,252,161,8,103,252,224,5,139,255,193,247,106,241,106,22,78,31,76,0,30,6,197,11,50,254,240,241,99,15,254,18,14,4,216,16,234,252,86,254,136,249,20,0,184,214,11,231,59,230,134,16,94,11,200,9,110,244,0,1,46,3,24,254,56,3,157,254,246,13,158,248,159,245,1,253,170,10,193,251,22,246,62,242,29,240,105,24,230,242,99,54,230,15,4,213,95,18,141,3,176,232,149,234,110,239,244,252,71,246,240,2,254,239,46,30,80,2,241,218,212,7,62,1,30,239,77,27,234,242,34,254,44,239,231,7,241,2,87,228,162,240,158,252,123,24,178,233,52,8,237,222,100,0,210,237,139,229,175,16,232,41,98,45,104,4,189,49,191,5,114,234,118,251,145,247,110,254,136,253,144,237,228,255,124,250,243,251,129,3,38,251,57,249,184,245,124,242,61,13,186,253,206,0,69,1,13,246,46,0,60,5,184,238,160,203,202,236,240,244,174,5,79,8,252,4,244,8,123,240,98,243,126,225,30,2,131,16,113,10,214,222,122,252,81,5,138,250,62,248,33,252,88,253,90,2,185,244,211,253,96,10,142,12,2,7,9,122,182,5,79,250,90,241,125,248,179,246,33,5,128,255,84,255,121,253,194,253,21,4,134,9,126,6,247,1,32,1,255,5,8,252,183,9,204,252,84,18,239,10,51,131,166,0,137,249,112,247,132,253,77,5,199,246,53,254,40,249,222,10,219,254,112,255,108,7,173,2,230,6,108,7,165,254,120,238,78,2,147,3,30,3,109,4,114,238,148,250,75,0,116,3,32,51,168,246,167,2,197,254,160,226,62,4,33,15,225,12,212,252,142,253,29,219,244,9,239,230,83,6,28,28,199,255,5,0,10,14,126,248,184,0,224,10,251,254,18,243,219,10,174,0,254,10,59,252,160,244,213,248,169,1,67,239,128,3,209,7,133,14,7,3,88,251,93,87,81,255,242,5,57,253,145,251,3,20,251,253,102,3,227,16,73,2,75,254,4,1,55,249,64,248,218,9,21,246,51,252,148,221,211,192,70,18,245,239,130,0,104,225,116,4,232,10,66,13,76,253,247,239,213,254,208,5,222,4,92,2,236,10,73,241,67,2,188,0,248,249,86,0,168,1,180,4,89,17,24,252,123,59,131,13,140,242,161,249,127,247,169,13,148,6,157,3,56], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+235537);
/* memory initializer */ allocate([11,191,240,97,22,135,2,145,3,10,253,221,253,54,2,251,6,24,3,27,250,151,249,98,252,21,250,140,255,242,4,225,1,152,240,110,111,25,247,201,21,2,4,242,15,163,253,184,2,70,4,34,254,100,22,79,28,181,5,241,5,22,255,214,255,146,252,14,1,214,253,118,14,185,255,82,5,39,30,49,1,170,202,135,236,208,251,4,248,195,26,182,1,13,223,155,3,231,253,231,5,21,252,8,8,5,247,38,195,247,1,152,7,116,12,14,9,225,6,10,5,238,246,200,253,201,249,70,245,82,248,200,217,234,5,36,234,230,15,75,255,66,244,145,248,16,255,137,251,137,1,6,250,202,252,8,2,221,3,192,249,210,242,178,3,166,2,86,0,91,248,155,7,164,4,100,1,207,2,198,244,59,247,190,181,35,2,107,35,183,1,176,246,79,3,21,243,140,255,166,251,67,254,79,242,57,252,28,251,16,19,113,2,198,5,102,244,29,247,57,5,166,1,30,15,142,248,247,251,188,6,236,253,198,6,243,3,168,170,35,254,5,255,153,253,2,3,96,29,6,4,236,238,66,254,172,243,246,246,172,0,133,3,70,0,45,7,181,4,192,250,117,11,56,4,246,250,73,5,221,39,134,4,127,43,48,2,104,242,184,246,115,29,214,234,244,200,90,8,3,255,128,219,141,248,129,8,175,2,212,10,86,245,222,253,172,239,229,7,191,253,226,9,18,241,88,228,203,3,35,8,60,251,203,0,115,12,121,14,16,253,225,245,64,253,195,187,112,251,42,255,214,9,52,1,183,253,93,4,155,248,184,9,64,7,233,255,114,9,150,244,168,7,235,0,163,249,171,223,64,4,240,7,106,3,203,10,181,248,60,0,148,6,66,3,140,245,38,6,230,243,178,12,117,241,130,255,59,0,237,252,150,10,162,3,104,5,219,1,181,240,118,251,104,6,78,190,52,9,186,255,249,2,55,16,246,252,11,2,73,255,174,75,129,239,157,250,125,249,102,249,0,254,38,34,222,255,232,14,90,253,189,10,114,9,171,254,64,251,184,16,96,247,248,254,188,244,71,18,203,252,32,7,188,229,8,250,246,208,76,217,167,3,242,16,140,255,100,2,6,0,95,255,143,7,64,6,70,254,219,15,206,9,138,8,2,226,16,14,100,246,208,251,134,255,231,248,10,255,226,10,119,35,13,2,30,255,68,10,11,246,179,5,181,17,87,4,254,187,177,17,15,246,56,243,147,1,58,245,172,248,174,10,88,8,229,231,249,247,139,4,252,244,176,11,162,11,178,5,36,6,204,9,8,53,247,249,13,58,228,252,212,230,182,15,250,238,239,253,111,13,186,245,103,246,214,11,100,244,114,254,215,1,243,9,103,4,64,5,202,0,164,1,190,248,179,253,82,2,198,5,214,21,146,6,232,249,134,254,106,247,144,1,183,8,54,2,176,255,6,248,51,238,251,246,39,34,94,239,11,5,250,45,206,2,38,9,96,11,50,20,166,9,176,26,65,3,126,19,217,7,22,251,126,252,122,250,190,4,158,2,200,247,52,236,20,3,203,181,25,253,160,252,156,254,56,6,102,233,140,2,88,19,241,246,183,251,129,8,138,249,63,11,147,249,84,255,211,249,10,244,219,252,215,251,82,247,121,81,134,251,96,3,154,6,254,248,87,3,51,1,16,9,34,14,40,24,223,239,187,0,137,246,82,19,0,244,43,255,195,245,22,248,95,233,38,252,195,249,77,8,194,5,230,6,104,1,212,237,250,251,10,6,195,251,3,255,248,3,160,255,184,249,151,228,9,237,15,5,241,254,167,14,85,1,92,77,42,248,18,9,6,247,97,1,227,247,4,253,212,0,150,0,140,251,52,2,154,253,12,1,25,248,180,254,69,253,87,252,148,6,175,249,177,166,178,4,112,255,62,0,117,1,170,253,184,0,219,3,137,14,157,253,86,0,92,14,106,1,116,253,42,255,201,254,74,253,75,248,47,9,35,253,191,249,91,251,67,110,102,255,10,0,165,254,72,13,53,5,97,249,251,252,82,5,65,254,73,244,142,253,16,249,170,9,147,8,239,251,227,252,36,7,62,0,69,13,13,249,148,244,204,6,98,249,243,15,252,58,31,15,115,225,148,255,36,1,230,3,69,12,181,22,106,252,246,250,122,252,127,3,200,250,206,255,222,7,238,247,79,9,68,0,25,124,178,254,219,4,189,7,53,253,125,0,132,254,8,251,44,4,155,254,58,249,142,251,138,253,18,4,176,2,74,254,210,253,100,246,178,244,100,16,20,252,127,247,13,247,163,237,90,201,235,2,74,234,62,245,158,7,36,245,222,32,250,250,78,252,220,0,53,246,64,255,142,14,175,250,16,5,89,247,104,3,78,32,19,245,180,229,232,4,91,248,156,244,107,0,1,198,76,7,30,18,12,5,18,252,165,20,131,11,92,236,174,3,153,0,164,1,128,251,121,254,28,14,13,18,172,0,250,2,148,252,23,242,186,199,216,253,246,245,160,238,168,194,218,252,96,252,52,13,82,253,212,245,201,240,54,253,142,253,29,249,120,4,229,1,34,0,126,248,248,5,43,255,186,19,220,252,185,0,96,0,248,12,147,253,183,254,92,250,96,3,108,249,199,64,80,7,255,12,98,8,108,4,232,223,73,0,124,25,87,6,205,239,135,236,170,5,122,253,235,227,172,17,196,249,72,8,73,15,168,2,46,8,124,6,240,2,59,251,110,9,146,15,182,215,48,8,129,0,174,234,122,2,206,234,174,253,253,217,35,8,20,247,35,236,87,237,213,250,52,249,13,24,183,252,130,255,247,0,117,251,163,228,23,15,4,253,240,249,76,5,36,42,23,253,63,207,183,255,114,20,108,243,163,11,123,2,44,13,228,253,220,255,71,11,101,20,163,3,68,249,40,237,12,3,207,255,120,0,29,253,122,3,202,2,98,250,54,254,187,248,164,190,190,248,30,204,134,8,116,229,21,243,44,2,104,244,30,2,202,246,183,5,48,242,74,7,17,11,167,250,216,249,247,244,233,13,167,249,66,7,228,251,201,251,22,5,255,247,108,74,92,251,215,239,56,6,159,237,58,4,112,251,51,9,137,2,148,248,234,245,232,3,7,244,161,246,41,14,38,4,92,3,26,10,171,245,163,57,75,12,138,19,192,229,192,6,190,247,226,19,234,244,204,11,72,236,86,16,189,8,194,2,175,236,170,255,140,248,73,251,135,0,163,2,56,255,138,169,212,5,186,9,212,250,145,251,182,252,177,5,185,0,62,5,188,13,142,252,45,4,135,4,204,255,52,7,94,251,42,2,20,15,32,7,168,247,143,252,255,250,53,204,63,253,166,255,102,8,61,2,227,10,44,4,80,248,121,0,37,3,30,17,247,251,252,219,24,253,90,250,12,28,1,1,161,232,149,249,202,231,62,7,60,242,36,4,138,255,56,0,181,252,16,11,158,255,91,242,112,1,6,0,171,248,225,241,94,248,51,70,194,3,252,5,38,249,192,14,149,2,23,248,196,255,11,252,58,251,10,244,187,255,187,236,248,11,104,251,213,0,221,1,57,4,143,6,232,246,192,7,1,171,143,252,202,255,179,251,188,251,86,2,112,6,200,242,43,255,123,1,218,250,76,248,118,2,232,253,78,248,51,254,156,254,112,168,193,248,143,255,108,3,7,245,181,253,237,246,200,255,129,8,227,252,113,6,27,240,70,5,229,247,101,0,152,250,167,6,61,4,215,1,157,31,252,3,240,239,202,3,98,3,80,250,171,254,138,5,118,205,123,1,59,38,22,7,33,9,87,249,185,38,2,4,170,7,24,253,172,244,102,249,254,5,65,252,139,253,26,9,151,14,134,18,189,243,169,247,250,8,51,245,147,250,206,241,3,106,159,2,160,8,238,1,247,3,83,251,17,255,191,254,135,251,89,253,131,253,212,243,32,2,72,252,114,3,140,1,63,4,165,243,132,245,247,2,43,253,118,247,226,253,241,9,85,14,24,0,153,6,233,40,44,7,93,254,66,1,171,9,116,7,190,250,50,0,255,230,196,241,40,2,44,9,47,5,77,46,163,9,117,21,8,6,208,1,4,7,15,245,25,32,246,3,201,247,180,14,155,31,170,0,122,207,172,6,122,246,175,248,178,7,112,8,93,236,121,253,138,255,14,11,75,9,189,251,165,233,124,0,201,11,161,1,55,0,96,5,201,251,210,27,14,12,183,69,164,9,201,12,169,253,230,12,102,252,231,247,96,249,37,3,230,7,149,248,116,12,145,5,244,238,116,255,80,241,181,1,113,5,238,250,14,67,253,250,168,244,76,253,6,2,108,254,176,3,58,248,56,252,43,5,72,9,68,210,139,8,92,12,209,253,164,8,62,6,51,249,104,1,121,2,3,12,108,253,12,252,10,3,53,2,28,248,133,255,5,0,87,247,105,244,118,1,16,1,80,1,67,249,104,254,34,247,171,245,236,251,251,253,119,7,126,254,169,238,77,226,24,252,236,29,77,2,83,58,85,11,222,46,210,204,129,248,64,15,86,0,81,6,156,28,6,12,178,6,28,18,56,246,62,255,54,243,58,253,33,0,83,248,6,247,209,9,214,2,75,0,67,0,116,3,56,8,14,16,144,7,147,40,162,10,78,248,48,207,191,18,14,12,134,244,183,6,166,247,174,254,156,251,203,3,152,239,224,1,223,242,76,24,66,23,38,7,233,3,180,11,70,16,218,244,75,254,106,250,48,4,200,254,107,205,41,12,81,246,14,248,44,27,245,10,80,8,88,3,157,221,155,237,6,251,136,255,228,4,58,15,126,25,182,240,28,247,194,10,212,245,34,244,40,16,38,10,132,247,253,18,103,246,2,0,123,245,216,252,199,13,96,251,136,1,102,247,102,9,192,3,216,251,227,245,137,4,114,9,216,2,46,254,255,236,211,0,128,57,211,247,71,248,85,0,182,206,231,247,44,244,213,251,198,6,69,246,34,37,90,254,98,245,106,244,43,15,220,244,80,1,26,5,7,247,217,7,29,10,255,11,192,0,41,251,199,214,2,0,106,251,36,244,211,38,229,255,2,251,168,5,223,72,249,2,163,3,189,1,162,255,206,0,192,1,183,248,232,0,255,238,244,17,252,254,48,252,82,2,136,2,28,3,160,250,94,251,240,11,99,12,213,233,35,24,249,250,38,66,58,250,66,4,65,2,139,31,95,4,127,11,120,243,60,7,194,7,115,23,133,3,62,252,132,243,141,248,136,1,211,245,236,10,242,15,56,254,219,243,61,251,123,0,166,9,174,0,26,251,186,250,201,236,247,4,14,48,126,251,83,231,238,242,221,250,112,255,190,4,207,255,163,13,251,251,5,248,75,223,101,16,107,19,80,38,4,38,188,2,199,8,61,245,14,248,188,12,71,3,198,214,125,6,220,44,148,243,139,248,65,4,211,252,44,12,201,247,114,241,94,238,151,2,128,4,62,15,254,18,179,10,12,241,195,2,152,10,183,224,192,252,148,191,64,250,138,246,39,234,66,1,154,248,250,10,109,0,4,249,2,8,211,13,216,243,222,231,183,9,54,8,121,255,91,12,48,8,27,16,202,254,190,251,254,255,154,245,65,189,93,5,168,5,162,0,15,2,143,2,56,247,54,242,194,0,25,5,166,29,117,234,201,4,71,6,24,241,137,8,137,245,122,238,186,253,117,19,117,249,147,0,198,57,119,0,251,45,52,251,244,3,11,232,57,247,183,240,68,5,202,248,255,253,14,231,19,253,70,26,233,2,215,252,225,252,152,12,43,0,74,247,38,10,178,11,202,249,66,212,116,199,0,255,183,2,109,3,160,241,82,245,88,250,56,5,159,249,255,12,169,13,140,11,242,252,142,11,182,248,60,11,211,7,168,252,2,5,204,19,135,1,213,214,167,6,0,128,196,252,97,37,75,1,26,27,50,12,16,252,31,11,134,2,198,233,176,6,229,252,202,238,88,5,51,1,242,253,98,247,26,0,46,255,78,5,234,2,128,7,155,2,26,15,99,254,48,253,24,239,85,246,91,251,161,252,31,241,68,236,137,222,43,11,123,7,31,19,152,48,54,205,197,10,175,232,214,15,76,4,42,219,66,19,26,40,14,250,180,27,182,221,80,248,229,16,248,32,48,15,82,248,80,253,105,246,150,11,180,246,146,6,92,19,250,246,134,241,148,1,118,26,154,68,107,207,149,245,0,19,61,219,220,230,156,219,121,252,106,234,135,13,102,249,126,235,232,206,34,9,226,250,53,244,8,3,127,253,155,13,54,0,20,214,218,240,77,253,49,187,178,17,27,40,150,30,40,33,176,206,94,238,225,188,158,27,43,12,80,16,127,1,50,238,154,1,235,24,98,24,94,18,245,18,39,255,190,1,29,241,164,246,244,0,184,247,203,12,2,20,180,0,171,17,232,33,180,248,236,231,76,10,64,236,57,240,158,210,174,15,85,44,200,245,48,32,1,236,196,7,8,246,172,23,134,12,106,253,126,10,92,4,49,215,68,244,138,2,131,30,140,208,185,254,88,3,108,252,115,254,168,253,13,18,195,11,163,21,41,21,186,246,195,37,150,237,141,30,253,244,61,2,140,17,90,7,110,151,206,5,205,228,79,4,211,9,4,32,57,7,188,226,133,235,58,8,86,235,8,213,126,250,136,242,156,222,72,238,206,225,11,12,221,23,134,199,80,222,131,254,160,30,86,18,190,240,31,32,243,12,217,22,56,51,180,204,193,23,25,46,56,226,136,254,28,231,95,229,178,26,224,6,101,250,48,4,177,13,42,250,59,253,154,22,198,1,15,7,90,10,48,30,77,5,22,252,10,235,192,246,4,8,77,1,168,24,176,254,82,32,139,249,43,239,26,230,25,11,144,9,206,32,0,21,176,227,62,250,206,248,233,239,70,3,245,1,146,239,212,15,30,251,49,174,246,242,176,253,99,244,145,27,128,255,93,243,39,239,50,246,207,211,195,236,31,12,168,5,190,235,214,250,81,190,164,7,242,224,81,10,182,244,44,17,18,9,155,250,137,248,192,1,239,9,207,13,14,3,135,14,144,253,74,6,229,244,159,29,2,7,188,2,35,12,176,17,85,21,236,9,206,251,88,23,229,2,64,2,74,17,48,17,200,236,92,22,106,241,94,251,149,41,76,4,41,41,12,11,150,45,57,223,196,128,67,219,105,229,149,252,229,8,224,2,62,238,251,182,180,4,197,251,94,13,0,243,125,23,80,244,180,22,184,10,108,210,41,246,176,246,205,241,132,25,218,26,252,244,154,235,27,208,70,200,249,229,130,251,16,248,51,8,34,18,102,6,190,239,124,253,249,0,195,243,54,46,40,214,82,48,210,18,124,248,249,233,208,230,151,9,222,236,155,253,224,6,89,9,134,5,127,27,150,228,13,23,172,244,202,14,98,243,122,241,186,13,56,240,188,237,223,24,87,250,58,245,184,244,226,15,28,228,152,1,24,226,84,12,207,77,190,248,15,26,96,1,229,242,2,12,148,21,107,250,162,7,248,229,158,216,53,17,194,249,218,252,243,6,255,228,150,27,200,19,118,25,238,251,72,13,102,234,88,251,78,2,30,243,252,252,59,2,161,231,82,38,164,207,22,5,64,5,154,242,246,14,10,16,160,22,204,231,224,0,212,245,114,15,249,206,93,234,142,223,9,7,87,238,250,13,3,239,172,233,96,19,36,14,236,5,147,22,174,21,130,241,1,13,46,41,102,16,28,20,37,243,196,0,88,24,31,27,233,250,190,215,70,7,147,25,248,249,76,244,52,11,219,238,18,229,141,111,182,204,117,5,229,246,20,240,54,11,8,14,213,25,9,1,74,237,70,242,176,243,6,34,230,0,70,12,16,251,30,7,255,252,24,24,0,249,141,8,100,10,152,245,74,13,235,253,228,243,36,254,116,251,204,23,142,244,44,13,249,232,59,33,106,252,148,237,210,249,151,93,226,5,56,9,139,255,237,7,60,254,81,230,196,3,180,204,234,244,216,14,229,242,96,12,110,20,108,43,58,3,81,249,38,242,230,28,4,240,188,244,231,2,8,249,16,241,147,242,26,4,22,243,160,3,11,236,193,224,45,6,161,33,202,237,246,241,174,249,201,38,114,240,41,234,171,221,92,250,21,209,24,5,124,49,238,235,85,42,241,224,7,240,81,15,1,235,74,246,226,245,134,44,176,255,54,30,61,238,234,211,70,228,178,225,183,20,212,28,254,211,126,212,28,222,30,0,184,24,85,2,172,30,72,12,163,240,38,59,114,15,165,47,5,254,125,249,141,21,165,239,197,2,206,250,46,8,131,18,61,5,84,32,96,33,133,216,89,216,57,14,3,3,190,18,231,18,74,243,226,219,120,227,2,58,21,185,252,11,129,19,190,236,233,42,126,24,80,33,16,23,46,205,112,225,20,5,62,253,100,255,124,239,46,1,234,38,241,243,120,17,189,17,123,51,80,230,19,246,92,32,205,255,246,20,239,238,33,1,50,15,169,241,102,7,60,85,41,244,216,20,36,223,183,9,69,251,153,229,12,5,165,14,56,221,126,2,207,26,154,0,121,4,84,253,248,25,222,240,213,7,62,18,56,17,95,16,144,15,120,2,141,11,4,250,122,240,240,245,156,249,126,241,120,255,174,236,60,15,111,1,192,105,72,7,146,5,7,243,92,3,24,249,39,248,148,242,106,10,85,217,208,250,230,246,250,243,70,243,8,238,228,21,128,235,167,6,51,17,83,237,173,223,61,26,236,240,228,42,118,214,88,223,13,247,87,79,178,29,68,240,227,1,234,236,117,10,199,236,177,23,17,21,159,247,57,24,40,254,4,7,53,11,6,242,237,11,218,246,135,243,227,245,113,243,42,5,24,2,92,255,198,254,192,18,145,248,198,250,199,209,153,164,186,21,88,17,184,248,216,9,101,239,72,250,189,19,151,222,244,240,212,232,175,252,55,228,91,242,38,235,121,249,216,5,152,17,218,248,84,22,46,255,117,5,244,247,194,8,185,253,44,10,235,20,114,54,94,51,66,5,89,10,9,250,40,238,187,34,231,28,164,230,125,215,235,236,0,51,186,223,13,251,113,244,156,252,53,23,43,1,167,253,130,34,156,5,28,21,122,7,65,241,212,3,144,34,34,247,96,248,246,26,194,33,131,155,84,37,204,56,206,7,155,204,52,1,236,201,114,216,157,247,104,32,236,6,70,4,16,218,144,222,128,226,151,21,90,250,183,251,90,233,138,188,44,11,46,255,88,8,175,0,217,2,255,45,222,235,150,239,30,52,137,15,158,56,229,233,145,35,197,212,146,241,186,18,175,253,161,26,83,7,145,236,79,14,45,16,131,223,28,221,79,8,176,239,112,4,108,255,216,29,191,31,24,253,50,9,133,1,64,6,181,230,50,238,239,41,143,44,56,15,42,51,22,7,71,20,246,240,69,10,254,71,151,32,22,18,240,237,66,253,6,241,28,247,178,244,236,249,157,5,168,1,20,22,140,231,83,9,43,233,72,29,161,41,62,245,198,18,145,4,28,5,238,239,29,235,228,58,54,22,119,28,188,11,146,231,66,20,240,200,83,40,74,248,117,219,88,234,38,252,146,232,5,1,142,17,163,9,137,248,165,253,60,238,192,250,203,7,189,249,224,40,102,20,130,14,34,235,153,224,242,48,159,152,235,248,204,15,234,2,187,31,210,208,161,237,155,11,121,238,252,9,64,15,42,246,224,5,142,22,55,21,96,4,90,252,174,235,86,229,186,221,244,27,168,246,147,41,154,244,54,239,33,13,82,241,130,252,196,22,53,255,215,236,80,25,251,45,138,178,119,187,200,236,145,188,82,39,141,39,236,220,249,178,2,92,3,109,47,10,154,228,240,23,49,163,62,237,69,228,106,3,47,51,163,84,229,222,118,205,190,204,146,241,84,182,66,242,254,241,114,49,231,252,165,41,13,27,38,253,147,211,91,225,94,0,189,245,100,232,91,247,227,238,42,216,72,233,200,255,3,239,138,14,71,15,73,249,47,246,22,204,146,12,105,0,84,7,180,255,173,251,3,10,168,17,48,40,230,22,198,225,36,24,135,38,100,5,100,26,72,10,146,182,98,36,22,28,226,226,176,1,219,196,14,33,80,8,174,246,106,245,36,1,17,253,203,243,3,24,77,19,74,12,230,11,120,0,65,1,4,233,241,19,52,239,120,24,195,254,131,6,74,253,14,31,7,22,44,243,65,4,200,230,154,198,57,242,176,251,217,16,134,174,240,30,226,213,32,203,165,3,171,17,80,10,70,8,97,0,154,253,106,38,213,218,232,0,222,19,192,229,7,250,56,2,67,12,175,241,137,222,53,202,130,24,238,238,235,233,40,221,13,226,81,219,3,230,201,48,174,241,17,236,220,207,188,18,228,253,156,40,84,14,117,242,212,27,210,238,87,0,149,208,52,255,189,4,114,247,172,46,175,245,126,246,241,233,3,11,76,12,230,13,201,230,121,14,108,6,238,243,127,239,146,232,112,0,125,69,204,227,118,8,57,16,164,17,180,251,125,249,134,250,123,221,200,24,206,249,133,242,53,9,104,2,120,254,29,224,197,210,16,24,33,245,215,30,57,44,185,209,134,31,111,20,160,230,156,243,114,242,112,244,83,211,209,1,42,254,248,245,189,43,55,219,235,239,118,251,155,248,199,246,39,2,142,56,182,13,164,250,45,12,212,223,168,244,220,56,119,12,200,0,118,8,106,201,158,10,106,15,140,9,190,7,200,20,39,8,82,247,37,6,230,2,132,221,179,240,184,212,15,255,232,222,231,23,34,1,196,246,165,243,131,7,84,248,186,253,4,10,66,234,245,230,21,8,224,28,155,35,228,98,224,5,236,9,210,252,46,249,54,2,212,249,14,247,170,0,186,2,105,0,95,37,198,229,184,253,186,236,133,254,21,254,46,252,228,17,156,4,229,242,90,7,9,239,209,18,223,5,240,38,82,221,212,236,91,13,46,237,50,247,38,26,240,238,159,213,27,236,158,17,199,243,152,0,134,7,118,238,230,5,156,186,213,229,194,3,146,13,117,19,25,0,40,228,152,5,10,21,36,12,63,238,68,4,127,6,173,250,4,12,44,221,14,24,244,0,99,251,199,252,91,252,62,234,69,67,233,253,180,244,89,236,239,250,62,244,208,22,166,2,236,2,104,15,94,6,192,241,175,234,198,245,108,3,255,25,238,244,37,10,245,229,50,5,216,255,185,238,113,24,231,2,195,23,184,253,98,241,135,250,243,6,210,235,207,17,182,21,140,33,180,230,97,29,231,249,86,19,246,252,236,13,139,44,14,252,177,243,185,200,4,252,35,10,50,243,235,95,5,237,115,252,10,9,21,5,50,8,224,233,98,15,46,240,53,255,40,13,236,245,245,11,206,219,137,231,164,229,50,15,158,7,183,254,26,4,174,251,76,2,153,92,107,253,1,27,210,2,68,233,99,8,205,14,103,249,149,2,13,21,185,222,128,4,216,14,248,27,114,20,63,5,146,12,172,244,121,254,94,239,220,19,81,237,94,28,227,216,213,252,124,235,74,25,70,188,172,246,220,245,245,221,204,22,51,37,127,2,44,18,255,11,42,12,144,249,27,6,93,252,97,216,42,17,234,244,132,209,12,252,73,3,76,233,24,244,101,245,60,255,94,233,202,177,157,7,136,13,254,252,152,8,20,242,183,7,158,231,111,248,114,15,46,22,72,245,96,7,15,241,138,22,29,15,123,32,38,227,38,5,22,5,98,234,54,238,156,3,36,241,60,239,27,167,220,224,211,226,41,242,178,30,115,216,179,245,99,237,108,214,200,232,135,4,35,243,11,17,61,251,40,208,196,19,192,227,35,27,183,249,35,244,36,236,180,25,1,62,216,20,127,28,82,9,145,11,47,18,242,37,216,19,115,45,254,6,81,11,175,2,110,252,76,253,3,230,142,222,124,250,244,0,126,17,114,6,7,28,22,4,223,229,109,14,64,242,158,23,200,250,184,7,182,65,104,251,24,3,59,249,94,32,65,227,158,246,168,222,112,5,57,243,180,25,181,236,26,6,83,2,115,239,8,19,170,16,250,248,67,230,33,29,111,16,250,38,100,240,68,247,250,243,69,7,117,39,166,246,78,243,61,226,86,228,31,200,32,22,199,250,245,212,1,241,206,39,81,28,14,12,10,249,24,0,18,242,17,42,250,239,248,230,80,253,229,220,202,11,202,232,54,29,144,254,5,225,54,244,110,26,178,255,73,22,64,243,180,251,242,18,166,17,228,255,124,231,41,19,182,27,214,238,226,244,168,255,178,1,247,7,96,1,99,38,84,48,183,4,143,222,132,238,216,5,193,236,39,8,182,229,110,4,175,255,57,0,3,222,154,244,113,15,228,244,206,248,196,18,61,235,111,254,148,27,243,191,62,237,135,217,134,68,61,210,112,207,236,229,107,36,123,204,127,233,118,31,148,253,249,226,142,14,126,69,200,30,251,0,167,11,152,14,206,27,45,67,165,33,165,5,70,196,200,192,76,43,149,236,222,232,155,248,107,35,105,36,53,224,202,2,182,0,190,243,90,28,174,248,35,245,48,42,99,11,196,20,170,235,235,245,235,39,28,254,94,3,119,0,228,25,234,5,43,15,144,252,162,29,243,245,207,12,217,14,140,17,246,240,200,36,218,255,94,29,194,253,212,15,144,251,100,253,200,37,192,218,247,9,129,239,206,251,224,241,254,32,158,0,190,12,29,31,31,5,70,222,126,229,188,2,109,19,149,3,14,253,124,251,166,23,19,8,5,42,165,1,6,4,87,44,101,8,66,239,43,47,241,17,169,4,86,235,138,222,107,244,168,26,162,231,88,9,189,242,230,20,27,245,105,29,175,248,216,11,42,250,113,245,153,183,47,6,67,37,252,9,186,238,65,232,117,245,76,225,35,238,212,223,185,16,201,251,86,187,232,244,44,29,67,18,118,236,12,251,7,250,226,223,93,32,2,253,38,239,160,23,243,44,182,19,116,246,114,12,196,6,192,30,198,25,12,11,152,244,86,32,207,51,36,216,54,5,80,234,36,41,36,21,250,9,164,216,104,4,137,240,118,243,251,15,32,7,120,19,182,21,100,247,32,8,38,241,214,25,44,227,28,14,240,237,222,24,253,248,198,15,83,24,40,239,210,236,177,247,229,58,48,16,11,190,173,14,255,8,98,253,249,21,226,245,222,245,187,9,154,243,103,16,128,4,4,250,116,227,126,222,31,25,159,11,144,23,221,11,229,226,173,245,127,21,80,225,109,246,189,20,162,241,209,31,72,7,107,223,41,195,36,30,159,215,231,34,62,48,78,215,4,240,222,2,160,40,182,42,92,22,242,6,204,22,125,243,52,214,206,10,82,16,41,185,51,191,167,234,115,236,71,28,136,99,142,28,248,230,254,23,188,225,113,250,34,239,191,254,173,244,144,14,144,243,6,242,178,210,57,251,150,222,144,2,151,240,12,240,44,253,45,1,67,37,223,37,249,248,214,245,157,250,94,235,155,237,82,46,90,37,172,226,22,19,128,3,148,22,96,255,76,206,130,218,196,4,221,234,48,236,180,230,13,210,152,255,95,36,110,20,79,2,246,16,7,1,142,51,119,186,156,248,59,10,18,71,224,247,152,64,65,72,186,154,197,99,66,0,8,230,91,6,234,10,50,241,208,36,107,5,222,80,140,20,91,20,166,6,251,3,121,212,155,230,233,182,117,42,148,239,130,19,186,6,121,33,86,14,34,17,22,190,172,34,7,247,73,245,46,238,9,220,97,31,166,254,254,241,21,219,170,12,16,6,182,16,125,229,206,27,46,14,250,17,53,227,11,206,72,215,182,197,62,244,93,7,48,16,118,238,234,15,116,30,79,251,180,227,115,10,197,4,108,228,228,205,64,242,191,7,249,237,15,32,70,6,5,2,62,14,172,227,48,3,150,241,94,253,44,51,130,192,119,18,8,224,56,252,10,235,16,247,220,176,150,4,72,180,153,239,84,235,70,2,194,204,44,7,162,6,14,248,247,198,242,25,222,214,226,1,173,252,240,38,138,27,202,203,94,223,132,18,174,177,63,255,167,248,75,251,54,240,155,27,72,50,214,22,72,237,215,248,200,9,106,243,185,249,74,10,235,17,105,26,13,6,100,4,211,36,138,15,143,223,100,29,203,9,144,233,166,12,118,20,176,241,182,2,176,144,118,249,29,213,250,33,138,253,52,18,244,11,132,227,156,39,166,46,168,5,68,233,184,243,28,12,79,41,232,26,177,13,12,39,227,10,28,254,121,31,223,5,185,24,2,12,114,15,203,36,32,253,29,9,190,248,192,12,70,240,2,63,91,199,92,235,40,254,82,3,166,227,6,6,193,5,212,246,113,228,154,218,29,247,225,238,118,29,152,254,127,244,218,240,28,0,41,3,88,2,198,8,75,2,13,249,128,242,31,253,170,12,37,246,186,248,239,23,131,3,46,4,2,195,238,42,244,243,74,37,171,28,195,34,46,250,117,215,23,220,239,240,97,32,93,28,201,48,134,30,198,230,199,4,126,60,48,213,168,248,58,19,117,225,241,253,190,246,103,14,78,5,127,40,70,200,40,250,36,4,147,219,50,234,149,240,128,187,190,5,14,19,41,42,88,11,250,245,125,236,149,25,253,23,40,43,105,12,18,254,127,35,29,3,241,245,16,234,173,4,150,11,233,211,50,18,8,254,219,17,22,7,142,73,142,102,95,9,46,34,96,10,14,32,69,205,97,220,253,251,55,254,204,4,249,23,18,9,196,6,194,233,132,252,7,255,78,255,159,228,240,238,146,1,68,234,193,235,166,9,119,237,228,10,73,243,195,235,62,253,40,0,205,236,222,34,207,241,105,246,206,58,0,21,157,252,154,227,45,252,141,27,247,226,181,53,175,19,70,247,26,33,119,27,179,240,7,20,78,226,68,2,35,47,204,8,149,0,86,0,186,253,159,233,145,8,82,16,21,220,208,209,57,15,18,5,236,251,50,25,93,7,150,179,61,24,254,237,16,246,72,20,235,236,157,19,187,246,154,255,190,28,126,246,72,242,48,240,254,11,45,0,192,250,202,0,115,247,192,1,148,4,123,11,221,253,235,3,30,231,59,14,123,251,92,15,100,232,174,205,167,7,218,249,14,10,6,58,67,192,29,230,249,1,78,4,111,219,105,224,101,29,70,250,28,1,172,14,129,254,27,20,196,19,38,254,19,2,0,232,176,248,74,251,15,2,3,237,134,207,84,29,198,227,182,19,55,208,199,239,20,18,190,199,111,235,22,2,248,5,160,203,194,255,187,182,0,251,171,219,242,215,226,220,65,231,212,225,190,242,159,7,41,204,147,250,102,235,248,237,85,218,201,215,52,5,14,234,15,214,144,226,158,219,162,228,8,253,14,30,139,11,108,254,16,245,146,59,12,241,106,23,32,21,219,32,184,64,144,227,11,229,34,255,238,249,162,252,177,248,171,3,162,241,4,239,128,243,148,12,78,6,150,33,226,31,213,6,46,227,134,249,163,3,30,15,223,35,229,5,52,236,239,255,101,22,71,224,209,10,133,243,32,243,236,34,12,11,90,246,112,246,245,28,221,244,222,251,103,238,75,218,46,236,73,0,42,243,82,240,32,249,2,10,122,53,120,242,62,21,190,242,101,66,128,244,35,1,128,16,151,4,67,247,18,229,153,234,245,250,62,13,79,21,130,3,133,13,22,225,79,237,87,7,35,4,119,241,92,233,190,19,165,240,171,24,100,246,117,7,61,2,211,242,236,11,78,255,218,3,60,2,168,232,149,22,192,236,213,214,68,2,217,182,245,2,223,6,47,240,184,8,98,7,19,16,187,2,138,244,62,19,87,9,96,42,239,19,244,16,18,250,240,8,235,8,182,34,245,235,179,238,224,238,63,243,157,46,153,15,210,44,137,14,252,5,208,3,224,23,162,7,200,246,9,249,32,8,44,231,178,9,218,237,56,248,54,6,254,6,218,12,248,246,204,253,252,1,104,249,158,226,209,219,243,11,91,7,67,244,233,250,70,220,42,40,53,5,84,18,221,247,80,194,160,8,104,4,202,210,19,228,154,251,125,236,19,74,138,231,181,19,131,8,202,252,31,251,108,39,174,254,112,22,99,6,231,9,226,23,197,250,111,223,238,238,192,16,164,9,235,11,203,48,174,218,62,240,10,2,195,251,220,22,57,245,54,19,35,214,62,255,144,211,243,11,43,47,13,4,140,20,48,3,30,23,61,248,244,30,122,232,122,215,87,45,203,97,178,210,254,65,154,9,171,234,9,248,129,1,114,23,150,29,205,4,190,252,248,251,227,226,134,10,89,250,48,14,119,16,213,13,120,11,34,243,233,3,205,230,13,238,94,210,200,30,213,8,202,14,223,244,228,8,198,252,158,14,162,29,178,254,21,11,229,246,207,205,146,4,130,251,123,235,27,252,220,220,188,31,186,8,136,3,10,247,72,12,184,28,180,234,0,6,160,221,94,7,150,184,197,217,126,224,222,208,0,6,108,17,191,250,138,5,47,29,139,52,125,227,131,21,139,26,72,255,201,34,8,248,187,236,134,19,149,28,245,229,242,235,134,35,143,222,26,246,94,13,230,8,46,12,205,0,179,22,199,8,58,23,54,4,199,247,222,228,170,0,167,249,130,237,89,250,23,239,55,238,74,247,222,221,71,196,143,28,9,26,183,19,192,7,120,46,98,54,6,215,159,219,144,5,81,244,128,5,79,1,210,34,189,14,110,34,237,30,48,238,142,255,144,253,24,35,194,249,188,253,161,12,78,2,132,247,166,243,111,240,18,21,18,54,151,210,73,0,26,50,76,251,255,19,64,40,234,216,121,245,38,5,156,0,84,0,8,253,226,237,36,241,225,11,242,252,78,244,215,243,125,2,72,243,57,233,196,1,76,251,78,6,150,210,95,237,116,41,250,221,205,177,46,41,73,239,0,27,107,250,228,14,28,11,63,15,154,210,6,221,180,0,58,15,18,15,119,0,105,5,198,15,245,232,55,252,178,234,249,51,164,229,46,23,91,31,76,227,43,241,171,139,164,236,245,7,229,246,36,243,62,32,197,25,94,17,88,225,106,24,120,5,98,251,154,236,94,242,126,250,18,247,6,13,94,1,55,36,171,11,90,252,186,233,215,240,159,255,97,253,244,19,123,255,22,5,110,45,102,221,45,244,214,255,98,14,29,250,152,15,9,22,218,10,6,222,51,246,176,250,77,0,68,8,98,0,37,11,66,231,27,23,66,251,95,245,217,34,100,5,194,239,37,239,124,237,199,173,132,27,98,3,46,8,30,219,43,35,229,235,223,236,79,13,218,210,184,16,156,17,41,26,76,6,228,5,99,33,79,200,105,255,198,218,174,227,57,44,162,199,176,236,72,246,69,5,8,255,46,250,213,6,130,15,58,233,31,81,34,18,164,12,36,0,73,189,165,212,108,23,249,213,217,255,142,30,153,226,105,250,179,0,255,240,250,8,127,5,15,255,1,247,28,36,214,241,209,25,167,7,250,253,112,1,142,6,42,235,39,233,134,236,197,246,95,2,249,10,18,252,241,225,38,39,168,8,224,220,186,16,39,3,115,57,56,37,199,212,198,11,85,12,221,21,115,4,238,250,198,241,159,30,92,3,16,239,64,10,181,239,255,6,247,244,242,20,239,253,214,5,81,1,121,238,97,253,240,20,211,12,69,19,156,198,193,15,243,238,153,10,9,229,8,249,146,213,29,24,158,20,11,58,172,252,36,39,16,48,194,34,239,243,223,35,49,7,84,32,65,19,251,254,16,251,103,2,31,14,199,56,157,25,7,2,132,16,214,28,243,248,79,238,128,19,181,16,170,254,118,218,183,235,146,228,32,165,98,9,28,253,59,11,68,236,191,7,123,19,8,13,34,241,55,5,204,244,78,3,228,29,168,3,182,13,38,238,62,244,155,221,33,24,195,238,247,22,156,196,160,249,104,52,65,238,254,14,179,219,208,6,152,3,184,60,236,14,36,233,95,15,53,9,170,230,140,7,12,47,26,231,15,246,171,246,195,10,119,224,245,223,51,18,190,16,0,63,37,252,178,1,113,238,180,238,48,237,167,215,79,238,160,203,29,204,144,251,162,15,9,251,219,13,102,235,55,234,189,2,147,254,52,245,114,1,143,254,51,10,192,252,22,15,252,17,150,225,162,43,83,250,224,249,6,42,168,0,146,1,63,248,156,5,102,221,96,39,145,222,158,15,42,239,90,203,224,243,62,211,250,1,238,184,116,241,144,229,24,31,139,239,97,4,134,249,139,251,174,248,129,254,30,236,236,2,248,251,73,251,22,4,183,248,173,246,78,8,168,241,77,26,22,245,213,14,202,60,43,209,170,0,241,23,146,2,161,3,192,18,56,239,69,252,115,247,68,255,108,12,138,255,2,253,122,247,240,228,50,247,215,25,186,238,180,24,225,255,158,14,56,233,98,236,63,18,38,6,91,231,32,1,48,245,68,246,46,237,184,235,8,255,92,243,83,254,120,0,158,4,10,215,108,244,127,241,166,232,41,46,172,177,131,230,6,8,145,252,166,253,229,244,76,28,164,250,161,1,84,255,250,12,100,230,147,228,210,22,189,28,17,245,76,14,155,29,74,18,62,247,73,0,225,219,69,82,244,247,226,241,182,9,185,18,113,244,2,254,182,255,162,232,226,8,205,239,188,12,202,7,114,249,186,226,200,202,0,10,49,227,128,252,175,236,234,244,168,212,79,248,247,22,188,1,108,243,38,57,51,19,184,246,229,222,126,38,116,44,52,43,254,5,179,199,14,17,184,218,106,214,26,226,4,186,153,13,88,243,240,6,124,246,45,223,95,14,134,248,249,48,92,234,82,235,107,23,80,23,207,245,14,190,21,3,222,218,165,216,146,208,100,226,78,228,2,248,57,43,193,29,81,242,35,248,188,13,203,24,61,255,209,243,140,9,14,0,122,236,255,2,112,19,122,240,78,35,67,2,12,7,242,223,255,127,255,233,250,3,76,52,228,3,63,206,149,243,246,247,95,53,250,4,133,238,218,28,94,249,7,70,26,232,70,62,150,244,150,242,15,23,189,24,67,220,60,55,48,250,183,11,127,4,57,9,113,248,253,215,210,210,57,235,197,3,26,20,68,14,71,254,131,247,100,242,101,14,229,202,89,249,178,255,128,250,85,72,52,241,62,243,90,12,228,3,238,77,144,222,125,19,193,25,47,235,134,11,184,201,60,242,214,21,215,15,196,23,189,9,115,49,102,233,250,18,84,28,57,228,106,227,35,21,225,28,246,221,130,242,230,249,127,7,207,255,88,253,117,28,114,254,116,244,188,27,187,21,230,253,183,6,240,255,16,241,181,1,70,229,224,5,62,22,190,4,137,12,54,195,243,238,113,36,23,156,145,5,218,245,59,223,21,229,53,243,232,12,103,240,9,231,90,252,182,30,236,18,122,255,162,38,218,237,164,9,83,217,241,239,248,243,64,236,220,1,213,204,167,5,205,0,136,246,186,27,213,208,218,237,99,202,175,32,162,244,243,222,107,5,225,13,12,216,45,245,90,18,173,230,202,47,106,224,1,13,70,9,196,1,243,248,219,19,222,7,164,0,231,27,81,0,174,23,22,11,198,20,138,236,160,5,222,7,55,243,254,229,226,252,124,243,118,5,169,253,54,233,22,8,36,18,170,188,134,1,108,249,188,236,1,35,71,208,249,243,174,25,107,5,153,232,133,225,5,5,15,29,117,254,24,244,246,7,177,252,78,253,249,235,180,8,172,239,85,242,18,2,184,253,156,38,189,254,190,1,228,194,54,220,109,249,59,14,6,242,74,10,240,1,161,31,109,0,32,4,142,5,76,21,117,25,63,254,171,246,46,1,171,26,227,5,222,243,236,227,211,236,71,254,155,50,163,240,54,235,35,20,125,165,36,245,161,245,48,240,44,50,131,241,155,25,188,233,196,14,90,230,193,238,83,43,27,44,43,25,186,35,228,252,116,250,224,21,66,47,98,233,219,25,22,215,111,208,254,232,196,84,140,43,99,13,58,12,161,233,54,57,129,54,95,245,124,5,226,243,171,237,154,18,221,6,229,9,158,15,238,253,10,253,181,20,110,250,244,34,48,253,221,26,233,240,92,9,146,20,83,253,122,3,236,227,182,10,242,254,189,31,220,252,36,126,52,27,151,33,118,242,200,251,25,223,22,8,217,254,99,255,200,234,152,0,174,9,102,241,80,4,220,5,86,235,97,246,14,231,23,246,229,246,38,243,162,246,159,0,188,25,13,246,136,246,120,247,124,32,38,22,24,234,216,245,99,10,166,0,236,57,62,10,6,215,6,192,64,0,178,1,224,17,62,244,175,9,114,229,103,13,104,1,213,251,93,13,152,2,189,15,46,240,16,255,35,15,160,2,3,14,245,1,190,9,208,255,13,39,187,12,103,33,56,226,190,67,13,42,232,16,119,241,193,6,228,244,70,231,250,19,229,60,251,254,126,226,148,10,92,28,220,22,224,221,180,1,240,231,180,253,225,232,120,22,55,12,50,238,28,2,74,0,48,240,151,14,193,30,203,244,224,253,145,255,62,20,8,4,11,9,97,255,241,19,10,16,18,254,166,2,108,237,231,240,35,227,68,246,25,28,26,20,10,225,11,47,129,43,183,6,3,9,156,234,135,49,60,31,214,2,165,3,150,12,91,29,166,2,30,233,100,245,223,5,58,244,179,247,118,19,136,236,211,1,218,3,74,21,64,250,194,20,251,250,218,0,173,242,159,17,111,31,172,16,141,223,165,214,48,67,231,12,129,29,241,20,84,4,210,224,48,32,32,233,208,242,144,240,188,244,49,17,172,227,238,15,114,29,92,13,246,201,141,251,246,41,24,246,124,2,78,30,186,16,79,242,166,4,42,227,28,224,186,20,104,254,115,236,216,10,126,30,173,18,33,225,190,246,60,54,30,2,11,22,36,27,71,25,139,10,47,3,102,17,90,7,242,8,240,240,242,243,23,32,162,12,92,17,212,249,19,11,245,243,50,26,241,28,18,18,98,10,4,9,29,31,246,251,232,245,88,1,192,2,248,47,104,40,160,224,198,238,232,231,204,26,41,31,2,234,232,229,119,236,201,231,118,215,28,249,6,243,68,239,232,251,161,10,38,210,232,209,217,224,194,10,96,13,39,226,59,247,175,236,62,255,100,248,222,244,15,16,170,170,210,221,210,16,174,95,188,40,118,105,112,19,115,245,45,243,45,253,253,249,102,26,254,217,67,242,1,25,62,238,102,254,84,217,173,236,84,27,231,42,246,19,236,77,178,255,254,248,43,43,242,255,60,1,47,25,50,176,147,36,102,35,170,247,143,53,48,25,255,25,144,235,2,18,144,215,30,244,247,221,145,22,122,246,214,245,131,227,13,253,80,26,144,11,164,241,190,244,178,217,62,5,218,4,74,8,189,10,119,2,102,25,218,8,60,205,52,53,50,77,160,31,190,2,214,238,36,222,76,250,100,243,83,255,161,231,35,18,132,248,2,16,70,247,178,4,227,6,26,24,80,231,184,50,208,232,109,32,133,23,143,8,210,1,52,240,135,248,126,242,5,32,79,243,209,232,79,9,111,239,113,19,193,238,192,2,160,13,92,223,245,39,50,2,14,0,36,237,206,240,81,226,144,239,162,243,108,4,56,191,6,254,117,5,122,24,235,12,150,22,45,9,185,12,55,244,134,30,192,4,16,29,144,216,154,49,176,3,197,4,109,249,152,0,132,23,26,225,57,15,214,228,33,219,146,217,236,240,249,234,124,239,68,248,51,240,18,29,128,234,97,8,124,2,41,11,70,238,204,252,179,16,200,247,212,19,71,20,149,254,42,165,170,7,190,255,126,29,88,0,17,34,175,250,53,30,155,245,162,20,8,236,232,255,49,252,128,243,69,247,24,20,213,0,60,231,122,240,242,4,177,246,128,9,132,255,23,255,80,242,108,41,38,3,106,252,81,45,132,75,206,0,32,29,75,221,36,218,15,12,101,14,121,247,142,226,194,46,22,236,60,227,107,251,229,243,132,25,62,229,14,18,196,252,134,1,211,1,12,235,90,17,170,248,245,34,12,239,251,254,96,245,3,26,56,63,104,230,104,241,200,195,158,61,206,254,112,239,241,248,192,215,65,43,183,10,134,15,75,234,85,242,195,20,10,214,134,254,91,238,195,232,16,226,242,244,146,230,48,232,4,8,97,13,179,7,0,243,206,20,174,250,14,7,50,200,26,206,170,23,219,242,33,253,230,245,30,183,8,26,30,37,202,249,67,1,45,25,154,186,102,57,198,217,112,14,61,238,65,6,61,14,184,253,142,3,212,9,5,32,58,15,210,16,119,2,28,248,213,16,3,253,65,230,35,8,9,35,62,250,229,255,170,35,80,233,44,33,121,255,182,8,248,8,99,238,248,17,87,19,138,7,252,245,255,232,198,250,39,210,243,24,191,241,185,234,98,246,113,237,12,252,195,13,80,242,218,218,68,244,145,244,144,245,204,246,33,253,179,0,182,3,198,6,77,4,105,6,182,249,119,251,186,249,77,255,158,249,55,13,158,253,240,0,73,0,104,4,50,3,228,251,151,249,212,2,110,248,51,249,69,251,127,15,196,7,165,5,194,11,155,8,107,249,94,249,210,248,9,253,112,255,3,2,231,3,191,4,167,12,136,248,0,248,53,249,48,250,108,255,54,6,90,5,42,4,246,4,95,245,155,249,99,0,84,248,224,0,78,252,99,250,70,252,243,2,140,5,16,245,93,247,0,247,0,248,245,18,54,253,129,254,111,8,31,7,24,9,173,249,208,249,209,248,86,21,89,249,222,252,29,255,229,1,249,3,159,6,101,246,95,9,228,248,206,8,163], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+245777);
/* memory initializer */ allocate([250,1,253,53,0,193,2,50,4,13,5,210,249,74,246,96,247,219,246,40,247,172,247,214,249,237,251,66,1,5,30,106,247,24,249,198,247,16,0,97,247,41,250,174,251,63,252,30,254,106,6,129,26,252,249,252,249,87,250,103,251,170,252,205,254,85,3,255,4,169,5,181,12,109,250,10,9,63,250,39,252,255,251,191,254,155,3,116,4,142,4,112,245,104,10,116,246,99,245,225,1,11,12,87,250,201,4,96,12,85,9,180,247,67,248,194,250,109,248,144,248,128,18,139,252,198,252,26,15,254,7,222,254,201,253,62,248,168,248,174,7,47,254,102,6,171,2,237,3,75,4,230,244,23,246,1,246,133,246,37,251,199,15,91,5,57,15,225,9,96,9,230,245,208,250,17,3,95,249,197,6,78,9,70,254,190,0,133,3,1,5,147,245,150,8,34,250,132,250,33,10,74,253,70,255,210,1,41,4,175,4,143,248,147,250,27,24,231,248,255,253,35,252,156,254,246,0,83,6,91,7,36,0,126,247,190,249,96,2,13,250,23,0,241,4,66,2,185,3,14,4,29,254,26,247,166,247,52,249,72,2,244,0,202,255,64,255,147,3,73,4,43,255,223,249,69,7,135,250,102,14,167,249,46,251,154,253,92,3,31,5,139,250,11,9,104,7,184,249,210,250,49,250,157,255,193,8,185,2,132,4,175,6,205,247,29,250,121,255,142,5,73,253,199,255,110,5,55,3,169,3,134,255,223,1,47,0,160,247,22,250,187,3,219,250,42,253,224,1,129,4,113,244,2,246,243,245,181,250,169,248,90,250,35,25,165,2,52,12,62,12,58,7,42,7,140,250,119,250,10,5,128,252,207,253,148,5,239,3,81,4,203,247,4,248,243,6,135,248,180,248,130,5,148,3,208,4,88,4,55,5,153,245,152,255,255,253,160,255,42,254,224,1,236,5,106,255,42,1,202,2,2,246,4,12,212,1,23,253,79,252,69,254,175,252,35,252,85,1,78,4,177,1,76,2,20,249,206,1,241,253,158,2,128,255,148,255,71,2,189,2,23,247,155,247,162,246,67,245,3,246,101,249,185,251,56,5,128,35,4,15,249,248,187,248,140,248,62,247,120,247,9,9,195,14,215,252,7,2,181,8,134,248,119,249,228,6,134,253,93,248,71,249,149,1,13,254,243,0,96,6,183,246,121,28,133,249,40,249,195,250,76,252,189,254,73,3,167,6,238,6,19,248,80,9,171,248,130,248,63,249,203,5,227,1,124,7,64,2,234,4,250,246,252,248,160,8,213,249,57,0,57,249,119,251,57,20,138,6,164,9,141,248,37,250,76,7,227,8,148,253,156,254,28,255,233,1,40,4,81,3,85,253,76,251,31,249,93,247,162,253,4,253,224,251,48,15,253,0,238,5,5,246,229,247,119,0,225,249,203,3,102,251,123,10,196,5,210,3,139,5,125,244,142,246,140,247,154,4,46,6,190,5,128,3,133,2,135,6,182,5,70,247,173,250,96,251,128,5,18,4,189,251,48,255,207,255,15,2,149,3,242,4,92,250,130,247,113,246,4,247,60,249,4,12,255,21,248,0,147,8,83,246,68,249,126,246,83,246,36,246,220,248,27,9,77,3,143,5,231,6,167,246,102,248,167,252,50,254,88,1,17,0,128,252,87,9,124,3,114,3,196,252,232,254,16,253,144,251,229,249,240,251,198,4,107,251,227,6,155,4,88,250,154,7,233,248,204,249,154,249,254,250,230,12,132,0,253,1,128,5,56,245,222,246,113,248,73,5,5,250,206,251,132,4,14,12,94,5,131,6,254,8,169,249,151,248,57,248,18,254,43,10,14,253,12,2,241,4,24,5,246,11,177,250,171,250,195,7,202,250,108,252,110,255,216,255,123,2,9,4,188,6,223,251,49,0,121,251,250,252,106,0,29,4,103,255,134,0,179,2,137,255,54,251,76,1,149,254,59,255,187,255,123,255,61,2,190,0,216,0,68,247,218,254,8,5,194,247,255,249,19,252,105,251,56,0,131,16,87,6,120,246,154,248,169,249,183,246,239,8,60,251,30,250,177,0,57,22,33,11,215,244,138,247,14,246,126,8,146,246,217,246,47,2,4,252,42,18,186,13,197,244,29,5,3,246,26,246,69,247,147,248,23,6,60,17,253,8,156,8,103,244,30,248,161,246,238,244,129,246,36,5,62,250,245,4,229,9,157,13,180,244,173,246,100,245,243,246,17,248,56,248,225,250,135,31,93,15,223,14,165,247,117,7,104,247,216,246,244,247,154,249,126,251,46,255,221,10,91,8,95,4,220,248,235,247,254,246,73,248,115,251,68,254,21,3,105,9,15,6,143,244,153,255,128,248,38,248,120,252,182,2,68,255,4,0,27,4,166,4,167,245,106,246,99,247,141,249,192,248,240,249,115,251,96,1,23,13,242,4,73,249,57,0,220,248,92,254,86,252,29,251,51,254,14,5,134,4,125,3,112,245,101,246,211,246,1,250,247,10,109,1,40,4,124,3,62,3,198,4,114,247,250,249,19,247,43,25,185,249,174,250,163,253,125,2,115,3,109,3,182,246,244,8,34,12,223,251,240,6,186,251,165,252,249,0,199,0,0,1,255,249,50,8,154,251,195,8,94,251,63,255,45,255,211,0,246,1,52,1,41,13,125,12,9,251,166,250,157,254,89,254,231,253,212,1,19,255,157,255,97,250,44,249,119,247,76,248,179,250,210,252,42,254,47,3,26,5,246,24,191,7,111,251,43,249,227,255,168,250,41,23,253,249,124,252,64,2,189,2,172,6,184,249,132,251,194,13,202,252,136,255,51,254,98,255,213,255,39,0,17,246,168,34,189,250,212,249,222,0,24,254,94,255,39,1,126,1,35,1,135,43,57,251,10,251,137,250,120,254,205,253,12,254,164,253,224,253,121,255,5,249,223,250,46,250,141,250,180,251,2,251,206,252,28,24,0,3,61,6,145,253,87,253,152,251,217,249,89,28,103,253,3,252,73,254,164,3,191,2,40,250,136,247,103,248,82,250,216,252,19,251,158,254,107,3,50,26,164,7,19,249,33,250,0,250,118,251,150,250,163,248,185,249,194,254,184,255,249,255,116,248,187,250,6,24,196,248,167,254,238,255,175,255,223,0,83,1,169,1,106,1,169,249,104,250,75,248,238,251,163,250,150,30,38,0,140,255,232,3,165,1,185,246,240,248,216,248,234,251,29,8,187,3,40,6,69,2,56,3,27,248,210,249,134,250,116,250,69,0,221,13,255,253,192,0,6,1,227,1,57,246,77,16,245,255,4,250,131,252,26,1,187,0,64,1,176,0,3,1,252,246,38,9,175,246,157,247,240,252,137,254,157,1,65,3,121,3,17,5,135,5,195,251,15,252,35,250,34,251,238,250,17,6,104,5,76,1,150,2,178,8,161,246,40,249,167,252,107,7,131,0,245,1,209,0,217,0,90,1,198,16,237,248,98,249,200,251,16,253,249,254,28,255,249,0,116,2,203,3,204,9,249,251,55,11,226,251,42,0,54,255,30,253,86,255,17,255,222,254,65,245,181,246,181,246,49,248,88,250,132,254,58,6,255,4,119,5,97,6,184,246,209,248,87,5,149,6,100,1,130,255,206,255,143,0,31,0,33,0,58,1,160,0,105,253,81,253,25,0,132,1,245,254,68,255,68,255,127,255,202,245,39,4,213,248,227,254,245,9,205,0,226,255,114,1,63,1,41,1,169,255,96,247,116,251,185,252,126,3,246,254,102,254,119,1,239,4,156,3,210,245,235,246,194,248,0,7,151,1,72,1,146,255,63,2,66,4,203,3,43,246,209,249,75,5,156,248,22,254,53,255,78,3,212,2,85,2,11,3,142,249,255,250,242,250,37,2,110,255,220,253,131,11,228,255,9,1,83,1,0,250,200,246,182,246,166,247,156,250,166,254,39,6,219,10,175,12,153,6,172,254,4,249,209,248,103,0,31,0,85,3,115,253,87,12,109,1,154,0,148,1,189,252,52,253,221,255,213,16,101,255,66,251,100,251,18,253,246,253,15,253,94,1,132,249,189,249,121,251,186,253,23,254,43,4,55,10,211,6,37,249,209,246,246,246,83,250,154,3,130,13,99,3,183,1,237,1,188,4,208,249,137,249,20,5,247,6,105,6,162,5,48,3,253,250,80,250,119,250,134,19,131,7,56,255,194,251,220,251,8,252,206,251,63,251,251,250,35,251,121,2,134,1,93,250,181,251,5,254,225,11,87,1,93,255,23,253,101,253,29,9,160,247,100,246,57,247,241,247,56,249,26,253,162,1,52,12,176,13,227,0,33,253,31,3,210,250,236,255,225,253,108,7,237,0,97,253,223,253,65,249,121,0,42,249,116,14,27,254,215,253,179,255,44,255,174,3,62,0,111,6,80,253,30,250,107,250,149,253,185,252,172,0,137,12,12,254,141,254,112,249,128,250,158,251,205,253,43,14,141,255,254,1,22,2,191,255,199,0,32,3,176,19,119,2,24,253,156,253,1,252,181,251,217,250,16,250,76,250,160,251,238,254,60,251,93,1,56,7,148,253,125,250,152,253,235,6,0,4,57,251,109,247,215,246,160,247,19,250,225,251,127,254,45,2,202,5,141,26,30,247,50,3,52,254,61,253,238,254,134,2,142,2,219,2,12,1,91,1,231,17,247,250,84,250,87,251,208,251,87,253,78,255,125,255,148,255,35,2,15,250,243,252,238,250,239,0,26,254,67,254,125,13,30,255,90,0,141,2,43,251,112,2,84,18,30,254,226,252,225,252,2,253,123,253,134,252,109,252,164,14,115,252,12,252,85,0,195,3,119,1,156,255,14,252,11,251,28,250,58,8,86,251,72,10,83,2,198,252,35,255,101,254,176,251,171,250,230,251,192,247,161,252,151,7,41,253,201,251,35,253,78,0,198,7,107,1,185,3,45,5,203,1,133,252,36,13,102,254,150,254,221,253,30,252,165,250,22,251,238,47,213,255,124,249,180,248,44,248,171,247,185,248,99,248,243,248,248,250,152,249,199,14,122,250,190,253,7,254,48,254,98,255,252,0,71,0,76,0,22,0,236,255,184,255,243,255,237,255,161,255,242,255,2,0,23,0,251,255,9,5,118,2,35,1,61,253,230,252,167,252,53,253,134,255,39,2,219,0,202,246,143,248,139,250,21,1,60,2,87,1,21,3,14,2,93,6,223,3,44,252,222,0,228,2,175,4,19,0,176,4,160,252,45,254,112,253,118,255,52,3,43,248,100,252,154,0,195,0,137,1,11,1,73,255,0,4,100,0,219,4,152,252,63,253,243,252,90,254,135,254,114,252,131,253,89,0,33,11,44,0,160,214,192,252,99,254,100,2,18,2,123,1,241,2,162,5,66,244,166,252,203,251,14,209,60,255,253,252,138,251,140,253,134,244,73,254,5,243,20,0,225,48,98,246,10,251,199,255,31,223,78,253,22,3,20,1,45,9,171,254,148,249,230,0,128,247,54,255,123,198,170,0,189,6,214,11,171,2,25,255,129,2,14,255,76,243,110,0,96,250,70,11,69,250,125,251,59,56,41,1,52,0,240,0,98,15,152,38,125,226,66,251,23,13,129,0,11,251,88,255,157,2,197,53,247,250,47,254,33,39,136,253,184,254,236,254,223,255,31,0,195,73,108,255,125,255,13,2,133,6,240,8,53,255,100,3,108,253,248,0,103,254,165,255,39,1,42,220,52,250,161,3,8,11,73,4,123,243,143,255,152,10,248,249,15,2,139,5,61,252,124,254,179,2,105,190,172,255,72,0,38,241,155,254,97,6,178,196,62,0,120,232,26,253,236,234,118,17,58,255,1,0,148,5,101,249,27,73,122,5,21,246,137,254,249,222,123,252,109,255,54,243,143,36,235,254,19,221,202,2,18,11,108,11,74,231,139,3,133,255,247,40,28,254,92,237,109,3,112,38,7,254,118,226,45,1,159,2,116,0,141,254,156,14,103,1,129,1,231,235,116,252,156,0,167,37,198,14,40,218,138,239,79,252,251,225,78,1,137,8,194,250,132,1,51,249,22,1,25,255,112,252,137,3,241,251,86,2,1,8,150,2,58,255,106,87,166,0,116,0,93,249,79,1,68,223,255,4,0,6,107,58,230,4,190,0,41,246,160,253,108,1,207,253,116,22,102,251,101,252,111,12,197,255,56,54,30,246,241,0,204,253,193,254,170,226,247,255,132,255,134,176,49,1,231,255,112,254,222,0,209,189,24,254,34,3,107,249,251,12,202,231,232,3,121,252,178,252,125,254,206,1,79,3,14,2,40,39,228,7,42,8,165,218,136,5,169,0,106,208,84,254,148,40,101,3,44,4,153,8,239,251,148,243,152,0,122,253,4,0,177,15,211,251,51,1,163,20,205,11,162,202,19,254,9,0,30,2,152,0,199,245,226,240,254,253,185,52,156,4,165,253,231,4,92,9,250,28,198,34,99,212,190,245,169,233,228,6,90,3,81,4,196,5,28,249,177,7,209,3,54,249,96,252,140,201,164,5,195,239,68,3,45,208,143,254,0,255,191,194,200,20,206,235,3,254,97,1,211,249,81,250,197,3,204,2,209,0,141,252,195,254,87,248,168,35,251,223,125,8,126,246,154,251,226,15,1,4,233,190,155,228,109,255,81,6,23,253,123,243,216,5,30,7,81,251,73,244,117,0,107,2,222,177,24,255,142,0,135,12,49,2,220,254,157,249,11,4,37,0,152,10,13,255,179,223,49,1,215,245,239,1,180,56,63,3,4,1,202,255,121,16,163,2,160,249,98,19,25,3,42,4,133,0,168,254,116,207,95,0,20,24,238,250,188,248,38,14,45,254,157,252,102,251,45,43,118,0,220,255,171,228,5,253,147,62,16,0,155,9,50,1,204,252,145,251,79,3,59,253,160,3,92,255,219,254,152,233,31,2,228,210,13,21,36,248,44,1,28,255,237,251,243,19,210,253,163,4,116,255,22,205,221,249,228,2,153,236,80,254,111,231,14,249,121,13,175,254,193,206,88,1,50,241,194,249,238,254,166,254,42,250,148,255,69,1,65,251,51,3,148,1,200,253,226,254,140,172,135,60,7,247,94,2,117,0,10,0,63,255,52,252,220,254,195,253,125,251,247,250,255,251,216,1,130,4,75,3,187,0,74,2,89,80,251,255,20,255,99,251,188,251,188,2,123,3,165,253,167,253,144,84,63,254,63,255,177,251,214,254,36,8,5,255,193,1,122,250,16,67,121,254,104,0,167,234,145,1,135,34,13,3,205,6,201,0,143,254,210,1,70,48,132,253,79,252,88,15,163,253,219,187,156,19,247,250,209,3,198,231,247,6,5,254,180,255,11,1,225,255,85,245,232,249,55,251,68,5,168,43,133,6,242,2,135,6,58,240,151,0,141,254,115,28,243,0,107,5,126,0,239,3,12,5,241,255,184,2,26,1,193,245,41,4,254,251,191,0,136,253,124,255,99,205,224,255,95,249,90,254,16,255,72,5,12,40,43,4,104,32,36,251,247,255,211,254,58,244,7,255,140,254,235,41,23,2,99,8,1,221,90,1,104,254,119,223,143,248,208,255,16,224,222,10,156,1,145,5,78,252,20,253,71,4,166,250,126,35,157,255,113,255,68,0,224,253,8,1,238,1,135,254,13,0,150,253,237,0,193,0,221,13,61,1,88,255,20,228,47,9,12,255,72,204,229,242,238,246,235,253,82,37,250,26,124,0,74,253,123,252,54,245,207,0,109,252,40,246,113,255,96,33,90,253,28,245,126,50,23,3,16,5,253,18,66,250,121,3,91,14,38,3,34,1,118,212,166,1,1,36,225,255,72,6,140,0,99,15,9,229,236,254,64,253,49,9,168,254,242,251,26,255,79,255,158,2,151,253,127,255,167,252,217,223,126,2,101,254,4,255,163,194,62,251,210,0,32,1,30,2,21,2,129,220,3,215,144,253,151,4,99,2,26,255,234,2,175,5,178,253,62,3,220,6,72,194,55,3,203,251,20,3,47,4,212,1,138,249,148,2,215,3,31,218,236,250,150,2,5,8,231,254,149,50,133,1,109,252,197,0,50,249,21,238,210,6,195,2,89,6,61,35,156,8,247,2,23,5,84,254,36,255,41,0,133,234,48,193,63,255,187,1,187,1,178,255,121,3,207,253,253,21,207,251,107,27,222,0,125,6,166,4,84,4,94,0,248,21,44,241,151,1,62,253,134,255,232,2,107,1,112,6,112,213,83,2,185,3,85,0,245,254,195,0,83,3,21,67,132,253,243,0,139,3,237,7,68,253,95,1,215,5,99,255,193,253,112,210,228,4,149,32,152,253,124,14,61,22,250,255,39,249,48,4,95,3,201,252,74,239,245,208,238,2,85,2,73,12,38,0,52,224,64,12,34,1,7,0,76,43,148,252,50,7,175,0,130,13,204,1,79,6,178,45,197,252,16,0,62,207,172,1,155,1,65,10,184,250,142,0,17,2,229,0,208,255,59,252,111,255,176,253,143,2,243,1,79,86,125,86,37,0,173,248,189,2,45,0,212,2,87,4,95,6,6,1,4,255,124,220,205,20,152,1,131,253,156,253,135,2,244,4,66,3,2,254,91,2,199,0,48,3,80,217,61,37,212,249,109,10,32,7,212,247,67,253,241,254,65,29,46,0,33,243,180,252,208,254,30,255,252,254,76,253,251,255,241,253,37,0,207,255,250,249,187,255,193,251,39,80,111,1,1,0,159,13,231,9,10,236,130,2,199,4,174,247,178,244,216,6,174,249,4,38,159,249,248,26,137,0,142,2,154,254,99,1,235,255,235,254,188,255,68,255,132,0,18,2,116,1,197,254,22,211,221,0,47,3,176,9,138,250,133,255,97,1,42,12,7,209,68,251,169,251,148,3,52,25,168,248,75,7,51,1,190,255,65,7,138,0,44,252,240,243,82,255,215,255,119,254,112,253,79,3,208,61,133,254,102,1,160,2,123,254,152,3,103,173,119,254,94,1,194,253,237,3,221,247,26,0,79,0,53,255,225,224,26,243,83,233,4,3,210,254,56,8,40,251,142,53,160,26,234,8,131,241,24,250,175,255,88,247,67,244,188,1,229,252,239,2,115,8,15,81,12,3,30,2,32,254,112,2,87,254,1,3,170,9,241,232,143,1,68,41,144,255,69,0,127,250,93,7,35,9,67,0,148,253,196,0,128,246,158,23,119,249,112,25,41,3,224,30,252,253,182,16,223,0,103,1,128,64,200,4,32,254,7,254,33,253,10,254,175,253,43,238,122,7,122,0,237,253,162,5,208,1,69,0,36,1,154,1,187,253,120,178,35,4,132,0,112,5,29,23,193,2,230,225,192,9,49,250,233,252,163,46,185,0,247,254,148,246,118,2,164,224,154,5,75,40,251,249,84,241,157,246,130,248,26,4,121,31,234,0,234,52,164,255,132,247,97,253,111,45,103,0,116,0,85,255,4,238,245,254,166,253,15,0,198,1,203,26,153,247,253,221,128,249,61,0,214,9,55,252,135,3,185,4,101,250,219,52,78,2,236,0,203,252,86,2,162,4,246,225,134,0,19,252,255,184,108,255,7,2,132,3,183,3,150,1,0,242,47,0,223,36,138,5,227,252,231,242,65,253,250,248,36,251,35,1,32,245,20,57,237,7,95,255,16,4,222,239,248,11,185,6,174,244,13,1,39,13,99,5,23,56,78,253,113,253,218,7,185,236,87,253,210,245,131,45,236,2,101,0,25,53,117,2,28,0,228,253,170,252,125,5,46,2,175,221,8,252,13,205,121,0,212,253,95,19,158,6,48,253,118,255,199,240,182,0,146,7,76,3,151,3,85,253,10,47,179,251,101,255,161,250,27,250,11,0,220,0,53,3,217,84,145,254,134,253,68,250,82,255,234,3,77,251,62,1,152,45,190,247,168,9,91,249,44,23,107,253,70,4,196,9,23,234,254,0,181,1,113,252,181,249,187,224,217,0,141,251,41,5,39,214,121,247,139,4,134,252,146,253,20,50,253,3,246,202,16,4,144,12,80,2,174,2,225,2,191,244,99,249,155,15,57,254,58,18,228,239,156,219,13,8,149,41,15,1,8,1,83,229,129,2,13,8,229,229,0,254,21,253,85,220,141,9,87,1,40,217,184,244,95,2,153,213,103,3,162,1,248,1,168,3,55,4,17,1,144,1,168,186,121,254,249,249,207,231,202,5,225,2,48,8,42,252,167,0,204,3,80,1,39,4,8,251,190,249,141,248,9,0,65,255,153,196,137,255,207,15,199,5,131,250,14,2,226,183,141,253,52,248,2,252,248,249,56,1,36,31,29,255,29,3,172,235,144,247,135,1,89,254,1,1,252,14,186,1,117,248,22,0,143,0,53,255,106,1,183,255,63,61,223,254,91,250,65,2,90,3,144,44,78,248,2,252,14,6,114,3,141,241,119,245,138,15,88,2,86,0,18,15,235,33,255,225,8,237,211,15,215,250,181,253,46,0,13,254,158,254,113,253,155,194,67,0,234,1,146,245,218,1,162,250,225,21,60,0,49,187,216,252,87,0,111,1,67,2,33,4,252,3,118,254,157,4,67,255,162,213,251,2,75,10,26,1,49,243,158,252,103,196,63,254,112,0,39,195,227,0,13,1,140,54,7,251,233,5,49,250,195,0,63,1,223,9,226,254,5,233,16,235,65,252,231,10,249,242,79,252,63,248,121,252,102,211,77,33,157,2,218,23,153,0,111,251,82,251,215,253,125,27,16,2,115,239,205,2,42,255,32,7,124,39,193,3,117,35,107,7,167,40,49,255,227,255,99,1,118,229,111,0,197,202,81,5,7,242,35,1,182,17,161,8,213,249,109,0,11,2,200,1,238,42,31,0,64,254,129,1,201,5,2,0,162,59,30,3,127,22,92,3,216,191,221,250,95,6,56,254,47,252,76,255,223,245,167,4,71,23,224,255,176,31,6,254,170,225,177,248,50,196,150,2,196,0,79,176,157,3,190,1,13,248,148,253,82,253,7,255,43,246,167,1,191,2,121,2,60,3,74,255,219,255,106,254,107,255,53,3,17,169,140,2,10,2,247,228,225,61,2,188,197,62,91,177,47,63,66,62,88,63,72,80,108,63,63,87,131,63,114,249,143,63,250,237,179,63,177,191,212,63,43,135,230,63,242,65,239,63,111,129,4,64,4,86,22,64,180,200,38,64,230,63,48,64,235,115,57,64,238,90,2,62,16,122,118,62,165,44,195,62,208,179,25,63,208,213,70,63,110,52,112,63,5,52,145,63,143,228,170,63,127,251,194,63,31,244,220,63,48,42,249,63,45,33,11,64,53,94,22,64,108,9,33,64,127,217,45,64,143,228,58,64,242,210,77,62,250,126,170,62,29,201,229,62,6,129,37,63,68,250,77,63,141,40,125,63,99,238,146,63,111,240,165,63,86,14,189,63,138,142,212,63,204,127,240,63,90,100,7,64,108,9,21,64,11,70,33,64,71,114,45,64,146,92,58,64,215,52,239,61,9,249,96,62,130,226,167,62,224,45,240,62,247,117,32,63,193,57,83,63,137,210,134,63,60,189,162,63,72,80,188,63,185,141,214,63,108,9,241,63,45,33,7,64,8,172,20,64,155,230,33,64,209,34,47,64,248,83,59,64,59,223,15,62,73,46,159,62,128,72,255,62,220,104,48,63,200,7,93,63,96,118,135,63,5,52,161,63,206,170,183,63,5,197,207,63,130,226,231,63,180,200,254,63,78,98,12,64,72,80,24,64,202,50,36,64,200,7,49,64,221,181,60,64,32,99,46,62,182,132,156,62,0,111,225,62,143,194,5,63,112,206,24,63,178,157,79,63,202,84,137,63,233,38,169,63,168,53,197,63,16,122,222,63,60,78,249,63,131,192,10,64,77,243,22,64,179,234,35,64,254,212,48,64,88,57,60,64,176,3,231,61,185,141,134,62,222,147,231,62,162,69,38,63,60,78,81,63,35,74,123,63,75,89,150,63,238,124,175,63,57,69,199,63,251,58,224,63,197,143,249,63,245,74,9,64,22,106,21,64,86,125,34,64,231,29,47,64,35,74,59,64,217,61,57,62,94,75,168,62,125,63,5,63,90,245,57,63,95,7,110,63,222,147,143,63,25,4,166,63,169,164,190,63,185,252,215,63,221,181,236,63,184,175,3,64,171,62,15,64,134,56,26,64,147,169,38,64,247,228,49,64,240,22,60,64,55,26,128,62,206,25,241,62,105,111,48,63,88,168,85,63,26,192,107,63,242,210,133,63,11,181,158,63,181,21,187,63,245,185,210,63,150,67,235,63,61,10,3,64,63,87,15,64,35,219,29,64,133,235,41,64,82,73,49,64,145,237,56,64,244,253,212,61,178,157,111,62,241,244,202,62,170,241,18,63,39,194,70,63,86,125,126,63,154,153,153,63,19,97,179,63,113,27,205,63,52,17,230,63,29,56,255,63,160,137,12,64,17,54,24,64,66,62,36,64,36,185,48,64,150,178,60,64,239,201,67,62,187,184,173,62,115,215,242,62,224,156,33,63,141,40,77,63,4,231,124,63,119,190,151,63,156,51,178,63,172,173,200,63,152,76,221,63,54,171,246,63,188,116,7,64,5,197,19,64,76,166,34,64,206,170,47,64,84,82,59,64,203,161,197,61,41,92,79,62,68,250,173,62,238,124,255,62,170,130,49,63,23,72,112,63,221,36,150,63,110,52,176,63,188,5,202,63,86,159,227,63,223,79,253,63,233,183,11,64,238,124,23,64,255,178,35,64,4,231,48,64,4,231,60,64,208,179,89,62,127,251,186,62,182,243,13,63,80,141,55,63,237,13,94,63,39,49,136,63,14,190,160,63,22,251,179,63,58,146,203,63,178,157,231,63,145,237,252,63,203,161,9,64,174,182,22,64,20,174,35,64,124,242,44,64,20,208,56,64,181,21,59,62,68,105,175,62,163,146,250,62,194,23,38,63,168,198,75,63,147,24,116,63,222,147,143,63,125,208,163,63,222,113,186,63,49,153,210,63,148,246,230,63,208,68,0,64,193,57,15,64,170,130,29,64,93,220,42,64,229,97,57,64,23,72,80,62,184,175,195,62,226,233,5,63,14,45,50,63,31,133,107,63,15,11,133,63,79,175,148,63,23,72,176,63,118,79,198,63,242,210,221,63,3,120,251,63,38,228,7,64,109,86,21,64,118,79,34,64,87,91,45,64,166,155,60,64,61,10,215,61,170,241,82,62,45,178,189,62,126,140,25,63,93,109,85,63,183,98,135,63,85,193,160,63,183,98,183,63,64,19,209,63,18,131,232,63,79,30,254,63,212,43,13,64,210,0,26,64,54,60,37,64,205,204,48,64,253,135,60,64,60,78,17,62,123,131,207,62,250,126,42,63,33,31,100,63,27,47,133,63,54,205,147,63,169,19,160,63,184,64,178,63,46,144,200,63,121,88,224,63,77,21,252,63,70,37,13,64,189,227,24,64,85,193,36,64,231,140,48,64,174,182,58,64,154,8,27,62,215,163,144,62,237,158,220,62,97,195,19,63,100,59,63,63,149,101,120,63,174,182,146,63,222,113,170,63,218,27,196,63,75,234,220,63,66,207,246,63,55,26,8,64,223,224,19,64,220,104,32,64,147,58,45,64,156,51,58,64,251,92,45,62,83,150,161,62,236,192,249,62,35,219,41,63,215,18,82,63,102,247,116,63,109,197,142,63,29,56,167,63,44,101,193,63,136,244,219,63,191,125,245,63,98,161,6,64,230,174,17,64,23,217,30,64,62,121,44,64,162,69,58,64,5,163,18,62,95,41,139,62,163,35,217,62,59,112,14,63,110,163,49,63,125,174,102,63,230,63,148,63,206,136,178,63,231,29,207,63,11,181,230,63,132,158,253,63,209,34,11,64,58,35,22,64,28,235,34,64,65,241,47,64,151,144,59,64,213,231,106,62,120,122,197,62,160,26,15,63,118,79,62,63,8,61,107,63,120,11,140,63,111,18,163,63,108,9,185,63,18,20,207,63,189,82,230,63,234,4,252,63,136,133,10,64,92,143,22,64,201,118,34,64,146,203,47,64,39,49,60,64,104,179,42,62,73,46,159,62,104,34,236,62,81,107,26,63,205,204,60,63,56,248,98,63,131,192,138,63,18,20,167,63,5,197,191,63,199,41,218,63,157,17,245,63,24,38,7,64,44,212,18,64,38,228,31,64,109,86,45,64,222,113,58,64,16,88,57,62,147,24,164,62,105,111,240,62,123,131,31,63,15,156,67,63,77,243,126,63,203,16,159,63,32,210,183,63,19,97,203,63,46,144,224,63,45,67,244,63,242,176,4,64,140,185,15,64,231,140,28,64,167,121,43,64,42,58,58,64,32,99,238,61,82,39,192,62,63,87,27,63,169,19,64,63,174,71,129,63,220,70,155,63,231,140,176,63,152,221,195,63,215,163,208,63,143,194,229,63,250,237,243,63,49,153,6,64,18,131,24,64,156,196,36,64,62,121,44,64,131,47,56,64,211,222,32,62,82,39,224,62,127,106,44,63,134,201,84,63,102,247,100,63,63,87,123,63,248,194,148,63,56,103,180,63,227,54,210,63,171,62,231,63,157,128,246,63,97,195,11,64,87,236,27,64,131,47,40,64,89,23,47,64,137,65,56,64,187,39,15,62,240,133,137,62,99,127,217,62,246,151,29,63,213,120,73,63,176,114,128,63,236,192,153,63,29,56,175,63,122,165,196,63,196,177,222,63,99,238,250,63,146,92,10,64,115,104,21,64,237,158,32,64,206,136,46,64,136,244,59,64,38,228,67,62,213,231,170,62,155,85,255,62,129,4,37,63,222,2,73,63,30,22,130,63,11,36,152,63,63,53,174,63,232,217,196,63,68,139,220,63,252,169,241,63,77,132,5,64,170,241,18,64,9,138,31,64,175,148,45,64,0,145,58,64,90,245,185,61,161,103,51,62,198,109,148,62,16,88,9,63,125,174,70,63,174,71,129,63,236,47,155,63,207,247,179,63,15,11,205,63,43,135,230,63,113,27,253,63,39,49,12,64,38,228,23,64,185,252,35,64,37,6,49,64,76,55,61,64,34,142,53,62,202,195,162,62,246,40,252,62,233,183,47,63,7,95,88,63,251,92,125,63,217,206,151,63,64,164,175,63,141,151,198,63,188,5,226,63,50,119,253,63,64,164,11,64,2,43,23,64,44,212,34,64,102,102,46,64,12,2,59,64,184,175,3,62,233,183,111,62,118,224,188,62,131,81,9,63,162,180,55,63,41,92,111,63,198,220,141,63,159,171,165,63,206,170,191,63,238,90,218,63,54,205,243,63,248,83,7,64,177,191,20,64,118,79,34,64,255,178,47,64,162,180,59,64,85,193,104,62,1,77,196,62,201,118,14,63,126,29,56,63,103,213,87,63,247,6,127,63,0,145,150,63,116,181,173,63,62,232,201,63,148,246,222,63,29,201,245,63,8,61,7,64,125,174,18,64,226,88,31,64,197,32,44,64,131,192,58,64,143,194,53,62,209,145,156,62,44,212,218,62,85,48,26,63,101,170,80,63,44,101,137,63,206,25,169,63,69,71,194,63,57,214,213,63,7,95,232,63,22,251,251,63,57,214,9,64,129,38,22,64,51,196,33,64,90,245,45,64,217,95,58,64,103,68,41,62,100,93,220,62,115,215,34,63,94,75,72,63,181,21,107,63,29,201,133,63,65,130,154,63,131,47,180,63,210,111,207,63,42,58,234,63,209,145,0,64,154,119,12,64,195,245,24,64,233,72,38,64,156,51,50,64,128,183,60,64,227,199,24,62,175,148,133,62,129,149,195,62,127,106,12,63,186,107,57,63,0,145,110,63,184,175,147,63,171,207,173,63,161,103,195,63,39,160,217,63,12,147,241,63,157,128,6,64,236,81,20,64,22,106,33,64,168,87,46,64,187,39,59,64,170,96,84,62,83,150,193,62,180,89,5,63,174,216,47,63,58,146,91,63,205,204,124,63,206,170,151,63,159,171,173,63,66,207,190,63,84,227,221,63,19,242,241,63,103,213,7,64,103,213,19,64,167,121,31,64,124,242,44,64,147,24,56,64,95,41,11,62,66,207,102,62,66,62,168,62,28,235,226,62,2,154,40,63,120,122,101,63,102,102,142,63,43,24,173,63,71,3,200,63,222,2,225,63,95,7,254,63,39,49,12,64,11,181,22,64,3,120,35,64,15,11,49,64,125,208,59,64,152,110,18,62,245,219,151,62,59,223,239,62,134,56,38,63,47,221,84,63,38,228,131,63,127,106,156,63,230,63,180,63,106,188,204,63,102,247,228,63,113,27,253,63,231,29,11,64,181,21,23,64,91,177,35,64,7,95,48,64,39,49,60,64,171,62,23,62,204,238,137,62,206,170,207,62,142,6,16,63,111,129,52,63,251,92,93,63,233,72,134,63,174,216,159,63,132,158,189,63,136,133,218,63,184,30,245,63,63,87,7,64,118,113,19,64,238,235,32,64,68,250,45,64,143,228,58,64,86,14,45,62,35,74,155,62,250,126,234,62,95,41,43,63,136,133,90,63,26,192,131,63,236,47,155,63,165,44,179,63,190,48,201,63,158,94,225,63,190,159,250,63,207,247,7,64,176,3,19,64,16,122,30,64,104,34,44,64,153,187,58,64,64,164,223,61,233,72,142,62,62,121,248,62,197,32,48,63,125,174,102,63,202,50,140,63,193,57,163,63,67,28,187,63,63,198,212,63,95,152,236,63,138,176,1,64,214,197,13,64,116,181,25,64,16,88,37,64,43,24,49,64,241,99,60,64,245,74,25,62,227,54,186,62,90,245,25,63,132,158,77,63,132,13,127,63,238,124,151,63,130,226,175,63,53,239,200,63,86,125,222,63,56,103,244,63,68,139,4,64,14,79,15,64,243,31,26,64,41,237,37,64,67,173,49,64,200,7,61,64,115,215,18,62,73,46,127,62,40,15,203,62,16,233,23,63,18,165,77,63,220,104,136,63,239,201,163,63,153,187,182,63,55,137,201,63,45,67,228,63,235,226,246,63,22,251,7,64,218,172,22,64,5,163,34,64,21,29,45,64,227,199,56,64,157,17,37,62,171,207,149,62,85,48,234,62,216,129,35,63,129,149,83,63,211,77,130,63,116,36,151,63,255,33,173,63,29,56,199,63,247,117,224,63,246,151,245,63,249,160,7,64,82,39,20,64,213,9,32,64,71,114,45,64,34,253,58,64,12,147,169,61,109,197,62,62,203,161,165,62,174,71,1,63,154,153,57,63,95,152,124,63,88,202,154,63,222,113,178,63,68,139,204,63,148,135,229,63,34,142,253,63,33,31,12,64,64,19,25,64,124,242,36,64,137,65,48,64,162,180,59,64,4,231,76,62,209,34,187,62,139,108,7,63,228,20,45,63,191,125,77,63,128,72,127,63,131,192,154,63,201,118,182,63,84,227,205,63,246,40,228,63,191,125,253,63,39,194,10,64,243,31,22,64,123,20,34,64,115,215,46,64,186,218,58,64,172,28,26,62,159,171,141,62,7,206,217,62,127,251,26,63,181,55,72,63,75,234,116,63,46,144,144,63,139,108,167,63,146,203,191,63,222,2,217,63,192,236,238,63,221,181,4,64,102,102,18,64,54,205,31,64,196,66,45,64,169,164,58,64,174,182,34,62,253,135,212,62,165,44,19,63,254,67,42,63,146,92,78,63,25,4,134,63,28,124,161,63,100,59,175,63,217,206,191,63,65,241,227,63,143,194,253,63,208,213,6,64,61,155,17,64,1,222,34,64,181,166,45,64,15,156,55,64,200,152,187,61,200,7,61,62,19,242,193,62,188,5,34,63,73,157,96,63,41,203,136,63,90,245,161,63,124,97,186,63,104,34,212,63,175,37,236,63,163,146,2,64,244,108,14,64,44,101,25,64,170,130,37,64,106,222,49,64,232,217,60,64,67,173,105,62,216,240,212,62,180,89,21,63,73,157,48,63,151,144,79,63,218,27,132,63,168,198,163,63,134,90,195,63,227,199,216,63,56,103,236,63,155,230,5,64,79,175,16,64,186,73,24,64,41,237,33,64,57,69,47,64,244,253,60,64,249,15,41,62,7,206,153,62,76,55,233,62,178,46,30,63,117,2,74,63,180,89,117,63,197,143,145,63,25,115,175,63,61,44,204,63,47,221,228,63,85,193,248,63,66,96,9,64,190,48,21,64,182,132,32,64,30,167,44,64,115,104,57,64,56,248,2,62,93,254,195,62,74,12,34,63,157,17,85,63,89,23,119,63,61,10,143,63,230,174,157,63,216,240,172,63,213,120,193,63,78,209,209,63,186,73,228,63,168,87,250,63,232,217,12,64,252,169,29,64,88,57,44,64,161,248,57,64,143,83,244,61,119,190,95,62,116,70,180,62,43,246,7,63,118,224,60,63,182,132,108,63,221,36,142,63,119,45,169,63,52,162,196,63,27,13,224,63,145,15,250,63,173,105,10,64,180,200,22,64,8,61,35,64,165,78,48,64,204,127,60,64,53,239,56,62,233,183,175,62,247,6,255,62,106,222,49,63,138,142,100,63,224,190,134,63,222,147,159,63,244,253,180,63,9,249,208,63,143,194,229,63,2,43,255,63,2,154,12,64,16,122,22,64,100,93,36,64,227,165,47,64,112,95,59,64,200,7,61,62,155,85,159,62,177,225,233,62,66,207,22,63,177,80,59,63,186,107,89,63,120,156,130,63,177,225,153,63,215,52,175,63,86,14,205,63,223,224,235,63,68,139,4,64,164,112,17,64,193,57,31,64,48,42,45,64,190,159,58,64,88,57,180,61,128,183,128,62,204,127,8,63,199,41,58,63,93,254,99,63,202,84,145,63,124,242,168,63,171,62,191,63,145,237,204,63,102,136,219,63,123,131,239,63,126,29,4,64,203,161,17,64,102,102,34,64,70,37,45,64,4,231,56,64,77,132,13,62,179,12,145,62,86,125,238,62,46,144,48,63,181,55,104,63,48,42,137,63,107,154,159,63,200,7,181,63,227,165,203,63,187,184,229,63,6,129,253,63,79,30,10,64,251,92,21,64,66,96,33,64,54,171,46,64,77,243,58,64,245,74,217,61,143,228,178,62,161,248,33,63,90,100,91,63,126,140,121,63,2,43,135,63,58,146,147,63,154,153,169,63,168,53,205,63,131,192,234,63,1,77,252,63,161,103,7,64,57,69,19,64,56,248,34,64,255,178,51,64,60,189,62,64,175,37,36,62,87,91,145,62,182,132,220,62,135,22,25,63,186,73,76,63,113,27,133,63,147,58,153,63,113,27,173,63,233,38,201,63,143,83,228,63,190,48,249,63,83,150,9,64,122,54,23,64,35,74,35,64,143,228,46,64,21,140,58,64,141,40,45,62,36,151,159,62,34,142,245,62,18,131,48,63,9,138,95,63,101,25,130,63,89,134,152,63,25,115,175,63,75,234,196,63,131,47,220,63,158,94,241,63,1,77,4,64,179,234,15,64,44,101,29,64,25,115,43,64,76,55,57,64,203,161,197,61,233,72,46,62,19,97,163,62,37,117,18,63,41,92,79,63,181,21,131,63,228,20,157,63,116,181,181,63,139,253,205,63,45,33,231,63,228,131,254,63,108,9,13,64,184,30,25,64,233,38,37,64,204,127,48,64,65,241,59,64,20,174,71,62,61,44,180,62,148,246,6,63,65,130,50,63,9,138,95,63,149,101,136,63,154,8,155,63,218,172,178,63,233,72,206,63,218,27,228,63,96,229,248,63,85,48,10,64,93,109,21,64,167,232,32,64,178,157,47,64,52,128,59,64,150,33,14,62,28,235,130,62,170,241,210,62,120,156,18,63,45,67,60,63,232,106,107,63,166,155,140,63,109,231,163,63,47,110,187,63,227,165,211,63,131,192,234,63,145,126,3,64,181,166,17,64,70,148,30,64,94,75,44,64,124,97,58,64,218,172,58,62,159,205,170,62,100,204,253,62,109,86,45,63,122,54,91,63,236,192,129,63,93,109,157,63,103,68,177,63,190,48,201,63,58,35,226,63,159,171,245,63,133,124,8,64,98,16,20,64,23,183,33,64,181,166,45,64,83,150,57,64,193,202,161,61,147,169,66,62,179,12,209,62,11,70,37,63,30,167,88,63,227,165,131,63,207,102,157,63,77,132,181,63,208,213,206,63,231,29,231,63,249,160,255,63,159,60,12,64,34,108,24,64,63,198,36,64,147,58,49,64,227,199,60,64,46,144,160,59,237,13,62,60,188,116,147,59,36,151,127,59,111,18,131,186,130,226,71,188,158,239,167,188,137,210,94,187,66,96,101,188,75,89,134,187,154,119,156,60,38,228,3,189,23,183,81,57,95,41,75,188,100,93,220,188,202,84,193,59,142,6,112,61,186,218,10,61,155,85,31,189,147,169,2,189,0,111,1,188,158,239,167,188,79,175,20,189,232,217,172,188,93,109,197,60,70,182,115,61,55,26,64,61,103,213,231,60,224,45,144,60,226,233,149,188,187,184,141,188,23,183,209,185,82,73,29,59,104,145,109,60,245,185,90,61,229,97,161,60,244,253,212,187,172,139,219,187,62,232,89,60,5,163,18,61,195,100,42,188,9,27,30,189,234,149,50,188,36,151,255,187,174,71,225,60,139,108,103,61,132,158,205,60,124,242,48,187,159,171,173,187,77,21,140,60,224,45,16,60,131,192,74,61,176,3,103,60,36,151,127,59,162,69,54,189,86,125,46,189,153,187,150,188,66,96,229,188,125,174,182,188,36,151,127,59,77,21,140,188,181,55,120,189,9,249,160,189,197,32,48,189,137,210,94,61,70,182,115,61,111,18,3,61,82,73,157,186,124,242,48,60,80,141,151,60,208,68,216,59,231,29,39,61,101,25,98,61,215,52,239,187,168,87,202,188,166,155,68,189,250,237,235,188,7,95,152,60,159,171,173,60,195,100,170,186,157,17,37,61,216,240,116,61,223,79,141,61,134,90,83,61,33,31,244,188,151,255,144,188,211,188,227,60,39,160,137,60,159,171,45,188,132,158,205,60,9,27,30,61,222,147,7,61,195,100,170,187,62,232,89,60,32,99,238,60,0,111,129,188,39,194,6,189,189,82,22,189,67,28,235,60,54,60,61,61,224,45,144,188,46,144,160,59,20,63,198,60,137,210,94,187,27,47,93,60,4,231,12,60,33,31,116,188,93,109,197,60,59,112,78,61,240,133,201,60,64,164,223,188,116,36,23,189,124,242,48,188,16,233,55,189,0,0,128,189,12,147,41,189,215,52,239,188,177,225,105,189,88,57,52,189,224,45,16,188,46,144,32,60,250,237,107,58,23,183,209,185,52,128,55,58,73,157,0,189,195,100,170,188,101,25,98,188,28,235,226,188,224,45,144,187,171,207,85,61,37,6,1,61,27,47,221,188,28,235,226,188,23,183,209,188,85,193,40,188,193,168,164,188,67,28,235,188,138,142,228,188,43,24,149,188,202,84,65,61,181,21,123,61,236,81,56,61,48,42,41,61,149,101,8,61,198,220,53,61,125,174,182,60,130,226,199,59,0,111,1,61,74,123,3,61,168,53,77,61,127,106,60,61,205,204,204,60,90,245,185,60,18,131,192,60,156,51,34,60,80,141,151,60,150,33,14,189,77,21,140,189,44,212,154,188,20,63,198,60,227,165,155,188,64,164,223,188,82,73,157,186,242,65,207,188,142,6,240,60,54,60,189,188,161,103,179,188,111,18,131,186,218,172,122,60,23,183,81,60,185,252,135,188,14,45,50,189,159,205,42,189,20,63,70,188,5,197,15,189,119,190,31,189,72,80,252,59,211,188,227,188,115,104,17,189,153,187,22,60,59,112,206,187,111,18,3,58,124,242,176,60,91,211,60,61,100,93,92,61,199,186,56,61,33,31,244,60,244,253,84,188,237,13,190,59,85,193,168,60,238,235,64,61,241,99,76,61,66,96,229,60,4,231,12,60,52,128,55,186,220,215,1,189,61,44,212,60,224,45,144,60,4,231,140,59,159,171,173,60,101,25,98,60,159,171,45,60,88,57,180,60,10,215,35,187,10,215,163,59,130,226,71,60,231,29,167,187,4,231,12,188,202,84,65,189,111,18,3,186,9,27,158,60,23,183,81,59,240,133,201,60,198,220,181,60,188,116,19,60,111,18,3,189,188,5,146,189,25,115,87,189,254,101,119,188,88,57,52,189,221,181,132,189,164,223,62,189,153,187,22,188,127,106,60,60,134,90,83,188,159,171,173,59,4,231,12,189,45,178,29,189,46,144,32,61,180,89,117,61,12,147,41,61,2,43,135,60,46,144,32,188,111,18,3,189,171,207,213,188,88,57,180,187,211,188,99,188,88,57,52,188,39,160,9,60,4,231,140,60,240,133,73,189,136,244,91,189,111,18,3,189,250,237,107,187,135,22,217,60,45,178,29,61,23,183,209,59,66,96,229,188,127,106,188,188,172,139,91,60,93,109,197,60,159,171,45,60,228,131,30,61,49,8,44,60,137,210,222,59,244,253,212,60,145,237,252,62,118,113,251,62,208,68,248,62,180,200,246,62,135,167,247,62,190,193,247,62,34,253,246,62,116,181,245,62,217,95,246,62,161,214,244,62,70,37,245,62,5,52,241,62,124,242,240,62,187,39,239,62,58,146,235,62,195,100,234,62,171,62,151,62,190,48,89,62,146,92,62,62,204,127,72,62,7,240,22,62,173,105,222,61,168,87,10,62,3,120,11,62,153,42,24,62,186,107,9,62,254,212,248,61,23,183,17,62,84,82,39,62,120,156,34,62,246,151,29,62,36,40,62,62,160,197,154,197,183,255,139,251,252,5,193,253,148,253,208,252,161,4,195,249,165,245,146,5,78,250,37,5,216,250,237,255,47,255,160,254,93,255,144,3,171], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+256017);
/* memory initializer */ allocate([255,76,255,222,253,159,251,77,254,167,254,229,0,108,1,174,252,120,2,86,254,153,254,0,128,22,1,3,252,54,1,225,255,157,254,70,254,22,255,159,1,54,255,103,215,109,6,134,254,34,247,69,3,191,248,44,2,89,252,192,250,200,11,124,13,61,6,98,5,210,1,84,202,146,252,195,5,237,0,235,250,28,38,176,253,23,0,64,255,79,1,198,255,29,1,120,1,40,0,24,0,36,1,170,1,86,248,226,252,233,2,99,5,222,255,141,1,100,198,115,231,175,28,26,231,90,17,48,198,86,7,232,255,70,6,40,253,36,254,218,6,228,251,143,3,67,12,92,250,34,255,80,248,66,7,50,5,244,0,213,0,167,3,164,255,164,254,155,0,162,1,200,113,236,0,66,255,30,255,203,254,78,255,78,253,46,0,204,2,234,253,147,0,138,253,181,255,198,252,37,0,137,18,224,251,96,9,118,5,214,5,204,1,35,255,92,11,112,253,5,195,132,244,38,9,158,255,69,2,184,243,41,254,188,14,9,8,47,6,170,53,117,255,74,1,151,4,173,1,63,0,48,199,138,254,159,5,54,251,90,254,78,253,48,3,255,4,176,253,106,6,188,2,58,5,0,0,54,253,46,0,121,1,68,255,146,254,59,255,131,253,146,253,250,254,187,255,131,253,14,251,1,1,108,2,240,251,68,1,136,181,166,253,49,254,207,250,1,2,139,10,91,254,130,248,202,8,108,254,147,1,22,250,134,0,147,0,3,0,170,1,93,2,20,1,49,2,230,255,218,254,118,2,12,254,32,254,123,255,56,253,136,251,238,0,135,253,173,0,20,142,98,251,238,254,118,255,241,254,24,255,30,0,194,2,88,255,176,252,192,2,172,247,8,255,148,255,157,2,141,4,234,0,219,4,87,208,160,8,77,248,195,252,65,40,132,240,34,250,103,254,178,240,168,17,45,247,227,252,187,8,72,234,82,249,88,246,24,1,45,249,44,252,79,238,168,235,235,248,74,1,122,3,180,231,58,253,49,234,160,237,111,252,104,11,60,207,12,239,78,1,233,250,27,1,28,253,19,251,228,13,138,12,136,210,154,199,3,246,229,252,235,2,34,2,72,246,99,7,229,1,213,2,82,1,43,6,44,8,50,9,28,1,252,10,234,1,162,5,187,0,117,245,172,4,9,249,204,4,60,9,52,52,2,1,54,8,237,231,56,255,157,234,244,10,192,253,222,26,220,244,198,8,162,4,72,2,120,255,138,20,241,14,229,11,131,249,130,235,244,9,66,236,225,238,250,249,112,50,212,249,244,4,121,250,36,248,253,3,198,247,211,3,86,9,83,13,204,251,73,254,40,21,53,5,184,1,94,13,184,203,236,9,240,9,172,241,252,246,18,4,77,2,70,16,226,19,3,6,137,242,91,27,212,238,63,1,178,253,225,1,41,254,244,86,112,248,215,254,22,5,139,4,169,3,92,255,79,3,0,3,59,3,82,254,24,3,216,1,235,249,200,2,166,253,17,252,234,254,50,252,130,243,64,41,180,247,79,1,74,251,117,2,112,202,12,0,119,249,77,253,102,253,182,244,58,3,0,7,245,249,32,248,39,3,18,7,73,3,210,252,190,4,248,2,224,251,148,1,162,255,144,0,41,1,184,253,106,0,116,0,124,255,236,0,5,254,86,0,85,3,98,253,157,1,255,127,218,2,83,42,10,254,17,5,239,240,245,251,190,249,92,255,71,249,188,5,251,1,40,4,198,5,227,16,8,253,142,252,21,239,4,10,75,213,184,11,53,8,68,246,184,255,92,49,183,10,167,251,114,223,64,26,44,9,235,1,233,255,215,251,226,5,42,8,61,249,51,248,163,2,169,1,229,31,183,2,237,8,79,254,3,2,47,254,165,254,18,252,101,1,201,255,57,0,225,1,250,132,208,252,60,0,76,0,73,254,184,254,39,255,9,1,123,0,71,3,218,0,75,5,243,0,146,252,237,205,48,20,62,1,96,5,141,244,145,49,173,255,36,255,32,11,254,252,150,0,95,6,163,7,16,6,165,250,19,244,216,6,174,227,232,255,254,253,64,234,7,250,144,255,163,1,144,251,96,253,201,248,144,251,90,0,197,1,202,18,212,50,205,246,83,246,113,5,195,1,62,13,12,0,76,247,48,7,17,246,156,246,103,244,186,0,68,254,204,0,247,254,53,211,156,8,29,7,7,14,67,0,117,34,175,15,73,255,242,232,68,250,130,44,246,11,128,255,36,254,191,9,184,244,170,52,174,2,216,250,115,1,140,252,37,7,238,248,81,1,156,251,94,250,176,1,158,7,77,251,151,2,51,215,6,9,254,2,137,0,66,17,5,11,135,0,116,0,124,208,248,241,174,2,6,9,205,4,138,7,36,249,227,250,159,5,99,241,207,254,11,6,44,217,126,12,53,5,99,9,225,244,204,240,253,254,26,249,113,3,230,55,81,249,184,252,211,8,211,11,9,250,132,4,88,11,181,255,40,253,0,6,129,255,152,0,88,243,42,253,118,209,13,4,173,252,155,248,20,253,34,243,166,251,184,23,103,0,253,249,221,17,155,249,122,20,145,10,94,217,254,0,227,249,105,254,26,7,36,166,86,4,119,0,0,1,61,253,61,254,89,253,118,1,89,252,99,253,147,1,246,255,174,253,243,253,123,5,8,252,215,253,83,2,87,255,219,9,174,255,179,3,52,45,114,251,148,45,158,236,74,3,164,252,89,0,20,243,128,253,46,2,173,252,110,2,22,252,187,236,202,10,199,7,135,255,121,5,145,255,207,255,100,3,135,0,144,250,233,254,208,253,156,1,15,255,134,5,222,252,24,251,214,254,191,1,74,69,192,254,130,251,114,6,114,254,250,21,188,23,41,221,199,1,172,49,210,247,157,0,81,5,21,250,214,5,190,231,215,253,7,249,88,254,23,244,30,240,92,251,36,253,200,7,122,248,215,5,61,4,94,168,163,4,135,1,24,250,235,2,199,254,10,254,51,5,200,1,189,254,246,0,187,253,56,0,168,5,23,8,23,2,14,3,8,2,120,255,222,254,194,207,174,209,56,254,36,9,202,254,22,0,162,8,29,246,120,254,126,252,79,15,74,5,180,254,97,239,169,0,169,1,36,254,17,10,108,251,192,7,10,1,2,2,252,253,177,9,81,0,55,8,58,253,17,1,125,5,37,198,226,22,37,14,42,252,89,1,252,7,158,0,254,247,166,253,186,3,86,1,239,0,157,0,195,254,221,255,252,254,51,1,28,131,228,0,179,255,225,0,102,255,131,2,141,252,250,253,32,0,116,1,208,0,40,168,54,254,18,2,104,0,254,0,249,252,16,251,197,253,132,3,249,254,189,254,216,254,194,3,8,2,36,2,108,247,42,0,128,5,45,255,11,193,4,8,112,49,202,252,251,1,65,1,252,252,238,252,112,255,45,242,124,3,154,242,19,0,217,248,137,4,44,7,220,3,146,251,64,253,78,244,180,2,253,2,201,1,88,6,246,1,13,0,108,1,81,1,108,125,237,5,31,255,189,0,141,0,217,3,196,253,6,1,110,255,31,0,236,0,13,1,234,254,106,249,112,201,223,4,15,252,22,4,155,52,252,4,244,254,51,1,153,250,8,6,136,0,181,3,70,0,190,1,111,5,116,247,233,2,138,254,105,200,56,253,158,196,235,253,148,255,60,247,48,251,194,1,129,252,62,4,242,252,198,251,50,253,108,253,28,3,209,247,162,10,44,254,75,249,147,0,242,163,121,1,36,255,61,249,120,250,230,1,15,255,10,1,222,252,190,254,42,4,224,253,89,255,8,2,239,250,156,255,110,2,158,2,68,255,199,2,32,0,131,4,116,2,94,1,144,255,102,255,232,251,212,255,36,0,58,254,48,1,255,127,100,1,206,1,86,251,37,2,138,0,0,0,20,4,137,255,195,0,74,4,9,2,222,12,64,241,32,255,201,16,24,251,209,254,59,8,44,1,29,204,117,11,134,243,128,250,200,239,99,16,31,1,92,252,223,4,141,52,21,1,162,1,170,253,87,0,108,4,176,255,107,254,168,203,144,2,226,250,89,250,122,240,183,6,57,1,244,1,54,4,142,255,169,5,219,254,136,255,110,237,207,21,235,0,236,235,159,252,28,254,212,60,80,1,194,248,102,255,58,254,61,250,42,253,122,241,48,240,39,6,224,1,70,4,95,247,126,243,164,1,204,253,208,255,196,3,149,245,124,8,126,249,112,0,38,253,203,0,34,14,15,194,11,237,48,0,196,251,232,5,87,252,25,13,59,254,223,0,219,8,139,0,190,0,167,7,48,253,37,17,169,2,143,40,144,255,102,48,142,252,159,6,211,13,87,255,59,12,134,255,43,14,252,0,185,0,245,253,112,0,37,255,214,0,74,255,154,255,118,0,230,0,196,255,223,252,231,255,42,0,233,254,6,1,154,129,88,1,226,253,126,1,33,255,108,254,177,4,170,245,93,255,221,252,225,11,15,252,234,14,244,2,202,22,169,55,220,248,139,0,38,255,110,253,222,250,140,236,6,243,75,250,194,249,165,255,160,9,70,252,173,235,233,252,59,5,226,202,82,2,190,2,124,254,165,251,183,246,142,254,182,241,6,243,79,7,209,9,94,11,255,15,109,247,195,16,118,3,201,253,158,4,210,254,96,253,235,255,244,254,196,141,57,255,0,252,252,250,229,1,152,5,194,251,119,0,6,4,162,1,125,253,115,251,55,7,226,255,180,252,115,252,96,254,164,253,159,253,223,254,121,254,18,255,162,255,121,254,214,252,157,1,100,1,186,3,113,248,20,121,185,1,138,0,101,5,106,4,247,246,46,2,53,255,8,255,73,252,152,1,23,7,0,1,83,254,132,252,73,253,114,4,183,1,8,253,193,255,98,25,58,2,148,59,187,242,170,0,167,3,82,1,1,0,240,253,12,2,227,253,231,254,253,255,243,1,179,254,173,2,180,1,176,125,133,1,103,255,60,2,0,1,53,0,16,0,122,252,212,2,33,11,199,9,80,0,155,2,181,248,230,2,101,59,245,221,228,245,36,254,62,254,35,253,133,252,154,4,41,249,162,249,142,255,144,0,118,255,161,39,68,255,184,249,125,255,9,255,224,253,46,38,158,253,204,244,112,242,89,1,178,219,140,14,74,10,252,235,120,254,247,9,119,253,14,3,238,255,96,255,161,254,42,47,41,54,242,250,238,4,193,243,211,244,18,0,241,2,167,0,108,2,128,246,206,7,228,2,110,7,144,1,50,255,190,13,21,242,136,253,72,0,238,248,240,5,197,252,196,253,68,6,155,253,120,14,32,253,92,43,158,49,139,243,232,252,32,242,85,6,49,7,212,4,191,4,55,254,70,37,62,36,73,10,159,221,94,3,205,6,24,237,196,245,104,2,68,1,104,8,48,14,112,3,40,254,135,7,128,242,199,247,59,252,98,13,155,248,23,12,128,251,42,242,182,0,230,3,126,254,178,4,225,1,97,248,2,254,93,252,152,6,151,0,160,202,202,240,51,252,118,252,244,5,104,37,47,10,209,48,205,252,162,235,48,23,134,253,158,253,204,239,91,254,26,254,184,248,206,254,117,9,212,2,37,255,232,250,198,247,8,254,106,26,146,20,100,244,79,251,148,250,30,249,84,1,135,82,25,252,126,0,111,0,56,251,54,249,55,1,56,253,62,254,142,255,120,253,16,253,84,255,67,0,119,1,57,252,248,251,245,213,163,248,81,247,70,243,224,1,28,255,113,255,237,250,72,51,10,244,138,5,6,0,119,253,232,248,224,254,255,2,89,1,108,3,21,254,180,3,28,2,89,255,177,7,165,248,57,254,104,80,112,253,114,0,52,1,23,1,81,4,174,253,52,5,255,0,156,254,70,255,228,253,106,7,151,252,35,254,124,5,11,119,114,1,190,254,175,254,50,255,72,254,130,252,202,255,46,254,128,253,104,254,0,255,208,253,33,250,114,2,195,253,108,249,163,1,151,1,28,8,158,19,71,12,145,251,170,208,206,208,74,250,244,247,200,234,188,251,39,6,166,7,56,252,122,0,190,3,64,235,165,2,96,248,12,208,198,249,187,4,186,251,200,7,232,212,79,244,190,252,239,250,141,251,56,1,246,249,99,239,167,4,21,0,211,10,127,2,46,246,223,25,234,2,38,7,151,11,152,6,211,197,52,31,3,16,159,255,141,4,210,246,65,0,228,250,42,7,220,247,147,6,254,19,159,249,246,255,94,235,147,1,47,250,248,254,142,1,140,246,54,50,38,250,174,245,50,250,58,3,187,2,91,247,8,247,73,46,222,1,102,247,207,253,6,255,199,0,127,246,76,252,110,254,177,1,147,1,231,50,132,255,76,255,219,5,125,253,15,2,104,44,201,22,170,3,130,12,60,254,59,11,117,251,139,255,1,248,212,251,211,0,50,12,20,255,236,52,66,253,96,1,200,254,147,248,159,247,30,9,188,208,180,255,93,254,106,1,173,13,36,255,242,243,60,2,1,6,168,12,47,250,12,252,128,2,255,253,162,3,134,1,43,121,212,2,178,255,62,253,183,0,99,255,134,255,177,252,124,251,45,1,252,1,56,254,65,1,61,1,20,5,0,254,49,249,206,39,218,254,140,255,87,16,94,5,48,52,197,250,40,7,243,9,66,253,34,245,72,250,152,4,249,250,208,8,121,8,68,3,48,8,8,255,241,6,42,44,45,255,9,1,6,241,80,1,144,7,182,253,121,2,13,4,133,248,62,50,162,3,239,254,29,9,89,243,173,1,118,1,214,9,97,253,58,2,96,247,129,1,228,254,3,195,40,249,61,5,237,253,24,253,169,251,34,1,2,247,12,252,139,244,146,254,226,255,13,238,120,5,48,2,48,0,123,61,79,252,155,1,84,7,137,9,160,247,58,251,160,48,54,0,42,253,73,245,244,9,52,8,27,5,152,1,58,255,246,248,193,255,129,248,165,3,183,254,240,253,210,193,168,6,212,11,217,0,94,2,12,245,4,8,104,36,80,2,201,3,180,26,135,2,97,253,72,2,255,255,236,13,241,245,180,1,109,247,158,1,55,255,75,4,252,252,36,255,190,253,45,254,125,0,90,252,15,1,28,172,32,1,215,0,216,0,220,1,208,253,0,3,118,4,87,255,168,251,240,200,156,199,209,10,72,250,195,255,93,5,45,242,213,251,151,4,243,249,163,252,180,254,172,248,87,12,84,1,175,6,107,246,201,1,232,9,90,4,26,247,160,9,75,243,46,254,3,48,196,48,204,244,224,252,118,4,108,239,78,255,197,14,6,6,105,253,184,7,33,12,145,0,156,255,18,249,241,251,91,6,180,60,98,16,16,21,229,2,24,7,224,253,116,220,159,16,197,251,14,251,20,10,152,239,142,7,185,6,129,0,228,8,112,245,195,250,226,250,106,209,58,250,199,0,243,2,107,2,135,16,34,254,165,249,38,251,50,7,114,51,144,246,10,3,192,0,17,1,14,3,6,3,140,8,186,252,67,12,4,250,153,249,207,251,172,253,2,3,159,254,203,255,82,0,190,254,152,175,168,254,69,254,158,0,112,255,214,253,50,0,186,3,111,255,176,254,254,247,84,2,74,252,126,245,84,54,41,202,184,18,111,3,72,2,85,244,199,3,192,0,183,253,241,252,195,250,220,243,170,249,174,9,174,250,66,250,236,249,82,254,146,255,32,253,95,224,25,8,196,3,95,254,133,6,207,234,90,225,24,2,83,50,102,249,119,4,14,255,74,254,30,247,57,0,46,1,194,253,125,2,0,11,150,249,118,8,84,255,125,3,165,1,154,253,203,253,174,254,242,253,195,251,85,252,142,251,33,252,127,7,184,6,99,182,98,248,170,254,138,7,65,1,184,0,68,252,138,254,50,254,40,255,250,255,26,0,130,1,206,255,91,2,48,253,122,2,4,255,5,1,164,252,218,0,62,89,24,45,53,254,78,252,196,1,154,255,77,251,246,248,175,251,202,254,19,3,36,255,167,251,5,248,138,2,199,53,202,241,216,254,122,252,99,254,252,0,208,252,84,255,7,254,201,250,122,3,0,3,245,253,40,3,181,254,32,78,248,254,227,6,133,0,255,255,48,254,181,3,70,252,109,255,244,6,66,255,30,0,2,227,249,237,18,252,42,254,26,253,244,1,85,29,220,5,14,6,226,241,42,3,35,10,226,5,130,205,4,14,146,1,13,246,225,5,65,0,4,0,54,13,103,247,119,246,15,250,182,234,20,241,26,1,92,20,162,4,224,251,226,246,220,3,187,50,134,1,45,16,136,245,127,6,158,224,0,249,31,255,94,253,21,228,198,51,95,6,179,39,252,242,249,255,93,253,33,253,4,3,5,247,186,254,105,6,106,251,137,248,82,0,8,3,123,3,67,254,158,72,238,0,137,5,188,246,10,218,134,245,88,2,135,250,92,2,1,249,234,255,10,6,28,249,13,2,181,250,92,1,188,12,91,4,204,0,12,2,225,0,24,206,89,253,21,195,92,251,54,4,82,0,165,252,28,0,51,3,60,251,51,2,5,9,75,1,122,251,38,248,248,254,129,254,196,6,88,254,74,245,249,252,183,254,132,0,135,1,237,4,9,4,172,217,203,209,129,9,130,10,94,2,92,245,48,28,216,254,214,248,98,249,200,1,132,237,112,254,136,243,148,5,196,254,150,202,114,245,16,9,108,230,23,248,198,4,213,6,165,15,108,11,45,242,16,236,227,246,98,250,38,10,62,0,11,253,248,2,87,1,154,0,53,131,234,253,16,5,185,2,88,0,89,1,191,253,12,254,82,255,186,254,58,255,16,1,157,0,209,252,132,253,117,251,157,252,239,254,30,4,6,3,88,6,221,3,107,0,192,251,95,253,95,8,78,166,202,253,151,0,72,0,229,255,10,4,68,254,245,1,113,7,81,250,21,0,33,1,82,214,235,252,139,246,130,245,185,254,36,3,63,244,139,3,192,3,99,5,213,255,216,253,155,8,130,250,113,252,170,212,239,253,106,17,200,239,186,255,90,12,254,206,70,1,106,3,146,5,203,11,11,9,104,0,28,207,201,249,195,244,4,3,190,7,136,4,117,238,89,13,12,250,165,247,130,0,162,3,143,36,124,184,136,254,250,15,44,254,156,0,40,255,60,0,125,253,144,242,0,1,189,252,171,246,124,6,226,253,164,249,174,16,246,13,192,243,177,1,45,4,72,117,49,2,12,1,22,3,38,1,207,0,240,249,32,253,159,255,41,255,158,255,178,2,174,2,54,255,32,253,59,254,143,2,255,1,100,255,238,3,105,1,144,5,26,251,151,254,27,251,117,250,222,254,78,0,43,2,53,2,24,254,101,252,239,184,138,253,116,252,188,0,157,3,108,249,241,0,193,254,114,199,111,66,121,250,18,1,80,2,64,5,248,6,37,253,88,1,224,3,141,0,34,1,225,1,116,2,111,2,114,251,212,247,140,0,224,251,168,53,242,2,188,7,18,255,84,8,164,250,88,247,231,208,130,249,66,0,206,6,161,8,62,252,218,249,28,244,173,0,6,244,183,0,132,238,8,252,16,24,12,3,87,251,250,242,179,0,141,254,244,0,160,0,82,253,157,2,74,1,170,1,65,0,159,0,104,253,70,255,223,1,26,253,54,0,93,2,91,127,83,252,114,1,165,255,88,3,57,3,18,4,118,1,139,2,57,1,222,2,16,255,207,255,83,253,54,248,164,253,149,252,44,0,140,252,118,3,212,50,30,250,35,239,122,248,234,11,253,251,30,254,216,255,137,0,0,246,86,5,220,209,64,8,218,8,126,245,197,250,68,253,13,255,18,9,238,251,27,18,118,243,185,16,47,0,158,2,2,36,141,4,46,3,194,255,28,247,187,50,54,253,177,9,75,5,128,3,24,11,128,249,0,8,167,254,237,8,218,6,99,253,236,8,224,254,193,253,176,3,8,250,44,0,47,4,62,253,225,253,189,250,112,3,1,1,84,5,164,5,24,186,99,0,3,6,21,7,157,253,99,1,14,247,212,3,237,252,132,0,44,1,49,9,204,0,226,252,216,254,174,253,127,3,74,3,67,73,105,4,79,0,67,255,3,2,114,3,226,254,109,0,49,1,118,1,43,5,93,3,238,255,178,255,38,1,192,254,162,2,248,1,97,255,219,253,161,255,109,129,166,255,146,2,58,4,75,6,119,255,182,255,136,4,230,252,201,255,54,3,67,10,179,4,44,242,101,38,76,225,153,220,81,240,130,252,86,247,217,2,145,252,179,248,114,246,210,15,24,254,155,51,222,254,204,252,115,1,116,55,98,3,133,252,218,0,210,248,114,8,120,4,70,255,0,2,136,5,34,2,226,12,27,251,128,0,178,4,45,2,81,248,168,2,33,2,117,255,64,244,21,72,6,243,119,255,163,0,97,5,92,4,12,10,215,249,202,248,139,2,217,250,28,3,162,252,75,1,31,17,149,9,154,248,192,12,57,55,74,3,241,243,156,14,180,251,160,246,172,250,102,9,161,1,167,246,156,252,170,243,16,218,152,13,133,250,104,7,201,0,5,5,175,253,58,210,99,0,229,253,70,255,45,0,38,247,60,208,158,245,242,10,82,251,254,3,0,241,121,5,130,248,119,6,189,6,96,0,51,255,111,252,93,6,56,2,251,250,240,4,120,251,82,2,223,0,176,254,100,250,40,254,176,178,41,2,214,5,61,255,58,2,26,1,115,253,202,255,165,251,153,0,28,254,141,0,68,255,234,254,83,255,208,1,13,0,134,253,214,255,134,1,48,254,10,255,110,2,205,4,76,253,247,113,194,253,126,4,121,255,125,10,148,9,63,0,62,252,106,252,135,249,70,248,84,255,91,253,170,242,65,5,132,240,59,11,124,250,114,253,72,244,243,41,84,44,72,247,4,2,111,32,67,255,4,10,106,255,139,254,135,3,237,254,90,9,145,251,252,1,168,1,88,249,82,247,51,241,146,7,216,0,98,206,184,9,172,250,129,247,90,4,205,252,60,245,28,6,184,3,36,0,97,2,91,252,224,249,110,0,143,0,217,249,116,239,16,2,194,58,128,248,92,1,193,245,97,20,119,7,192,251,3,1,178,253,108,1,33,8,255,241,150,2,249,0,137,255,145,255,10,3,119,8,11,0,196,9,14,28,116,56,36,17,25,16,39,14,62,6,20,2,5,254,109,3,246,14,116,1,120,247,6,245,228,45,209,247,201,251,2,244,0,253,85,11,253,241,244,245,24,39,51,2,20,238,2,4,93,4,87,7,28,209,96,254,61,1,240,7,8,7,34,4,172,255,216,254,44,249,28,10,245,212,165,249,64,243,176,9,96,0,98,8,144,245,114,9,82,14,202,251,81,255,90,5,187,9,190,216,83,253,63,226,162,15,96,43,135,3,60,23,5,11,234,11,95,246,127,4,176,252,165,247,33,48,128,250,67,250,254,7,123,245,175,9,86,242,5,12,18,241,49,7,156,246,92,212,105,254,10,244,67,249,157,234,85,2,132,7,59,255,178,1,144,249,118,10,98,246,124,4,87,2,4,5,141,204,75,252,148,230,242,2,42,29,36,23,131,5,232,253,73,42,76,2,41,1,202,254,175,253,128,252,16,3,14,255,204,2,245,1,204,255,203,15,13,253,78,253,70,10,98,69,145,247,78,8,186,3,220,250,121,43,34,6,131,1,177,245,129,54,201,254,111,20,7,247,228,241,90,253,163,251,178,2,233,254,99,9,251,249,237,1,100,249,0,248,253,252,91,252,167,1,188,2,72,3,227,2,164,7,80,252,100,2,138,245,101,0,245,0,238,252,82,3,13,1,75,5,13,85,207,1,227,245,84,2,249,253,20,3,213,255,196,4,178,41,239,18,168,4,79,1,107,3,150,255,148,41,40,10,15,21,250,254,248,8,216,232,208,251,134,255,200,9,33,5,93,4,43,252,94,1,119,1,214,252,8,0,182,5,28,248,192,246,8,0,135,88,1,6,87,0,140,3,64,3,236,236,56,1,108,2,18,4,164,238,148,2,46,6,106,245,118,244,28,39,148,218,166,31,64,22,165,250,37,244,237,242,146,1,218,0,72,4,124,248,88,0,34,247,79,16,197,251,15,254,123,246,252,242,200,252,212,0,198,246,248,17,136,225,19,211,115,30,236,0,200,250,136,205,193,2,180,17,48,250,226,45,115,243,166,245,220,9,178,245,128,255,184,254,74,13,197,1,14,255,60,246,176,8,196,2,194,1,58,244,124,255,227,4,125,255,193,252,58,253,31,170,222,0,172,247,67,243,234,1,52,244,164,252,246,9,124,3,145,253,174,241,104,253,125,255,226,7,1,11,27,209,240,1,158,253,186,227,187,240,205,244,216,26,111,7,80,3,244,25,228,14,202,233,41,240,135,254,208,247,249,215,212,251,206,5,159,1,3,255,118,247,26,4,3,3,56,229,20,4,42,29,137,11,166,226,65,6,103,27,14,249,170,249,220,242,37,249,19,11,176,0,140,10,223,3,0,10,214,253,3,19,35,6,22,234,50,10,150,48,89,241,20,217,63,245,248,18,221,245,209,234,41,39,44,3,175,2,155,10,173,15,14,12,249,208,72,1,104,240,204,15,176,240,145,255,215,253,72,249,150,9,170,6,171,250,36,3,183,129,41,254,129,3,194,237,12,3,160,241,127,250,186,245,20,0,184,0,99,255,222,254,234,10,222,253,96,255,28,6,122,4,116,2,77,237,17,255,225,43,20,254,163,7,96,2,57,36,108,243,246,14,134,1,162,232,242,242,200,242,52,9,28,7,111,242,211,3,216,255,34,177,47,0,56,255,242,19,131,254,32,7,59,255,232,8,130,9,183,245,127,250,171,251,208,251,89,3,18,6,35,29,6,0,98,47,202,251,14,4,212,254,76,202,129,12,6,253,110,10,229,251,67,254,146,3,84,255,210,253,74,10,122,251,57,12,182,255,169,242,62,4,68,221,118,0,121,253,29,1,186,0,206,11,43,236,62,5,125,13,201,224,191,255,82,18,176,3,133,14,139,248,201,217,145,254,93,249,252,252,0,128,6,5,104,254,84,1,172,254,174,1,250,4,84,2,147,255,41,253,20,1,78,252,139,0,12,7,230,251,22,242,144,250,101,251,1,1,103,6,108,100,230,8,111,9,126,8,153,0,126,0,196,255,80,2,226,3,178,254,244,254,34,7,206,254,63,247,214,10,140,243,246,2,62,254,87,31,30,2,163,26,80,249,115,55,106,247,25,1,244,255,178,253,127,251,216,17,164,241,181,7,155,235,209,248,165,253,252,12,188,9,2,244,178,252,123,0,96,251,155,2,122,213,191,255,201,245,203,3,235,39,35,251,210,28,182,247,254,246,59,2,6,247,166,7,252,238,6,220,225,16,245,10,96,7,121,43,2,5,69,233,32,246,151,252,99,4,176,232,172,245,117,234,153,247,80,252,224,225,41,248,44,247,128,248,52,8,187,254,153,0,26,4,10,0,182,5,138,2,241,206,202,13,242,2,141,17,248,5,177,228,22,237,203,5,152,246,225,10,141,249,194,252,153,5,96,246,211,73,157,248,191,243,228,3,181,9,240,11,219,251,81,240,22,247,76,5,244,245,22,254,185,4,113,4,4,0,132,253,254,250,233,3,90,251,84,255,31,201,96,239,76,248,177,8,126,237,226,251,134,20,177,31,198,16,36,0,245,45,103,240,196,251,24,15,56,244,140,215,97,1,147,11,52,251,24,2,97,2,169,254,222,4,33,14,173,241,186,18,120,176,217,1,213,2,34,251,143,249,108,7,227,245,203,244,10,246,138,252,116,251,172,248,51,1,200,14,82,237,36,254,68,253,70,8,188,248,253,5,107,236,52,9,233,12,10,13,24,200,2,251,190,254,158,7,70,252,58,248,158,5,30,13,55,29,230,11,235,229,250,243,181,6,41,12,60,207,234,250,35,255,2,254,183,40,87,242,74,16,234,241,71,27,170,244,202,1,155,2,54,2,111,9,109,254,174,244,212,255,216,248,146,255,7,7,148,4,7,0,2,250,90,0,174,2,234,150,65,6,202,252,146,2,182,0,105,255,89,1,208,5,136,5,240,254,24,6,46,38,36,8,16,0,248,199,148,5,2,2,98,10,224,250,47,8,198,1,9,249,248,247,177,17,130,4,65,247,188,3,156,2,140,250,174,244,149,1,141,206,244,206,118,253,181,253,133,13,90,246,0,0,172,243,114,12,248,239,193,6,158,5,206,248,90,254,124,17,153,7,92,252,97,250,66,253,138,250,21,13,84,7,25,252,218,247,41,186,80,254,196,15,5,247,109,4,88,0,83,247,86,245,86,252,26,252,124,255,86,254,36,8,12,8,146,251,199,254,146,1,230,253,223,245,230,7,213,2,30,6,234,247,118,84,231,6,88,254,96,128,205,0,41,251,75,243,198,0,23,251,38,9,130,248,225,5,196,1,68,5,164,253,210,3,55,4,252,255,172,9,33,251,110,255,163,252,120,248,66,208,14,205,152,250,77,248,108,250,200,4,129,253,173,255,10,4,160,13,250,246,203,253,74,0,177,254,214,10,90,2,104,3,172,247,109,255,112,8,244,0,162,0,56,49,116,2,46,216,240,250,44,4,224,248,175,236,122,12,18,8,129,252,240,252,43,9,66,248,73,0,6,4,45,49,194,255,32,247,243,14,16,249,242,9,119,250,238,12,118,18,250,243,220,253,182,222,96,6,245,229,240,3,104,4,37,3,186,3,104,2,243,1,218,132,209,250,22,3,66,255,34,4,123,251,152,5,240,255,155,1,148,243,59,3,71,1,146,3,180,6,162,5,28,4,157,249,243,248,207,239,146,202,13,14,31,247,224,232,8,14,112,4,45,255,205,2,61,15,244,235,220,11,167,253,176,50,97,6,76,40,118,249,44,254,137,3,27,9,73,3,9,255,91,232,175,253,47,243,195,16,39,20,227,251,234,248,53,10,173,8,122,4,103,3,91,254,226,253,155,3,17,242,142,251,67,39,108,42,23,232,107,253,211,233,134,252,246,254,52,8,79,24,186,255,158,245,178,255,96,13,202,2,90,8,181,250,43,252,198,7,4,3,170,3,31,5,85,248,156,3,12,168,4,1,171,254,227,4,214,249,23,0,95,5,44,4,128,10,131,240,201,2,34,235,255,254,37,0,110,232,236,254,228,0,40,251,253,227,182,242,171,198,172,6,195,254,192,244,106,3,186,5,12,2,43,8,53,2,132,239,247,254,52,0,211,242,36,255,153,243,86,10,192,1,164,249,62,248,152,8,138,14,120,194,208,27,12,248,134,247,141,253,201,251,36,240,209,8,99,252,166,242,80,203,228,250,148,13,241,252,172,240,204,252,164,252,114,9,166,11,207,221,41,35,38,1,117,209,55,252,1,13,7,253,179,5,68,235,19,7,123,1,50,1,120,2,84,245,208,9,164,4,114,242,137,247,196,253,30,247,135,249,10,94,97,255,118,255,222,248,33,246,211,243,118,252,22,249,98,251,216,4,8,244,9,9,234,252,80,1,253,240,184,203,89,254,10,51,242,255,140,248,224,255,47,10,231,1,134,246,195,0,135,0,182,10,4,6,246,251,88,3,16,247,225,254,250,252,241,1,224,6,191,0,178,0,42,1,38,0,78,135,33,3,80,250,7,9,248,4,203,248,78,1,91,252,183,0,178,249,227,2,89,7,20,203,235,202,216,5,229,247,255,250,26,250,108,0,99,14,160,251,240,2,44,252,235,254,247,250,224,7,222,254,46,7,191,254,117,255,143,252,153,207,135,198,114,7,222,3,126,243,16,9,237,2,80,7,15,246,79,250,65,249,222,2,185,254,196,254,38,4,179,243,113,244,162,8,144,3,184,3,134,7,42,221,74,4,82,2,97,250,134,250,89,43,154,13,40,254,219,0,251,240,106,253,243,37,88,15,230,4,39,248,87,48,68,249,114,54,100,7,146,250,174,2,126,8,242,3,239,250,57,255,63,7,207,1,41,10,56,17,186,7,143,6,178,249,253,255,67,209,92,63,60,3,217,5,21,253,28,254,7,2,244,248,26,241,215,12,56,8,125,4,222,1,178,240,224,5,72,9,196,254,248,253,87,250,178,240,152,2,212,10,206,191,78,1,228,253,246,252,4,245,118,232,216,238,114,246,151,13,158,14,144,253,55,15,121,4,168,254,77,1,122,46,91,245,73,50,135,251,241,248,233,254,60,254,211,249,36,2,196,235,36,248,83,13,164,4,129,250,80,240,44,254,112,7,68,249,130,211,226,255,66,56,74,6,166,247,225,4,90,1,209,23,103,250,113,253,82,255,68,14,170,15,186,3,78,250,158,254,176,248,127,245,112,3,178,252,232,250,67,249,214,6,94,251,240,5,243,1,185,253,25,71,197,251,5,243,0,12,192,234,74,255,41,4,168,251,40,252,197,9,239,253,101,2,6,8,204,1,131,235,11,11,91,250,157,246,158,205,224,5,20,223,245,251,244,237,168,6,230,245,162,5,137,48,232,247,229,2,216,241,179,50,239,7,148,254,166,14,38,236,80,248,146,0,158,2,108,240,193,252,122,15,141,1,69,24,102,251,48,3,168,255,80,254,108,218,52,45,194,0,33,1,90,248,189,247,153,252,252,20,183,243,28,14,108,6,58,3,13,2,15,246,254,253,231,253,181,9,10,252,252,4,29,2,88,252,210,254,108,251,183,0,59,3,131,93,96,4,166,254,199,254,199,10,94,15,246,243,44,247,118,252,57,252,216,5,102,0,34,245,67,1,171,251,219,255,250,9,152,244,230,3,94,252,96,248,142,251,50,7,199,249,193,67,66,251,215,251,134,8,111,251,225,45,22,1,118,32,211,5,204,253,145,4,214,32,79,5,31,251,210,247,171,250,229,15,36,7,129,3,234,4,59,4,223,16,98,2,254,2,225,8,217,15,109,2,82,1,37,5,51,174,36,2,36,248,51,2,78,4,229,255,191,11,105,4,212,251,2,5,133,244,167,11,166,7,8,7,120,7,192,6,162,253,12,7,96,237,204,19,171,250,191,17,143,1,184,200,194,231,43,24,99,247,150,4,156,248,44,243,50,255,56,11,194,245,213,255,4,44,152,255,36,1,212,248,124,231,213,2,18,8,164,253,118,44,64,254,230,2,38,11,114,252,186,252,246,248,94,14,115,254,238,253,105,214,52,9,129,47,226,5,89,10,249,242,56,12,121,8,54,23,104,8,44,55,172,1,187,0,248,0,56,6,212,255,197,255,138,244,91,7,101,252,113,10,177,252,150,0,162,247,60,226,70,43,173,253,90,25,151,202,180,3,219,0,222,250,248,243,59,5,12,43,82,5,247,0,185,248,45,4,54,241,170,6,40,4,64,1,183,17,136,0,211,14,185,5,180,250,63,254,13,0,91,254,233,6,246,79,133,8,141,254,140,9,24,253,215,8,101,255,80,253,20,255,127,238,15,6,252,10,172,9,100,250,42,254,240,254,228,8,82,2,166,252,46,252,98,4,164,9,122,219,159,254,4,252,238,1,111,51,234,6,198,6,186,255,234,237,70,48,206,252,45,252,165,240,232,3,9,239,10,10,191,21,250,12,114,11,20,255,68,237,75,27,134,249,195,16,94,4,174,6,254,247,2,203,254,255,233,255,56,8,77,4,196,254,114,7,107,6,84,1,52,23,108,12,187,252,186,7,238,214,186,5,232,228,16,14,181,4,189,3,45,255,176,223,75,6,210,20,159,235,40,247,207,233,243,243,15,220,194,255,38,13,90,5,234,218,244,0,116,234,186,4,114,11,80,254,15,251,120,1,138,248,8,252,179,252,156,12,70,4,160,243,122,2,247,254,158,242,15,17,92,240,235,254,23,197,158,15,199,37,90,13,179,2,164,35,93,245,147,7,7,9,69,2,140,236,53,13,34,250,110,3,243,251,216,5,186,11,136,3,244,234,28,243,7,1,253,4,74,253,254,2,245,6,110,4,250,0,166,128,227,254,210,0,246,9,129,254,140,3,46,1,36,1,160,254,55,10,159,255,185,248,116,7,125,10,10,254,73,241,160,1,222,3,166,253,3,250,43,0,8,5,46,5,254,64,177,1,76,251,58,7,183,249,127,5,228,227,15,9,138,22,48,6,126,4,134,253,106,249,79,5,140,250,182,1,246,0,186,0,2,212,86,251,50,241,61,243,132,10,243,2,142,0,148,63,222,246,195,250,193,40,38,0,26,250,40,246,123,243,145,3,199,14,170,249,120,237,99,7,198,9,248,255,110,244,43,8,138,58,246,4,115,11,170,2,49,4,25,216,70,6,14,252,202,252,144,4,133,250,254,0,132,4,134,12,118,15,203,6,110,254,114,253,2,237,179,248,83,10,214,244,146,2,114,252,12,246,52,21,56,248,48,255,158,7,90,195,8,2,140,239,110,12,64,16,244,5,156,244,74,2,141,12,163,2,185,0,139,253,157,2,186,252,246,1,31,240,97,1,24,240,216,248,196,247,170,19,180,9,26,60,202,247,124,19,70,0,243,3,8,10,80,5,251,244,24,13,190,212,130,245,99,2,204,1,19,7,21,12,34,0,76,220,117,251,26,0,149,252,206,9,110,4,214,250,226,8,64,252,201,252,2,254,68,4,210,5,186,5,70,248,255,127,181,246,5,252,135,253,230,250,14,255,2,8,56,5,148,245,109,247,70,254,8,0,244,8,248,16,121,246,64,250,11,4,149,199,228,248,165,24,208,247,45,0,33,14,25,6,228,4,12,11,186,41,130,252,89,42,69,9,155,255,145,3,112,8,93,10,144,11,175,238,169,4,28,19,181,247,25,225,223,3,173,245,172,250,199,241,248,217,188,1,101,3,174,11,158,3,60,251,116,249,68,29,24,17,98,241,204,228,179,17,98,29,130,245,164,0,46,4,119,227,71,7,30,2,146,0,224,252,60,72,15,237,220,240,114,8,247,19,46,10,147,16,37,244,82,244,82,249,86,254,61,235,228,246,4,252,244,254,38,251,217,255,108,249,0,128,8,5,42,253,24,249,48,1,190,2,103,244,68,253,74,2,5,6,181,251,164,254,0,245,123,247,20,251,134,249,230,8,67,1,244,249,209,9,40,46,144,246,51,233,138,255,114,26,32,13,255,239,248,254,10,251,40,4,122,217,171,241,200,255,91,2,61,250,184,5,175,218,6,0,237,243,211,20,116,254,124,3,42,245,190,237,83,14,2,217,216,235,134,251,70,240,16,248,120,11,13,7,254,251,41,4,92,254,196,253,220,6,33,254,185,253,40,120,36,253,238,2,14,1,251,249,28,0,166,251,160,255,248,254,143,4,36,2,58,2,84,0,67,248,194,247,144,251,102,1,63,231,255,254,190,198,120,4,184,220,66,1,110,241,242,243,185,250,8,243,236,239,116,254,127,255,126,243,123,5,165,254,96,9,141,254,20,2,19,6,56,245,54,4,36,3,222,250,196,85,183,8,8,245,101,248,70,3,140,48,78,199,128,254,238,249,93,253,139,252,78,5,76,6,62,243,158,255,84,7,65,254,193,8,47,13,27,249,232,10,162,2,23,250,148,251,144,241,104,44,132,248,38,245,46,254,135,254,42,8,57,15,46,21,10,246,56,9,207,12,209,33,222,3,176,247,32,10,54,252,163,246,243,254,214,88,182,2,54,1,127,246,152,3,78,253,198,5,90,5,62,254,189,1,157,250,36,251,70,9,120,5,240,251,196,233,92,249,162,249,28,240,87,251,49,253,119,244,22,242,8,1,65,204,235,237,5,0,173,12,164,233,145,9,118,12,1,235,24,242,6,241,247,4,32,6,6,253,122,11,14,3,146,250,243,0,46,254,96,5,206,3,146,249,8,249,249,0,254,253,25,203,112,7,26,42,252,252,101,255,158,30,226,255,50,14,39,254,116,220,144,255,106,240,184,252,215,5,214,246,186,254,71,14,12,5,220,254,36,213,103,13,250,254,171,0,209,217,39,252,66,2,56,1,7,246,47,13,132,223,130,5,210,250,155,9,212,243,55,4,26,28,160,10,206,7,182,10,64,18,203,249,28,221,132,255,116,253,184,255,105,9,98,252,179,241,78,241,240,57,186,250,70,247,234,4,188,249,169,0,103,0,239,4,112,254,3,253,144,0,56,3,87,3,224,203,163,249,185,7,179,11,84,248,118,253,37,255,169,210,82,232,232,252,37,251,98,250,221,6,156,5,101,241,44,3,168,252,125,218,132,246,148,211,201,12,242,246,185,223,15,6,250,247,194,241,77,12,207,8,82,2,100,254,42,244,22,6,182,2,69,251,106,2,184,12,126,25,220,249,162,220,255,25,120,243,32,14,114,8,65,12,158,16,2,18,200,216,164,4,79,1,153,253,128,2,58,248,198,254,126,23,168,246,130,247,87,1,74,26,216,250,183,0,159,255,18,242,172,11,225,203,219,249,146,220,172,1,23,11,72,26,171,251,167,251,178,251,148,19,28,5,153,240,135,12,252,2,144,244,120,4,28,244,193,15,54,7,60,25,187,239,61,33,96,38,92,61,126,253,236,2,124,0,106,254,233,50,39,3,213,254,39,5,219,5,74,251,178,251,199,243,211,14,47,0,77,246,90,246,239,8,188,15,120,6,148,254,80,249,224,249,156,240,46,245,136,202,28,3,52,13,107,1,137,6,136,4,162,240,68,11,60,236,64,3,191,18,108,1,42,244,156,214,243,248,72,243,68,246,217,248,64,4,100,43,164,12,8,20,236,11,134,17,84,0,30,8,200,0,25,240,177,6,3,6,21,96,5,252,32,0,208,255,82,0,81,0,147,4,19,251,9,249,99,249,146,8,178,6,31,255,59,248,146,1,51,10,60,253,227,193,222,0,5,254,55,50,138,4,0,250,188,244,119,7,24,251,98,252,173,248,88,250,86,245,243,11,49,251,144,6,32,7,8,5,41,255,247,255,40,0,67,252,14,108,204,248,121,248,178,252,136,251,73,254,77,242,228,244,168,248,125,2,18,4,237,0,239,3,125,254,119,209,232,245,114,255,112,2,18,254,159,5,177,8,39,205,147,248,27,251,209,251,85,228,150,247,46,3,27,15,106,4,205,245,44,247,12,6,155,207,6,252,102,0,154,4,34,4,241,197,228,7,254,15,21,251,163,252,138,252,209,243,78,10,189,6,172,250,218,247,183,0,251,1,46,252,242,243,138,197,247,2,195,250,186,255,90,33,158,11,116,255,205,9,148,238,164,10,164,250,235,1,6,232,167,254,134,247,93,251,182,254,174,212,41,61,212,254,57,8,240,1,211,247,65,254,208,7,123,13,202,5,246,2,46,16,50,2,54,240,211,5,111,12,149,6,87,245,75,6,178,45,70,58,25,0,74,3,50,245,101,253,228,249,197,245,134,2,111,5,94,3,115,252,163,247,179,253,188,5,13,253,44,5,3,253,122,2,195,0,90,179,18,252,119,251,130,9,240,248,72,16,12,16,236,245,133,253,27,246,134,247,139,241,233,251,149,254,1,3,200,19,248,255,114,253,42,9,240,2,168,53,40,240,7,0,116,21,158,28,226,236,236,240,253,12,149,240,113,18,181,21,141,241,194,0,99,205,28,4,219,250,174,245,141,244,26,4,145,240,88,9,45,218,215,9,64,11,140,241,228,248,63,3,18,17,103,251,22,128,104,1,42,245,96,253,240,248,242,255,243,251,209,250,129,5,89,247,172,0,21,6,177,3,239,7,66,253,52,7,174,251,216,1,43,10,46,252,222,10,197,233,193,5,220,233,217,27,200,25,144,247,108,0,204,248,14,8,165,246,28,253,154,6,211,255,43,253,77,0,68,28,153,205,228,242,4,253,78,7,208,2,103,247,22,3,222,38,146,241,36,235,65,240,19,16,207,26,48,9,204,5,22,14,9,237,202,2,8,16,96,24,93,28,57,229,55,19,225,244,45,26,45,29,152,253,78,211,113,248,197,35,24,240,133,0,168,232,151,9,112,219,174,244,255,238,215,225,230,243,79,242,8,10,200,234,192,253,168,216,250,0,125,8,156,239,30,239,128,10,100,20,118,232,166,254,158,45,23,8,80,227,122,247,238,253,76,255,248,245,244,5,175,249,135,221,19,237,234,10,3,245,147,245,137,246,107,245,231,220,57,8,235,237,196,2,248,7,208,233,90,246,147,227,185,26,123,25,100,16,124,229,66,248,4,15,120,236,156,0,138,7,244,6,16,241,226,254,68,15,167,6,136,28,121,4,144,0,156,4,233,27,103,12,1,202,180,25,6,244,79,231,245,217,80,17,135,251,107,11,180,245,254,14,131,228,183,240,238,4,138,250,107,1,115,255,138,252,221,233,44,255,186,247,99,245,164,10,142,182,206,247,101,255,137,250,14,3,29,3,254,2,53,10,254,20,73,241,81,249,112,2,181,2,240,9,247,231,11,28,179,26,6,253,197,19,143,2,40,10,248,35,138,228,135,27,118,6,180,242,176,0,146,234,94,5,238,195,25,254,32,29,94,248,100,9,78,244,184,249,58,9,14,254,240,224,1,232,100,240,60,6,59,244,157,4,2,250,111,235,220,0,139,245,23,4,235,237,38,197,126,15,66,254,63,210,194,233,119,254,6,255,200,250,30,227,228,5,95,24,204,14,129,24,71,24,54,3,97,10,121,31,199,32,110,253,255,245,189,210,227,245,210,229,245,219,8,252,84,247,26,218,100,23,67,7,44,232,14,238,221,0,225,9,169,8,81,32,12,7,16,232,213,244,189,223,157,237,66,246,121,7,160,254,47,238,223,254,247,248,30,252,163,238,23,252,46,21,116,42,58,227,143,6,181,235,53,229,166,11,106,254,96,9,168,17,229,241,156,248,36,19,80,242,3,3,214,10,252,252,119,248,70,227,119,1,116,2,170,17,45], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+266257);
/* memory initializer */ allocate([4,55,252,147,31,101,255,106,12,142,251,216,6,120,188,38,17,77,246,233,247,183,250,125,251,56,254,133,245,142,26,140,248,5,7,255,229,46,245,234,21,74,199,34,23,132,240,86,252,171,252,136,5,203,251,46,238,96,255,188,22,41,244,227,19,195,7,70,245,61,241,238,0,248,254,254,243,58,210,154,36,78,38,98,231,139,15,134,244,194,15,137,1,137,250,142,238,133,8,244,2,138,1,216,8,176,241,78,0,214,1,100,243,102,15,78,249,196,2,124,19,146,7,94,245,203,17,66,236,254,251,112,75,98,1,107,0,19,235,244,238,85,2,250,245,4,245,26,247,66,254,104,5,141,254,250,245,124,254,132,240,227,220,176,35,61,13,248,32,62,234,18,251,14,233,8,8,171,232,71,255,188,17,196,236,154,0,187,241,167,251,24,244,187,27,82,245,124,11,208,229,7,6,72,224,150,39,243,218,11,230,208,18,70,254,224,255,130,246,68,19,15,232,70,236,232,23,157,247,2,229,194,250,51,4,102,246,50,0,117,237,248,243,94,7,210,5,28,74,48,0,19,3,137,9,107,254,132,6,137,250,154,8,127,8,248,241,12,6,88,245,0,237,248,1,127,1,120,1,207,251,94,8,248,1,214,243,234,24,116,234,150,52,196,0,48,7,175,27,24,3,1,242,46,1,244,3,128,234,14,1,26,13,122,238,248,246,38,246,200,244,197,240,43,247,91,20,137,5,253,243,105,255,39,252,252,252,162,249,164,0,147,2,216,5,163,254,147,253,224,255,90,244,72,249,109,242,54,227,251,249,98,4,250,79,190,6,122,17,100,243,112,27,193,12,10,2,111,247,191,247,12,21,120,7,41,23,248,45,118,251,40,10,208,15,140,2,32,13,113,243,120,1,44,39,166,23,26,241,125,251,93,0,160,17,3,242,59,240,60,29,55,250,237,10,75,10,13,208,36,245,165,231,107,22,127,10,120,1,96,23,13,246,126,221,236,16,192,10,150,7,234,3,16,243,131,20,170,255,142,225,150,3,147,246,59,12,12,243,47,8,39,238,234,195,98,234,10,5,59,20,112,11,218,11,61,9,14,1,204,226,48,244,254,26,75,5,138,231,8,248,250,40,152,5,252,47,101,4,168,243,166,17,205,3,209,246,66,249,175,7,208,5,126,1,231,13,98,241,164,244,80,252,130,249,170,2,134,3,248,238,162,19,100,239,68,251,59,243,120,232,52,241,168,35,178,245,167,249,59,1,15,12,63,243,55,215,217,227,18,240,62,243,137,226,153,235,84,21,192,9,214,219,29,255,208,15,92,3,248,253,48,53,126,242,253,14,41,3,152,255,34,240,18,237,120,255,161,249,153,54,144,251,52,13,75,4,74,240,39,7,32,13,182,220,204,255,252,253,160,39,210,19,2,19,90,32,52,252,192,9,32,9,62,34,65,11,113,9,44,234,248,11,94,15,150,239,115,2,38,252,214,6,190,3,212,246,142,19,219,245,166,255,133,0,231,90,127,9,112,240,102,7,210,247,232,248,143,19,164,243,222,9,186,248,91,10,17,7,5,28,82,13,154,0,82,58,216,11,62,235,44,0,164,34,225,253,146,247,221,20,2,1,4,224,188,14,244,10,120,29,147,32,24,242,193,255,33,253,20,5,44,239,195,251,134,236,28,6,168,229,211,245,202,254,251,4,142,4,128,253,206,18,21,17,31,12,38,251,161,23,78,237,85,2,182,0,67,9,38,27,39,247,133,1,179,198,106,248,83,245,27,254,159,252,171,253,160,250,90,6,140,240,36,251,252,5,78,15,17,243,38,6,168,255,163,175,161,234,185,255,61,249,156,5,124,9,142,15,32,238,110,252,84,21,147,236,114,6,196,246,74,246,140,12,48,21,59,246,243,17,87,252,216,2,236,235,36,217,157,5,64,41,184,233,248,254,64,245,181,3,109,20,91,250,174,1,59,3,7,16,49,248,239,237,181,239,191,221,33,221,249,27,187,17,56,27,87,23,238,237,23,245,96,39,110,215,81,246,188,6,176,11,98,1,66,14,0,13,138,17,117,248,180,28,115,28,24,243,94,17,94,249,56,251,70,244,244,16,17,4,95,2,58,254,91,239,105,185,81,251,194,240,58,2,176,22,206,21,54,26,235,0,51,255,64,239,144,13,82,253,153,255,182,241,76,254,48,218,66,255,19,1,105,252,218,9,217,247,136,35,196,19,206,230,42,40,16,13,25,224,248,225,105,46,29,12,0,251,42,217,35,210,165,8,200,2,136,15,134,239,91,235,237,10,180,11,166,15,5,8,40,9,56,24,141,0,56,10,115,240,58,27,158,239,171,249,100,202,92,30,240,10,172,8,189,1,246,254,190,15,188,1,28,255,82,10,81,6,49,246,163,6,36,34,110,13,241,247,211,247,14,7,182,3,56,228,23,250,186,244,171,221,102,3,128,13,226,239,254,242,29,2,67,216,3,249,84,12,114,17,179,232,223,1,57,20,10,245,202,9,146,249,231,241,81,6,51,227,182,243,171,246,17,14,170,30,89,0,211,242,62,18,172,239,142,243,240,11,101,249,34,5,18,36,137,225,43,5,248,238,118,217,118,248,155,31,116,203,55,33,188,7,239,43,8,30,191,232,187,239,136,243,28,2,95,6,131,0,202,8,210,20,110,255,236,221,180,243,18,11,124,4,210,240,118,1,212,248,198,240,177,37,95,4,237,39,128,0,164,34,123,227,41,10,228,4,36,9,51,241,74,18,181,0,82,17,52,249,16,17,111,3,148,253,254,7,50,7,76,3,99,252,54,246,240,242,140,221,46,253,61,254,9,2,135,3,250,250,13,244,68,235,105,237,110,245,107,250,202,10,159,3,77,250,150,227,4,209,134,34,147,15,102,9,178,33,200,243,105,25,30,239,59,255,96,246,178,10,210,255,161,0,95,54,204,8,11,8,213,3,204,0,137,4,46,19,171,2,41,239,33,8,116,248,95,4,77,232,51,235,80,33,160,237,110,234,217,231,112,22,177,242,27,248,128,10,98,243,186,9,48,252,12,254,102,225,16,8,119,12,132,18,102,14,226,6,44,10,118,246,168,233,130,226,201,1,106,242,95,224,146,230,111,220,95,31,225,236,244,1,124,246,203,5,193,238,25,248,72,241,63,246,137,248,21,3,54,2,55,252,148,239,240,23,44,236,104,10,130,239,99,26,238,6,225,26,64,0,181,4,229,219,174,18,80,17,73,20,46,247,77,237,247,226,219,6,230,252,17,5,145,226,229,49,164,35,38,3,44,9,80,224,194,30,4,239,126,250,162,254,32,246,64,2,149,2,16,1,246,17,179,2,121,7,235,242,167,248,194,248,245,252,203,252,252,32,60,0,10,10,235,248,182,250,96,238,161,234,120,18,217,12,57,10,146,219,242,229,165,252,103,245,145,217,68,18,159,245,34,12,143,250,38,40,3,244,51,247,247,3,198,8,77,247,16,0,124,254,26,31,213,5,206,243,109,245,46,31,38,232,74,250,127,249,234,250,43,9,56,14,238,196,93,247,161,1,163,26,191,3,196,244,44,229,52,43,231,246,210,254,59,6,254,237,42,37,133,49,250,237,173,244,115,255,7,237,167,5,0,25,178,244,160,6,184,244,97,7,161,13,215,10,8,254,59,230,118,235,168,227,133,254,31,251,120,255,46,12,47,242,223,12,126,242,55,8,113,254,177,59,34,255,239,248,172,0,209,8,155,7,195,2,234,13,197,233,247,13,94,247,118,22,47,3,219,15,240,255,26,5,4,204,59,249,198,250,107,242,127,20,98,248,228,235,90,253,138,31,204,6,34,1,241,7,31,18,112,239,232,253,162,235,170,250,187,9,245,1,197,255,128,238,174,1,227,254,197,232,13,253,33,199,64,22,48,27,110,17,13,9,14,25,138,204,98,19,125,252,36,23,92,43,183,20,54,252,32,246,161,231,205,8,188,8,41,2,202,1,75,247,80,31,86,228,53,11,143,239,148,238,120,230,229,13,26,249,135,30,113,253,115,232,126,235,165,249,86,10,118,242,0,242,133,3,65,40,129,252,85,254,181,3,40,245,108,13,1,3,221,239,59,35,222,236,22,242,214,224,153,254,78,5,8,250,233,243,208,22,186,231,31,10,218,247,8,37,128,2,42,11,216,0,215,241,108,22,160,228,183,251,213,247,113,255,224,18,66,24,178,250,158,15,54,253,67,3,92,240,80,14,188,7,216,4,86,11,254,1,227,249,171,1,252,247,144,239,31,250,163,4,51,251,148,14,92,252,10,252,176,18,42,72,9,236,231,11,202,255,245,249,204,240,164,33,18,1,166,5,36,242,247,225,89,254,168,4,100,238,93,215,225,221,66,254,188,1,47,231,168,15,74,250,54,221,119,251,165,246,138,9,156,8,160,234,32,188,167,9,79,253,114,5,183,241,185,247,255,252,56,11,113,5,115,245,48,242,66,14,134,254,91,3,246,242,132,5,194,11,85,243,177,254,221,241,1,254,117,248,42,228,102,236,140,219,168,238,114,7,39,247,106,5,136,31,80,230,236,250,82,21,226,236,118,2,22,228,215,8,42,3,152,11,100,4,85,247,244,8,182,240,212,248,229,229,231,5,61,245,116,5,121,9,222,162,201,8,203,255,133,252,114,249,26,249,4,249,246,1,142,239,211,0,136,40,125,234,69,3,204,231,84,8,40,254,87,216,66,28,80,250,108,255,22,19,123,9,67,9,210,4,62,252,154,24,248,3,199,6,202,253,146,252,121,224,221,9,132,47,253,18,33,37,53,227,98,254,186,11,64,2,165,254,26,252,45,11,220,252,218,11,42,3,236,252,229,253,212,247,106,19,36,7,203,244,14,245,249,25,89,14,63,255,62,240,210,2,106,6,208,14,66,34,188,40,25,243,247,240,88,238,22,255,162,239,61,251,236,250,224,239,192,32,130,251,42,6,226,231,208,251,249,236,12,224,214,229,222,14,38,227,15,246,28,4,218,253,132,251,228,250,126,221,162,245,190,7,12,34,179,25,80,5,156,246,101,7,120,10,217,14,89,43,175,5,149,9,95,226,177,226,90,206,92,254,231,7,112,253,100,4,56,11,204,37,43,239,54,255,178,5,130,230,234,253,1,250,156,3,252,11,138,251,209,19,4,5,0,234,101,3,155,249,174,244,36,19,38,216,8,215,183,251,98,7,254,42,212,255,88,5,69,248,107,25,60,1,193,3,8,0,11,240,1,10,14,248,203,251,34,10,47,254,242,235,156,252,54,0,218,229,136,37,68,242,253,27,3,43,70,37,172,18,16,245,150,251,78,249,132,245,143,254,138,18,128,245,50,16,28,226,216,3,65,243,236,254,82,220,224,244,113,240,10,39,24,14,162,12,172,253,7,1,30,12,78,255,40,247,236,14,59,239,136,233,7,242,182,240,71,4,230,249,94,86,2,18,69,0,73,244,254,0,130,8,171,244,77,251,244,250,82,10,74,243,147,250,139,11,60,5,30,2,42,3,89,5,136,12,229,252,56,243,99,245,151,251,77,34,58,229,44,244,152,253,217,2,17,2,222,228,85,6,102,37,195,197,22,21,86,3,250,252,6,217,215,234,44,246,181,237,83,22,190,255,8,13,80,236,128,2,114,226,166,13,104,27,35,247,96,5,86,201,48,25,148,240,95,249,108,240,97,230,72,9,135,16,197,243,253,7,143,246,225,232,152,228,97,249,86,35,226,224,67,20,7,246,122,5,209,246,36,255,43,23,225,248,34,247,72,2,56,241,108,11,22,24,37,244,66,9,59,19,200,251,170,2,37,225,181,213,224,248,116,252,32,6,19,242,193,15,86,239,100,248,155,3,112,21,53,255,164,246,117,252,223,10,50,243,135,5,30,30,66,255,168,235,25,247,242,4,148,251,192,242,11,40,216,251,19,44,114,8,165,8,32,236,127,17,206,237,245,248,254,5,119,239,23,240,26,27,126,15,242,236,180,254,73,23,1,36,232,1,120,25,78,17,52,31,167,36,230,245,182,4,185,228,151,252,227,4,57,7,57,23,160,247,16,248,196,248,160,1,136,14,115,9,14,33,101,12,4,45,178,244,115,234,45,255,166,69,98,12,74,4,47,253,238,247,92,248,231,243,219,251,255,10,191,1,189,2,193,1,27,254,49,10,215,4,209,8,32,249,19,12,114,29,126,14,127,245,236,243,247,26,103,246,199,12,211,24,50,250,196,252,202,7,9,242,109,15,113,12,46,10,208,236,89,193,127,221,39,7,20,10,201,7,163,251,176,242,90,226,146,227,115,255,136,10,37,3,104,7,52,1,122,1,92,36,78,11,28,239,18,4,69,3,108,18,162,237,189,9,203,235,168,33,44,254,19,198,175,14,179,12,115,239,196,250,104,20,51,8,4,253,185,223,93,249,76,0,72,250,67,8,186,253,214,12,187,241,249,3,160,6,122,250,100,253,236,217,158,233,109,9,10,251,74,232,106,66,116,8,192,234,9,7,181,247,32,3,87,8,193,18,137,252,163,247,121,253,18,237,49,254,191,253,202,248,213,253,119,248,254,7,80,32,49,223,46,15,194,232,150,239,200,206,11,245,221,1,65,0,252,23,65,4,127,237,7,35,160,7,80,248,180,241,241,25,82,3,24,243,17,249,170,15,67,42,29,56,72,253,205,250,68,249,19,255,229,241,244,0,189,11,253,16,74,255,228,239,162,9,186,10,195,255,63,13,144,250,204,14,46,6,139,14,228,27,97,247,162,241,141,245,4,255,204,226,210,36,204,231,154,12,226,13,74,231,68,239,202,24,176,238,79,20,183,245,61,246,176,4,140,251,186,240,224,25,92,65,58,23,2,253,70,10,80,251,196,7,134,21,81,251,30,16,7,5,198,1,253,248,104,10,137,19,34,4,244,1,75,254,176,11,36,248,96,255,28,3,18,237,84,230,152,216,91,2,227,1,98,238,1,206,174,13,8,249,182,13,140,240,150,23,84,35,115,232,2,28,184,249,120,0,146,3,56,255,99,15,126,231,204,11,91,24,62,245,248,20,99,249,116,232,130,1,42,248,106,7,72,210,11,217,243,253,192,245,7,7,44,16,176,12,199,255,109,241,180,14,206,21,10,241,76,246,238,247,237,5,124,252,198,223,1,224,116,10,123,4,96,26,252,26,172,4,182,245,80,13,164,11,238,251,131,15,120,2,174,236,198,233,133,0,141,9,66,254,242,250,247,252,28,13,4,234,124,232,150,224,205,19,115,250,115,245,243,196,2,12,112,252,242,245,83,10,132,20,186,247,9,15,47,241,174,252,74,16,96,24,71,253,64,27,88,241,131,4,89,30,48,221,208,225,128,16,198,246,80,241,104,14,98,9,173,242,163,243,10,246,248,255,47,255,178,254,187,252,56,22,97,13,44,238,15,39,84,237,21,12,250,16,76,234,100,6,219,6,152,198,18,7,147,25,196,255,214,15,43,41,230,23,194,238,224,6,253,13,183,252,119,17,233,255,180,0,3,1,169,238,82,204,210,250,121,7,147,253,151,249,190,244,186,236,4,2,210,240,140,238,146,255,82,238,219,235,126,29,159,238,45,3,244,238,232,6,131,221,211,7,164,250,81,7,47,255,3,6,52,4,136,207,72,250,170,248,27,6,228,7,192,2,145,5,237,254,122,241,10,18,160,251,63,236,250,241,182,15,71,248,108,2,143,0,53,246,113,14,65,243,104,2,70,244,237,242,59,82,210,238,108,1,124,248,28,1,92,245,7,247,52,19,142,10,2,19,197,16,35,245,70,4,11,250,206,253,111,21,206,247,50,18,82,5,171,253,158,242,101,12,202,235,82,15,252,240,202,5,103,18,221,22,210,5,123,21,127,187,188,3,32,2,12,1,82,237,8,254,93,240,113,252,87,2,210,6,102,227,115,7,198,7,89,66,99,12,171,245,16,4,185,227,242,21,48,1,22,14,207,242,46,14,151,28,108,0,16,254,2,4,246,11,120,254,62,9,156,7,238,253,38,3,140,10,140,245,99,245,118,20,120,193,201,252,248,254,232,249,10,252,8,253,156,241,182,254,12,22,124,249,1,216,233,245,243,28,175,253,145,8,57,250,180,244,250,14,215,241,54,208,177,251,76,7,255,235,39,15,188,10,144,7,234,7,220,17,107,232,238,12,26,222,204,45,170,20,244,246,35,16,66,3,181,240,101,3,58,249,136,233,231,4,62,37,215,241,141,255,232,232,131,255,250,8,42,250,22,23,16,254,97,245,40,5,103,12,60,244,190,240,250,17,104,237,226,232,248,245,232,25,158,221,12,233,214,24,45,9,207,0,71,20,177,32,212,232,150,10,14,31,89,14,224,245,31,5,192,32,248,238,166,33,226,233,156,4,99,8,20,4,55,6,77,234,195,249,66,17,38,0,213,249,67,18,67,249,99,249,186,230,250,11,79,226,234,205,12,2,86,244,178,242,156,34,14,251,94,252,220,16,147,4,164,244,199,0,7,249,221,244,252,241,0,12,255,241,148,245,157,251,228,5,204,1,124,26,232,179,38,11,218,249,236,3,210,19,115,7,60,248,153,4,74,0,100,250,176,8,208,4,64,244,130,242,162,252,92,2,115,253,218,10,45,9,170,12,234,32,82,254,100,14,206,18,162,248,254,19,207,5,186,1,238,246,124,252,218,244,22,255,146,215,14,225,23,253,46,250,250,233,130,232,17,240,93,244,161,254,21,37,30,247,158,211,26,224,60,227,69,32,18,6,70,249,43,18,193,252,228,8,222,5,40,10,242,4,104,17,207,239,3,241,0,242,146,16,218,15,165,246,197,228,134,17,161,12,82,24,26,5,14,211,177,231,244,235,1,6,201,238,230,5,100,22,248,10,185,22,148,236,172,244,129,3,119,246,229,248,19,22,180,228,177,216,16,247,68,233,30,251,157,3,48,12,237,23,83,217,119,255,100,14,55,230,53,4,200,12,21,0,13,13,186,252,197,241,65,249,191,238,148,2,105,230,72,255,67,224,12,249,112,20,189,23,224,224,23,25,239,14,210,11,203,17,208,1,246,12,128,234,69,3,13,242,13,15,27,247,184,248,26,253,252,234,208,23,200,26,52,4,109,3,126,253,134,7,152,237,110,199,5,243,144,245,61,29,188,247,164,240,185,8,58,243,70,1,173,8,132,0,155,248,20,253,197,1,13,14,252,246,237,238,0,22,25,14,247,251,68,254,225,245,207,67,208,243,212,245,85,12,142,254,26,36,186,249,115,10,171,252,195,5,96,254,48,243,121,251,191,0,170,241,26,1,186,16,67,252,94,244,236,13,91,0,216,175,26,244,224,4,253,4,40,13,94,4,55,1,170,253,126,5,183,246,92,250,137,5,214,241,167,0,216,230,13,13,117,2,37,246,46,17,93,251,226,16,129,254,142,7,30,243,174,222,147,8,100,20,254,1,24,251,236,228,219,251,21,20,142,192,146,250,222,253,80,241,19,248,95,252,100,232,81,242,56,1,30,33,189,2,161,34,107,18,195,7,62,5,120,5,185,255,147,235,245,249,133,221,45,9,36,50,57,250,13,18,115,23,163,229,144,243,221,233,142,244,206,251,132,12,74,1,84,18,56,11,200,213,75,0,20,251,83,70,4,16,74,250,111,5,125,249,9,248,81,253,58,237,25,23,122,10,50,30,122,27,143,10,130,6,120,0,65,6,75,8,122,5,162,237,35,212,195,30,41,234,26,18,30,247,199,11,171,253,160,226,185,251,50,237,83,255,186,21,253,5,247,10,18,33,75,20,126,30,25,10,195,244,26,27,154,240,146,1,15,241,66,16,189,35,233,230,143,9,129,27,116,11,171,217,76,8,198,255,253,255,200,205,219,224,204,5,139,3,180,0,106,31,180,247,4,17,235,239,102,4,22,218,203,247,117,15,171,248,115,4,236,27,123,14,195,250,157,17,60,251,218,17,142,249,152,230,124,27,228,215,184,254,70,18,83,208,198,19,201,23,16,254,196,225,159,8,137,17,51,255,106,5,121,245,94,250,122,18,124,3,29,47,234,14,23,243,79,17,84,36,142,13,0,18,219,16,124,3,98,3,78,249,249,5,9,10,122,211,4,244,230,254,90,6,75,2,224,249,162,249,36,255,15,248,229,27,84,245,43,242,76,13,154,60,91,7,119,245,98,252,84,23,85,25,118,229,63,8,186,9,177,4,91,21,208,246,192,12,159,255,96,9,40,253,220,242,89,13,201,5,46,11,206,1,39,11,143,235,108,22,40,28,244,214,74,243,170,5,10,251,219,254,72,13,190,228,51,39,67,251,212,16,81,10,131,33,70,33,153,244,161,254,53,254,235,247,151,253,126,2,189,250,107,0,121,23,243,7,232,254,217,7,208,12,44,251,144,197,199,235,120,246,197,3,170,245,209,247,154,20,33,7,121,14,247,14,66,254,78,240,10,28,145,246,248,16,58,7,3,254,12,254,32,4,234,238,77,22,56,5,24,13,235,30,2,247,177,47,230,199,29,25,143,5,96,11,74,25,193,249,92,4,232,8,54,249,36,12,96,233,30,242,111,2,170,251,30,232,136,17,237,34,152,243,102,53,8,243,185,254,159,245,75,227,198,14,55,250,105,22,56,255,152,11,254,218,120,22,192,19,80,18,24,235,80,254,118,252,8,241,185,222,249,255,83,14,255,13,106,24,20,34,241,41,155,36,182,3,162,249,12,214,156,22,15,16,162,244,181,1,78,246,118,7,185,0,136,247,173,243,69,242,38,249,114,19,202,16,247,228,220,1,38,245,34,2,140,245,58,247,209,243,168,244,109,245,102,248,38,30,244,8,147,9,110,16,66,251,150,254,92,4,164,252,30,0,31,252,136,252,234,251,108,241,36,247,19,246,172,23,84,247,195,249,142,249,216,250,88,0,205,4,70,8,44,9,150,5,183,248,114,247,182,247,204,248,235,247,46,249,15,0,46,249,41,5,145,245,79,244,81,243,5,245,163,247,176,250,94,7,14,1,131,254,44,22,234,247,68,254,94,253,198,251,136,251,166,254,201,252,22,18,32,255,148,7,119,246,232,247,110,247,217,254,127,8,185,4,34,253,168,0,155,3,79,5,149,245,133,1,231,245,25,247,109,247,139,251,8,252,38,255,109,0,134,7,64,20,78,247,160,248,7,251,236,251,25,0,205,1,118,3,101,4,225,4,89,247,179,246,37,12,85,248,199,11,21,248,234,252,168,4,110,6,140,8,166,244,218,245,228,1,188,246,164,250,198,251,182,6,152,2,111,5,92,9,42,246,145,7,198,246,50,246,32,250,131,11,190,1,172,2,155,7,11,8,65,243,71,244,88,243,38,244,218,245,39,13,55,17,23,9,146,9,178,11,181,246,173,248,186,248,243,24,92,248,119,250,243,253,74,4,44,7,116,11,128,5,150,251,119,250,157,6,250,254,123,253,253,253,187,1,223,2,107,2,238,244,58,247,170,245,39,246,213,252,208,25,91,254,36,6,223,7,162,12,218,247,101,250,89,0,112,6,70,3,38,252,121,251,72,251,224,255,74,5,169,247,145,247,116,30,136,246,75,252,8,248,101,251,228,0,163,4,192,11,109,244,60,246,230,247,23,248,97,250,156,6,134,254,172,253,194,255,115,9,62,242,196,243,173,244,38,243,143,244,28,11,49,0,211,16,194,10,57,15,112,244,25,5,190,248,193,252,157,250,251,252,185,12,211,3,207,3,233,5,223,244,182,249,179,9,200,1,141,250,134,253,79,3,40,5,92,4,151,4,193,9,238,249,128,8,95,249,27,252,225,252,136,255,83,1,228,3,99,5,95,44,235,249,85,247,67,247,0,249,220,247,15,252,13,3,13,13,171,3,162,7,188,248,213,246,187,247,48,248,142,250,241,14,106,0,35,10,114,8,134,244,72,246,192,247,4,3,221,251,30,7,159,0,249,3,148,9,226,5,33,5,201,245,81,246,131,244,84,247,50,246,42,253,95,18,242,6,47,13,195,243,152,245,251,244,45,245,23,6,24,252,78,254,82,7,34,16,171,11,74,244,124,245,234,246,44,6,73,247,189,250,70,16,229,7,153,4,227,9,192,244,223,246,227,245,225,5,229,244,92,246,173,254,221,251,140,12,168,16,216,243,187,244,183,244,207,3,38,246,26,247,209,2,193,19,149,15,45,13,230,243,125,244,152,251,53,247,143,7,165,11,191,11,207,3,191,7,0,8,211,244,2,247,129,246,76,250,44,250,12,250,80,252,20,6,242,6,13,6,158,245,45,247,208,10,100,246,89,250,141,11,247,2,68,1,229,9,173,9,137,244,105,249,6,246,169,245,105,250,118,0,147,254,40,40,246,5,119,13,246,245,220,8,209,246,189,247,28,10,247,255,190,252,91,4,86,7,61,9,79,0,108,4,173,249,130,250,224,249,26,249,32,255,57,3,65,8,102,5,220,253,147,245,251,248,125,245,165,247,65,246,46,255,252,4,55,53,11,9,173,7,79,249,182,249,117,247,230,9,41,250,235,250,110,2,51,2,106,8,183,10,158,12,8,249,18,249,232,252,19,254,125,255,156,0,176,3,187,4,162,248,101,1,6,252,225,0,227,254,1,4,122,255,218,0,34,1,153,0,237,22,153,246,216,244,21,244,20,246,90,243,44,247,142,254,61,254,170,24,12,254,6,246,194,247,145,252,189,254,231,253,58,2,204,4,20,6,62,5,74,246,38,13,46,7,87,252,65,252,85,253,63,0,169,3,140,2,188,4,140,247,88,250,166,0,225,252,218,253,219,250,225,1,43,1,118,21,80,5,181,243,242,245,35,252,14,6,160,7,34,250,160,255,189,13,24,5,7,9,141,244,158,247,130,247,252,247,67,2,168,2,128,3,137,10,191,2,85,5,34,16,193,246,189,245,203,243,90,252,235,243,149,247,69,252,137,23,160,19,207,243,8,244,189,244,102,246,187,6,182,252,216,11,39,17,23,9,21,11,24,246,96,247,182,249,115,247,109,25,112,250,164,251,147,5,14,11,42,13,60,4,230,249,137,249,164,249,21,254,212,8,191,254,165,1,6,3,213,4,61,243,209,3,158,243,184,243,118,245,212,250,144,5,218,11,251,12,19,13,51,244,11,244,235,7,215,246,84,3,240,244,78,249,38,23,165,17,255,14,46,250,144,246,66,249,12,251,78,250,167,247,77,249,188,253,123,5,96,52,67,244,110,245,9,244,71,245,39,245,168,247,226,10,202,0,21,20,79,13,224,243,71,244,152,243,196,242,77,242,209,244,207,247,21,9,58,10,2,24,51,248,176,243,244,251,122,245,229,245,86,244,66,245,85,247,185,249,56,23,179,244,183,245,75,247,5,245,78,246,189,247,85,247,100,251,126,20,180,12,217,243,252,247,123,245,138,244,243,248,23,10,97,1,238,4,140,33,60,15,92,246,90,245,187,248,208,246,67,247,66,245,215,246,112,248,65,38,200,32,94,242,204,243,244,241,210,241,174,243,170,246,231,2,252,25,222,24,255,23,220,244,37,242,204,243,98,245,186,251,18,254,49,0,227,251,67,244,255,127,71,249,51,251,77,249,202,249,51,6,47,251,56,13,4,255,56,1,96,4,41,243,146,244,24,244,244,244,58,246,95,251,236,7,194,14,231,1,35,8,104,2,215,251,170,249,99,248,253,250,161,252,163,26,5,2,111,4,2,5,71,10,89,250,59,250,20,252,30,1,78,5,121,255,172,254,147,0,126,255,59,21,183,249,132,248,34,249,214,251,154,251,222,1,227,3,74,4,157,5,55,249,197,250,184,248,39,248,242,251,20,252,195,253,42,3,86,23,24,11,93,1,233,249,40,250,129,251,205,254,174,255,169,2,59,3,38,2,8,3,138,7,166,0,180,251,47,250,95,251,98,251,70,251,186,254,90,3,152,6,255,245,186,13,32,253,19,6,197,255,118,252,133,255,87,0,102,0,18,1,110,7,53,254,192,11,40,252,61,253,178,254,197,253,195,254,66,255,141,254,210,244,95,2,66,5,19,250,60,251,151,253,190,9,185,2,190,0,64,0,192,12,86,15,31,251,250,249,91,252,210,254,10,255,8,255,69,0,229,254,26,249,18,253,150,248,21,251,185,26,246,249,239,252,192,255,184,4,14,5,14,250,50,249,175,248,150,248,81,250,216,27,16,253,182,6,118,5,99,4,74,245,125,18,240,249,77,246,94,247,17,254,99,1,96,3,62,3,247,2,95,245,189,247,157,248,96,249,143,251,233,249,15,251,110,253,177,253,82,3,69,253,238,4,217,253,225,251,109,3,96,0,124,254,64,255,33,254,189,251,53,245,157,250,218,12,27,9,150,252,205,254,126,254,103,2,110,1,133,0,145,245,61,20,243,16,130,252,153,252,134,253,91,255,153,1,91,0,221,254,167,245,101,254,103,31,101,248,124,251,57,0,95,1,246,3,216,1,58,255,232,248,178,253,71,11,90,249,167,251,86,13,212,253,117,0,227,1,135,254,85,249,134,251,125,251,214,9,222,7,130,254,3,0,250,255,206,0,158,255,18,42,18,1,121,250,122,249,4,252,244,251,238,252,242,252,49,254,216,253,60,246,220,40,168,249,5,249,61,253,209,250,197,255,119,1,91,0,22,0,40,245,217,246,200,247,57,3,9,253,201,252,226,1,125,4,241,4,58,2,116,249,222,248,200,248,237,23,145,250,204,252,63,254,76,3,74,2,23,2,199,244,85,246,209,245,205,245,218,248,25,254,107,6,144,6,40,8,10,10,203,246,31,252,117,12,63,250,178,13,77,251,231,252,150,2,208,1,98,0,53,246,81,6,255,248,113,248,229,250,87,255,9,0,117,3,216,2,154,4,38,248,190,250,161,250,69,255,220,253,193,10,48,254,151,255,31,3,255,1,134,247,132,246,127,247,39,250,24,8,60,3,185,1,252,3,105,3,232,3,239,250,5,250,185,248,81,248,20,250,192,251,10,253,26,255,25,6,255,25,131,247,5,249,244,249,29,249,170,250,232,255,123,253,180,26,200,5,131,7,88,245,189,248,6,7,38,248,207,249,91,253,141,254,125,5,230,4,254,4,54,247,45,245,193,244,41,245,64,247,173,250,240,254,209,4,28,24,210,19,190,244,141,246,250,247,140,246,28,251,91,1,45,5,7,7,187,6,9,17,6,3,18,8,82,7,24,1,61,253,163,253,187,253,106,253,176,251,10,248,199,27,119,255,141,252,201,251,23,252,202,255,177,252,11,252,235,251,192,252,88,18,197,14,144,253,51,250,176,250,177,250,229,250,61,251,158,252,79,252,43,21,24,250,253,246,170,247,248,247,68,249,139,249,138,253,157,0,71,13,41,253,164,252,155,250,132,254,52,253,201,250,235,14,78,0,254,255,21,1,143,243,210,243,101,245,218,243,36,250,90,6,24,13,3,12,164,7,229,253,0,65,76,251,23,247,253,246,32,247,211,246,39,248,120,247,39,245,185,246,9,252,64,24,110,254,205,250,98,251,5,253,38,253,175,255,177,253,96,251,121,248,31,2,112,17,185,251,125,255,226,253,127,255,230,1,146,254,183,251,198,249,214,253,241,255,175,254,80,12,45,253,71,0,216,255,129,1,203,254,255,252,34,1,171,252,222,251,84,251,235,249,173,253,111,14,105,4,182,1,193,6,227,250,53,252,153,252,90,0,138,5,237,4,233,255,154,250,33,255,241,249,55,253,236,251,143,17,96,255,157,252,38,251,164,4,159,0,120,0,135,249,73,252,0,6,97,255,226,250,77,4,108,254,155,0,181,6,232,255,185,249,43,9,8,8,105,248,223,250,239,250,175,255,34,0,161,5,98,1,194,247,175,248,252,253,78,4,126,8,83,8,0,0,78,252,39,253,61,0,107,0,242,255,148,255,206,255,42,0,92,255,79,255,164,255,227,255,162,0,69,5,180,246,205,247,100,249,44,252,207,255,162,255,75,1,37,5,235,14,30,254,242,252,249,252,115,252,128,253,181,251,153,253,31,255,20,6,157,11,138,253,70,0,70,255,193,249,204,251,88,17,134,252,78,0,180,255,251,253,169,252,162,248,15,250,74,251,128,251,124,252,241,2,58,5,222,6,127,9,127,246,223,249,242,250,185,253,40,2,248,7,102,255,250,0,1,2,29,9,204,252,61,248,13,247,66,247,168,248,141,249,160,251,250,254,221,7,28,38,13,245,242,245,182,245,27,245,100,1,210,248,69,1,232,17,0,14,182,9,12,250,82,7,175,254,248,248,133,249,150,1,146,9,228,4,11,255,250,251,193,7,115,254,227,249,205,255,148,0,247,7,68,251,39,253,68,253,245,255,136,3,137,2,19,2,17,247,152,249,254,2,43,253,171,0,196,249,107,5,117,12,96,253,53,254,230,252,90,254,54,253,61,255,25,255,185,0,99,0,72,252,56,247,134,247,90,251,55,254,178,5,34,0,155,4,123,9,147,6,134,249,165,14,232,248,48,248,7,11,37,251,121,250,201,2,107,3,75,0,238,252,193,0,175,195,200,0,26,4,95,191,215,255,73,1,155,252,86,255,166,252,165,10,217,0,191,1,59,8,233,255,125,254,216,215,129,254,192,254,131,1,140,62,177,255,57,252,200,13,181,247,231,253,132,253,31,249,181,3,100,0,239,255,66,254,5,1,255,87,75,1,26,0,169,255,50,255,12,247,102,251,92,255,86,2,147,0,121,3,105,199,249,244,0,251,156,248,33,0,29,249,225,3,199,18,71,252,133,8,180,253,59,0,216,254,218,0,35,1,152,255,239,1,188,251,184,8,200,197,41,252,153,244,27,3,201,188,3,248,172,11,85,2,184,215,50,253,108,247,66,233,79,3,24,5,11,253,150,237,108,255,63,3,34,253,38,3,252,16,204,254,244,0,54,2,146,10,92,2,20,253,160,252,200,253,37,255,128,255,80,253,38,255,110,0,151,141,226,1,76,0,89,250,114,255,95,254,3,255,188,31,193,178,222,3,194,17,12,252,110,224,133,0,180,249,61,247,52,241,32,6,180,244,84,3,150,249,105,242,233,255,20,5,204,253,243,251,249,0,59,199,213,255,65,1,88,253,10,0,95,254,130,91,141,1,148,255,51,7,180,0,200,46,115,218,97,1,184,14,130,0,245,251,244,16,218,0,84,2,32,255,245,252,112,249,46,5,152,0,53,252,3,218,157,254,208,20,53,254,114,63,74,254,158,3,66,24,120,7,1,3,61,10,108,255,16,252,5,2,85,1,246,241,59,252,119,44,150,252,203,189,143,4,213,242,137,249,74,2,124,255,150,15,254,252,211,0,246,0,2,2,90,255,34,253,200,118,254,254,247,253,236,255,83,1,243,1,244,245,62,8,16,1,77,5,123,0,25,11,192,254,225,255,68,254,11,254,215,0,214,255,83,2,108,0,228,1,33,255,169,3,219,1,184,255,193,254,75,0,51,255,46,252,61,220,145,0,228,7,253,255,134,9,206,15,255,250,149,252,252,5,170,253,0,48,113,1,2,248,87,1,246,252,233,6,227,245,127,253,29,68,1,7,176,253,94,248,185,249,40,24,112,13,0,254,106,245,206,250,129,255,61,34,83,0,13,255,197,254,197,2,0,1,152,4,82,251,49,254,202,3,210,254,200,253,27,252,2,252,159,0,0,43,27,0,18,51,243,5,89,243,26,9,56,237,227,23,51,217,169,5,105,8,217,243,244,6,37,253,121,0,143,252,47,200,247,254,54,2,157,253,3,255,107,244,250,0,151,255,190,255,10,10,126,248,152,10,115,7,23,248,58,254,173,0,183,5,227,255,45,131,143,255,41,249,231,242,254,0,233,3,125,26,227,255,129,253,247,250,32,1,242,1,255,171,48,0,109,0,153,247,33,255,80,5,154,242,146,2,167,239,86,249,220,4,107,7,124,0,12,0,221,255,33,1,126,1,177,1,5,1,125,255,54,0,122,253,232,254,86,0,180,0,153,0,87,255,238,176,161,255,222,2,244,253,77,0,102,0,20,33,91,254,29,0,253,255,51,0,246,5,168,253,248,254,99,1,157,7,39,252,221,254,170,255,228,39,235,252,119,254,74,255,205,255,178,3,180,190,70,252,155,4,71,245,3,254,90,237,181,253,160,253,233,29,3,254,124,254,219,3,109,0,38,255,85,187,244,253,45,254,149,249,68,254,150,5,237,9,132,255,249,6,27,0,225,30,183,255,193,243,39,251,2,255,190,247,151,4,12,3,206,255,215,15,23,2,182,1,32,0,143,255,252,254,81,0,78,4,197,255,4,114,208,255,212,0,227,255,168,254,47,2,88,3,29,254,96,2,216,255,38,250,112,0,134,40,174,4,78,254,213,15,6,5,236,0,31,7,174,62,80,2,47,6,78,0,133,235,31,5,200,1,194,250,222,253,159,254,233,51,179,254,239,253,133,174,183,0,89,255,168,250,174,254,78,253,152,16,51,255,102,253,134,253,139,249,150,4,234,0,66,183,123,3,28,1,184,245,20,250,33,1,234,43,215,2,133,0,28,1,189,254,166,250,140,3,143,204,100,254,131,4,154,1,98,2,0,244,228,223,131,253,242,0,121,253,232,247,169,62,244,8,183,224,95,1,191,243,253,243,229,251,217,17,125,0,23,0,1,5,183,9,8,2,47,255,80,253,205,0,32,251,246,0,167,253,21,2,79,208,6,247,58,3,54,245,45,0,19,59,209,2,104,4,30,3,92,253,93,1,103,255,7,1,89,0,170,252,232,255,162,254,29,255,157,0,75,2,16,255,71,255,151,2,184,129,108,255,52,255,164,246,171,253,168,254,168,31,232,254,137,254,8,1,136,2,229,2,222,254,191,254,7,1,199,253,131,254,167,0,221,6,60,140,30,0,137,1,142,1,78,2,14,255,81,0,65,6,99,14,19,3,176,254,163,2,200,251,55,253,5,1,244,71,224,6,97,2,254,237,217,253,230,10,95,77,67,5,131,255,60,219,251,254,36,2,32,4,179,0,107,252,75,255,93,49,245,254,109,2,124,209,86,5,76,0,243,22,26,253,138,1,155,0,142,254,177,9,46,0,224,195,168,254,234,217,183,250,62,247,107,249,250,250,16,9,128,247,63,249,193,2,210,249,54,6,67,6,137,82,29,242,144,8,141,252,110,13,233,0,173,7,231,253,143,1,46,237,11,240,47,2,220,254,10,5,116,245,10,0,211,254,183,248,226,0,52,0,190,250,50,1,60,1,7,208,243,253,29,1,159,37,254,255,175,252,84,6,128,0,176,0,3,252,39,254,249,30,123,255,155,9,223,255,19,250,225,169,4,247,98,0,71,242,78,1,9,18,63,255,227,250,1,251,226,2,69,254,95,0,150,1,148,2,63,253,202,255,217,255,28,103,2,253,249,0,137,246,79,30,79,253,187,240,4,188,65,0,57,7,177,3,35,62,106,5,79,254,193,252,51,231,177,240,78,7,160,31,55,1,195,58,173,6,197,254,8,5,98,29,41,255,48,236,222,4,50,250,178,14,174,17,237,5,112,248,225,253,249,254,3,3,25,216,87,254,22,236,59,0,246,254,12,252,132,254,173,247,118,2,149,1,153,2,58,238,123,5,8,0,210,255,145,252,142,1,236,253,71,255,226,254,153,3,191,255,122,1,157,2,174,0,80,196,91,0,248,252,32,33,159,9,184,0,17,8,102,253,207,253,26,16,82,2,220,2,167,15,172,252,185,255,194,0,130,255,229,6,222,249,200,3,255,254,224,254,182,3,90,107,179,254,114,1,107,250,29,1,46,2,237,43,121,255,53,2,16,5,251,254,194,255,88,2,175,5,177,5,52,3,101,1,77,251,169,0,227,64,131,252,103,1,231,0,162,1,221,253,161,255,26,15,1,254,56,231,51,255,155,3,17,255,179,192,173,249,217,0,222,242,58,231,241,249,137,2,20,254,8,1,201,255,170,0,96,66,165,255,50,1,43,0,46,245,70,2,52,249,77,0,142,252,12,1,253,253,211,255,51,232,24,0,36,234,74,35,28,1,139,12,78,3,134,4,162,251,164,253,254,253,122,5,19,254,86,252,204,240,242,0,131,2,141,5,78,254,106,254,154,255,168,255,43,210,161,0,6,2,210,3,228,5,248,0,244,251,127,5,116,254,37,1,130,4,101,250,239,1,51,32,20,0,179,252,3,235,147,2,62,9,220,113,145,0,91,2,248,15,5,255,231,244,34,246,202,80,179,250,106,246,148,2,131,255,91,1,252,45,143,255,155,254,123,247,46,251,116,7,80,254,171,64,8,255,54,3,156,60,98,255,115,253,37,6,93,0,86,245,169,251,190,3,242,249,127,251,17,0,98,2,13,3,140,254,152,249,144,0,121,255,109,251,124,86,85,254,230,255,178,2,224,252,39,250,212,254,62,21,134,1,40,44,37,36,74,4,188,21,247,255,16,15,197,3,224,7,3,206,151,6,147,3,103,14,27,2,192,9,190,2,212,250,185,255,101,205,32,29,18,18,176,252,233,248,63,3,103,8,241,30,72,244,123,0,165,4,47,250,222,0,109,19,144,7,54,0,225,214,42,251,123,251,116,2,32,55,140,247,198,5,39,252,250,239,123,2,225,0,201,254,159,253,9,252,45,1,251,1,171,255,187,1,186,0,216,253,57,253,164,189,209,250,220,0,53,2,119,249,225,253,201,72,75,1,127,0,170,254,22,0,179,255,152,254,73,254,11,254,200,248,133,251,29,254,109,4,161,254,41,0,140,3,246,1,110,253,218,1,82,254,172,211,255,255,237,253,195,1,197,2,227,0,46,252,92,1,247,254,13,1,136,254,207,9,68,255,145,255,125,254,41,3,241,3,34,6,13,253,57,211,155,2,129,252,190,1,20,1,145,0,255,253,139,255,50,254,172,254,177,5,61,252,191,0,236,252,106,255,45,252,5,254,108,148,122,0,112,1,183,255,67,39,47,254,130,2,251,1,84,229,241,0,95,236,62,6,106,251,69,9,32,247,138,248,148,255,15,0,166,0,2,0,22,41,165,3,84,206,254,1,10,3,88,254,158,1,35,19,247,2,94,3,74,254,138,252,201,1,48,1,87,92,136,0,53,255,222,1,203,253,244,0,227,253,115,9,251,252,83,4,39,255,43,6,243,251,220,1,159,255,227,3,53,70,161,0,82,64,78,255,50,253,186,249,179,3,199,7,218,8,225,4,148,10,157,253,144,5,114,255,203,255,36,0,253,1,47,102,112,255,101,1,219,255,22,255,75,2,55,1,3,254,153,249,180,254,174,249,130,254,46,1,47,222,188,255,226,255,33,2,222,205,158,0,158,0,135,0,109,2,158,254,153,252,195,1,196,4,225,255,2,0,154,203,60,0,3,0,132,254,29,2,212,255,40,2,146,254,155,0,50,254,61,0,24,255,190,195,61,1,176,2,97,4,117,11,239,27,88,255,49,220,39,246,233,2,232,10,48,215,57,2,17,241,118,2,238,237,161,255,96,254,60,3,3,1,72,0,171,0,123,2,6,255,128,255,86,254,103,255,4,1,253,252,58,1,235,0,26,0,25,126,169,254,239,2,93,250,68,1,84,253,108,7,202,250,230,7,30,0,49,4,154,246,32,8,27,254,192,254,224,59,164,252,239,253,196,191,37,255,200,6,107,255,96,255,196,252,65,4,157,1,241,0,136,14,166,255,146,0,85,4,243,0,191,254,0,255,188,255,88,0,206,255,59,2,155,4,58,158,104,0,161,3,35,0,17,2,117,0,100,202,222,2,192,250,200,1,210,21,30,6,227,206,184,252,175,249,66,246,255,6,109,7,250,11,145,247,98,254,240,240,90,217,184,249,111,253,251,59,251,252,255,219,110,253,52,252,122,18,86,244,106,242,11,253,120,250,138,241,169,70,117,2,149,27,124,0,211,22,158,0,73,74,100,247,192,228,93,6,231,233,77,4,189,248,111,250,220,253,148,251,77,236,50,4,176,253,60,255,110,7,177,88,52,251,214,0,83,253,12,248,192,246,197,254,110,252,21,2,218,0,67,4,141,253,239,7,98,54,104,0,62,254,142,17,14,254,151,254,158,96,111,2,5,4,133,9,157,251,28,236,105,230,182,1,178,64,119,1,210,204,63,255,44,248,228,13,179,0,40,7,38,8,30,3,234,253,61,255,63,228,28,3,129,15,19,208,34,6,177,16,124,245,216,4,171,244,3,248,107,246,116,1,101,2,220,253,11,255,175,2,2,1,252,220,36,250,17,250,31,252,163,68,155,254,148,3,78,251,216,6,33,8,232,253,143,243,218,251,135,75,209,2,26,217,28,4,152,252,248,0,195,243,200,1,105,6,149,0,245,255,139,11,54,1,150,243,121,182,241,1,53,252,69,230,156,250,95,1,106,0,213,255,95,2,110,237,213,0,6,4,1,21,220,252,3,246,82,3,57,4,62,253,45,5,182,197,230,252,20,201,95,248,123,3,32,243,73,1,2,254,154,251,89,4,217,6,101,254,233,6,173,1,71,255,4,252,194,0,150,255,206,44,177,253,240,254,166,1,81,1,12,2,106,255,54,3,51,0,136,255,25,28,34,3,128,2,116,255,214,255,221,109,4,252,29,1,47,254,123,12,69,0,226,1,71,252,6,1,8,226,139,254,38,20,249,21,69,244,38,2,251,20,243,21,104,247,16,21,220,252,135,0,20,5,230,241,233,255,79,254,191,52,224,0,143,3,171,199,10,254,153,247,125,249,115,248,72,11,235,254,35,2,35,252,43,12,224,255,88,253,92,255,36,3,156,1,62,0,102,255,66,255,156,0,70,213,152,254,168,255,75,3,72,1,251,252,245,254,132,206,88,3,216,5,13,255,182,253,224,2,129,247,91,253,3,244,56,29,28,249,72,240,247,245,13,7,194,0,98,229,145,251,19], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+276497);
/* memory initializer */ allocate([255,122,10,100,255,134,252,5,5,112,1,10,7,85,253,93,255,167,4,249,204,16,254,177,254,74,68,234,2,50,3,48,0,171,83,170,253,39,249,111,251,169,247,40,0,102,220,80,2,184,240,188,7,248,254,208,254,202,31,71,255,30,1,48,244,48,0,162,249,141,3,149,2,106,253,165,70,240,0,55,255,69,0,192,0,49,1,105,169,180,2,145,251,28,252,142,1,182,255,121,72,66,252,199,4,54,234,252,1,160,254,210,4,62,254,241,1,12,3,79,0,51,0,35,255,255,0,230,255,40,52,86,255,231,0,78,2,169,0,35,253,212,252,191,255,37,255,53,174,200,0,35,0,79,255,58,254,120,2,245,254,105,254,136,255,111,2,80,255,104,253,203,2,233,255,62,1,148,0,101,4,16,0,197,2,73,171,26,255,99,254,118,5,45,251,229,254,79,6,175,0,213,254,93,1,144,1,144,255,2,85,103,253,108,1,65,4,23,5,202,255,11,2,131,254,224,250,48,0,138,252,20,251,152,1,159,1,99,223,203,27,180,0,250,252,180,13,53,252,1,255,61,255,81,0,142,245,47,252,157,254,36,250,178,0,223,247,176,238,10,252,84,1,186,22,138,0,150,255,21,66,179,4,93,1,199,12,193,3,107,1,120,23,101,232,152,14,38,253,151,239,254,253,13,232,188,255,169,197,11,249,198,240,216,255,0,182,51,254,98,249,11,251,13,253,175,255,65,9,228,1,19,2,34,55,85,0,32,0,98,216,114,255,88,2,186,246,119,1,163,2,153,245,155,0,77,252,27,25,212,44,229,4,185,19,39,4,211,7,184,249,159,9,136,247,152,251,55,4,127,1,28,252,112,1,184,4,30,242,65,252,244,17,71,251,198,239,246,4,149,36,41,245,41,249,230,3,201,177,165,254,225,5,218,0,114,255,86,1,128,255,245,253,97,255,75,0,45,254,1,1,123,255,114,255,200,2,147,253,172,1,112,140,13,0,146,1,57,254,119,0,29,254,97,4,51,254,192,3,39,3,210,255,41,1,8,58,221,0,156,254,221,0,189,58,120,237,5,246,191,1,118,250,184,5,111,5,132,250,76,233,0,2,239,246,154,38,242,0,6,247,119,255,175,252,146,243,178,36,132,5,28,4,89,5,120,252,18,254,25,255,89,4,63,4,251,203,0,3,102,251,61,244,24,0,229,0,164,0,70,216,72,1,52,1,177,253,213,0,225,253,174,255,234,252,149,252,26,3,210,253,29,226,195,253,242,4,220,247,227,8,69,255,97,0,128,1,202,209,71,255,40,254,85,5,116,45,131,250,104,1,25,254,72,254,228,248,163,254,219,254,29,1,25,0,117,255,97,254,228,253,148,255,112,4,95,253,230,0,2,75,223,253,226,253,151,3,197,4,250,253,196,0,116,170,27,3,115,0,240,255,203,1,11,13,165,254,166,254,70,255,73,253,245,254,54,253,185,0,10,1,62,251,120,0,7,255,233,0,146,255,52,137,29,1,219,0,208,8,24,2,70,254,161,2,49,250,35,254,196,255,242,248,183,0,229,227,191,253,182,8,86,226,98,243,65,0,179,89,111,0,134,1,222,27,124,241,253,235,37,254,224,255,158,255,46,254,138,255,213,255,74,0,209,251,122,252,178,6,164,15,26,0,97,0,144,6,167,1,252,0,195,37,38,2,98,1,34,255,19,0,32,255,217,252,109,1,81,2,107,1,173,252,228,255,41,2,238,0,31,254,1,3,23,1,191,71,50,254,30,1,217,18,115,255,244,1,159,79,82,6,225,255,254,253,76,246,185,254,198,222,63,253,152,252,18,2,243,216,220,255,81,254,8,11,113,12,176,6,194,254,41,37,175,216,102,2,9,254,133,1,30,50,143,255,241,255,17,252,245,253,243,250,202,247,225,253,123,251,185,253,204,4,6,1,94,253,201,248,14,255,43,1,7,209,35,2,177,253,43,220,19,1,156,1,189,9,229,3,205,4,190,7,162,107,245,0,106,0,216,250,103,255,89,254,69,252,63,254,136,1,56,3,28,3,99,251,104,6,140,252,186,255,85,34,37,39,242,248,251,3,90,0,214,5,23,8,113,252,121,251,212,0,159,8,30,252,60,246,15,254,92,0,232,210,114,254,250,252,194,5,32,0,97,253,85,255,30,251,7,255,137,4,114,253,51,255,220,255,197,6,251,2,181,166,57,62,66,62,200,62,60,78,33,63,113,27,77,63,199,186,128,63,243,31,154,63,54,171,182,63,211,222,216,63,121,88,248,63,89,23,11,64,206,136,22,64,250,237,31,64,158,94,37,64,125,208,43,64,140,219,48,64,174,71,57,64,20,63,6,62,56,248,162,62,114,138,238,62,183,98,15,63,222,113,42,63,149,101,72,63,254,212,128,63,17,199,162,63,53,94,194,63,111,240,221,63,231,251,249,63,117,2,14,64,250,237,23,64,65,241,31,64,150,178,44,64,8,61,59,64,212,154,38,62,112,95,231,62,106,222,33,63,216,129,51,63,167,232,72,63,213,231,122,63,2,43,151,63,217,61,169,63,82,73,197,63,27,13,232,63,194,134,247,63,119,45,5,64,29,90,20,64,168,53,33,64,239,56,45,64,189,227,60,64,61,10,23,62,163,146,122,62,135,22,217,62,92,32,17,63,240,133,73,63,81,218,123,63,155,85,151,63,183,209,176,63,24,149,196,63,199,75,215,63,46,144,240,63,228,20,9,64,222,113,26,64,231,29,39,64,98,161,50,64,211,222,60,64,218,172,250,61,79,64,147,62,50,85,0,63,229,208,50,63,38,228,99,63,102,136,139,63,186,73,164,63,200,7,189,63,198,109,212,63,82,73,237,63,34,253,2,64,224,190,14,64,195,100,26,64,95,7,38,64,50,119,49,64,151,255,60,64,69,71,50,62,63,87,155,62,96,118,239,62,157,128,22,63,7,206,57,63,34,253,118,63,58,35,146,63,76,55,169,63,108,9,193,63,102,136,219,63,226,233,245,63,251,58,8,64,253,135,20,64,107,154,31,64,199,75,43,64,4,231,56,64,67,173,41,62,65,130,162,62,8,61,251,62,16,233,39,63,29,90,84,63,79,64,131,63,65,130,154,63,252,169,177,63,0,111,201,63,127,106,228,63,172,139,243,63,35,74,7,64,103,68,21,64,59,1,33,64,1,222,46,64,45,178,57,64,83,5,35,62,168,53,141,62,129,38,226,62,252,169,33,63,19,97,83,63,177,191,124,63,121,88,144,63,88,57,164,63,123,131,183,63,254,212,208,63,62,232,241,63,172,173,8,64,93,220,22,64,120,11,36,64,146,203,47,64,186,73,60,64,191,14,28,62,164,112,221,62,103,213,23,63,33,31,52,63,129,4,69,63,198,109,100,63,91,66,150,63,43,24,189,63,95,152,212,63,196,66,229,63,140,185,251,63,237,158,12,64,142,6,24,64,186,73,32,64,189,82,42,64,69,216,56,64,172,28,90,62,254,67,154,62,228,131,190,62,90,245,217,62,188,5,2,63,129,149,51,63,150,67,123,63,242,176,160,63,145,126,187,63,48,42,217,63,102,247,244,63,72,225,6,64,54,60,21,64,106,222,33,64,255,178,47,64,32,210,59,64,177,225,233,61,201,229,191,62,23,217,30,63,156,162,67,63,201,229,79,63,148,246,102,63,22,251,123,63,65,241,147,63,119,45,185,63,105,0,223,63,21,140,250,63,50,85,8,64,149,101,24,64,72,191,37,64,115,104,49,64,202,84,61,64,18,131,0,62,123,131,111,62,180,200,182,62,208,68,8,63,192,236,62,63,213,9,128,63,150,33,150,63,88,168,173,63,17,199,194,63,60,78,217,63,42,58,242,63,95,7,6,64,197,32,20,64,120,156,34,64,214,86,48,64,190,193,59,64,39,194,6,62,195,100,106,62,219,138,221,62,163,146,42,63,149,212,89,63,174,216,127,63,187,184,149,63,242,176,176,63,146,203,199,63,192,91,216,63,187,184,237,63,136,133,6,64,200,152,23,64,179,12,37,64,66,96,49,64,237,158,60,64,7,206,25,62,238,90,130,62,66,207,198,62,89,134,8,63,234,149,50,63,163,146,106,63,116,181,141,63,40,15,171,63,66,96,197,63,236,81,224,63,206,136,242,63,158,94,5,64,166,10,18,64,51,196,29,64,0,0,44,64,77,132,57,64,138,31,35,62,26,81,154,62,58,35,234,62,147,169,34,63,183,209,80,63,12,2,123,63,137,210,150,63,43,246,175,63,172,173,200,63,214,197,221,63,93,220,246,63,117,147,8,64,183,209,20,64,193,202,33,64,182,243,45,64,216,129,59,64,71,114,57,62,129,38,162,62,4,86,238,62,70,148,38,63,106,222,81,63,195,245,128,63,181,55,152,63,16,233,175,63,213,231,194,63,131,192,218,63,103,68,241,63,85,193,4,64,154,153,17,64,121,233,30,64,104,34,44,64,152,76,57,64,200,7,61,62,116,36,183,62,98,16,8,63,190,159,58,63,213,231,106,63,59,1,141,63,161,248,161,63,133,235,185,63,254,212,208,63,149,212,233,63,240,133,1,64,170,96,12,64,85,193,24,64,183,209,36,64,48,42,49,64,2,154,60,64,161,103,179,61,134,90,19,62,23,183,81,62,181,21,187,62,41,203,32,63,5,163,98,63,15,156,139,63,48,76,166,63,213,231,194,63,217,95,222,63,137,65,248,63,228,20,9,64,189,82,22,64,67,28,35,64,75,200,47,64,195,211,59,64,59,112,14,62,6,129,213,62,43,246,39,63,200,152,75,63,36,151,95,63,64,164,127,63,158,239,151,63,35,219,185,63,109,86,205,63,125,63,229,63,47,221,0,64,207,247,11,64,191,125,21,64,34,108,32,64,232,106,47,64,70,182,63,64,193,168,164,61,131,192,10,62,157,17,133,62,201,229,255,62,18,165,61,63,206,136,114,63,50,85,144,63,223,224,171,63,231,29,199,63,174,182,226,63,175,37,252,63,242,210,9,64,111,18,23,64,216,129,35,64,250,237,47,64,20,174,59,64,148,135,5,62,237,13,158,62,192,236,254,62,231,140,40,63,254,101,87,63,17,54,132,63,36,185,156,63,132,158,181,63,118,79,206,63,195,245,232,63,217,206,255,63,126,29,12,64,86,14,25,64,228,20,37,64,216,240,48,64,54,205,59,64,74,12,66,62,106,222,145,62,45,178,189,62,79,64,211,62,78,98,32,63,255,178,107,63,11,181,150,63,82,39,176,63,138,176,201,63,28,235,226,63,108,120,250,63,5,163,10,64,209,34,23,64,20,174,35,64,241,99,48,64,45,67,60,64,236,81,56,62,246,151,157,62,25,4,246,62,68,250,45,63,67,173,89,63,188,150,128,63,100,204,149,63,220,215,169,63,205,59,190,63,193,57,211,63,17,54,236,63,83,150,5,64,236,81,20,64,69,71,34,64,55,26,48,64,2,154,60,64,20,174,71,62,148,135,165,62,177,225,233,62,98,16,24,63,69,71,66,63,210,111,127,63,214,197,149,63,106,77,171,63,181,55,192,63,49,8,212,63,170,130,233,63,59,223,3,64,159,205,18,64,216,240,32,64,74,123,47,64,104,34,60,64,83,150,129,62,183,209,224,62,88,57,20,63,80,141,55,63,75,89,102,63,211,77,146,63,29,201,173,63,61,44,196,63,151,255,208,63,39,160,225,63,40,126,252,63,220,70,11,64,159,205,22,64,40,15,35,64,150,67,47,64,95,7,58,64,254,212,56,62,224,190,142,62,245,219,183,62,11,181,198,62,35,74,11,63,63,53,78,63,7,206,137,63,18,131,168,63,120,11,196,63,55,26,224,63,60,78,249,63,41,203,8,64,210,0,22,64,252,24,35,64,163,1,48,64,88,57,60,64,60,78,81,62,136,244,187,62,58,35,10,63,116,70,52,63,255,178,91,63,113,172,123,63,11,36,144,63,25,226,168,63,15,11,189,63,202,84,217,63,222,147,239,63,148,246,2,64,156,196,16,64,97,84,30,64,70,37,45,64,99,238,58,64,98,161,214,61,82,184,94,62,226,88,215,62,249,160,23,63,151,144,63,63,215,163,112,63,87,91,145,63,144,160,176,63,45,67,204,63,45,178,221,63,197,254,242,63,94,75,8,64,105,0,23,64,24,38,35,64,220,70,47,64,80,141,59,64,13,113,172,61,179,12,49,62,140,74,202,62,15,11,37,63,173,105,94,63,119,190,135,63,64,164,159,63,139,108,183,63,5,197,207,63,66,62,232,63,229,97,1,64,137,65,12,64,183,209,24,64,25,226,36,64,27,47,49,64,209,145,60,64,61,155,21,62,248,194,132,62,14,45,210,62,202,84,17,63,200,152,59,63,143,83,100,63,249,49,134,63,50,119,157,63,11,36,184,63,145,237,212,63,12,147,241,63,185,141,6,64,65,241,19,64,23,183,33,64,21,140,46,64,84,82,59,64,62,232,25,62,45,33,159,62,216,129,243,62,72,80,44,63,246,40,92,63,127,251,130,63,111,18,155,63,44,212,178,63,70,182,203,63,129,4,229,63,78,209,249,63,91,66,10,64,26,81,22,64,170,241,34,64,109,197,46,64,83,150,57,64,191,125,93,62,81,218,187,62,51,51,3,63,26,192,43,63,247,117,80,63,63,53,126,63,229,208,154,63,242,210,181,63,132,13,207,63,154,8,219,63,145,126,235,63,2,188,5,64,179,123,22,64,35,219,33,64,54,171,42,64,16,88,57,64,81,107,90,62,192,91,224,62,124,242,32,63,109,197,94,63,41,237,141,63,185,252,175,63,246,151,205,63,14,79,223,63,147,169,234,63,248,194,244,63,40,15,251,63,23,72,4,64,25,115,11,64,215,18,22,64,169,164,38,64,52,162,56,64,156,162,35,62,122,54,139,62,157,128,198,62,43,135,246,62,162,180,23,63,80,141,71,63,72,191,133,63,219,249,166,63,33,176,194,63,212,154,222,63,21,29,249,63,216,240,8,64,60,189,22,64,99,238,34,64,137,65,48,64,218,27,60,64,207,102,149,62,9,138,15,63,9,27,46,63,219,138,61,63,147,24,84,63,0,111,113,63,17,54,148,63,88,57,180,63,179,12,209,63,13,113,236,63,122,165,252,63,53,239,4,64,250,126,18,64,163,35,33,64,227,165,47,64,121,233,62,64,195,100,42,62,170,130,145,62,12,2,203,62,81,218,11,63,124,242,80,63,198,109,132,63,206,170,151,63,218,27,172,63,197,143,193,63,112,206,224,63,238,124,255,63,20,208,12,64,94,75,24,64,220,104,36,64,87,91,49,64,184,30,61,64,163,146,186,61,235,115,117,62,202,84,1,63,186,107,73,63,195,211,131,63,227,199,144,63,36,185,156,63,147,169,170,63,137,65,184,63,121,233,214,63,87,236,247,63,34,253,10,64,15,156,23,64,118,113,35,64,219,249,46,64,184,175,59,64,30,167,40,62,52,17,150,62,56,103,196,62,164,223,254,62,197,32,32,63,237,158,108,63,163,35,145,63,173,105,166,63,118,113,195,63,43,135,230,63,29,90,252,63,228,20,9,64,181,55,24,64,29,56,35,64,105,0,43,64,207,247,55,64,35,219,121,62,147,169,194,62,216,129,243,62,245,74,41,63,232,217,92,63,211,188,131,63,38,83,157,63,207,247,179,63,206,136,194,63,150,33,222,63,97,195,243,63,201,118,6,64,11,36,20,64,114,249,31,64,247,228,45,64,198,220,57,64,229,208,34,62,79,64,147,62,30,22,234,62,99,127,25,63,235,115,69,63,170,241,114,63,139,108,143,63,49,8,164,63,7,206,185,63,94,186,209,63,242,176,232,63,192,236,2,64,88,168,17,64,190,159,30,64,16,233,43,64,172,28,58,64,122,54,107,62,237,158,220,62,42,58,18,63,136,244,43,63,50,85,80,63,41,237,133,63,201,229,159,63,53,94,186,63,34,253,214,63,45,67,236,63,232,106,251,63,245,74,9,64,57,69,23,64,43,135,34,64,233,183,47,64,156,196,60,64,236,81,152,62,123,131,239,62,146,203,255,62,221,181,20,63,14,190,32,63,251,58,48,63,72,80,92,63,165,189,145,63,62,121,184,63,71,3,216,63,197,32,240,63,253,246,5,64,214,86,20,64,249,15,33,64,12,2,47,64,90,100,59,64,1,222,2,62,155,85,191,62,208,179,25,63,102,247,52,63,46,144,80,63,211,77,130,63,108,9,161,63,41,203,176,63,221,36,190,63,200,7,221,63,178,157,255,63,27,13,8,64,88,202,18,64,40,126,36,64,56,103,48,64,191,125,57,64,185,141,6,62,220,104,128,62,177,191,204,62,115,104,17,63,237,13,62,63,146,203,111,63,247,117,144,63,215,163,168,63,1,77,196,63,109,197,222,63,242,65,247,63,80,252,8,64,86,125,22,64,200,152,35,64,98,16,48,64,61,44,60,64,61,155,213,61,124,97,114,62,54,205,219,62,193,57,35,63,96,229,80,63,54,205,123,63,109,197,150,63,174,71,177,63,33,176,202,63,205,204,228,63,244,253,252,63,249,49,10,64,183,98,23,64,91,177,35,64,168,198,47,64,175,37,60,64,209,145,28,62,156,196,128,62,69,216,176,62,229,242,223,62,74,123,51,63,180,200,102,63,240,133,137,63,168,53,173,63,124,242,200,63,117,147,224,63,104,34,0,64,191,14,8,64,70,148,14,64,43,24,29,64,86,125,46,64,236,81,60,64,97,84,18,62,5,197,143,62,37,6,225,62,129,38,34,63,0,145,78,63,176,114,120,63,188,116,147,63,154,153,169,63,44,101,193,63,125,63,221,63,190,193,247,63,207,102,9,64,254,67,22,64,172,139,35,64,169,19,48,64,195,211,59,64,102,102,38,62,245,185,154,62,216,129,243,62,252,169,33,63,132,158,77,63,237,13,126,63,198,109,148,63,222,2,169,63,87,236,191,63,242,176,216,63,190,159,242,63,219,249,6,64,41,92,19,64,126,29,32,64,17,54,44,64,213,120,57,64,196,66,45,62,96,118,175,62,57,214,5,63,185,141,70,63,71,3,120,63,246,40,140,63,231,29,167,63,217,206,183,63,215,163,200,63,247,6,231,63,71,3,248,63,204,93,7,64,7,206,21,64,169,19,32,64,95,7,46,64,79,64,59,64,129,38,66,61,55,26,0,62,185,141,70,62,193,168,196,62,244,108,38,63,72,80,108,63,39,194,142,63,213,120,169,63,79,30,198,63,103,68,225,63,102,136,251,63,252,169,9,64,248,83,23,64,102,136,35,64,208,68,48,64,126,29,60,64,211,222,96,62,32,99,238,62,146,203,63,63,210,0,126,63,120,122,149,63,245,219,159,63,103,213,167,63,66,207,174,63,237,13,182,63,152,221,195,63,72,80,220,63,229,242,255,63,175,37,16,64,105,0,31,64,200,7,45,64,43,135,58,64,176,3,231,61,179,123,114,62,18,165,189,62,131,47,12,63,116,181,69,63,73,46,127,63,57,180,152,63,252,24,179,63,102,247,204,63,127,217,229,63,0,145,254,63,130,226,11,64,225,122,24,64,18,131,36,64,14,190,48,64,170,96,60,64,131,81,9,62,187,184,141,62,121,233,230,62,88,202,34,63,152,76,85,63,186,73,132,63,181,166,153,63,234,149,178,63,236,192,201,63,26,81,226,63,203,161,253,63,160,26,11,64,161,103,23,64,102,136,35,64,240,22,48,64,134,201,60,64,183,98,255,61,83,5,131,62,234,4,180,62,161,248,241,62,64,164,47,63,202,195,114,63,162,180,151,63,229,97,177,63,143,228,202,63,49,8,228,63,141,40,253,63,231,29,11,64,152,221,23,64,230,63,36,64,156,196,48,64,121,88,60,64,58,146,75,62,231,251,169,62,24,149,244,62,154,119,44,63,20,174,87,63,90,100,131,63,230,174,149,63,180,200,174,63,41,237,197,63,248,83,219,63,197,32,248,63,92,143,10,64,234,149,22,64,75,89,34,64,186,73,48,64,16,88,61,64,4,231,12,62,221,36,134,62,17,199,218,62,41,237,29,63,43,135,70,63,138,176,113,63,148,246,142,63,220,104,168,63,140,74,194,63,35,219,217,63,26,81,242,63,17,199,6,64,179,234,19,64,211,222,32,64,177,225,45,64,1,222,58,64,208,68,88,62,18,131,224,62,250,237,27,63,83,5,67,63,138,142,116,63,26,192,147,63,147,24,172,63,157,17,197,63,243,142,219,63,88,168,245,63,77,21,8,64,197,254,22,64,150,33,38,64,94,75,52,64,33,31,60,64,27,158,66,64,204,238,9,62,7,240,86,62,167,121,135,62,41,203,176,62,66,207,6,63,71,114,73,63,0,145,134,63,168,198,163,63,201,118,190,63,179,234,219,63,148,246,246,63,89,134,8,64,77,132,21,64,44,212,34,64,58,146,47,64,179,234,59,64,183,209,160,62,158,239,23,63,105,111,64,63,20,208,84,63,63,87,91,63,244,253,116,63,51,51,131,63,236,81,144,63,54,205,171,63,172,173,208,63,29,201,237,63,18,131,4,64,192,236,18,64,166,155,32,64,146,92,46,64,220,70,59,64,129,4,197,61,172,173,88,62,159,205,202,62,220,104,16,63,189,82,54,63,161,103,99,63,43,24,141,63,138,142,172,63,114,249,199,63,242,176,224,63,67,28,251,63,82,184,10,64,233,183,23,64,243,142,35,64,80,141,47,64,190,193,59,64,16,233,183,61,190,159,26,62,8,172,156,62,244,253,20,63,37,117,82,63,102,247,132,63,216,240,156,63,50,230,182,63,191,125,205,63,233,183,231,63,171,62,255,63,54,205,11,64,229,242,23,64,231,140,36,64,69,216,48,64,52,162,60,64,75,200,7,62,141,40,109,62,46,144,192,62,253,135,4,63,132,158,45,63,23,72,96,63,131,47,140,63,215,163,168,63,151,255,192,63,3,9,218,63,81,218,243,63,207,247,7,64,226,233,21,64,252,24,35,64,64,164,47,64,240,22,60,64,14,45,50,62,2,154,168,62,84,116,4,63,196,177,46,63,235,226,86,63,248,194,132,63,85,48,154,63,135,167,175,63,149,101,200,63,128,72,223,63,140,219,248,63,211,222,8,64,240,22,20,64,119,190,31,64,32,65,45,64,52,128,59,64,250,237,107,62,174,71,193,62,135,22,249,62,91,66,30,63,85,193,72,63,140,185,107,63,153,187,142,63,241,99,164,63,161,103,187,63,71,114,217,63,13,224,245,63,98,16,8,64,103,213,19,64,50,119,33,64,25,115,47,64,204,93,59,64,117,2,26,60,171,207,213,60,179,123,114,187,75,89,134,59,153,187,22,188,224,45,144,187,237,13,190,188,215,52,239,187,117,2,154,187,39,160,9,187,205,204,204,60,104,145,109,189,66,96,101,188,77,21,12,189,142,6,112,189,111,18,3,59,16,233,55,61,182,243,125,60,134,56,86,189,138,142,228,188,216,240,244,60,226,233,149,188,153,187,150,189,1,222,130,189,137,210,222,186,39,160,9,61,122,54,171,60,153,187,150,59,72,80,252,59,179,123,114,188,17,199,58,188,166,155,68,188,127,106,60,60,10,215,163,187,162,69,54,61,82,73,157,59,117,2,154,60,247,117,96,188,111,18,3,188,239,201,195,60,153,187,150,188,98,161,86,189,119,190,159,188,59,112,78,188,30,167,232,60,0,111,129,61,176,3,103,60,7,95,24,188,82,73,29,188,46,144,160,60,127,106,188,60,8,61,27,61,72,80,252,60,129,38,194,60,52,128,183,188,143,194,117,189,190,159,154,189,136,244,219,189,168,87,202,189,181,55,120,189,24,149,212,189,192,236,30,190,80,141,23,190,39,160,137,189,59,112,78,61,222,113,138,61,39,160,9,61,39,160,137,187,152,76,149,61,96,118,207,61,51,196,177,61,196,66,173,61,19,97,195,61,170,241,82,61,208,68,216,187,233,72,174,189,240,167,70,189,69,216,240,60,193,202,33,61,114,138,14,60,36,151,255,59,125,174,54,61,198,109,180,61,39,160,137,61,82,73,29,189,10,215,35,187,231,251,41,61,188,150,16,61,111,18,3,60,195,100,170,59,227,165,155,60,43,24,149,60,101,25,226,59,39,160,137,60,190,48,25,61,179,123,114,59,215,52,239,188,233,183,47,189,254,101,247,60,3,120,139,61,164,223,190,188,56,248,194,188,82,73,157,185,4,231,140,187,124,242,176,59,237,13,62,187,33,31,116,188,74,123,131,61,109,197,126,61,113,172,11,61,237,13,190,188,91,211,60,189,75,89,6,188,55,26,64,189,255,33,125,189,148,135,5,189,163,35,57,189,75,234,132,189,253,135,116,189,83,5,35,189,184,64,2,189,237,13,62,188,224,45,144,58,250,237,107,58,82,73,29,189,82,73,29,189,36,151,127,188,244,253,212,188,52,128,55,186,165,189,65,61,198,220,53,60,5,163,18,189,20,63,70,189,231,29,167,188,237,13,62,187,188,116,19,188,213,120,233,188,131,192,74,189,117,2,26,189,54,205,187,61,33,31,244,61,243,31,210,61,117,147,152,61,120,156,34,61,18,165,61,61,242,65,207,60,10,215,35,59,201,118,62,61,10,215,35,60,130,226,71,61,195,100,42,61,125,174,182,60,25,115,215,60,250,237,235,59,159,171,173,187,70,182,115,61,166,155,196,59,61,44,84,189,0,111,1,189,4,231,140,187,62,232,89,188,164,223,190,188,143,194,245,187,132,158,205,188,28,235,226,60,172,139,219,187,137,210,94,188,23,183,209,185,18,131,192,60,52,128,55,60,43,24,149,188,221,181,4,189,49,8,172,188,66,96,101,187,193,202,33,189,82,73,29,189,111,18,3,58,143,194,117,188,78,209,17,189,169,19,80,60,208,68,88,187,137,210,94,187,158,239,167,60,80,252,152,61,249,15,233,61,59,223,207,61,168,198,203,61,38,228,131,188,188,116,147,187,134,90,83,60,202,84,65,61,31,133,107,61,198,220,181,60,43,24,21,60,179,123,114,59,238,235,64,189,43,246,23,61,208,68,88,60,195,100,170,60,168,87,202,60,91,177,63,60,75,89,134,60,236,81,184,60,95,41,75,60,153,187,22,187,224,45,16,60,153,187,150,187,117,2,154,59,9,249,32,189,250,237,235,58,179,123,114,60,111,18,3,59,224,45,144,59,2,43,135,60,200,152,187,60,195,100,170,188,19,97,67,189,182,243,253,188,75,89,134,188,119,190,31,189,154,119,156,189,61,10,87,189,117,2,26,188,143,194,245,59,231,29,39,188,188,116,147,187,59,112,78,189,5,52,145,189,121,88,168,61,115,104,145,61,86,125,46,61,52,128,183,58,43,246,23,189,10,215,35,189,73,157,128,188,182,243,125,188,187,184,141,188,101,25,98,188,166,155,196,186,172,139,91,60,122,54,43,189,113,172,139,189,23,183,209,188,10,215,163,59,188,116,19,61,151,255,16,61,179,123,242,59,156,51,34,189,18,131,192,188,30,167,232,60,168,87,74,61,218,172,122,60,52,128,55,61,10,215,35,59,130,226,199,187,59,112,206,60,205,204,204,61,139,108,103,62,173,250,92,62,172,173,88,62,64,19,97,62,152,110,82,62,98,16,88,62,146,203,63,62,220,70,67,62,6,18,84,62,246,151,93,62,187,184,77,62,115,215,82,62,99,127,89,62,8,61,91,62,189,82,86,62,51,51,179,61,167,232,200,61,179,12,241,61,63,87,219,61,243,142,211,61,36,151,255,61,98,161,214,61,219,138,253,61,251,203,238,61,59,112,206,61,99,127,217,61,95,41,203,61,58,146,203,61,136,133,218,61,95,152,204,61,252,24,243,61,154,153,153,61,120,156,162,61,12,147,169,61,50,230,174,61,87,236,175,61,120,11,164,61,16,122,182,61,18,20,191,61,130,115,198,61,127,106,188,61,90,100,187,61,160,137,176,61,51,196,177,61,16,122,182,61,13,113,172,61,85,193,168,61,0,0,128,61,201,118,190,61,121,233,166,61,196,177,174,61,16,233,183,61,12,147,169,61,121,88,168,61,53,94,186,61,88,202,178,61,126,140,185,61,14,79,175,61,49,8,172,61,228,131,158,61,156,196,160,61,77,21,140,61,224,156,145,61,204,238,169,62,71,3,216,62,213,231,234,62,115,104,209,62,170,130,209,62,77,132,205,62,88,168,181,62,113,172,171,62,127,217,189,62,86,159,171,62,201,118,190,62,70,37,181,62,206,25,209,62,200,152,219,62,59,223,207,62,80,141,215,62,69,216,112,61,122,54,171,60,75,89,6,188,127,106,60,188,40,126,12,189,146,92,126,189,246,151,93,189,187,184,13,189,187,184,13,189,226,233,21,189,88,57,180,188,135,22,217,188,231,29,39,188,190,48,25,61,218,172,250,60,120,122,37,61,218,172,250,60,188,116,19,60,124,242,176,187,149,101,8,61,117,2,154,59,56,248,194,60,176,3,103,60,2,43,135,60,218,172,250,60,49,8,44,61,184,64,130,60,95,41,75,60,12,147,41,61,0,111,129,60,129,38,194,188,176,3,103,60,8,172,156,61,17,199,186,59,244,253,212,188,86,125,46,189,193,202,33,189,59,112,78,188,141,40,109,189,159,205,42,189,71,255,190,176,220,1,240,254,31,0,130,253,38,3,195,255,220,0,176,0,178,0,236,252,71,254,179,254,152,254,249,254,140,255,0,254,66,38,41,253,200,34,168,4,235,254,244,2,98,253,27,3,201,254,240,0,151,253,93,253,54,252,244,2,89,3,17,2,90,255,162,2,122,3,246,253,69,3,79,0,150,253,228,250,248,201,232,2,46,21,128,10,19,2,142,1,220,5,83,248,47,255,166,254,101,2,99,8,69,39,138,250,189,0,148,255,215,1,78,251,231,3,178,0,250,2,167,253,92,4,252,36,231,254,251,2,76,251,202,252,236,255,96,255,218,252,128,57,243,254,143,0,174,250,236,253,236,252,4,250,107,254,85,0,241,254,161,236,20,1,222,255,228,255,190,255,112,0,68,255,186,253,90,253,128,0,168,2,214,3,84,2,122,47,28,215,89,255,132,254,222,2,216,254,26,1,33,255,170,255,170,254,212,252,2,2,131,1,94,254,148,254,64,251,14,0,117,1,101,1,145,42,227,43,54,253,206,0,150,253,161,253,84,2,190,0,214,2,240,1,212,254,95,0,254,3,103,255,212,0,228,253,252,0,25,1,238,0,22,255,28,0,24,0,184,0,255,127,141,253,57,2,67,1,230,1,32,2,164,254,179,253,228,254,238,0,228,0,219,1,83,0,183,225,182,0,233,2,144,1,135,253,49,255,137,0,126,1,90,0,78,0,203,2,192,1,207,1,169,3,219,39,241,208,101,253,142,254,20,250,152,254,94,0,64,3,3,4,245,3,92,0,186,234,66,3,46,1,252,2,162,255,50,254,159,31,33,4,52,1,133,253,52,1,147,252,78,252,152,253,51,0,66,4,217,203,234,1,205,252,78,59,128,254,155,1,222,253,14,255,204,1,189,254,76,0,21,1,46,6,132,3,161,251,89,1,36,5,114,4,228,7,76,6,108,255,44,3,217,4,146,215,233,218,59,252,187,255,175,7,88,255,128,255,18,4,191,1,235,1,123,255,37,236,62,254,92,255,50,0,70,1,13,1,229,254,226,0,216,255,178,254,146,255,60,0,209,255,169,0,206,35,164,4,82,252,242,255,64,8,26,255,122,2,27,253,42,255,176,254,162,253,30,12,59,0,216,0,13,7,104,251,211,0,248,255,52,2,156,0,251,254,44,1,85,2,174,170,66,0,24,255,6,254,154,251,33,4,91,2,168,5,121,254,249,0,27,219,0,216,182,2,167,0,122,251,123,253,127,254,47,255,74,1,7,2,167,254,168,253,192,0,78,0,27,255,208,0,163,220,129,254,150,41,248,254,84,0,39,1,108,255,87,0,12,5,1,1,56,4,204,253,165,246,80,251,28,254,208,255,255,253,129,254,245,255,252,253,52,188,108,251,38,255,124,0,185,254,31,0,72,1,176,255,231,0,58,0,73,252,48,2,11,254,120,254,64,119,200,255,126,1,253,253,206,255,101,255,82,1,0,0,98,254,125,252,95,0,11,0,122,1,162,254,203,1,161,2,76,0,86,0,123,1,222,125,143,0,208,255,169,1,118,254,196,255,164,254,194,1,23,254,220,0,56,0,105,4,131,255,66,1,168,0,240,255,66,1,219,254,38,1,218,255,72,1,141,0,180,2,174,255,96,255,0,128,116,255,249,249,55,4,28,4,100,252,199,253,168,0,10,249,47,3,194,2,218,250,148,242,44,11,170,42,236,0,71,40,114,3,137,248,11,0,102,6,67,255,245,0,166,252,52,43,198,252,184,2,224,0,171,6,230,6,216,1,80,42,247,254,95,255,163,0,222,1,254,254,228,254,170,255,240,1,169,1,185,255,152,215,115,255,169,1,79,250,121,4,193,255,55,253,185,253,185,254,116,2,112,1,238,255,46,249,243,253,174,254,146,255,153,254,92,0,23,255,176,172,204,1,237,254,158,255,198,255,51,0,208,0,56,0,135,251,205,255,14,255,65,0,76,0,214,0,141,0,28,0,170,255,26,0,157,3,193,0,252,38,186,254,78,44,176,0,234,253,209,254,130,0,217,249,189,0,16,254,69,253,125,1,155,1,132,2,229,0,109,255,182,2,50,248,11,2,216,249,92,31,111,215,124,248,150,4,96,2,98,9,63,2,39,249,181,1,208,252,243,4,147,0,168,5,154,253,97,3,52,4,100,255,136,19,228,7,229,7,43,40,52,254,179,246,102,243,105,240,40,19,228,254,105,0,244,254,25,4,203,0,122,253,220,2,90,25,128,255,164,3,10,0,158,252,74,0,192,255,66,3,204,0,159,0,94,255,86,255,146,255,20,143,52,0,0,254,184,255,71,1,103,2,22,2,28,254,131,0,250,254,31,0,105,254,28,1,33,0,110,43,86,255,62,1,48,50,154,251,109,253,244,1,54,1,109,254,22,255,237,0,224,253,208,4,13,255,102,251,59,252,139,255,108,0,232,250,208,45,50,247,207,4,203,251,120,255,136,253,153,255,0,255,148,249,212,254,144,6,105,251,68,252,213,255,182,6,175,0,144,0,19,1,222,252,33,255,92,4,65,1,153,252,106,251,105,251,240,3,255,0,196,121,28,0,147,253,34,255,71,207,13,213,56,253,247,0,226,6,162,1,75,255,90,0,92,0,106,254,77,254,151,255,172,253,214,8,140,255,218,249,182,242,140,26,8,31,205,3,155,245,212,8,109,2,184,228,126,1,161,250,212,245,14,6,83,250,109,4,198,3,147,1,28,1,184,255,220,255,174,0,201,1,166,255,38,0,75,254,36,254,142,254,213,1,255,127,245,254,94,1,182,2,87,255,242,252,62,8,148,253,242,252,99,253,178,230,54,41,34,243,229,1,177,0,41,2,96,243,92,6,31,9,154,252,152,254,168,251,149,8,38,254,7,236,18,13,110,3,54,2,17,241,105,251,101,1,13,41,53,4,254,253,244,3,38,0,59,0,157,2,142,2,93,1,234,251,99,1,192,0,57,0,95,0,93,46,66,253,217,39,204,0,45,0,160,253,68,254,153,3,210,251,196,254,6,5,250,245,234,7,129,255,177,255,70,252,93,0,248,250,216,216,181,2,116,34,146,254,172,255,22,231,146,6,141,253,130,1,254,0,247,1,104,255,176,254,38,0,171,254,117,1,171,255,64,4,85,249,119,0,14,255,242,0,186,254,94,255,109,0,70,0,142,255,193,252,233,254,0,128,62,0,58,0,214,0,136,0,194,0,153,255,193,216,158,253,91,0,202,254,27,47,90,1,112,253,218,3,222,1,108,1,241,6,83,255,105,253,153,255,243,3,139,254,200,0,96,6,214,204,67,14,162,1,222,1,68,0,39,255,169,0,78,0,104,251,89,251,128,249,184,254,152,0,227,251,35,2,15,2,61,215,80,255,123,43,119,255,220,255,38,4,33,0,71,0,38,253,32,8,13,8,140,254,131,253,172,255,232,2,109,0,155,254,38,2,53,1,17,255,122,255,135,0,19,176,79,255,78,253,24,254,220,255,97,254,19,1,64,0,122,1,242,43,222,252,199,253,56,255,219,5,47,51,190,251,81,255,189,0,94,255,17,253,28,4,75,252,158,255,225,4,223,1,232,250,221,12,3,3,106,6,131,254,143,5,210,8,160,4,198,18,58,213,223,240,92,1,209,252,61,235,22,243,21,243,33,9,8,3,131,255,208,255,77,254,101,255,226,255,38,1,116,0,96,0,209,255,254,3,121,254,73,255,252,0,58,3,224,255,37,1,167,250,134,71,110,255,239,0,246,254,34,0,102,255,64,253,14,254,121,255,228,0,205,253,46,255,98,255,254,253,55,255,197,253,171,254,84,254,74,0,104,255,41,1,94,255,124,253,40,255,4,255,14,202,193,2,208,1,105,82,74,0,87,255,24,3,12,0,131,0,64,1,114,254,66,254,44,0,150,254,132,1,234,255,243,255,47,255,181,4,125,36,78,2,85,253,161,254,177,0,174,249,239,1,14,0,193,254,243,2,88,44,249,0,35,252,38,6,102,252,148,254,110,1,148,215,81,1,210,253,132,255,24,47,102,0,34,3,220,253,2,255,252,5,7,0,230,254,53,254,185,252,171,0,163,238,182,249,21,250,219,255,202,3,50,1,143,252,18,255,102,255,198,255,27,0,179,1,166,0,59,2,225,0,180,252,17,217,64,255,150,252,53,254,253,250,105,250,16,6,218,255,82,253,49,255,197,2,206,46,129,254,130,7,164,255,196,255,196,2,124,252,99,3,39,0,190,5,5,2,74,255,56,254,90,0,2,4,64,255,4,39,174,3,48,0,21,3,213,3,74,0,76,253,253,250,215,4,89,6,159,251,226,254,165,251,38,1,172,51,212,3,56,1,23,253,191,45,31,4,28,4,117,252,201,0,176,2,108,1,147,4,96,0,177,253,43,252,10,255,107,3,160,254,165,2,113,3,115,254,90,50,10,0,0,0,156,1,76,0,208,1,19,1,47,253,228,255,59,255,104,0,18,255,140,254,240,254,234,1,146,5,195,3,80,204,90,251,22,3,161,0,191,254,114,4,134,2,103,1,73,255,109,253,127,255,92,1,81,167,248,3,109,255,26,0,176,255,36,1,54,1,1,255,49,1,69,0,169,97,240,255,100,253,210,0,17,0,244,255,45,0,10,253,180,255,224,253,142,252,61,0,26,0,110,249,140,221,154,0,1,210,64,0,216,1,48,254,245,0,222,1,232,249,101,3,144,8,98,0,133,2,161,255,103,219,174,253,133,253,132,212,132,3,70,6,120,252,73,3,10,10,72,250,193,3,32,4,157,2,205,1,235,12,99,255,124,253,121,0,74,253,170,0,116,0,137,1,227,5,23,255,114,253,94,255,108,0,98,0,63,68,91,1,176,211,67,253,228,254,10,255,175,254,145,248,14,0,137,38,197,1,202,211,178,241,69,9,82,4,112,250,83,249,73,245,164,252,0,43,43,6,218,255,155,250,211,1,25,254,230,250,113,1,170,1,88,254,128,0,54,4,61,4,171,2,8,49,24,3,72,255,234,254,186,0,214,7,107,1,54,1,181,255,94,3,121,1,234,1,0,255,224,249,132,255,223,213,80,250,244,253,21,251,5,2,204,248,146,3,1,3,177,3,227,2,227,251,77,253,177,0,96,0,210,251,94,255,61,253,174,253,99,217,103,0,196,1,34,253,138,229,15,253,192,0,88,0,220,254,201,0,236,253,231,0,231,254,77,253,48,251,24,249,15,253,113,1,20,6,117,255,156,2,173,3,8,1,132,40,12,38,208,3,215,9,168,255,173,3,190,1,126,255,83,8,137,253,69,1,29,1,176,0,20,255,134,253,165,255,112,0,255,127,23,255,42,253,156,0,113,3,39,255,15,254,20,255,174,251,27,1,164,0,184,254,139,253,206,148,239,255,176,0,174,254,64,255,26,2,251,252,122,2,76,255,104,3,66,255,238,253,74,2,82,27,244,11,176,254,224,2,12,251,138,251,187,255,177,250,233,251,49,252,170,255,201,48,138,4,3,254,34,254,205,2,254,253,10,254,37,249,56,43,244,29,84,1,230,0,129,255,210,5,193,255,168,2,215,254,125,0,164,6,201,9,3,0,5,248,255,0,11,6,57,2,77,246,221,2,128,252,113,3,172,18,8,6,126,203,48,5,145,7,160,238,128,254,237,2,173,0,182,28,156,0,112,255,52,0,241,253,222,255,253,255,83,255,118,0,240,253,181,255,39,0,42,0,150,252,212,198,218,1,99,254,150,255,141,255,81,254,54,0,210,2,156,0,44,254,113,1,149,0,188,255,233,252,38,5,102,8,69,0,198,1,88,74,3,0,111,0,216,255,93,1,88,0,129,1,202,255,117,254,32,255,249,253,0,0,37,255,179,0,3,255,141,211,253,42,65,7,130,255,8,255,48,1,152,253,95,1,68,1,244,1,214,5,146,250,45,9,23,251,166,251,43,255,220,31,238,247,18,38,251,2,176,252,93,1,249,255,211,2,58,252,213,1,91,0,4,255,56,5,67,2,24,7,92,5,83,252,108,1,20,1,223,255,7,0,87,254,79,254,235,255,34,2,97,253,217,133,98,252,101,0,147,0,46,1,216,253,224,0,56,2,174,246,7,2,54,254,115,51,72,250,137,4,127,2,246,255,147,252,75,1,44,13,184,255,38,20,62,253,138,3,108,10,240,3,84,245,192,12,105,0,118,2,161,2,100,248,60,255,182,204,190,6,225,2,221,18,93,0,142,2,127,8,18,15,251,255,245,0,41,254,113,1,59,21,100,1,122,205,61,0,192,7,207,3,194,2,106,246,126,253,163,255,244,252,69,254,49,250,52,254,88,4,129,1,53,1,228,215,197,0,100,249,178,248,50,0,114,248,4,21,87,251,7,3,19,254,32,252,211,253,136,11,152,1,8,18,195,250,22,42,185,20,86,3,215,11,67,0,105,2,132,9,232,247,67,250,36,3,190,253,243,0,8,1,190,35,200,0,1,42,162,254,182,0,204,255,106,254,252,1,7,253,95,255,138,251,25,0,228,1,127,0,126,0,221,1,171,254,110,0,115,1,255,127,66,4,166,2,175,0,146,0,252,3,127,252,110,3,119,255,5,254,234,253,146,2,166,2,249,1,15,253,49,255,135,1,60,0,17,165,252,252,213,250,214,249,253,255,196,0,19,253,220,0,30,254,239,252,200,1,38,0,10,4,189,253,198,255,253,249,165,1,22,253,238,0,251,5,42,83,74,2,71,254,236,254,232,5,41,2,129,250,236,254,60,0,212,251,43,1,138,2,231,255,46,49,10,8,157,3,217,254,48,249,32,20,71,19,93,254,16,1,129,254,103,253,62,255,1,255,62,2,245,254,29,2,7,4,230,254,120,253,110,2,72,250,228,255,243,254,235,253,176,255,36,254,26,1,176,254,125,0,104,0,208,1,12,221,81,3,171,0,238,5,216,254,51,0,229,255,25,12,17,236,100,254,18,254,62,255,55,253,3,251,102,0,204,6,67,254,104,13,156,4,4,25,100,213,54,252,31,0,142,0,14,255,177,255,178,255,180,255,124,0,7,4,83,0,201,255,242,5,155,253,0,128,118,254,26,5,31,1,189,2,139,237,195,251,159,1,134,255,230,253,93,253,82,0,116,0,40,253,157,255,244,1,147,2,183,254,36,1,150,255,27,36,172,254,99,209,14,254,85,1,199,252,111,254,110,254,142,0,243,255,203,254,46,253,141,0,0,0,87,253,238,1,159,2,70,251,186,5,201,250,223,45,232,254,80,6,39,211,52,0,61,1,134,3,115,253,57,252,18,254,94,255,83,253,74,254,244,2,81,0,49,255,65,2,204,226,159,254,150,3,225,255,149,255,181,0,11,2,210,255,16,253,117,1,116,252,240,248,108,252,120,2,228,5,221,255,225,228,64,0,16,51,113,253,163,0,197,4,137,249,248,245,66,254,111,254,214,1,146,253,80,252,160,14,54,254,203,0,125,0,238,0,76,20,21,0,161,47,71,4,67,4,237,252,123,251,44,252,126,251,27,30,227,255,106,0,202,4,184,2,50,252,133,254,231,253,56,0,95,0,35,254,240,253,19,212,10,252,140,0,124,1,89,0,28,2,84,0,149,253,190,254,196,253,16,255,230,255,215,2,54,1,43,0,234,252,225,255,2,161,110,0,106,2,44,0,148,255,89,0,65,255,223,255,55,255,22,254,43,0,120,255,86,5,254,255,162,0,192,252,213,1,116,255,234,254,88,2,97,194,93,249,184,0,33,7,216,2,245,248,148,252,152,0,60,0,211,252,247,11,95,252,204,3,230,254,206,2,234,32,136,252,103,5,104,253,59,2,190,3,214,3,236,0,220,253,66,0,106,7,238,254,219,41,99,249,79,0,26,251,40,1,97,2,170,2,206,251,16,1,157,0,228,181,121,1,244,255,182,1,24,2,96,253,36,1,207,2,48,254,82,4,216,254,212,252,6,0,178,254,67,0,166,2,126,1,166,2,45,1,107,169,184,0,80,0,97,253,170,255,139,0,214,254,160,1,158,253,33,4,15,0,26,255,120,1,0,253,131,2,58,0,27,0,178,0,26,253,60,0,12,254,229,1,45,178,8,252,205,2,102,4,31,1,123,8,124,254,173,5,235,255,244,254,237,249,249,254,201,2,173,6,177,251,53,214,252,6,248,255,11,254,132,252,212,44,42], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+286737);
/* memory initializer */ allocate([248,210,1,134,31,226,254,163,0,35,0,238,1,76,0,148,5,55,247,100,0,250,249,63,1,42,255,67,253,146,39,218,254,70,209,112,253,227,0,0,254,10,252,213,0,168,253,48,253,63,0,76,255,6,5,39,4,57,218,224,251,245,4,204,5,20,0,22,3,29,0,78,217,139,254,96,2,105,1,109,253,43,0,246,251,160,255,37,255,191,255,136,1,97,179,48,254,212,0,52,3,74,255,29,255,207,1,45,1,130,2,37,255,130,1,110,251,108,0,49,234,166,1,5,254,18,2,222,251,125,255,20,0,105,199,101,0,242,255,97,254,32,0,147,251,107,252,176,3,192,252,68,2,205,9,65,252,214,1,160,4,176,1,42,251,193,0,186,203,25,9,201,7,11,4,80,0,67,12,215,253,147,6,134,1,200,5,130,2,52,2,91,212,166,1,40,252,209,253,82,253,168,0,247,252,214,252,2,251,85,254,160,255,155,6,244,113,77,254,206,255,56,252,221,0,173,2,52,0,139,254,13,2,205,253,94,1,16,2,49,1,193,2,57,1,100,2,2,255,36,255,154,249,100,255,24,0,109,0,131,252,71,253,245,0,19,10,155,2,114,255,27,48,74,253,215,14,5,0,74,254,39,254,86,254,59,0,251,234,200,255,200,0,232,254,236,254,96,0,179,1,217,2,80,1,123,0,54,253,140,254,191,206,235,208,18,255,223,0,14,255,230,0,151,2,123,253,98,0,3,2,3,0,212,2,254,1,208,255,66,4,83,255,96,236,24,2,123,2,113,255,190,2,172,0,60,255,164,0,190,0,104,255,76,255,238,0,114,255,183,254,191,0,216,254,96,254,255,45,16,254,161,255,136,1,226,3,184,253,99,252,61,252,30,1,54,254,32,12,58,248,200,3,106,250,230,3,105,254,69,111,180,1,42,0,122,1,46,255,148,0,107,255,236,253,94,0,140,253,186,0,70,255,238,254,250,0,196,254,164,191,78,211,207,254,60,255,1,253,137,247,255,255,122,1,104,247,22,0,101,9,176,3,6,249,218,252,157,2,184,3,195,40,64,245,167,249,36,4,230,207,3,5,234,0,155,246,115,2,30,3,222,251,55,1,22,245,101,245,73,0,42,255,45,3,67,245,236,41,67,254,141,208,53,246,76,248,116,6,128,248,215,0,42,1,82,4,58,3,235,226,69,0,113,249,93,253,225,4,164,5,171,251,208,255,84,250,192,246,218,11,20,254,12,51,55,1,138,242,70,1,110,250,80,9,158,247,100,11,253,34,60,255,164,8,191,1,239,6,47,10,70,209,234,254,239,16,49,249,135,0,212,0,215,255,164,255,164,0,245,255,8,254,60,3,249,253,190,252,251,0,127,7,250,2,85,97,76,255,124,255,182,254,138,0,225,0,14,4,3,0,138,125,124,254,208,0,130,253,198,250,91,255,200,0,26,255,225,0,247,252,34,247,6,32,71,2,106,15,2,250,130,6,248,251,120,44,202,0,30,0,198,10,7,254,1,245,241,4,64,0,239,255,152,254,124,2,134,0,246,1,3,1,104,3,12,146,234,251,164,254,170,255,29,253,55,0,192,1,168,0,112,253,70,4,206,251,200,17,190,252,248,8,52,9,196,253,131,248,227,42,55,12,204,255,15,217,241,253,202,7,166,249,17,4,238,12,241,246,184,8,76,211,160,246,4,249,26,251,145,20,126,12,176,27,170,17,12,5,65,255,242,193,227,10,22,0,182,249,184,0,124,1,9,2,80,1,98,255,109,3,212,1,115,25,12,253,148,234,100,0,48,254,28,36,90,245,148,249,75,245,14,235,157,249,126,3,199,248,134,39,64,243,136,238,231,4,13,242,75,254,230,251,225,5,86,212,63,255,7,211,232,255,207,2,212,0,49,248,43,253,246,1,116,251,220,251,150,253,165,255,30,253,228,2,50,247,229,237,140,10,95,0,171,252,69,4,156,210,56,252,20,37,231,255,104,253,111,1,81,4,125,21,144,255,92,29,46,40,53,3,28,254,204,0,145,5,93,242,46,251,112,239,223,14,61,11,32,7,167,1,210,1,84,254,179,252,170,255,220,51,244,32,78,253,80,253,62,2,198,244,216,253,188,17,158,3,189,234,117,2,117,254,42,8,196,187,79,1,115,9,251,4,90,241,203,249,214,1,57,249,74,1,228,9,70,4,182,231,140,252,20,255,50,218,39,217,65,254,30,2,40,253,126,248,108,0,111,247,78,252,198,12,73,8,64,10,242,3,10,214,154,255,253,10,242,204,243,5,4,250,245,250,164,1,49,248,6,1,86,251,126,239,86,250,237,254,83,0,144,4,54,6,19,250,86,254,112,250,152,0,164,2,199,44,56,3,212,247,174,251,18,211,233,246,234,254,37,10,245,255,25,3,138,255,137,1,68,2,13,254,25,253,179,255,85,254,104,254,76,253,245,141,9,255,34,248,102,252,97,0,69,2,93,21,117,250,70,253,210,5,26,241,254,244,8,202,168,2,11,14,8,6,62,9,54,244,175,9,67,1,90,1,252,254,81,1,170,10,182,47,162,251,219,211,44,244,212,0,215,255,228,6,188,253,41,2,78,21,248,255,146,254,78,251,133,3,228,252,98,223,28,17,84,250,212,254,128,4,242,11,108,242,229,255,246,50,34,0,82,211,215,250,8,250,181,51,114,0,210,9,208,3,197,253,88,251,254,247,157,249,60,252,160,1,233,255,197,251,247,255,255,127,220,253,44,2,63,251,200,255,69,1,24,4,111,255,202,0,240,5,44,0,146,1,144,1,157,253,219,33,197,251,44,4,200,4,1,209,14,9,171,251,242,4,26,5,65,18,29,1,29,234,19,6,156,255,221,251,147,1,43,255,88,253,120,252,179,44,69,2,128,47,130,253,53,1,191,255,165,3,24,247,166,7,82,10,16,7,9,31,216,247,82,3,84,254,17,3,35,252,210,4,123,250,233,2,252,213,151,7,72,255,180,12,160,255,164,3,104,253,166,51,62,44,162,250,185,254,109,7,45,4,252,249,104,0,117,255,120,252,106,0,128,6,157,3,46,0,97,1,189,252,214,253,82,6,68,252,75,254,41,253,181,242,14,4,200,3,180,1,46,0,223,238,84,1,249,189,14,254,47,0,214,253,113,254,142,246,165,254,102,1,240,90,234,0,84,255,174,254,34,4,132,247,255,255,174,6,192,255,185,253,80,247,244,252,131,253,172,13,108,0,21,4,60,3,40,253,250,36,73,246,27,206,132,7,122,251,208,0,49,0,136,0,23,47,42,0,155,250,137,254,242,210,7,255,66,6,228,3,204,0,58,253,153,18,1,254,111,194,166,0,96,251,64,255,50,0,151,255,122,3,162,218,14,8,0,250,133,0,71,255,125,253,84,255,130,252,157,254,240,255,141,250,30,2,112,8,31,254,176,251,231,252,5,2,26,176,186,2,75,255,121,255,78,254,141,6,75,255,97,254,30,253,218,249,128,6,22,201,85,2,190,207,52,254,199,254,188,6,82,253,85,0,118,251,120,253,97,3,165,0,31,255,101,248,2,11,246,252,86,240,146,1,174,2,162,43,180,254,96,40,11,253,186,18,156,8,35,254,220,254,146,254,220,32,84,246,238,1,254,1,18,41,1,3,130,2,71,254,55,4,42,27,150,16,32,247,222,254,32,255,32,5,142,1,0,6,76,253,74,1,157,0,78,252,156,255,218,248,214,0,204,155,102,5,212,248,72,254,110,0,6,254,74,254,190,246,126,0,50,2,69,242,246,3,78,33,151,249,67,246,59,17,6,220,62,8,113,2,114,0,67,1,146,9,103,9,170,2,207,7,48,219,176,9,69,0,213,247,187,209,156,241,83,254,170,249,105,252,250,253,70,0,170,5,61,242,6,20,74,22,85,250,73,10,52,3,52,255,74,44,178,224,241,2,153,255,34,1,101,252,128,5,42,1,86,248,137,252,219,37,170,250,216,212,201,255,33,255,240,251,93,255,132,0,164,2,8,253,126,19,202,254,186,219,133,246,106,56,94,254,222,252,153,254,189,254,61,11,46,255,100,250,38,6,74,251,9,1,101,255,31,255,0,128,91,1,222,0,115,251,200,0,156,3,111,4,181,252,190,255,169,254,178,254,143,255,209,0,14,0,53,255,190,4,128,252,142,3,40,250,39,7,103,225,183,252,43,215,69,6,190,222,35,254,208,255,15,255,198,255,0,128,213,0,108,0,194,1,131,4,226,255,89,0,240,0,0,253,52,5,34,1,159,250,183,3,74,2,21,221,18,5,240,1,193,2,131,249,6,7,142,248,71,247,76,249,38,252,100,247,131,251,126,10,130,33,255,127,133,2,107,253,121,255,2,3,80,254,218,253,127,254,240,254,113,2,210,4,39,253,19,0,217,6,228,254,150,255,113,253,238,2,70,254,103,90,184,254,248,253,6,254,22,3,232,251,38,253,41,254,74,254,227,1,138,254,171,3,30,255,115,254,175,252,234,208,252,252,216,255,0,210,232,0,228,253,63,246,89,253,81,1,77,5,202,1,171,254,138,226,233,3,236,1,96,254,40,250,250,220,86,38,40,249,94,253,222,9,224,253,172,244,218,250,214,249,18,255,75,0,173,43,214,6,146,243,52,2,198,253,16,2,236,3,146,0,120,4,6,29,158,0,52,37,220,255,172,254,71,254,84,2,133,249,140,5,82,253,220,255,172,253,167,8,241,250,246,178,155,247,234,251,221,246,114,251,241,11,142,254,212,253,223,255,190,254,4,1,233,255,150,255,189,254,147,0,199,255,179,0,202,1,172,2,253,250,227,4,207,4,140,183,255,253,32,254,73,253,81,2,0,12,168,7,66,1,66,253,237,251,224,253,117,23,98,5,100,0,31,255,176,252,242,250,238,242,60,3,206,245,62,244,151,37,207,250,164,7,182,251,110,241,113,4,125,48,20,251,153,9,164,213,168,26,63,239,115,253,210,254,193,238,138,2,108,249,241,23,142,254,116,253,83,243,39,254,106,255,54,244,72,7,22,251,160,3,181,246,115,56,137,255,234,8,8,255,67,12,102,25,222,16,166,8,165,249,126,0,90,254,70,1,146,253,210,254,252,125,244,254,200,1,252,254,252,254,56,252,135,1,15,254,152,0,228,6,172,214,143,254,21,1,70,0,175,204,166,251,169,251,208,1,218,8,104,244,216,2,64,251,190,6,20,4,88,1,204,191,22,6,106,12,217,253,92,2,186,1,133,252,98,37,60,6,227,253,122,247,218,2,118,252,242,0,167,3,140,255,203,255,220,158,224,253,241,252,97,0,112,252,78,251,146,253,109,255,41,255,150,254,240,255,246,253,98,249,154,254,44,253,68,10,183,1,70,185,226,249,232,11,37,16,42,251,95,243,150,251,188,244,54,245,7,4,243,251,63,0,85,247,205,41,18,250,174,215,145,5,24,3,228,248,124,1,247,252,55,244,251,5,228,251,93,242,61,4,84,254,3,253,143,255,42,0,247,254,109,1,99,0,165,252,35,0,98,2,44,0,17,254,6,1,153,6,34,8,101,84,156,1,51,253,117,251,43,243,58,236,209,249,87,2,235,254,194,255,103,2,126,23,11,249,209,1,224,253,222,200,13,44,236,255,184,2,151,2,132,4,16,255,119,2,14,245,77,1,16,246,164,249,7,3,64,252,215,253,240,1,134,254,14,2,91,254,86,254,34,1,43,2,147,1,134,1,30,132,25,0,193,1,142,2,178,254,219,250,165,0,240,1,18,6,168,255,247,252,114,2,25,250,196,220,67,249,161,49,226,252,40,251,195,0,140,7,191,252,85,252,43,0,182,0,243,9,15,19,18,36,114,1,10,8,179,225,32,2,82,4,108,253,34,2,255,38,225,0,124,0,184,3,151,247,60,249,200,10,10,251,80,255,6,13,177,229,242,253,235,40,141,253,155,30,41,247,219,1,219,2,140,3,72,32,69,6,64,255,162,19,110,9,103,20,83,2,69,4,41,9,228,252,215,33,4,4,252,31,71,255,30,250,28,244,156,255,230,248,31,231,86,255,192,6,223,219,118,3,193,247,163,254,134,251,79,8,102,45,149,224,64,11,167,8,157,6,1,247,162,6,97,4,9,242,97,252,52,253,148,7,210,9,104,210,83,6,148,3,249,255,183,253,252,1,220,250,52,252,10,3,46,38,178,247,64,9,200,255,60,26,145,4,184,241,206,250,58,37,130,208,164,4,94,211,159,254,177,3,107,248,214,6,194,3,147,251,1,7,14,9,175,245,85,4,165,3,36,3,249,1,60,0,150,249,66,247,232,246,234,249,224,249,229,255,184,3,4,0,96,5,162,252,28,184,220,248,11,16,58,254,52,0,78,251,126,4,174,2,98,248,15,254,125,213,144,1,90,254,198,6,202,255,157,43,19,243,2,25,147,252,1,178,112,254,106,6,25,5,128,246,213,243,119,1,58,15,20,7,71,235,78,252,181,6,11,253,250,12,126,0,235,2,44,7,229,38,112,7,146,2,243,50,13,249,163,2,204,2,59,254,158,2,220,249,210,0,3,250,123,255,38,1,34,2,236,161,244,251,27,254,139,255,72,255,144,253,17,1,123,252,98,3,97,2,161,251,28,0,250,0,13,0,70,0,154,4,114,3,136,253,136,171,197,250,158,3,234,248,1,251,76,7,75,255,127,1,89,253,210,251,227,19,124,4,10,4,96,8,37,245,30,241,184,17,177,6,235,3,10,52,50,11,111,243,204,9,43,17,224,1,14,0,167,0,251,2,222,255,10,4,194,250,187,250,156,255,31,255,208,1,110,252,133,250,197,248,215,92,2,3,55,254,255,254,208,251,177,4,71,2,197,255,67,10,189,5,249,255,134,210,24,13,21,252,250,255,68,45,201,254,125,246,124,247,208,246,160,7,156,21,153,7,113,28,248,1,106,46,165,253,45,0,42,0,140,250,165,251,239,251,219,251,54,2,83,245,3,253,175,2,118,0,106,251,68,176,12,255,38,252,105,255,72,11,78,4,233,250,121,255,17,2,162,4,164,51,73,255,138,3,143,239,153,238,199,8,246,0,182,230,234,10,170,5,161,230,229,248,86,2,74,254,244,0,216,251,95,253,96,253,229,249,31,2,26,247,241,243,213,252,74,7,80,0,213,181,86,253,57,2,217,253,2,2,220,26,158,29,71,3,65,240,55,3,38,9,236,250,156,4,190,2,72,216,91,248,229,1,138,254,105,255,198,212,51,254,232,205,59,251,1,5,50,253,220,7,74,1,223,254,25,254,49,255,46,253,138,1,156,0,25,248,2,213,139,254,252,255,18,255,85,41,223,3,44,251,210,252,41,2,15,5,35,247,223,10,75,248,169,2,31,38,90,14,112,249,170,208,196,250,188,246,224,254,95,8,184,254,41,3,56,1,246,7,224,2,246,255,140,3,201,211,74,0,218,24,158,251,10,6,72,255,94,6,197,248,161,247,24,4,154,34,50,254,198,230,252,249,43,3,130,0,42,242,72,215,137,36,132,1,144,4,251,248,4,7,201,239,231,246,1,0,240,254,78,3,126,253,248,0,136,251,121,217,108,249,66,255,187,29,205,239,76,253,234,20,197,246,97,2,194,236,94,12,46,8,89,3,143,254,118,0,213,2,125,252,167,253,250,255,44,2,228,128,182,3,34,254,245,2,136,0,208,253,14,253,50,2,64,254,223,0,64,253,104,2,109,1,82,88,167,4,16,251,162,255,159,3,218,254,10,251,240,255,40,246,22,248,164,1,35,230,8,254,194,37,196,1,133,254,160,248,24,2,137,4,51,244,97,2,230,236,25,255,86,15,81,252,255,127,153,253,44,1,102,3,26,253,173,1,214,255,155,0,36,4,124,252,165,254,34,0,235,1,215,241,7,250,191,39,178,0,254,224,106,254,92,6,150,254,84,227,79,254,233,1,56,2,162,2,24,2,186,244,26,232,240,255,237,253,182,0,218,5,158,239,206,254,63,0,107,250,85,4,119,2,110,215,240,255,206,232,204,255,142,41,231,252,35,0,150,252,97,6,4,255,197,2,226,254,244,252,20,67,224,255,144,3,137,0,108,249,221,10,251,233,82,1,209,42,121,5,176,0,98,7,51,2,141,254,66,2,21,255,142,252,152,253,177,253,96,253,203,252,162,47,149,3,10,3,85,254,102,1,125,250,240,7,164,250,99,7,8,249,38,7,240,248,48,254,149,54,224,7,158,33,110,252,95,227,195,248,189,245,171,8,68,10,113,8,137,8,110,9,153,34,239,254,248,3,205,8,46,4,139,3,111,1,82,254,62,2,15,4,93,0,170,0,255,0,245,254,38,2,100,253,31,1,35,7,121,77,244,0,109,241,4,0,117,83,129,255,100,1,131,2,224,7,218,12,218,4,46,0,34,253,6,247,196,254,38,230,216,254,71,250,145,2,85,250,213,1,212,0,7,11,13,245,170,209,163,3,44,0,148,2,40,6,56,7,223,214,253,10,117,251,252,254,61,255,192,63,137,242,250,254,180,255,73,254,97,242,12,5,2,13,152,253,197,5,108,7,139,34,81,0,178,252,189,26,161,255,144,255,25,255,129,0,70,27,165,0,213,243,152,9,240,7,169,47,187,10,155,6,40,253,113,248,17,255,200,3,218,60,44,247,235,248,184,1,140,8,251,240,254,4,120,255,148,250,86,225,50,254,105,11,52,249,120,255,164,0,103,0,50,255,255,127,53,254,225,4,224,2,178,253,227,252,116,2,100,2,71,1,140,1,40,2,128,255,180,255,254,254,211,253,173,1,170,0,20,2,165,254,169,0,175,253,159,110,135,253,197,250,27,252,254,254,68,1,116,2,182,12,162,251,198,34,193,255,154,18,252,244,125,9,52,3,210,255,10,235,111,247,211,220,232,250,171,253,97,216,43,2,72,244,38,1,215,249,153,252,116,255,214,2,116,14,78,247,135,3,3,255,90,40,126,244,144,2,213,2,100,253,104,252,117,6,32,5,87,6,130,251,62,209,109,8,180,17,172,254,56,222,152,253,107,250,44,252,226,255,135,2,38,254,186,1,234,19,188,0,22,251,20,224,81,213,145,239,144,255,197,9,87,243,99,248,159,0,243,253,66,4,164,1,178,40,135,209,48,4,178,255,252,251,39,13,169,245,93,13,229,7,54,9,51,252,16,1,7,109,216,1,110,254,117,5,97,252,248,251,6,251,80,3,221,0,71,245,58,253,76,253,103,254,130,7,142,0,82,2,29,4,170,211,233,252,183,14,33,6,29,2,145,46,134,0,112,1,76,252,127,245,128,3,87,251,166,4,66,33,156,5,249,3,87,2,226,242,162,15,136,50,93,253,20,4,70,251,40,1,171,251,200,7,2,5,6,3,210,204,160,253,119,212,134,0,22,1,176,3,136,252,94,1,218,249,189,0,18,246,148,13,54,244,40,13,168,219,209,248,21,2,254,255,33,4,174,2,213,209,134,251,51,252,58,6,198,13,182,244,8,250,161,13,37,254,253,254,118,218,37,254,40,252,25,242,26,253,152,1,126,255,13,247,131,3,145,47,114,248,94,255,90,243,74,6,228,21,211,5,240,247,41,5,226,244,65,244,149,248,128,252,44,2,177,7,79,247,83,72,60,16,53,5,161,13,136,247,105,7,96,250,22,250,243,201,249,3,189,18,197,1,203,247,90,229,155,3,185,0,242,2,55,255,201,239,126,0,231,252,75,254,170,9,190,16,251,230,167,15,148,249,11,253,206,204,156,9,174,248,181,248,181,251,230,235,129,11,114,8,181,238,156,6,251,2,220,6,203,252,66,0,164,254,209,7,190,2,22,4,171,250,198,253,49,4,143,127,247,255,194,1,7,253,140,3,56,255,196,253,230,250,29,10,102,9,134,7,236,6,34,43,59,248,74,15,88,251,25,7,66,210,169,11,130,244,68,61,127,7,101,253,13,251,92,20,188,1,96,3,252,240,182,1,178,246,206,3,215,3,137,252,202,252,185,0,245,0,136,243,6,4,161,5,8,146,200,245,132,254,44,1,198,7,162,255,25,252,29,1,41,2,59,8,192,3,165,252,233,3,160,249,160,8,234,250,51,5,140,240,97,41,117,248,122,238,160,36,69,230,49,254,235,241,156,9,26,5,2,0,195,7,107,6,216,253,47,5,100,4,187,253,67,5,138,2,182,140,22,1,38,4,179,5,183,3,112,9,140,1,174,253,162,3,178,1,236,12,0,245,90,21,223,18,203,244,188,255,130,252,58,0,20,205,210,0,108,248,36,246,115,4,252,7,224,255,201,3,139,8,4,2,69,2,249,31,32,8,176,0,60,253,249,5,108,4,93,253,152,250,59,213,150,4,131,235,68,2,66,29,186,12,218,16,146,10,148,202,57,249,145,7,65,2,148,255,116,10,100,2,58,252,58,252,183,12,121,5,163,5,198,248,4,255,54,36,173,19,44,250,91,248,170,247,174,4,142,13,242,40,44,254,97,253,137,249,69,252,176,12,32,13,192,1,194,248,199,157,45,245,10,243,49,2,96,253,255,6,146,8,170,253,137,6,92,254,35,2,122,0,96,255,84,255,150,6,115,254,163,4,11,0,145,252,198,255,67,1,180,0,228,245,165,247,254,248,148,244,231,3,167,150,0,251,135,250,254,252,15,24,159,238,178,239,150,20,51,237,43,16,25,248,134,10,68,11,90,13,196,232,46,12,104,251,83,18,118,33,0,128,87,253,215,253,40,255,40,255,93,252,5,254,67,2,92,252,28,253,93,1,81,0,72,8,58,251,52,2,216,249,217,4,159,0,19,10,164,12,5,75,24,253,65,249,245,248,223,4,193,253,251,254,5,1,28,2,1,255,196,255,108,250,152,200,182,235,95,3,229,3,19,4,196,252,210,1,247,206,58,8,56,0,202,253,118,4,145,1,80,5,18,9,117,2,169,3,138,11,154,216,244,255,250,9,128,233,11,2,176,196,124,2,156,0,165,0,178,245,110,4,146,2,46,17,151,250,124,248,155,4,150,12,116,252,127,251,162,70,243,3,156,7,17,252,96,1,84,255,210,230,234,255,28,255,248,254,73,0,76,0,181,8,187,250,215,23,188,210,64,2,46,13,176,249,224,30,74,12,216,3,32,4,166,249,41,12,166,241,203,0,60,254,86,252,26,8,105,9,52,251,6,224,50,245,90,43,62,6,46,222,33,253,44,2,74,6,5,227,109,235,134,4,25,11,145,17,127,29,238,247,81,4,249,2,245,9,28,249,54,11,49,15,58,250,120,7,200,9,119,250,195,3,246,198,67,2,28,0,119,244,53,6,122,15,164,250,24,243,54,2,127,10,228,37,96,246,202,204,189,11,252,252,65,241,118,255,108,239,167,19,219,9,189,244,70,2,66,254,238,254,239,12,99,255,240,252,76,252,220,254,13,12,243,252,186,3,171,247,219,229,85,54,68,247,160,1,227,245,134,243,156,2,60,248,70,247,61,9,10,4,177,4,156,255,152,6,116,1,156,0,2,255,163,3,64,2,184,237,54,2,225,248,38,1,109,6,30,108,183,250,50,251,208,6,58,2,143,6,96,2,221,255,18,228,225,238,40,209,162,244,208,247,0,2,46,7,57,12,102,254,254,246,217,253,192,240,44,16,18,206,49,249,150,255,162,239,78,234,175,50,195,253,52,242,46,240,15,0,27,5,62,0,107,6,60,248,142,22,16,8,126,18,241,3,246,7,22,245,112,245,227,8,233,254,204,249,114,252,83,122,225,4,150,249,78,0,164,0,252,254,146,252,186,2,165,4,159,0,7,232,54,248,7,3,156,13,99,6,97,4,39,17,5,233,220,211,138,14,90,254,124,247,122,243,147,243,46,250,35,1,46,5,143,1,160,7,43,223,192,8,175,0,213,13,162,16,238,5,243,252,81,4,242,1,164,254,3,3,46,62,120,0,123,1,12,248,117,241,196,42,221,248,148,12,40,0,210,0,218,254,211,252,211,246,61,253,199,3,185,3,65,10,210,202,17,250,238,36,86,45,121,252,49,3,93,24,82,221,96,255,24,249,188,1,4,245,95,249,14,252,60,252,54,7,181,11,73,10,124,248,245,1,72,250,98,9,38,252,137,251,15,2,163,4,95,252,187,81,205,253,17,3,26,254,84,252,89,6,228,252,71,253,92,1,84,254,171,5,63,4,52,247,79,246,171,3,122,3,52,246,179,250,180,248,115,5,14,231,30,170,14,10,128,254,188,254,72,30,180,11,127,253,33,225,143,233,126,239,174,239,214,238,91,36,66,15,29,255,16,254,204,17,75,4,186,252,14,246,166,4,209,38,49,43,6,15,100,255,177,1,199,244,23,249,36,0,116,12,138,17,17,17,106,18,183,237,12,245,11,250,77,252,56,236,172,239,188,250,132,250,183,251,174,240,192,251,68,254,188,202,245,249,149,6,167,249,210,222,188,9,184,255,165,38,166,9,193,2,105,0,233,21,229,234,78,3,90,0,80,253,160,4,142,24,3,255,182,249,20,13,222,247,134,34,107,246,221,250,45,251,49,253,1,238,166,247,110,234,30,215,108,7,5,6,128,245,217,2,112,1,115,221,2,5,182,1,28,246,232,246,225,18,255,231,197,15,0,14,29,31,41,250,87,27,83,236,172,250,183,27,157,16,151,10,112,223,106,15,189,250,192,0,204,252,184,254,128,251,18,6,101,3,189,19,235,37,0,233,58,239,238,240,240,242,152,32,124,253,214,6,252,248,107,255,134,241,25,198,144,2,49,250,94,246,128,2,18,247,170,244,90,11,44,0,211,0,176,254,24,117,214,254,44,8,80,253,65,7,15,7,87,249,139,12,169,1,234,251,128,0,167,4,82,248,42,253,32,244,208,241,188,4,170,11,146,20,62,4,40,14,252,11,166,1,221,3,159,95,207,14,75,247,127,241,181,246,166,250,249,248,182,10,69,243,147,236,142,253,239,8,23,22,151,2,106,252,210,51,82,30,149,251,186,9,205,243,53,11,178,252,244,244,119,0,204,56,236,17,32,245,127,241,13,246,114,14,117,12,44,13,196,234,88,3,30,17,28,16,78,13,176,254,113,252,119,255,172,16,172,238,30,6,145,4,52,244,156,54,94,255,198,227,10,246,78,252,152,246,224,251,181,253,239,254,92,252,37,255,171,224,194,251,229,245,12,15,211,4,234,255,222,0,180,251,198,249,137,0,63,248,241,39,134,19,164,254,62,254,251,25,87,247,231,225,204,9,77,39,96,238,42,247,12,24,146,11,150,0,104,246,65,4,97,252,159,253,198,243,110,249,65,251,221,219,126,255,64,241,203,254,208,201,236,254,246,228,174,255,100,10,25,251,94,230,80,10,86,10,166,1,172,255,124,232,225,210,82,249,122,242,150,245,222,48,73,12,38,255,140,11,191,1,30,0,220,8,150,246,136,250,148,2,175,1,252,11,2,1,210,244,79,15,133,10,24,253,254,11,125,247,88,251,92,252,209,247,233,254,253,7,243,223,159,59,193,238,68,8,207,15,68,40,38,12,88,5,245,249,167,42,220,3,175,255,117,252,64,249,228,251,45,242,95,237,240,245,242,251,39,36,152,0,175,1,151,9,248,249,88,7,200,254,164,10,232,203,155,239,81,251,197,2,73,253,105,249,186,1,252,245,166,249,160,248,78,7,211,13,150,244,78,242,46,225,146,234,152,249,130,8,125,8,128,243,238,237,92,4,105,51,155,235,172,252,233,251,0,243,121,240,167,238,54,11,78,250,32,22,228,255,13,15,17,7,161,10,146,2,98,196,27,14,151,12,83,2,44,0,49,235,74,246,242,248,94,2,86,246,44,251,215,3,205,6,58,223,156,7,83,7,242,248,106,231,210,252,21,253,161,8,204,250,10,8,210,250,176,22,89,4,243,213,184,253,198,15,132,5,228,242,24,0,230,205,30,239,17,247,215,213,192,11,9,229,7,251,54,6,160,253,254,253,203,254,112,255,24,248,30,7,23,17,98,4,137,253,180,255,173,253,192,0,197,211,232,31,196,39,122,253,174,9,164,17,71,4,94,0,6,0,227,4,110,253,60,10,114,2,6,12,215,2,89,30,198,3,247,241,178,228,202,246,254,3,8,5,173,10,253,254,221,254,178,9,41,1,12,251,98,40,227,2,186,248,183,205,131,246,3,26,49,17,54,247,148,6,228,5,244,6,199,251,246,255,132,232,127,3,187,246,17,251,125,0,168,5,136,18,20,6,157,227,50,9,152,211,131,4,237,225,112,250,110,252,177,253,168,9,26,2,151,5,185,3,5,0,6,244,217,251,3,0,150,1,211,3,154,3,100,253,97,6,2,0,137,2,117,255,196,3,92,3,137,182,152,7,135,8,178,250,115,5,113,251,249,20,59,242,223,2,118,245,60,41,143,251,117,240,103,5,51,248,107,23,65,25,6,9,245,6,201,254,48,13,31,28,71,245,136,249,186,233,108,12,201,11,215,233,56,253,58,221,10,8,198,253,170,0,228,8,29,15,140,219,227,224,106,4,63,8,6,22,29,250,128,11,38,6,105,252,77,250,54,252,85,43,32,2,120,244,110,255,180,237,209,254,240,253,81,251,134,252,96,245,127,249,56,213,117,1,121,6,168,7,150,250,43,1,252,238,81,238,244,34,210,28,44,6,21,5,87,232,226,29,25,227,38,18,24,249,196,10,249,254,226,254,178,254,89,5,238,252,80,241,56,3,44,203,21,236,99,249,165,254,227,248,200,7,134,13,141,5,36,19,50,254,237,203,175,249,210,246,243,15,239,221,8,233,36,19,96,11,235,0,129,40,196,250,8,3,218,245,8,56,35,241,200,253,52,241,7,14,118,254,203,251,68,15,192,23,161,7,82,250,11,252,251,1,113,39,68,13,202,237,5,253,202,9,206,5,16,12,68,2,170,255,93,4,70,6,130,242,226,213,6,19,26,24,180,15,213,233,192,26,183,1,195,221,37,15,106,24,222,2,173,12,150,252,40,239,145,252,240,238,249,250,140,12,174,247,101,250,83,6,232,254,246,243,210,251,23,182,172,3,132,246,244,249,138,251,241,254,193,0,16,255,134,252,150,3,2,239,78,236,222,220,196,19,161,230,127,13,253,254,124,3,246,250,68,5,231,251,119,206,207,255,110,71,75,0,23,3,38,7,236,239,0,40,244,255,53,254,173,9,234,245,240,242,194,249,214,3,188,254,208,255,123,239,228,222,112,43,100,0,162,231,140,4,65,9,252,247,247,0,114,2,165,8,231,8,189,245,33,1,41,254,144,251,230,248,53,60,67,2,10,4,77,229,59,222,133,206,246,2,92,252,210,238,53,2,202,1,24,248,46,240,228,243,105,7,44,5,119,12,84,7,236,29,129,1,214,251,253,249,219,250,184,245,254,2,63,0,133,1,67,255,112,4,115,253,34,3,243,2,70,0,140,139,128,2,79,209,149,42,30,8,239,253,133,40,205,9,40,245,152,255,72,247,174,0,187,252,158,0,227,5,171,7,239,254,254,5,60,4,21,33,8,10,118,49,28,247,248,10,4,8,250,226,178,1,193,14,223,3,152,2,164,10,95,6,208,241,51,8,186,253,44,16,245,2,240,43,28,2,111,250,36,216,68,6,88,2,14,248,220,251,209,3,51,7,247,14,91,252,208,252,159,11,243,230,53,6,109,252,72,253,107,8,212,253,27,186,20,13,41,251,246,3,21,246,52,6,192,254,98,9,51,250,130,224,234,251,78,250,200,0,43,5,101,1,88,241,20,11,142,22,138,210,111,252,120,253,140,6,246,0,3,251,215,251,30,9,63,58,228,0,112,3,132,247,0,12,40,246,165,5,162,5,8,10,26,251,218,2,98,248,64,255,227,46,205,249,254,9,202,2,33,0,228,16,222,237,25,255,233,254,1,255,160,69,12,5,202,13,2,253,192,255,245,0,141,6,180,6,203,9,246,241,52,242,184,11,204,7,34,235,180,248,246,233,235,255,108,4,78,251,80,4,113,230,218,4,201,1,81,249,0,128,49,0,54,254,39,1,90,3,251,7,244,4,23,251,166,254,25,3,42,2,236,4,198,251,217,3,83,250,168,6,127,9,214,244,186,5,208,234,90,221,106,18,253,249,135,22,110,0,248,245,54,250,164,254,196,210,234,244,189,4,169,253,201,249,112,242,5,229,47,24,88,15,100,18,46,5,26,250,178,24,9,15,240,239,9,30,88,23,30,243,116,1,182,234,96,247,164,25,253,228,143,3,120,16,146,6,29,253,158,247,203,0,94,1,208,252,95,1,198,242,56,244,59,197,184,213,215,253,151,236,138,0,0,1,136,6,208,248,35,11,222,61,118,11,79,7,168,253,35,243,179,252,120,245,183,5,205,251,208,2,103,251,254,249,111,9,147,28,28,254,58,4,194,3,254,2,179,252,65,214,212,232,198,238,0,15,106,1,194,0,32,238,225,39,36,242,129,255,78,251,246,0,34,253,2,3,55,1,202,243,4,3,138,246,139,251,214,207,192,3,31,6,0,11,80,0,194,238,246,252,153,2,4,9,92,254,76,255,38,251,89,254,106,47,113,0,59,250,83,11,214,0,92,1,97,252,4,253,26,0,153,251,16,247,0,128,22,5,138,1,134,2,59,254,78,252,186,252,113,6,12,247,158,4,234,249,243,230,247,254,106,248,117,242,71,7,58,242,118,13,161,252,118,3,202,0,54,255,90,61,178,8,227,6,126,3,168,3,63,63,75,253,146,6,22,26,206,6,85,5,188,2,27,249,221,252,43,1,110,247,235,4,177,2,134,6,133,253,28,0,114,46,242,255,146,252,193,234,103,0,116,43,16,2,155,4,194,255,100,3,104,253,237,2,152,251,149,5,27,254,128,7,158,252,152,4,27,4,123,1,226,140,50,9,4,255,144,249,100,254,220,252,59,5,129,254,212,252,191,3,125,3,51,249,182,5,180,248,214,1,64,8,159,248,68,247,124,249,13,253,254,245,74,5,39,24,44,213,19,22,218,251,246,9,175,231,62,255,151,6,242,252,32,6,171,255,10,0,248,255,104,4,247,253,190,251,115,248,143,242,118,245,233,11,66,233,111,81,198,2,21,3,176,248,58,4,38,251,56,16,88,6,43,42,155,247,122,255,63,4,132,3,249,224,58,20,155,242,154,210,223,241,236,226,200,252,134,13,189,253,194,252,242,3,27,243,170,47,186,234,29,249,84,1,24,253,3,254,42,2,116,4,234,47,208,250,44,18,224,3,117,248,60,253,50,4,202,10,115,11,98,254,39,255,182,39,185,239,121,252,148,2,232,3,27,0,243,251,4,250,28,5,207,33,127,35,74,244,200,38,118,241,212,253,204,18,246,11,88,2,1,5,39,15,114,0,228,234,77,7,126,8,35,8,145,210,211,254,231,241,139,9,252,8,255,18,186,252,227,255,118,8,39,5,62,8,107,5,27,253,55,251,63,249,32,203,48,227,16,250,107,2,201,236,213,9,14,239,142,249,219,1,200,1,20,17,24,3,152,12,171,7,221,253,233,247,94,8,2,255,13,6,66,229,126,9,160,255,132,77,83,2,173,4,169,250,227,7,222,7,245,249,65,241,94,251,38,218,118,254,246,239,64,249,244,251,129,11,253,1,162,55,155,248,66,246,68,244,202,1,39,249,68,10,62,38,122,13,140,249,190,254,71,32,112,15,148,247,194,247,70,254,232,4,25,6,207,236,132,242,74,0,235,11,203,34,208,242,160,255,14,65,45,2,8,2,66,254,40,246,80,249,103,8,137,246,177,14,77,242,231,1,55,8,9,3,96,254,253,1,212,1,45,14,173,243,196,44,58,8,113,247,10,252,130,4,101,36,192,2,230,254,26,12,162,10,84,0,150,0,222,232,247,11,181,32,136,209,123,251,18,247,11,249,163,28,51,5,178,254,50,252,139,249,240,2,78,248,167,255,114,242,114,9,202,250,31,14,226,49,140,255,173,7,149,249,200,5,79,247,66,214,106,251,18,2,52,252,91,252,207,2,210,2,250,5,195,254,105,0,181,200,9,10,154,17,202,222,87,253,248,249,226,253,2,245,119,251,139,253,16,249,44,242,170,250,159,241,46,7,162,249,65,253,69,49,209,207,28,248,125,8,27,0,59,1,158,18,238,17,189,249,188,255,130,4,132,244,174,4,204,30,198,9,182,253,184,1,252,235,106,246,219,245,198,252,233,28,243,10,200,17,116,243,150,11,65,234,76,2,168,8,20,29,183,245,222,232,178,1,95,13,244,15,248,8,202,51,22,8,240,237,54,251,166,0,145,254,241,253,86,4,129,250,106,255,140,0,72,2,139,254,167,245,94,3,244,1,220,12,78,242,89,253,115,177,239,6,42,253,50,13,242,2,86,248,124,233,198,250,212,241,77,253,202,17,158,248,123,232,90,230,30,10,6,1,205,9,1,1,222,238,80,246,208,24,22,248,210,4,113,254,24,89,83,247,142,253,54,253,173,254,84,251,57,254,176,255,201,2,126,6,218,1,236,246,241,253,5,16,226,214,247,237,252,40,137,251,37,3,80,5,212,14,174,3,172,2,36,10,33,5,53,6,198,253,100,21,229,255,4,36,43,250,71,10,186,229,96,244,41,200,137,0,34,253,33,248,146,2,67,1,83,0,235,9,50,251,178,6,224,247,146,2,141,182,162,11,228,3,210,242,228,255,201,250,150,0,106,8,45,4,172,252,37,1,23,2,20,252,31,252,148,241,16,207,94,1,246,6,38,254,159,5,67,200,248,255,10,249,15,253,72,249,167,0,72,254,110,245,222,0,163,249,224,254,159,2,145,255,30,40,110,3,152,0,74,1,24,252,127,2,0,251,87,4,232,247,159,5,36,254,41,2,98,244,154,253,130,6,46,254,35,46,143,250,154,0,112,2,71,253,176,0,84,4,248,1,250,0,60,2,250,255,192,2,16,0,135,2,137,251,129,250,101,254,193,92,63,1,67,255,108,254,127,253,170,255,61,253,254,252,210,254,13,0,114,254,76,0,87,253,243,253,98,1,55,251,11,253,126,165,28,254,59,252,82,254,165,52,130,3,249,1,239,255,244,53,134,252,101,1,150,2,232,3,89,252,196,255,176,3,144,1,80,254,35,255,23,4,51,1,76,255,140,20,125,64,138,2,243,254,27,6,142,232,246,243,186,0,250,242,118,233,242,3,118,254,128,0,69,253,25,2,229,255,246,3,237,253,206,255,93,255,128,249,254,251,220,2,240,250,96,85,62,2,160,1,23,253,69,254,154,250,16,1,23,3,28,5,204,254,156,249,168,0,86,213,119,0,90,251,99,4,212,5,170,6,52,4,32,248,198,12,30,252,108,3,244,246,80,244,81,49,100,254,97,255,129,20,144,5,208,254,45,2,81,254,152,254,172,254,207,253,220,254,212,6,32,255,253,6,160,254,130,1,136,0,76,0,29,5,242,254,116,161,253,253,118,4,71,8,120,4,83,255,240,3,75,253,82,254,228,251,98,7,61,207,104,211,102,11,55,6,78,251,10,249,201,250,74,5,167,6,2,254,191,16,170,252,129,4,226,7,250,253,64,252,49,46,15,5,205,253,244,43,190,0,238,15,222,0,213,243,234,12,235,2,78,10,247,3,118,249,96,31,174,246,61,2,163,254,192,252,96,0,92,37,188,45,29,254,46,5,12,7,169,244,24,248,22,255,241,3,157,12,24,255,35,3,19,1,188,1,139,253,64,255,125,1,247,250,147,255,165,142,14,1,92,254,104,254,46,254,113,0,231,253,246,254,40,1,180,0,250,1,247,3,203,253,251,253,214,5,211,212,128,15,57,249,146,13,57,248,122,223,139,31,204,6,101,240,249,250,2,246,6,4,158,14,150,253,216,245,9,249,136,10,200,5,30,4,85,1,178,14,129,16,50,249,194,210,252,16,204,221,237,1,108,254,0,15,231,251,85,253,62,252,163,0,245,42,159,255,176,252,232,237,234,10,124,10,236,9,227,2,86,33,104,14,146,252,66,12,16,10,44,25,90,14,189,246,38,255,48,11,238,47,50,11,189,0,197,17,30,19,22,231,230,251,162,243,247,232,197,8,243,10,186,255,139,248,223,10,111,15,153,0,213,43,110,253,236,49,18,255,90,13,69,247,242,2,55,1,29,253,146,246,190,2,52,4,47,1,192,254,47,0,40,243,22,255,160,250,206,11,153,255,12,249,204,2,110,46,190,42,230,234,201,234,172,4,144,253,139,252,116,253,80,243,74,0,77,254,82,253,154,0,227,33,253,12,13,249,171,254,52,2,123,252,55,5,129,253,166,13,228,248,34,1,164,255,240,243,167,18,164,247,30,9,198,2,40,41,62,197,231,57,198,251,235,251,240,3,222,2,241,0,232,251,91,252,245,0,145,3,114,0,66,1,250,248,246,0,43,4,92,1,152,1,73,255,40,253,141,205,173,2,245,5,158,6,183,0,88,255,159,49,12,251,77,6,232,247,10,6,231,2,52,9,87,8,218,253,103,255,47,5,2,0,199,48,217,243,43,9,70,249,212,254,63,255,174,8,120,248,110,253,128,254,150,233,139,251,50,14,72,40,187,255,243,249,127,42,3,7,151,254,210,248,143,0,178,4,71,1,67,195,12,251,62,255,212,12,244,255,168,254,6,248,127,6,78,1,226,252,151,252,200,6,188,254,195,0,95,254,130,254,104,166,44,3,34,254,62,252,61,254,218,2,126,1,121,255,31,5,222,254,122,0,148,0,249,252,207,254,38,130,172,255,98,0,118,1,113,1,212,255,155,3,80,254,156,0,65,250,236,0,217,255,143,0,110,255,67,3,135,0,229,0,215,254,154,6,130,26,119,208,47,3,80,255,76,7,247,255,20,244,108,0,114,0,4,1,73,44,127,245,124,255,253,2,17,255,54,0,179,2,247,217,141,253,38,254,180,47,174,8,85,226,17,255,1,7,67,8,51,2,170,246,57,248,90,11,163,2,155,3,146,0,235,241,213,3,67,249,92,0,206,253,56,173,48,1,62,254,189,254,135,252,42,253,176,2,94,251,30,10,210,1,70,1,34,253,52,1,242,252,109,243,195,3,198,1,68,5,255,253,185,3,122,250,192,254,244,3,132,251,161,4,52,188,241,255,10,6,66,5,134,8,103,246,146,5,102,249,155,0,89,34,114,5,254,1,48,10,53,255,137,10,96,2,52,10,26,203,177,0,34,18,200,252,85,7,184,248,145,6,247,251,207,5,19,253,100,1,245,255,255,255,146,254,41,255,251,5,218,255,102,252,134,254,216,254,221,4,255,77,171,246,53,254,111,241,93,255,178,25,98,1,65,250,195,0,97,1,39,7,163,253,13,247,153,254,179,3,217,32,126,13,128,48,130,9,157,13,40,0,94,1,104,6,226,2,157,217,167,3,85,255,80,252,127,5,113,254,59,2,245,10,204,204,16,3,166,2,101,9,72,1,95,254,164,4,196,249,119,253,178,250,150,251,85,1,202,0,101,246,43,44,54,247,66,242,236,248,10,13,100,252,43,39,188,11,191,2,72,255,102,253,223,0,148,249,203,227,179,13,124,39,44,5,100,254,141,254,164,255,192,9,110,12,10,0,29,40,26,252,14,252,98,2,224,12,206,248,151,1,150,1,183,249,75,255,154,8,106,253,86,250,80,5,208,5,44,255,221,5,42,255,213,253,168,0,19,1,45,1,74,252,200,12,189,254,152,80,235,255,63,249,5,43,101,8,194,219,79,26,175,253,50,227,82,254,40,245,39,9,162,250,7,2,244,236,59,3,83,246,77,248,225,4,172,164,238,248,199,0,7,253,134,8,118,6,191,1,24,254,61,251,108,1,203,255,130,254,35,252,154,0,223,253,152,252,8,3,45,255,26,30,1,253,70,31,118,255,197,7,76,255,50,1,230,1,88,4,120,253,244,255,2,6,212,254,154,9,55,233,99,251,0,226,212,229,147,253,204,254,213,138,90,2,232,255,94,0,240,2,5,2,86,0,7,255,34,4,192,2,108,254,125,254,106,0,136,253,97,255,251,4,59,255,17,251,70,251,103,249,8,215,158,7,11,248,86,23,136,240,38,0,4,5,35,11,3,245,179,249,146,249,180,39,138,0,116,244,196,0,138,255,28,254,92,3,124,0,250,254,30,0,88,250,128,0,31,1,71,1,78,2,136,106,135,1,30,253,161,249,31,254,25,250,82,0,194,253,31,253,154,253,65,254,176,255,36,1,237,255,252,0,254,255,43,146,76,1,141,0,205,5,102,255,102,5,37,249,90,254,100,249,160,247,142,3,236,3,102,7,255,249,129,3,54,254,27,76,215,250,232,8,110,2,32,1,51,247,23,252,48,252,104,254,118,254,132,0,6,255,84,254,234,255,140,0,31,1,115,255,5,121,219,254,119,2,217,2,254,255,25,255,129,255,121,1,145,252,218,254,149,255,253,0,60,252,234,4,58,2,71,0,205,36,166,32,79,36,162,32,222,253,129,4,241,248,41,6,95,11,240,248,16,7,161,249,188,250,191,228,130,254,89,6,23,245,137,41,185,7,255,248,64,207,1,0,218,7,23,0,167,1,78,4,128,248,34,254,53,7,248,3,209,1,246,2,32,3,252,249,72,21,24,215,67,245,35,252,38,231,67,36,117,1,0,246,154,234,174,249,20,0,204,253,206,251,235,15,41,254,253,253,153,1,235,247,103,1,236,252,158,210,220,9,149,3,197,10,243,0,67,243,10,27,124,24,180,243,12,245,172,242,90,239,145,248,19,4,33,208,94,255,62,6,240,1,198,1,121,5,157,249,89,206,95,253,64,13,231,4,66,6,74,251,215,254,238,247,193,11,125,4,5,5,229,250,156,1,67,109,183,0,57,2,24,5,62,253,56,3,133,253,154,254,172,254,228,255,192,250,187], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+296977);
/* memory initializer */ allocate([3,14,0,164,2,13,255,236,255,85,209,70,5,186,31,196,0,79,216,61,19,76,241,125,6,111,254,145,0,253,0,168,2,206,2,154,253,155,253,242,1,219,254,95,239,84,253,251,197,230,214,186,2,1,6,32,248,138,4,132,245,214,249,8,0,18,255,114,243,67,245,215,249,93,251,113,0,79,250,44,4,78,2,25,0,124,253,232,3,126,9,180,249,190,51,132,245,150,249,216,237,48,3,177,251,124,226,121,22,98,240,198,250,248,252,90,248,76,218,248,250,222,254,112,239,28,245,1,224,89,6,254,9,214,4,224,248,217,255,199,243,44,221,26,243,0,234,24,249,98,3,196,2,172,2,202,13,188,221,205,5,165,2,98,215,174,2,172,252,194,228,166,20,158,245,100,2,156,4,217,242,189,16,76,22,136,5,166,0,227,10,143,241,151,5,112,6,6,31,224,253,216,251,254,253,184,252,154,252,222,4,2,242,162,219,38,241,185,15,197,223,90,23,132,0,149,253,232,10,58,38,220,4,242,0,100,248,163,237,240,232,183,3,62,29,90,242,48,0,140,238,157,246,202,23,217,246,177,239,56,5,14,246,231,254,32,253,34,249,72,249,58,43,106,252,182,250,45,15,223,255,236,239,222,4,38,255,110,224,2,253,116,30,225,5,23,6,60,252,205,6,58,254,164,249,6,253,218,11,220,252,136,252,46,218,131,37,4,246,58,11,176,234,250,11,189,225,188,3,108,253,254,249,131,254,8,253,211,6,35,2,251,253,71,253,125,250,154,1,254,253,108,240,37,255,46,52,167,246,232,254,222,43,80,10,27,3,230,9,98,224,210,248,71,0,16,0,53,255,128,16,160,255,243,244,218,7,169,7,224,250,14,251,112,15,238,26,84,27,130,224,100,18,169,4,145,242,13,6,167,3,170,0,102,2,156,252,43,0,10,255,68,255,84,252,130,0,126,0,32,253,185,2,2,254,200,255,60,6,242,202,25,4,236,60,155,255,195,2,117,10,30,2,246,253,132,253,194,0,199,246,28,251,12,2,224,255,227,0,93,254,116,253,167,253,84,0,68,215,119,250,61,51,195,253,190,14,208,241,233,7,43,251,76,253,50,250,192,0,197,4,196,1,180,1,4,253,180,245,103,255,83,253,118,0,88,254,133,253,54,254,209,0,191,253,246,208,144,16,147,213,49,0,2,250,33,252,144,246,232,254,47,8,207,248,254,4,162,255,89,254,196,253,75,252,222,2,193,251,161,48,114,25,26,238,91,225,118,241,166,5,227,9,42,251,234,247,235,5,205,250,78,9,42,4,238,250,91,251,155,26,180,248,198,251,60,249,100,1,194,245,237,1,239,242,87,5,201,6,145,17,114,198,186,250,158,254,196,250,30,33,128,251,40,7,1,7,62,3,206,3,162,201,10,2,64,250,58,246,191,245,99,255,152,254,239,255,194,252,161,2,36,0,197,250,244,197,10,2,191,203,83,3,169,3,177,251,212,255,152,1,148,254,71,252,120,254,45,7,38,9,212,4,111,0,38,255,105,252,217,3,93,39,215,251,48,7,132,255,196,14,249,212,204,0,181,1,194,252,56,26,72,249,32,1,33,252,70,4,15,22,240,250,20,247,106,6,232,3,221,255,141,255,208,0,12,255,181,251,192,252,212,247,34,3,93,255,15,13,60,252,58,1,126,0,76,251,242,2,82,186,198,252,62,17,139,32,254,252,222,4,84,242,144,6,65,3,148,255,238,1,114,252,86,231,240,244,249,9,170,231,141,4,47,14,75,249,100,9,0,128,8,2,218,255,204,4,60,253,58,0,4,1,3,3,76,2,64,254,133,1,156,0,94,2,194,252,144,1,24,254,68,255,24,2,108,250,206,46,100,255,129,250,4,7,12,4,137,3,91,5,64,250,69,1,26,12,100,250,49,25,57,8,81,212,96,6,200,248,251,3,223,4,28,5,185,250,201,252,143,6,117,253,210,3,40,1,64,4,125,15,122,250,194,209,139,0,216,33,132,242,244,248,16,12,4,248,35,255,189,250,208,4,115,252,213,250,127,250,119,5,253,9,216,56,255,5,32,236,163,6,244,3,5,13,100,15,246,8,165,4,48,247,28,254,21,243,203,250,208,1,207,254,24,253,232,255,16,176,76,1,152,11,52,1,119,253,36,1,110,254,202,4,241,245,31,250,156,255,133,5,221,2,0,252,104,2,135,255,190,254,67,0,95,255,60,253,251,0,206,1,183,151,168,251,155,250,188,254,226,254,67,4,150,2,214,61,68,51,231,251,232,248,157,254,56,7,223,252,82,249,209,9,202,1,226,252,130,1,42,253,156,254,40,251,147,251,124,254,119,2,91,0,75,7,207,9,206,254,25,12,63,56,197,253,143,8,156,244,34,11,249,2,118,246,186,2,111,247,77,245,134,248,19,240,233,237,158,49,77,1,138,4,152,231,78,207,202,254,149,255,95,246,93,255,178,7,26,252,27,251,215,7,79,0,86,254,236,254,109,1,56,2,248,253,90,92,20,1,35,4,184,0,57,4,138,2,238,8,65,255,115,3,102,248,246,0,64,0,31,255,32,3,142,3,120,255,163,4,187,3,12,195,47,50,21,253,106,3,250,1,122,253,128,7,63,254,191,254,128,4,61,5,117,6,85,1,224,255,139,3,161,2,21,4,221,4,13,254,165,215,75,18,159,251,164,243,54,13,253,24,195,250,255,252,162,4,229,0,182,250,54,227,155,0,66,7,241,21,97,242,9,255,241,252,212,2,252,1,205,54,240,253,61,7,36,6,68,2,60,253,16,2,142,250,218,34,236,8,38,2,12,12,66,249,93,243,68,253,220,27,44,242,56,255,216,12,209,252,115,247,208,4,108,9,40,8,179,251,48,49,38,3,228,5,205,6,13,0,100,4,213,240,81,253,12,224,234,243,238,242,245,6,60,46,111,253,115,242,149,5,226,248,151,242,87,0,31,15,139,2,59,252,35,249,122,26,109,0,112,0,125,255,198,2,167,46,181,208,124,242,42,253,234,3,37,241,68,2,196,10,243,250,116,0,201,1,69,2,250,14,114,249,47,252,218,4,8,248,232,0,206,216,108,6,14,247,88,5,172,0,60,244,143,5,196,245,24,14,177,213,209,254,182,249,174,12,50,2,92,20,192,1,147,252,186,3,176,2,235,220,67,2,205,2,35,5,72,252,161,26,150,2,146,12,45,28,188,247,206,40,244,3,222,8,166,252,10,0,214,251,122,41,220,23,221,253,149,12,131,252,48,15,192,251,155,216,9,255,40,4,84,242,51,12,80,246,176,247,228,10,51,247,228,217,40,254,90,255,88,253,215,2,74,0,185,200,67,255,58,249,98,2,111,251,77,3,94,0,238,252,138,1,187,253,244,1,189,7,68,213,98,1,244,1,143,1,96,248,139,254,149,8,152,237,234,245,191,10,142,2,101,2,26,251,126,5,8,8,26,207,47,6,186,253,226,18,251,249,252,1,156,175,14,1,190,4,3,2,198,251,5,0,7,0,235,253,228,255,246,4,229,250,241,1,199,255,181,254,165,3,92,0,168,252,38,215,32,238,249,216,122,9,152,25,50,244,23,1,206,253,64,255,86,7,67,247,114,19,39,249,76,1,74,250,171,252,238,0,222,1,18,38,39,227,206,215,170,223,201,1,49,12,73,3,48,0,95,241,238,250,131,253,228,248,44,254,8,255,120,5,138,1,131,255,74,252,4,45,188,248,170,1,251,252,125,49,172,249,98,255,89,6,21,4,0,3,190,255,244,255,89,6,254,252,47,2,54,0,81,2,132,56,146,58,234,1,31,2,213,252,188,2,235,254,132,3,78,255,48,248,219,1,241,0,182,3,106,0,20,251,106,3,162,252,219,73,101,248,180,252,205,0,229,4,173,255,174,7,252,8,122,245,84,3,146,9,149,2,178,254,250,253,144,251,183,246,69,1,128,4,255,1,113,3,67,169,130,3,62,2,186,253,247,254,174,250,3,255,216,255,244,252,81,248,213,1,204,5,206,252,98,252,190,3,97,254,2,225,182,254,74,1,159,5,107,6,77,0,10,4,100,255,194,208,198,14,163,233,248,253,170,253,41,9,178,13,213,20,190,254,99,0,208,255,210,5,20,0,129,44,140,13,136,251,101,27,112,241,233,27,152,5,18,7,26,0,112,252,126,230,201,251,235,6,95,0,167,15,174,211,213,255,249,0,232,198,7,255,1,0,43,253,244,0,29,4,23,7,142,253,152,1,168,254,180,7,174,8,240,8,236,246,101,254,103,240,238,1,62,253,42,236,81,210,195,241,214,247,161,9,5,23,24,236,159,26,231,253,139,19,234,4,185,0,237,249,149,252,1,248,86,255,79,254,62,255,4,252,93,1,44,253,189,131,197,0,251,0,94,254,34,255,150,253,22,1,42,2,107,1,183,0,126,252,14,0,94,1,233,2,250,247,169,249,38,3,254,252,34,251,58,6,202,255,187,183,236,5,72,3,170,255,228,1,2,2,185,4,210,3,52,2,231,253,34,0,81,254,128,0,170,3,241,248,64,3,166,255,187,140,126,253,117,5,204,255,11,2,119,254,216,0,140,3,9,0,193,255,198,2,75,252,3,0,72,255,175,0,101,2,81,253,104,254,27,0,169,252,82,71,2,5,76,252,37,255,70,9,132,6,41,238,39,4,3,248,250,46,205,1,2,12,26,4,4,249,169,0,126,203,100,2,19,0,29,248,173,2,196,1,104,255,43,1,54,1,233,246,92,1,41,255,98,6,55,255,114,8,196,215,164,48,107,241,92,254,84,9,6,2,252,246,96,255,16,6,19,13,114,6,221,12,172,251,17,8,182,206,20,0,214,255,125,253,202,0,238,250,251,0,185,9,42,5,58,9,114,14,66,255,80,2,60,207,87,252,24,8,251,5,46,1,103,254,125,252,8,252,124,254,79,4,54,117,21,3,183,249,220,253,22,252,31,4,93,2,69,252,21,6,196,1,145,253,42,3,85,2,72,253,132,41,106,251,94,2,68,10,215,253,7,247,12,26,216,245,19,3,176,13,234,241,247,15,28,4,132,24,61,226,81,1,5,10,243,255,181,4,132,255,198,4,78,146,177,255,215,253,116,2,30,2,35,5,159,253,66,1,129,252,135,254,74,253,98,2,239,0,104,255,171,244,162,38,204,2,6,4,22,243,220,3,30,253,50,2,95,247,116,249,155,17,141,4,132,205,98,3,102,255,80,14,145,254,236,245,138,227,196,253,119,8,118,0,252,1,179,238,32,254,74,3,185,9,156,249,6,248,101,4,55,7,26,10,249,233,33,13,8,253,181,43,111,2,230,254,73,5,233,254,3,2,208,252,201,2,66,1,161,1,252,244,166,251,229,249,145,1,156,171,236,250,52,252,6,247,29,254,128,8,194,252,87,8,12,240,71,4,158,7,111,248,27,2,138,254,125,12,170,2,216,1,168,250,97,224,6,209,225,18,210,21,211,1,96,9,148,0,125,1,118,255,186,3,53,254,44,253,202,3,156,0,93,248,173,250,48,2,7,253,84,249,193,249,0,188,216,251,164,250,12,254,136,4,223,2,185,1,251,252,28,255,164,1,152,251,4,1,162,3,79,50,98,252,25,255,75,5,174,252,47,2,113,44,63,249,174,9,193,3,80,1,32,4,217,19,60,38,213,253,227,15,216,33,96,245,74,250,196,11,144,227,197,3,182,5,161,237,65,14,36,8,69,253,250,254,152,1,68,255,145,8,88,247,99,238,32,253,241,251,16,237,205,223,234,224,84,255,218,250,94,37,57,18,35,13,168,241,45,6,217,253,24,248,94,6,7,6,90,0,64,249,232,252,249,248,11,10,80,0,100,254,211,254,202,244,4,7,49,235,111,0,190,67,80,2,196,247,221,1,5,6,242,4,218,251,41,255,94,247,223,0,191,4,59,255,87,0,92,184,189,255,36,3,114,254,138,255,127,242,27,253,113,248,64,253,238,254,54,2,152,252,227,248,74,50,193,19,21,8,206,6,195,231,29,232,178,249,218,254,187,0,166,235,198,6,70,250,142,247,38,247,126,253,108,255,184,1,2,0,233,0,193,254,131,253,34,253,26,255,45,1,252,1,79,254,55,1,199,254,74,251,194,152,235,253,63,6,208,0,219,254,255,8,192,2,50,6,216,251,162,249,178,2,161,6,111,2,250,6,76,1,170,2,199,0,151,49,219,1,8,5,89,246,227,252,188,255,187,37,208,252,95,246,34,2,115,250,60,6,98,252,119,17,56,9,175,21,124,252,41,1,96,0,144,1,168,3,12,6,214,251,167,249,140,2,136,5,138,255,243,253,171,2,9,6,60,5,204,80,168,3,247,251,251,252,224,32,186,3,42,237,127,16,193,213,200,254,128,252,19,2,68,12,143,249,252,1,54,40,197,254,226,247,72,2,243,5,118,0,229,3,195,209,163,253,250,254,60,249,155,253,188,47,150,245,246,248,5,254,198,238,156,255,79,8,142,255,138,252,10,245,244,1,10,4,5,245,98,49,247,3,23,220,151,239,238,0,72,4,121,251,83,6,230,9,108,6,119,242,189,18,127,2,23,10,220,250,100,217,180,3,199,5,162,4,32,249,169,254,250,250,139,249,166,2,241,226,190,17,105,231,192,249,190,228,48,0,192,1,113,1,61,6,144,241,183,247,234,3,124,9,152,211,9,21,59,3,78,214,52,247,192,8,206,4,254,243,154,248,40,1,88,247,59,2,114,0,15,254,117,249,31,5,7,247,51,7,162,254,168,252,19,8,174,4,180,253,14,1,42,254,80,10,18,1,130,76,6,253,49,211,145,253,6,254,140,16,27,213,42,255,192,248,153,1,4,251,89,252,111,249,252,19,6,3,192,11,36,17,144,255,235,218,172,251,174,5,105,5,41,4,7,2,26,254,52,1,139,251,33,1,144,5,168,241,139,193,102,241,200,249,254,254,232,12,62,0,161,5,45,0,82,253,210,251,176,249,67,253,9,9,126,7,235,18,142,2,250,189,7,1,45,7,34,240,167,10,59,253,244,5,164,249,233,7,231,254,8,1,214,4,1,252,51,209,82,244,243,250,33,3,122,218,164,253,46,255,224,4,174,15,68,14,234,211,210,247,42,254,206,250,187,56,172,246,133,5,128,240,129,2,120,11,161,0,105,249,20,251,186,6,80,248,108,1,170,252,206,199,162,39,24,3,133,0,210,6,5,1,17,13,104,254,244,7,16,1,132,5,208,2,26,243,41,250,18,239,162,8,31,3,138,68,40,10,34,5,252,2,47,5,105,13,135,254,200,16,98,9,206,251,214,1,52,28,4,246,254,12,14,239,218,247,103,248,89,46,197,13,233,5,240,5,234,248,36,205,95,252,47,248,40,250,68,2,35,243,182,243,119,247,162,5,134,1,22,248,163,247,64,255,244,182,9,248,22,239,155,6,6,255,171,5,159,244,16,11,44,243,83,11,249,5,136,252,230,1,179,246,77,250,153,245,18,2,51,253,8,255,78,249,118,49,28,7,32,211,236,251,219,11,32,15,130,246,167,2,51,4,219,1,175,253,162,3,41,249,149,1,252,246,100,8,254,1,18,245,189,1,16,255,47,229,58,8,197,211,158,2,246,16,154,0,188,225,243,248,5,21,182,252,71,253,59,253,176,2,14,254,149,21,108,59,42,248,206,239,108,246,88,9,62,242,25,248,26,5,146,21,148,3,224,241,225,254,115,253,77,1,182,254,4,0,202,158,123,2,119,0,99,248,131,3,220,255,219,255,98,10,123,255,16,8,234,253,219,253,47,249,186,255,255,127,65,4,155,252,150,0,169,253,134,251,194,253,88,254,121,1,120,253,209,254,78,2,197,1,118,7,161,254,41,2,48,1,16,253,16,253,10,254,214,255,21,134,134,253,193,1,126,2,62,4,130,250,196,4,34,3,100,252,174,248,44,255,86,0,56,255,140,251,106,2,147,253,163,253,32,213,163,6,165,253,8,8,160,238,17,250,4,10,25,253,16,48,202,5,35,2,203,249,207,252,39,255,159,249,191,251,34,247,181,0,134,253,50,15,222,2,217,250,13,248,232,12,88,51,140,220,29,240,70,0,29,5,43,4,158,254,249,5,99,5,22,252,4,243,243,253,207,252,98,250,82,42,12,4,153,48,218,4,157,9,42,11,209,8,174,1,103,251,118,4,154,252,76,3,78,4,184,4,54,250,62,3,214,68,63,245,6,0,174,0,33,17,173,254,109,8,101,255,188,255,66,255,99,251,29,0,2,248,164,247,27,0,181,3,97,7,190,1,202,255,56,65,207,255,24,243,119,248,41,7,151,14,17,254,55,251,33,210,45,247,123,3,94,248,32,11,8,254,140,4,71,246,93,3,67,2,229,210,208,3,214,255,197,5,132,246,231,249,112,0,74,0,95,245,14,47,120,2,3,5,148,248,198,7,87,251,70,6,166,250,4,245,227,250,117,250,18,207,63,13,139,239,106,245,13,1,90,0,239,56,167,254,52,3,230,23,124,3,158,24,247,244,76,1,1,244,231,8,172,14,185,0,43,244,98,9,245,0,242,3,239,254,17,128,116,255,168,253,226,1,236,5,50,254,139,7,149,7,16,1,202,254,32,2,90,254,209,252,164,251,35,3,151,253,152,249,16,239,41,210,72,14,104,251,146,4,191,231,91,8,221,249,19,8,243,3,114,38,22,3,166,6,65,255,143,3,211,10,3,255,26,3,234,240,163,248,18,254,22,8,134,245,4,3,251,2,208,16,215,194,110,247,50,248,61,252,154,235,81,255,238,0,32,0,83,39,76,253,8,11,38,254,200,11,38,209,205,255,201,2,119,9,48,11,174,254,230,18,185,251,215,0,97,203,254,255,192,2,240,2,194,198,116,5,228,1,52,2,138,252,249,252,181,251,7,3,245,251,125,6,11,252,162,251,193,1,54,3,173,55,74,204,196,251,173,251,120,249,228,3,216,1,189,8,72,254,162,4,176,4,192,247,148,250,187,251,146,248,43,2,184,254,43,250,14,248,170,1,160,247,124,254,196,177,5,5,98,4,218,2,125,6,216,249,220,247,114,11,81,1,190,255,55,6,237,33,57,9,146,0,90,5,22,0,91,5,151,255,162,239,115,1,60,204,72,1,21,5,29,252,105,14,22,25,177,255,129,250,128,254,60,3,72,3,86,3,10,1,198,4,28,3,218,253,39,253,67,251,169,255,12,2,46,4,62,87,227,246,62,2,168,2,144,253,207,1,207,15,20,255,114,0,252,3,76,253,39,6,192,254,99,243,222,0,8,2,228,3,56,8,228,234,235,184,175,251,72,255,223,251,216,41,51,246,28,228,253,246,53,5,225,11,183,0,217,4,75,225,12,244,152,5,9,0,105,250,211,245,103,10,17,1,250,0,2,3,28,253,43,26,79,213,197,227,105,0,89,244,77,251,101,6,72,232,26,230,165,3,10,250,146,2,52,10,1,21,165,255,190,255,80,19,209,11,163,10,155,252,142,0,36,41,130,38,49,255,0,12,206,245,0,0,81,0,54,4,88,8,246,254,223,0,163,3,127,254,215,3,5,4,108,0,242,8,21,254,61,104,53,2,116,255,106,253,168,2,98,247,221,252,247,252,6,255,45,254,98,0,128,11,248,207,162,239,50,247,20,253,228,247,172,18,2,254,35,255,148,5,238,231,133,10,94,24,66,240,10,1,140,25,198,9,27,20,215,237,12,7,238,214,171,242,199,9,95,8,124,248,29,241,90,14,245,16,226,251,198,243,20,251,192,253,119,3,52,101,251,252,162,4,36,2,162,253,24,253,29,252,40,5,5,254,23,1,11,7,109,246,112,3,225,255,251,255,79,6,2,3,214,209,38,4,154,251,216,1,215,254,162,208,83,251,120,7,62,252,217,4,44,9,28,9,25,244,25,6,4,15,208,2,125,254,115,1,126,11,150,4,213,246,220,4,164,39,172,249,244,209,35,5,225,255,181,248,122,13,203,249,60,20,112,12,202,245,243,255,130,0,107,0,41,1,113,0,129,250,6,114,224,253,83,255,222,3,145,3,200,248,34,252,206,4,8,1,104,7,194,228,154,255,72,247,242,14,35,247,93,236,94,0,188,206,180,1,165,232,221,6,221,6,44,253,74,9,24,10,216,2,2,252,150,227,156,2,232,2,252,253,164,1,166,209,246,0,179,250,102,9,90,14,222,245,102,6,35,244,158,246,245,5,120,227,202,251,236,6,48,36,78,48,202,0,2,0,40,253,172,2,75,254,166,5,38,242,60,3,198,247,80,245,196,3,76,255,124,25,202,8,2,2,242,252,163,2,138,5,39,212,200,10,126,240,223,253,168,35,55,230,212,253,82,248,239,237,107,255,58,255,254,242,217,249,202,231,144,2,162,2,111,1,17,7,155,0,250,235,221,23,196,253,63,19,168,5,193,248,100,6,200,33,218,7,13,35,15,12,188,39,34,0,97,251,244,255,223,251,192,0,117,244,10,4,138,254,196,9,102,36,6,240,156,235,108,254,2,252,78,250,169,250,253,2,87,251,6,6,46,1,199,250,222,255,169,5,154,5,162,8,148,1,51,243,168,224,83,5,89,226,136,35,37,220,152,4,113,227,32,2,18,221,55,253,200,255,63,10,221,255,87,6,164,8,197,6,56,253,209,250,192,254,82,248,88,44,4,251,36,241,218,253,8,2,16,237,38,2,208,5,176,3,4,42,242,252,11,22,169,245,143,230,84,242,195,244,88,7,22,230,45,9,0,1,184,1,188,0,20,223,28,238,175,9,155,18,241,248,255,253,60,239,63,249,34,229,192,1,206,229,118,251,74,19,47,253,89,21,129,5,201,221,126,252,98,239,146,235,210,240,223,224,194,6,72,14,174,4,209,13,33,0,251,15,216,247,34,226,136,4,106,11,87,3,26,251,200,245,254,252,83,253,156,255,191,253,193,236,232,252,197,247,141,37,3,10,232,19,255,23,180,242,74,222,68,16,12,127,188,254,155,1,222,255,71,253,50,3,185,255,22,9,114,255,35,252,24,250,102,1,252,254,207,14,193,253,93,0,224,0,208,0,179,251,255,127,123,4,53,255,223,7,205,1,156,2,216,254,244,242,218,255,208,2,31,252,229,6,192,250,43,5,136,2,27,252,217,2,69,2,93,1,93,3,13,248,255,6,162,247,202,252,111,250,52,3,101,230,213,252,164,194,112,252,227,18,220,5,164,253,15,2,87,252,128,253,40,251,84,18,235,4,174,0,248,208,194,1,4,32,236,10,253,235,59,6,26,2,155,255,38,255,205,21,111,1,116,245,21,1,63,8,158,10,178,5,155,0,156,255,212,12,14,254,233,38,31,250,160,215,110,251,217,20,8,4,157,197,130,4,190,253,3,210,79,252,108,253,157,2,36,9,242,251,240,5,201,2,103,10,166,1,38,251,126,7,22,255,255,248,212,249,241,254,4,234,38,248,79,208,8,249,191,238,12,245,205,243,36,239,126,0,209,24,169,246,216,247,68,3,10,246,9,2,22,251,150,3,119,17,240,253,147,16,153,253,125,13,229,229,248,6,22,3,144,51,188,2,66,1,209,252,161,23,222,254,160,3,159,251,5,250,146,252,130,251,124,5,69,1,238,253,77,254,2,255,220,252,24,246,77,2,247,32,193,251,136,192,131,253,8,250,49,1,215,249,130,2,85,167,117,255,39,5,76,2,249,243,32,3,171,253,128,250,130,251,73,12,156,252,172,12,20,252,236,3,77,250,158,210,51,238,197,241,110,252,142,16,142,253,185,15,155,12,25,2,67,239,218,7,235,2,59,6,63,6,106,23,227,252,113,252,38,11,158,242,216,222,149,248,211,254,158,247,145,255,246,253,196,248,3,12,232,240,5,250,142,2,193,0,0,212,185,21,48,1,13,2,90,1,55,245,156,251,110,4,162,32,84,207,1,252,46,226,66,245,18,250,137,19,200,5,241,251,10,254,175,5,74,2,244,3,10,251,147,48,127,3,145,4,210,1,56,214,235,240,29,17,254,6,255,2,240,248,231,253,223,251,186,246,246,247,8,39,166,252,224,249,90,253,28,241,16,250,241,5,230,0,76,249,106,52,118,248,45,252,200,12,92,4,53,238,209,253,192,254,48,47,128,53,226,254,140,2,116,9,189,6,235,254,213,0,234,251,106,6,192,253,22,250,51,252,35,250,77,0,25,2,162,253,120,4,88,253,200,253,80,4,128,8,55,252,121,6,240,252,83,4,224,251,197,255,25,234,64,0,137,46,78,255,255,33,160,14,20,1,206,255,249,205,98,4,6,232,109,7,73,254,221,2,173,26,185,11,195,255,19,252,232,14,147,15,252,241,246,252,209,8,69,47,196,0,228,53,99,1,127,5,221,3,101,0,17,4,220,3,250,4,58,250,153,251,40,5,70,254,124,13,75,249,220,4,46,254,156,252,189,254,246,1,219,4,186,255,129,3,190,3,221,10,68,246,20,3,232,2,220,207,87,4,72,210,60,254,34,253,118,76,211,255,184,253,173,246,194,252,91,2,124,1,19,3,110,244,254,7,220,9,157,246,187,2,208,239,51,6,61,2,76,2,238,0,168,255,31,0,234,254,0,128,107,251,23,253,155,2,68,255,197,4,143,254,251,254,66,1,250,247,139,2,100,0,212,247,59,1,22,6,84,2,105,254,110,255,46,251,6,135,185,255,121,2,24,2,191,250,27,7,143,2,168,2,83,250,236,1,15,251,244,250,244,6,188,255,240,3,215,0,244,177,247,253,180,243,0,255,193,0,148,3,197,1,86,0,116,0,108,0,238,5,116,250,35,250,176,2,157,2,172,4,213,249,82,252,100,3,36,3,110,0,102,4,202,0,62,4,220,91,46,4,169,249,235,2,218,255,140,255,152,4,42,2,199,246,240,3,61,4,180,7,254,248,160,255,208,1,82,174,72,251,239,240,46,254,131,247,157,9,60,9,93,252,84,253,240,11,49,253,88,252,119,3,179,243,236,3,173,27,87,244,79,219,22,20,107,218,150,0,174,0,60,2,72,247,122,254,76,5,160,0,212,213,208,8,190,8,242,0,127,6,229,1,90,48,212,4,176,2,164,244,60,4,23,4,242,18,184,255,126,253,68,6,152,0,174,252,158,2,200,3,121,243,154,6,105,0,44,246,19,45,134,1,163,251,180,253,237,213,63,11,134,18,97,223,35,6,174,252,163,253,89,248,139,1,36,48,214,6,242,8,164,255,6,3,175,244,1,4,207,248,34,2,64,15,68,15,230,44,9,0,60,5,56,209,243,253,242,5,213,255,213,255,188,248,240,231,57,255,175,9,241,17,196,244,87,244,20,4,194,255,212,252,184,40,71,246,182,251,28,3,244,250,234,247,72,4,104,248,159,247,234,238,17,4,10,252,76,35,162,247,72,1,216,223,152,0,232,203,79,247,148,53,145,254,210,253,106,248,161,0,40,254,176,8,20,253,222,13,215,252,19,254,73,8,210,4,4,3,26,20,181,9,22,247,122,29,95,250,59,6,216,35,64,24,12,5,168,6,128,15,36,250,74,248,65,242,246,244,149,0,121,252,248,1,69,255,84,252,121,0,41,255,153,253,255,254,94,248,190,3,9,8,65,255,10,83,42,253,33,8,254,4,134,6,170,252,170,10,60,224,238,253,236,3,14,10,150,5,24,246,157,213,109,5,155,0,116,255,110,8,202,10,223,14,10,15,112,241,70,252,154,211,197,2,135,57,2,2,182,2,169,255,89,3,7,255,93,254,105,2,94,254,136,251,224,255,122,247,185,252,169,5,208,251,239,252,10,255,66,53,200,48,102,1,65,254,42,247,158,3,255,3,123,252,167,254,212,8,6,250,70,250,99,244,134,247,42,8,44,0,76,164,91,2,52,249,167,254,74,254,68,244,42,5,240,243,250,4,85,1,164,254,234,253,31,4,210,11,92,252,2,2,254,34,127,195,138,254,53,4,142,4,48,0,248,3,106,252,229,255,102,254,246,254,135,250,208,240,154,244,158,247,255,10,42,7,149,252,162,0,90,253,84,7,15,248,207,7,202,205,229,249,192,0,158,1,14,3,219,243,152,5,155,239,54,9,69,33,16,3,232,4,174,250,122,11,165,211,192,235,182,215,217,255,122,247,106,249,241,0,61,255,24,255,231,231,206,0,181,0,42,254,240,3,169,253,228,254,221,2,188,252,136,2,118,255,30,8,57,1,112,95,36,2,71,254,166,5,164,249,62,251,192,255,52,253,104,246,195,7,160,254,255,251,97,248,40,5,94,1,232,2,38,10,40,252,104,184,110,2,252,255,220,249,125,3,29,244,243,238,127,0,255,255,30,255,96,249,52,5,176,250,100,26,36,10,27,47,114,1,150,241,241,1,73,2,83,6,246,252,214,35,2,248,166,8,212,7,109,4,45,4,132,0,6,255,237,249,118,252,49,2,152,205,241,251,186,224,84,7,252,8,164,251,103,7,246,6,150,14,172,251,58,5,127,250,8,255,245,62,78,250,156,0,190,245,64,0,81,251,40,242,187,16,194,242,108,254,146,5,117,252,48,245,244,252,222,255,32,183,211,7,3,2,99,12,115,253,250,2,232,242,102,255,109,251,60,254,202,249,208,232,7,2,186,4,246,1,103,254,214,8,183,2,4,4,204,33,228,9,180,245,144,13,94,251,70,5,117,253,129,253,190,32,94,243,118,2,173,215,19,247,132,248,58,3,87,250,30,253,168,254,254,3,80,243,71,174,56,255,56,2,172,255,9,3,222,249,60,245,18,11,26,0,38,15,83,249,101,0,153,5,66,247,49,1,61,0,239,251,95,9,116,2,27,250,124,254,178,3,221,2,254,249,118,253,223,77,222,1,56,214,82,3,86,253,191,1,7,9,35,0,22,251,28,9,103,211,207,6,190,252,148,2,98,12,74,9,82,245,6,253,129,251,246,248,148,219,17,18,0,9,94,251,156,4,30,19,150,2,101,228,101,3,101,2,10,7,231,18,84,13,172,234,162,252,150,239,196,30,223,251,56,11,200,250,195,6,220,213,64,4,105,13,42,0,85,252,175,9,25,25,223,3,171,249,150,12,96,246,172,11,227,255,225,1,86,45,16,245,133,223,236,29,199,242,193,4,40,253,170,241,172,2,9,247,44,253,201,253,154,247,150,255,128,248,161,247,137,13,176,7,191,251,79,209,112,245,233,11,185,250,57,28,95,22,243,253,79,10,163,7,211,8,89,25,181,248,8,6,129,243,128,236,116,9,23,16,212,244,223,218,152,247,220,39,147,251,79,251,68,250,83,244,50,18,66,2,91,4,112,1,34,6,248,252,9,254,18,6,49,5,72,253,8,253,63,2,9,250,231,240,180,32,206,242,55,224,56,223,113,242,194,248,12,237,150,20,134,253,96,2,9,5,20,226,119,19,14,251,234,247,118,252,219,12,155,9,199,18,111,239,141,22,46,247,108,238,74,10,136,204,12,25,26,1,39,233,38,1,142,253,120,3,192,251,144,2,192,0,138,253,179,242,75,207,66,11,136,8,80,15,155,10,60,229,169,251,101,3,95,255,85,1,64,7,22,219,159,10,189,253,0,241,197,221,129,4,52,242,197,253,2,253,109,32,120,11,251,214,207,251,84,39,142,244,164,24,69,245,21,12,82,249,231,240,72,250,161,238,190,1,130,3,10,21,206,251,213,237,61,24,199,1,19,249,10,251,74,27,67,246,236,15,109,41,38,246,209,3,2,16,129,4,78,254,231,15,182,244,104,11,215,35,228,8,91,18,130,2,213,251,56,252,252,1,40,249,216,2,188,12,12,254,134,5,178,21,201,10,181,7,160,237,79,8,117,5,210,251,56,199,241,196,84,29,57,5,86,16,158,244,107,241,126,10,42,254,201,8,195,240,164,5,221,14,99,0,21,249,158,254,121,252,61,245,59,253,140,236,214,0,66,245,116,253,238,251,154,5,190,251,156,253,242,245,250,4,30,5,8,253,140,5,144,255,216,10,21,237,212,58,191,236,154,240,167,233,164,249,138,251,207,11,101,250,122,5,242,3,111,2,57,242,64,10,184,0,220,3,98,0,84,1,36,65,18,251,118,251,111,12,48,237,176,253,251,3,130,250,82,246,67,9,20,252,104,15,35,3,33,22,43,247,43,64,93,1,41,12,108,252,186,1,38,249,33,242,185,250,27,6,220,250,20,2,87,1,120,254,229,5,51,253,134,255,158,9,95,252,71,255,85,253,164,182,122,10,133,255,6,2,133,254,216,235,245,0,148,7,140,54,233,207,78,2,226,255,159,0,234,249,108,248,36,0,8,250,253,253,102,251,88,3,117,254,29,0,34,233,113,205,230,51,244,245,25,4,0,3,220,12,175,240,204,255,50,254,176,7,69,19,118,2,162,3,2,4,46,10,63,1,235,254,189,24,185,247,164,237,116,8,47,6,154,0,59,8,69,250,83,1,122,2,168,188,173,253,59,242,126,245,4,249,36,254,215,255,165,0,8,252,80,250,164,254,25,44,152,244,36,241,53,9,236,46,8,15,4,7,116,8,77,234,175,17,55,255,197,3,227,236,91,13,41,25,155,6,179,255,92,1,255,252,183,106,167,254,176,254,227,253,192,254,204,3,158,3,254,251,28,4,190,2,224,0,76,0,230,2,220,0,148,24,177,33,98,241,43,16,155,232,17,234,127,253,25,255,187,252,12,24,45,16,208,14,138,18,244,38,8,7,115,254,67,247,86,247,85,226,55,245,16,254,85,250,154,4,54,252,54,251,223,9,199,247,242,6,166,5,194,7,242,38,205,204,39,252,138,251,169,250,183,254,110,238,78,2,36,0,25,8,211,251,94,3,133,0,212,9,229,255,142,17,174,210,154,249,220,9,169,5,52,22,157,253,20,219,198,245,142,19,153,13,129,253,123,1,227,246,14,254,55,253,126,1,16,3,13,1,196,233,162,254,12,2,239,182,238,251,187,250,186,4,234,6,124,15,44,19,149,251,127,68,236,252,152,248,30,0,134,245,20,4,68,6,100,241,18,0,235,6,75,1,183,16,74,10,144,254,65,254,173,228,56,251,80,253,8,235,20,255,88,221,145,9,99,208,113,17,103,7,180,9,35,5,186,234,55,254,193,253,101,0,52,9,207,249,132,12,152,255,180,227,114,249,223,252,196,245,5,238,156,209,5,249,146,11,252,248,199,242,101,254,164,22,84,11,206,253,67,3,37,1,215,27,75,19,209,2,100,244,30,254,121,0,122,245,27,247,156,1,226,49,170,254,206,2,234,12,246,1,143,227,205,254,40,2,246,27,217,12,69,236,110,20,95,251,208,11,82,252,189,250,229,254,143,201,48,255,16,10,118,252,56,7,60,22,126,246,175,0,157,30,80,7,72,238,243,242,67,252,195,57,194,249,98,35,192,14,151,1,58,249,235,4,61,244,125,255,251,241,154,253,16,1,104,244,181,249,61,14,66,224,72,8,4,19,170,234,77,204,132,242,67,232,200,19,199,249,141,250,133,246,141,251,66,252,49,6,206,250,130,8,246,252,217,13,20,11,32,30,105,23,80,254,247,13,161,3,241,224,115,0,132,8,64,15,63,255,20,6,4,255,111,252,14,10,172,46,83,238,111,5,191,222,188,17,241,205,205,242,188,237,46,7,212,233,41,5,232,231,117,5,252,3,182,1,115,255,96,13,136,1,0,254,178,249,140,250,194,254,109,246,9,6,36,228,29,249,88,254,247,13,196,252,16,75,186,7,88,6,79,248,125,249,252,252,17,248,243,252,196,6,244,0,44,255,160,1,132,3,0,221,234,3,203,251,59,18,57,242,50,6,203,204,118,246,245,14,6,17,32,4,144,11,193,251,106,253,167,18,84,231,13,24,104,241,8,248,69,255,136,3,230,4,132,253,240,7,34,253,9,251,125,245,48,13,52,2,167,225,150,234,72,3,91,55,60,233,58,252,149,6,48,216,124,254,78,254,122,14,82,2,140,8,109,1,209,0,42,1,33,7,20,255,218,49,108,6,127,12,44,254,76,50,130,0,135,247,178,242,13,242,209,237,35,9,5,42,12,5,104,11,33,1,198,254,177,253,161,249,14,249,240,250,2,255,213,1,64,219,130,4,78,1,252,255,126,248,227,10,61,1,160,1,89,249,251,54,65,6,126,2,44,247,51,252,200,252,0,11,118,244,210,12,124,241,142,252,137,242,242,11,211,229,209,4,177,0,251,13,180,13,45,242,241,214,83,29,184,29,120,248,178,9,49,253,230,8,47,20,100,38,76,41,205,241,66,245,79,13,140,255,15,13,152,242,209,242,214,3,135,3,89,243,68,254,218,249,179,254,141,37,134,248,236,253,87,7,178,255,232,185,139,228,50,6,206,243,104,1,111,254,195,4,218,247,250,11,110,3,148,22,76,252,102,0,160,7,162,1,96,254,234,3,100,5,17,5,164,255,128,253,213,253,121,251,155,144,35,249,72,253,124,0,150,253,54,6,44,1,170,253,156,3,66,255,58,249,156,239,31,235,12,201,83,23,101,32,218,240,88,250,15,249,82,255,153,3,237,249,158,252,48,2,232,0,134,248,94,240,252,252,168,7,175,236,96,13,92,25,91,14,224,252,226,20,52,17,129,253,201,41,95,6,90,250,139,238,132,225,137,14,216,18,148,253,75,4,116,244,55,20,107,246,226,236,2,10,206,248,76,19,111,5,2,11,71,4,67,239,69,25,82,248,28,199,72,247,80,2,194,21,134,245,91,10,70,18,236,226,173,246,156,26,43,206,224,233,214,255,134,0,211,244,12,249,98,255,130,5,130,236,161,2,35,8,177,245,203,11,254,255,113,32,67,248,190,247,202,255,76,11,123,6,191,197,182,255,188,251,93,251,161,9,86,247,23,3,160,253,5,12,26,0,184,251,100,249,162,12,52,228,213,248,132,235,142,1,153,39,186,2,250,8,242,1,148,27,30,25,113,5,236,9,231,1,2,250,122,248,237,235,97,13,181,17,203,19,233,253,100,252,170,3,249,248,248,62,245,7,113,241,203,252,170,11,10,9,33,255,78,5,9,0,137,10,242,248,84,252,210,241,205,248,40,245,58,247,68,2,114,249,123,9,78,8,113,248,140,11,81,3,58,71,126,2,86,1,12,4,249,0,232,255,153,10,75,248,122,255,139,238,34,248,238,231,192,178,191,2,206,255,247,8,10,247,179,7,155,4,246,3,70,9,56,250,233,5,118,2,6,6,140,96,206,13,110,11,150,2,186,244,247,253,164,254,146,1,88,4,141,254,51,6,30,7,88,7,4,5,46,1,81,7,4,5,100,252,20,25,42,18,50,31,171,1,105,1,172,223,48,1,121,209,231,250,30,248,189,0,2,1,71,3,82,252,223,1,166,243,85,251,142,251,24,6,198,248,72,235,108,216,219,214,235,250,181,243,88,253,56,0,164,16,45,229,186,250,186,251,151,250,39,7,254,255,83,252,156,14,21,30,169,252,232,12,116,13,141,238,13,1,4,240,76,2,133,54,226,249,23,242,144,7,0,11,166,11,12,7,150,10,163,1,173,2,116,17,232,1,208,218,78,245,134,15,6,217,111,249,142,246,36,9,51,253,125,252,217,244,26,215,6,4,214,246,77,234,255,9,132,8,52,235,40,7,54,40,86,1,54,44,184,246,192,240,12,250,34,241,54,4,152,248,31,28,62,242,84,5,243,8,113,252,100,255,25,239,246,252,13,137,191,253,98,255,48,2,189,10,31,3,129,10,81,1,211,254,62,251,219,4,175,2,144,252,93,254,40,0,232,254,4,0,42,7,180,38,161,7,152,1,56,4,73,34,21,15,40,2,6,229,38,242,246,229,35,0,145,248,180,18,216,19,49,11,23,255,7,4,89,238,72,202,143,246,50,249,35,227,119,12,142,253,101,254,73,227,247,11,247,248,231,238,98,244,132,255,218,10,173,10,93,1,89,251,128,230,93,249,251,26,239,0,51,245,182,233,43,14,48,8,236,255,237,8,252,27,195,13,194,210,32,14,154,253,122,24,227,254,59,14,226,5,81,14,237,4,222,246,162,1,58,236,29,19,129,11,131,7,82,244,77,238,102,221,209,10,91,236,154,8,9,13,207,41,204,2,238,21,122,197,194,246,217,234,25,0,127,249,1,17,244,11,145,247,237,3,205,249,144,254,75,252,28,245,39,4,27,5,197,255,210,255,63,231,244,1,86,251,98,11,68,9,143,250,134,248,236,14,120,251,121,255,193,14,185,200,88,20,14,247,106,22,250,3,129,1,91,7,190,245,183,219,58,4,22,6,36,249,160,10,249,253,6,205,168,241,223,6,243,255,143,13,231,15,167,232,167,0,142,239,171,8,64,5,148,246,145,17,222,228,148,2,70,34,187,243,192,23,130,238,216,9,159,253,248,243,27,253,184,30,4,29,179,254,130,4,199,248,198,5,204,1,174,254,5,230,80,246,156,6,56,8,106,6,160,10,249,3,199,10,226,248,148,245,39,247,5,252,34,221,207,5,221,2,232,196,167,21,138,239,124,228,154,2,196,27,174,8,106,246,131,19,244,19,201,5,194,8,111,22,25,254,197,37,39,1,211,13,228,18,231,1,251,249,56,3,198,232,36,26,144,254,146,250,41,232,193,17,111,10,16,208,88,12,248,2,224,247,195,13,64,245,132,244,50,253,154,8,109,234,42,9,52,234,113,236,68,24,226,234,172,211,248,4,13,21,27,9,107,14,96,251,255,241,108,238,165,253,218,255,91,235,237,253,236,18,246,240,104,15,131,230,165,233,247,246,39,252,111,3,66,2,111,243,240,241,2,245,152,5,48,45,75,250,31,249,242,239,248,239,153,255,245,248,75,20,59,250,68,5,107,0,62,15,191,4,194,13,180,242,138,35,19,255,68,0,34,0,36,246,248,208,217,231,74,8,214,1,23,251,90,1,24,255,67,249,25,23,11,250,15,233,54,7,152,211,19,4,253,251,105,16,232,240,58,239,76,30,55,7,152,241,255,127,48,247,16,0,108,8,11,1,104,4,114,5,112,248,24,254,107,254,167,254,44,4,66,2,224,5,88,251,107,254,36,1,125,4,147,16,152,0,12,4,246,6,95,10,203,164,180,251,115,248,98,1,198,3,238,249,149,4,94,251,239,1,106,2,241,3,101,245,205,1,86,23,171,3,224,13,45,5,57,13,68,252,129,8,53,8,111,255,24,252,22,9,162,9,6,11,206,61,187,253,55,253,46,17,60,3,79,243,154,240,198,7,162,252,224,8,92,1,100,244,241,0,138,245,167,248,221,168,161,1,181,253,56,1,24,1,36,246,76,9,43,1,91,15,178,0,94,11,16,246,156,254,238,252,34,2,183,255,162,252,240,0,139,249,6,5,221,240,232,247,59,250,160,65,132,251,51,8,144,12,54,20,129,8,226,11,228,252,158,1,6,254,115,3,45,7,171,5,48,11,82,3,91,9,98,254,182,12,111,248,5,192,120,240,130,8,63,250,151,18,192,252,186,34,252,12,19,244,105,254,6,250,81,254,60,251,128,0,112,242,212,3,52,0,132,198,196,6,139,7,138,230,8,249,151,212,114,17,232,255,145,222,105,0,102,21,236,239,91,247,66,244,202,6,163,239,238,12,15,253,77,7,68,2,139,252,17,12,210,31,130,236,223,248,244,253,36,14,248,228,109,2,216,251,25,18,27,250,80,0,59,213,64,245,220,1,156,241,219,13,81,248,36,13,71,11,39,253,241,30,136,239,159,241,175,199,118,240,5,1,134,251,156,251,123,252,9,3,15,3,254,255,35,252,210,249,148,15,105,30,29,231,46,247,16,13,98,1,233,51,11,13,60,1,142,243,216,247,97,248,54,1,223,253,64,253,216,255,64,17,120,254,247,251,18,22,99,0,64,244,124,241,144,9,82,241,247,36,255,248,126,255,169,6,101,25,90,247,154,11,20,215,52,2,192,232,227,253,29,8,166,255,188,25,214,244,59,249,225,219,167,254,158,243,122,19,25,13,252,236,169,34,113,0,153,235,26,6,93,255,114,246,149,238,140,224,82,4,125,213,161,4,36,249,104,255,37,12,181,0,109,250,99,32,155,44,135,231,68,8,43,254,30,20,75,5,182,0,28,253,11,3,182,225,76,7,144,0,96,15,196,255,240,252,25,255,111,3,136,66,31,247,94,7,230,253,247,3,6,7,135,253,66,4,118,7,128,0,50,232,102,248,222,249,41,253,231,183,242,1,16,3,189,238,120,6,235,255,154,0,126,9,231,14,215,255,108,245,198,249,228,0,240,252,116,28,60,254,46,226,188,205,236,13,97,21,36,251,183,8,28,0,225,16,72,250,122,5,178,250,193,8,144,2,152,251,136,4,208,246,57,14,88,253,24,7,208,26,214,255,245,4,232,254,15,251,0,248,238,0,115,253,3,53,34,15,243,254,41,31,190,8,34,251,238,247,133,18,170,6,170,13,83,2,255,9,55,0,81,2,145,6,76,6,43,0,60,245,142,10,135,9,89,246,215,252,98,7,136,66,237,252,72,239,143,4,122,248,147,236,99,251,52,245,201,239,146,11,116,13,76,3,142,9,189,54,254,12,85,251,219,248,52,6,229,6,188,243,114,33,167,199,200,15,211,7,30,253,248,251,14,243,68,247,36,2,0,3,212,246,180,1,219,6,31,0,248,237,235,4,13,1,7,6,143,250,218,20,177,191,84,11,80,246,123,6,217,0,24,233,38,15,148,20,220,4,248,253,78,251,214,4,182,0,231,251,73,253,192,254,80,229,240,232,98,11,200,245,26,10,50,213,70,243,202,248,231,237,67,9,179,12,1,242,71,10,190,239,219,11,158,10,104,2,74,11,206,0,0,63,211,3,223,13,48,229,107,243,249], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+307217);
/* memory initializer */ allocate([22,108,14,182,6,234,0,228,244,132,6,102,0,127,10,186,252,220,3,92,4,21,2,186,15,189,227,84,23,43,202,190,242,66,242,218,254,17,231,139,6,155,17,68,21,129,1,117,248,162,3,187,2,103,6,159,1,64,26,174,30,234,5,120,12,51,247,62,198,229,250,103,3,49,5,89,7,228,25,35,11,171,255,20,247,70,238,187,252,72,247,13,1,77,247,106,54,241,247,140,226,18,35,171,4,157,10,254,250,52,252,25,5,24,15,108,9,4,9,40,237,46,243,160,252,23,254,78,250,144,8,31,62,156,9,232,10,215,239,10,4,153,254,5,0,249,8,250,255,237,240,222,1,1,250,32,8,27,253,238,7,165,253,176,245,146,248,240,223,234,14,7,251,54,224,223,7,209,35,144,242,13,249,236,15,192,253,163,255,74,249,232,2,3,10,88,26,255,240,75,5,54,6,156,239,156,201,100,1,69,52,248,9,210,244,230,10,190,253,234,13,151,10,82,253,57,241,23,254,206,4,128,3,184,4,179,251,102,242,82,246,4,3,230,4,64,1,223,248,185,254,46,4,80,249,39,1,35,185,198,245,1,6,165,253,198,14,8,251,147,248,158,1,169,0,82,230,202,228,151,10,36,243,148,51,212,250,36,14,98,19,19,11,81,16,253,18,182,246,98,234,117,14,128,239,137,253,129,243,115,253,177,18,235,251,207,247,68,2,142,8,116,255,48,0,3,12,190,250,214,252,224,7,54,2,17,246,235,0,214,232,164,7,225,1,59,74,158,240,89,25,137,10,188,18,107,13,190,27,246,11,180,5,74,233,163,10,85,16,141,236,26,246,246,247,120,255,226,13,132,245,148,59,16,16,182,243,252,10,14,28,174,245,67,21,237,251,221,252,226,10,170,249,196,7,244,252,202,5,41,205,30,249,159,250,91,240,161,0,160,218,230,31,40,7,74,1,172,230,177,3,220,238,66,4,244,253,20,6,186,253,64,1,2,3,86,252,203,221,209,3,60,4,106,228,224,13,7,3,156,237,23,247,216,253,213,216,167,16,173,4,96,253,163,255,84,22,15,241,82,238,245,6,71,38,98,17,189,7,179,243,64,218,47,12,210,14,165,255,54,26,72,3,182,251,46,44,139,244,17,3,243,245,236,2,11,7,135,250,245,249,234,239,81,3,188,253,132,250,0,6,90,219,182,249,31,9,147,1,133,244,57,244,87,241,87,226,104,6,18,13,222,245,164,224,109,21,141,8,215,242,58,8,249,20,243,245,253,253,179,5,84,27,64,5,123,254,159,228,92,40,184,252,227,240,133,3,207,230,212,246,99,246,249,239,214,252,244,247,16,4,117,0,241,125,25,255,177,3,231,3,97,251,180,0,163,5,188,0,87,3,158,249,6,3,54,255,99,0,178,6,30,1,175,252,176,7,241,217,158,195,165,252,114,241,209,8,99,1,89,255,118,249,16,7,24,254,94,4,120,250,107,249,112,11,191,5,135,251,232,253,3,9,52,252,89,251,89,6,100,250,122,1,210,78,130,253,34,7,216,1,212,254,179,252,235,251,50,4,239,251,2,254,217,255,4,2,196,17,181,10,43,216,224,246,244,14,45,8,204,239,78,220,143,16,216,9,48,242,33,241,182,11,78,247,14,229,230,18,248,9,24,248,53,234,90,5,186,45,54,226,30,6,221,3,186,236,191,250,182,232,163,16,134,4,128,241,106,245,243,251,105,0,83,245,44,4,98,14,64,15,252,7,184,0,25,2,146,242,160,250,76,1,148,69,158,243,82,9,214,247,153,13,184,250,175,1,8,252,218,251,204,253,40,249,214,245,19,5,64,26,21,3,251,4,183,217,200,20,23,9,48,240,91,17,116,225,88,4,208,4,141,251,104,252,24,253,179,252,86,241,70,23,244,234,8,13,6,242,69,240,176,2,125,228,120,255,93,255,141,250,88,52,193,6,186,248,52,10,65,1,222,240,179,3,34,252,164,243,223,44,46,0,70,248,165,247,198,4,57,15,64,218,108,14,55,21,220,242,134,241,180,0,87,240,3,10,199,254,156,12,161,249,221,217,32,220,86,232,14,238,16,4,5,243,65,1,95,243,171,19,129,248,107,234,107,7,172,4,214,248,121,254,37,2,190,247,100,250,192,245,137,9,106,2,42,148,183,252,88,252,43,4,133,4,230,0,16,3,13,253,6,7,37,255,254,251,161,251,64,1,205,245,154,250,72,34,127,4,155,14,161,253,181,11,232,225,18,233,8,7,77,5,109,19,54,218,194,235,206,255,138,252,8,8,222,252,139,248,62,2,76,249,12,231,190,244,58,242,140,243,225,253,244,0,176,37,9,20,51,236,86,2,167,220,42,7,209,242,89,5,181,5,241,250,132,254,238,254,90,28,119,219,159,246,139,46,33,236,225,5,115,16,49,253,122,252,226,6,88,255,130,2,187,2,237,247,91,252,68,4,66,252,203,2,70,248,80,248,179,249,17,251,247,252,146,4,76,218,158,218,100,2,161,240,237,0,130,1,141,16,68,250,68,216,156,236,103,11,228,230,240,227,119,0,26,14,59,0,96,12,158,234,171,252,153,233,27,249,247,11,184,250,176,3,114,248,84,242,66,36,32,23,16,3,90,0,19,1,139,12,114,9,134,222,254,214,22,248,4,252,83,244,231,5,215,255,58,211,68,248,176,20,54,10,235,255,2,3,100,255,255,244,116,237,32,222,119,13,193,227,246,17,189,250,79,253,130,243,178,1,56,0,239,247,6,7,193,53,235,253,0,251,228,252,177,9,56,0,97,5,159,234,156,35,95,251,166,253,243,9,147,241,80,221,162,11,133,35,37,7,236,18,119,253,60,1,94,255,240,5,74,233,252,18,199,0,206,250,194,235,131,231,82,10,196,4,0,11,254,239,115,240,48,204,114,254,105,1,208,10,78,237,255,3,159,255,143,2,115,254,99,9,216,249,126,254,168,251,24,3,85,251,9,253,230,2,217,2,156,244,4,252,102,83,230,255,7,242,147,2,17,251,98,5,13,239,88,7,234,18,99,253,77,251,48,23,48,3,92,223,76,14,137,6,91,253,190,246,116,6,6,34,26,251,27,24,44,229,133,252,160,229,87,255,210,233,92,226,81,243,166,11,161,20,179,236,153,254,230,242,83,3,183,249,70,212,98,2,5,1,112,248,155,10,44,242,72,246,38,8,222,23,146,3,104,243,241,6,234,249,169,3,152,14,219,243,111,7,154,16,130,238,76,10,244,8,85,250,247,39,176,29,150,8,89,247,53,247,82,248,252,249,45,254,147,1,111,6,205,244,227,245,222,255,246,246,166,253,67,9,54,10,170,8,66,246,75,14,148,10,204,251,110,252,233,0,125,4,145,5,63,1,45,252,255,3,86,253,110,0,239,0,171,1,191,2,93,244,47,246,167,245,39,247,252,28,14,2,126,8,116,11,204,244,248,247,72,247,115,6,211,250,168,252,38,255,43,8,202,1,228,5,72,251,179,252,244,0,71,254,46,2,240,2,68,253,166,250,117,254,212,3,191,254,24,255,15,255,37,1,151,40,0,249,100,248,18,250,231,251,43,0,244,5,241,7,126,246,47,1,194,6,75,251,104,250,97,251,74,253,161,4,29,246,160,245,65,245,36,249,215,250,180,251,31,1,157,33,204,244,6,246,209,2,239,247,121,249,253,252,163,2,175,8,126,245,59,246,247,246,37,7,117,12,45,0,33,7,232,7,175,243,248,244,87,245,252,246,150,6,142,254,226,1,46,10,100,244,236,246,188,9,30,249,130,249,28,0,112,19,142,12,47,245,196,254,134,251,94,248,86,0,196,255,142,254,120,4,143,21,7,249,254,249,236,251,188,253,167,255,192,2,127,4,230,245,186,251,49,29,60,251,204,251,206,255,5,4,58,7,218,13,207,12,242,248,89,251,240,253,170,2,136,4,61,5,220,244,5,6,202,246,207,248,243,246,185,250,225,3,113,9,141,245,178,9,243,247,215,247,97,14,114,2,83,6,26,7,156,244,5,11,78,246,138,247,196,251,113,4,161,21,48,11,61,246,10,249,108,8,254,9,163,251,127,0,123,4,20,6,244,245,25,15,40,248,243,248,89,253,119,0,35,0,39,5,112,245,176,248,36,249,187,26,113,252,66,1,105,6,157,9,164,245,91,248,180,7,210,249,10,12,84,0,62,4,207,5,89,244,235,246,36,245,28,246,190,248,233,254,108,39,167,17,196,246,158,10,141,248,118,10,19,252,246,0,219,5,143,6,246,245,75,34,44,248,165,249,180,252,89,0,176,6,97,8,244,12,29,249,150,249,3,11,169,253,9,0,138,3,121,5,15,247,80,247,158,9,212,249,181,252,197,9,232,255,30,5,19,12,47,249,94,9,16,251,37,253,113,0,63,3,48,5,13,245,180,246,8,245,181,246,14,247,160,250,22,255,194,8,209,13,167,247,254,247,20,251,65,11,177,0,134,4,144,5,25,243,205,243,198,243,211,244,229,247,224,9,213,255,50,15,222,243,144,245,6,246,41,7,198,252,55,0,46,19,252,12,153,15,128,247,114,246,200,248,238,252,18,13,54,6,242,7,91,245,247,254,47,1,52,4,63,248,77,14,20,6,191,7,146,243,104,245,84,244,231,244,204,250,208,18,22,25,88,16,74,247,32,251,128,247,242,248,175,249,146,252,180,14,29,5,24,247,253,1,45,255,170,1,5,3,99,0,1,2,116,2,167,0,196,0,48,247,246,248,123,251,212,2,125,5,103,5,80,9,103,254,96,253,59,254,51,255,167,255,244,255,240,0,114,0,84,247,217,252,234,250,180,249,107,254,110,4,101,5,187,2,232,248,153,247,165,248,159,11,160,3,247,5,29,6,7,3,163,247,67,248,4,250,177,253,10,13,171,2,227,6,210,1,20,248,218,247,168,5,146,253,77,2,14,5,126,4,145,0,178,246,187,251,145,254,218,3,67,1,148,1,163,3,141,254,204,244,79,245,201,247,129,0,3,3,218,5,182,7,55,250,220,251,162,246,155,251,29,1,217,10,159,11,151,5,96,245,212,6,185,246,201,248,112,252,245,14,40,3,242,7,68,246,113,246,32,251,33,252,169,5,24,5,99,3,147,4,73,244,4,246,53,245,6,247,31,13,181,16,199,7,34,11,124,245,176,245,223,245,21,7,54,254,252,11,244,3,1,8,70,243,252,244,227,244,165,246,227,10,211,255,81,21,240,13,69,246,190,247,164,248,6,0,180,254,24,255,144,6,115,4,240,7,177,246,121,247,67,249,110,252,192,0,79,16,11,8,150,244,100,244,152,244,94,247,137,251,58,7,164,9,79,7,190,243,157,255,165,245,50,246,127,255,119,2,141,6,133,7,26,243,204,243,114,243,185,243,200,245,7,253,138,15,138,16,94,249,200,252,73,248,26,253,145,9,158,253,21,0,230,3,25,244,119,245,69,245,129,248,247,249,110,29,219,4,220,13,185,248,23,251,83,1,253,251,122,0,155,253,197,7,185,3,72,247,33,249,41,249,55,252,201,249,125,7,187,254,121,3,219,52,2,251,87,247,92,248,176,250,132,252,118,253,158,252,1,255,192,0,141,251,38,251,203,247,110,249,191,249,134,11,36,9,121,0,150,2,190,1,180,245,175,6,103,2,184,248,239,250,182,251,216,254,46,4,4,5,123,3,164,28,12,247,226,246,159,248,110,251,92,7,198,253,52,0,122,4,176,3,221,247,112,247,140,246,139,247,250,249,62,250,234,254,51,16,226,5,130,6,246,3,135,249,79,247,43,247,120,33,91,250,245,253,141,255,231,3,90,2,54,245,43,247,15,1,251,248,159,249,234,252,135,1,139,3,22,5,52,4,141,248,85,247,117,246,85,248,41,250,242,250,114,18,167,3,155,6,90,5,205,246,207,249,50,246,7,247,130,10,45,250,121,253,104,1,180,5,199,5,7,248,112,1,214,40,3,251,52,253,84,255,230,253,225,254,169,0,24,255,192,3,193,251,101,246,108,247,91,251,81,248,206,249,241,252,155,20,251,10,13,250,59,249,187,246,102,248,206,249,0,251,70,254,51,255,26,9,175,24,77,246,189,247,171,245,32,248,72,250,89,0,17,2,58,5,171,20,114,12,138,22,249,246,120,245,140,246,149,253,238,246,242,32,127,255,125,6,208,4,159,250,3,251,87,251,150,1,204,250,34,251,25,252,15,254,0,4,220,5,25,245,119,250,131,247,115,9,44,250,34,253,235,10,47,2,238,2,7,2,102,245,3,254,14,18,95,14,218,254,73,0,219,252,90,2,157,255,94,0,158,245,64,248,251,26,12,249,36,251,16,1,106,3,140,0,46,5,181,2,137,245,30,247,9,246,39,52,197,245,218,17,53,249,5,9,0,5,211,4,13,252,220,247,80,248,132,250,8,10,75,12,176,254,14,1,243,1,250,1,225,249,64,247,131,245,97,248,50,247,223,10,125,250,174,34,17,9,155,6,249,245,110,246,244,245,18,247,10,248,245,248,220,250,197,254,208,1,199,4,60,248,97,252,13,248,117,8,79,14,105,252,184,254,229,0,254,255,217,0,43,245,144,247,179,245,121,247,217,19,102,250,246,5,14,11,162,6,129,4,6,245,148,251,32,21,56,248,171,16,179,250,41,3,51,2,9,0,192,255,123,244,149,27,252,17,112,250,209,248,158,253,5,255,114,1,133,3,147,0,40,247,63,12,169,12,178,251,115,254,244,250,39,0,17,0,124,1,127,1,53,250,78,250,52,3,87,8,122,253,33,254,173,0,23,0,238,254,70,254,46,252,64,251,120,248,92,28,31,251,68,252,232,255,250,0,182,1,128,0,240,15,152,0,117,10,181,253,101,253,96,253,106,253,20,254,46,253,80,253,141,248,237,252,29,12,132,250,46,251,4,254,233,14,168,1,145,2,170,255,125,247,169,253,93,8,90,250,201,248,245,16,223,252,230,255,199,255,216,0,167,249,222,252,216,6,235,250,57,10,247,249,255,253,111,254,234,0,146,2,19,5,1,251,106,3,128,250,145,251,216,255,89,254,138,1,148,2,172,2,13,13,87,252,206,248,103,251,153,7,147,253,19,0,163,255,141,0,197,255,190,245,40,13,204,249,89,248,30,250,145,14,165,254,218,0,241,1,73,2,65,246,108,246,186,247,66,2,31,255,122,1,40,0,56,4,140,3,249,2,234,247,185,249,230,9,1,250,213,5,104,10,215,0,122,2,61,1,23,255,92,16,90,250,175,247,236,248,108,250,213,249,242,251,97,0,221,3,246,7,87,14,109,245,208,245,106,247,161,251,65,6,18,4,45,5,206,4,125,4,250,245,226,251,75,14,131,247,20,249,55,253,200,251,155,255,219,3,37,3,237,249,19,253,26,250,115,13,134,250,76,16,72,253,181,1,20,1,219,0,81,245,107,246,222,247,58,15,157,252,186,253,42,253,110,4,203,4,97,4,29,9,61,252,62,250,82,9,65,252,185,254,118,255,4,0,12,1,223,1,183,244,176,244,115,245,73,248,175,253,188,4,231,5,63,4,202,5,76,6,89,249,10,19,46,0,172,250,194,250,224,253,145,252,57,254,24,254,116,254,200,245,81,3,136,246,72,248,45,250,29,253,69,1,4,5,39,7,199,4,208,255,79,250,181,247,218,250,81,6,216,251,180,9,45,254,21,2,195,2,95,1,166,1,243,253,111,253,202,0,36,254,133,0,89,253,79,252,192,252,114,7,91,244,211,245,137,248,19,246,33,45,207,249,19,6,148,8,80,6,147,245,215,246,137,246,200,248,36,249,54,19,57,253,162,4,81,7,119,5,96,253,135,250,12,250,142,251,94,253,5,5,195,0,116,3,135,254,213,251,179,247,121,1,45,249,188,249,69,3,178,254,141,255,197,255,160,0,227,1,84,247,61,50,159,249,176,249,98,252,77,251,143,255,166,255,122,1,148,0,108,22,88,0,58,247,194,249,246,249,98,249,230,10,184,255,78,2,28,0,208,245,216,16,212,251,19,12,136,253,117,253,110,1,63,0,232,2,119,1,210,6,193,10,229,247,171,249,247,251,41,254,204,3,199,0,63,2,143,2,156,247,103,9,124,247,28,249,250,251,191,251,243,15,176,255,161,1,128,1,172,4,20,247,11,246,21,249,251,252,213,0,164,4,20,3,63,5,78,5,232,245,43,30,133,247,3,247,39,250,74,254,233,3,110,0,159,2,171,3,35,25,145,22,27,249,249,250,99,251,10,252,87,0,105,252,90,254,68,254,118,248,42,19,132,249,234,249,33,14,103,251,5,1,9,0,5,1,209,255,21,246,189,10,84,246,6,247,233,251,217,250,171,254,164,253,63,8,219,10,137,244,147,19,188,248,197,246,106,249,247,251,32,3,238,6,164,6,198,5,3,45,228,252,48,250,151,248,160,248,101,249,25,249,254,248,170,249,70,251,20,247,39,245,178,246,165,250,18,255,181,11,110,12,76,2,105,4,192,2,248,0,167,6,248,254,230,250,133,251,208,253,23,250,68,252,131,6,60,5,100,20,28,247,89,247,255,247,57,250,242,250,250,252,66,0,246,4,27,8,101,250,67,248,238,246,152,248,215,250,50,254,138,0,158,19,245,9,147,6,156,255,48,249,8,250,89,254,205,23,195,255,224,254,145,253,118,253,196,252,15,250,134,0,216,4,137,250,86,250,100,2,55,252,25,10,177,3,200,254,142,251,72,246,47,246,60,248,185,249,251,252,56,13,168,4,91,10,20,10,40,252,33,248,71,250,216,249,225,8,59,251,91,0,55,10,72,3,19,5,211,251,153,247,149,248,33,253,184,1,120,3,15,255,246,1,185,3,29,14,14,7,193,248,1,247,34,249,218,250,52,250,246,255,85,2,139,14,200,7,24,254,241,247,20,247,132,247,143,248,245,249,87,252,238,255,204,12,16,28,106,248,2,247,161,246,76,248,158,250,133,253,46,1,57,4,78,21,30,13,65,254,217,252,205,0,243,248,246,249,66,254,220,24,108,252,151,0,135,254,186,253,168,252,52,255,37,253,140,252,94,253,255,254,189,255,28,6,182,9,235,3,28,250,100,249,235,5,135,252,146,253,62,9,9,0,239,255,11,255,149,14,223,251,228,254,125,12,225,255,72,254,165,251,183,249,214,248,118,248,230,0,6,1,176,28,217,255,46,249,206,253,238,249,210,248,144,249,226,250,109,8,80,0,154,255,238,0,201,252,146,253,48,253,141,255,238,254,16,0,230,249,7,249,1,250,178,254,44,10,60,13,102,254,153,255,164,254,114,255,140,6,71,254,37,247,60,248,115,250,88,253,22,5,122,10,127,1,246,255,207,5,194,251,5,255,146,251,141,0,172,255,21,252,126,252,95,0,0,9,34,3,243,249,230,249,90,10,132,8,64,0,0,254,192,252,63,253,83,254,34,7,21,247,72,248,3,251,139,10,248,1,249,0,247,255,178,0,223,255,179,250,142,251,189,11,37,1,229,0,97,6,59,255,228,253,35,251,175,249,11,251,239,25,133,9,121,253,35,250,183,251,229,251,130,251,97,251,75,250,71,0,249,5,31,11,125,4,63,253,191,250,187,249,139,253,151,253,196,255,223,247,101,250,170,3,76,3,225,251,183,252,155,4,136,1,88,4,178,3,28,251,64,249,246,254,151,27,201,250,104,252,232,251,206,0,48,0,149,253,156,18,18,1,90,9,225,252,226,252,21,252,2,251,248,248,166,249,121,250,14,254,159,5,107,6,70,248,22,251,144,251,5,5,247,255,84,2,141,0,93,247,140,3,34,3,42,254,155,251,144,12,22,255,100,254,3,0,44,252,15,0,233,251,250,5,148,2,194,7,32,254,13,254,218,253,35,253,237,253,46,5,185,249,19,3,144,251,22,252,191,255,102,1,231,2,253,0,218,254,170,13,247,251,10,251,234,252,25,2,252,6,53,1,184,255,39,251,49,248,97,2,165,11,255,251,150,249,66,252,5,15,59,251,62,252,59,252,180,249,55,248,223,255,144,251,62,4,210,255,154,4,27,255,139,0,132,2,206,2,96,249,107,9,251,3,224,251,52,0,224,0,25,254,117,254,216,255,125,0,185,11,93,248,98,248,240,252,169,251,129,3,254,253,159,0,17,3,71,4,128,11,6,246,153,246,73,248,136,253,6,4,176,6,110,1,207,1,125,0,206,246,228,252,31,22,225,251,129,251,154,252,92,1,92,253,167,5,215,0,19,252,5,250,114,252,201,8,74,254,73,11,107,0,108,254,241,254,234,253,2,252,187,247,54,249,213,8,255,254,236,252,32,0,211,6,172,4,142,3,33,0,1,0,233,255,28,0,231,255,19,0,13,0,227,255,233,255,208,255,117,252,191,247,70,248,110,250,233,253,53,6,116,7,164,10,110,6,127,252,246,2,22,9,162,2,87,250,111,0,220,0,219,1,94,255,71,250,12,248,240,253,28,5,217,247,17,248,228,250,183,0,35,0,73,4,240,3,72,7,188,247,1,247,120,248,251,254,38,9,220,254,200,5,12,1,46,6,55,4,97,251,126,251,247,252,53,1,194,4,171,2,34,5,141,6,10,253,47,249,142,5,205,250,154,249,180,251,209,254,139,19,199,255,133,254,1,254,12,253,41,253,245,246,188,248,17,249,92,253,14,15,189,255,204,255,226,7,252,5,96,255,59,255,181,255,114,248,146,251,233,7,18,7,21,254,83,0,134,2,134,1,215,254,71,254,170,254,33,254,26,254,216,254,226,255,187,1,127,4,180,13,231,23,19,254,109,250,143,250,7,251,0,251,105,249,109,249,25,250,245,19,16,252,143,251,130,253,119,253,170,254,178,253,34,254,191,253,163,254,189,253,244,9,49,254,59,8,200,253,90,253,236,252,58,254,160,253,60,254,142,7,205,5,46,249,17,252,106,251,195,253,239,0,137,255,167,2,180,255,105,249,164,7,126,252,35,254,200,1,100,255,180,5,13,0,92,0,37,252,42,2,44,245,238,245,98,249,21,255,241,2,247,5,82,4,3,6,62,5,231,250,160,25,10,250,27,249,231,252,168,253,248,0,226,253,193,255,91,254,220,18,8,5,212,249,222,248,117,251,10,252,35,255,206,252,147,255,195,255,241,4,147,7,15,251,98,254,120,7,66,255,123,251,93,253,12,253,89,252,225,9,136,0,83,249,65,249,229,248,32,250,48,251,65,252,104,4,46,16,103,248,142,11,124,252,104,250,72,249,156,250,125,1,193,5,211,4,38,4,219,3,250,255,147,253,36,255,122,246,125,254,233,253,233,255,90,252,188,255,135,236,63,2,227,1,75,28,205,251,149,3,203,6,216,248,188,253,28,6,131,0,76,255,9,251,88,14,161,0,16,4,201,6,159,10,77,4,71,255,126,250,221,0,90,254,29,222,15,253,111,254,244,234,13,0,250,2,98,5,89,4,232,6,79,255,69,13,114,8,11,1,213,8,100,255,172,6,176,252,177,255,229,248,169,243,84,234,23,253,40,28,241,251,131,29,122,255,101,10,192,247,222,8,57,248,185,1,152,231,246,0,166,0,44,8,134,250,14,255,224,202,229,253,135,1,91,9,249,42,43,252,154,42,109,254,55,3,111,6,218,254,93,0,248,1,184,234,189,4,199,248,251,243,22,3,183,252,12,50,254,211,166,248,219,252,238,254,176,7,207,255,165,4,176,255,231,254,216,255,153,1,119,9,69,2,174,250,207,0,155,252,179,253,222,12,194,254,16,238,36,254,246,3,121,255,177,185,62,255,39,3,126,244,34,255,44,0,254,253,201,238,79,251,131,4,21,255,98,0,80,17,170,254,82,9,122,5,68,252,29,13,167,7,182,18,117,255,90,242,72,239,179,253,26,223,107,1,22,253,128,2,152,254,17,252,180,251,203,224,170,206,238,3,184,249,160,252,30,255,109,252,16,248,250,4,84,2,72,7,43,4,61,6,204,1,45,248,72,234,172,224,50,9,123,1,177,243,44,0,112,27,70,253,171,244,112,19,159,3,199,4,163,255,172,0,189,0,239,25,62,232,42,253,244,253,4,244,38,241,16,0,241,251,151,255,29,9,162,254,206,254,133,254,192,252,2,5,56,0,201,13,50,2,165,253,66,23,38,1,15,251,109,31,106,240,87,255,133,255,61,243,60,2,145,252,26,6,95,251,31,3,139,218,151,1,178,253,65,0,224,244,177,1,85,234,237,255,12,28,32,225,120,254,67,1,64,254,127,238,67,241,90,235,165,7,226,0,8,248,220,12,171,11,88,249,19,11,107,255,155,5,55,3,239,6,47,245,146,0,234,0,125,255,241,255,12,1,37,0,139,0,22,0,60,255,91,0,81,242,211,234,24,0,232,254,58,0,114,1,143,2,132,5,113,0,50,1,20,64,22,255,59,1,67,252,72,0,151,251,201,7,225,182,121,250,69,5,36,9,29,2,57,1,176,250,31,0,161,5,178,255,79,217,119,254,111,1,56,253,39,248,116,1,215,254,133,255,47,1,54,254,189,254,46,0,253,33,235,250,192,221,213,255,26,7,212,0,225,253,43,236,155,224,24,246,190,2,24,3,131,254,240,254,149,7,176,24,177,248,142,201,250,254,241,247,108,0,163,252,229,1,72,254,0,3,33,22,210,254,49,1,40,202,73,11,129,255,162,255,145,0,28,5,231,30,72,223,125,253,172,253,77,5,81,252,49,5,172,255,194,255,115,6,135,1,9,247,176,234,155,254,253,237,81,5,121,15,217,254,130,2,70,253,166,33,77,6,242,253,136,255,51,255,17,0,53,177,228,4,251,254,23,2,36,251,92,0,197,254,110,3,124,1,157,0,145,12,19,254,251,252,1,2,2,254,40,44,125,252,229,255,142,1,14,231,147,2,23,252,79,245,17,204,195,4,10,252,63,255,189,1,167,246,88,1,231,255,169,253,224,244,116,3,94,0,245,255,204,253,220,255,211,38,54,242,206,1,82,252,105,39,56,3,178,11,219,254,71,0,183,39,55,254,199,2,60,252,176,247,226,9,160,0,2,246,147,9,118,6,12,241,24,6,111,3,1,252,94,223,83,3,179,255,144,255,116,76,218,7,203,251,207,250,254,250,253,4,252,0,10,234,9,18,58,0,245,246,53,254,31,251,92,0,196,2,31,253,5,243,182,0,21,6,111,253,34,2,65,254,173,74,109,6,176,254,230,255,7,248,38,23,138,18,182,248,82,15,238,10,200,20,7,0,214,1,74,3,229,0,201,253,230,2,22,243,147,2,153,252,30,255,223,245,21,252,163,250,83,2,0,253,178,80,176,3,204,4,23,1,5,250,150,253,105,1,77,240,169,254,161,254,231,27,37,1,92,0,103,245,243,254,226,255,180,254,253,15,216,0,239,0,205,253,151,7,80,252,36,247,70,0,47,255,184,1,213,5,66,254,235,1,150,254,25,0,181,254,177,1,207,249,173,0,102,4,226,241,22,255,167,245,157,4,127,253,96,255,143,14,183,252,170,247,140,250,130,233,242,255,108,1,213,237,127,4,194,0,142,235,246,22,188,250,148,250,23,255,226,14,164,252,7,37,232,255,40,230,107,5,57,254,191,1,32,255,75,244,12,0,174,13,183,255,214,1,46,220,141,6,28,253,176,253,154,249,163,2,163,255,78,186,214,6,177,252,225,3,167,246,207,255,19,248,148,7,76,2,219,1,117,242,55,0,223,19,173,11,124,1,147,3,34,245,114,9,39,44,74,4,241,3,92,5,108,233,209,254,171,5,204,3,247,226,197,253,125,6,64,0,25,40,5,6,206,255,60,252,30,253,3,255,223,243,73,253,222,253,249,252,229,181,234,243,181,246,226,2,89,6,111,2,49,4,14,3,211,2,167,242,190,253,67,255,12,16,91,4,58,251,114,220,128,237,91,1,178,3,66,1,141,241,193,0,221,196,111,1,201,3,236,252,74,253,148,253,230,255,240,255,4,0,34,254,56,81,105,251,25,255,6,10,10,251,162,0,181,0,85,250,6,235,131,246,50,221,46,241,81,233,137,249,248,0,80,17,113,5,109,246,110,245,24,253,175,2,74,3,255,250,144,11,212,246,153,0,121,249,103,250,30,251,184,251,197,9,239,234,170,16,182,251,112,3,65,251,49,3,69,254,69,39,193,2,79,253,137,245,75,251,26,243,215,252,106,252,19,252,124,0,183,254,108,0,204,255,71,235,93,254,128,0,55,224,147,5,131,1,21,255,234,245,190,0,83,255,249,251,112,10,39,252,237,12,217,232,159,28,241,222,254,255,147,23,231,2,40,2,242,255,188,253,188,255,146,209,220,1,61,0,148,4,239,253,36,252,103,3,248,252,180,254,134,81,128,1,115,30,178,213,211,2,154,6,249,253,194,3,151,2,20,5,47,254,47,0,6,242,56,0,61,224,249,7,180,222,233,250,205,24,111,7,186,229,132,4,32,255,6,5,205,246,169,242,217,3,10,254,86,246,49,0,27,245,224,241,85,249,35,13,116,255,166,6,129,248,2,211,108,254,62,0,235,228,93,251,78,42,132,0,28,1,129,253,69,5,63,9,201,254,142,253,233,2,28,22,104,255,135,255,140,235,31,254,1,23,17,251,5,223,223,255,168,3,167,1,139,255,111,0,225,251,153,255,191,254,6,5,157,253,9,3,59,3,166,1,94,255,145,229,15,255,33,1,71,254,192,250,146,10,20,251,215,237,177,252,21,193,249,254,222,248,247,253,8,253,174,3,53,1,124,245,29,237,171,252,218,252,236,254,190,254,15,22,195,4,79,254,166,254,109,251,252,251,191,0,106,254,188,1,33,0,16,1,174,13,219,1,126,247,123,7,222,254,243,251,65,3,73,253,135,255,159,1,44,2,1,4,36,247,78,1,31,11,24,249,123,254,46,201,218,240,68,3,253,17,63,248,153,254,198,5,107,255,55,3,98,252,196,252,135,0,213,1,123,253,184,254,162,255,78,255,4,11,13,3,199,246,110,233,32,5,78,15,255,255,186,241,82,252,65,246,103,2,210,0,146,189,116,254,67,254,126,1,51,2,54,249,95,0,109,220,5,19,92,1,15,2,56,22,111,255,85,251,193,246,19,253,69,255,41,26,27,0,91,1,27,49,192,255,85,254,181,14,56,3,64,251,154,251,109,23,74,2,110,0,218,254,16,255,110,6,70,255,80,5,157,1,197,230,1,250,120,243,248,253,147,253,165,33,74,4,237,255,57,255,74,211,111,253,159,254,138,3,166,2,81,180,130,255,152,6,132,2,207,4,153,247,26,253,64,1,188,255,118,207,66,245,203,5,189,249,177,245,212,11,102,10,116,255,29,21,107,252,105,254,207,0,176,36,199,253,163,3,132,255,174,255,226,24,221,1,24,208,69,4,99,13,36,253,206,255,232,0,189,255,97,2,79,6,49,254,71,2,16,7,219,5,3,254,145,160,231,0,184,255,64,255,179,254,126,226,170,254,180,220,208,254,136,0,166,195,53,5,133,251,48,250,96,250,75,0,63,0,235,2,41,1,5,255,30,0,211,254,238,248,170,255,32,2,50,215,20,5,228,40,218,0,89,246,190,7,167,1,230,11,168,251,111,253,152,255,175,41,210,255,55,213,195,231,5,251,180,7,169,3,181,255,182,254,239,253,235,245,230,5,167,248,164,250,67,249,205,56,208,253,140,252,178,3,205,254,89,236,118,30,66,255,208,2,245,5,29,0,100,3,214,4,116,1,50,254,163,9,155,245,161,10,22,250,211,2,34,245,18,254,240,0,21,228,75,2,239,2,77,6,46,43,50,4,19,1,204,3,54,252,27,0,181,255,24,0,247,255,163,0,88,0,21,0,87,0,178,255,25,253,128,255,224,246,21,255,25,253,178,240,179,254,64,4,61,255,90,255,14,3,137,255,65,243,92,2,107,8,254,254,254,250,127,255,43,0,252,235,40,254,173,2,93,200,242,250,157,255,126,248,228,254,90,254,168,251,134,243,71,248,168,5,93,254,252,227,20,0,186,255,54,8,0,0,22,1,90,7,235,216,76,6,132,23,71,0,115,255,3,4,213,255,160,252,64,254,247,172,176,254,214,247,87,20,162,2,210,2,6,4,87,5,171,7,169,23,216,3,193,251,150,241,47,0,195,255,104,0,175,255,127,3,22,0,216,2,65,255,147,12,108,20,229,255,222,252,158,5,190,220,184,250,187,253,144,3,104,253,233,255,246,253,112,252,178,0,165,253,59,2,62,2,150,1,52,2,175,0,107,254,107,244,208,251,213,6,67,252,110,254,215,36,113,6,103,254,35,1,133,22,40,3,98,26,215,2,219,255,2,255,250,5,213,0,181,12,101,1,115,1,45,0,4,251,112,207,239,10,124,248,80,255,173,251,73,255,198,0,78,14,20,0,114,251,203,9,100,242,185,252,135,61,0,0,64,62,246,40,220,62,186,73,44,63,206,25,97,63,39,49,136,63,112,206,160,63,14,190,184,63,220,215,209,63,30,167,232,63,131,47,0,64,94,75,12,64,94,75,24,64,94,75,36,64,166,155,48,64,200,7,61,64,62,232,89,62,96,118,207,62,43,246,7,63,65,241,35,63,154,153,73,63,215,163,96,63,154,119,140,63,165,189,169,63,215,52,199,63,121,233,214,63,60,189,234,63,227,165,7,64,122,165,20,64,99,127,29,64,76,55,41,64,196,66,57,64,242,65,79,62,104,34,172,62,52,128,247,62,159,171,45,63,30,167,104,63,72,225,138,63,163,1,156,63,38,228,179,63,9,27,206,63,232,106,227,63,38,228,251,63,190,48,9,64,74,12,22,64,34,253,34,64,172,139,47,64,227,165,59,64,106,222,241,61,158,94,105,62,19,242,225,62,182,132,28,63,66,96,69,63,202,84,113,63,27,158,142,63,76,166,162,63,27,158,190,63,192,236,222,63,204,238,249,63,229,97,9,64,193,57,23,64,23,217,34,64,218,172,46,64,121,233,58,64,68,139,236,61,150,67,139,62,199,41,250,62,32,99,46,63,163,1,92,63,207,102,133,63,203,161,157,63,79,175,180,63,185,141,206,63,240,167,230,63,4,231,252,63,187,39,11,64,132,13,23,64,156,162,35,64,32,210,47,64,93,254,59,64,248,83,227,61,12,147,169,62,152,110,242,62,206,170,15,63,157,128,54,63,160,137,80,63,127,251,130,63,78,98,168,63,193,202,201,63,24,38,227,63,21,140,250,63,249,15,9,64,166,155,20,64,37,117,34,64,7,240,46,64,156,162,59,64,12,147,41,62,31,133,171,62,217,206,215,62,36,151,15,63,200,7,45,63,67,173,89,63,231,251,145,63,56,103,180,63,148,135,205,63,217,206,215,63,122,199,225,63,202,50,0,64,233,38,17,64,133,124,32,64,179,123,46,64,136,244,59,64,79,30,22,62,254,67,186,62,186,218,234,62,32,65,17,63,31,244,60,63,41,237,93,63,20,63,118,63,239,56,149,63,211,188,187,63,100,59,223,63,238,124,247,63,228,131,6,64,63,87,19,64,100,204,33,64,252,24,47,64,57,69,59,64,245,74,217,61,19,97,131,62,5,163,242,62,91,211,44,63,105,0,95,63,222,2,137,63,229,208,162,63,129,149,187,63,68,139,212,63,36,185,236,63,35,219,1,64,145,15,14,64,181,166,25,64,57,214,37,64,165,189,49,64,25,226,60,64,138,142,228,61,215,18,114,62,177,80,203,62,138,176,33,63,140,185,91,63,186,73,132,63,175,148,149,63,254,67,170,63,103,213,199,63,91,211,228,63,171,207,253,63,255,33,13,64,176,3,23,64,170,241,34,64,127,251,46,64,188,116,59,64,66,62,136,62,189,82,214,62,193,57,3,63,171,207,37,63,165,189,97,63,66,96,141,63,111,129,164,63,161,214,180,63,143,228,202,63,190,48,225,63,165,78,248,63,171,62,11,64,222,147,23,64,211,222,32,64,50,85,44,64,117,2,58,64,135,22,25,62,177,191,140,62,183,209,224,62,229,97,33,63,28,235,82,63,26,81,130,63,55,137,153,63,126,29,176,63,46,144,200,63,115,215,226,63,239,201,251,63,201,118,10,64,77,243,22,64,19,97,35,64,227,165,47,64,36,151,59,64,17,199,186,61,33,31,52,62,173,250,156,62,96,229,16,63,145,237,76,63,216,240,116,63,25,115,151,63,181,166,185,63,126,29,208,63,2,188,229,63,36,185,0,64,20,208,12,64,183,98,23,64,48,187,35,64,224,190,50,64,211,77,62,64,21,140,10,62,122,165,140,62,41,203,208,62,222,2,25,63,120,11,68,63,12,147,105,63,57,214,141,63,201,118,174,63,51,51,203,63,13,113,228,63,155,85,247,63,243,142,7,64,32,65,21,64,94,75,32,64,161,248,45,64,61,10,59,64,130,115,70,62,142,6,208,62,18,20,255,62,181,166,25,63,212,43,69,63,181,55,104,63,118,224,148,63,94,186,177,63,180,89,205,63,16,233,231,63,231,29,247,63,23,183,5,64,0,111,17,64,99,127,29,64,17,54,40,64,50,85,56,64,36,40,62,62,58,146,171,62,165,78,224,62,131,47,28,63,197,143,65,63,12,2,91,63,75,234,132,63,188,150,168,63,160,137,200,63,7,95,216,63,101,170,224,63,234,4,252,63,237,158,16,64,252,169,33,64,114,138,46,64,190,193,59,64,170,96,212,61,228,20,93,62,244,108,214,62,237,13,30,63,45,178,77,63,227,165,131,63,118,224,156,63,221,36,182,63,133,235,209,63,136,133,234,63,238,235,0,64,36,185,12,64,78,98,24,64,100,93,36,64,36,185,48,64,56,103,60,64,102,102,38,62,150,33,142,62,236,81,216,62,39,160,25,63,208,179,73,63,144,160,104,63,184,64,138,63,177,80,163,63,11,181,190,63,155,85,223,63,93,220,254,63,248,83,11,64,195,211,23,64,9,249,36,64,176,3,51,64,13,113,60,64,153,42,88,62,53,94,186,62,120,122,21,63,190,159,58,63,9,27,78,63,94,75,128,63,203,161,157,63,200,7,181,63,8,61,203,63,150,67,227,63,191,125,253,63,83,150,9,64,97,50,21,64,113,61,34,64,36,185,48,64,237,158,60,64,23,183,17,62,167,121,135,62,97,195,211,62,92,143,34,63,141,151,78,63,243,142,115,63,77,243,142,63,92,32,169,63,204,238,201,63,44,212,226,63,7,95,248,63,84,227,9,64,252,169,21,64,118,224,32,64,155,85,47,64,163,35,61,64,103,213,231,61,143,83,116,62,215,18,210,62,103,213,23,63,130,226,71,63,31,244,124,63,80,141,151,63,115,104,177,63,157,17,205,63,162,69,230,63,105,0,255,63,98,16,12,64,30,167,24,64,188,150,36,64,96,229,48,64,47,221,60,64,165,189,1,62,239,56,133,62,121,88,200,62,153,42,24,63,65,130,66,63,3,120,107,63,46,255,137,63,131,192,162,63,195,211,195,63,53,239,224,63,116,36,247,63,73,157,8,64,167,232,20,64,125,174,34,64,75,200,47,64,227,165,59,64,187,39,79,62,77,243,174,62,211,222,224,62,168,53,29,63,59,112,62,63,22,251,91,63,95,7,142,63,180,89,173,63,53,94,194,63,223,224,211,63,52,162,228,63,178,46,2,64,44,101,17,64,7,240,30,64,142,117,45,64,24,149,60,64,65,241,227,61,145,237,124,62,45,67,188,62,197,143,17,63,184,30,69,63,123,131,111,63,26,81,138,63,183,98,159,63,242,210,189,63,210,0,222,63,98,161,246,63,80,252,8,64,12,147,21,64,228,20,33,64,213,231,46,64,67,173,57,64,195,100,42,62,253,246,181,62,54,171,14,63,242,65,63,63,8,172,108,63,63,198,140,63,113,172,163,63,129,149,187,63,212,43,213,63,44,212,234,63,70,37,1,64,78,209,13,64,227,54,26,64,237,13,38,64,35,219,49,64,244,253,60,64,130,115,6,62,102,102,134,62,42,58,242,62,102,247,36,63,178,157,79,63,118,224,124,63,67,28,147,63,21,29,169,63,5,52,201,63,153,42,232,63,134,56,254,63,105,111,12,64,5,197,23,64,255,178,35,64,176,3,47,64,145,126,59,64,143,228,242,61,90,100,155,62,32,65,1,63,178,157,47,63,182,243,93,63,41,92,127,63,142,117,145,63,198,109,172,63,96,229,200,63,164,223,222,63,249,160,247,63,110,163,9,64,220,215,21,64,254,101,35,64,177,225,49,64,224,156,61,64,28,235,226,61,30,22,138,62,43,24,245,62,10,104,34,63,108,120,74,63,207,102,117,63,152,110,146,63,216,240,172,63,227,199,200,63,245,74,225,63,75,89,246,63,65,241,7,64,64,19,21,64,250,126,34,64,229,208,46,64,48,187,59,64,94,186,201,61,140,185,107,62,235,115,181,62,47,110,19,63,111,18,67,63,203,16,119,63,95,41,147,63,139,108,167,63,102,102,198,63,127,106,228,63,149,212,249,63,252,24,11,64,229,208,22,64,137,65,36,64,8,172,48,64,184,64,58,64,254,101,247,61,86,159,139,62,165,78,224,62,115,215,18,63,173,250,60,63,180,200,86,63,60,78,129,63,247,228,161,63,174,71,193,63,100,59,223,63,138,31,251,63,233,38,9,64,48,42,21,64,129,4,33,64,86,125,46,64,77,243,58,64,46,255,33,62,178,46,142,62,184,30,229,62,162,180,39,63,250,237,91,63,64,19,129,63,101,25,146,63,243,31,170,63,172,139,203,63,61,44,228,63,129,38,250,63,27,158,10,64,242,176,20,64,23,72,32,64,78,98,44,64,164,223,58,64,150,67,11,62,252,24,147,62,131,192,234,62,233,38,33,63,238,90,66,63,172,173,104,63,48,76,134,63,127,251,162,63,59,1,197,63,47,110,227,63,43,246,247,63,111,129,8,64,116,70,20,64,147,24,32,64,130,226,43,64,138,142,56,64,235,115,181,61,35,74,59,62,54,60,189,62,91,211,28,63,180,89,85,63,94,186,129,63,120,122,157,63,195,211,187,63,118,79,214,63,132,158,237,63,90,100,3,64,2,43,15,64,16,88,25,64,108,9,37,64,110,163,49,64,71,3,60,64,223,79,77,62,43,24,181,62,215,163,240,62,114,249,31,63,86,14,61,63,25,226,104,63,228,131,150,63,227,199,176,63,234,4,196,63,242,210,213,63,136,99,237,63,152,221,7,64,157,17,21,64,61,155,33,64,235,226,50,64,2,188,61,64,150,178,76,62,155,85,159,62,51,196,241,62,7,240,54,63,120,11,100,63,192,91,128,63,210,111,151,63,90,245,177,63,102,102,206,63,224,45,224,63,45,67,244,63,185,252,7,64,53,239,20,64,107,43,34,64,176,114,44,64,64,19,57,64,0,145,254,61,93,109,133,62,192,91,224,62,143,194,21,63,125,63,69,63,222,2,121,63,9,138,143,63,187,39,167,63,88,202,194,63,251,203,222,63,31,244,244,63,193,168,8,64,50,119,21,64,226,233,33,64,5,163,46,64,3,9,58,64,134,201,212,61,34,108,120,62,53,94,218,62,211,222,32,63,242,176,80,63,86,125,126,63,181,166,153,63,184,175,179,63,113,172,203,63,204,93,227,63,31,133,251,63,42,58,10,64,205,59,22,64,138,31,35,64,74,123,47,64,42,169,59,64,113,172,11,62,217,206,119,62,148,246,198,62,79,30,22,63,61,44,68,63,10,104,98,63,12,2,139,63,99,127,169,63,98,161,198,63,200,7,229,63,142,6,0,64,46,255,9,64,95,41,23,64,106,77,35,64,97,50,49,64,39,194,58,64,245,219,23,62,161,248,145,62,38,83,229,62,83,150,33,63,186,218,74,63,232,106,123,63,242,210,149,63,63,87,171,63,205,204,196,63,40,126,220,63,223,224,243,63,168,87,6,64,21,140,18,64,255,178,31,64,205,204,44,64,206,136,58,64,251,203,110,62,240,133,233,62,81,107,10,63,247,6,31,63,73,157,64,63,211,77,82,63,97,195,115,63,104,145,149,63,202,195,194,63,35,74,219,63,243,31,234,63,11,36,4,64,139,253,17,64,181,21,31,64,32,65,45,64,254,101,59,64,3,9,10,62,27,13,160,62,24,149,4,63,126,29,56,63,17,54,108,63,71,114,145,63,32,65,169,63,118,224,188,63,177,80,211,63,69,216,232,63,130,226,255,63,122,165,12,64,20,208,24,64,75,234,36,64,117,147,48,64,6,18,60,64,174,216,223,61,10,104,98,62,152,221,243,62,200,152,43,63,234,4,84,63,33,31,116,63,183,98,143,63,188,150,176,63,180,89,205,63,251,203,230,63,127,217,253,63,254,67,10,64,50,230,22,64,120,122,37,64,195,245,48,64,96,118,59,64,219,249,62,62,127,251,154,62,250,126,234,62,163,1,44,63,61,10,87,63,179,12,129,63,50,85,152,63,220,104,176,63,2,188,197,63,197,32,216,63,60,78,249,63,161,214,8,64,155,230,17,64,36,185,32,64,168,198,47,64,230,63,60,64,174,71,33,62,229,242,159,62,95,7,238,62,165,78,32,63,100,59,79,63,100,93,124,63,235,115,149,63,9,27,174,63,208,68,200,63,179,12,225,63,113,61,250,63,196,177,10,64,29,56,23,64,150,178,36,64,135,22,49,64,238,235,60,64,105,111,240,61,178,46,142,62,224,190,238,62,243,31,34,63,92,32,81,63,147,58,129,63,197,32,152,63,217,61,177,63,69,71,202,63,167,232,224,63,98,16,248,63,124,242,8,64,127,217,21,64,212,154,34,64,160,26,47,64,0,0,60,64,26,192,219,61,103,213,103,62,179], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+317457);
/* memory initializer */ allocate([12,209,62,167,232,24,63,155,85,63,63,243,142,115,63,103,68,145,63,174,182,170,63,219,138,197,63,237,13,222,63,98,16,248,63,190,48,9,64,188,5,22,64,159,205,34,64,140,185,47,64,27,13,60,64,153,187,22,62,188,116,147,62,207,102,245,62,247,117,32,63,27,47,77,63,112,206,128,63,182,243,149,63,169,164,174,63,82,184,198,63,23,217,222,63,157,128,246,63,81,218,7,64,209,145,20,64,31,244,32,64,72,191,45,64,186,218,58,64,41,203,16,62,248,83,131,62,54,171,222,62,13,113,28,63,244,253,68,63,252,24,115,63,123,131,143,63,193,202,169,63,88,202,194,63,116,70,220,63,90,100,243,63,67,173,5,64,17,54,20,64,40,126,32,64,140,74,46,64,94,75,60,64,110,52,0,62,231,140,136,62,120,11,228,62,52,162,36,63,48,76,86,63,83,150,129,63,12,2,155,63,125,63,181,63,59,223,207,63,99,127,233,63,1,77,0,64,52,162,12,64,9,249,24,64,173,250,36,64,118,224,48,64,172,173,60,64,57,69,7,62,248,83,131,62,75,234,196,62,230,174,21,63,46,255,65,63,200,7,109,63,82,39,136,63,193,168,156,63,49,8,188,63,95,7,222,63,205,204,252,63,120,11,12,64,190,193,23,64,242,65,35,64,141,151,46,64,47,221,56,64,24,38,19,62,25,4,150,62,174,182,226,62,246,151,29,63,182,243,77,63,153,187,118,63,92,143,146,63,153,42,168,63,220,215,193,63,221,36,222,63,5,52,249,63,78,209,9,64,127,217,21,64,143,228,34,64,40,15,47,64,211,188,59,64,196,66,45,62,242,210,141,62,175,37,196,62,246,40,28,63,236,81,72,63,150,33,110,63,254,212,136,63,190,193,159,63,111,18,187,63,247,6,215,63,223,79,245,63,45,33,11,64,231,251,21,64,205,59,34,64,197,32,48,64,169,164,58,64,145,237,252,61,164,223,126,62,192,236,222,62,124,97,34,63,115,215,82,63,69,216,128,63,34,108,152,63,154,119,172,63,149,101,200,63,133,235,233,63,207,247,3,64,165,78,16,64,201,118,26,64,220,215,37,64,189,227,48,64,211,188,59,64,100,59,223,61,112,206,72,62,38,83,197,62,19,242,17,63,125,208,51,63,124,97,98,63,149,212,145,63,176,114,176,63,49,8,204,63,54,205,227,63,140,219,248,63,209,34,11,64,193,168,24,64,124,242,36,64,235,115,49,64,202,50,60,64,119,190,31,62,188,5,178,62,23,72,0,63,124,242,32,63,1,222,66,63,109,86,125,63,248,83,147,63,168,198,171,63,104,145,197,63,171,62,215,63,190,193,239,63,153,42,4,64,36,185,16,64,93,254,31,64,9,249,44,64,22,106,57,64,207,102,21,62,254,101,119,62,230,63,196,62,31,133,11,63,76,166,74,63,218,27,108,63,62,121,136,63,151,255,152,63,58,146,179,63,79,175,212,63,199,75,247,63,109,86,9,64,159,171,21,64,182,132,32,64,123,131,43,64,23,217,58,64,118,79,30,62,38,83,197,62,118,79,30,63,117,147,88,63,206,170,135,63,18,20,159,63,46,255,177,63,61,10,199,63,0,145,222,63,250,126,242,63,69,216,4,64,57,69,15,64,138,176,25,64,18,131,36,64,62,121,48,64,246,40,60,64,27,47,221,61,159,60,108,62,206,136,210,62,177,80,27,63,143,194,69,63,238,90,114,63,176,114,144,63,37,6,169,63,84,116,196,63,44,101,225,63,144,49,255,63,234,4,12,64,99,238,22,64,199,75,35,64,215,18,46,64,226,233,57,64,190,193,23,62,174,182,162,62,45,33,255,62,238,90,34,63,171,62,71,63,145,237,124,63,220,215,153,63,58,146,171,63,186,218,194,63,136,99,221,63,155,230,245,63,3,9,6,64,60,189,18,64,27,13,32,64,159,171,45,64,154,8,59,64,250,126,234,61,244,253,148,62,81,107,250,62,249,49,38,63,142,6,80,63,207,247,115,63,160,26,143,63,78,98,168,63,242,176,192,63,251,58,216,63,62,232,241,63,107,154,7,64,138,176,21,64,220,70,35,64,159,205,46,64,154,8,59,64,165,78,192,61,31,244,44,62,102,102,166,62,116,70,20,63,157,17,69,63,8,172,108,63,175,37,148,63,213,120,177,63,116,70,204,63,9,27,230,63,116,181,253,63,122,199,9,64,82,73,21,64,188,116,35,64,214,86,48,64,224,190,58,64,0,145,254,61,109,86,125,62,140,219,200,62,196,177,30,63,222,113,74,63,55,26,112,63,95,41,147,63,146,203,175,63,25,115,199,63,219,249,222,63,101,25,250,63,47,221,8,64,106,188,20,64,214,197,33,64,88,202,46,64,60,189,58,64,112,206,72,62,201,229,191,62,111,129,4,63,216,129,35,63,92,32,81,63,9,27,134,63,236,47,155,63,240,133,177,63,48,187,199,63,225,122,220,63,137,65,240,63,87,91,5,64,170,241,18,64,193,168,32,64,176,114,44,64,128,183,56,64,166,155,4,62,52,17,118,62,198,109,212,62,59,112,30,63,163,146,74,63,94,186,105,63,76,166,138,63,113,172,163,63,63,53,190,63,154,8,219,63,39,160,249,63,144,160,8,64,51,196,17,64,130,226,31,64,243,142,47,64,216,240,60,64,111,18,131,60,116,70,20,61,192,236,30,60,17,199,186,59,52,128,183,186,215,52,239,187,153,187,150,187,23,183,209,187,20,63,70,188,108,9,249,58,33,31,116,60,88,57,52,189,202,50,68,189,154,119,28,189,166,155,68,189,43,24,149,188,150,67,139,60,17,199,58,60,33,31,244,188,41,92,143,188,208,68,88,187,151,255,16,189,96,229,80,189,10,215,35,187,145,126,251,60,5,197,15,61,222,113,10,61,49,8,44,61,101,25,98,60,41,92,143,188,231,29,39,188,159,171,173,59,39,160,9,60,82,73,157,185,85,193,40,61,124,242,48,187,104,145,109,60,36,151,127,187,185,252,7,60,10,215,35,61,23,183,209,56,98,161,214,188,88,57,180,59,75,89,6,188,114,138,14,61,87,91,49,61,247,117,96,60,82,73,29,187,88,57,180,187,98,161,214,60,207,102,85,61,77,243,14,61,80,141,151,60,108,9,249,59,147,169,2,189,29,201,101,189,127,106,60,189,242,65,207,188,192,236,30,188,148,135,133,60,153,187,150,60,179,123,114,187,166,155,68,189,43,246,23,189,73,157,128,61,39,49,136,61,179,123,242,60,17,199,186,187,242,65,207,60,90,245,185,60,41,92,15,61,187,184,141,61,100,59,95,61,234,149,178,60,117,2,26,60,16,233,55,189,7,95,24,189,111,18,3,58,134,90,211,60,202,84,65,60,213,120,233,60,227,165,155,61,121,88,168,61,245,219,87,61,216,240,244,188,46,144,160,187,150,67,139,60,119,190,159,60,137,210,94,60,140,74,234,60,177,191,236,60,211,188,99,60,124,242,176,59,108,9,121,60,130,226,199,60,52,128,55,59,52,128,183,187,244,253,212,188,145,126,251,60,140,74,106,61,114,138,14,188,224,45,16,60,95,41,203,59,0,0,0,0,205,204,76,60,0,0,0,0,215,52,239,188,158,239,167,61,234,149,178,61,1,77,132,61,187,184,13,61,108,9,249,59,224,45,16,187,242,65,207,188,66,62,104,189,117,2,154,188,39,160,9,189,149,212,137,189,211,222,96,189,185,252,135,188,61,44,212,188,66,96,101,188,111,18,131,59,237,13,62,187,197,32,48,189,99,127,89,189,242,65,207,188,108,9,249,186,30,167,232,187,9,249,32,61,250,237,235,59,111,240,5,189,202,84,193,188,18,131,192,188,151,255,144,188,7,95,152,188,66,96,229,188,193,168,164,188,72,80,252,187,118,224,28,61,122,54,43,61,74,123,3,61,69,216,240,60,222,113,138,60,91,177,63,61,70,148,246,60,62,232,89,60,79,175,20,61,134,90,83,61,201,229,191,61,182,243,253,61,5,197,15,62,20,174,7,62,32,65,241,61,95,152,204,61,132,158,205,60,179,123,114,187,131,192,74,189,114,249,143,189,161,103,179,188,171,207,213,188,108,9,249,188,231,29,167,188,7,95,24,189,115,104,17,61,98,161,86,60,7,95,24,188,156,51,34,188,101,25,226,187,137,210,94,187,244,253,212,187,195,100,170,188,54,60,189,188,91,177,63,188,232,217,172,188,203,16,199,188,153,187,150,59,14,79,47,188,66,96,229,187,240,133,73,60,127,106,188,60,108,9,121,60,75,89,134,60,85,193,40,61,219,138,125,61,233,183,175,61,160,137,176,61,52,128,183,187,205,204,76,60,43,24,149,60,150,33,14,61,192,236,30,61,17,199,58,61,11,181,38,61,22,251,203,188,127,106,60,189,85,193,168,60,216,240,244,60,242,65,207,60,12,147,169,60,151,255,144,60,56,248,194,60,242,65,207,60,166,155,68,59,39,160,137,59,111,18,3,59,221,181,4,188,137,210,94,188,104,145,237,188,39,160,137,187,130,226,71,60,231,29,167,59,14,79,47,60,17,199,186,60,232,217,172,60,137,210,222,187,234,149,50,189,216,240,244,188,36,151,255,187,9,138,159,189,31,244,236,189,40,15,139,189,4,231,140,60,143,194,117,60,231,29,167,187,221,181,4,60,23,183,81,189,72,80,124,189,250,237,107,61,156,162,163,61,84,116,164,61,39,160,9,61,23,183,209,56,33,31,244,188,80,252,152,189,127,106,60,188,120,122,37,188,150,67,139,188,10,215,163,187,114,138,142,60,104,145,237,188,107,43,118,189,143,194,117,188,20,63,70,60,2,43,135,60,127,106,188,60,52,128,55,59,220,215,1,189,2,43,135,188,78,209,17,61,199,186,56,61,166,155,68,60,74,123,3,61,39,160,9,60,237,13,190,187,130,226,71,60,221,36,70,62,89,134,56,62,156,196,96,62,180,200,118,62,229,97,97,62,147,24,68,62,127,106,60,62,221,36,70,62,120,156,98,62,189,227,84,62,91,66,62,62,58,35,74,62,11,70,101,62,228,131,94,62,127,106,60,62,135,22,89,62,145,126,251,62,24,149,244,62,223,224,235,62,37,6,225,62,120,156,226,62,101,170,224,62,101,25,226,62,201,118,222,62,108,9,217,62,72,191,221,62,194,134,231,62,37,117,226,62,184,30,229,62,73,157,224,62,20,174,231,62,156,162,227,62,93,207,133,1,149,3,214,4,142,253,120,252,171,248,24,9,248,205,191,250,150,1,80,0,127,1,255,240,164,4,117,252,65,9,159,203,183,43,13,246,236,253,250,2,165,249,168,2,255,246,213,252,162,251,160,12,85,13,38,248,59,254,96,229,252,239,107,6,201,43,165,3,32,247,160,5,95,246,50,229,186,0,27,6,236,222,216,248,114,251,172,253,186,254,105,0,141,255,160,254,144,253,133,123,129,0,211,254,153,253,199,254,80,255,108,2,251,255,182,250,21,242,166,2,211,254,109,2,136,3,255,252,222,250,68,252,10,247,150,254,125,1,162,246,189,66,100,0,122,15,194,252,17,73,237,0,240,250,206,13,172,5,3,1,154,6,222,243,216,241,196,254,240,255,12,23,147,8,16,252,255,55,93,55,155,249,106,4,86,4,243,1,20,250,244,1,48,253,18,254,14,252,16,251,251,252,109,5,212,0,100,31,12,3,96,2,97,254,163,3,211,254,118,247,208,8,62,253,172,50,123,242,145,241,25,8,48,245,11,250,141,226,71,254,15,253,206,17,21,224,41,249,27,229,237,15,58,26,53,0,66,4,66,244,104,14,118,251,197,255,46,1,160,3,62,254,238,0,57,42,97,1,186,2,36,254,172,0,106,247,231,238,162,226,69,6,204,24,27,20,91,255,165,0,49,254,163,255,227,4,159,2,75,2,110,254,29,255,50,254,200,146,215,0,200,255,66,252,111,253,252,1,98,0,5,245,93,250,4,12,74,24,224,217,31,215,254,252,89,1,4,12,140,255,188,244,167,8,164,245,26,5,78,10,132,255,195,254,110,1,181,5,217,254,209,19,204,1,128,7,184,47,136,228,160,26,221,11,186,245,193,251,221,250,123,0,186,253,167,247,197,19,35,1,204,6,42,255,128,7,114,242,143,42,19,37,230,13,24,251,64,254,192,215,169,246,98,7,228,1,49,43,236,25,166,1,12,9,129,249,164,254,121,2,176,4,252,6,156,251,141,160,140,0,101,3,226,2,223,0,107,250,90,2,177,1,60,255,153,251,111,248,145,252,202,254,204,253,254,3,228,238,79,28,158,240,109,17,171,8,239,222,50,36,44,238,159,243,121,242,35,254,237,2,156,9,248,252,38,1,85,255,48,4,212,6,232,3,48,255,116,7,26,252,150,248,11,215,56,9,82,209,148,246,207,245,45,15,78,245,68,5,209,253,194,250,150,36,24,6,208,252,154,4,86,1,81,255,6,5,198,11,145,41,246,0,56,12,218,25,207,254,154,42,215,24,213,238,135,5,196,0,128,43,236,6,25,244,241,12,49,251,74,248,51,244,56,250,191,250,194,252,15,6,217,9,6,254,141,30,35,30,214,19,23,32,54,8,16,6,199,8,182,14,170,243,237,248,119,2,140,15,115,254,70,35,13,251,74,248,3,6,152,254,197,254,28,3,115,237,28,8,7,252,205,2,242,8,204,43,149,36,90,6,123,1,12,8,49,5,4,0,231,255,188,250,54,2,14,251,134,6,118,8,67,51,42,0,112,9,134,247,20,231,172,0,60,1,40,0,44,1,25,254,146,1,36,255,78,3,130,252,123,250,77,247,170,7,22,76,92,198,41,56,186,253,254,252,70,255,16,252,16,250,46,253,139,252,62,10,55,1,15,253,224,1,27,2,13,252,44,249,192,252,165,253,33,248,101,3,244,197,168,253,62,8,228,1,14,233,252,5,218,12,34,255,194,237,223,255,230,252,243,247,95,251,160,255,81,1,3,2,161,248,26,0,59,79,57,254,225,252,194,255,197,251,236,0,71,249,199,253,21,251,105,1,66,4,30,255,200,5,55,52,130,253,172,3,152,14,19,25,149,232,62,3,57,230,197,17,47,6,215,220,80,4,255,250,10,251,162,255,80,4,228,247,140,2,215,8,185,5,231,255,86,35,53,224,170,245,112,204,234,253,116,196,88,250,146,250,196,1,72,2,198,254,88,251,183,3,117,3,140,1,8,3,23,5,18,5,64,254,127,128,22,255,194,255,31,0,92,255,238,251,174,255,230,255,240,254,209,253,92,255,157,2,12,254,4,2,67,5,143,37,99,4,190,250,150,248,149,32,169,214,238,8,143,235,223,5,198,1,24,248,152,16,6,247,187,247,78,52,175,252,30,8,72,4,117,253,56,208,138,254,212,252,111,241,195,252,112,255,189,4,43,254,88,4,122,4,48,3,50,3,112,252,57,252,139,3,12,0,139,9,9,253,215,248,82,255,186,252,232,1,232,249,190,184,210,253,134,21,220,250,222,6,117,15,38,228,142,250,98,19,30,15,141,248,225,219,169,8,216,240,195,238,101,7,243,243,54,255,87,2,27,5,38,6,210,251,223,245,94,245,34,37,70,216,81,4,15,19,160,8,38,0,220,21,154,232,123,243,35,0,189,36,37,255,106,2,28,5,97,1,129,13,176,6,205,2,119,205,25,0,128,8,226,245,57,251,16,2,38,5,236,17,254,29,111,22,18,223,121,238,84,5,146,31,65,249,125,254,213,1,100,12,145,1,45,245,182,2,218,56,26,247,56,14,180,212,156,3,175,253,255,240,14,239,227,0,238,2,158,11,238,244,27,249,85,8,99,251,29,20,238,45,173,46,210,13,138,9,241,10,177,5,202,252,165,242,92,246,191,0,122,253,49,252,9,251,64,3,16,12,17,254,218,216,25,7,39,5,144,252,62,5,88,250,243,241,18,243,49,34,95,255,106,230,142,5,128,253,4,254,22,45,235,254,91,255,69,3,221,28,82,252,1,43,159,255,12,6,138,5,67,254,57,8,78,252,28,222,154,20,138,34,64,2,144,250,55,249,4,251,115,21,56,1,40,14,246,10,109,8,231,253,120,6,190,7,236,250,110,255,207,1,240,1,152,65,116,255,37,249,192,252,181,247,113,254,179,22,66,253,75,11,210,241,205,248,90,1,252,1,148,254,14,254,210,253,48,125,24,253,90,0,140,254,174,1,192,2,103,3,139,0,4,3,184,2,148,255,238,255,54,1,101,254,226,252,209,1,91,255,191,254,233,2,43,147,16,253,243,1,41,255,172,0,35,0,60,255,254,252,18,1,222,253,160,255,42,254,240,220,196,35,69,2,136,3,220,237,135,225,197,13,161,253,44,25,218,15,72,253,173,251,136,253,195,5,196,0,91,252,115,3,77,4,22,1,177,1,32,2,15,254,4,0,166,248,224,5,82,2,78,137,218,0,211,0,82,3,35,252,63,1,157,252,214,255,242,2,242,1,186,255,206,253,148,2,215,210,54,0,35,3,169,1,198,3,7,252,56,251,170,206,42,7,215,255,98,0,197,251,180,13,214,6,41,249,72,0,9,254,218,255,195,86,252,0,88,0,221,0,178,2,82,0,196,250,252,1,126,2,64,3,226,1,51,0,18,31,142,10,104,251,126,34,201,254,232,9,72,232,205,239,114,20,238,1,99,255,247,250,210,233,175,249,228,5,116,255,201,255,201,2,184,1,185,128,105,0,118,254,155,253,52,252,66,2,98,4,224,255,114,0,28,255,86,1,43,251,99,4,102,4,68,255,150,255,44,44,53,241,51,2,95,13,58,217,87,6,9,246,88,250,227,239,150,3,170,250,36,254,190,255,4,0,249,2,164,0,195,255,221,79,238,0,40,1,236,1,154,251,158,255,79,251,14,0,208,248,159,252,154,4,155,252,105,0,139,3,248,0,2,6,174,11,171,45,103,30,30,6,208,229,93,9,82,2,223,248,129,254,168,16,119,7,212,1,250,3,92,253,140,245,180,225,193,245,209,41,150,10,114,224,120,235,163,6,204,247,157,254,218,247,76,42,99,2,18,0,194,252,210,3,171,239,44,5,114,235,185,254,4,7,207,217,26,5,114,248,30,221,48,37,196,246,99,240,31,216,74,231,114,5,34,249,100,3,168,4,156,244,233,255,206,249,216,254,182,1,233,254,165,200,238,249,50,255,79,9,250,1,157,4,106,32,21,254,45,245,66,239,52,228,112,249,250,1,193,6,91,205,99,252,39,252,164,1,46,249,245,254,34,254,13,210,250,251,187,0,218,240,236,5,168,9,141,254,29,0,41,3,92,249,104,255,48,2,41,7,61,56,200,3,160,255,86,243,63,246,180,255,48,8,121,37,80,251,190,1,225,5,122,31,186,6,245,1,155,3,109,251,212,218,24,246,200,28,254,255,72,235,120,246,160,254,254,1,64,1,45,1,120,0,175,2,82,252,137,0,56,3,196,254,32,5,254,1,147,251,200,148,108,254,17,4,16,1,8,198,175,250,189,49,30,3,16,254,155,6,124,249,62,249,160,3,95,243,82,1,190,253,156,0,16,3,237,252,14,255,150,253,171,252,254,250,10,210,130,15,146,47,14,248,244,0,173,242,44,1,159,0,166,13,12,244,77,250,76,246,72,214,240,2,227,0,180,249,102,252,219,253,158,0,212,8,40,226,129,238,21,240,148,246,229,225,88,2,186,207,93,0,126,249,229,252,252,204,61,0,255,1,202,247,182,247,108,1,99,255,6,9,240,249,236,4,158,0,31,37,138,27,7,0,242,232,70,228,188,1,152,14,212,248,37,12,232,246,201,1,153,252,185,254,244,252,149,2,236,33,226,9,244,254,186,3,100,5,251,251,162,1,120,255,69,242,161,7,104,249,81,222,36,243,78,30,236,10,123,45,93,252,11,254,151,252,68,254,194,250,180,201,10,255,229,254,13,249,230,3,218,250,152,1,225,5,50,254,171,41,235,248,78,0,126,191,104,1,19,248,174,3,138,6,171,0,61,1,244,0,159,4,212,2,248,2,98,6,95,3,25,3,126,0,186,254,212,3,139,253,203,86,119,253,250,4,205,2,75,5,195,248,0,249,7,252,200,247,0,253,84,249,254,8,49,9,159,43,238,41,172,242,38,247,75,0,152,255,169,1,144,252,24,8,118,11,94,252,14,1,146,246,99,252,255,3,22,253,20,255,172,249,57,3,44,5,155,255,108,180,245,250,73,2,117,8,75,11,78,14,191,253,8,7,152,1,50,250,107,0,95,1,193,254,80,4,188,3,147,1,116,2,235,254,199,255,170,3,0,128,185,255,71,254,48,255,224,255,191,0,58,1,85,255,101,2,237,2,76,3,40,254,68,254,184,3,42,0,166,224,160,10,119,7,36,245,23,48,134,255,241,13,165,255,160,23,248,252,158,6,193,255,8,251,253,13,86,6,234,9,190,0,204,204,204,252,16,244,165,4,108,250,12,255,16,253,213,231,111,242,71,253,88,5,19,4,22,30,96,1,116,255,57,205,176,255,128,49,63,250,41,12,225,5,155,2,88,9,231,6,25,2,157,7,145,2,126,255,212,3,207,6,77,32,76,9,249,246,197,0,117,253,227,9,41,2,163,251,116,254,216,1,213,17,128,206,18,9,152,254,34,206,157,8,165,245,62,214,38,255,74,2,109,20,34,0,59,0,194,6,202,4,58,8,168,15,170,248,208,218,170,250,106,251,222,254,243,251,106,6,210,4,49,1,1,251,126,253,102,4,113,204,227,255,130,2,112,11,144,7,252,254,76,2,170,45,66,36,222,242,52,30,49,4,178,10,80,18,29,250,75,250,33,247,149,251,177,7,152,247,101,6,250,252,66,0,90,251,50,255,21,254,200,251,132,2,134,254,111,1,60,70,209,249,114,8,150,3,135,255,80,254,115,0,5,0,23,3,176,7,17,247,218,249,183,218,138,43,212,13,164,237,253,253,60,238,113,3,79,2,20,4,253,254,46,252,2,0,232,0,10,3,58,255,119,251,134,254,173,255,165,1,26,1,196,103,223,252,164,249,65,248,211,254,163,3,118,3,148,8,173,5,240,2,140,11,106,242,234,1,116,250,247,51,13,5,6,219,206,1,227,205,122,43,125,31,81,2,113,14,157,253,234,253,70,253,132,251,62,6,37,1,42,253,70,253,33,1,180,0,108,3,143,254,213,255,234,0,131,171,88,250,15,253,32,254,188,3,226,3,19,2,108,252,118,2,208,2,4,247,184,218,118,250,225,3,82,8,201,246,156,9,173,254,235,254,41,6,174,47,77,242,0,251,146,7,103,3,198,248,215,252,220,242,6,27,110,4,146,19,68,34,55,8,209,217,132,250,28,20,42,250,13,6,225,6,212,252,142,2,157,253,54,3,27,255,128,254,226,40,175,254,159,8,131,0,2,11,147,244,210,242,174,221,152,222,22,247,88,0,222,251,123,33,84,11,239,253,223,249,90,7,43,252,204,0,139,11,125,239,100,16,31,244,52,42,30,7,82,0,144,7,76,9,192,50,229,233,135,242,49,5,124,249,11,5,66,249,136,32,58,1,177,10,91,253,80,9,114,252,146,252,175,2,128,2,47,253,112,252,28,206,225,247,114,254,4,249,44,246,249,221,242,251,39,252,17,228,159,220,122,3,203,1,214,254,150,3,179,216,80,3,52,253,30,7,68,3,212,218,39,252,157,250,103,254,67,247,12,4,198,251,88,249,53,5,104,250,199,44,205,246,169,232,118,249,128,253,214,253,160,32,172,10,125,235,147,16,158,254,78,14,176,253,155,219,75,251,196,251,29,252,24,44,206,247,172,249,63,9,250,250,64,235,192,255,28,2,233,246,113,245,35,248,55,222,230,250,76,252,163,5,152,2,96,9,98,18,221,15,131,1,236,255,67,7,67,36,1,185,38,3,135,250,229,4,84,2,128,8,110,249,161,8,221,2,124,5,4,230,194,10,182,3,42,9,45,14,37,229,205,19,170,219,192,5,174,3,160,4,64,215,192,3,147,15,193,7,165,1,44,1,52,253,170,3,244,1,96,255,226,0,169,255,144,249,191,248,71,248,189,254,1,9,237,201,204,239,94,244,54,21,162,242,142,251,158,247,12,6,106,250,222,2,173,254,150,33,40,238,16,254,221,1,105,19,33,10,26,11,197,33,195,246,225,226,129,245,249,0,92,29,203,255,219,0,115,4,100,253,54,2,246,253,9,5,33,0,115,255,104,252,222,9,19,245,72,64,48,248,10,253,62,255,232,42,187,0,150,6,65,237,199,37,46,7,56,251,45,5,144,2,198,234,135,12,21,7,41,7,39,56,227,47,161,255,232,253,46,249,16,242,70,254,196,3,64,250,65,5,132,10,179,253,8,2,104,2,101,1,70,1,173,250,187,111,188,2,217,1,116,252,151,251,22,4,82,4,41,254,40,254,44,252,29,0,62,2,162,254,223,253,183,253,112,248,23,1,114,3,144,252,204,255,168,136,115,1,102,255,5,251,134,248,104,0,146,255,98,4,49,253,217,2,25,253,104,1,254,2,198,0,102,210,100,2,150,214,133,4,186,0,196,243,254,11,255,5,155,0,6,3,40,219,102,19,195,229,64,1,47,20,112,0,167,10,220,43,88,5,72,7,173,4,17,250,224,5,199,69,49,0,164,8,99,2,4,249,116,11,139,1,32,0,202,253,121,9,15,219,161,2,158,2,9,255,81,6,222,206,128,5,206,1,169,197,158,5,216,252,198,248,240,252,64,7,144,249,255,2,84,250,140,249,171,249,248,3,148,5,61,212,121,16,246,230,10,10,8,252,72,249,180,220,122,254,62,0,35,251,211,11,1,255,110,6,78,5,117,252,160,252,138,255,106,3,12,1,252,0,104,0,98,252,216,253,74,251,197,3,48,255,104,160,122,3,20,250,138,253,139,252,220,252,138,254,8,168,137,251,247,252,20,2,185,0,91,2,239,6,161,248,157,1,54,254,244,251,45,255,133,10,64,27,230,218,157,5,179,39,146,9,218,249,77,19,116,3,42,254,218,242,56,18,164,1,200,253,71,22,10,0,100,249,143,0,56,6,42,213,75,11,111,244,98,15,198,7,190,6,129,235,254,12,81,230,72,2,235,254,71,254,143,6,248,253,59,5,53,4,58,211,245,254,161,254,201,0,187,42,54,16,50,15,204,5,55,10,92,253,64,254,12,9,2,251,6,38,33,244,25,11,196,3,123,226,156,0,196,227,136,255,157,21,30,239,4,7,251,9,72,217,34,244,188,8,166,4,222,0,108,249,201,12,24,249,89,24,214,230,97,33,207,255,211,255,62,9,37,1,52,1,79,253,52,1,112,1,60,254,101,4,22,9,225,246,127,186,235,7,245,252,222,2,16,248,222,4,174,244,78,16,182,255,216,255,223,243,169,247,228,3,86,206,30,14,72,19,120,248,248,5,194,239,1,249,242,246,139,3,186,254,241,87,108,253,254,3,178,1,204,253,28,0,144,255,252,0,116,1,182,252,254,255,136,2,19,9,154,253,81,91,249,254,230,1,104,254,150,254,203,252,44,253,204,3,224,4,188,1,51,249,92,254,165,250,64,4,203,253,22,0,118,254,192,255,220,254,153,255,11,254,210,136,218,254,246,254,177,1,68,253,230,2,12,253,105,254,63,252,108,255,120,250,239,251,31,254,121,0,90,1,0,40,85,49,196,5,169,245,70,5,36,248,250,254,11,234,202,2,46,17,84,245,23,215,106,38,211,235,33,252,211,253,83,245,124,242,147,22,147,2,192,5,237,7,221,246,70,188,105,22,112,252,18,23,61,235,152,3,183,10,72,247,151,7,15,253,160,6,230,248,32,247,204,253,230,250,241,253,100,255,224,38,36,0,220,9,5,8,49,7,122,249,126,41,228,9,16,234,188,254,148,251,132,251,128,7,248,39,181,255,138,253,212,213,82,6,80,4,3,246,165,253,67,8,198,3,77,241,145,243,173,252,150,17,227,249,78,39,57,1,59,253,211,41,99,3,236,14,69,245,142,13,106,248,26,254,252,15,111,231,197,246,44,2,118,12,182,19,179,248,70,11,76,41,76,252,161,239,8,6,65,249,209,2,175,243,56,253,166,3,74,6,46,4,224,4,149,41,36,9,162,212,72,245,159,254,191,255,147,236,10,249,243,251,186,4,168,4,114,4,82,4,206,36,140,2,133,218,129,249,204,1,147,35,245,244,7,3,107,4,124,18,93,0,220,1,131,1,255,127,95,255,10,1,106,254,92,2,163,2,83,0,179,253,129,253,220,0,194,252,152,8,114,255,48,248,128,255,134,3,55,3,31,1,205,2,65,7,166,249,208,0,224,10,184,255,146,180,46,24,241,247,115,220,91,13,185,6,212,247,76,1,123,230,86,226,114,4,39,3,234,245,100,253,154,1,15,254,246,5,96,0,176,3,247,12,14,5,177,254,172,7,132,254,150,253,253,11,101,0,20,74,6,247,192,215,90,251,26,252,152,250,54,211,0,255,133,238,187,15,52,242,36,7,225,250,167,242,171,240,35,255,40,108,229,8,53,251,19,4,113,254,1,243,3,2,129,6,152,253,164,10,222,253,0,18,192,253,153,255,152,220,255,250,205,253,252,241,126,8,200,252,51,13,200,246,98,1,76,3,124,228,9,247,203,245,112,212,238,3,216,251,145,189,156,4,131,1,0,223,68,3,190,253,61,10,156,254,60,250,58,9,54,3,195,17,118,0,148,210,96,1,111,1,66,252,121,207,191,255,201,249,0,247,192,244,148,6,172,6,99,249,243,252,185,255,28,39,234,253,168,241,161,1,0,248,93,248,251,40,23,251,93,3,98,254,38,240,226,11,249,5,65,233,221,26,178,240,225,3,221,0,16,10,156,225,170,0,120,253,117,255,174,242,38,31,12,253,97,10,172,253,239,48,57,255,184,53,150,8,86,252,39,247,200,6,1,1,237,5,92,253,115,251,198,244,127,246,123,0,195,252,45,10,226,215,170,243,40,14,24,8,48,27,210,5,26,18,199,1,17,224,115,4,63,238,45,250,143,14,222,221,97,248,81,2,14,0,81,11,186,9,31,247,100,250,16,213,189,11,216,238,150,242,47,238,10,252,222,218,183,249,32,251,199,249,66,255,24,215,192,12,30,247,233,19,135,253,217,1,171,1,213,2,41,6,24,43,62,1,60,208,78,0,164,251,185,1,138,7,201,15,120,253,28,239,32,255,178,10,122,34,216,255,71,1,225,6,67,9,171,0,199,15,173,242,65,246,126,4,107,208,88,249,35,0,16,2,161,1,114,2,74,7,40,254,210,1,137,3,170,252,149,252,170,4,51,95,232,1,26,0,183,2,241,6,30,3,87,255,240,255,28,251,139,1,103,3,146,4,133,253,155,249,46,8,205,234,247,191,128,254,32,15,33,0,81,253,15,249,192,239,204,11,142,248,28,15,187,2,112,254,99,26,75,243,155,49,194,5,144,28,223,3,122,253,146,104,220,9,96,8,12,254,72,4,179,248,12,4,85,249,9,2,213,247,165,5,31,9,107,0,238,0,29,255,136,255,0,128,79,2,255,254,99,3,49,251,138,2,47,254,100,1,175,1,250,2,252,253,174,253,0,2,242,0,250,8,244,3,254,249,28,210,223,13,24,234,130,247,132,246,61,41,113,2,234,3,217,108,179,253,9,250,240,249,156,0,113,7,17,4,162,239,252,8,67,6,44,252,28,249,228,1,19,6,152,245,125,1,156,45,112,221,12,244,163,2,122,253,224,2,1,251,19,251,60,248,31,2,168,248,125,7,139,247,30,11,87,46,28,8,141,40,205,254,2,17,73,0,28,245,96,246,196,3,38,255,16,6,54,7,190,5,65,2,174,253,213,2,78,120,43,0,13,0,62,250,4,1,194,4,153,5,142,255,252,3,120,253,90,253,169,248,191,255,23,3,110,1,99,33,163,3,67,4,250,3,184,63,164,251,247,252,182,251,148,1,180,0,125,252,207,244,151,216,17,253,40,0,202,246,92,244,246,13,225,30,66,255,247,35,238,255,178,182,242,254,76,235,25,248,118,9,91,251,243,4,195,251,64,253,167,26,116,8,2,0,125,0,241,246,155,1,79,2,24,254,202,253,190,242,48,1,169,207,244,254,90,43,106,255,168,246,25,251,100,12,162,0,15,5,9,23,8,31,131,23,1,13,34,248,141,11,187,236,197,18,220,10,179,234,120,10,148,12,224,10,219,253,60,178,58,251,38,2,44,242,30,7,242,15,95,9,68,229,97,8,170,3,171,253,122,0,236,255,118,197,172,249,39,6,49,2,152,1,95,231,248,2,98,6,92,10,147,223,84,244,72,7,220,9,156,12,42,29,196,245,154,1,84,5,204,6,156,8,207,7,168,6,215,245,161,254,152,255,192,41,2,228,134,0,166,254,76,46,246,203,157,243,50,251,85,4,224,246,62,252,205,253,6,4,16,11,55,252,51,248,161,12,98,254,202,223,230,247,177,10,229,13,89,6,12,4,77,3,56,7,174,6,108,215,22,238,3,27,174,10,11,222,101,253,32,6,222,6,92,9,66,243,63,246,64,250,184,209,79,253,51,13,156,6,169,5,28,11,76,33,18,195,81,1,78,2,231,12,198,249,12,246,177,17,177,1,127,248,152,3,37,4,99,249,191,0,44,0,189,3,163,246,154,251,41,0,116,8,205,249,56,2,118,188,79,18,252,251,109,254,145,4,254,250,190,249,242,0,46,251,78,7,43,4,140,9,216,6,8,246,71,34,104,5,51,22,94,237,108,207,88,253,224,203,60,255,236,254,213,254,222,2,90,48,60,9,71,1,42,250,48,2,166,255,66,13,240,1,53,9,117,2,239,255,16,4,62,253,77,2,38,1,145,251,180,97,188,1,182,4,214,254,144,5,244,5,116,247,192,255,179,251,50,248,118,1,97,5,154,250,171,211,176,5,85,255,191,246,54,27,8,245,229,220,62,13,213,252,159,2,216,11,188,242,169,217,198,8,66,17,90,253,59,7,200,249,226,212,86,251,228,241,29,10,6,255,17,254,179,4,68,5,219,252,61,7,167,254,213,253,205,221,33,218,72,241,30,250,20,224,190,254,5,228,81,231,4,8,116,0,149,238,232,246,249,18,247,245,139,5,191,3,114,4,122,27,228,18,121,13,170,26,99,52,131,252,213,3,244,247,130,241,105,12,7,253,152,251,34,17,129,255,42,26,98,13,150,244,195,255,152,1,146,5,42,251,108,60,94,0,117,1,13,14,128,246,59,248,165,252,240,220,122,11,247,252,153,1,50,255,178,225,56,13,39,1,46,254,29,0,245,30,0,8,162,3,248,8,210,216,74,1,184,30,20,252,127,254,82,8,132,1,3,14,128,238,24,6,32,206,210,245,242,31,3,3,65,242,202,249,176,253,144,8,154,251,179,255,149,240,76,7,232,250,99,43,13,3,96,24,38,16,14,243,151,1,19,232,48,20,9,254,107,8,34,252,143,0,219,0,34,217,94,251,90,250,138,7,253,220,12,240,3,232,48,252,153,0,159,202,52,2,63,53,138,0,243,254,123,1,53,5,82,249,84,252,1,254,190,4,114,247,67,5,139,250,215,250,94,0,246,248,227,25,26,5,197,207,220,10,189,251,246,238,183,19,66,254,112,242,176,23,51,4,222,1,1,3,58,0,34,3,50,2,211,249,164,111,194,0,58,5,61,2,213,253,105,2,103,254,31,251,248,255,109,4,184,3,136,255,198,9,193,20,201,3,128,249,233,6,89,208,175,21,110,254,254,18,198,12,255,127,202,255,105,5,50,255,19,0,10,2,104,251,101,253,252,254,148,250,41,249,70,247,228,0,169,254,131,252,126,252,20,252,213,9,24,255,4,82,251,1,191,248,14,10,72,3,153,253,126,248,148,2,76,3,52,0,248,4,97,2,76,253,45,85,170,3,166,2,113,254,234,255,209,248,28,252,24,6,218,0,133,15,109,230,129,251,182,240,235,252,170,3,11,211,22,247,162,253,185,254,16,12,29,3,252,249,82,226,98,5,156,255,60,8,141,248,105,210,2,6,128,43,54,1,208,247,35,244,109,12,195,6,251,7,96,13,182,251,254,7,33,2,14,249,93,2,164,3,64,3,204,246,38,250,105,4,22,45,119,0,14,213,120,241,220,16,90,1,75,220,81,15,106,252,156,234,116,1,194,254,38,36,87,253,32,19,51,6,84,6,58,7,217,15,29,250,150,254,206,251,184,254,34,250,236,243,175,10,134,254,204,210,244,250,241,245,187,242,114,226,239,220,134,6,211,33,113,253,116,3,23,7,124,219,58,2,138,1,134,6,150,7,61,255,130,1,41,2,181,34,10,220,144,253,248,246,236,61,14,3,50,2,39,250,208,2,12,7,135,5,31,241,199,14,130,248,88,242,131,253,69,2,137,4,193,3,64,252,94,252,119,249,136,3,246,44,18,247,20,217,148,11,136,233,181,8,18,3,57,250,62,182,237,5,128,0,210,12,157,0,126,247,204,253,115,232,254,2,9,238,36,14,228,238,110,177,91,253,86,8,163,255,206,5,136,2,74,237,70,7,60,250,200,255,141,242,194,245,10,245,95,251,122,0,9,7,245,249,209,47,31,245,82,9,56,0,21,240,44,213,192,252,120,237,186,250,33,11,1,255,161,250,163,0,26,5,37,0,0,9,140,250,30,212,240,37,196,6,42,247,48,14,81,254,189,253,51,240,38,3,120,208,227,250,72,3,62,250,150,3,40,251,191,249,48,0,215,239,22,27,128,15,202,28,248,15,200,33,47,9,186,5,103,2,230,207,213,246,30,17,94,3,64,239,190,243,94,7,251,238,119,1,157,7,73,0,31,1,135,0,196,255,38,250,133,246,239,4,250,12,186,253,100,68,78,251,22,6,23,13,228,1,73,254,197,253,142,254,176,46,136,45,129,250,126,250,96,244,53,254,141,1,188,7,162,250,213,4,180,19,230,247,149,1,102,214,82,255,244,206,86,248,217,17,243,250,56,255,34,12,87,1,236,2,126,7,60,4,98,253,3,0,210,251,115,254,125,15,238,38,159,253,219,37,124,252,137,0,1,9,200,232,80,252,36,250,126,2,65,253,186,253,114,39,245,253,8,3,242,4,252,18,69,24,157,4,254,233,6,2,156,35,124,237,187,41,221,253,241,250,165,255,104,0,213,243,68,249,239,255,161,7,23,253,182,2,38,254,216,47,172,253,94,253,253,2,162,2,142,17,181,4,251,22,154,249,100,240,104,253,246,33,12,234,128,15,51,253,71,215,227,254,195,206,112,1,192,240,75,48,248,250,218,4,39,250,211,243,92,9,36,255,164,6,28,245,250,0,107,0,106,255,89,1,169,2,212,255,94,246,123,254,50,8,56,1,54,0,174,10,47,169,48,251,14,249,39,4,206,249,254,229,88,1,183,244,4,239,155,241,204,247,12,0,37,249,255,230,107,255,214,31,63,214,20,253,163,5,0,128,162,6,181,5,216,0,93,5,2,245,246,3,111,4,29,255,227,250,152,253,30,6,139,1,44,253,84,3,43,6,81,218,66,251,216,2,73,1,28,36,179,0,36,28,188,252,142,240,168,0,166,233,152,0,186,244,216,1,117,253,250,19,30,34,185,255,142,44,74,4,84,250,166,4,86,2,144,252,19,57,252,48,13,250,60,5,247,3,230,5,48,255,206,0,34,5,4,250,10,255,118,243,155,249,59,255,197,0,0,128,168,5,65,255,72,249,39,255,253,3,205,3,205,247,56,0,94,2,39,0,223,249,75,251,185,246,148,247,190,18,200,9,118,209,165,3,129,232,97,10,161,244,203,235,84,248,40,6,148,20,166,4,163,2,88,3,74,249,20,239,166,0,20,6,61,74,248,7,174,4,134,247,32,7,175,242,121,0,62,3,4,255,243,253,33,1,91,249,36,1,86,3,130,251,172,251,171,0,255,1,98,86,150,2,17,251,228,253,254,246,228,246,101,3,185,235,186,0,24,2,154,1,104,226,78,2,57,53,191,13,18,15,29,245,136,254,150,230,123,3,161,19,250,247,124,32,189,247,244,29,80,233,96,246,138,246,5,6,245,240,42,6,164,1,151,253,149,230,166,252,160,0,36,15,242,244,174,232,33,243,101,38,75,4,81,6,174,13,204,243,236,239,138,0,31,1,146,3,220,253,32,4,246,249,194,4,29,255,112,45,194,253,28,252,90,217,40,3,20,233,79,250,182,32,218,247,232,254,14,4,16,2,70,7,28,1,86,15,112,255,0,28,200,4,108,45,35,255,250,3,147,6,154,3,49,2,254,26,103,7,228,11,69,49,182,255,112,250,118,6,168,34,207,8,34,252,9,248,13,1,86,37,138,39,190,3,210,1,100,248,38,251,18,4,118,3,137,251,140,242,240,221,126,7,212,254,130,74,163,249,223,3,140,3,128,252,183,4,18,14,62,237,160,244,4,16,120,11,192,250,203,1,8,229,54,253,12,2,171,0,106,250,174,5,91,245,106,4,11,253,45,11,90,212,48,245,90,21,78,14,110,0,49,248,88,48,131,247,52,246,234,244,23,248,230,238,134,0,128,217,202,6,3,4,148,5,38,0,232,249,24,50,108,54,37,2,74,2,208,2,155,3,240,251,245,244,56,243,110,7,191,247,64,10,224,12,222,255,3,48,169,5,150,208,228,252,186,0,217,10,17,252,204,12,181,253,131,248,126,255,72,8,204,253,148,254,237,3,153,253,224,5,148,246,3,36,108,211,70,246,238,4,96,245,72,6,52,243,14,5,90,7,68,255,178,27,141,23,145,239,77,245,72,0,205,216,120,249,229,5,132,255,143,249,164,1,217,241,211,251,39,212,14,253,124,254,22,3,119,243,182,254,184,245,112,209,106,12,4,249,25,10,50,16,152,7,59,245,136,214,220,0,200,200,110,8,238,254,218,7,150,254,83,4,164,254,58,248,96,0,39,252,63,6,30,6,113,5,48,1,156,250,100,252,227,254,108,2,226,255,122,252,98,102,205,5,18,4,120,251,96,1,79,255,221,4,87,7,238,255,215,2,91,254,223,0,238,250,42,4,194,3,26,5,26,15,102,3,164,182,223,240,107,0,128,250,19,251,40,3,206,252,202,6,159,5,148,247,37,250,196,247,238,237,199,15,60,252,42,65,111,251,10,1,157,36,214,4,88,245,77,9,127,47,107,8,40,254,11,247,255,253,224,14,78,253,114,247,141,251,250,255,99,5,237,166,100,5,156,253,52,1,114,5,122,252,82,250,196,245,200,251,208,244,27,243,108,0,218,0,14,34,151,253,182,251,156,5,43,248,130,240,158,245,8,24,150,252,228,237,1,34,202,242,216,208,162,1,211,248,218,206,14,1,236,252,106,251,108,8,205,1,215,254,222,1,136,253,156,254,164,22,8,209,160,1,42,10,216,13,40,251,54,252,10,19,53,28,192,2,236,34,12,9,150,4,233,9,4,21,251,255,230,248,204,11,232,239,130,27,110,218,170,249,248,13,151,9,214,254,195,1,78,235,203,28,222,249,100,205,30,38,40,255,121,3,19,21,37,245,60,240,200,6,177,248,12,248,161,251,55,7,144,3,244,8,82,3,220,0,20,5,180,8,143,1,187,244,120,245,95,9,107,12,122,24,93,6,35,51,24,255,54,235,117,5,44,253,130,6,36,248,59,14,120,5,92,245,169,185,6,254,153,255,38,5,169,9,197,3,181,253,111,4,120,252,2,254,241,213,145,7,183,253,183,255,130,249,205,11,84,1,69,207,174,249,255,255,134,248,126,148,68,10,74,246,21,1,106,3,209,246,165,10,147,3,226,3,71,251,73,254,120,11,46,0,246,3,232,248,23,242,206,199,41,12,96,215,255,251,66,8,48,5,234,254,158,4,228,248,88,15,218,251,230,254,209,250,68,250,87,23,38,9,138,253,135,239,132,39,26,251,170,245,166,235,42,217,112,7,21,0,248,1,21,9,163,5,70,25,38,10,194,31,42,3,48,1,221,251,123,253,42,57,130,243,181,16,99,253,254,227,18,6,239,246,82,9,208,251,179,9,211,239,25,11,86,13,78,31,187,243,105,42,234,25,66,12,127,12,192,254,36,0,170,250,223,239,85,12,42,10,177,16,125,246,85,10,170,11,128,241,101,240,156,234,171,237,128,249,240,24,63,212,40,5,136,8,18,236,88,244,223,249,188,247,23,250,204,55,82,212,147,244,37,253,215,250,37,231,203,5,135,13,12,5,239,247,155,254,148,35,227,24,0,15,7,229,42,221,90,11,134,249,245,2,206,7,188,253,60,253,150,8,75,7,192,3,170,17,104,7,118,249,177,236,135,10,95,246,226,247,27,38,11,237,214,245,138,13,57,15,207,241,54,19,255,247,146,14,66,248,155,216,126,242,182,248,32,0,86,249,64,14,204,254,82,252,162,249,194,6,0,2,20,57,87,13,206,3,7,12,253,2,129,3,242,254,235,248,3,250,94,4,11,245,52,245,106,4,250,248,242,17,194,243,196,3,142,177,14,10,194,126,157,250,52,0,102,1,30,255,110,7,1,1,209,251,118,253,113,254,131,254,25,8,6,9,116,8,29,32,153,5,139,253,160,5,96,4,222,242,222,237,208,7,122,1,184,4,168,245,182,17,235,12,144,51,220,10,28,12,134,243,146,214,213,210,117,238,170,8,108,238,110,2,33,5,122,10,187,11,149,250,210,240,225,249,0,237,147,42,130,175,186,249,196,255,90,2,125,0,38,253,168,251,211,3,69,1,243,255,71,255,217,4,224,254,216,253,154,23,119,228,65,227,80], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+327697);
/* memory initializer */ allocate([250,237,1,196,43,191,255,134,247,128,235,200,8,234,251,79,2,37,8,228,244,244,0,130,242,69,2,35,5,227,11,48,1,148,253,149,1,24,178,1,3,52,4,80,250,74,253,0,10,234,251,210,9,216,56,50,6,141,228,154,237,86,5,16,6,2,17,224,12,206,1,88,2,244,1,153,12,219,19,232,252,127,12,70,253,251,241,220,245,234,242,198,10,53,244,32,22,85,219,108,18,203,243,234,12,124,24,176,253,146,253,208,239,110,231,126,19,20,253,62,7,238,251,76,244,73,239,82,1,184,248,65,222,56,212,164,3,46,253,252,6,121,248,194,1,143,8,52,46,0,231,244,20,68,247,140,12,148,32,99,243,226,244,188,237,223,248,68,10,209,254,179,253,48,30,136,239,230,240,208,238,62,255,204,211,14,22,132,14,219,18,232,0,185,253,52,1,215,248,105,8,52,246,210,255,89,3,141,218,208,10,16,20,182,5,22,20,54,31,160,242,43,4,38,29,80,19,98,0,246,3,114,237,0,54,106,4,30,9,177,36,112,9,89,238,27,0,208,7,161,3,52,255,225,1,36,245,120,241,243,4,13,1,249,234,49,248,225,4,114,239,121,219,240,226,180,232,10,24,85,229,40,12,203,245,92,255,68,6,221,4,206,255,171,33,52,240,44,18,30,11,167,32,225,20,170,244,247,8,193,18,104,236,130,231,77,11,172,10,74,242,203,245,196,17,24,231,158,17,70,41,67,7,14,4,67,223,222,10,170,249,159,0,245,251,96,243,74,241,44,6,48,253,132,238,233,240,104,252,169,247,54,254,96,1,171,245,213,11,45,1,135,251,34,254,112,14,76,210,202,38,249,25,122,28,58,9,74,67,166,12,250,6,150,2,203,3,32,253,121,253,209,6,6,254,247,252,178,5,102,9,119,250,3,225,178,252,162,245,80,4,106,2,33,245,72,216,6,243,26,37,85,252,218,246,172,248,134,248,84,0,140,13,123,230,116,30,43,241,218,250,121,247,30,5,129,252,79,19,38,4,140,238,142,0,12,255,116,3,101,2,117,201,35,233,77,252,15,73,60,252,66,4,46,4,108,5,220,249,170,251,159,2,170,6,108,2,250,254,139,246,27,247,223,233,164,235,130,19,75,9,175,253,0,8,153,56,141,4,17,249,211,247,162,9,163,1,148,1,53,21,17,12,186,250,183,7,233,8,60,0,87,2,192,249,238,8,54,9,42,26,217,191,176,14,154,2,227,250,190,250,226,10,60,9,168,5,90,4,36,70,75,235,126,9,154,4,92,255,147,8,87,15,134,255,31,253,188,5,51,1,185,248,56,6,222,225,132,246,190,3,220,0,59,0,28,16,103,248,143,43,156,33,227,247,77,237,30,238,72,4,125,10,78,25,122,32,179,231,254,240,125,8,213,255,104,0,50,246,37,12,236,246,114,239,155,237,95,243,156,12,190,44,124,9,66,2,12,3,184,251,72,0,160,167,115,250,248,239,226,0,208,1,66,249,77,248,20,8,118,4,132,5,132,5,30,3,211,245,133,242,176,251,80,247,54,247,114,242,196,253,116,250,244,250,198,255,39,255,87,172,84,255,32,231,30,0,134,247,95,0,122,1,146,244,124,247,4,11,85,253,226,7,39,239,99,203,20,21,16,7,176,253,124,18,54,230,30,234,41,252,222,239,35,254,44,251,41,247,152,15,94,205,14,249,185,245,139,246,22,253,172,7,218,6,8,253,193,10,140,255,236,240,6,40,64,254,218,250,156,255,124,215,140,5,46,255,208,10,48,0,187,246,41,30,111,243,184,254,7,6,33,246,125,14,184,15,108,252,20,238,42,253,50,239,42,252,134,198,31,14,90,251,91,35,199,0,204,8,68,5,148,239,181,2,217,4,176,200,100,246,31,248,181,11,254,2,152,254,62,254,153,244,216,224,138,12,77,255,231,34,158,2,131,4,232,26,55,247,169,10,18,7,139,24,172,2,11,218,29,249,103,252,30,238,101,15,248,230,151,5,74,245,165,255,210,247,186,247,232,217,241,10,63,246,147,0,243,232,106,235,114,51,250,10,40,6,137,243,13,40,130,16,196,250,152,9,55,4,253,48,252,235,92,223,24,252,210,253,180,0,234,247,168,248,170,233,81,253,53,41,42,4,220,0,205,239,73,253,64,14,124,242,185,243,169,249,102,8,42,212,250,245,5,231,224,13,176,239,70,253,224,4,112,0,236,237,64,252,44,253,167,4,36,8,103,59,166,254,115,1,190,0,225,20,69,239,198,226,74,5,184,238,65,241,209,239,164,5,228,197,179,253,194,9,25,5,26,254,92,6,157,252,48,6,70,4,246,255,20,251,234,251,224,9,80,107,142,3,211,251,61,3,139,255,183,251,2,3,252,0,124,250,49,9,152,8,245,255,112,2,11,33,176,24,7,219,201,4,228,9,39,21,36,36,95,250,158,250,57,4,51,248,192,240,108,198,156,235,43,14,93,22,36,24,40,235,72,0,30,18,147,3,16,254,116,2,88,7,92,254,240,10,25,228,102,226,108,12,142,239,169,251,163,11,70,254,74,255,218,10,94,9,202,201,161,8,230,254,136,252,180,0,0,14,19,252,2,0,231,3,254,243,181,4,3,238,130,20,103,67,23,11,158,10,90,253,165,245,160,0,60,6,77,18,20,9,28,12,160,14,94,248,102,210,109,2,90,253,158,231,135,242,158,248,62,12,223,254,6,228,220,8,11,223,144,253,135,19,198,232,213,50,244,0,56,255,42,250,172,251,184,14,189,1,125,9,16,251,18,3,79,244,154,13,144,9,56,252,96,251,213,0,252,252,67,19,42,0,246,240,228,7,206,185,84,0,200,11,166,253,13,7,219,2,194,13,210,245,131,253,191,99,168,2,59,4,42,16,66,6,190,0,194,248,62,252,133,254,61,246,149,9,150,254,56,238,81,18,120,8,214,232,200,214,47,234,170,237,143,9,255,7,44,21,68,15,87,250,166,255,188,255,240,1,87,206,177,247,126,5,242,213,134,9,230,8,146,11,245,230,234,255,82,248,254,10,46,249,129,254,179,246,163,232,168,42,190,207,112,253,212,8,80,20,140,248,29,247,180,16,150,4,92,252,236,253,16,11,89,2,15,6,14,223,182,239,245,230,139,35,26,229,195,8,49,2,234,7,242,241,155,251,134,2,188,235,129,23,136,253,4,3,153,244,64,241,46,217,157,9,134,255,128,0,120,250,3,250,87,1,38,5,86,202,8,250,238,230,84,251,64,3,255,127,19,253,163,248,218,252,227,2,190,248,62,15,5,4,76,1,182,247,216,4,145,10,82,5,190,0,34,4,132,250,200,4,98,4,184,4,190,0,192,7,181,250,158,6,248,173,12,252,114,9,11,251,126,251,89,4,243,8,243,246,59,1,72,50,8,247,26,250,80,4,60,44,134,251,6,252,46,5,122,252,168,0,135,2,220,248,2,241,206,233,172,10,18,255,122,255,138,52,34,6,120,9,228,3,90,242,120,241,33,19,243,22,149,0,33,231,3,26,231,246,4,27,110,4,169,1,186,181,33,254,148,248,142,13,15,249,213,252,187,6,210,255,201,247,238,250,113,11,73,239,129,253,117,246,63,28,93,251,159,247,247,252,41,243,31,19,174,34,154,219,33,1,175,15,180,243,170,253,178,8,180,45,114,0,165,12,114,37,38,238,32,10,30,14,32,247,243,244,228,242,185,251,86,235,101,18,181,248,118,248,14,175,169,3,124,3,135,5,8,6,134,11,226,19,169,3,125,250,123,0,225,255,224,249,82,1,86,252,89,21,164,22,224,1,34,245,23,13,71,246,129,254,249,5,202,233,142,9,75,253,4,206,169,253,102,7,216,249,60,247,178,237,181,39,195,251,66,39,121,10,114,4,240,9,239,248,218,252,158,20,230,221,100,241,217,246,203,3,74,243,91,255,44,255,188,239,82,3,233,0,130,202,186,1,49,4,14,15,130,205,47,248,140,13,3,253,61,3,126,8,251,5,108,232,160,213,255,212,35,3,177,6,68,11,200,7,75,0,83,244,12,1,90,1,206,7,190,18,16,35,232,237,71,7,225,239,156,253,182,18,194,42,240,250,73,31,185,250,100,1,81,249,57,1,253,8,38,5,114,31,188,2,194,4,222,8,148,247,67,0,1,6,149,7,114,13,9,52,179,2,40,9,34,10,15,6,13,15,111,28,55,215,238,3,170,209,156,21,157,253,186,253,209,8,199,244,153,15,243,235,40,247,82,246,40,6,42,7,189,236,24,40,107,250,92,215,137,1,125,241,66,250,45,248,128,1,5,19,132,229,239,250,36,6,19,4,68,27,226,238,67,244,114,14,80,16,188,250,148,236,38,6,87,38,149,232,45,252,25,14,118,14,201,222,156,2,26,13,248,9,223,35,105,251,200,4,213,244,168,43,200,23,181,250,84,0,247,4,132,254,216,20,43,1,78,253,147,254,145,224,161,241,124,243,54,5,117,203,144,250,152,8,194,241,234,251,60,239,229,2,91,249,186,6,13,8,178,250,98,28,44,231,195,3,142,8,187,250,166,248,208,200,202,237,224,13,53,2,171,251,37,21,215,4,198,245,26,3,240,247,29,46,44,35,170,247,244,10,178,3,80,0,173,246,75,251,11,0,106,6,223,248,236,246,102,236,112,16,165,20,149,2,142,48,115,7,16,3,112,42,84,1,18,0,118,255,69,11,57,247,17,0,78,1,156,243,161,11,202,3,24,2,252,249,252,253,24,254,0,254,202,250,118,248,142,246,54,4,5,97,12,0,12,8,4,255,24,246,98,247,149,243,127,229,118,221,32,34,113,5,119,0,116,6,142,39,88,3,87,3,26,253,223,254,96,247,247,14,253,26,100,230,168,9,11,255,63,249,180,5,58,244,59,0,198,255,132,0,63,15,78,241,117,250,217,51,148,10,184,225,84,0,197,13,231,250,178,254,147,203,43,23,19,237,119,245,154,2,46,2,178,251,120,2,126,244,57,16,78,240,164,17,11,19,108,17,225,249,185,8,130,1,14,253,232,4,97,8,100,249,10,205,45,6,250,253,45,17,191,4,45,253,85,13,128,253,32,236,175,6,54,253,232,9,129,9,77,253,6,42,196,221,165,21,233,247,130,249,155,50,198,50,228,4,162,255,34,3,13,10,3,246,190,255,192,252,106,0,40,253,26,4,213,252,132,245,117,2,116,191,251,5,175,249,68,5,204,0,186,6,112,1,42,2,40,249,114,0,69,5,160,7,17,252,66,10,243,7,212,31,21,246,56,239,148,238,162,222,239,243,249,249,167,252,199,245,27,249,242,25,119,8,5,250,31,229,86,0,98,254,248,232,224,235,37,68,105,4,114,236,120,11,152,242,78,247,152,4,204,3,146,4,18,2,62,13,4,1,163,244,34,242,121,235,235,6,130,254,102,249,174,66,128,10,54,2,126,9,24,249,45,13,180,5,120,242,139,253,47,12,174,1,30,242,165,32,163,27,37,1,139,11,195,255,249,228,181,236,94,14,60,229,140,2,158,8,30,23,48,245,50,244,89,22,254,252,178,251,223,251,56,245,14,12,235,21,96,255,154,10,238,251,9,10,88,200,6,15,20,32,16,21,144,0,136,209,106,2,188,4,211,12,63,241,53,253,226,240,224,9,172,244,109,6,6,249,196,248,216,10,188,250,182,253,234,0,252,255,126,249,46,0,47,8,61,248,216,182,92,244,197,9,202,15,79,0,199,248,35,248,111,31,150,248,148,255,84,1,104,237,86,8,40,35,91,1,125,40,171,18,4,26,158,6,75,243,22,247,48,250,166,40,138,224,170,242,138,244,181,249,100,12,109,247,109,19,225,4,72,11,42,240,150,233,77,244,22,247,185,7,159,254,252,253,202,20,153,12,213,236,23,5,208,237,219,38,20,255,166,36,28,9,28,8,190,5,101,12,104,18,85,10,47,2,40,19,231,5,77,249,8,237,118,22,4,251,206,254,164,232,57,56,163,5,85,0,156,0,38,30,25,3,103,16,74,8,74,4,128,0,52,248,139,250,236,255,234,253,16,204,18,250,102,244,23,252,182,230,254,231,145,32,100,21,242,11,242,253,241,250,87,6,169,221,233,4,214,7,163,233,219,11,155,244,0,5,225,222,46,23,142,38,181,204,14,0,64,4,247,255,177,7,110,1,114,243,192,0,204,10,219,5,90,1,17,248,172,244,31,246,48,4,197,45,86,20,212,255,46,246,60,221,76,11,84,8,51,14,151,14,166,10,118,5,147,23,242,244,40,238,168,1,8,222,88,5,236,240,31,7,196,245,194,17,94,247,124,6,120,249,228,214,28,254,182,3,11,0,114,238,180,231,235,233,236,203,52,11,204,1,232,239,66,240,51,243,10,2,181,242,102,4,86,255,156,248,242,238,24,5,149,13,29,250,87,4,174,253,134,6,32,223,102,249,188,9,59,228,227,9,35,16,69,224,236,236,121,64,16,255,193,255,99,125,206,3,176,250,165,246,43,248,124,251,147,252,96,254,102,252,65,7,254,2,71,0,100,5,253,254,240,254,124,248,194,9,38,243,83,193,240,247,150,11,120,11,15,251,73,8,232,1,197,14,204,5,87,251,168,18,23,252,99,253,33,6,133,254,164,253,251,255,105,248,245,2,103,1,208,253,118,0,21,70,19,9,215,0,197,29,2,242,62,224,70,253,165,38,64,245,95,254,18,251,32,250,247,12,162,4,112,247,198,11,13,3,238,241,210,231,211,225,97,12,246,7,151,4,100,2,173,9,216,239,136,208,186,17,55,2,140,255,106,243,42,254,138,255,215,219,133,253,6,12,180,210,93,0,174,239,54,16,97,23,62,17,194,247,30,2,155,251,38,251,22,255,39,3,151,250,112,246,56,3,109,0,222,248,216,11,13,1,108,55,140,13,140,3,244,255,242,8,126,22,149,6,168,2,75,23,53,245,83,255,222,255,63,12,206,4,178,8,167,9,182,218,218,8,209,249,217,2,178,13,88,214,116,253,164,8,148,253,202,10,17,253,63,231,13,239,35,16,46,251,47,21,25,247,188,244,95,252,218,206,160,1,254,7,242,240,122,43,78,245,98,253,54,255,72,24,158,227,254,37,28,5,31,249,88,18,219,251,112,255,226,1,206,249,25,17,104,236,202,240,248,8,244,16,213,253,69,244,187,247,62,252,100,0,196,17,178,248,195,201,71,5,102,243,78,224,121,1,121,254,192,250,156,247,148,18,66,242,163,199,98,253,18,255,144,1,210,4,37,17,157,4,22,4,169,1,224,255,72,3,106,139,44,6,32,252,52,7,169,7,231,250,31,4,162,1,52,0,127,253,126,9,19,249,53,235,13,13,9,235,203,54,235,11,24,15,148,1,90,16,173,248,66,233,31,239,112,0,139,1,79,255,56,4,64,244,8,2,8,0,226,0,150,5,157,249,8,0,184,245,79,243,245,241,110,2,52,2,212,32,127,56,160,0,108,225,239,239,93,191,80,3,176,24,7,9,234,15,254,247,156,2,183,5,238,246,254,6,96,3,61,1,174,253,137,9,218,247,175,247,158,247,209,248,245,251,39,1,161,9,31,245,219,245,175,255,142,247,33,252,244,11,240,11,169,11,145,246,169,15,242,11,115,251,255,250,190,254,117,2,184,8,225,1,49,247,141,4,81,250,147,253,227,255,155,3,91,5,250,244,139,246,220,245,140,248,194,24,23,1,53,7,204,13,117,244,245,245,6,246,232,2,7,249,115,252,7,3,84,12,226,2,224,6,54,254,178,253,183,255,22,0,165,255,70,1,182,251,25,250,24,252,205,6,0,252,206,253,113,254,224,2,197,37,195,247,176,248,253,249,72,251,247,254,226,3,60,9,183,247,158,255,243,5,109,250,86,250,123,251,218,254,95,5,65,244,147,245,225,244,15,249,84,251,23,251,41,4,168,35,124,244,51,246,214,1,39,246,101,248,40,253,247,1,226,14,22,246,91,246,87,247,165,7,20,10,27,255,188,4,215,8,154,243,156,245,24,245,124,245,202,4,0,254,43,2,120,15,93,244,134,246,186,7,122,247,180,248,57,254,73,18,228,17,46,246,150,249,251,251,80,249,160,1,186,252,150,254,184,4,91,20,176,247,181,248,199,250,219,253,186,255,60,3,228,5,32,247,181,249,139,28,180,249,36,251,51,254,237,2,206,9,85,14,164,12,203,248,203,250,158,252,12,1,82,3,150,6,11,245,55,4,46,247,229,247,31,248,165,251,214,0,175,10,97,245,116,10,150,247,72,248,68,11,137,1,223,4,78,9,29,244,140,8,113,245,207,246,187,248,48,255,67,17,159,17,117,247,162,249,198,8,27,9,175,251,58,255,50,3,185,6,124,247,243,13,207,248,54,249,4,252,14,0,151,1,4,4,24,246,133,247,189,247,230,25,56,252,206,254,158,5,246,13,149,246,191,248,119,7,246,249,149,10,57,0,142,3,191,6,169,243,251,245,141,245,70,245,31,248,234,253,13,33,215,23,5,247,96,11,197,248,100,10,57,250,159,255,124,4,156,8,50,246,77,34,110,247,2,249,166,251,146,255,116,4,69,11,189,12,127,248,159,249,206,10,236,252,109,254,98,2,115,6,45,246,27,248,111,9,186,249,131,251,175,9,41,1,157,6,239,14,254,249,210,9,19,251,120,252,20,255,38,2,45,6,169,244,120,246,150,244,67,245,80,246,199,248,89,254,29,14,92,13,172,248,119,248,255,249,139,11,58,0,246,3,158,7,33,243,63,244,167,243,146,244,207,246,51,9,95,1,126,21,188,243,71,245,35,245,223,4,243,251,26,2,75,19,30,17,0,14,20,247,239,246,204,248,25,253,84,12,10,6,54,9,206,253,155,255,15,254,84,251,1,252,180,7,231,4,94,5,182,243,248,244,15,244,59,245,56,249,162,14,233,21,254,19,149,247,127,249,91,249,12,249,73,248,153,251,113,12,244,7,20,246,68,1,31,254,55,1,112,2,207,2,31,2,6,4,38,2,1,2,130,246,231,248,151,251,62,0,246,5,17,7,124,8,222,250,245,251,182,253,220,254,233,0,209,0,31,2,4,255,188,246,87,248,163,249,230,250,104,254,195,1,59,5,24,3,197,245,244,246,168,249,149,7,166,2,209,3,174,6,172,1,61,246,191,246,203,247,88,250,172,11,106,3,193,9,195,1,41,247,100,247,123,5,137,253,182,2,144,5,122,6,13,255,200,247,134,254,99,1,166,5,117,1,121,1,205,3,12,253,14,245,52,246,223,247,177,0,96,1,124,9,55,9,3,250,106,245,16,246,178,251,163,1,60,12,198,4,150,7,60,245,52,7,131,246,194,248,253,250,120,15,97,6,101,11,214,244,32,245,198,247,255,251,52,6,137,3,68,4,121,6,44,244,101,245,34,245,86,247,36,11,166,15,230,9,142,14,33,245,205,246,158,247,65,8,79,251,33,13,154,4,110,10,129,243,20,245,134,245,71,246,113,7,41,254,233,19,84,17,107,247,202,251,233,246,164,1,131,253,10,0,111,6,82,5,23,7,41,246,197,246,130,247,82,250,225,255,29,16,118,13,18,244,119,244,78,245,232,246,156,249,62,4,190,8,84,8,239,243,80,254,142,245,45,246,88,255,233,2,188,8,1,9,114,243,119,244,169,243,242,243,68,245,80,251,18,13,7,20,130,251,11,254,195,247,130,249,253,8,111,254,139,2,40,5,0,244,208,245,239,244,55,247,149,250,24,30,19,7,96,19,86,246,227,245,83,0,13,254,239,252,194,0,32,5,162,5,100,245,129,249,216,247,236,248,140,250,70,7,143,254,117,5,105,34,13,247,108,246,66,248,180,250,89,254,163,1,76,2,129,3,62,4,79,0,149,247,91,248,111,1,56,4,233,0,206,2,185,1,3,2,130,2,218,2,150,9,6,3,5,247,10,250,240,252,153,254,96,0,129,1,226,1,41,19,59,246,129,246,1,248,141,251,131,0,231,2,231,3,219,4,14,5,150,247,79,254,99,246,103,247,240,249,93,255,56,255,169,15,195,6,116,6,179,246,175,20,79,250,129,252,152,13,50,251,162,255,215,1,42,2,157,2,102,246,9,251,22,1,66,247,196,248,211,252,120,3,8,4,33,3,240,3,254,254,230,253,48,249,217,247,141,249,41,251,174,8,252,255,15,3,114,3,222,1,14,3,201,250,83,250,192,6,141,253,125,254,51,255,221,0,193,0,22,247,250,253,40,29,240,248,146,251,57,255,84,1,65,1,154,1,105,2,230,8,76,254,222,247,90,248,43,250,139,252,116,2,26,3,87,3,221,3,232,0,165,251,199,245,152,247,246,250,237,250,54,254,222,0,96,15,21,13,64,247,29,245,127,245,49,247,39,251,48,3,3,9,30,6,149,6,187,6,144,11,170,247,28,246,250,248,152,251,207,251,4,21,245,3,245,5,135,5,72,248,200,1,230,253,103,250,189,250,22,0,16,254,28,1,131,1,209,1,90,247,185,248,43,247,25,4,49,250,58,251,74,6,109,2,232,3,92,4,167,246,37,253,235,15,71,9,102,251,116,252,129,254,71,1,31,2,60,2,233,247,9,248,238,12,145,248,34,250,184,255,123,0,181,2,209,2,150,3,182,248,29,251,215,251,254,21,218,249,227,253,1,0,246,3,45,3,119,3,159,247,139,246,128,247,36,249,64,7,152,1,255,255,247,2,85,4,252,4,237,11,111,245,93,246,236,247,120,251,125,5,203,1,143,4,195,4,38,5,106,247,11,248,43,248,100,247,9,248,63,250,7,250,8,1,53,5,30,7,183,247,102,250,40,254,109,7,144,9,179,253,88,254,248,0,120,1,90,2,221,249,248,251,37,251,173,249,50,22,118,251,106,1,58,2,97,3,84,3,173,248,219,252,162,16,223,249,176,11,105,251,51,0,164,0,58,1,136,2,221,247,198,21,249,9,182,248,124,251,126,253,58,255,74,1,190,1,90,2,195,246,65,6,57,11,5,248,26,250,138,251,236,255,76,2,23,2,164,2,97,247,155,249,114,2,233,2,244,249,178,253,233,2,28,2,249,1,106,2,237,2,147,250,89,3,107,5,114,254,162,253,181,255,170,255,11,0,78,0,250,12,189,250,186,7,105,250,23,253,232,254,214,255,135,0,94,1,120,1,4,254,187,250,145,11,96,251,121,253,23,251,193,11,138,254,11,2,104,2,200,248,215,255,92,10,183,249,189,249,212,12,232,255,246,1,122,0,192,1,223,246,251,251,222,2,3,250,243,5,224,250,14,253,79,1,254,1,6,3,1,3,139,255,139,0,26,251,68,250,59,252,137,254,2,0,227,0,6,2,115,12,12,250,248,252,27,251,161,11,238,253,63,1,195,255,244,0,157,1,14,247,13,12,29,249,56,250,162,250,200,12,169,255,67,1,165,1,140,2,243,246,122,247,188,249,255,255,223,252,40,5,100,255,139,3,31,3,150,3,42,250,99,247,113,4,69,0,225,4,109,13,157,3,29,0,163,1,192,1,246,13,228,249,79,249,70,9,83,252,4,255,123,0,7,1,110,1,27,2,35,4,192,248,39,249,254,2,88,249,106,0,6,1,84,2,172,2,52,3,57,246,170,248,43,7,174,253,0,252,199,247,225,249,232,1,26,3,115,3,166,249,155,253,126,250,30,11,123,250,229,13,164,254,204,1,76,1,65,2,117,252,188,2,112,249,106,4,155,249,231,252,96,255,218,255,217,1,118,2,207,5,80,7,10,250,99,5,218,252,121,0,129,254,149,0,3,1,157,1,247,2,255,244,58,245,14,247,188,250,204,1,246,6,0,6,233,5,223,5,39,247,121,12,117,0,88,249,169,250,25,254,125,0,109,1,82,2,139,2,17,247,248,4,23,246,10,248,21,250,190,253,178,11,70,2,173,3,34,4,236,249,209,249,48,253,208,249,188,3,248,251,69,7,146,0,146,1,173,1,120,247,131,6,217,4,33,1,52,0,24,255,247,254,210,0,248,0,75,1,109,4,235,248,179,248,107,250,52,250,244,21,112,254,36,5,122,4,126,4,73,248,206,252,127,248,250,247,24,249,137,11,224,253,170,1,88,3,83,4,237,1,29,248,176,0,133,248,240,251,205,2,165,255,216,2,135,2,8,3,200,246,227,2,168,247,30,0,124,2,65,254,140,255,242,1,19,2,7,3,54,247,159,33,229,247,120,248,208,251,62,254,38,0,183,1,46,2,10,3,132,17,32,4,218,248,76,249,36,252,100,254,4,1,56,0,169,1,67,2,61,247,254,15,13,251,124,8,34,252,206,253,97,0,48,1,21,2,97,2,22,3,12,3,19,248,101,248,209,250,200,4,255,0,88,1,4,2,148,2,177,253,166,6,138,255,134,250,140,1,149,250,220,8,9,255,177,0,99,1,113,5,242,246,73,248,229,249,95,3,85,252,147,254,155,1,32,3,251,3,190,246,48,18,3,247,193,247,113,249,70,253,202,1,20,3,236,3,114,4,237,8,60,19,108,248,93,248,121,251,76,254,237,0,5,0,44,1,108,1,68,246,117,8,27,248,232,247,224,5,156,253,163,255,249,0,164,2,31,3,149,246,160,7,40,249,142,246,19,247,213,250,147,253,69,3,19,4,242,4,76,0,88,12,128,247,128,247,75,249,175,251,21,4,154,1,216,2,172,3,34,27,198,248,62,248,202,249,4,251,217,251,254,251,7,252,219,252,166,254,9,0,161,244,229,244,149,248,58,255,145,8,253,12,35,5,37,0,240,253,141,254,87,2,17,253,147,247,136,248,169,252,220,3,198,4,61,4,185,3,140,12,23,245,252,245,85,249,111,253,171,2,85,4,171,2,135,2,190,1,142,248,245,246,247,245,132,246,94,249,168,253,76,4,206,14,40,13,124,8,225,7,129,252,182,250,34,253,248,9,109,254,188,255,110,254,16,253,92,252,75,251,111,248,60,2,102,250,12,254,189,253,35,1,187,6,32,5,159,6,18,255,77,249,19,248,11,250,208,252,149,254,0,11,167,0,148,8,1,7,129,3,199,251,250,254,198,250,28,4,49,251,162,255,16,5,247,1,184,0,76,2,247,247,113,252,115,248,23,249,167,0,245,3,238,6,134,5,9,5,102,9,142,248,249,247,96,248,66,249,174,249,61,254,63,2,205,11,9,10,248,252,143,249,193,247,118,248,37,250,187,250,173,253,73,1,18,12,82,21,94,248,227,250,238,249,121,251,148,251,73,1,202,2,248,2,225,9,113,9,22,4,255,251,166,251,211,250,102,255,35,250,64,16,72,253,230,0,142,1,38,248,129,1,192,250,36,0,11,251,37,252,241,3,173,5,139,4,55,6,148,3,2,250,4,254,221,0,196,249,150,251,114,5,27,2,164,2,164,2,239,4,237,7,28,1,56,6,161,0,132,255,196,253,174,250,102,248,156,247,48,250,34,255,103,19,78,251,85,252,137,254,176,255,175,253,67,254,94,254,243,252,232,249,31,0,149,18,119,250,70,252,110,254,193,0,196,254,234,254,98,252,129,252,0,252,76,254,113,10,199,7,254,0,28,0,163,252,245,250,195,5,108,245,127,245,186,247,65,253,34,1,49,7,0,8,189,4,82,2,132,0,218,245,133,246,36,252,169,251,98,255,222,1,70,8,11,10,62,3,106,250,90,253,251,252,60,5,169,9,226,252,17,253,215,0,18,1,191,255,79,1,101,248,252,248,100,250,22,15,157,253,105,0,225,255,7,3,157,2,159,5,14,251,134,6,29,253,21,251,196,253,239,255,149,255,176,0,130,0,59,15,150,13,220,253,107,250,104,251,176,251,133,251,33,250,3,251,212,251,254,254,85,10,217,6,179,254,197,252,230,250,197,252,10,254,206,254,137,255,190,249,148,249,130,7,103,4,140,253,207,251,92,1,195,0,104,2,173,2,214,6,126,252,196,248,21,7,68,253,254,0,86,2,22,255,79,254,245,251,198,9,94,0,211,1,120,249,119,252,8,3,167,2,245,255,209,251,203,248,197,251,192,254,178,2,110,0,60,253,203,251,210,9,70,0,100,254,212,254,141,254,51,253,164,6,167,249,190,250,162,7,14,0,192,255,135,255,181,0,95,253,115,252,226,8,147,250,10,8,33,250,50,1,69,255,47,255,187,255,243,5,136,253,73,253,253,250,36,252,199,253,226,252,247,253,142,1,18,11,161,7,89,247,166,249,106,0,6,0,14,254,199,255,173,0,219,2,234,3,86,249,165,6,184,254,47,249,138,250,128,8,237,255,55,1,236,1,155,2,207,251,245,248,108,249,191,2,220,250,11,7,147,2,145,3,138,3,9,4,66,248,154,255,177,3,172,249,206,2,43,2,101,2,38,0,138,1,165,1,178,10,121,251,56,247,196,248,224,249,33,0,107,1,210,5,167,3,49,2,184,5,94,246,71,251,76,251,76,253,217,7,129,0,98,1,116,1,124,1,251,247,98,4,224,8,200,252,181,250,98,252,134,255,55,2,14,2,155,3,216,250,59,0,30,255,138,6,24,250,218,5,137,253,221,0,26,0,9,255,216,255,177,249,195,249,63,8,34,0,211,252,200,0,219,0,246,2,232,3,50,1,138,1,82,254,139,255,103,254,175,255,49,255,16,0,36,0,176,0,55,249,174,244,67,244,90,247,200,253,92,8,36,16,32,10,248,1,247,253,27,250,26,14,46,4,158,248,217,250,245,255,174,0,108,255,44,255,165,254,48,254,212,251,248,245,28,246,75,248,249,253,56,8,129,14,90,7,111,255,217,250,185,246,186,248,181,252,13,8,246,254,185,5,98,3,144,3,159,4,8,249,24,8,205,0,137,254,88,4,138,254,234,253,82,254,94,255,52,255,119,1,82,0,201,252,132,251,16,253,73,18,173,254,9,255,234,252,192,251,18,254,2,247,250,246,189,249,46,0,39,13,206,255,137,1,103,5,177,5,159,250,43,248,131,2,70,1,56,1,165,4,31,255,51,2,5,1,186,255,101,253,89,251,49,247,42,254,232,3,142,0,243,253,237,8,244,2,13,8,71,252,0,23,197,250,2,250,28,251,240,255,140,255,207,254,137,254,172,253,27,14,135,252,1,254,43,0,215,252,109,253,31,253,2,254,254,254,148,255,21,250,246,10,237,249,1,4,92,252,167,253,146,0,164,0,207,0,71,0,70,6,93,0,140,246,249,246,151,249,12,255,249,6,36,3,16,4,171,1,26,250,38,0,70,246,61,248,44,0,187,2,127,5,220,3,37,4,155,1,138,4,154,250,147,245,157,249,119,252,223,5,162,2,77,5,101,3,244,0,155,1,52,10,0,249,157,247,99,249,154,5,25,1,38,0,228,0,168,1,243,8,74,5,176,247,159,250,10,252,159,253,131,0,105,255,162,1,90,2,111,0,152,8,245,249,127,251,155,5,254,250,6,0,145,255,255,255,92,0,238,0,101,2,33,247,99,251,81,250,105,252,74,255,42,4,140,7,143,6,77,249,9,11,28,249,33,249,27,253,195,252,245,1,234,2,32,4,136,5,152,6,205,254,178,253,203,3,224,241,160,249,38,255,69,7,57,250,145,254,72,230,231,1,73,252,56,42,24,255,188,1,89,0,64,251,215,249,3,5,249,0,253,255,194,241,157,8,164,251,70,10,62,8,121,12,14,1,67,255,78,0,198,252,242,3,232,214,142,254,210,4,28,234,250,254,253,4,160,5,177,8,162,9,49,1,165,9,28,253,120,0,112,12,77,8,161,4,98,243,61,6,122,249,165,223,127,217,127,255,228,34,181,250,51,34,195,2,0,255,121,255,167,1,7,6,246,6,245,236,147,1,117,1,34,6,73,255,14,3,111,218,21,246,66,4,11,2,17,27,54,251,89,40,234,254,25,252,252,254,238,248,154,2,49,254,44,232,248,7,0,1,20,2,61,250,127,1,81,51,55,213,78,247,37,251,48,6,212,246,215,252,18,14,208,252,194,0,224,1,84,0,249,8,88,1,195,235,157,231,200,245,45,8,200,27,187,246,190,250,35,1,140,254,161,252,241,189,170,248,122,1,198,252,67,2,225,2,44,254,16,247,8,1,122,2,108,0,2,255,109,18,250,250,69,11,218,3,176,236,158,255,215,7,223,3,52,247,185,244,3,232,163,253,22,215,128,3,6,0,235,0,105,254,186,255,222,1,56,223,138,213,63,2,96,253,103,0,64,1,77,255,27,255,189,1,132,254,100,4,199,12,209,250,237,254,17,255,115,215,114,220,81,5,96,0,25,251,235,254,100,36,97,254,46,247,32,35,139,255,89,6,64,253,44,252,240,2,173,35,168,221,89,254,240,254,159,252,19,247,187,1,34,248,224,245,108,12,174,4,10,10,32,13,78,228,239,12,185,2,181,8,46,0,40,254,72,27,116,255,244,252,151,40,202,251,48,0,204,253,47,236,40,6,198,252,29,254,184,3,75,4,240,210,116,253,119,1,184,1,105,227,86,10,215,247,244,10,211,14,208,229,251,0,43,3,56,251,72,248,177,236,241,229,12,3,216,244,29,225,143,9,171,14,121,255,103,4,72,1,41,2,122,13,95,1,66,236,251,255,53,4,109,0,2,255,121,254,1,254,148,1,195,255,254,1,139,1,100,232,226,226,108,1,193,253,65,0,102,254,127,248,8,255,128,0,55,1,235,66,169,247,205,253,140,252,52,9,145,240,104,251,201,190,2,250,185,7,114,2,174,9,18,6,210,251,38,0,217,253,114,1,211,212,181,254,38,4,151,250,111,249,4,4,22,13,239,0,180,255,100,255,49,0,141,1,148,27,238,244,129,230,22,0,128,7,73,252,100,1,6,226,57,221,136,255,61,1,209,254,160,0,18,2,3,18,59,4,2,2,81,208,229,254,133,5,176,252,123,253,80,254,0,0,64,255,172,18,99,242,88,251,178,214,250,4,15,244,219,1,68,255,183,0,185,30,50,212,244,254,235,1,142,5,228,255,149,0,3,2,141,249,158,2,62,254,66,252,64,239,55,2,74,255,156,2,229,15,43,255,104,251,148,0,150,34,105,255,218,1,87,2,17,5,237,0,14,181,177,11,30,254,177,253,214,250,25,0,140,253,196,252,53,255,36,250,143,21,172,255,211,2,143,251,193,4,245,50,61,253,140,254,56,255,210,239,234,252,188,0,152,229,160,223,254,2,110,1,188,1,251,253,137,245,66,250,195,255,161,0,106,241,237,11,220,7,183,1,115,2,12,2,162,21,37,2,39,254,60,247,207,32,5,231,179,22,83,3,58,0,112,44,250,255,175,254,79,253,26,250,78,253,124,254,253,241,105,10,43,13,198,248,71,252,255,253,69,2,200,215,36,2,68,4,53,2,125,70,215,0,50,250,10,251,194,1,144,252,151,1,109,230,201,32,206,0,253,253,227,249,37,255,176,248,199,5,126,1,199,253,118,236,33,251,211,255,28,253,1,249,25,67,70,251,249,2,132,0,165,249,106,19,187,21,210,2,238,21,174,1,27,22,139,0,169,4,233,5,120,4,217,250,49,2,231,235,242,3,199,0,144,2,138,240,216,13,34,249,42,3,214,249,104,62,117,255,245,251,96,254,225,253,94,254,8,11,115,230,94,0,95,253,221,45,170,1,241,255,96,235,12,3,3,7,248,237,0,32,215,254,50,255,115,3,65,9,117,254,86,239,208,243,57,255,217,3,216,4,96,1,232,0,86,255,176,0,157,1,17,254,137,250,242,2,106,2,41,232,77,255,14,246,197,3,174,250,218,252,70,3,184,240,190,250,193,243,87,252,219,0,51,1,75,242,186,4,77,9,13,225,214,24,139,252,86,11,28,1,0,10,253,6,222,26,6,0,190,238,98,247,189,251,48,7,138,255,157,245,240,3,144,8,115,6,83,5,164,225,228,4,80,251,133,0,11,253,245,1,158,255,211,188,98,0,225,253,207,6,109,2,215,252,98,248,231,252,144,4,25,253,44,228,166,0,195,30,142,238,100,1,106,250,45,254,141,33,203,38,8,2,158,252,153,7,169,253,78,254,113,0,77,2,128,242,85,2,188,23,90,4,188,37,252,5,25,8,118,255,47,253,250,251,227,250,113,2,56,240,187,4,108,182,133,240,140,238,197,0,88,2,20,252,208,252,208,253,36,254,144,247,254,255,26,0,226,31,33,4,78,255,37,210,166,248,232,3,29,255,109,0,196,248,117,251,9,189,140,0,50,253,130,251,33,0,117,5,211,255,51,255,153,0,42,250,29,80,205,255,120,252,169,253,123,7,116,3,248,1,229,248,121,238,228,4,21,251,104,247,31,234,64,254,82,253,146,22,105,3,70,239,235,253,39,1,62,254,142,5,89,9,195,12,185,240,249,0,235,241,138,243,184,251,138,246,18,1,130,248,230,15,50,255,80,254,127,7,123,253,237,254,154,50,55,1,199,5,152,245,172,252,55,237,78,4,137,254,20,0,123,6,101,251,175,4,44,0,42,234,168,251,202,253,151,211,131,255,153,252,158,0,184,4,9,1,249,253,107,254,135,9,151,251,35,7,11,219,100,33,186,249,124,1,60,19,150,2,34,5,121,254,24,248,59,3,187,203,58,255,114,255,64,6,1,13,125,0,96,253,36,255,45,2,210,72,60,0,128,28,24,215,56,253,164,4,40,3,64,0,223,1,43,2,8,1,138,1,157,253,214,252,249,224,21,255,23,229,217,249,40,5,131,254,10,227,204,6,24,253,113,1,142,253,13,229,160,247,175,253,156,2,161,254,84,241,233,235,234,248,38,3,37,254,76,2,5,254,128,220,139,253,154,0,223,228,175,251,162,41,77,254,128,1,11,253,159,4,222,14,21,253,134,254,23,2,240,39,114,2,158,252,117,248,52,250,186,22,18,253,100,218,6,255,77,2,115,253,58,255,104,0,90,252,183,4,46,0,192,3,248,251,140,16,119,17,176,244,15,6,222,225,127,248,234,2,97,253,250,19,106,21,246,253,240,242,143,248,252,219,105,253,181,250,157,253,65,0,88,5,116,2,4,251,132,229,193,245,107,253,139,255,75,254,131,21,133,12,160,3,25,2,241,218,80,0,154,255,230,253,235,254,95,3,115,250,166,23,203,4,184,2,254,13,4,254,35,249,145,0,87,249,79,251,61,16,14,243,243,8,190,252,53,3,40,2,44,253,1,2,254,217,16,221,121,7,245,1,40,255,204,2,206,10,201,252,231,9,58,1,238,6,212,242,235,0,244,0,64,251,58,253,177,2,80,26,204,255,218,0,66,223,68,254,152,3,57,2,230,236,254,247,156,253,172,6,31,254,116,195,194,244,77,253,26,2,131,255,175,255,162,252,146,216,18,47,144,250,186,254,133,0,61,0,206,255,203,2,250,229,95,253,249,41,172,253,44,0,66,15,247,0,23,253,86,19,46,255,241,1,173,248,5,32,93,8,174,5,233,255,56,250,136,8,220,252,139,21,225,250,67,221,192,244,234,241,230,254,140,255,148,31,106,2,109,254,82,4,187,199,135,4,229,0,230,2,72,255,11,180,183,254,21,253,40,251,207,5,122,249,185,252,179,255,142,252,22,213,221,244,232,255,21,253,225,241,147,7,109,5,132,0,247,20,75,5,152,1,8,251,124,44,153,0,148,10,33,250,169,0,189,28,51,0,238,202,108,254,208,254,114,2,163,0,234,248,253,253,189,1,77,2,86,251,2,3,43,2,246,0,91,255,56,173,184,0,247,254,164,251,27,254,85,224,56,248,203,213,144,252,81,250,206,196,8,9,80,249,245,255,149,248,112,254,254,255,58,1,194,254,232,254,110,253,214,251,232,245,3,4,33,3,72,209,239,5,169,34,209,1,99,243,9,7,164,254,237,2,7,0,55,4,253,247,1,45,193,252,143,203,85,231,145,251,64,4,32,4,210,255,18,252,118,1,55,236,139,4,110,254,206,255,77,250,114,37,2,2,97,250,130,253,101,255,87,235,107,31,156,253,227,2,60,4,196,255,123,3,18,3,250,255,202,251,49,8,43,235,169,13,23,0,111,252,23,5,189,3,221,255,238,230,110,255,53,252,178,10,223,37,70,249,46,248,137,3,43,249,107,252,122,0,123,1,187,254,57,254,230,0,57,3,119,255,177,254,160,255,96,255,134,1,219,2,195,245,255,232,147,240,18,20,71,3,90,251,190,255,193,3,8,238,41,9,71,6,112,246,3,230,176,253,150,255,61,226,230,252,94,251,213,206,245,255,80,247,31,255,169,244,22,2,75,5,166,228,58,1,238,1,158,7,159,222,29,246,122,246,179,255,118,3,197,248,176,3,84,216,187,11,54,7,127,7,227,7,215,1,195,1,76,254,12,252,103,177,19,1,98,0,240,6,66,2,96,0,240,255,132,4,105,14,7,0,49,255,152,3,105,0,198,255,81,255,163,0,185,2,105,254,195,255,237,4,17,5,197,19,206,20,154,251,4,2,184,4,156,212,185,1,7,0,125,252,237,255,144,254,182,1,137,248,90,2,204,2,57,1,85,3,168,5,207,252,83,250,104,5,237,238,19,4,92,7,83,6,148,8,91,39,244,249,79,251,228,252,108,20,97,10,52,32,163,253,166,1,75,253,99,12,145,2,62,21,85,255,121,2,43,6,74,249,23,208,59,4,48,252,219,254,38,241,206,254,100,253,138,30,196,250,110,254,183,8,136,238,78,209,145,61,90,100,59,62,180,89,213,62,245,185,42,63,91,177,95,63,167,232,136,63,57,180,160,63,30,167,184,63,254,67,210,63,153,42,232,63,151,144,255,63,236,81,12,64,227,199,24,64,134,201,36,64,251,92,49,64,186,107,61,64,19,242,65,62,149,212,201,62,104,179,10,63,36,185,44,63,105,111,64,63,50,85,96,63,29,56,143,63,84,82,167,63,11,36,192,63,121,233,214,63,17,199,234,63,151,255,4,64,224,190,18,64,239,56,29,64,189,82,42,64,213,231,58,64,216,240,52,62,205,59,174,62,198,109,4,63,166,155,52,63,125,208,99,63,167,232,136,63,50,119,157,63,237,158,180,63,193,168,204,63,122,54,227,63,67,28,251,63,177,225,9,64,9,27,22,64,69,71,34,64,231,29,47,64,178,157,59,64,182,243,253,61,51,196,113,62,37,117,226,62,19,242,33,63,198,220,69,63,165,78,112,63,27,158,142,63,13,113,164,63,177,191,188,63,122,54,219,63,158,94,249,63,65,130,10,64,98,161,22,64,8,61,35,64,95,152,48,64,93,220,58,64,34,108,248,61,59,112,142,62,23,72,0,63,96,229,48,63,8,61,91,63,226,233,133,63,203,161,157,63,107,43,182,63,18,20,207,63,39,194,230,63,61,155,253,63,106,77,11,64,238,124,23,64,75,200,35,64,10,215,47,64,224,45,60,64,77,132,13,62,16,88,153,62,23,72,240,62,217,95,22,63,229,97,49,63,68,105,79,63,5,52,129,63,84,227,165,63,114,138,198,63,158,94,225,63,175,37,252,63,131,192,10,64,126,140,21,64,7,240,34,64,2,43,47,64,162,69,58,64,42,58,18,62,94,186,137,62,9,27,190,62,243,142,243,62,49,153,42,63,235,226,102,63,50,85,144,63,247,6,175,63,95,7,198,63,45,178,213,63,165,189,233,63,42,169,3,64,132,158,17,64,97,195,31,64,46,255,45,64,97,84,58,64,213,231,42,62,182,243,157,62,57,214,229,62,206,136,18,63,170,130,49,63,57,180,88,63,217,206,119,63,59,1,149,63,199,75,183,63,151,144,215,63,213,231,242,63,88,202,6,64,136,244,19,64,9,249,32,64,213,231,46,64,134,90,59,64,176,3,231,61,104,179,138,62,226,233,245,62,169,19,48,63,95,7,94,63,211,222,136,63,236,47,163,63,15,156,187,63,184,30,213,63,136,244,235,63,107,43,2,64,82,184,14,64,132,158,25,64,30,22,38,64,67,173,49,64,117,147,60,64,253,246,245,61,197,32,112,62,13,224,205,62,106,77,35,63,50,119,93,63,220,70,131,63,47,221,148,63,154,153,169,63,86,14,197,63,65,241,227,63,6,18,0,64,227,199,12,64,187,39,23,64,100,59,35,64,241,99,48,64,174,216,59,64,10,215,131,62,70,37,213,62,215,18,2,63,139,253,37,63,90,100,91,63,76,166,138,63,56,248,162,63,168,87,178,63,146,92,198,63,72,225,226,63,199,75,255,63,93,109,13,64,86,125,22,64,229,97,33,64,2,188,45,64,207,102,57,64,22,251,11,62,185,252,135,62,47,221,228,62,239,201,35,63,160,137,80,63,154,153,129,63,232,106,155,63,33,176,178,63,116,36,199,63,41,237,221,63,233,38,249,63,84,82,11,64,100,204,25,64,63,198,36,64,170,241,46,64,247,228,57,64,51,196,177,61,105,111,48,62,141,151,142,62,78,209,1,63,111,240,69,63,165,78,128,63,144,160,152,63,25,4,182,63,11,181,206,63,29,56,231,63,112,95,255,63,78,98,12,64,61,44,24,64,134,201,36,64,200,7,49,64,36,185,60,64,42,58,18,62,221,181,132,62,102,102,198,62,106,188,20,63,50,85,64,63,77,243,110,63,95,7,142,63,203,161,173,63,138,31,203,63,184,175,227,63,42,169,243,63,23,183,5,64,38,83,21,64,127,217,33,64,9,27,46,64,111,240,57,64,232,217,108,62,224,45,208,62,182,243,253,62,57,214,21,63,135,167,71,63,172,139,107,63,213,120,145,63,134,201,172,63,240,133,193,63,7,206,225,63,127,106,244,63,149,212,5,64,173,250,16,64,87,91,29,64,47,221,44,64,195,245,56,64,38,83,69,62,14,79,175,62,233], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+337937);
/* memory initializer */ allocate([183,239,62,250,126,26,63,227,165,59,63,44,101,89,63,9,27,134,63,96,118,167,63,162,180,199,63,96,229,216,63,179,234,227,63,34,108,0,64,34,108,16,64,45,33,31,64,53,239,44,64,131,192,58,64,129,4,197,61,111,240,69,62,95,41,203,62,58,146,27,63,192,236,78,63,1,222,130,63,148,135,157,63,107,154,183,63,174,71,209,63,73,157,232,63,82,39,0,64,33,31,12,64,149,101,24,64,175,37,36,64,88,57,48,64,242,176,60,64,244,108,22,62,48,42,137,62,245,185,218,62,227,165,27,63,145,126,75,63,36,185,108,63,28,124,137,63,115,215,162,63,220,215,193,63,140,74,226,63,39,49,0,64,13,113,12,64,96,229,24,64,111,240,37,64,65,241,51,64,233,38,61,64,230,174,37,62,231,140,200,62,13,113,28,63,23,72,64,63,184,30,85,63,197,32,128,63,125,174,158,63,228,20,181,63,122,199,201,63,249,49,222,63,61,10,247,63,225,122,8,64,125,208,19,64,111,18,35,64,164,112,49,64,145,15,62,64,174,216,31,62,93,220,134,62,114,249,207,62,141,40,29,63,118,79,78,63,134,56,118,63,104,34,140,63,242,176,168,63,44,212,202,63,197,143,225,63,165,78,248,63,71,114,9,64,223,79,21,64,28,124,33,64,210,111,47,64,70,37,61,64,100,93,220,61,104,145,109,62,86,159,203,62,198,109,20,63,152,76,69,63,41,92,127,63,126,29,152,63,231,140,176,63,34,142,205,63,235,226,230,63,18,20,255,63,198,109,12,64,161,214,24,64,177,191,36,64,136,99,49,64,206,25,61,64,150,67,11,62,128,72,127,62,65,241,195,62,133,124,16,63,200,7,61,63,144,160,104,63,111,18,139,63,70,37,165,63,53,94,194,63,177,191,220,63,66,96,245,63,31,133,7,64,11,70,21,64,44,212,34,64,86,159,47,64,149,101,60,64,13,113,44,62,135,22,153,62,83,150,225,62,180,89,21,63,12,2,59,63,231,29,103,63,184,64,138,63,220,70,163,63,3,120,187,63,19,97,211,63,44,212,234,63,187,39,3,64,2,154,16,64,250,126,30,64,57,180,44,64,107,43,58,64,250,126,234,61,12,2,107,62,187,39,175,62,183,209,0,63,19,97,51,63,245,219,103,63,190,159,138,63,127,251,162,63,43,135,190,63,23,72,216,63,168,87,242,63,29,56,7,64,56,103,20,64,2,188,33,64,27,158,46,64,106,77,59,64,141,151,46,62,248,83,195,62,8,172,28,63,223,224,75,63,187,39,111,63,81,218,139,63,181,21,163,63,188,116,187,63,152,221,211,63,121,233,230,63,141,40,253,63,192,91,12,64,231,140,24,64,245,74,37,64,141,151,50,64,248,194,60,64,74,123,3,62,20,63,134,62,87,91,241,62,16,233,39,63,4,231,76,63,98,16,128,63,243,31,146,63,133,124,168,63,247,228,201,63,66,62,232,63,84,82,255,63,112,206,12,64,231,140,24,64,68,139,36,64,42,169,47,64,220,70,59,64,32,99,238,61,243,142,147,62,53,239,8,63,209,34,59,63,48,42,89,63,249,15,121,63,108,9,145,63,72,225,170,63,250,237,195,63,77,132,221,63,105,111,248,63,246,40,8,64,101,170,20,64,140,74,34,64,70,182,47,64,247,117,60,64,251,92,237,61,167,121,135,62,96,118,239,62,51,51,35,63,7,240,70,63,193,168,116,63,247,228,145,63,173,250,172,63,119,45,201,63,82,39,224,63,123,131,247,63,154,119,8,64,216,240,20,64,27,158,34,64,122,54,47,64,241,244,58,64,27,47,221,61,118,113,91,62,133,235,177,62,245,219,7,63,100,93,60,63,103,213,119,63,40,15,147,63,101,25,170,63,18,20,199,63,101,25,226,63,218,27,252,63,90,100,11,64,194,134,23,64,156,162,35,64,136,244,47,64,32,210,59,64,94,75,8,62,254,212,120,62,212,154,198,62,238,90,2,63,247,228,33,63,174,216,79,63,131,47,132,63,117,2,162,63,185,252,191,63,56,248,218,63,120,122,245,63,11,36,8,64,43,24,21,64,14,45,34,64,73,46,47,64,245,219,59,64,210,111,31,62,252,24,147,62,158,94,233,62,249,160,39,63,25,226,88,63,87,91,129,63,170,241,146,63,46,255,169,63,241,244,202,63,111,18,227,63,81,107,250,63,0,145,10,64,135,22,21,64,38,83,33,64,254,212,44,64,0,145,58,64,132,13,15,62,251,92,141,62,240,22,232,62,165,44,35,63,137,65,64,63,105,111,96,63,239,56,133,63,54,60,165,63,221,181,196,63,156,196,224,63,144,160,248,63,89,134,8,64,68,139,20,64,14,190,32,64,72,80,44,64,211,222,56,64,55,137,193,61,103,68,41,62,7,95,184,62,4,231,28,63,16,122,86,63,45,67,132,63,7,240,158,63,101,25,186,63,35,74,211,63,140,74,234,63,149,212,1,64,7,206,13,64,164,112,25,64,55,137,37,64,22,106,49,64,143,83,60,64,165,189,65,62,29,201,197,62,218,172,250,62,57,69,23,63,245,185,58,63,202,195,114,63,246,40,148,63,109,86,173,63,136,99,189,63,227,165,211,63,147,24,244,63,27,47,9,64,151,255,20,64,239,201,31,64,179,12,45,64,83,5,59,64,11,70,37,62,110,52,160,62,156,51,2,63,198,109,52,63,238,124,95,63,40,15,131,63,78,98,152,63,144,160,176,63,238,235,200,63,213,9,224,63,182,132,244,63,209,34,7,64,57,180,20,64,99,127,33,64,144,160,44,64,38,83,57,64,34,142,245,61,166,155,132,62,17,199,218,62,158,239,23,63,64,19,65,63,102,102,118,63,20,174,143,63,217,95,166,63,237,158,196,63,213,231,218,63,13,113,244,63,33,31,8,64,110,52,20,64,19,242,33,64,36,40,46,64,82,184,58,64,27,158,222,61,197,254,114,62,199,41,218,62,242,176,32,63,187,39,79,63,200,7,125,63,222,2,153,63,131,47,180,63,22,106,205,63,195,211,227,63,6,18,252,63,5,163,10,64,41,237,21,64,215,52,35,64,211,188,47,64,171,62,59,64,147,58,1,62,28,235,98,62,120,122,197,62,84,116,20,63,34,253,54,63,127,106,92,63,39,160,137,63,26,81,170,63,247,6,199,63,16,88,225,63,111,129,252,63,172,28,10,64,231,29,23,64,81,218,35,64,121,88,48,64,22,251,59,64,207,247,19,62,151,255,144,62,20,208,228,62,69,216,32,63,209,145,76,63,17,199,122,63,79,64,147,63,206,136,170,63,163,1,196,63,90,100,219,63,88,202,242,63,4,86,6,64,30,22,18,64,19,97,31,64,183,209,44,64,100,204,57,64,30,167,40,62,23,72,208,62,241,244,10,63,254,101,39,63,193,168,68,63,249,15,89,63,87,236,111,63,18,165,149,63,255,33,189,63,132,158,221,63,218,27,244,63,13,224,5,64,236,192,17,64,131,47,32,64,214,197,45,64,176,3,59,64,37,117,2,62,45,67,156,62,194,23,6,63,53,94,58,63,45,67,108,63,52,128,143,63,14,79,167,63,54,60,189,63,234,4,212,63,115,104,233,63,224,45,0,64,41,203,12,64,77,21,24,64,38,228,35,64,98,16,48,64,223,224,59,64,100,93,220,61,156,196,96,62,43,135,246,62,229,242,47,63,56,248,82,63,165,189,113,63,18,165,141,63,144,49,175,63,226,233,205,63,119,190,231,63,107,43,254,63,170,130,9,64,152,110,22,64,50,119,37,64,242,210,49,64,163,1,60,64,70,182,51,62,36,40,158,62,78,98,240,62,85,48,42,63,47,221,84,63,234,149,130,63,11,181,150,63,191,125,173,63,200,7,197,63,161,103,219,63,146,92,246,63,181,55,8,64,89,23,19,64,10,215,31,64,196,177,46,64,153,42,60,64,194,134,39,62,101,25,162,62,122,54,235,62,196,177,30,63,238,235,80,63,4,231,124,63,20,63,150,63,27,158,174,63,57,180,200,63,208,179,225,63,186,218,250,63,23,217,10,64,249,160,23,64,22,106,37,64,68,250,49,64,5,52,61,64,181,166,249,61,94,75,136,62,68,139,236,62,107,43,38,63,57,214,85,63,133,235,129,63,152,110,154,63,179,123,178,63,74,12,202,63,67,173,225,63,224,45,248,63,119,45,9,64,143,194,21,64,188,5,34,64,252,24,47,64,25,226,60,64,172,139,219,61,29,56,103,62,95,41,203,62,105,111,16,63,25,226,56,63,146,203,111,63,147,169,146,63,115,215,170,63,93,109,197,63,217,95,222,63,18,20,247,63,48,42,9,64,30,22,22,64,240,167,34,64,64,164,47,64,33,31,60,64,169,164,14,62,61,10,151,62,106,222,241,62,234,4,36,63,159,171,77,63,149,101,128,63,226,233,149,63,50,119,173,63,169,164,198,63,93,220,222,63,2,188,245,63,139,108,7,64,36,185,20,64,248,194,32,64,88,168,45,64,121,233,58,64,40,15,11,62,29,201,133,62,108,9,217,62,158,94,25,63,42,169,67,63,55,26,112,63,194,134,143,63,59,223,167,63,140,219,192,63,46,255,217,63,251,58,240,63,180,89,5,64,239,201,19,64,140,219,32,64,26,81,46,64,47,110,59,64,165,189,1,62,231,251,137,62,249,160,231,62,199,186,40,63,7,240,86,63,227,54,130,63,65,241,155,63,242,210,181,63,128,183,208,63,62,121,232,63,172,173,0,64,38,83,13,64,175,37,24,64,108,9,37,64,143,83,48,64,169,19,60,64,185,141,6,62,28,124,129,62,84,116,196,62,122,165,12,63,27,158,62,63,25,226,104,63,91,66,134,63,43,135,158,63,120,11,188,63,168,198,219,63,72,225,250,63,248,83,11,64,105,0,23,64,69,71,34,64,14,45,46,64,199,41,58,64,191,125,29,62,52,17,150,62,239,201,227,62,76,166,26,63,26,192,75,63,25,115,119,63,16,88,145,63,163,35,169,63,133,235,193,63,68,139,220,63,14,190,248,63,222,2,9,64,58,35,22,64,225,11,35,64,21,140,46,64,70,182,59,64,180,89,53,62,206,25,145,62,97,195,211,62,226,233,21,63,220,104,64,63,91,177,111,63,249,160,135,63,123,131,159,63,52,162,188,63,91,211,212,63,156,196,240,63,41,92,7,64,40,126,20,64,236,192,33,64,19,97,47,64,106,188,60,64,36,151,255,61,183,98,127,62,92,32,225,62,120,156,34,63,234,149,82,63,39,49,128,63,247,6,151,63,45,67,172,63,7,95,200,63,131,81,233,63,104,34,4,64,236,81,16,64,98,161,26,64,107,43,38,64,184,30,49,64,27,13,60,64,18,20,191,61,77,21,76,62,219,249,158,62,146,203,223,62,116,70,36,63,106,188,100,63,87,236,143,63,4,231,172,63,165,78,200,63,76,55,225,63,5,163,250,63,21,140,10,64,35,74,23,64,64,164,35,64,154,119,48,64,95,152,60,64,162,180,55,62,38,83,165,62,15,156,243,62,91,177,31,63,181,55,72,63,180,200,118,63,139,108,143,63,130,226,167,63,242,176,192,63,18,20,215,63,137,210,238,63,153,42,4,64,13,224,17,64,18,20,31,64,229,242,43,64,162,69,58,64,110,52,0,62,235,115,117,62,20,208,196,62,85,48,10,63,143,83,52,63,32,65,97,63,153,187,134,63,86,14,157,63,169,164,182,63,215,18,210,63,168,53,237,63,129,4,5,64,192,236,18,64,143,83,32,64,138,176,45,64,170,241,58,64,59,112,14,62,143,228,178,62,143,228,18,63,22,106,77,63,32,65,129,63,159,205,154,63,37,6,177,63,228,131,198,63,13,113,220,63,220,104,240,63,152,221,3,64,152,221,15,64,234,149,26,64,249,49,38,64,116,181,49,64,225,122,60,64,29,201,229,61,100,59,95,62,143,194,213,62,145,126,27,63,170,130,65,63,211,77,114,63,204,93,147,63,131,192,170,63,131,192,194,63,130,226,223,63,93,220,254,63,33,31,12,64,161,248,21,64,173,105,34,64,100,59,47,64,109,197,58,64,248,83,35,62,181,21,155,62,16,233,247,62,247,228,33,63,12,147,73,63,8,61,123,63,99,127,153,63,191,125,173,63,181,55,192,63,113,27,221,63,180,89,245,63,142,117,5,64,56,248,18,64,133,235,33,64,46,255,45,64,198,220,57,64,113,61,10,62,122,165,140,62,152,76,245,62,204,238,41,63,123,20,78,63,235,226,118,63,174,216,143,63,205,59,166,63,210,0,190,63,130,115,214,63,192,91,240,63,26,81,6,64,80,252,20,64,174,182,34,64,139,108,47,64,223,224,59,64,236,47,187,61,69,216,48,62,238,235,160,62,165,44,3,63,75,89,54,63,54,171,110,63,57,214,149,63,167,232,176,63,40,15,203,63,202,50,228,63,61,44,252,63,231,251,9,64,74,12,22,64,67,28,35,64,58,146,47,64,22,251,59,64,254,67,250,61,197,143,113,62,103,68,201,62,226,88,23,63,203,16,71,63,248,83,115,63,63,198,148,63,135,167,175,63,249,49,198,63,18,165,221,63,14,79,247,63,17,54,8,64,175,37,20,64,187,184,33,64,174,182,46,64,148,246,58,64,226,233,85,62,20,63,198,62,211,77,2,63,61,44,36,63,136,244,75,63,143,228,130,63,23,72,152,63,188,5,178,63,17,54,204,63,131,47,220,63,91,66,238,63,141,151,6,64,247,6,19,64,111,129,32,64,65,241,47,64,217,61,57,64,38,228,3,62,126,29,120,62,97,84,210,62,236,47,27,63,20,208,68,63,122,54,107,63,122,54,139,63,79,175,164,63,125,174,190,63,176,114,216,63,210,0,246,63,235,226,6,64,182,243,17,64,175,37,32,64,193,202,45,64,50,230,58,64,82,73,157,60,54,60,61,61,23,183,81,60,124,242,176,59,36,151,127,188,202,84,65,188,27,47,93,188,166,155,68,59,166,155,68,188,95,41,75,59,166,155,196,60,199,186,56,189,125,208,51,189,124,242,48,189,245,219,87,189,12,147,169,188,242,65,207,60,39,160,9,60,35,219,249,188,250,237,107,188,153,187,150,59,44,212,26,189,128,72,63,189,231,29,39,188,66,96,229,60,27,47,93,61,254,101,119,60,197,254,50,61,176,3,103,60,206,136,210,188,237,13,190,187,215,52,239,59,14,79,47,60,124,242,176,59,43,246,23,61,49,8,44,188,2,43,135,60,140,74,106,188,179,123,114,60,154,119,28,61,124,242,176,187,30,167,232,188,23,183,209,56,234,149,178,188,134,90,211,60,97,195,83,61,73,157,128,60,23,183,81,187,227,165,155,188,40,126,12,61,250,237,107,61,187,184,13,61,46,144,32,61,0,111,129,188,1,77,4,189,177,191,108,189,36,185,124,189,20,63,198,188,250,237,107,188,117,2,154,60,22,251,203,60,39,160,9,59,232,217,44,189,49,8,44,189,154,153,153,61,191,14,156,61,184,30,5,61,208,68,216,187,185,252,7,61,117,2,26,61,192,236,30,61,37,6,129,61,61,10,87,61,46,144,160,60,231,29,167,59,20,63,70,189,38,228,3,189,202,84,193,59,208,68,88,60,0,111,1,60,129,38,194,60,228,131,158,61,224,190,142,61,153,187,150,60,74,123,3,189,111,240,5,189,247,117,224,60,30,167,232,60,17,199,186,59,177,191,236,60,239,201,67,61,30,167,104,60,159,171,173,187,17,199,58,60,215,52,239,60,23,183,81,187,198,220,53,188,155,85,31,189,176,3,231,60,181,21,123,61,10,215,163,60,82,73,29,186,198,220,53,60,82,73,157,59,64,164,223,60,137,210,222,58,116,36,23,189,221,36,134,61,8,61,155,61,248,83,99,61,56,248,194,60,82,73,29,187,10,215,35,188,86,159,43,189,114,138,142,189,0,111,129,188,202,50,68,189,7,95,152,189,78,209,17,189,57,180,200,188,10,215,35,189,52,128,55,188,172,139,91,60,23,183,209,56,232,217,44,189,206,136,82,189,221,181,4,188,185,252,7,60,254,101,119,188,1,77,4,61,23,183,209,184,198,220,53,189,48,76,38,189,14,79,175,188,10,215,163,187,18,131,192,188,158,239,167,188,208,68,216,188,221,181,4,189,112,206,8,61,46,144,32,61,135,22,217,60,177,191,236,60,188,116,147,60,204,238,73,61,90,245,185,60,192,236,158,60,6,129,21,61,137,210,94,61,3,9,138,61,102,247,100,61,226,233,149,61,163,146,186,61,238,235,192,61,43,135,150,61,114,138,142,60,163,35,57,188,65,130,98,189,39,49,136,189,90,245,185,188,61,44,212,188,62,232,217,188,239,201,195,188,8,61,27,189,39,194,6,61,187,184,141,60,49,8,172,188,17,199,58,188,59,112,206,187,166,155,196,59,78,209,17,188,156,51,162,188,176,3,231,188,111,18,3,188,5,163,146,188,104,145,237,188,153,187,150,59,59,112,78,188,208,68,216,187,41,92,15,61,62,232,89,61,18,131,192,60,156,51,162,60,159,171,173,60,16,233,55,61,3,120,139,61,76,166,138,61,46,144,160,187,4,231,12,60,166,155,68,60,78,209,17,61,90,245,57,61,179,123,114,61,16,233,55,61,210,0,222,188,96,229,80,189,88,57,52,188,91,177,191,60,48,76,166,60,203,16,199,60,20,63,198,60,62,232,89,60,46,144,32,60,111,18,131,59,82,73,29,59,111,18,3,186,143,194,245,187,59,112,78,188,9,249,32,189,195,100,170,187,2,43,135,60,23,183,209,58,9,27,158,188,239,201,195,60,39,160,9,61,237,13,62,59,142,6,112,189,63,198,92,189,117,2,26,188,185,252,135,189,16,233,183,189,27,47,93,189,208,68,216,187,172,139,91,60,179,123,242,187,172,139,219,59,207,102,85,189,160,137,48,189,195,100,42,60,223,79,141,61,75,200,135,61,229,97,161,60,137,210,222,186,61,44,84,189,253,135,116,189,77,21,140,188,124,242,176,187,66,96,101,188,111,18,3,188,4,231,140,60,116,70,20,189,188,5,146,189,182,243,253,188,82,73,29,60,203,16,199,60,191,14,28,61,95,41,203,187,46,144,32,189,249,49,230,188,9,27,30,61,91,211,60,61,101,25,226,59,82,73,29,61,111,18,3,60,176,3,103,188,77,21,140,60,13,113,172,62,82,39,160,62,48,42,169,62,159,171,173,62,111,18,163,62,145,126,155,62,251,203,142,62,149,212,137,62,233,72,142,62,187,39,143,62,234,4,148,62,84,82,135,62,194,134,135,62,248,194,132,62,198,220,149,62,240,22,168,62,164,223,254,62,183,98,255,62,173,105,254,62,174,216,255,62,100,204,253,62,100,59,255,62,201,118,254,62,164,223,254,62,91,211,252,62,191,125,253,62,91,177,255,62,228,131,254,62,247,6,255,62,45,33,255,62,118,79,254,62,97,50,245,62,37,217,95,253,10,2,220,255,140,1,79,254,181,3,70,254,49,207,118,247,184,16,27,252,77,249,39,227,133,254,170,13,196,253,87,217,30,26,128,237,65,2,74,7,147,2,133,255,110,249,164,1,158,252,106,17,189,22,83,12,249,30,70,234,250,248,14,12,108,33,191,255,17,221,50,9,165,239,42,241,115,2,189,248,224,217,237,248,68,249,211,255,210,248,102,6,243,1,148,0,177,254,180,81,248,254,212,253,243,254,10,252,5,250,199,2,249,253,206,1,3,236,104,15,74,252,85,32,110,3,61,237,117,236,206,238,142,237,172,11,112,255,25,229,165,41,115,252,188,2,17,247,94,47,155,255,7,253,44,7,59,3,159,253,26,2,186,1,104,238,20,7,234,14,191,28,96,0,213,253,62,6,56,39,214,253,156,3,98,13,6,249,60,10,172,247,99,3,249,253,5,247,96,253,4,254,201,0,103,246,120,42,117,236,46,21,70,221,152,255,19,10,172,3,145,1,103,3,159,43,192,4,30,4,196,244,13,250,146,240,51,251,174,242,84,254,64,14,83,219,47,244,40,249,159,29,113,15,146,7,59,15,155,5,234,31,251,3,240,246,19,5,128,251,226,0,138,1,64,44,65,250,92,2,72,255,55,2,136,241,165,233,206,232,167,1,146,36,194,17,10,243,189,242,220,19,11,239,11,249,197,245,54,4,147,254,151,0,99,254,169,171,56,252,54,255,73,255,81,3,31,254,151,1,245,255,108,245,168,9,129,10,240,219,246,218,16,249,133,2,26,250,126,250,29,232,142,255,10,246,130,7,132,6,32,1,234,250,180,3,175,7,52,0,89,9,73,248,118,1,206,67,204,250,183,20,123,12,142,245,176,18,118,250,177,250,199,255,178,247,10,18,186,34,55,25,157,4,76,0,118,1,113,37,58,34,160,2,126,253,154,2,171,230,215,6,183,12,90,252,52,24,124,3,171,0,154,255,212,255,186,254,50,5,192,254,32,254,182,252,152,168,207,253,115,255,123,2,128,230,79,22,96,9,70,3,30,11,116,243,35,235,153,234,97,19,62,8,200,226,137,239,28,31,228,250,195,4,5,6,190,238,149,24,86,238,233,236,128,233,230,10,161,5,247,23,147,251,165,249,211,4,146,3,60,2,237,251,63,250,249,253,246,237,52,251,76,208,77,4,214,213,60,239,253,238,31,25,180,253,32,252,100,2,21,249,95,26,7,19,69,2,108,2,160,254,21,1,215,2,178,8,104,33,213,255,247,8,193,36,98,4,194,29,93,7,168,4,104,250,177,251,218,33,226,247,109,254,5,249,36,6,104,247,231,225,169,229,3,251,52,251,187,3,189,29,0,250,82,33,71,22,70,21,155,16,171,252,46,19,42,6,16,11,250,4,206,245,243,0,4,11,183,3,24,36,81,6,93,2,157,229,88,245,230,233,26,15,99,255,191,4,234,222,10,248,67,255,171,40,20,29,136,254,151,1,152,251,2,3,102,254,247,1,171,6,18,3,239,253,82,0,229,255,8,84,230,254,81,0,151,251,82,253,213,253,114,10,157,255,4,5,168,8,214,4,148,1,186,242,242,3,126,15,146,251,134,245,142,55,211,249,51,38,166,251,80,3,113,7,81,8,159,240,122,237,205,4,115,31,8,239,74,15,177,16,109,253,159,0,92,251,204,248,144,3,24,251,34,254,226,192,203,244,191,3,208,247,138,247,56,9,181,30,98,245,42,231,229,29,239,25,89,243,102,249,38,251,111,13,230,4,70,252,92,2,104,68,224,254,108,9,211,0,214,254,96,10,159,235,22,249,124,3,187,7,54,250,170,13,216,255,184,40,242,251,186,248,177,38,42,1,77,0,131,8,164,238,20,10,235,247,183,230,61,0,84,0,11,4,123,253,106,253,200,252,25,253,152,255,86,248,132,255,112,19,254,234,26,251,113,228,110,242,57,214,26,251,243,9,74,253,122,12,174,255,182,245,230,0,102,1,244,255,58,6,166,255,86,2,180,255,112,173,2,251,78,3,172,255,3,1,24,246,166,238,33,9,186,249,64,243,202,243,177,253,241,250,120,246,224,245,136,42,189,22,162,252,50,236,162,40,119,214,159,0,156,245,126,3,192,247,18,249,148,14,4,252,166,1,15,37,72,6,32,252,254,7,19,1,76,214,46,10,25,252,221,1,180,248,102,249,156,18,237,230,130,226,223,31,17,2,4,9,118,254,166,246,10,11,24,26,240,1,44,14,122,253,114,12,111,253,44,247,120,250,14,220,240,1,224,25,137,9,18,6,109,247,246,222,125,242,210,1,50,26,32,4,183,221,60,21,96,240,198,243,186,18,17,232,216,7,66,6,195,0,46,2,174,250,144,252,154,245,254,37,191,217,173,11,146,243,182,246,198,250,62,4,182,237,116,1,113,254,121,43,167,253,102,253,86,20,174,251,106,1,83,12,72,1,122,217,207,2,66,6,230,3,218,246,89,3,230,5,220,1,88,28,44,18,138,233,129,236,3,18,14,34,174,238,233,239,161,254,186,249,247,251,123,241,1,14,165,36,198,249,188,19,10,227,51,255,52,9,195,232,222,221,246,5,210,248,152,18,188,234,111,2,112,0,209,244,78,22,56,19,25,37,175,14,252,41,55,255,204,2,235,2,1,246,19,240,63,254,27,253,120,255,233,250,196,253,94,7,38,252,223,214,205,255,80,5,114,9,116,0,46,250,136,7,7,217,112,18,227,0,52,212,146,14,76,244,20,5,207,38,100,1,246,237,128,254,204,3,102,12,148,14,221,252,106,10,22,3,19,8,39,9,71,251,93,216,21,0,106,35,44,238,204,9,80,255,8,1,106,38,32,13,110,28,170,36,6,251,10,2,206,255,54,16,140,252,80,2,80,253,53,1,14,81,160,2,210,250,166,254,110,1,10,8,161,253,121,2,108,2,91,253,74,1,69,0,176,1,63,1,180,1,212,254,85,85,194,254,92,253,64,1,126,254,121,3,44,253,142,250,152,245,81,254,254,7,120,255,144,21,44,26,168,4,147,22,170,36,43,242,250,233,3,193,253,254,33,2,245,254,180,7,194,246,213,255,103,2,251,0,235,3,44,252,214,8,233,214,134,47,215,7,140,252,232,249,30,251,21,254,74,254,52,3,188,4,184,13,98,1,214,251,210,255,98,0,59,1,84,33,176,3,239,250,75,31,5,4,129,254,186,249,67,223,142,249,36,11,66,252,221,6,82,239,112,8,189,219,102,11,122,241,32,255,10,24,217,233,180,14,214,253,94,20,34,246,225,255,35,2,6,0,97,6,46,238,144,5,153,4,158,252,112,6,141,2,168,23,203,248,9,251,162,254,84,2,18,247,165,38,62,230,75,4,118,2,231,253,230,0,204,3,122,255,21,254,79,0,50,1,182,255,253,0,208,0,244,248,73,0,123,211,122,1,45,50,235,248,86,1,73,1,141,4,38,2,44,2,141,255,243,2,117,0,207,9,4,1,91,251,130,250,8,250,74,7,228,12,50,218,1,4,173,40,199,0,62,11,12,242,253,33,153,248,91,251,192,253,200,242,94,255,142,213,181,12,13,251,91,0,229,8,170,255,190,242,176,25,85,246,144,251,57,239,182,249,128,224,41,1,52,221,175,238,118,244,174,255,94,211,254,237,15,8,242,5,220,224,17,254,7,7,106,11,197,235,159,252,131,18,64,43,87,15,29,254,153,212,185,246,104,250,186,4,194,250,114,9,152,6,84,3,192,255,133,0,26,238,32,228,62,41,167,242,166,243,241,7,77,12,22,244,228,9,56,2,116,246,242,15,213,244,146,215,137,236,233,25,230,0,66,23,140,251,111,253,26,252,132,4,224,2,66,221,64,0,171,3,252,254,88,249,242,253,206,250,155,252,133,246,89,48,16,5,136,255,192,214,2,7,126,220,207,5,250,27,7,2,130,254,94,243,190,255,14,5,59,9,202,5,242,1,43,240,16,253,102,255,181,253,219,254,149,64,65,0,69,251,130,6,35,1,4,11,174,8,2,0,97,3,88,1,74,251,66,251,142,247,138,34,55,43,211,247,104,7,167,252,112,255,65,1,180,218,112,17,174,19,230,254,136,4,62,255,55,3,151,13,214,223,202,22,192,254,202,27,72,255,153,245,106,210,216,1,35,248,254,250,38,17,101,17,178,247,77,246,124,252,138,231,67,247,229,253,146,251,164,0,170,1,247,220,46,249,88,248,236,31,177,247,20,178,145,2,56,253,88,1,69,254,202,1,204,253,56,0,244,2,99,255,18,1,212,250,212,242,165,11,123,2,18,219,204,236,68,11,12,9,8,32,84,250,87,8,249,6,226,251,82,0,143,19,188,239,130,2,25,36,227,19,234,3,163,9,39,223,170,252,163,252,243,246,149,1,238,248,231,252,29,225,240,1,19,252,45,13,8,252,55,37,226,253,136,6,111,220,24,1,162,43,17,1,140,3,89,0,23,255,98,42,102,3,180,1,94,6,0,13,13,254,227,19,200,4,175,35,32,254,146,251,124,9,168,244,213,19,222,7,43,11,181,16,83,30,15,34,46,211,83,6,143,4,140,243,217,251,79,254,61,239,86,10,0,4,216,7,61,1,234,2,71,1,168,26,150,4,18,35,134,20,12,221,120,255,214,245,94,250,70,253,74,252,8,7,40,1,8,252,117,6,187,14,146,219,184,17,121,27,121,18,230,25,18,4,167,0,221,44,50,48,109,255,18,11,99,2,52,7,199,254,230,1,108,252,137,252,113,250,130,2,242,0,75,0,173,248,123,253,41,251,186,247,178,5,240,254,89,249,181,3,10,3,66,85,214,0,216,250,54,1,120,10,250,249,102,247,48,4,124,255,237,247,247,241,155,223,165,215,70,35,146,1,114,245,168,11,220,208,98,12,182,251,105,251,92,251,182,11,135,4,80,249,120,252,236,0,42,0,55,3,36,2,222,253,94,248,117,62,92,247,94,7,252,8,245,8,46,10,89,11,61,9,66,251,56,6,82,5,94,247,138,6,156,248,201,58,12,252,248,244,232,252,73,211,136,43,245,18,155,254,50,251,236,2,188,4,218,254,88,254,96,245,78,0,155,247,198,3,114,30,109,6,138,0,59,253,208,1,30,14,188,215,54,1,138,237,146,241,64,4,192,253,178,2,68,0,111,255,46,243,192,219,191,218,6,251,130,12,76,2,254,6,157,5,40,15,245,248,126,251,234,58,172,246,46,249,139,252,219,8,21,7,152,6,241,251,47,38,94,1,146,12,54,41,24,4,109,241,92,241,189,13,114,252,105,253,99,254,235,251,44,251,8,255,124,255,84,251,12,0,199,61,141,2,149,5,141,254,254,15,22,244,55,2,108,234,136,212,91,239,137,7,73,249,44,32,174,2,29,5,223,251,53,253,230,245,47,5,218,255,220,231,171,13,224,247,20,35,158,248,62,0,20,252,236,12,177,22,110,233,231,240,158,253,180,0,249,253,57,12,40,35,71,6,36,33,40,240,133,18,117,238,157,254,212,250,179,4,184,248,213,252,133,193,135,255,45,5,207,252,134,247,135,233,219,2,173,248,18,247,23,220,205,254,247,0,165,9,54,249,254,207,31,0,4,4,158,2,190,255,192,248,58,2,42,242,183,242,144,0,192,254,244,253,184,0,96,252,186,249,226,42,214,243,99,221,187,5,132,4,104,3,84,32,23,22,73,253,228,10,149,14,107,8,4,248,236,215,147,6,67,7,249,254,46,70,237,255,85,6,50,0,251,254,209,239,221,4,234,255,228,249,41,3,158,9,187,224,223,4,65,250,5,253,106,249,70,253,52,11,28,3,196,15,168,241,201,43,78,4,103,219,16,252,249,4,118,252,150,238,106,6,74,243,235,13,162,255,133,231,164,253,239,33,84,9,166,8,223,6,148,225,200,16,213,226,219,13,176,12,77,3,152,225,109,247,214,255,207,20,22,252,181,240,27,238,65,251,105,252,140,242,22,20,174,248,52,244,189,245,105,4,152,238,48,7,48,211,110,252,34,231,167,13,41,245,228,1,29,233,212,3,81,248,70,5,161,3,200,26,144,240,219,242,234,5,255,28,93,253,44,247,139,23,0,244,12,231,124,241,162,246,188,21,167,5,170,255,156,4,41,251,164,250,77,254,222,250,70,248,174,3,30,248,3,4,192,2,193,79,162,255,41,251,252,0,85,255,180,251,148,6,121,5,111,2,158,254,142,245,78,236,34,253,25,230,163,29,37,19,196,249,150,26,134,16,165,252,157,252,242,4,227,240,124,240,12,6,231,236,251,10,215,8,164,9,98,1,203,231,2,251,155,7,43,22,116,41,62,249,8,8,186,255,218,11,185,253,111,3,121,241,81,222,39,251,54,3,200,22,163,0,205,251,240,252,142,1,146,4,51,253,138,254,88,3,158,171,89,0,255,253,4,1,86,3,128,4,250,2,167,253,11,2,149,255,9,4,85,7,80,250,226,0,234,174,109,1,17,221,25,5,193,0,180,3,39,1,136,10,163,243,66,248,121,246,43,4,22,208,6,252,72,13,78,255,203,7,225,45,41,7,57,38,147,4,70,2,204,248,157,0,38,251,16,240,96,3,21,249,95,239,209,2,86,240,54,31,142,0,218,2,184,7,33,230,29,18,30,227,137,251,189,252,13,13,196,6,158,227,64,254,3,21,34,1,63,7,65,27,237,25,95,230,166,250,25,249,47,245,91,251,32,15,225,236,185,237,66,15,128,249,234,5,228,30,232,224,205,239,45,251,86,249,242,12,144,0,132,6,223,218,220,8,51,16,211,9,85,250,75,25,139,6,106,0,213,3,201,0,53,1,60,0,123,255,40,254,49,2,132,254,106,4,91,0,174,203,46,56,24,254,192,251,207,252,100,0,49,1,219,8,223,9,208,249,227,3,107,233,255,241,222,248,35,3,244,239,191,243,79,47,45,255,70,3,15,19,84,248,64,249,6,54,36,8,241,210,152,2,61,246,163,242,65,253,176,17,200,3,240,3,22,209,216,3,98,10,166,1,132,5,20,42,168,8,61,239,49,5,236,246,88,9,19,248,34,48,29,4,169,0,91,49,122,252,194,255,98,253,65,244,6,243,124,244,25,7,64,214,16,251,157,7,174,10,48,4,107,250,37,8,72,40,107,249,175,238,249,250,108,218,148,251,20,0,102,2,166,9,5,11,46,23,198,13,28,44,50,0,86,205,84,209,90,4,188,7,79,252,55,253,19,235,182,14,65,254,201,3,199,8,78,46,100,8,151,207,238,5,98,2,175,17,140,4,67,5,114,250,137,2,141,2,87,3,232,255,200,117,20,0,204,253,247,244,245,255,128,250,176,255,239,0,49,1,165,243,170,252,56,2,238,255,140,239,109,254,32,1,63,244,229,0,128,251,6,64,147,252,54,254,60,1,128,255,123,208,64,4,196,252,122,213,243,254,235,2,254,251,180,6,88,213,12,220,205,243,190,3,16,232,252,254,173,252,12,250,174,246,184,230,228,0,107,10,86,12,116,255,183,6,26,9,86,245,8,12,44,0,127,61,137,247,139,210,161,253,220,1,152,1,39,207,186,248,156,248,72,254,55,241,212,246,205,4,174,254,74,254,227,252,237,116,53,253,110,1,59,255,64,2,68,255,228,1,240,0,20,237,144,4,226,251,95,3,107,3,217,254,37,193,76,248,136,15,249,14,240,11,254,252,243,3,230,243,165,0,133,15,105,219,238,255,213,254,10,212,237,3,196,33,60,198,36,247,84,10,38,223,66,2,121,8,2,253,204,10,74,9,210,12,106,245,188,29,226,253,226,208,123,246,98,254,6,254,164,215,172,10,71,3,223,245,155,3,135,4,223,251,91,227,170,255,16,11,64,44,176,249,210,254,47,17,221,253,219,23,255,38,11,229,171,255,224,253,204,236,110,1,14,19,42,222,145,28,16,244,253,251,77,9,202,34,154,227,253,1,156,251,48,246,156,249,198,22,20,233,65,9,92,243,13,49,103,245,249,49,115,244,152,6,172,252,115,18,134,255,224,246,166,237,230,250,25,227,214,247,95,248,31,250,7,13,102,213,218,245,42,5,252,9,42,28,239,249,238,4,86,7,33,214,210,6,80,245,168,5,30,34,126,218,60,3,216,6,160,249,101,31,168,10,50,2,169,248,180,214,224,253,50,247,51,248,16,231,169,255,10,233,39,254,242,1,112,244,190,233,20,211,23,7,2,8,220,28,110,20,222,10,226,21,2,2,206,254,222,50,11,2,232,213,178,252,204,2,14,1,22,13,123,232,140,5,225,231,70,248,127,15,92,45,248,12,252,239,92,246,243,17,38,235,65,0,150,13,19,0,173,13,232,193,201,250,187,248,104,248,95,15,46,14,19,18,252,232,54,254,127,1,45,255,174,253,91,255,33,97,112,253,252,8,108,254,1,1,214,0,125,253,250,8,76,255,35,0,110,19,66,3,26,252,54,249,73,21,250,219,150,213,92,16,187,35,249,233,101,249,222,3,103,248,93,13,57,242,45,35,10,248,191,246,234,19,199,3,224,61,196,0,124,243,201,251,248,252,30,46,184,250,251,247,219,7,53,1,130,2,5,6,70,250,143,238,23,26,124,22,50,29,198,255,184,248,20,23,216,249,90,137,120,252,197,253,144,251,169,1,234,255,154,2,126,4,34,253,82,0,230,4,30,255,75,254,134,252,184,5,216,242,219,3,147,209,103,4,200,227,80,7,250,223,71,34,121,245,177,5,254,58,125,252,152,250,73,248,99,7,56,12,185,5,143,249,173,250,203,5,47,1,234,253,249,255,82,249,159,250,1,3,154,49,229,220,222,252,28,18,60,2,212,7,71,242,186,1,121,217,143,12,58,238,90,8,6,239,50,22,45,43,52,28,114,38,29,3,137,250,137,245,31,233,161,247,169,12,26,9,248,0,138,253,20,4,127,2,152,242,125,0,67,86,184,7,21,252,45,3,40,2,197,253,6,17,200,231,51,14,63,21,132,253,233,0,8,237,65,242,52,254,44,27,137,239,1,6,215,30,86,54,43,226,112,5,36,6,136,2,106,14,60,248,97,246,26,243,165,2,100,252,233,253,119,232,30,16,10,28,207,239,96,19,188,248,82,213,66,250,222,218,30,255,254,254,32,0,33,254,174,8,94,0,94,44,144,15,84,245,63,8,178,253,116,246,168,254,87,254,86,2,154,250,67,251,32,187,30,6,107,5,63,242,199,255,219,248,180,18,62,2,50,255,26,31,197,35,59,25,198,249,181,250,10,19,42,4,214,7,1,7,111,226,65,9,84,4,25,5,26,244,28,201,56,249,51,240,24,239,73,29,232,12,238,5,222,233,239,253,160,16,59,18,164,3,41,250,82,215,98,254,194,247,178,243,30,251,161,221,93,254,42,20,49,33,240,221,22,253,57,244,3,25,15,15,182,28,165,0,197,255,66,252,148,22,156,23,200,6,200,11,31,0,244,3,94,13,174,29,75,229,212,247,214,8,27,24,134,215,196,247,184,250,6,7,248,236,31,231,203,9,80,10,186,23,43,7,132,11,132,1,142,1,177,219,248,234,216,247,48,8,230,2,214,12,185,1,223,27,192,247,26,217,20,234,175,9,51,21,126,216,94,253,52,1,243,251,2,3,2,2,76,7,4,255,131,209,40,252,158,2,202,9,20,21,233,251,153,35,143,213,8,19,184,6,178,8,179,3,224,246,89,10,173,0,72,250,198,244,111,17,10,251,101,13,98,24,252,234,164,225,58,238,253,222,253,7,217,244,216,20,38,197,94,254,234,236,120,253,152,14,177,3,68,252,39,237,140,255,130,0,97,7,170,37,206,14,237,238,12,28,236,249,162,25,97,247,26,225,250,1,166,171,150,2,174,254,81,252,2,252,53,25,45,1,48,254,55,254,72,3,241,12,194,42,218,254,220,31,138,0,111,250,93,9,232,252,68,25,7,18,1,254,66,62,238,1,18,1,168,232,108,253,54,15,164,247,144,5,211,7,5,16,7,11,232,79,96,248,211,249,101,3,116,2,76,0,124,5,220,15,252,1,151,243,78,252,80,244,118,9,115,4,117,248,16,255,243,3,109,1,174,251,237,81,98,250,116,1,137,0,222,251,147,4,28,251,234,10,154,5,22,7,226,1,108,15,112,245,198,79,15,255,185,1,159,251,243,1,12,4,106,252,236,37,162,243,24,254,117,215,127,243,122,235,177,248,33,22,178,206,89,226,127,0,189,5,37,247,21,7,155,239,17,8,166,253,117,254,116,253,77,1,86,181,188,251,214,16,54,6,152,6,83,250,177,0,50,17,144,4,84,23,241,250,70,243,6,6,32,237,49,13,87,234,218,241,176,236,16,8,226,244,182,31,179,252,134,229,200,241,97,22,117,252,1,213,251,255,74,10,146,212,60,8,144,0,243,51,251,0,80,1,51,2,181,255,188,11,169,0,204,240,197,5,42,4,221,249,167,251,192,251,5,2,209,1,175,170,251,249,186,251,49,7,3,220,186,187,126,6,8,0,168,4,150,4,246,3,229,233,73,253,60,1,215,235,11,7,224,251,191,246,153,244,125,11,16,218,183,7,170,1,206,43,240,8,42,24,76,227,10,244,13,13,180,12,250,239,166,254,148,252,80,228,254,242,155,17,54,1,160,249,43,1,180,245,76,245,16,253,175,39,223,227,160,218,62,12,94,240,215,255,175,9,232,248,237,200,247,13,137,4,27,25,94,246,134,1,165,248,135,231,14,251,249,254,194,5,176,253,14,173,94,0,91,16,1,0,155,12,55,243,158,7,150,1,31,2,125,6,168,245,220,219,0,248,157,232,46,253,68,19,198,238,216,48,220,249,196,8,234,21,51,1,18,218,198,241,220,230,16,17,140,11,35,247,204,231,229,15,2,253,145,241,88,13,102,233,60,218,157,45,184,4,59,252,236,5,108,4,250,3,232,231,178,7,139,215,99,5,43,253,171,221,146,14,191,255,106,237,230,248,230,251,169,37,167,17,70,11,107,10,204,24,132,9,74,254,186,7,98,219,250,250,53,15,231,247,65,212,223,247,17,13,140,242,248,218,106,9,194,7,179,248,180,12,61,23,185,247,111,254,42,255,88,13,213,251,78,72,86,244,182,13,252,1,155,254,187,252,75,251,68,11,67,45,45,45,213,253,152,245,151,252,58,14,236,247,198,6,200,238,74,1,75,255,178,250,127,5,245,217,41,3,37,216,238,247,112,13,241,247,166,12,150,14,135,6,238,2,234,26,228,15,214,4,237,1,206,250,76,0,214,34,103,42,85,0,204,47,242,13,206,251,192,11,48,219,142,243,247,4,132,254,99,255,146,236,79,41,158,250,37,255,74,5,203,249,184,42,220,8,53,241,240,251,143,29,156,3,250,40,218,252,218,250,216,249,47,255,93,0,95,241,20,241,183,1,156,217,135,231,160,252,110,122,35,0,52,5,187,1,178,253,78,3,104,0,100,3,161,252,246,5,192,251,230,44,113,228,236,13,109,0,0,244,70,247,78,238,74,7,159,242,212,38,86,12,227,248,88,253,156,251,68,11,167,4,195,255,30,218,172,29,210,253,197,220,99,251,208,0,194,250,188,255,200,254,38,1,68,250,130,5,39,0,167,173,212,2,167,247,167,3,248,255,199,215,181,13,146,230,98,230,6,229,143,248,123,7,32,23,233,220,88,13,132,28,164,250,114,250,30,7,63,215,30,246,133,6,42,2,64,244,233,242,102,252,87,32,192,235,144,21,177,18,171,2,6,254,50,238,146,7,250,32,161,206,202,255,165,244,204,252,20,39,244,6,229,1,121,5,54,241,18,3,207,232,72,10,252,249,204,3,242,242,246,8,140,31,18,252,211,45,223,248,220,11,61,4,136,4,48,218,103,43,158,30,56,246,192,247,72,9,230,9,40,14,43,2,26,14,248,253,193,252,241,255,14,254,167,0,199,2,99,167,25,252,70,250,149,249,118,254,28,21,105,239,253,246,212,15,124,251,40,251,22,254,194,249,243,238,66,223,253,40,208,1,48,191,139,14,227,225,203,252,134,239,102,252,142,1,3,22,136,8,226,19,24,228,116,9,24,3,188,254,2,251,100,12,45,51,72,6,100,240,85,247,179,11,244,228,48,3,78,246,106,254,130,13,247,1,38,224,132,13,238,9,137,241,76,33,195,255,82,254,172,90,179,4,31,9,180,21,36,254,155,3,203,253,81,2,181,249,22,7,178,249,101,228,91,248,182,39,46,239,91,254,70,240,62,7,103,217,155,2,40,30,166,244,91,27,225,248,200,24,90,222,107,244,96,245,194,255,222,252,153,7,222,17,4,238,107,223,6,2,41,242,95,0,90,239,156,235,123,255,30,40,207,7,162,12,196,34,254,236,132,241,143,238,190,17,241,9,234,6,83,27,231,13,109,4,128,251,88,57,234,3,122,2,143,205,150,6,147,249,252,248,206,255,112,0,172,251,46,4,174,2,44,4,19,6,128,3,170,13,218,40,224,255,241,46,31,253,138,2,80,254,148,1,170,0,121,42,72,7,74,249,53,43,236,249,74,241,225,0,87,27,194,6,249,228,153,248,153,244,58,32,66,39,233,237,48,250,63,237,32,250,80,245,146,255,210,241,64,245,102,212,104,4,236,245,172,45,90,253,58,5,127,8,114,232,104,2,115,6,134,228,15,244,116,9,206,7,31,17,71,249,246,213,84,254,86,11,118,252,54,239,93,8,38,251,88,21,161,253,13,21,14,221,206,240,132,42,8,6,116,2,79,248,78,54,222,249,200,251,79,253,188,237,198,241,241,2,169,211,146,255,24,253,190,16,139,4,33,12,24,38,135,43,200,16,94,249,244,3,236,8,35,252,66,252,247,218,226,2,24,0,170,1,102,6,58,15,181,34,122,11,134,221,166,11,113,249,18,33,117,253,24,20,176,10,239,2,172,255,30,30,5,12,69,11,146,0,178,251,247,245,9,248,51,43,34,217,232,251,249,251,223,255,2,236,184,251,62,248,2,9,96,9,104,36,44,24,244,1,42,8,61,0,163,211,118,0,225,5,8,4,128,248,92,255,240,217,194,237,235,212,154,255,64,252,1,252,246,245,6,16,107,240,42,211,4,3,21,250,178,251,110,247,186,6,85,251,48,224,234,2,194,218,178,12,150,153,70,6,122,254,72,253,10,1,77,252,49,2,10,250,248,255,56,4,69,255,39,22,201,8,226,255,223,239,0,253,100,213,242,14,74,215,112,255,21,251,164,250,31,242,7,5,225,235,42,25,19,236,106,5,23,3,199,249,142,50,4,253,168,1,188,231,5,38,190,2,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+348177);
/* memory initializer */ allocate([218,12,2,46,237,48,251,6,0,28,254,206,252,187,3,25,25,10,14,36,20,226,254,234,5,114,17,36,249,57,44,89,253,55,250,35,254,177,224,13,244,124,17,167,2,137,251,61,11,21,10,158,12,239,0,242,46,195,249,119,52,76,46,4,1,234,12,54,253,19,5,233,238,246,252,170,0,203,253,74,242,24,230,26,13,13,23,210,251,232,232,154,242,150,236,152,237,88,10,103,220,25,6,234,3,229,233,151,243,126,2,241,8,230,251,22,48,132,215,14,11,63,252,62,255,214,230,158,8,126,13,217,247,231,16,56,4,17,40,171,31,40,19,187,243,221,246,144,29,149,254,181,14,24,31,155,27,216,5,254,240,13,7,111,9,145,3,151,249,221,234,97,226,245,17,212,250,66,11,46,44,246,245,195,244,216,13,34,18,55,247,198,27,205,254,171,242,201,244,242,220,42,231,185,233,206,15,83,0,95,7,108,242,6,239,77,244,166,254,210,255,127,86,192,253,37,10,184,2,240,5,140,0,121,11,228,242,36,252,250,15,34,251,237,242,107,5,216,8,2,5,128,27,218,252,246,205,175,251,255,127,86,239,108,0,50,248,88,253,1,251,45,254,146,255,206,1,0,3,142,6,128,5,160,248,165,251,214,36,220,22,6,242,247,20,184,251,42,239,140,218,254,16,160,23,212,9,142,12,116,17,236,254,71,59,176,252,197,244,198,254,142,232,33,210,192,1,22,36,46,244,162,240,24,11,234,247,58,7,188,1,255,1,226,253,42,227,114,23,145,199,38,250,176,0,44,3,184,245,13,247,16,243,113,15,114,1,150,247,142,6,94,251,18,231,8,6,206,13,73,241,221,226,97,28,56,243,173,41,115,249,122,228,113,249,124,255,60,8,100,248,134,244,239,234,178,231,227,211,18,8,213,3,37,253,77,7,93,247,230,13,247,171,90,253,19,254,217,247,245,0,123,2,37,248,12,243,133,52,41,8,54,216,90,4,39,251,73,8,255,246,244,12,254,250,173,10,62,1,206,13,236,18,97,250,228,34,31,226,212,253,161,226,142,242,204,19,38,242,138,33,23,223,234,27,85,253,153,2,236,11,235,245,248,0,128,223,222,8,133,27,224,252,2,23,139,8,5,255,8,246,229,240,81,14,149,249,19,210,90,234,14,7,85,14,4,254,148,242,88,2,172,40,206,234,144,6,63,238,16,45,189,248,186,234,14,238,52,239,107,251,26,1,52,8,4,246,14,37,99,227,172,227,173,243,249,252,150,202,176,16,250,11,136,36,111,6,112,4,26,3,248,253,114,253,3,6,60,247,83,12,249,208,219,2,51,13,144,248,210,26,197,37,176,246,51,8,134,246,97,6,226,242,226,233,116,8,183,41,46,235,154,27,194,22,69,255,24,237,106,251,146,241,208,3,12,246,244,8,67,242,17,252,55,240,172,2,118,197,75,237,217,239,232,238,74,214,54,250,30,215,247,13,88,248,113,12,174,4,60,255,132,252,208,234,194,18,40,53,164,225,112,15,52,17,204,255,73,4,110,12,117,245,132,3,22,251,137,224,226,243,16,3,242,245,20,6,36,4,215,234,25,2,215,46,118,253,25,254,246,215,110,26,124,241,38,4,221,9,15,4,70,244,110,22,10,254,25,238,112,255,112,255,248,232,46,252,250,6,116,250,152,7,126,255,174,235,214,249,141,30,101,210,252,38,201,19,54,23,150,254,216,63,223,252,140,7,218,4,246,255,23,3,86,255,92,246,33,254,225,12,232,16,209,44,243,249,228,207,209,0,203,6,83,7,25,5,42,239,7,205,207,236,248,35,58,252,10,10,118,255,122,3,93,5,212,250,59,252,115,33,120,226,234,1,144,250,63,22,232,233,55,21,134,15,149,251,34,251,202,250,237,240,178,243,80,205,239,228,153,2,177,36,234,1,164,8,18,0,30,2,229,0,171,240,44,7,127,16,148,20,176,4,215,1,20,0,70,217,114,233,170,32,41,23,81,228,213,7,8,61,90,6,43,21,44,250,0,250,95,254,165,7,25,10,108,254,155,251,248,8,84,2,68,3,156,254,233,2,6,245,63,11,206,246,78,171,148,255,214,2,162,252,81,2,214,255,10,1,180,250,185,247,157,76,46,3,158,9,132,244,222,0,11,14,2,22,217,252,195,4,142,9,34,22,209,248,180,27,171,214,240,235,152,246,94,22,164,251,212,246,82,231,31,35,94,26,55,235,80,227,110,247,88,234,169,6,212,48,109,35,82,248,206,236,177,8,209,13,51,250,235,235,178,1,172,249,249,234,58,253,189,234,90,15,170,27,155,2,39,243,126,243,207,247,178,7,129,210,145,244,206,247,191,250,121,13,229,247,6,1,12,253,37,7,241,254,244,250,55,4,142,233,168,254,76,14,152,238,9,14,28,226,169,250,196,252,14,247,39,4,138,16,68,187,113,252,76,232,16,4,116,244,144,10,227,6,206,3,60,12,185,2,243,4,240,0,112,234,176,207,78,42,135,253,205,232,3,9,76,7,88,247,19,251,85,2,98,231,231,235,222,13,95,29,205,228,168,14,108,3,136,248,30,0,24,220,51,4,232,237,148,35,115,4,143,3,74,36,244,4,18,252,74,249,244,229,222,12,26,250,127,25,200,1,136,250,160,44,184,239,156,240,130,18,1,237,174,11,130,12,71,254,120,237,15,18,1,239,157,15,248,212,31,253,136,0,42,31,39,241,74,16,18,14,87,247,81,3,8,246,40,169,67,1,193,0,252,255,250,251,78,2,89,6,136,12,157,214,64,10,27,253,65,51,236,251,65,6,55,20,151,8,7,241,12,7,246,246,25,3,34,211,113,253,8,243,97,244,225,15,204,243,62,253,160,227,242,251,246,243,129,234,21,228,175,32,181,4,188,251,98,249,202,251,64,45,8,0,43,251,227,247,4,38,99,19,220,10,162,2,69,2,34,32,49,251,220,219,132,2,44,243,24,253,255,127,211,255,166,1,141,251,228,251,219,247,73,253,156,253,171,5,224,254,58,0,146,252,53,0,96,11,157,248,20,228,101,7,212,11,165,0,195,3,212,8,32,225,225,22,120,182,199,245,250,251,152,252,220,5,94,4,23,253,143,0,76,254,215,4,0,241,249,6,54,246,13,79,254,251,236,249,165,250,108,253,95,251,171,3,35,5,182,241,204,234,75,2,247,239,60,6,68,49,149,22,148,4,94,242,98,251,179,254,114,24,222,245,96,8,34,237,66,255,180,7,127,10,47,5,37,252,58,197,51,18,185,255,234,26,52,6,77,237,222,16,136,241,240,1,31,234,162,7,30,251,195,242,220,235,22,36,250,8,175,236,183,0,12,248,114,0,218,47,230,246,71,0,189,242,134,250,84,14,19,2,163,42,138,4,58,30,129,35,30,251,220,5,213,24,131,4,26,236,175,245,121,6,214,1,230,7,23,2,206,254,145,185,121,252,97,11,146,234,233,6,117,250,122,35,101,8,188,13,48,27,65,3,99,4,242,4,136,6,78,253,162,37,86,244,189,237,238,3,99,247,153,244,123,243,57,245,107,0,93,252,34,218,36,9,162,252,34,245,204,241,58,219,92,37,33,4,216,33,46,5,88,15,172,5,172,237,147,242,162,33,30,215,18,230,193,244,80,13,93,3,15,244,201,252,164,0,81,12,142,241,179,194,138,252,176,5,206,12,240,231,199,255,86,4,22,0,87,244,131,28,198,251,15,225,76,208,224,1,35,226,45,255,50,6,34,15,170,12,141,252,74,26,195,249,6,254,160,14,128,29,73,226,191,255,94,250,10,1,28,39,58,6,188,245,76,27,231,251,252,253,77,253,160,2,49,19,252,6,125,58,86,1,194,3,44,28,100,4,244,1,111,4,201,254,46,15,4,49,56,21,75,24,13,13,134,255,4,22,215,26,177,213,170,15,156,216,176,5,96,20,11,252,78,4,68,16,46,250,190,235,14,255,110,238,250,12,0,14,128,247,72,22,3,2,220,210,166,5,207,16,168,240,125,239,156,227,181,23,190,211,54,3,250,247,37,244,44,246,232,248,44,241,216,32,145,34,42,244,247,223,125,4,220,28,12,4,26,10,242,21,30,247,83,236,39,250,128,1,174,5,218,31,136,6,151,246,19,13,202,51,45,252,1,2,146,30,102,10,26,7,161,21,176,251,85,10,120,214,193,221,221,233,251,251,38,3,176,220,180,237,24,3,112,236,81,233,172,240,196,3,57,1,39,246,82,4,160,233,222,52,114,224,120,16,148,250,228,245,218,3,56,199,126,250,133,13,80,5,188,250,152,255,213,5,214,244,212,244,253,7,154,71,206,18,212,241,63,253,100,243,108,253,152,245,56,10,196,17,169,14,38,6,217,250,170,251,44,2,232,12,13,245,252,50,240,17,106,11,99,53,238,246,16,244,99,245,174,0,130,239,56,239,241,225,86,5,250,6,17,4,146,255,51,248,6,16,193,248,124,252,203,0,31,5,84,13,11,16,81,88,240,239,171,1,72,246,1,1,13,251,3,251,226,230,231,227,171,41,143,17,35,239,190,26,157,51,167,28,52,252,191,243,79,1,159,253,59,12,102,9,78,241,103,8,188,235,5,226,20,8,21,248,138,14,251,252,52,243,3,6,50,225,237,3,125,53,249,17,62,223,4,254,30,22,231,236,93,0,149,214,211,15,254,255,70,4,223,236,30,247,183,246,180,8,125,234,48,254,129,242,29,255,217,36,157,31,59,247,117,14,233,251,85,229,245,7,134,7,230,241,196,195,187,253,17,232,229,247,197,9,88,247,9,21,7,247,156,245,27,6,172,12,138,5,36,248,148,11,203,47,109,222,168,10,43,242,145,230,30,43,62,44,73,255,178,251,14,4,200,4,20,0,161,5,163,254,216,4,199,225,94,252,131,5,33,27,34,16,24,203,191,245,222,13,77,12,38,253,234,29,26,12,161,2,45,247,252,9,7,6,198,5,73,252,64,224,87,19,143,46,236,17,0,223,16,3,22,211,140,248,18,10,120,11,184,226,54,233,195,7,79,13,219,239,196,236,188,250,236,250,148,3,131,3,33,79,235,7,170,5,36,17,92,241,6,15,139,8,122,251,112,18,227,241,192,20,215,15,192,1,17,231,166,221,72,247,128,7,66,3,207,105,14,253,90,0,130,5,39,252,155,250,195,255,138,2,56,4,123,27,44,245,47,251,98,52,142,17,40,254,176,244,37,236,87,247,110,233,181,1,59,229,132,19,114,13,204,23,159,230,225,240,184,15,126,252,183,255,5,244,23,245,8,22,188,23,106,246,14,14,235,254,136,6,54,229,115,9,25,38,148,24,131,34,75,217,140,237,150,253,98,28,96,254,173,7,152,236,117,9,131,4,231,14,140,255,115,241,192,30,219,236,79,9,76,6,118,247,2,247,231,10,78,247,120,4,189,203,54,230,218,252,187,27,206,247,98,16,176,247,215,33,77,239,196,1,121,255,91,232,0,5,15,50,206,12,4,33,127,17,144,249,173,5,127,5,58,252,8,252,101,12,91,227,56,238,136,204,48,249,65,2,220,249,99,2,178,4,110,255,115,233,196,11,56,244,211,249,90,12,234,14,78,248,51,24,154,7,72,218,45,11,61,225,61,12,96,225,199,42,108,249,206,254,29,255,48,38,174,255,200,6,156,4,129,13,198,244,245,20,252,226,180,29,63,10,74,244,34,247,170,40,228,4,91,245,175,238,222,6,151,235,122,25,42,26,200,2,86,18,168,246,240,0,167,1,42,244,92,206,192,243,200,235,224,1,168,249,156,205,113,29,19,17,162,4,220,248,11,253,198,248,50,252,85,241,135,5,98,231,82,10,17,241,222,249,102,224,59,32,153,7,3,220,123,4,32,16,51,239,38,3,47,249,192,2,64,246,95,5,222,252,9,0,216,252,4,255,179,234,17,15,113,40,232,253,83,7,176,244,216,213,30,13,39,4,134,252,32,28,76,14,150,1,24,11,195,228,139,238,30,18,101,224,212,10,157,224,192,6,61,235,66,28,98,245,123,14,54,251,174,209,163,246,4,3,213,12,7,240,136,250,89,4,216,190,93,7,77,254,65,252,242,0,207,252,3,1,38,248,191,248,211,253,110,252,95,199,66,248,119,2,40,252,189,247,76,243,195,10,225,7,194,247,96,221,232,252,245,250,55,245,195,246,186,2,23,4,204,3,145,198,94,41,151,240,151,2,204,3,180,4,15,245,15,5,240,250,50,0,168,5,120,3,169,248,122,0,78,0,73,255,180,253,74,63,124,254,64,247,112,4,242,4,211,230,59,10,128,249,71,231,116,245,21,6,15,254,86,2,146,255,18,5,178,254,191,0,201,116,131,1,163,1,76,0,152,0,21,2,78,0,112,0,101,0,158,0,136,0,20,255,88,0,43,0,107,0,84,0,21,0,15,231,81,249,221,6,131,5,192,35,184,255,148,5,182,251,88,40,6,254,152,254,29,1,220,255,0,245,51,3,88,0,176,0,31,254,84,255,19,8,196,12,103,21,157,33,8,44,168,248,105,1,46,6,147,236,157,250,251,14,74,0,253,255,237,1,81,254,110,5,101,0,218,253,59,0,220,1,43,254,185,253,56,2,220,2,9,252,176,251,70,253,114,93,106,4,12,251,24,1,204,0,197,255,195,217,195,254,167,3,128,11,94,215,252,245,216,237,226,5,250,14,22,252,245,10,98,255,103,254,46,3,106,255,159,255,11,242,242,249,76,5,230,20,147,254,194,245,130,242,54,1,170,4,143,3,80,213,169,3,44,31,90,235,214,253,207,7,17,251,206,253,10,0,191,254,232,2,44,0,64,0,238,254,72,138,84,1,229,251,244,2,226,255,250,255,243,254,239,254,12,0,95,0,29,6,118,204,222,209,27,254,218,249,158,1,16,255,60,254,52,2,228,2,36,254,191,3,55,4,224,249,90,254,37,0,102,255,133,39,188,255,132,5,86,46,164,242,73,16,58,20,15,2,253,251,250,251,63,248,192,1,52,253,160,6,150,7,2,255,52,1,76,4,234,252,166,31,230,25,69,14,6,252,181,253,178,228,237,255,135,6,145,5,153,31,124,14,98,251,6,3,147,2,113,0,181,1,50,0,67,3,236,253,55,212,146,6,190,226,224,245,210,4,175,237,123,227,113,255,33,13,97,4,177,0,39,254,1,2,136,0,197,3,76,240,31,18,68,251,247,4,89,11,47,229,3,41,40,241,230,242,91,236,234,241,74,252,138,17,14,2,238,3,2,0,224,6,187,22,201,255,182,251,205,248,92,1,242,247,20,220,128,14,54,211,110,243,166,252,160,10,77,2,64,1,93,3,59,0,237,20,52,2,132,254,26,2,114,255,234,1,212,0,180,6,158,2,112,7,75,255,163,11,175,3,20,66,247,4,220,3,222,252,46,250,194,35,131,2,189,6,67,5,245,244,0,240,229,1,77,228,148,243,117,237,188,249,40,6,164,233,216,23,117,255,190,6,195,45,104,1,95,29,209,9,72,20,96,247,55,248,61,3,125,254,164,233,66,17,116,0,117,244,30,255,249,0,121,1,101,8,143,244,157,19,8,244,32,3,77,250,120,44,108,33,204,6,112,1,233,244,255,247,158,5,179,250,244,15,104,7,240,253,85,6,32,249,173,53,46,1,6,252,210,217,63,242,22,5,94,5,115,4,150,3,68,249,4,253,90,3,36,3,20,249,116,1,190,254,242,253,148,46,88,209,172,15,213,6,201,6,247,249,68,0,121,3,24,1,178,2,104,247,44,4,28,254,85,255,199,1,212,255,150,243,195,8,178,253,237,2,232,252,92,178,198,0,236,0,135,10,171,242,140,2,28,1,204,252,146,251,57,255,144,255,238,233,94,254,23,4,66,4,212,8,31,243,140,247,212,52,184,6,186,254,142,3,86,249,72,15,105,251,151,6,152,247,50,0,35,0,182,6,209,2,100,36,48,247,22,239,49,27,80,17,149,224,45,0,90,5,144,13,76,11,104,243,88,5,75,5,206,253,74,253,234,2,198,0,164,4,3,11,59,12,189,246,38,25,79,3,63,8,53,216,133,242,158,217,82,242,143,2,137,2,180,5,14,1,118,0,45,0,192,0,188,0,141,251,254,254,151,2,172,255,129,148,3,253,119,252,101,1,252,255,89,0,140,254,232,255,178,0,103,4,209,0,153,4,54,245,181,253,208,5,29,35,145,12,10,246,215,0,68,37,228,227,235,4,124,241,207,10,251,254,40,255,104,3,64,244,228,247,234,33,197,2,45,14,87,0,214,243,128,214,246,0,122,249,54,249,205,4,200,29,160,251,16,3,49,1,233,0,71,255,24,1,70,250,244,254,198,0,243,1,52,1,117,247,131,251,124,254,218,255,174,254,196,251,32,180,40,0,166,7,64,247,170,255,8,1,108,217,249,250,246,15,158,14,198,9,162,216,222,17,43,250,54,4,146,12,106,9,148,254,25,4,78,10,35,0,241,250,200,0,225,244,66,42,224,208,71,9,92,1,159,254,228,10,203,252,132,243,1,254,146,0,223,7,235,0,186,251,62,10,128,10,177,255,56,20,140,252,218,209,26,3,136,10,208,229,124,13,15,5,32,15,108,11,146,17,90,255,170,253,67,251,123,3,102,21,246,254,247,252,251,255,248,252,235,3,211,248,100,255,246,69,197,1,215,254,247,249,89,3,224,254,204,254,27,231,253,7,202,248,191,11,68,247,144,248,47,3,183,244,104,16,128,32,144,38,154,253,190,252,16,15,158,1,22,255,23,6,229,226,57,14,50,251,69,3,129,255,92,10,155,1,236,253,252,206,100,249,10,4,142,246,56,252,46,2,228,249,96,248,51,1,216,251,136,229,52,6,180,245,181,3,80,32,244,255,116,242,153,13,188,25,20,10,225,28,16,1,248,5,26,7,98,247,163,254,116,254,72,210,207,5,25,38,199,237,232,255,36,8,244,252,172,19,121,253,84,14,49,2,75,4,186,251,22,2,246,4,157,255,238,3,36,254,240,253,193,48,53,6,57,6,110,249,110,27,104,10,254,33,205,253,58,4,50,255,87,0,70,248,112,255,228,0,208,4,121,3,4,56,65,0,219,251,14,41,161,255,137,2,53,0,62,252,129,254,175,9,42,5,250,248,24,11,20,254,93,254,90,0,88,253,79,0,2,4,80,174,57,6,26,253,62,4,4,2,187,2,89,9,192,255,38,248,46,0,165,252,111,0,72,254,201,55,16,1,29,3,99,216,106,241,54,12,22,244,20,5,73,0,38,249,2,251,98,7,106,245,192,2,136,4,1,0,13,1,232,255,146,253,124,0,138,0,246,253,2,254,95,0,110,254,86,149,42,254,42,255,97,255,140,1,55,255,140,254,122,0,136,0,19,252,232,2,157,7,214,252,168,245,42,253,128,254,187,3,208,4,74,5,167,254,227,179,32,4,63,255,233,4,249,254,142,1,16,253,90,2,98,0,25,3,17,0,218,78,67,255,201,245,82,255,166,0,180,1,155,1,234,251,118,1,41,254,3,255,233,0,160,32,62,5,1,251,89,36,142,8,89,243,114,235,130,242,52,7,172,2,47,1,174,238,103,232,89,242,78,246,133,1,97,1,159,0,242,255,5,142,1,254,98,255,92,0,111,254,220,255,215,254,191,1,163,253,13,1,85,0,212,0,8,0,138,255,126,255,207,0,94,51,248,221,200,9,75,5,60,243,116,5,116,237,104,247,232,249,228,0,94,255,155,4,208,11,230,2,164,252,69,0,10,0,54,117,230,253,23,254,131,255,42,255,108,1,86,253,229,254,20,2,122,255,227,0,64,254,236,255,246,254,70,0,2,0,94,36,10,58,88,3,19,254,227,242,36,0,8,255,214,0,25,1,183,255,196,12,233,2,11,255,17,252,146,0,136,1,36,0,106,31,137,11,53,230,239,225,73,17,62,246,59,2,110,247,60,13,230,252,207,253,53,245,120,7,42,244,225,0,214,0,229,255,66,3,91,214,181,1,6,254,233,253,205,32,52,5,154,246,92,221,100,244,105,5,40,1,97,3,14,9,122,3,244,0,135,255,226,0,119,1,128,3,115,215,38,247,180,242,215,3,231,4,3,1,163,44,199,1,31,244,51,1,114,246,220,1,211,2,18,0,16,216,254,1,40,2,114,253,148,252,47,254,116,2,228,206,18,3,119,254,190,239,170,3,209,250,97,249,160,253,184,250,125,255,144,252,62,3,248,3,115,85,104,254,232,249,12,254,110,249,197,1,94,252,36,5,120,255,178,1,85,253,156,1,202,0,233,0,126,1,46,248,205,219,246,251,6,34,178,1,71,224,219,11,207,243,0,7,152,10,255,249,198,251,86,3,57,5,196,251,91,0,123,238,241,9,196,238,118,248,54,208,62,237,33,18,181,1,96,252,115,8,174,243,9,2,103,253,80,251,94,10,163,3,124,254,138,255,136,251,133,0,225,19,86,251,8,250,57,252,229,252,188,0,126,7,129,3,122,228,63,226,206,27,123,22,92,245,42,225,40,254,152,254,177,253,222,3,40,244,62,30,214,2,114,21,167,36,223,1,40,244,144,248,246,27,98,18,138,9,216,249,198,255,100,255,119,240,120,245,99,16,90,255,14,13,226,249,183,14,193,239,138,233,129,21,17,226,164,17,23,240,204,245,16,20,222,254,102,253,2,5,8,3,202,253,166,253,202,254,235,3,120,253,112,11,169,243,171,1,112,251,114,245,162,189,51,255,169,254,84,251,68,248,117,6,0,254,228,248,94,254,216,242,194,13,82,248,100,19,160,233,191,235,46,255,71,249,147,39,108,228,23,13,78,1,160,255,135,243,79,249,154,253,183,245,147,0,240,249,197,246,116,241,61,249,74,227,77,21,84,245,205,244,170,48,160,1,0,0,62,17,65,3,78,2,81,6,149,1,73,0,100,3,232,0,195,0,15,0,60,255,242,252,237,2,69,252,172,255,152,4,215,253,61,208,171,242,48,50,200,250,20,0,126,3,254,0,23,252,155,250,106,254,123,251,54,254,44,1,117,254,57,3,222,255,74,0,126,1,6,252,230,215,58,5,83,43,32,2,29,3,48,239,109,5,21,253,132,7,255,254,55,10,219,255,233,238,14,3,158,0,134,254,19,0,140,2,229,253,244,3,141,239,239,4,99,252,96,0,246,219,33,23,239,223,185,255,210,248,103,247,239,226,196,255,137,1,6,234,248,254,22,252,85,0,197,7,176,249,40,255,110,252,179,38,108,31,190,253,106,225,87,249,216,241,126,9,59,0,181,22,102,3,195,254,15,246,76,240,206,250,191,4,136,36,49,21,68,1,61,237,87,253,6,254,154,237,82,230,168,239,65,0,217,2,226,250,149,250,105,5,60,9,136,6,189,9,74,254,169,250,117,252,38,0,4,177,148,249,0,2,99,254,92,1,144,255,236,253,17,3,52,5,228,27,132,248,26,249,206,210,19,7,49,220,180,255,5,250,81,255,53,249,253,252,222,7,7,2,15,0,64,2,32,34,45,252,228,255,38,7,73,1,210,254,174,47,35,250,75,20,207,254,176,5,187,253,208,5,142,0,235,0,99,255,192,0,4,6,102,252,48,43,47,46,108,244,48,250,176,6,30,248,144,252,46,243,66,255,58,255,132,9,8,255,222,0,22,0,95,3,224,5,30,8,1,248,216,0,10,251,36,253,180,184,162,4,106,12,38,253,176,1,166,3,81,6,105,3,21,254,186,255,0,253,167,2,118,5,25,2,148,254,172,0,227,253,162,255,232,255,127,255,155,151,201,0,214,253,155,254,185,255,60,0,96,0,127,249,145,5,220,4,76,1,212,251,70,1,66,3,148,253,63,250,49,6,152,5,160,3,94,73,148,250,81,11,192,1,40,0,43,5,153,5,19,3,215,0,225,12,26,10,168,252,195,1,220,186,223,2,213,255,149,1,28,251,232,2,244,3,165,2,56,1,206,0,233,254,80,254,21,26,169,255,184,255,96,215,150,255,216,43,128,4,90,254,232,7,192,2,158,9,83,251,232,0,137,255,4,0,145,252,64,6,60,253,168,13,23,1,113,255,184,251,213,253,242,17,206,5,161,0,174,3,226,7,170,9,118,193,132,254,63,255,105,211,201,1,236,254,44,212,188,249,218,255,45,3,52,240,96,7,87,239,111,6,142,252,213,3,34,253,146,255,140,0,22,244,224,4,219,253,113,251,57,252,2,14,176,2,156,250,168,1,217,185,230,7,226,8,212,255,130,250,80,254,55,5,109,253,83,37,3,242,37,43,78,7,38,3,87,2,239,247,156,0,188,238,16,0,45,9,159,253,14,244,30,253,196,255,220,253,137,255,207,255,26,0,248,5,206,248,162,24,254,54,76,253,104,21,65,1,204,7,96,5,242,243,234,1,202,255,127,4,164,3,189,1,97,217,192,61,13,12,98,3,28,248,7,249,78,8,104,252,158,1,222,254,138,0,244,0,226,3,66,253,130,5,74,1,202,0,163,2,123,254,15,255,74,122,124,1,44,1,203,255,36,3,147,255,157,1,212,255,6,0,14,0,230,1,219,254,144,255,26,0,112,45,188,252,148,240,250,253,172,250,96,44,230,13,180,253,220,247,234,1,125,1,69,252,159,8,119,244,91,4,247,254,2,0,65,0,208,1,76,255,145,255,82,255,104,255,212,136,121,0,49,255,189,252,102,4,71,255,91,0,160,255,222,0,157,255,163,255,102,216,82,254,72,255,140,254,62,255,185,3,156,255,126,1,114,250,107,54,213,248,135,249,53,3,152,1,40,3,167,253,49,254,230,27,220,21,99,12,126,8,180,10,170,211,251,3,169,5,126,254,106,6,119,14,175,16,128,6,184,8,94,253,215,3,39,2,95,33,154,0,129,254,141,246,93,4,248,253,42,213,202,238,98,241,177,255,115,252,21,7,179,19,156,1,75,4,154,5,173,0,20,3,164,255,20,252,8,5,169,255,163,3,1,40,169,252,6,0,107,254,20,10,191,44,126,4,132,248,30,14,250,254,36,1,129,3,201,37,131,254,175,6,103,245,169,251,26,1,124,247,22,247,38,247,44,253,175,252,245,209,120,3,48,12,77,250,239,1,196,213,232,252,238,254,40,252,65,208,31,253,166,246,213,254,190,253,58,245,241,5,6,3,146,7,89,3,113,248,217,0,142,2,172,5,145,241,78,26,36,3,134,0,178,3,148,247,23,37,168,253,86,248,124,235,10,255,245,4,44,33,237,4,99,247,150,255,222,250,60,3,245,3,229,208,151,2,180,1,168,245,135,38,138,253,111,244,188,11,247,3,175,243,61,250,231,255,143,1,178,252,174,1,43,251,100,255,69,255,91,4,10,254,149,254,130,1,252,244,174,3,98,252,215,2,106,4,92,176,238,254,116,4,198,0,199,0,244,9,186,1,157,0,246,249,109,14,124,3,204,1,152,25,250,18,0,246,31,222,138,7,47,221,99,13,174,2,61,0,130,221,154,254,58,5,182,255,156,4,55,11,18,241,104,0,110,9,50,249,161,44,86,238,137,1,56,244,204,3,34,0,117,0,15,193,12,229,204,228,190,6,181,252,14,255,163,247,35,3,187,251,186,1,240,6,125,9,24,252,233,1,137,1,123,2,133,1,102,4,253,47,144,249,124,211,187,244,200,255,0,15,82,255,105,12,84,249,165,4,122,7,234,5,67,255,168,255,20,1,16,255,136,255,143,244,95,38,166,2,56,2,26,0,96,39,241,245,218,252,192,255,6,25,174,255,109,251,121,8,244,248,101,253,219,255,54,0,112,16,77,42,144,46,44,254,124,7,215,252,142,254,144,0,32,14,249,254,0,239,132,255,44,1,10,255,72,254,141,255,191,1,105,254,133,81,172,254,54,0,4,253,217,252,69,253,229,254,215,2,102,252,74,4,65,2,250,255,215,252,206,255,141,255,181,255,24,1,156,0,182,0,225,0,32,137,44,255,95,254,11,255,177,0,94,0,4,0,141,253,167,0,47,0,152,0,148,0,45,5,124,246,177,216,72,253,18,217,8,4,0,252,138,241,93,15,144,1,77,1,180,2,238,240,39,10,65,251,123,254,137,1,102,253,87,8,40,40,117,246,180,7,154,1,120,254,78,2,34,48,245,253,117,4,52,0,68,250,51,3,43,255,162,0,116,0,154,253,122,214,52,255,33,251,23,2,199,0,86,232,234,9,108,6,237,210,230,249,182,5,43,250,38,255,216,254,163,253,65,1,95,2,146,254,255,254,187,252,184,17,93,210,242,4,35,241,144,17,38,11,8,0,112,221,124,0,144,2,239,251,155,1,144,0,148,3,189,1,165,255,252,254,107,255,142,252,79,254,135,255,89,1,68,0,93,1,53,3,140,2,251,0,243,165,247,3,200,2,183,255,126,27,16,250,178,22,196,206,25,11,169,1,9,1,10,6,170,3,59,7,100,251,191,10,14,254,9,5,250,252,71,1,207,15,60,224,194,245,73,21,149,12,82,244,123,39,88,7,173,0,90,240,143,1,180,254,130,2,41,1,95,238,50,251,182,254,236,252,135,170,135,3,228,250,35,2,246,253,93,7,62,249,193,255,205,3,129,3,158,2,111,253,24,255,242,1,92,0,248,255,254,212,48,4,144,254,184,248,241,44,169,13,218,2,110,8,163,249,185,250,209,249,199,8,30,250,96,8,122,252,127,2,175,0,138,232,38,252,106,239,26,250,249,6,192,217,17,254,203,7,27,220,122,250,10,246,42,6,86,9,83,244,137,6,68,248,21,0,42,240,104,33,131,4,211,254,180,4,192,14,6,1,220,248,211,248,10,252,247,255,151,10,187,5,207,1,171,210,207,6,68,252,67,251,204,240,254,5,198,215,22,0,122,252,110,253,33,249,203,9,16,6,246,207,230,251,111,2,107,243,242,5,220,255,66,254,219,232,96,8,228,244,232,58,64,248,47,14,139,7,102,7,169,4,98,249,156,243,211,252,200,250,22,2,147,254,65,3,219,254,255,84,14,251,64,251,228,3,254,255,119,254,166,252,247,2,201,3,26,255,105,255,209,3,150,252,119,0,128,252,6,1,138,255,89,0,95,0,94,0,75,254,89,137,50,254,104,1,180,253,178,254,86,0,253,251,48,255,24,2,60,255,111,1,45,254,119,0,224,255,16,246,60,24,126,34,248,254,89,225,80,3,219,8,37,15,22,231,55,247,140,5,180,248,141,242,163,14,178,253,58,0,238,254,79,232,232,222,18,23,37,12,202,22,65,15,38,8,20,5,244,14,250,253,240,253,168,241,2,7,1,17,152,1,54,2,239,245,143,251,189,10,154,245,240,253,201,226,174,21,116,11,176,254,97,14,14,248,212,0,227,221,249,3,210,8,33,32,131,1,227,0,109,3,192,10,161,250,76,10,195,31,10,15,42,229,122,251,104,241,226,222,228,0,79,233,97,0,5,246,116,244,96,252,166,2,112,0,154,5,30,251,216,4,100,254,85,239,29,241,226,16,154,242,25,30,80,21,36,229,132,242,161,28,70,12,220,0,150,2,251,5,140,234,148,250,186,26,209,241,106,1,165,19,116,31,193,246,30,235,92,22,154,254,165,9,148,8,110,250,240,254,22,2,64,255,237,253,63,253,186,255,253,254,93,0,79,1,162,255,111,255,239,255,152,3,162,4,206,252,169,253,87,1,109,178,152,11,161,0,128,0,70,239,86,2,152,0,186,4,219,250,247,249,27,255,181,0,168,230,67,22,102,28,127,24,105,34,27,0,94,237,220,252,88,255,9,255,88,253,127,255,42,254,104,255,147,3,176,0,120,252,110,2,24,1,170,11,10,4,234,251,30,254,63,155,18,255,169,4,181,245,18,255,35,5,27,247,52,6,128,252,0,2,160,252,99,2,114,254,253,4,44,255,154,254,202,0,194,51,16,0,164,252,82,6,0,252,54,1,40,45,22,253,220,240,12,3,9,240,37,254,89,3,249,3,97,250,134,252,155,0,108,33,106,1,122,251,68,8,221,254,190,255,8,251,254,1,142,250,211,8,103,237,40,3,28,253,87,252,169,54,191,0,17,1,10,226,120,26,78,3,141,248,187,3,106,204,92,248,161,6,134,6,183,254,12,255,91,9,231,23,222,252,17,252,137,2,50,252,170,0,168,247,228,213,252,3,246,4,162,7,94,4,36,52,215,3,142,250,174,253,254,253,182,253,2,4,227,248,36,2,214,254,14,13,69,3,141,250,153,54,253,3,144,225,142,244,186,5,118,21,181,252,128,9,98,5,188,255,174,0,151,1,76,0,147,252,179,2,27,219,10,2,136,242,245,9,100,254,202,246,107,3,76,236,72,252,127,216,174,25,53,231,56,245,106,253,29,0,29,255,20,19,24,5,155,1,8,243,130,9,17,3,26,198,60,17,224,8,249,230,124,8,155,253,127,249,40,1,230,2,112,2,135,0,196,20,137,243,169,252,243,247,229,1,140,243,182,11,102,5,212,9,122,246,78,242,18,255,225,2,139,253,233,3,5,3,132,68,198,5,44,253,4,253,49,251,26,251,210,249,76,253,161,254,241,249,85,255,183,0,38,0,100,253,244,2,254,252,24,95,119,252,242,227,246,1,74,241,102,249,52,6,242,5,52,7,252,4,178,5,247,252,195,6,248,18,244,197,183,251,36,0,226,250,78,3,36,250,9,2,171,241,4,255,128,17,214,245,179,252,85,2,96,238,38,4,220,254,170,183,180,7,178,254,176,255,24,251,146,254,56,14,76,254,244,255,122,249,77,254,216,5,149,5,172,212,244,3,88,252,56,251,48,208,24,244,210,0,113,7,83,251,155,254,225,217,184,245,180,254,167,242,230,58,216,5,158,8,8,7,205,0,104,5,218,13,195,248,243,2,248,3,214,2,58,0,106,255,3,205,135,40,227,245,182,254,80,6,9,12,203,10,199,245,76,251,68,1,203,255,152,11,205,5,214,0,124,0,178,254,19,255,144,65,52,10,255,3,54,239,148,247,240,16,45,239,88,19,12,4,81,0,6,253,88,13,202,2,69,255,252,239,11,253,100,4,240,39,147,27,168,1,196,254,1,5,26,208,144,3,49,248,2,0,37,253,72,255,111,3,90,252,54,255,121,254,234,251,174,254,155,255,153,187,80,249,52,234,233,246,82,246,234,6,63,233,219,5,66,2,126,255,144,5,230,248,110,0,30,2,22,0,220,3,125,239,20,11,89,250,146,4,47,48,131,8,48,212,60,246,64,0,112,252,70,252,142,2,222,252,57,254,171,253,234,0,216,254,43,3,59,4,56,7,52,16,125,2,48,230,198,246,202,242,104,253,224,204,23,11,18,12,222,12,54,238,214,9,201,255,69,3,112,5,17,23,7,5,52,250,197,3,149,64,77,242,145,248,230,249,104,9,173,19,48,237,129,5,105,1,158,248,170,0,158,253,37,249,244,253,157,252,162,231,107,177,23,253,68,252,80,255,182,11,130,0,100,253,181,252,245,254,148,254,195,253,239,1,127,0,190,255,255,127,15,1,104,254,142,2,133,255,39,7,151,0,228,3,82,0,116,2,5,255,144,0,198,0,168,255,101,1,37,0,100,2,184,0,238,0,184,253,204,255,183,138,97,254,148,1,202,253,100,0,147,2,176,254,109,3,211,0,38,253,135,254,184,0,120,235,52,250,89,251,196,247,24,0,115,225,209,0,216,244,204,248,185,2,166,22,89,251,171,1,82,46,232,3,251,254,184,0,82,253,158,4,186,243,190,243,139,0,144,0,117,0,74,14,18,242,230,249,160,2,244,7,203,58,51,236,217,253,17,2,160,6,42,255,138,245,178,232,133,241,31,11,6,246,32,249,84,251,40,8,228,24,242,6,135,50,141,8,200,7,225,6,66,2,226,253,15,253,98,251,225,16,79,7,53,1,192,2,21,251,116,3,192,74,151,245,72,4,232,11,89,255,104,3,168,254,188,251,208,1,183,12,170,255,72,6,218,251,223,249,93,249,152,17,238,254,56,2,148,5,91,80,172,5,130,252,233,252,203,1,142,252,232,251,128,244,169,212,241,252,192,252,110,246,138,2,224,10,84,12,17,2,201,1,227,1,247,206,143,2,174,2,11,253,161,3,212,0,218,4,55,255,165,249,218,18,153,248,229,3,103,243,84,0,80,0,31,1,168,247,149,1,68,255,134,252,160,184,1,254,138,255,198,241,6,252,164,1,106,49,38,254,228,253,66,27,65,27,66,17,138,4,204,250,168,251,27,249,80,10,50,2,116,251,232,4,83,2,55,2,29,254,233,132,64,252,208,252,244,2,225,5,12,0,250,253,234,0,184,0,167,2,72,1,168,253,119,255,11,1,72,254,236,9,81,2,255,3,20,210,114,2,14,248,124,22,102,217,103,12,90,251,92,6,80,15,147,12,114,5,66,3,116,255,196,15,114,18,57,254,33,12,181,250,222,243,232,3,126,30,77,247,175,2,212,249,108,12,242,207,142,250,87,254,232,1,69,255,220,255,219,0,158,0,230,46,147,6,103,8,254,255,170,251,38,208,197,255,160,2,52,7,36,8,203,247,116,6,241,252,122,2,55,204,173,254,92,15,212,8,92,207,152,0,60,1,80,253,79,0,112,252,223,247,104,5,188,0,150,7,62,253,204,0,188,2,240,6,77,54,158,202,188,254,216,1,31,4,122,253,82,0,255,252,147,252,69,254,29,255,124,252,124,2,154,252,214,1,144,255,170,253,206,238,90,245,239,6,40,255,213,255,13,183,161,252,4,238,105,13,162,2,101,255,208,0,10,6,38,1,99,255,152,253,62,43,205,4,240,253,76,8,187,2,40,14,54,0,252,253,194,0,12,203,110,7,6,254,219,250,124,7,215,1,170,254,68,3,18,0,138,3,102,2,248,255,73,252,28,4,159,255,164,8,100,252,54,1,6,0,35,253,122,0,179,92,212,1,89,1,9,6,154,5,99,2,147,1,192,243,90,247,202,255,255,3,146,250,133,235,96,241,254,254,215,26,14,249,161,2,198,246,49,205,248,252,50,252,203,251,194,32,118,240,27,239,212,4,171,15,137,4,249,254,200,4,99,205,156,255,241,10,178,5,247,243,66,2,17,0,13,4,26,253,84,23,136,253,88,11,79,206,179,229,34,254,182,0,75,248,204,252,1,229,216,236,82,252,164,254,159,254,162,254,184,30,34,0,56,2,193,7,188,3,238,12,118,0,237,247,56,49,103,35,73,6,19,251,40,1,32,251,136,249,191,255,40,7,245,5,223,5,29,20,18,17,154,249,228,240,64,1,247,5,88,254,12,69,244,6,148,4,148,251,104,4,14,5,190,254,155,255,206,1,244,229,48,244,149,29,176,212,45,6,13,0,138,250,38,2,24,17,87,6,191,6,89,3,66,235,224,9,239,253,111,254,27,2,108,25,150,16,9,16,13,235,96,0,161,203,74,253,197,19,117,13,45,243,164,254,66,250,90,4,90,2,108,254,127,255,130,2,11,6,70,90,49,247,177,7,77,1,17,5,116,0,101,249,108,1,240,253,246,2,41,251,222,248,7,255,117,254,172,2,168,252,130,253,240,216,43,245,249,231,36,251,190,243,40,218,54,248,212,27,88,5,178,248,200,254,71,7,18,252,195,3,21,3,231,2,194,239,8,253,104,5,155,226,65,252,250,254,120,22,165,15,251,208,46,255,118,3,87,248,31,19,5,255,98,255,212,0,165,2,6,2,86,1,30,255,152,254,210,1,17,0,232,110,236,255,246,0,82,253,254,254,128,2,134,254,136,255,69,254,54,4,204,245,36,8,86,249,238,16,189,237,230,237,32,9,242,216,247,38,251,250,218,10,220,12,75,249,138,0,66,8,160,251,76,255,134,251,212,46,61,3,30,246,133,221,177,26,89,251,139,249,131,10,29,240,142,4,179,7,47,1,224,253,77,250,251,254,41,4,82,13,2,8,91,12,253,253,80,21,91,239,107,21,251,5,206,247,228,7,189,14,76,2,147,3,158,0,156,209,26,1,100,251,9,1,28,43,190,255,51,249,154,248,118,239,232,11,218,0,250,251,192,8,134,206,14,247,119,249,137,248,200,5,31,1,175,255,158,4,216,0,18,214,153,8,198,255,149,253,137,33,194,253,32,238,60,7,44,254,153,229,13,226,167,0,227,3,166,251,4,251,251,247,130,8,59,224,10,251,114,225,170,214,4,21,221,11,47,4,59,3,108,19,0,4,127,255,76,255,70,244,178,252,32,253,115,37,98,7,47,40,94,248,18,4,22,6,74,252,102,9,196,248,227,8,38,26,65,253,114,252,14,15,44,3,9,2,205,251,7,253,237,20,185,240,52,15,8,31,228,17,167,19,64,4,204,27,46,249,153,235,47,10,155,12,248,8,227,21,211,0,37,253,50,25,16,243,166,207,186,254,149,16,72,16,225,252,21,242,7,254,213,2,79,235,148,8,173,8,240,255,112,242,59,1,114,2,13,232,71,0,152,3,225,238,196,250,141,245,104,253,244,28,40,251,175,250,229,3,23,241,183,246,59,210,125,6,22,0,28,2,115,235,74,252,48,29,76,12,223,29,208,238,206,17,196,238,155,252,8,250,198,245,119,32,62,8,22,2,52,254,33,255,94,255,196,252,18,1,52,7,69,7,209,249,243,26,102,20,20,249,192,244,0,231,95,18,46,10,106,240,56,251,192,239,72,35,213,254,255,127,127,1,89,3,213,249,89,254,140,4,186,249,194,4,102,254,9,3,220,254,122,0,26,1,182,255,142,250,3,1,34,253,102,0,174,255,104,127,171,1,223,253,110,255,115,255,84,1,250,1,216,252,171,0,246,252,132,3,52,255,235,254,28,255,86,254,54,2,31,254,142,251,117,252,112,0,162,10,103,3,115,0,222,227,161,7,198,252,236,248,116,254,126,198,184,252,155,0,90,4,248,21,88,4,109,255,17,231,158,3,225,5,104,1,169,3,177,203,201,3,150,27,170,8,53,242,215,1,202,1,191,0,47,254,216,33,112,251,34,2,61,8,80,252,182,255,108,6,175,255,8,253,128,248,99,10,18,52,231,5,132,251,66,5,28,3,236,255,0,195,222,4,90,251,126,213,250,252,186,255,59,14,128,252,38,7,64,255,250,3,61,4,161,255,203,254,147,2,91,0,215,2,122,238,230,1,226,247,211,4,177,199,43,240,173,249,227,245,186,253,214,237,236,15,6,253,169,251,21,1,168,5,26,253,198,254,45,252,97,7,119,10,76,248,176,9,46,1,53,11,33,220,67,254,231,248,94,50,106,0,187,0,130,250,153,253,106,251,234,2,141,254,126,1,94,1,237,248,241,253,36,0,244,1,189,252,150,255,110,4,97,247,253,3,92,1,140,3,236,170,192,1,176,2,196,255,2,249,109,7,50,166,187,5,84,2,112,252,138,243,204,5,13,1,103,254,38,254,122,249,48,5,152,0,110,254,103,1,34,253,104,204,62,0,155,239,158,231,75,20,231,244,166,19,234,10,240,4,150,251,237,14,193,3,217,2,51,4,49,0,108,255,99,28,36,10,27,236,164,223,37,229,13,244,69,15,229,237,122,5,66,231,170,254,245,243,163,252,234,1,233,4,138,253,128,0,192,8,64,3,36,4,246,248,140,249,128,0,136,30,201,199,190,229,0,243,230,245,228,11,64,4,41,6,84,3,114,255,80,255,91,5,212,4,208,3,133,47,196,249,57,255,8,254,244,212,186,253,204,3,68,250,158,246,102,253,1,243,156,247,54,4,62,255,203,37,202,247,44,251,186,255,82,252,35,1,84,5,123,5,222,242,163,50,137,254,64,249,79,6,206,246,121,2,6,254,62,255,237,50,92,55,22,2,254,251,87,254,184,9,76,255,90,253,76,254,16,1,227,5,178,254,72,3,24,252,212,251,5,4,206,254,24,0,173,238,150,232,229,250,155,16,128,15,223,9,43,252,190,245,208,238,14,255,225,248,89,253,31,50,234,255,51,0,131,254,118,9,184,246,36,224,59,250,194,228,78,4,139,254,211,1,50,44,214,253,80,254,56,3,109,28,137,1,78,255,179,0,115,253,72,46,199,249,63,55,37,253,244,251,238,246,5,1,56,248,128,251,106,250,182,250,205,255,227,254,155,249,144,0,197,255,122,247,99,22,26,2,144,252,141,1,194,11,195,2,226,248,18,252,78,18,24,236,150,16,232,243,99,240,2,255,239,212,138,1,167,254,92,73,82,253,251,253,162,242,104,0,131,247,135,9,232,234,246,255,60,4,29,7,166,253,151,5,149,1,95,8,243,1,149,1,95,1,194,255,209,255,162,7,37,139,184,1,30,4,47,2,70,251,186,1,160,3,255,255,59,0,23,1,144,255,146,255,72,254,116,254,37,3,55,1,90,3,81,254,210,251,16,138,135,0,222,4,167,254,22,3,242,1,63,1,210,254,43,254,246,255,0,2,195,252,242,253,252,247,152,9,134,0,81,180,70,251,244,250,128,2,160,12,20,10,205,3,148,246,15,1,230,254,120,2,245,253,177,252,118,255,34,252,197,9,24,2,90,255,52,8,155,254,122,0,210,1,252,255,242,7,115,78,42,6,188,1,168,254,79,253,101,22,56,254,9,254,176,253,186,250,242,251,164,3,132,248,74,4,34,252,97,167,8,6,70,254,116,254,198,253,85,253,152,253,105,250,118,0,17,16,200,254,252,8,45,8,216,246,117,244,199,24,210,16,162,216,142,24,94,233,218,252,152,2,39,255,36,2,208,19,18,18,149,249,157,210,11,3,164,7,112,244,102,2,39,8,144,35,142,246,7,3,161,238,0,3,63,6,196,251,231,3,116,6,66,4,118,2,83,251,89,242,112,252,167,217,136,2,206], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+358417);
/* memory initializer */ allocate([12,36,7,37,53,197,10,193,252,89,251,202,248,95,250,234,254,174,222,57,254,17,254,67,1,113,252,196,9,20,55,51,14,248,3,88,252,145,20,236,243,77,8,135,255,192,255,112,253,175,254,222,36,80,226,123,5,115,209,132,8,52,10,128,6,67,4,194,254,28,243,85,254,26,1,187,7,126,3,65,253,2,2,160,0,161,6,108,25,60,3,187,0,222,255,186,251,211,244,240,0,107,236,116,23,68,237,33,252,158,0,173,44,62,249,98,1,171,4,206,14,64,215,0,242,48,54,80,1,251,7,221,0,92,2,114,11,56,4,119,250,86,7,146,252,53,254,93,254,108,1,243,251,84,30,28,12,48,0,49,43,144,7,181,8,190,35,40,254,154,4,127,255,60,11,7,255,254,254,99,251,183,254,187,253,140,251,81,248,91,1,229,253,118,254,7,3,129,251,225,255,28,4,148,248,43,255,240,249,212,87,164,0,143,255,135,0,242,250,38,2,58,30,201,227,29,253,82,5,142,21,193,0,134,247,171,209,179,250,95,1,167,8,165,0,16,0,162,253,215,2,98,255,252,252,148,203,32,251,134,48,212,252,232,6,70,254,245,4,204,251,131,3,124,0,7,255,170,251,141,2,8,244,160,249,71,3,26,255,0,2,130,2,174,51,229,51,216,253,167,251,173,253,96,3,25,2,12,252,229,253,153,253,21,254,246,3,32,3,246,255,22,2,53,251,77,158,215,4,230,255,250,14,104,0,250,2,235,4,64,8,212,254,104,252,212,252,100,2,219,251,134,254,10,255,249,255,34,43,196,183,125,250,179,255,151,1,212,253,218,0,215,6,45,4,218,254,253,6,136,3,29,1,180,255,44,1,96,255,128,255,186,242,47,248,153,6,82,19,66,245,147,5,168,206,175,248,246,248,165,251,39,245,172,238,121,11,248,230,45,254,231,1,19,4,74,15,175,255,4,6,58,210,88,5,144,206,185,253,241,3,96,254,249,0,82,7,133,4,226,3,166,252,102,255,38,1,77,1,230,255,73,0,216,249,236,255,208,253,212,251,45,5,180,253,49,102,44,6,101,254,181,253,197,251,177,255,250,2,36,1,146,253,20,3,28,1,222,7,78,0,42,2,252,253,60,5,67,3,44,1,5,159,46,2,63,253,234,255,139,0,97,255,10,255,183,253,222,16,234,0,28,5,58,255,214,242,92,22,77,9,19,54,4,0,57,2,66,31,164,4,193,255,94,249,16,18,107,254,38,255,142,16,136,252,100,251,166,14,16,237,231,218,37,1,193,251,38,204,223,255,202,244,201,1,150,253,82,1,222,255,30,1,89,1,55,235,136,3,232,233,222,247,100,49,1,227,20,2,190,3,51,248,53,250,90,244,43,12,197,248,23,248,61,7,106,252,121,252,18,6,28,2,91,191,161,5,123,11,8,251,34,12,70,9,66,15,71,253,120,4,238,2,133,254,154,230,212,3,130,1,36,0,85,4,171,4,128,24,168,16,221,5,249,20,232,249,207,13,60,4,227,2,249,251,208,238,4,33,82,254,5,249,11,226,25,255,141,255,228,16,228,248,206,247,238,252,54,29,107,245,81,200,139,22,115,0,92,249,145,255,54,250,167,250,144,255,122,0,40,254,233,0,123,9,24,7,180,0,31,254,160,3,82,0,84,0,68,253,64,254,78,252,176,7,108,6,168,0,89,255,36,63,155,0,180,215,173,3,184,253,232,1,96,0,85,20,235,1,204,248,1,205,242,4,160,254,188,252,46,2,10,6,72,249,57,1,241,7,85,2,241,199,74,17,209,12,209,253,54,10,176,12,39,247,184,215,178,249,224,254,224,1,139,5,222,253,27,254,67,3,192,3,206,1,155,3,118,25,66,3,57,253,161,206,107,34,49,255,14,7,81,1,40,251,68,237,79,9,21,1,117,4,201,3,59,0,197,0,85,5,154,253,72,220,216,18,76,254,95,16,228,245,157,17,135,1,65,236,97,243,66,27,12,231,51,0,105,0,161,252,26,4,47,51,225,49,92,254,230,249,133,255,142,10,36,1,37,4,123,0,149,1,125,7,237,254,237,1,161,255,61,255,130,0,203,245,50,35,196,0,154,250,15,23,113,28,49,6,253,9,148,252,94,12,254,26,78,2,12,244,209,253,114,18,137,1,101,2,120,254,50,244,164,38,16,7,155,3,187,31,145,38,127,249,45,9,78,11,79,2,208,7,106,241,107,252,220,0,152,1,40,1,112,253,48,10,92,249,144,1,18,214,58,21,104,25,137,250,127,8,77,251,42,231,59,251,58,236,45,0,202,3,12,254,214,250,152,4,250,22,89,210,180,24,121,247,23,9,154,3,4,234,77,242,102,9,106,3,119,5,166,17,169,254,89,3,32,255,34,3,43,253,143,222,80,17,182,7,33,7,136,247,61,254,176,242,187,25,165,29,33,13,153,237,62,250,79,12,158,7,254,3,186,5,232,35,58,18,202,252,0,4,38,9,84,247,145,4,220,40,177,11,36,252,201,238,185,229,134,3,123,6,80,0,106,0,144,1,34,0,210,6,186,228,244,40,189,24,179,252,251,242,228,6,217,0,134,237,22,243,176,241,242,244,206,8,97,252,201,255,75,2,20,7,25,1,23,17,226,241,187,250,10,7,216,231,168,245,163,239,91,219,85,243,205,239,128,1,193,8,148,21,34,254,2,250,203,208,0,32,246,248,235,17,59,23,145,243,187,245,45,7,130,9,252,0,156,253,167,237,192,253,150,0,64,253,128,253,174,0,130,255,187,215,94,1,141,243,106,18,243,244,74,49,132,247,174,13,209,1,97,255,167,253,26,5,150,4,64,254,220,254,120,255,242,0,31,0,211,220,197,231,213,216,25,0,47,255,236,255,244,250,28,251,208,16,97,14,110,17,207,238,60,17,216,4,192,253,34,14,83,2,19,255,240,9,112,232,25,250,243,5,172,241,112,242,176,21,219,236,240,254,75,23,180,10,146,252,210,50,191,0,31,248,0,3,199,1,211,255,39,229,176,241,79,10,63,252,252,11,110,239,47,5,58,9,139,248,166,251,100,0,204,232,220,0,97,3,104,205,180,255,1,251,177,253,68,4,82,242,88,0,186,247,253,50,99,216,48,244,235,253,125,248,255,239,135,0,136,6,131,249,110,6,142,254,151,254,132,2,59,255,116,229,60,213,172,45,50,252,232,1,93,1,96,15,30,250,107,255,1,2,121,5,16,249,121,254,46,255,57,0,200,255,168,254,250,3,53,31,163,236,167,0,219,3,196,255,62,0,86,6,183,4,187,255,82,1,251,192,210,255,250,3,76,250,203,252,122,253,36,5,126,0,233,237,182,252,31,250,217,61,252,230,94,238,130,11,107,11,174,4,187,243,219,243,179,249,61,7,118,252,76,254,170,251,230,254,42,255,160,242,187,243,108,240,28,1,246,86,245,4,251,6,164,251,107,250,249,3,115,1,69,255,199,252,22,2,94,1,64,4,26,0,176,0,210,34,6,26,167,3,26,8,206,224,84,237,146,8,4,7,185,2,56,240,182,9,164,6,190,35,219,255,232,249,145,9,94,255,128,0,211,226,126,245,231,254,166,237,168,1,23,2,136,5,243,0,193,253,120,251,70,1,143,246,40,3,56,194,226,3,210,254,26,0,126,3,48,227,139,1,182,253,55,3,195,250,204,3,100,0,241,0,231,2,214,1,11,1,218,253,218,1,182,0,76,71,178,0,74,255,249,255,168,13,84,8,95,3,105,255,229,2,146,247,5,253,116,253,9,254,78,254,32,253,2,3,100,255,129,181,187,1,158,254,13,255,66,0,162,16,58,26,249,13,186,67,44,2,14,242,245,4,130,250,132,6,163,254,166,255,13,3,82,0,46,2,168,3,236,252,208,251,235,255,184,230,50,244,37,254,171,228,0,245,66,241,147,6,130,201,154,13,176,248,64,10,40,4,194,254,20,5,66,251,179,0,245,255,132,255,208,17,245,244,86,231,152,233,135,4,29,5,170,234,124,210,96,16,151,0,225,253,100,242,16,247,137,255,233,2,93,5,135,255,139,253,84,20,226,29,242,247,214,242,178,244,174,254,175,250,56,4,166,241,52,50,25,232,214,249,32,253,15,255,228,249,147,255,71,254,79,1,160,1,142,6,194,18,89,243,38,24,154,0,184,241,199,250,125,189,171,6,131,254,88,249,135,254,254,3,176,253,215,3,191,254,37,0,202,248,108,238,15,10,82,55,208,253,169,36,83,16,196,250,118,242,163,12,191,6,9,6,233,255,124,2,24,1,217,255,103,3,173,0,45,221,133,246,98,8,142,241,135,208,67,241,223,240,178,19,112,0,20,3,141,251,245,0,34,2,22,1,248,255,19,252,187,1,180,255,24,251,63,32,1,15,228,23,130,16,121,14,2,251,186,230,100,20,4,23,116,242,176,10,51,21,248,242,248,254,114,7,38,1,196,255,90,228,19,30,192,217,60,228,18,248,31,4,206,228,190,2,230,247,24,255,127,0,82,254,146,2,240,254,245,2,138,0,159,0,172,254,2,238,253,3,146,0,246,225,113,23,28,22,35,13,145,254,166,51,71,254,13,0,150,252,156,2,245,8,107,3,214,4,110,0,10,3,154,5,48,252,103,8,23,224,141,5,62,10,206,0,229,252,208,252,149,199,209,249,28,13,155,11,60,252,191,254,183,252,108,254,111,0,37,234,152,16,21,241,214,0,40,246,56,253,31,250,81,3,179,3,148,252,188,0,149,12,95,3,105,0,72,188,26,7,14,0,17,0,51,231,123,1,138,18,139,207,208,253,136,242,80,14,59,32,77,3,127,1,68,5,29,253,244,252,159,6,220,18,133,255,121,253,55,3,212,38,73,255,244,248,56,228,95,255,66,2,149,253,14,45,142,12,50,6,176,18,20,246,164,4,208,254,27,254,120,253,200,252,173,253,143,221,42,16,159,3,69,243,58,255,182,15,165,8,165,249,133,2,10,57,222,251,201,5,122,249,143,255,52,2,58,253,61,254,152,254,19,251,200,9,247,0,190,21,162,227,64,5,14,236,184,249,154,7,112,239,31,227,200,40,234,12,148,7,25,252,155,0,64,3,55,0,234,39,211,44,76,243,153,223,67,5,101,9,93,13,197,245,214,8,243,244,242,2,205,254,36,2,8,248,150,251,61,1,170,0,36,1,248,0,41,10,14,182,106,248,137,5,142,6,238,12,238,245,79,248,14,6,194,11,70,0,8,0,248,11,176,252,248,1,84,255,180,0,251,6,147,251,123,9,234,3,104,253,216,255,192,0,152,164,20,252,1,2,206,252,130,254,104,1,104,1,12,1,98,0,54,255,64,255,100,253,132,205,74,210,157,28,29,3,145,7,162,2,102,246,227,253,39,250,119,249,69,252,156,254,26,254,182,0,43,1,210,255,65,0,120,239,138,5,132,25,52,9,226,236,6,19,41,13,23,238,39,34,217,5,85,250,94,3,92,222,74,249,180,6,171,246,115,1,80,2,229,28,140,243,119,253,126,0,236,250,94,5,244,250,133,2,42,250,176,10,68,250,240,248,185,188,160,254,111,0,34,255,20,255,171,0,58,255,198,224,18,241,204,20,40,190,251,253,119,0,58,1,152,254,253,253,179,1,8,2,130,253,99,6,164,1,167,4,62,3,198,2,241,26,109,11,19,12,254,1,196,12,90,249,198,192,206,2,201,243,49,254,251,2,245,251,213,2,134,255,134,2,172,0,92,255,235,254,221,22,94,228,246,255,22,249,16,246,90,23,150,252,18,254,24,255,129,56,23,7,146,248,219,3,3,250,192,4,229,2,108,2,161,0,62,17,88,16,224,255,128,244,245,237,50,254,85,61,254,251,116,255,164,246,45,249,230,253,0,252,219,0,86,3,161,254,92,3,30,255,218,238,220,2,45,248,130,246,228,253,80,2,86,6,156,4,129,1,252,247,210,15,249,67,118,253,13,255,173,6,237,4,95,0,205,254,10,236,102,253,74,228,235,253,243,250,51,188,113,11,85,9,137,255,99,254,61,1,62,252,197,2,240,249,26,0,175,0,188,2,198,253,152,78,83,4,232,0,169,0,135,252,235,253,4,251,22,0,191,3,98,3,70,252,232,252,105,3,84,255,221,6,195,0,148,0,167,1,138,17,78,34,119,2,170,2,40,7,112,241,50,249,134,212,79,251,240,6,52,36,182,253,178,250,122,253,114,2,158,252,5,0,7,1,110,15,8,253,158,244,49,206,131,206,233,5,252,255,119,2,43,7,56,1,89,255,10,6,236,253,107,2,152,4,156,5,140,255,56,1,142,27,48,12,235,15,216,250,203,2,50,255,220,249,70,5,24,69,98,251,224,249,168,2,6,0,207,0,242,3,88,2,2,253,42,2,53,250,132,2,150,221,112,2,148,0,81,240,0,250,185,248,92,0,218,2,42,198,130,1,202,235,116,250,181,254,2,255,152,255,19,1,156,227,3,10,207,46,191,255,107,31,169,249,227,245,206,245,48,5,82,12,143,7,88,14,31,249,120,19,149,2,209,0,242,251,122,0,5,252,236,142,55,0,102,1,229,253,232,1,55,0,106,2,20,0,198,254,190,1,8,252,106,2,163,255,162,255,181,254,220,255,194,0,86,249,228,25,140,1,110,255,3,253,4,41,59,10,174,255,114,213,188,240,136,252,64,255,108,2,163,0,78,0,6,3,219,254,152,255,38,237,14,201,165,248,70,243,31,238,52,250,36,21,78,239,169,236,244,12,117,252,156,7,93,251,108,254,70,14,144,1,186,255,203,1,104,243,134,243,34,9,38,17,251,255,161,243,201,12,116,0,254,251,124,249,183,14,16,1,234,190,137,0,158,249,17,252,220,0,202,254,214,3,28,32,240,255,29,251,172,245,240,242,188,8,219,249,238,31,100,2,118,4,209,213,137,1,61,253,196,18,141,1,208,4,220,254,130,22,8,195,105,11,216,230,216,13,165,246,8,254,98,7,172,0,14,252,178,0,124,1,117,251,148,1,50,251,10,4,172,253,105,0,10,248,199,7,237,21,200,254,196,239,35,216,20,12,160,237,43,232,172,249,243,251,150,251,54,6,129,32,227,252,247,0,186,3,153,255,254,14,26,9,80,39,125,12,196,222,20,5,12,252,49,230,235,240,19,22,31,0,37,254,46,6,166,250,83,4,116,8,231,2,201,253,234,18,142,244,119,12,66,255,74,247,209,255,254,0,99,8,79,2,0,254,32,5,135,4,43,3,164,5,224,250,255,254,144,62,21,3,254,245,143,15,139,254,217,219,46,1,185,241,118,22,240,240,227,228,94,15,246,246,180,21,253,239,247,254,33,254,21,237,126,255,20,0,5,237,11,12,82,25,102,241,160,240,78,2,32,231,8,249,75,0,193,240,78,229,156,238,153,252,252,2,162,251,27,34,38,0,108,255,216,242,70,231,142,254,186,8,139,3,7,245,78,250,254,246,110,254,119,10,58,251,114,4,192,0,219,250,244,3,154,60,112,2,23,1,64,240,5,10,18,24,86,252,128,22,149,6,254,16,123,11,199,252,181,254,48,7,212,253,171,1,222,237,233,255,154,32,153,29,45,254,8,15,198,1,134,240,117,1,140,255,10,9,4,19,48,255,169,250,245,248,121,10,38,3,73,239,20,13,240,253,203,54,18,255,55,254,52,245,64,3,184,237,2,17,195,4,223,252,110,9,172,235,72,241,132,230,43,20,99,213,120,6,65,1,188,12,19,249,214,0,121,255,45,238,86,20,70,237,206,5,150,1,254,251,25,1,7,7,38,255,64,1,116,252,104,3,32,4,139,11,48,255,225,252,132,60,78,1,106,107,98,254,246,254,134,2,229,0,94,0,241,255,46,1,23,254,111,254,125,0,240,2,36,254,56,255,48,252,195,0,4,0,110,254,172,8,244,3,195,6,226,9,116,253,124,172,89,253,157,252,61,255,142,255,46,5,227,9,164,254,71,255,142,255,178,0,74,253,214,254,48,34,199,6,80,10,186,246,47,24,236,5,139,22,49,26,3,255,202,222,218,3,86,8,194,248,162,13,90,253,208,255,133,0,76,3,157,249,94,6,168,23,12,253,171,251,27,6,91,250,117,255,68,2,88,250,13,183,78,3,122,254,253,254,12,6,188,254,25,1,142,0,0,7,187,4,48,5,44,239,248,251,220,234,134,18,55,255,209,255,215,254,45,223,243,37,100,28,84,241,37,6,165,2,168,255,111,255,13,19,146,50,192,12,17,7,62,28,233,245,91,6,6,249,55,228,56,250,193,247,4,254,159,1,128,6,29,254,230,253,7,255,80,0,93,27,254,245,137,252,217,14,11,25,174,8,36,0,107,3,31,236,145,42,174,15,84,19,212,249,145,5,234,248,121,254,160,255,66,1,172,230,104,7,146,225,74,252,117,239,86,223,46,12,235,18,170,14,46,4,144,249,12,30,117,249,77,13,150,3,222,8,61,2,193,0,136,23,208,34,215,236,238,248,217,3,85,7,110,8,154,247,126,254,68,15,238,7,163,1,201,206,198,253,106,255,44,6,36,0,104,255,2,0,230,253,227,249,153,26,53,253,134,231,75,206,194,229,42,3,165,253,11,6,233,3,202,8,42,3,237,6,96,253,71,1,246,0,14,25,169,226,148,3,185,254,62,3,86,46,21,17,235,3,226,24,62,249,177,247,101,2,91,6,114,2,251,2,160,252,207,0,23,255,154,14,60,222,158,249,254,247,66,15,61,254,186,50,36,237,99,244,150,237,33,2,54,3,223,2,45,242,0,255,65,0,163,255,162,255,107,11,163,27,77,241,28,24,184,218,141,245,7,241,162,3,162,1,112,238,206,14,130,1,139,225,234,0,159,253,253,254,198,1,74,1,10,6,46,226,82,248,3,2,64,246,118,1,73,10,58,244,30,16,192,38,65,228,161,5,106,255,15,30,158,2,208,255,215,255,0,254,63,229,7,249,171,14,68,7,114,9,214,246,86,251,218,249,150,60,188,1,21,250,73,2,230,2,57,255,165,251,134,255,245,255,140,0,173,225,158,5,195,254,68,254,3,189,232,255,125,10,168,252,162,243,85,4,52,1,233,0,30,0,63,0,18,2,133,2,84,0,133,0,251,23,97,251,79,214,10,206,144,255,248,249,15,18,64,2,220,252,255,3,146,249,168,4,13,1,121,10,44,0,115,252,242,255,98,254,48,0,94,240,160,18,112,13,180,12,161,5,101,0,116,1,94,12,138,250,69,1,56,63,57,253,230,1,48,5,114,0,62,254,225,255,128,4,106,8,187,255,4,255,32,0,154,3,219,0,249,247,165,1,159,250,238,3,154,253,234,0,216,255,172,255,204,0,35,106,182,0,10,4,0,6,66,3,154,224,219,4,254,243,107,225,157,43,194,248,107,251,153,252,9,16,4,14,137,243,188,0,202,247,124,0,90,255,134,31,198,212,232,25,179,10,149,225,184,0,16,233,80,5,191,251,249,4,84,0,109,249,208,249,207,3,50,255,136,4,180,0,12,0,23,232,60,21,122,198,61,23,156,229,66,3,214,6,186,243,146,252,7,0,36,255,115,248,115,255,160,0,26,0,244,2,224,252,6,0,88,224,179,228,25,13,66,242,158,17,114,207,224,2,131,245,238,251,32,0,160,4,249,253,200,254,207,251,110,254,71,0,90,254,221,255,255,6,191,49,23,247,63,10,34,250,218,240,71,26,45,41,170,251,4,9,102,3,100,4,106,3,130,250,123,0,254,0,149,1,72,1,244,14,139,226,24,12,191,200,96,253,67,249,89,254,130,248,68,16,101,254,22,12,200,253,247,13,177,244,134,254,7,244,24,255,193,1,174,31,216,8,153,250,211,253,69,214,52,226,59,16,242,2,122,255,103,26,27,4,250,247,124,252,76,252,67,2,3,251,151,0,206,1,42,45,202,254,188,223,254,39,227,250,20,244,89,1,79,253,147,251,180,253,36,2,212,3,204,250,113,3,112,1,8,3,64,253,166,1,145,48,34,5,49,250,111,237,119,10,20,12,85,252,136,0,182,253,176,13,246,251,82,231,178,13,164,1,22,9,10,4,4,255,114,254,168,231,136,17,234,231,38,249,140,3,20,19,188,235,87,244,41,42,140,255,66,18,140,15,247,255,37,3,32,6,172,249,168,255,110,255,211,11,230,192,83,11,159,30,24,23,85,254,14,1,69,250,125,254,161,254,103,2,190,254,254,255,219,251,114,253,56,0,74,254,132,0,84,9,204,1,124,8,82,7,44,244,230,12,243,7,64,253,58,251,133,178,40,254,190,248,106,249,226,254,5,0,20,253,235,1,162,254,8,239,103,0,193,5,136,9,7,53,186,250,176,5,137,40,170,7,220,11,42,251,44,6,95,2,72,5,229,3,188,4,23,254,251,0,235,15,127,242,42,24,18,3,44,1,28,246,139,254,38,246,36,12,218,254,74,19,92,244,229,5,162,48,73,253,152,251,160,255,98,1,162,241,46,33,176,9,216,8,42,20,131,46,113,18,87,4,240,2,183,11,84,15,107,250,65,1,20,1,53,1,165,253,89,2,194,255,9,13,14,242,201,12,218,25,47,248,182,3,20,2,204,3,83,6,188,3,65,0,159,253,231,254,79,198,74,254,68,2,230,0,28,255,132,216,1,48,200,34,104,3,32,243,255,5,128,254,221,1,111,252,247,252,34,2,189,1,20,252,77,254,52,253,118,255,60,2,179,1,18,18,160,252,172,233,6,245,11,5,68,237,15,255,223,9,218,246,176,250,65,16,94,7,128,255,15,250,158,53,26,7,214,253,99,255,63,218,47,10,11,252,67,2,98,4,35,6,132,245,100,44,192,230,72,255,250,249,218,233,189,251,98,253,249,4,229,251,249,255,234,254,9,246,220,253,79,214,102,250,169,254,61,1,220,243,177,249,65,247,204,200,234,1,58,254,163,9,198,7,214,1,208,251,184,1,34,1,190,11,188,238,221,247,234,11,219,10,211,246,178,253,179,236,40,29,216,220,130,245,3,248,248,221,47,243,84,246,136,2,108,255,152,1,169,250,167,251,211,106,167,251,227,2,39,0,163,5,48,255,82,253,218,3,223,2,66,253,76,0,153,2,62,255,91,255,110,1,162,253,212,236,164,240,187,193,6,245,220,17,48,3,212,247,117,16,68,246,166,15,158,3,210,0,170,251,157,249,242,254,30,255,150,254,69,255,254,6,200,11,168,8,50,15,226,7,211,250,72,77,253,252,100,1,70,8,158,255,80,253,248,3,210,3,47,2,217,255,160,0,202,254,222,25,38,249,160,212,204,0,92,247,66,9,166,210,95,4,144,12,30,12,12,2,22,1,195,252,12,2,28,0,70,3,118,1,180,255,15,238,139,244,201,41,146,230,150,236,23,248,89,219,156,242,240,239,105,10,179,5,125,250,165,1,225,1,74,3,171,254,147,0,98,255,12,16,45,0,71,19,235,255,31,225,10,8,134,4,156,59,201,253,16,253,32,252,186,251,221,251,66,9,52,3,143,2,251,254,24,1,127,240,198,24,73,33,42,12,113,1,19,208,148,6,4,0,78,18,193,7,172,241,32,244,165,2,2,255,57,0,95,255,35,252,133,254,163,27,188,253,30,11,151,243,19,247,190,3,72,228,102,255,253,253,239,242,175,52,220,13,244,248,34,1,82,254,214,2,143,1,54,0,2,245,251,39,166,7,228,242,206,250,24,2,146,12,142,200,200,0,228,252,162,252,56,250,19,7,166,254,92,2,121,254,25,255,1,2,1,215,115,232,164,230,214,221,155,254,35,255,158,248,147,245,8,0,36,249,76,233,232,251,210,8,223,0,38,254,130,4,30,255,92,1,202,249,99,11,158,0,5,162,107,3,178,252,126,4,24,252,180,252,140,255,10,255,37,255,30,254,145,254,120,0,5,2,23,254,186,1,212,31,176,19,186,14,18,252,205,255,153,243,218,215,140,238,164,4,217,5,141,230,251,255,164,249,173,246,239,250,51,253,94,6,232,0,232,241,224,229,140,9,232,252,10,255,155,1,184,5,77,14,172,12,159,251,190,249,218,195,69,254,114,3,132,5,158,3,16,0,183,255,133,10,0,28,73,219,16,2,236,30,202,219,123,249,60,245,24,5,2,12,26,250,215,247,211,5,236,249,90,254,98,254,132,0,64,255,100,23,148,17,148,29,30,213,245,236,101,14,96,7,108,253,42,249,253,253,88,245,195,243,74,245,154,2,211,244,114,2,0,1,243,0,235,17,17,242,224,254,10,9,157,18,228,212,154,28,157,29,91,10,192,12,118,254,10,255,133,252,72,250,75,249,123,0,251,253,26,254,5,252,47,28,42,2,210,2,99,239,89,9,237,11,65,11,2,6,200,247,61,2,65,1,161,2,62,15,217,244,176,3,240,205,114,1,168,13,184,3,101,250,235,24,254,2,225,8,39,253,80,0,128,246,130,251,104,9,129,252,137,60,49,251,230,254,22,243,77,254,89,255,56,242,205,233,243,230,197,9,39,237,124,0,56,12,87,254,16,245,38,252,21,247,17,254,192,242,232,249,211,247,163,210,219,255,157,0,74,254,230,252,196,7,211,255,228,5,20,0,98,0,54,254,11,255,106,4,110,0,243,253,253,252,96,4,198,2,2,171,174,0,46,255,25,237,92,246,120,253,220,238,245,255,174,11,75,255,74,237,120,239,50,14,27,25,212,10,166,0,76,244,27,209,94,6,7,255,179,0,88,3,30,251,136,239,201,7,44,20,149,18,49,236,235,16,43,244,4,251,80,212,208,244,214,4,188,24,129,246,252,4,174,254,36,254,229,233,150,246,206,9,61,7,11,237,153,243,152,248,232,41,140,14,192,3,235,38,49,1,86,252,122,253,56,245,156,5,113,0,182,255,230,243,6,240,134,11,141,10,224,3,206,0,143,250,125,247,146,213,164,246,16,252,79,10,245,249,96,254,48,36,32,7,152,254,145,1,4,19,197,248,17,248,29,248,41,249,216,253,244,2,161,3,109,5,54,6,214,247,78,251,219,250,4,2,250,248,4,252,74,253,226,16,108,5,112,7,211,245,41,251,237,3,11,253,32,251,154,254,187,2,55,255,153,1,69,4,171,244,50,247,211,245,221,245,200,247,111,249,198,26,132,10,83,12,118,13,25,246,115,250,47,249,130,3,2,248,79,250,236,251,243,254,212,6,81,7,36,247,182,251,151,1,183,248,201,247,230,5,63,251,113,254,182,6,225,7,54,14,107,249,245,249,56,250,101,6,24,253,68,2,74,2,33,5,129,5,105,2,28,248,129,248,125,247,164,3,87,252,47,2,3,7,248,5,60,6,205,244,7,246,53,246,163,245,195,246,63,248,86,255,231,33,175,16,177,16,215,8,213,248,114,248,73,249,14,249,53,9,125,0,39,5,7,6,229,6,105,14,65,251,65,9,3,250,181,249,253,252,133,255,237,3,17,5,185,5,69,246,71,10,156,249,137,249,220,4,102,251,130,1,193,3,20,5,17,6,203,246,156,246,255,246,127,247,78,249,129,254,158,255,2,1,62,15,171,9,149,244,236,245,131,245,13,245,138,245,132,246,33,251,194,1,238,31,171,19,2,247,163,249,41,250,40,7,80,6,191,253,127,2,104,3,98,4,157,5,17,3,101,248,72,248,55,3,139,248,19,252,174,1,220,4,177,6,128,6,23,246,89,31,87,249,43,248,18,248,125,251,64,0,82,4,183,7,229,8,150,246,177,245,12,247,190,248,162,0,232,2,43,2,23,6,183,6,14,7,22,247,66,248,134,248,135,5,7,249,149,8,254,0,251,2,58,5,205,6,51,246,57,248,232,246,195,248,5,247,25,20,222,255,215,5,97,11,202,11,39,248,56,249,107,9,197,249,85,7,220,250,181,2,18,4,29,6,208,6,159,245,143,247,82,247,169,247,102,17,8,249,51,5,136,12,36,11,139,11,154,14,198,250,111,250,42,8,191,249,233,254,254,255,200,2,196,4,156,5,175,246,15,251,181,27,231,249,50,249,21,252,27,1,241,3,51,7,7,8,53,247,129,247,6,9,215,250,72,248,82,7,164,0,221,10,161,10,183,9,215,9,179,251,253,249,217,249,49,250,44,253,231,255,99,1,131,2,243,3,8,247,249,248,153,248,92,249,183,10,100,252,2,255,32,0,224,5,118,7,5,245,130,3,197,246,42,246,152,246,55,249,88,252,221,0,28,10,223,9,25,246,200,246,83,246,187,248,166,248,41,7,3,14,27,5,93,8,226,8,79,254,54,248,100,249,218,250,138,250,162,254,238,5,131,7,67,3,238,4,58,247,55,13,154,9,72,250,174,248,41,252,99,255,19,2,210,5,193,6,71,37,79,249,37,248,33,248,178,248,55,252,222,255,136,4,188,6,127,7,30,246,140,0,125,248,62,249,72,249,163,253,117,2,41,6,206,3,93,5,36,247,210,249,91,252,100,4,168,249,254,253,60,16,138,255,235,5,115,7,37,247,194,253,225,250,70,252,209,255,21,251,15,0,108,1,86,3,241,3,83,247,117,2,226,3,146,249,212,250,27,250,55,9,125,13,113,5,120,7,2,14,18,247,23,246,0,246,145,246,44,249,144,254,21,12,65,11,51,10,4,246,232,10,234,249,93,4,111,249,191,255,220,255,4,2,209,4,234,5,19,2,234,248,230,3,253,248,99,249,153,252,213,2,100,3,224,5,185,5,139,3,44,1,244,247,194,246,168,246,167,248,172,253,218,6,121,8,56,8,61,245,149,10,6,247,189,245,137,246,173,248,35,253,46,15,88,10,5,11,111,2,227,253,93,255,193,254,85,0,84,0,15,0,204,2,255,1,60,2,108,15,213,10,32,250,46,249,216,248,90,252,178,255,220,3,253,4,238,5,138,245,168,8,142,247,229,246,228,247,56,252,117,13,46,4,29,8,158,8,180,244,135,246,142,245,167,244,228,244,232,245,155,250,197,12,136,10,209,12,214,247,143,254,21,250,169,250,56,255,41,8,227,2,188,2,98,3,145,4,28,247,223,251,35,11,29,10,106,249,253,253,191,255,67,2,254,4,57,6,235,244,102,246,251,245,33,245,229,244,92,246,88,249,5,250,195,5,57,16,95,247,191,248,175,248,127,247,246,2,5,250,135,12,139,4,226,5,59,7,177,246,109,249,209,248,140,22,233,248,47,254,105,1,62,4,120,7,92,8,187,245,104,249,72,6,114,247,141,246,240,247,27,251,117,5,51,8,2,9,1,2,128,6,109,249,163,249,110,249,147,255,13,1,183,2,48,4,37,5,208,0,190,249,130,248,242,251,211,252,56,1,24,0,26,0,249,2,222,3,16,247,79,247,100,248,116,248,216,248,75,252,62,254,152,3,37,3,188,5,175,244,183,245,3,246,208,1,130,247,123,251,146,4,182,8,246,9,218,9,173,245,120,248,49,247,238,245,82,0,98,247,193,255,103,10,215,7,244,8,226,0,19,246,129,245,63,245,75,247,236,249,17,3,253,14,27,9,188,9,64,246,52,249,95,246,9,247,153,247,118,4,107,1,127,15,151,7,128,9,197,245,160,246,8,2,30,247,148,248,50,250,87,8,127,5,252,8,240,8,5,245,6,244,200,243,230,243,31,246,61,250,124,8,85,13,29,14,243,13,52,2,213,246,47,247,183,246,104,248,21,249,186,253,253,1,147,6,183,7,227,254,168,247,31,246,96,246,187,247,22,1,70,4,18,4,144,8,184,7,245,6,174,248,6,248,201,247,48,249,236,251,45,13,228,4,69,7,81,7,128,245,199,248,98,246,66,246,199,247,145,248,173,8,250,0,117,6,185,8,95,51,29,249,233,245,42,246,123,247,244,251,231,253,144,255,214,0,78,2,160,253,34,247,76,247,235,250,6,252,103,14,41,254,230,254,141,3,129,6,134,246,177,6,216,252,40,251,170,250,48,252,116,255,194,6,171,2,191,0,85,28,228,247,83,245,118,245,51,247,164,251,120,1,175,2,34,5,252,5,204,252,65,250,212,247,1,248,252,248,189,250,36,253,204,24,225,9,161,5,76,250,203,248,234,251,149,249,150,31,96,252,90,0,148,2,172,1,68,255,92,2,26,248,44,2,112,249,151,249,122,252,66,3,173,3,200,5,114,7,121,246,243,245,237,243,219,244,141,246,186,249,8,9,64,10,99,10,99,10,250,250,31,247,160,246,222,248,139,9,145,250,173,2,30,7,18,7,89,6,55,248,37,253,9,38,60,250,97,251,36,251,34,0,171,255,0,0,201,0,75,16,130,246,203,244,206,244,72,246,126,251,27,251,26,1,155,10,59,14,174,247,38,246,69,243,21,244,95,244,100,247,16,251,79,4,201,27,12,31,9,251,98,249,37,248,242,250,185,249,247,0,209,254,203,2,180,16,116,7,223,246,193,247,72,247,181,247,144,249,234,250,6,30,189,4,214,3,216,3,222,245,177,247,67,248,200,247,155,246,82,248,88,252,161,255,70,1,160,2,41,247,131,252,169,250,8,5,215,250,185,250,199,9,235,2,134,1,9,255,84,247,164,252,57,14,182,14,68,249,49,250,237,253,239,0,134,0,174,255,253,245,255,249,43,15,137,248,195,247,79,249,32,4,214,2,209,3,67,4,174,248,170,250,164,249,61,43,139,249,72,253,118,0,178,255,81,1,29,0,145,9,98,250,167,253,3,250,208,252,238,4,28,2,79,0,52,254,133,250,132,12,130,248,156,248,137,248,68,250,48,252,214,255,225,10,64,4,52,2,20,255,37,247,236,246,174,247,168,248,85,254,254,254,225,253,135,3,22,20,1,249,181,249,207,251,95,11,177,11,241,250,112,254,229,0,192,0,171,255,109,17,81,249,105,250,152,249,197,13,138,250,155,255,37,255,71,1,159,1,99,253,16,250,195,25,245,250,3,20,155,0,32,254,250,253,216,253,134,252,207,245,162,27,148,12,226,251,196,248,115,251,231,255,89,0,151,254,116,255,182,249,166,8,87,11,55,249,88,249,102,251,60,253,85,255,177,0,162,2,205,251,134,252,82,0,207,1,104,250,232,251,65,253,9,253,9,255,88,1,144,9,112,253,145,251,14,17,185,253,63,253,40,0,198,254,92,253,9,251,37,17,72,252,177,12,186,249,12,250,108,251,22,254,97,0,128,0,165,255,190,255,243,250,160,6,166,251,81,250,249,253,60,10,223,1,255,254,24,250,11,248,255,250,216,6,251,250,236,248,229,10,204,255,164,2,153,1,40,1,71,248,237,251,14,1,177,249,83,8,229,251,95,255,14,254,255,2,137,6,20,4,27,0,173,251,62,249,192,248,16,251,237,254,89,255,125,3,187,1,10,15,97,0,36,251,101,249,226,249,192,251,218,251,187,252,97,255,38,7,112,250,190,9,170,248,4,250,57,248,103,11,62,0,143,1,12,2,125,1,196,250,145,246,20,248,218,0,194,250,154,1,47,3,21,2,180,3,206,7,67,251,201,248,107,14,181,247,30,7,244,249,25,2,219,3,100,1,123,0,36,15,84,246,27,248,109,247,230,249,31,253,202,8,197,2,29,3,78,4,17,8,46,247,166,246,232,248,0,250,35,4,45,18,177,5,200,1,229,255,78,247,32,253,253,2,169,248,116,247,255,248,96,252,124,3,1,7,209,8,98,251,146,249,3,249,217,23,112,248,220,16,205,254,113,255,223,0,236,0,91,247,186,248,225,248,254,12,238,248,152,250,59,254,239,3,51,5,125,5,39,16,6,247,135,249,189,7,90,249,171,252,194,254,42,1,248,2,1,4,23,246,34,245,87,244,129,245,233,244,141,17,64,254,153,16,232,11,118,10,21,4,155,12,78,253,146,250,48,252,116,253,75,2,194,0,19,253,178,250,38,253,250,0,156,246,12,246,147,247,253,251,32,0,43,8,35,4,80,5,6,1,169,247,243,247,15,249,178,249,10,255,212,7,45,10,236,5,76,252,220,251,204,251,149,249,20,253,144,0,59,6,194,6,19,2,194,251,122,247,29,254,113,247,149,246,65,248,215,246,67,39,183,252,176,5,156,3,207,0,44,18,217,248,22,248,82,249,69,247,196,15,13,253,186,255,21,2,119,3,149,248,234,246,175,247,189,247,186,249,163,5,253,9,173,3,106,2,15,2,181,3,245,249,237,247,7,249,199,1,196,255,79,0,202,0,144,3,186,3,33,246,215,56,155,248,245,246,207,245,204,248,241,1,31,1,59,255,114,2,183,26,220,252,237,250,21,251,171,251,159,255,208,3,144,0,169,254,161,250,226,246,156,14,231,251,164,11,53,249,38,254,223,0,137,0,155,0,85,255,146,11,22,7,182,246,173,245,55,247,171,251,90,3,131,2,94,6,119,5,206,247,206,3,74,249,111,247,158,247,48,250,25,13,109,255,163,4,242,4,23,6,28,246,131,244,57,245,203,247,182,251,26,6,25,4,253,7,111,8,6,247,15,29,175,247,199,246,242,246,240,249,90,254,226,1,217,3,87,4,162,23,25,22,94,249,37,247,177,247,145,251,116,255,226,254,160,254,132,255,50,251,164,13,166,250,59,251,142,11,41,251,40,254,46,253,87,255,167,255,250,246,172,11,193,246,139,246,227,245,14,248,106,253,165,1,71,7,176,10,204,245,53,21,200,247,47,247,120,246,231,248,211,18,115,3,110,2,124,2,231,43,184,254,37,248,79,249,130,249,246,250,55,251,16,250,251,249,112,252,144,1,177,251,118,245,94,255,7,1,60,252,156,2,149,1,220,2,189,9,69,246,232,3,162,244,231,252,185,250,253,253,27,4,210,7,221,6,102,8,38,248,27,248,50,247,152,248,95,248,152,2,155,27,72,10,19,2,169,250,76,247,65,8,29,248,5,9,78,250,86,254,218,4,82,1,205,0,34,255,219,250,242,248,83,246,133,246,83,246,196,248,64,250,113,252,213,8,40,40,191,246,126,1,108,12,70,251,191,249,20,253,36,253,248,1,160,5,118,4,243,255,98,2,103,246,29,253,218,250,11,252,204,255,42,254,115,2,126,18,224,4,131,11,137,253,24,6,48,8,191,252,107,251,61,250,244,247,115,247,199,3,85,250,248,249,10,253,230,253,225,255,115,5,222,13,253,255,49,248,73,248,58,249,136,245,48,246,11,248,230,250,4,255,8,5,124,23,226,18,193,251,187,12,43,12,167,250,144,251,76,252,248,254,186,253,91,253,125,253,60,246,4,5,195,254,176,248,130,251,130,251,54,1,64,3,61,6,26,11,151,24,222,14,97,253,0,250,76,250,24,251,57,251,32,250,120,249,65,250,78,5,236,3,155,248,90,4,149,249,153,255,255,253,189,0,47,1,140,0,174,249,120,253,48,253,106,28,61,2,76,255,37,253,54,251,228,249,50,249,151,0,55,8,230,249,50,252,94,0,34,2,208,13,51,255,135,249,26,246,117,247,24,11,32,251,195,1,55,10,171,0,223,1,207,254,237,250,84,249,160,247,199,249,247,250,206,10,239,8,112,254,188,0,205,255,141,0,105,0,176,247,112,19,102,249,64,251,105,251,41,1,174,5,193,1,34,254,54,252,134,248,77,250,220,11,108,10,74,252,134,253,5,254,138,254,4,0,34,0,128,249,85,11,79,3,1,11,126,251,141,249,18,251,120,251,144,253,117,2,42,6,253,2,46,248,183,247,9,250,146,7,240,254,113,0,31,1,187,3,63,250,60,0,111,31,137,0,234,253,183,252,203,251,32,250,4,249,34,249,177,248,119,0,163,3,239,6,64,253,232,10,98,1,11,254,166,250,10,248,249,251,161,249,134,248,145,252,121,1,165,29,173,0,60,255,21,254,134,249,206,14,251,252,61,249,212,11,49,0,11,252,205,253,48,251,71,252,38,253,248,245,122,248,89,253,245,254,188,254,62,252,51,0,205,1,168,10,47,14,205,13,102,249,226,244,190,246,103,248,107,252,217,253,20,1,74,10,230,13,224,245,42,249,138,246,206,249,76,251,23,252,251,17,10,7,113,10,149,6,150,10,171,252,239,246,129,248,189,249,156,252,122,14,34,1,58,2,82,1,59,247,88,249,133,248,33,2,237,252,99,6,189,6,14,2,154,2,68,6,130,2,126,251,159,12,48,251,20,249,145,253,217,0,27,0,3,0,129,2,149,246,132,7,57,252,209,249,37,250,12,9,74,5,141,255,77,1,47,2,71,249,171,9,106,248,190,247,84,251,197,253,233,6,46,9,35,5,161,253,158,17,122,250,76,247,224,250,159,5,213,1,8,255,113,254,242,254,47,253,19,250,33,251,253,252,220,255,88,25,174,3,233,254,196,253,239,251,140,248,172,246,23,247,221,245,29,247,7,250,51,0,215,1,83,17,186,11,178,10,209,15,26,6,110,245,120,249,143,249,76,251,250,253,232,254,6,3,64,5,6,0,98,248,15,250,24,249,52,252,140,5,195,11,65,255,132,2,198,5,148,12,199,254,214,11,103,255,183,252,29,253,134,254,11,252,126,250,233,248,200,247,247,251,207,247,56,248,81,252,87,9,168,1,113,1,65,6,3,13,214,5,244,247,21,248,43,6,129,250,96,4,232,254,59,255,249,2,24,4,58,253,254,15,3,250,64,248,172,249,148,251,253,253,27,254,203,3,84,10,139,15,107,253,157,248,160,251,127,252,180,9,87,6,21,0,2,250,122,246,129,12,26,250,90,3,77,250,57,253,204,250,191,252,16,255,251,2,72,4,101,250,227,255,102,12,19,249,237,255,196,2,144,6,147,1,114,252,80,247,146,245,149,253,40,5,17,253,213,250,2,252,59,11,56,4,217,3,1,0,191,0,143,30,37,254,164,253,154,251,57,252,141,251,192,249,25,249,119,251,194,250,88,248,192,247,255,248,196,249,31,12,23,2,209,7,163,12,151,0,38,247,217,252,71,248,131,249,25,251,24,9,72,10,117,12,109,2,150,251,121,247,153,251,87,9,140,252,125,8,78,253,158,254,252,253,96,1,186,3,55,7,182,255,20,251,209,248,253,9,59,251,228,0,138,253,94,255,130,1,182,5,159,248,220,245,88,247,179,248,250,253,1,5,25,9,93,10,93,4,1,250,242,251,40,249,186,248,157,249,213,251,226,3,92,20,159,10,248,254,27,248,32,7,194,247,149,253,2,6,115,254,180,254,103,255,92,3,1,5,168,25,2,249,101,246,85,249,84,249,225,252,38,1,89,0,219,1,224,3,124,249,229,248,38,248,169,249,31,8,183,12,124,254,79,2,197,5,69,2,248,249,220,1,223,248,65,252,240,250,243,251,59,254,122,4,85,18,71,3,235,7,205,11,61,249,46,249,84,248,165,251,173,4,102,0,164,0,94,255,3,247,255,250,26,248,143,15,158,251,231,254,85,0,96,1,18,4,63,6,63,25,163,255,38,248,60,248,22,247,115,247,133,248,71,249,17,0,86,18,168,1,26,252,145,255,53,248,34,251,104,251,78,0,140,255,159,7,243,11,74,248,9,249,61,247,42,251,95,15,96,252,241,255,241,4,0,6,115,7,216,255,230,254,86,5,107,251,100,242,99,1,202,251,216,14,34,17,221,255,160,239,11,2,11,5,166,2,156,0,224,8,237,251,51,4,199,248,198,254,246,253,136,1,50,8,177,255,217,1,237,254,2,0,254,24,195,1,94,0,173,0,81,254,91,4,220,213,35,0,31,7,204,242,159,255,158,255,162,254,233,255,16,251,204,254,244,34,73,253,177,255,192,13,52,1,84,1,150,254,221,253,183,4,98,251,104,215,108,255,252,13,225,1,87,254,94,3,30,19,224,2,104,255,142,253,23,0,35,233,39,0,113,255,162,1,153,255,79,250,230,205,134,255,27,1,31,255,65,41,103,255,168,34,218,252,205,255,93,0,164,1,47,255,89,1,19,226,36,253,208,255,223,1,31,255,20,1,73,52,222,206,96,250,247,254,238,254,81,4,208,242,77,253,189,253,52,252,44,1,93,1,106,1,210,2,40,254,185,0,46,3,14,0,138,18,249,2,176,254,155,6,120,3,123,249,227,182,59,3,211,245,153,3,155,0,68,0,112,0,40,244,225,254,158,1,170,255,194,255,43,255,150,255,39,3,149,253,86,2,78,255,32,12,31,254,239,249,226,4,85,223,82,253,120,218,116,0,209,255,65,1,167,255,171,3,221,255,197,224,81,216,242,253,145,0,107,1,122,8,53,4,57,251,30,253,120,0,104,254,122,254,176,255,108,254,185,249,53,216,224,230,193,3,94,0,77,250,233,1,241,25,116,1,239,3,70,23,190,252,222,0,51,0,26,1,19,252,121,17,119,221,183,255,35,254,211,253,121,0,91,255,85,251,182,1,139,0,66,255,147,239,74,239,247,237,88,226,40,0,90,254,53,254,82,2,163,28,164,0,41,1,71,10,141,220,178,255,116,1,187,231,227,251,182,0,185,255,126,254,164,253,56,210,40,2,151,253,157,1,12,5,4,0,27,254,138,4,163,23,208,235,75,255,0,4,138,253,237,254,29,240,77,222,106,5,202,3,89,254,157,11,56,9,107,1,238,254,154,1,48,0,0,3,142,11,85,254,86,0,64,0,128,255,239,254,74,255,220,254,100,3,207,1,73,0,140,255,147,230,81,235,219,255,179,2,88,1,136,255,168,0,163,1,238,1,105,251,208,73,121,255,136,254,38,255,59,254,108,252,240,251,93,169,178,252,19,252,8,1,159,0,85,2,72,252,199,252,137,1,184,254,154,198,115,1,249,254,228,2,38,0,23,252,9,5,100,253,187,0,101,255,143,0,171,2,221,27,205,253,65,223,221,254,176,0,75,0,101,2,203,228,40,211,68], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+368657);
/* memory initializer */ allocate([1,22,254,74,2,160,1,250,2,145,22,64,0,209,255,228,239,84,251,143,255,189,2,45,255,31,9,130,0,172,2,110,28,98,255,43,255,41,1,93,42,97,250,47,254,17,0,232,252,99,25,53,216,68,254,120,250,226,1,124,2,192,5,240,2,157,0,178,254,98,243,237,255,165,229,148,2,246,243,217,15,145,26,237,255,123,2,19,0,79,38,14,2,126,0,188,1,66,255,94,254,126,151,54,255,243,0,85,2,10,0,89,1,46,3,182,254,160,0,88,1,146,15,214,1,203,1,83,9,219,253,113,46,211,248,226,255,48,10,103,2,253,8,253,252,203,249,233,228,41,5,191,16,39,1,210,253,33,250,157,253,56,8,155,1,38,255,121,4,86,254,58,0,154,255,13,0,75,29,220,1,64,240,67,247,158,245,105,248,148,20,15,4,133,1,179,27,234,255,156,0,70,255,128,9,146,252,49,1,66,249,137,12,105,1,250,251,249,1,106,2,250,254,171,248,12,1,245,2,24,0,242,94,102,0,205,3,142,0,71,252,81,251,116,0,1,255,250,20,165,254,147,254,169,3,229,228,91,251,8,253,19,2,33,249,63,253,211,253,148,253,127,4,250,0,125,84,4,250,128,255,141,5,45,255,80,2,6,20,197,0,52,253,89,4,212,22,246,254,244,255,211,252,85,0,226,3,198,247,181,240,122,5,21,2,9,2,141,252,87,0,126,254,254,255,2,239,78,77,76,255,149,254,60,0,101,0,75,249,119,0,131,254,100,0,203,253,192,12,236,11,200,0,105,227,26,0,91,1,30,254,113,41,2,253,14,2,145,253,167,13,83,1,202,238,197,255,43,255,174,2,165,253,133,0,99,0,48,0,180,6,66,251,117,5,164,246,128,254,123,252,90,241,108,253,38,239,57,1,192,0,36,1,3,1,124,253,176,0,51,8,25,31,227,255,130,2,102,244,0,7,195,255,4,239,66,2,75,7,180,248,32,0,142,20,137,0,221,23,187,1,80,255,95,1,144,1,82,7,81,255,31,240,185,2,36,1,24,253,121,0,242,235,84,27,58,255,116,2,49,4,169,253,140,255,20,186,135,2,231,251,105,253,147,5,162,255,209,2,55,1,81,1,96,5,32,245,107,15,62,5,41,6,106,254,252,254,12,216,109,0,54,9,133,9,90,1,237,4,204,254,210,247,146,6,144,0,93,253,183,0,172,1,74,252,225,4,246,249,33,0,2,255,169,2,16,251,60,252,202,254,70,3,100,0,64,170,52,250,228,249,83,1,42,1,67,0,174,254,89,0,197,2,53,0,2,1,153,254,243,10,17,6,200,254,199,224,165,249,165,4,220,1,133,255,80,1,1,253,166,183,77,2,174,3,123,253,131,254,135,248,186,253,55,0,148,252,3,254,55,98,178,2,237,252,144,251,114,0,162,0,86,1,25,255,218,221,99,0,122,253,38,254,152,250,146,255,158,255,186,33,242,255,52,218,200,254,102,1,240,1,92,253,159,255,112,7,180,247,190,255,180,248,246,1,255,253,84,243,31,8,60,250,64,21,216,255,131,254,244,1,18,255,41,254,128,47,248,0,19,252,186,244,173,0,215,242,157,254,0,255,139,255,38,254,254,250,157,254,130,0,31,237,31,0,24,255,125,205,198,252,66,1,71,3,1,6,73,0,226,0,160,248,29,254,224,244,66,255,247,4,13,14,94,238,218,255,205,23,91,1,188,255,97,254,151,255,128,249,59,211,146,255,113,254,133,1,1,254,167,3,88,254,84,249,254,251,199,90,42,1,195,28,10,220,202,253,3,1,100,254,67,251,79,1,102,2,160,3,204,3,129,248,105,254,253,1,47,1,62,202,244,253,120,40,38,5,58,245,46,9,150,255,137,255,188,255,245,231,1,255,64,254,222,255,192,255,226,238,47,0,123,2,173,254,150,1,65,254,67,254,160,214,233,0,160,0,117,234,203,250,99,26,72,252,172,0,20,251,218,254,152,13,160,254,25,255,159,1,226,1,14,254,65,255,14,248,254,30,61,31,80,253,225,218,120,1,28,255,12,254,222,0,3,252,105,254,5,1,179,0,110,2,193,4,69,254,5,253,4,254,49,253,99,238,91,0,193,1,229,254,91,0,217,255,193,3,92,216,60,6,55,220,185,254,221,0,42,254,164,2,12,0,136,5,216,3,20,213,132,234,67,255,41,253,226,0,83,18,176,2,247,2,162,3,212,230,142,255,229,253,242,253,235,255,62,251,138,2,200,23,163,1,41,24,80,251,84,0,48,251,222,255,149,255,60,0,200,8,194,1,163,4,240,4,75,255,89,3,187,8,213,244,85,203,64,255,182,253,49,255,63,234,247,1,48,13,219,4,68,253,71,8,118,247,216,254,128,3,43,1,177,0,184,0,95,5,194,9,161,0,67,2,157,241,187,1,235,255,70,255,110,242,238,0,18,1,21,1,187,254,123,223,33,255,125,0,191,0,77,1,167,254,145,250,52,227,125,44,225,251,226,15,182,251,87,0,53,255,187,1,107,1,65,252,35,60,176,15,2,255,75,6,88,255,210,251,149,10,0,253,250,1,35,251,189,22,195,9,28,6,27,0,85,0,197,7,188,251,150,0,52,252,148,2,223,255,175,2,33,2,228,249,208,2,60,255,204,255,41,249,220,156,34,251,153,253,135,1,0,254,7,165,204,1,104,1,171,255,45,253,6,255,93,255,208,255,103,252,108,240,169,1,12,251,97,249,161,12,187,251,114,251,198,0,178,29,21,0,98,1,221,2,181,47,165,254,20,2,85,254,22,0,170,8,190,253,202,242,38,254,143,253,78,0,62,238,95,3,203,255,155,254,7,250,246,3,198,2,76,5,82,254,159,249,9,159,95,0,26,0,78,2,177,253,103,225,181,250,213,217,10,254,117,252,183,195,189,3,207,1,35,0,16,254,38,1,81,8,250,4,96,255,173,255,19,2,1,253,29,1,232,0,95,23,22,232,84,6,16,16,17,255,59,249,210,255,215,250,211,1,101,2,93,241,20,247,167,54,117,1,51,188,37,255,176,255,46,255,182,5,37,0,100,249,36,2,43,233,164,1,54,0,162,254,227,254,189,7,6,1,150,252,28,11,77,254,95,231,49,25,72,0,119,2,162,255,96,0,70,254,113,4,89,0,108,1,64,13,72,242,125,254,31,4,62,1,169,251,197,228,88,1,111,220,160,255,110,219,190,0,31,255,114,1,161,0,183,255,218,248,174,0,48,0,250,253,98,242,137,0,21,255,42,3,23,0,80,0,126,253,221,255,196,254,243,254,139,254,147,246,91,252,221,9,11,1,4,254,56,255,166,1,114,242,7,251,128,2,92,248,139,0,138,1,237,251,0,213,98,255,191,251,25,248,202,0,45,252,24,253,97,255,120,254,219,255,113,249,135,8,85,5,189,244,112,237,49,247,109,0,124,6,155,253,1,254,4,5,93,227,179,3,97,27,232,247,191,254,88,252,217,253,149,252,160,0,109,150,142,2,9,1,164,0,120,1,214,2,107,255,253,10,162,255,96,22,190,2,162,251,5,246,217,0,70,255,149,255,146,0,173,255,194,255,60,255,196,2,146,0,145,14,96,254,212,0,93,255,75,225,91,1,83,0,201,251,30,252,15,1,226,251,145,249,139,0,236,255,98,1,18,5,164,242,106,4,161,0,219,1,183,240,212,1,23,0,29,1,93,249,42,32,77,252,222,0,4,1,180,16,171,254,243,24,21,0,234,1,140,248,138,249,196,255,167,9,221,2,121,255,109,0,144,251,92,198,58,19,141,4,149,0,120,240,190,255,174,253,37,24,146,255,36,1,105,4,177,253,127,217,189,61,49,153,106,62,32,210,207,62,65,241,19,63,163,146,58,63,78,209,97,63,91,211,132,63,18,131,152,63,65,241,171,63,231,29,191,63,72,225,210,63,91,66,230,63,169,19,248,63,191,125,5,64,186,218,14,64,147,24,24,64,97,50,33,64,193,202,41,64,43,135,50,64,152,221,59,64,202,84,193,61,58,35,74,62,136,244,155,62,87,91,241,62,209,145,28,63,34,108,72,63,89,23,103,63,205,204,132,63,87,236,151,63,122,165,172,63,247,117,192,63,251,203,214,63,204,238,233,63,75,200,255,63,11,70,9,64,5,197,19,64,129,4,29,64,138,31,39,64,214,86,48,64,46,255,57,64,215,52,239,61,197,143,145,62,8,61,251,62,113,172,43,63,41,92,79,63,64,19,113,63,110,163,137,63,122,199,153,63,50,85,168,63,126,140,185,63,76,166,202,63,130,115,222,63,27,158,238,63,213,120,1,64,39,194,10,64,205,204,20,64,41,237,29,64,229,242,39,64,30,167,48,64,188,5,58,64,21,140,10,62,160,26,111,62,68,139,172,62,137,65,224,62,102,247,20,63,159,60,60,63,68,250,93,63,74,12,130,63,53,94,146,63,9,27,166,63,63,53,190,63,91,66,214,63,113,172,235,63,224,45,0,64,57,214,9,64,93,254,19,64,168,87,30,64,11,36,40,64,26,81,50,64,200,7,61,64,22,106,205,61,65,241,99,62,52,128,183,62,228,131,254,62,179,12,33,63,66,96,69,63,81,107,106,63,46,144,136,63,47,110,155,63,32,99,174,63,202,84,193,63,77,132,213,63,204,127,232,63,2,188,253,63,238,235,8,64,140,185,19,64,204,238,29,64,192,91,40,64,27,158,50,64,120,11,60,64,208,68,216,61,151,144,79,62,226,88,151,62,86,14,205,62,6,129,5,63,140,185,43,63,131,192,90,63,45,33,135,63,210,0,158,63,145,126,179,63,30,167,200,63,141,40,221,63,14,190,240,63,59,112,2,64,125,208,11,64,61,155,21,64,220,70,31,64,20,208,40,64,81,107,50,64,91,211,60,64,59,223,207,61,218,27,124,62,225,11,211,62,120,11,20,63,48,42,57,63,243,31,98,63,91,211,132,63,192,91,152,63,202,195,170,63,111,129,188,63,0,145,206,63,179,12,225,63,215,18,242,63,53,94,2,64,235,226,10,64,0,0,20,64,205,204,28,64,59,112,38,64,120,11,48,64,147,169,58,64,34,253,54,62,107,154,119,62,2,43,167,62,208,179,9,63,231,140,40,63,52,162,68,63,29,90,116,63,164,112,141,63,51,51,155,63,141,40,173,63,102,247,188,63,242,210,213,63,11,36,232,63,159,205,250,63,139,253,5,64,0,111,17,64,33,31,28,64,177,225,37,64,108,9,45,64,22,251,55,64,87,236,175,61,10,215,35,62,117,147,152,62,209,145,252,62,232,106,43,63,147,24,84,63,192,236,126,63,168,198,147,63,5,197,167,63,202,195,186,63,244,108,206,63,19,242,225,63,200,7,245,63,29,90,4,64,247,228,13,64,177,80,23,64,4,231,32,64,118,79,42,64,126,29,52,64,188,5,62,64,53,94,186,61,98,16,88,62,159,60,172,62,197,143,241,62,226,233,21,63,44,212,58,63,147,24,100,63,70,148,134,63,71,114,153,63,187,184,173,63,69,71,194,63,32,210,215,63,216,129,235,63,52,162,0,64,86,125,10,64,215,163,20,64,185,141,30,64,84,116,40,64,189,82,50,64,159,60,60,64,56,248,66,62,24,38,147,62,154,119,188,62,247,6,255,62,229,242,31,63,94,186,73,63,99,127,105,63,154,153,137,63,207,247,155,63,85,193,176,63,239,201,195,63,138,176,217,63,68,250,237,63,12,2,3,64,66,62,12,64,205,204,20,64,238,235,28,64,48,76,38,64,68,105,47,64,72,191,57,64,54,205,187,61,42,169,83,62,249,49,166,62,210,0,254,62,55,137,33,63,22,106,77,63,224,156,113,63,4,231,140,63,205,59,158,63,78,209,177,63,168,53,197,63,188,5,218,63,152,221,235,63,241,99,0,64,83,150,9,64,229,242,19,64,184,30,29,64,60,189,38,64,190,193,47,64,29,201,57,64,21,140,202,61,46,144,96,62,165,78,192,62,250,126,10,63,229,97,49,63,134,56,86,63,213,231,122,63,0,0,144,63,254,67,162,63,34,142,181,63,101,170,200,63,109,86,221,63,137,65,240,63,139,253,1,64,9,138,11,64,141,40,21,64,77,243,30,64,209,145,40,64,208,213,50,64,21,29,61,64,50,85,176,61,148,246,70,62,182,132,156,62,190,48,249,62,0,145,30,63,238,90,66,63,67,28,107,63,50,119,141,63,32,210,159,63,234,4,180,63,146,203,199,63,43,24,221,63,254,101,239,63,198,220,1,64,88,202,10,64,215,163,20,64,132,158,29,64,209,34,39,64,125,208,47,64,203,161,57,64,164,223,190,61,98,16,88,62,155,85,191,62,45,67,12,63,162,69,54,63,90,100,91,63,41,92,127,63,142,117,145,63,74,123,163,63,25,4,182,63,103,213,199,63,60,189,218,63,227,165,235,63,29,201,253,63,77,21,8,64,48,76,18,64,160,137,28,64,52,128,39,64,220,215,49,64,197,32,60,64,143,83,244,61,233,183,111,62,170,96,180,62,14,190,0,63,134,201,36,63,190,193,71,63,146,203,111,63,189,227,140,63,27,158,158,63,240,133,177,63,164,112,197,63,26,192,219,63,167,121,239,63,83,150,1,64,58,35,10,64,164,223,18,64,58,146,27,64,103,68,37,64,211,77,46,64,78,209,57,64,159,205,170,61,58,146,75,62,79,30,182,62,125,174,6,63,54,60,45,63,48,187,87,63,7,95,128,63,219,138,149,63,153,42,168,63,19,242,185,63,136,99,205,63,249,15,225,63,63,87,243,63,14,79,3,64,214,86,12,64,165,189,21,64,56,248,30,64,45,67,40,64,2,188,49,64,162,180,59,64,55,26,192,61,186,107,73,62,111,129,164,62,41,92,239,62,63,87,27,63,202,50,68,63,206,25,113,63,4,86,142,63,176,114,160,63,97,84,178,63,67,28,195,63,132,13,215,63,44,212,234,63,231,29,255,63,112,206,8,64,139,108,19,64,159,171,29,64,43,246,39,64,9,27,50,64,114,249,59,64,23,72,208,61,147,169,130,62,219,138,221,62,3,9,26,63,187,39,63,63,5,52,97,63,217,61,129,63,37,117,146,63,110,163,161,63,195,211,179,63,192,236,198,63,131,192,218,63,1,77,236,63,5,197,255,63,170,130,9,64,183,98,19,64,25,226,28,64,72,225,38,64,2,154,48,64,7,240,58,64,24,38,211,61,12,2,107,62,174,216,191,62,138,31,3,63,140,219,40,63,209,34,75,63,100,59,111,63,164,112,141,63,228,131,158,63,180,89,173,63,193,168,188,63,114,138,206,63,84,82,223,63,101,25,242,63,17,199,2,64,45,67,12,64,202,195,22,64,206,136,34,64,74,123,47,64,153,42,60,64,205,59,206,61,252,24,115,62,63,53,190,62,198,109,4,63,6,129,37,63,0,145,78,63,138,142,116,63,240,167,142,63,5,52,161,63,200,7,181,63,201,229,199,63,140,185,219,63,230,63,236,63,169,19,0,64,87,91,9,64,97,84,18,64,79,64,27,64,242,210,37,64,73,46,47,64,23,183,57,64,120,122,165,61,14,190,48,62,106,222,145,62,67,28,235,62,237,158,28,63,108,9,73,63,235,115,117,63,169,19,144,63,122,54,163,63,181,55,184,63,145,126,203,63,224,45,224,63,213,231,242,63,172,139,3,64,149,101,12,64,182,243,21,64,28,235,30,64,93,254,39,64,122,165,48,64,141,151,58,64,213,231,42,62,239,201,131,62,255,33,189,62,0,145,14,63,136,99,45,63,146,92,78,63,74,12,130,63,109,86,149,63,140,185,163,63,140,185,179,63,29,201,197,63,230,63,220,63,113,27,237,63,66,62,0,64,179,12,9,64,251,92,21,64,124,97,30,64,161,103,39,64,60,189,46,64,144,160,56,64,156,162,35,62,64,19,129,62,50,230,174,62,125,208,3,63,200,152,43,63,35,74,75,63,69,216,112,63,50,230,142,63,78,209,153,63,129,38,170,63,137,210,190,63,137,210,214,63,163,1,236,63,203,16,255,63,134,90,7,64,103,68,17,64,186,73,28,64,156,162,39,64,253,135,48,64,91,66,58,64,199,186,184,61,21,140,74,62,2,43,167,62,195,100,234,62,16,122,22,63,59,112,62,63,76,55,105,63,200,152,139,63,128,183,160,63,205,204,180,63,112,206,200,63,66,96,221,63,222,2,241,63,83,5,3,64,212,43,13,64,5,163,22,64,225,122,32,64,62,232,41,64,58,146,51,64,15,11,61,64,194,134,167,61,104,145,45,62,132,13,143,62,47,221,228,62,204,93,27,63,15,156,67,63,173,105,110,63,218,27,140,63,93,220,158,63,33,31,180,63,39,49,200,63,22,251,219,63,153,187,238,63,39,160,1,64,225,11,11,64,200,7,21,64,27,158,30,64,159,60,40,64,154,153,49,64,5,197,59,64,131,192,74,62,247,117,160,62,106,222,209,62,82,184,254,62,107,43,38,63,244,108,86,63,138,176,113,63,125,208,131,63,219,249,150,63,28,124,177,63,3,9,202,63,116,70,220,63,82,39,232,63,54,171,246,63,240,133,5,64,131,192,18,64,237,13,30,64,222,147,39,64,138,142,48,64,215,52,59,64,222,2,9,62,233,183,111,62,70,148,182,62,61,155,245,62,4,231,28,63,74,12,66,63,227,199,104,63,233,72,134,63,247,117,152,63,10,104,170,63,253,246,189,63,8,61,211,63,23,217,230,63,207,247,251,63,29,56,7,64,217,61,17,64,249,49,26,64,193,168,36,64,79,30,46,64,197,143,57,64,201,229,191,61,23,72,80,62,133,124,176,62,183,209,0,63,111,18,35,63,237,158,76,63,135,167,119,63,53,239,144,63,88,57,164,63,72,191,181,63,48,76,198,63,94,186,217,63,102,247,236,63,138,142,0,64,133,235,9,64,158,239,19,64,23,183,29,64,179,234,39,64,46,255,49,64,218,27,60,64,63,53,222,61,100,93,92,62,27,13,160,62,204,238,233,62,124,97,18,63,30,167,56,63,42,58,98,63,48,187,135,63,69,71,154,63,98,16,176,63,228,20,197,63,224,156,217,63,156,162,235,63,230,63,0,64,83,150,9,64,70,182,19,64,37,6,29,64,159,205,38,64,49,8,48,64,211,77,58,64,249,49,102,61,243,142,83,62,114,138,206,62,68,139,12,63,40,15,43,63,186,218,74,63,111,18,115,63,113,61,138,63,87,236,151,63,149,101,168,63,13,224,189,63,36,185,212,63,58,146,235,63,11,70,1,64,88,168,9,64,203,161,17,64,145,15,26,64,70,182,35,64,85,193,44,64,15,11,57,64,165,78,192,61,195,211,107,62,36,151,191,62,240,167,6,63,21,140,42,63,143,83,84,63,30,22,122,63,254,212,144,63,211,188,163,63,141,40,181,63,175,148,197,63,214,197,213,63,233,38,233,63,219,249,254,63,78,98,8,64,100,59,19,64,129,4,29,64,200,7,37,64,9,27,46,64,3,9,58,64,242,210,205,61,145,15,122,62,222,147,199,62,85,48,10,63,243,31,50,63,53,239,88,63,55,26,128,63,179,234,147,63,240,167,166,63,108,9,185,63,17,54,204,63,178,157,223,63,156,51,242,63,51,51,3,64,238,235,12,64,75,89,22,64,97,195,31,64,108,9,41,64,250,126,50,64,165,78,60,64,60,78,209,61,114,249,79,62,111,129,164,62,229,97,225,62,165,78,16,63,249,49,54,63,95,7,94,63,252,24,131,63,9,27,150,63,108,9,169,63,95,7,190,63,131,192,210,63,141,151,230,63,129,149,251,63,38,228,7,64,32,99,18,64,209,145,28,64,164,223,38,64,27,47,49,64,181,55,60,64,150,67,75,62,225,11,179,62,122,165,236,62,163,35,25,63,233,183,63,63,27,13,96,63,123,20,126,63,191,125,149,63,30,22,170,63,241,244,186,63,250,126,202,63,201,229,223,63,156,51,242,63,57,69,3,64,90,100,11,64,83,150,21,64,201,118,30,64,38,228,39,64,75,200,47,64,142,117,57,64,74,123,3,62,163,35,121,62,35,219,185,62,34,108,248,62,95,152,28,63,219,249,62,63,65,241,99,63,166,155,132,63,20,63,150,63,181,55,168,63,218,27,188,63,2,43,207,63,159,205,226,63,57,69,247,63,129,38,6,64,196,66,17,64,17,54,28,64,196,177,38,64,141,40,49,64,133,124,60,64,207,102,213,61,30,22,106,62,181,55,184,62,110,163,1,63,20,208,36,63,227,54,74,63,41,92,111,63,161,103,139,63,2,188,157,63,199,186,176,63,72,225,194,63,146,92,214,63,192,91,232,63,97,195,251,63,248,83,7,64,243,31,18,64,29,90,28,64,170,241,38,64,83,150,49,64,125,208,59,64,119,190,159,61,160,137,48,62,35,219,121,62,5,163,178,62,2,43,7,63,9,27,62,63,251,92,109,63,255,178,139,63,41,203,160,63,61,155,181,63,140,74,202,63,173,105,222,63,3,9,242,63,247,6,3,64,84,116,12,64,243,31,22,64,20,174,31,64,21,29,41,64,245,185,50,64,21,29,61,64,247,228,225,61,148,135,133,62,32,65,209,62,214,197,13,63,147,58,49,63,52,128,87,63,201,118,126,63,35,74,147,63,251,92,165,63,149,101,184,63,254,67,202,63,31,244,220,63,0,145,238,63,68,139,0,64,145,15,10,64,61,10,19,64,162,180,27,64,219,138,37,64,100,59,47,64,233,72,58,64,20,208,4,62,110,163,129,62,31,244,204,62,34,108,8,63,100,93,44,63,31,133,75,63,193,168,116,63,197,254,138,63,166,155,156,63,82,73,173,63,62,121,192,63,122,199,209,63,111,240,229,63,23,217,246,63,72,191,5,64,45,67,16,64,18,20,27,64,231,140,36,64,0,0,44,64,196,66,57,64,124,97,178,61,240,133,73,62,41,92,175,62,136,99,253,62,84,116,36,63,26,192,75,63,6,18,116,63,86,125,142,63,46,255,161,63,150,33,182,63,74,12,202,63,157,17,221,63,48,187,239,63,162,69,2,64,134,201,12,64,251,203,22,64,102,247,32,64,169,164,42,64,197,32,52,64,129,4,61,64,24,149,212,61,138,176,97,62,48,76,166,62,122,199,233,62,66,62,24,63,114,138,62,63,197,143,97,63,232,217,132,63,46,255,153,63,23,72,176,63,6,129,197,63,17,199,218,63,102,102,238,63,145,15,2,64,131,47,12,64,106,222,21,64,119,190,31,64,202,84,41,64,203,16,51,64,57,180,60,64,240,22,8,62,50,119,141,62,177,225,201,62,97,195,3,63,11,181,38,63,27,158,78,63,96,229,112,63,79,64,139,63,22,106,157,63,174,71,177,63,15,156,195,63,93,109,213,63,82,39,232,63,16,233,255,63,2,154,8,64,246,151,17,64,171,62,27,64,240,133,37,64,139,108,47,64,17,199,58,64,25,115,215,61,63,87,91,62,52,128,183,62,69,216,0,63,216,129,35,63,75,200,71,63,141,151,110,63,231,251,137,63,54,205,155,63,224,45,176,63,136,99,197,63,82,39,216,63,126,140,233,63,198,220,253,63,207,247,7,64,155,230,17,64,231,29,27,64,80,252,36,64,222,113,46,64,134,56,58,64,64,164,223,61,222,2,137,62,105,111,208,62,135,22,9,63,136,133,42,63,105,111,80,63,48,76,118,63,176,3,143,63,110,163,161,63,104,145,181,63,167,232,200,63,127,106,220,63,25,4,238,63,163,35,1,64,12,2,11,64,73,157,20,64,249,49,30,64,191,14,40,64,143,194,49,64,211,188,59,64,91,66,190,61,114,138,78,62,109,86,157,62,231,251,233,62,10,215,19,63,188,116,67,63,237,13,110,63,76,166,138,63,13,224,157,63,53,94,178,63,66,96,197,63,154,8,219,63,194,23,238,63,68,250,1,64,160,26,11,64,8,172,20,64,64,19,29,64,27,158,38,64,167,121,47,64,240,133,57,64,82,184,158,61,223,79,77,62,33,176,178,62,184,30,5,63,36,185,44,63,212,154,86,63,86,14,125,63,20,63,150,63,110,52,168,63,134,56,182,63,232,106,203,63,224,190,222,63,154,119,236,63,16,88,1,64,249,49,10,64,213,120,17,64,160,26,27,64,152,221,35,64,132,158,45,64,203,161,57,64,101,25,226,61,104,179,106,62,113,172,171,62,69,71,242,62,191,125,29,63,225,122,68,63,49,153,106,63,15,156,139,63,5,52,161,63,234,4,180,63,88,202,194,63,184,64,210,63,98,161,230,63,144,49,255,63,128,183,8,64,77,243,18,64,124,242,28,64,99,238,38,64,36,185,48,64,143,228,58,64,48,42,169,61,205,204,76,62,196,66,173,62,184,175,3,63,204,93,43,63,130,115,86,63,8,172,124,63,104,179,146,63,143,194,165,63,55,137,185,63,95,41,203,63,185,141,222,63,231,140,240,63,9,27,2,64,247,6,11,64,250,237,19,64,137,65,28,64,171,207,37,64,203,16,47,64,122,199,57,64,208,179,217,61,66,62,104,62,251,58,176,62,152,110,242,62,209,145,28,63,224,45,64,63,231,29,103,63,149,212,137,63,132,13,159,63,152,221,179,63,171,62,199,63,193,202,217,63,170,130,233,63,150,178,252,63,153,42,8,64,215,18,18,64,220,70,27,64,101,25,38,64,20,208,48,64,188,116,59,64,31,133,235,61,169,19,144,62,2,154,232,62,49,8,28,63,177,191,60,63,136,244,91,63,18,165,125,63,178,46,142,63,111,240,157,63,182,243,173,63,91,66,190,63,77,243,206,63,27,158,222,63,142,6,240,63,87,91,1,64,159,205,10,64,234,4,20,64,95,41,31,64,238,235,44,64,45,33,59,64,129,38,194,61,170,96,84,62,5,197,175,62,228,20,253,62,37,117,34,63,70,182,67,63,170,130,97,63,217,206,135,63,148,135,157,63,52,162,172,63,129,149,187,63,73,46,207,63,105,111,224,63,44,101,241,63,67,28,3,64,123,20,14,64,68,139,24,64,233,183,35,64,127,106,48,64,20,208,60,64,99,127,217,61,11,70,101,62,209,145,188,62,15,11,5,63,86,159,43,63,170,130,81,63,208,213,118,63,244,108,142,63,128,183,160,63,143,228,178,63,27,47,197,63,254,212,216,63,51,51,235,63,0,145,254,63,20,208,8,64,111,18,19,64,233,38,29,64,222,147,39,64,205,59,50,64,40,126,60,64,198,220,181,61,223,79,77,62,51,196,145,62,82,73,221,62,102,136,19,63,161,248,65,63,113,27,109,63,25,4,142,63,159,205,162,63,210,111,183,63,88,202,202,63,183,98,223,63,76,55,241,63,201,118,2,64,80,141,11,64,115,104,21,64,102,102,30,64,239,201,39,64,29,90,48,64,230,174,57,64,68,105,47,62,139,253,133,62,166,10,198,62,139,253,21,63,157,17,53,63,250,126,90,63,36,151,135,63,39,194,150,63,146,203,167,63,208,179,185,63,227,165,203,63,194,134,223,63,145,15,242,63,153,42,4,64,37,6,13,64,213,120,21,64,42,169,31,64,76,55,41,64,123,131,47,64,54,60,57,64,149,212,9,62,65,130,130,62,87,91,209,62,40,126,12,63,247,228,49,63,235,226,86,63,209,34,123,63,240,167,142,63,192,91,160,63,97,195,179,63,22,106,197,63,43,246,215,63,62,232,233,63,40,126,252,63,173,250,8,64,68,250,17,64,81,107,26,64,15,156,35,64,169,19,44,64,145,237,56,64,192,236,158,61,139,253,37,62,174,182,130,62,70,148,214,62,245,74,25,63,17,199,74,63,203,16,119,63,174,71,145,63,6,129,165,63,174,71,185,63,216,240,204,63,135,22,225,63,6,18,244,63,77,21,4,64,235,115,13,64,105,0,23,64,73,157,32,64,79,30,42,64,103,213,51,64,29,201,61,64,124,242,176,61,52,17,54,62,243,31,146,62,254,212,216,62,114,138,14,63,254,212,56,63,235,115,101,63,146,203,135,63,170,96,156,63,37,6,177,63,207,102,197,63,149,212,217,63,235,115,237,63,131,81,1,64,68,105,11,64,152,76,21,64,95,41,31,64,14,190,40,64,11,181,50,64,179,12,61,64,140,74,234,61,38,228,131,62,189,82,214,62,215,52,15,63,0,0,48,63,37,117,82,63,116,181,117,63,77,21,140,63,43,24,157,63,194,134,175,63,19,242,193,63,161,214,212,63,199,75,231,63,133,235,249,63,14,45,6,64,88,57,16,64,222,113,26,64,215,163,36,64,102,102,46,64,92,143,58,64,173,250,220,61,47,110,99,62,104,179,170,62,98,16,248,62,140,185,27,63,220,104,64,63,93,220,102,63,107,154,135,63,53,94,154,63,176,3,175,63,174,182,194,63,98,16,216,63,249,15,233,63,57,214,253,63,33,31,8,64,27,158,18,64,65,241,27,64,163,146,38,64,56,248,46,64,21,29,57,64,58,146,203,61,193,168,100,62,145,15,186,62,70,182,3,63,11,36,40,63,82,39,80,63,99,127,121,63,188,150,144,63,243,31,162,63,79,175,180,63,12,147,201,63,173,250,220,63,11,181,238,63,136,99,1,64,127,251,10,64,64,19,21,64,41,92,31,64,223,79,41,64,3,9,50,64,179,234,59,64,66,96,229,61,189,227,84,62,82,39,160,62,24,38,211,62,25,115,7,63,86,125,46,63,108,9,89,63,133,235,129,63,125,174,150,63,159,60,172,63,147,169,194,63,240,22,216,63,45,67,236,63,204,127,0,64,173,105,10,64,154,119,20,64,140,74,30,64,163,1,40,64,247,228,49,64,199,186,60,64,196,177,174,61,59,223,79,62,81,218,187,62,121,88,8,63,241,244,42,63,105,0,79,63,152,221,115,63,27,158,142,63,30,167,160,63,239,56,181,63,25,226,200,63,206,136,218,63,179,234,235,63,22,251,251,63,19,97,7,64,215,52,15,64,36,151,23,64,75,200,35,64,23,217,46,64,254,67,58,64,16,88,185,61,100,204,93,62,97,50,181,62,70,37,5,63,31,133,43,63,88,168,85,63,59,1,125,63,76,166,146,63,60,189,162,63,76,55,177,63,156,51,194,63,61,155,213,63,157,128,230,63,74,12,250,63,136,133,6,64,202,84,17,64,201,118,26,64,205,59,38,64,16,233,47,64,171,207,57,64,39,160,9,60,190,48,25,61,75,89,134,60,218,172,122,188,250,237,235,60,14,79,47,60,96,229,208,188,20,63,198,188,0,0,0,0,88,57,180,187,221,181,4,188,143,194,245,187,224,45,16,187,195,100,170,187,101,25,226,187,137,210,222,186,82,73,157,57,43,24,21,60,52,128,55,59,124,242,48,187,150,67,11,60,4,231,140,59,18,131,192,188,121,88,40,189,120,122,165,60,225,11,19,61,117,2,26,61,74,123,3,61,218,172,250,60,5,163,18,189,101,25,226,188,188,116,19,188,23,183,81,59,82,73,157,59,255,33,253,60,185,252,7,61,30,167,232,60,129,38,194,60,231,29,167,59,120,122,37,188,164,223,190,188,14,79,47,189,178,157,111,189,228,131,30,189,36,151,127,59,221,181,4,60,237,13,62,59,137,210,222,186,82,73,29,186,137,210,222,187,224,45,144,59,43,24,149,60,117,2,26,61,228,131,30,61,112,206,8,189,100,93,220,188,43,24,149,188,101,25,226,187,195,100,42,187,66,96,101,59,46,144,160,187,159,171,173,188,231,29,39,189,57,180,200,188,7,95,152,60,44,212,154,60,218,172,122,60,166,155,68,60,73,157,128,60,88,57,180,59,153,187,150,187,5,163,146,60,30,167,232,60,23,183,81,187,171,207,213,188,158,239,167,188,36,151,127,187,114,138,142,60,216,240,244,60,12,147,169,60,82,73,157,58,52,128,183,187,111,18,131,58,176,3,103,60,56,248,66,188,227,165,155,60,37,6,1,61,208,68,88,59,23,183,81,188,143,194,245,60,75,89,6,61,72,80,252,60,188,150,16,61,62,232,217,60,208,68,216,59,75,89,6,189,64,164,223,188,124,242,176,59,104,145,109,60,41,92,143,60,166,155,196,58,77,21,140,188,95,41,203,59,75,89,134,188,188,116,147,59,30,167,232,187,10,215,35,59,211,188,227,60,103,213,231,60,91,177,63,60,195,100,42,187,213,120,233,188,231,29,39,189,226,233,21,189,202,84,193,187,195,100,170,188,151,255,16,189,112,206,8,189,25,115,215,188,23,183,209,187,250,237,235,59,82,73,29,186,18,131,192,188,179,123,114,187,145,126,251,188,69,216,240,188,148,135,133,188,229,97,161,188,18,131,192,188,82,73,157,60,195,100,170,58,161,103,179,188,240,133,73,188,23,183,209,185,221,181,4,188,82,73,29,188,240,133,73,188,120,122,37,188,39,160,9,59,254,101,119,60,159,171,45,60,254,101,119,60,215,52,239,60,208,68,88,59,103,213,231,60,95,41,75,60,237,13,190,59,137,210,222,186,108,9,121,187,108,9,121,60,176,3,103,60,208,68,88,60,78,209,145,60,73,157,128,60,215,52,239,59,224,45,144,60,176,3,103,60,192,236,30,60,153,187,22,188,148,135,133,188,127,106,188,188,172,139,91,188,156,51,34,188,69,216,112,188,111,18,131,59,226,233,149,188,41,92,143,188,111,18,3,188,185,252,7,188,104,145,237,188,159,205,42,189,83,5,35,189,100,93,220,188,83,5,163,188,140,74,106,188,159,171,173,187,156,51,34,188,124,242,176,187,83,5,163,188,161,103,179,188,150,67,139,188,14,79,47,60,192,236,158,60,66,96,101,59,197,254,50,61,48,76,38,61,197,32,176,60,166,155,68,60,159,171,173,59,52,128,55,187,56,248,194,60,3,9,10,61,51,196,177,60,224,45,144,58,90,245,185,60,130,226,199,60,111,240,5,61,44,212,26,61,197,254,50,61,78,209,17,61,208,68,88,187,163,35,57,60,11,181,38,61,112,206,8,61,205,204,76,188,82,73,157,185,176,3,103,188,64,164,223,188,247,117,96,188,0,111,1,188,104,145,109,188,30,167,232,187,17,199,58,60,116,70,148,60,143,194,117,60,150,67,11,60,72,80,252,187,108,9,121,187,161,103,179,188,25,115,215,188,190,48,153,188,164,223,190,188,62,232,89,60,135,22,217,60,36,151,127,188,43,24,21,188,88,57,52,188,23,183,209,186,140,74,106,60,151,255,144,60,166,155,196,60,75,89,6,60,140,74,106,188,206,136,210,188,52,128,183,186,23,183,81,57,75,89,6,60,188,116,147,60,184,30,5,61,150,67,11,61,218,172,122,188,155,85,31,189,166,155,196,188,75,89,6,60,66,96,101,60,153,187,150,59,101,25,98,188,44,212,26,189,226,233,21,189,106,77,243,60,59,112,206,60,36,151,255,59,59,112,206,59,82,73,29,58,224,45,144,59,179,123,242,59,117,2,26,60,163,35,57,60,49,8,44,60,247,117,96,60,161,103,51,61,98,161,214,60,36,151,255,187,80,141,151,188,197,32,176,188,11,181,38,189,14,45,50,189,195,100,170,188,23,183,209,185,250,237,107,188,158,239,167,188,95,41,203,188,184,64,130,188,101,25,226,187,218,172,122,188,208,68,88,60,115,104,17,61,33,31,244,60,166,155,68,60,250,237,235,59,202,84,193,60,25,115,87,61,202,50,68,61,164,223,190,60,62,232,89,188,103,213,231,188,91,177,63,189,211,222,96,189,80,141,23,189,23,183,81,59,52,128,183,59,153,187,22,59,10,215,163,59,82,73,29,59,138,142,228,60,237,13,62,60,188,116,147,187,82,73,157,186,14,79,47,60,227,165,155,60,242,65,207,60,154,119,156,60,4,231,140,59,9,27,158,60,114,138,14,189,240,133,201,188,240,133,73,60,49,8,172,60,27,47,93,60,82,73,29,188,234,149,50,188,108,9,249,187,36,151,127,188,104,145,237,188,111,18,131,60,192,236,158,60,161,103,179,60,61,44,212,60,205,204,204,60,119,190,159,60,109,86,253,62,210,0,254,62,145,237,252,62,236,192,249,62,208,68,248,62,188,5,242,62,3,9,234,62,222,2,233,62,11,36,232,62,248,194,228,62,247,228,225,62,192,236,222,62,191,14,220,62,245,185,218,62,48,76,230,62,11,181,230,62,213,120,233,62,67,28,235,62,15,156,243,62,173,250,252,62,219,138,125,62,180,89,53,62,58,35,74,62,73,157,64,62,104,179,42,62,127,251,58,62,42,169,83,62,114,249,79,62,197,143,49,62,228,20,29,62,96,229,16,62,143,83,52,62,184,64,66,62,235,115,53,62,249,15,41,62,183,98,255,61,97,50,213,61,218,27,252,61,217,61,57,62,248,194,100,62,214,195,220,235,250,248,112,255,153,237,164,237,3,11,123,254,148,0,216,245,170,6,142,248,190,253,239,1,24,0,61,3,129,254,219,206,147,45,241,251,115,5,110,10,224,254,23,0,116,2,8,255,0,254,79,0,186,254,204,234,242,244,84,246,27,251,109,252,10,47,94,253,146,255,134,11,45,15,89,233,215,3,104,2,116,253,196,255,140,254,22,0,115,255,89,255,98,0,125,0,156,255,75,106,133,0,129,255,241,254,240,254,80,255,244,4,173,0,90,254,127,9,98,240,19,245,24,9,182,0,126,25,246,12,118,231,172,214,126,15,56,33,15,2,35,37,59,24,222,3,35,252,142,23,120,255,135,2,180,251,188,254,198,245,61,246,244,1,124,255,182,252,213,4,15,14,237,8,90,11,14,42,20,44,22,245,242,0,184,0,114,248,55,0,185,252,99,251,150,1,87,3,134,3,250,40,185,254,231,249,110,22,172,1,170,8,243,5,109,20,170,35,8,253,108,0,116,255,213,86,108,4,155,1,208,2,158,1,156,254,23,253,4,251,125,252,206,253,113,1,5,0,166,225,5,16,42,14,126,0,243,255,252,238,216,2,131,243,138,7,66,250,232,228,102,254,64,26,105,7,238,253,85,239,123,247,148,252,40,254,20,246,6,216,168,15,233,39,255,245,27,248,204,2,158,250,187,254,171,1,11,255,58,1,208,255,138,255,106,255,169,137,144,254,0,1,113,1,112,253,178,255,10,255,116,255,30,251,133,253,52,5,220,202,113,215,161,250,97,1,113,9,92,8,163,254,180,5,205,255,203,254,11,2,253,1,48,9,184,4,135,254,25,248,236,37,141,1,192,4,114,41,192,238,144,21,62,15,185,247,32,254,92,254,146,4,36,0,24,243,14,6,246,254,146,6,216,252,116,9,140,10,111,63,70,15,60,2,137,254,85,0,209,217,136,255,166,8,219,10,246,44,68,10,96,254,52,249,231,250,202,4,78,0,78,0,123,2,166,1,188,201,22,5,235,239,62,251,121,10,12,223,69,249,242,8,255,10,148,4,75,255,93,253,37,254,5,253,90,9,201,241,223,30,109,253,19,9,229,18,154,229,244,36,56,250,157,246,33,245,216,5,38,3,54,254,10,255,12,0,2,255,121,0,197,5,135,253,255,253,23,3,208,0,122,254,79,255,244,250,9,176,207,238,138,245,66,35,128,0,247,254,54,3,4,1,194,43,60,12,169,248,205,240,92,7,182,252,149,255,92,29,184,4,240,249,29,252,179,4,102,8,36,43,5,5,234,8,80,0,68,5,222,20,41,8,156,3,192,5,82,250,189,223,30,255,237,215,225,246,118,246,224,0,185,12,8,250,29,26,94,6,177,7,48,0,194,18,163,23,219,3,214,33,192,246,136,236,74,248,47,240,56,235,139,19,43,1,112,254,215,2,208,0,69,255,22,11,61,238,210,37,66,247,41,4,122,243,107,39,51,19,129,11,157,249,58,255,50,4,70,253,52,253,160,255,110,5,172,245,238,3,198,239,91,41,108,4,96,11,25,227,98,223,17,3,156,0,222,254,114,255,138,254,143,247,42,4,78,5,250,248,234,11,237,255,196,1,230,40,60,213,94,16,40,252,215,247,40,253,223,5,177,16,44,3,86,19,90,241,76,3,49,251,210,249,43,246,81,9,215,214,175,22,243,237,76,1,155,254,60,207,140,6,160,0,10,42,55,251,162,250,14,0,147,250,172,244,45,254,20,251,203,1,163,252,102,0,179,6,199,16,100,227,24,227,195,40,31,1,74,7,253,2,194,6,102,13,24,253,254,255,19,249,160,255,209,7,117,8,118,0,80,36,224,237,252,237,222,27,8,20,225,224,148,1,79,254,79,254,174,8,142,224,231,7,206,10,252,254,120,246,71,6,138,9,83,30,26,254,182,14,51,9,91,29,230,0,224,4,87,221,224,223,81,220,134,250,236,248,199,4,152,0,244,246,29,253,107,254,240,252,170,253,113,2,247,1,81,255,195,253,51,132,246,1,34,254,214,253,90,252,131,1,176,255,28,254,67,253,222,255,205,255,18,254,75,250,237,3,104,11,12,45,107,10,118,249,192,252,232,33,121,233,18,3,234,249,242,247,241,3,120,254,51,8,147,227,229,245,158,24,254,11,144,17,79,249,54,240,83,224,106,6,154,248,122,13,72,3,48,14,160,0,66,2,149,0,255,2,242,2,208,0,154,252,96,253,252,0,226,255,43,255,30,254,50,0,190,253,254,255,108,255,246,0,82,131,200,253,130,0,216,1,249,2,229,255,205,255,198,1,144,0,124,0,212,22,94,223,90,37,85,241,250,254,214,12,96,4,215,3,140,253,34,253,60,249,112,250,97,1,109,254,5,62,16,203,177,254,81,1,7,2,140,0,41,1,150,0,213,2,244,252,108,3,140,255,165,255,128,255,19,1,195,9,97,36,0,253,27,215,124,4,124,8,239,230,220,12,117,247,172,251,239,11,81,4,113,2,26,3,68,0,81,1,104,5,150,255,252,253,62,2,100,3,81,3,27,252,81,0,196,100,28,0,206,0,28,242,161,254,34,4,102,4,110,225,190,20,250,239,232,20,77,229,64,240,207,5,230,0,241,21,169,3,244,40,185,255,93,10,179,4,255,255,155,2,47,250,104,216,102,30,5,253,24,3,154,5,86,255,111,1,96,0,24,170,4,255,244,2,145,0,60,250,128,5,243,5,205,252,192,253,36,254,212,251,15,255,217,255,11,6,81,37,146,253,249,248,69,7,227,23,160,252,194,41,182,253,214,1,200,0,138,4,74,2,44,0,126,210,125,13,30,34,62,245,78,255,236,0,166,245,94,10,139,10,156,4,205,20,54,254,216,255,38,255,250,255,126,0,138,26,250,1,92,3,87,46,140,2,129,6,139,239,255,18,144,5,80,22,105,253,80,253,246,255,115,250,92,253,211,250,134,254,201,254,22,254,45,76,218,4,12,1,229,17,51,6,127,251,80,3,158,250,121,251,249,1,63,0,192,2,150,7,156,8,198,247,44,0,223,1,182,251,77,1,165,171,151,253,212,230,219,13,2,5,8,249,56,18,206,250,47,10,217,4,5,242,247,0,149,252,95,44,59,244,120,255,243,205,192,199,65,7,26,252,62,5,163,4,174,254,239,4,63,2,202,4,29,252,84,2,190,1,37,1,255,2,156,254,70,0,18,3,210,1,202,0,149,0,81,3,193,142,140,2,124,0,47,255,132,255,106,254,169,234,123,250,236,250,37,235,31,249,162,18,120,10,210,214,158,13,225,21,116,11,45,6,233,1,9,2,57,191,1,0,7,250,54,23,210,4,106,18,145,249,126,4,242,10,130,2,74,2,252,14,240,0,51,1,22,254,67,0,3,3,48,3,118,252,18,6,66,4,207,246,139,253,27,44,125,11,90,244,1,37,154,5,1,239,175,224,203,235,135,31,139,7,1,5,41,240,104,243,130,248,241,254,52,255,158,2,163,13,107,0,120,132,227,0,75,0,165,255,108,0,171,0,203,255,55,255,117,1,63,0,118,0,126,0,152,255,127,0,168,255,18,7,168,45,0,216,38,2,108,14,142,236,173,249,40,0,143,3,200,251,68,2,1,253,77,1,192,0,147,1,52,1,120,252,142,0,193,121,247,1,179,251,110,255,112,255,35,0,181,0,157,254,54,0,78,2,243,1,95,0,25,249,188,1,207,255,112,8,8,28,0,47,78,25,27,253,56,234,124,253,155,255,29,251,12,251,61,9,45,39,25,2,60,250,51,1,60,8,82,246,80,252,229,41,93,1,110,239,121,255,153,29,116,238,212,5,48,246,56,30,2,236,156,229,124,246,158,248,170,246,84,6,146,3,122,6,47,0,84,210,122,255,52,249,60,255,49,37,120,255,160,250,22,222,144,251,72,4,135,3,132,251,178,254,28,255,252,255,93,253,57,255,122,7,11,11,166,212,175,247,1,246,46,252,175,0,40,7,91,39,202,246,160,248,6,211,214,244,104,48,207,254,50,255,161,3,217,1,208,243,50,245,212,251,43,251,164,1,50,253,235,255,176,254,211,255,34,254,19,250,38,7,156,206,3,1,202,46,1,1,214,5,33,249,247,0,35,253,112,0,62,247,34,1,234,0,236,215,245,6,242,248,248,239,211,6,38,0,76,253,107,19,103,220,123,248,212,249,153,253,120,218,195,14,106,212,213,1,128,237,43,1,1,245,60,8,118,7,204,246,66,0,11,2,72,254,250,8,133,239,48,246,170,251,184,43,44,23,187,245,207,224,32,252,7,3,146,251,215,12,132,3,87,253,217,255,74,251,84,249,112,229,151,254,16,43,48,33,58,255,241,240,206,5,13,246,237,6,50,0,236,254,226], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+378897);
/* memory initializer */ allocate([254,17,3,52,225,182,1,238,17,234,10,213,20,100,21,60,8,148,2,26,14,4,9,166,222,224,0,124,255,134,0,219,2,220,3,168,250,54,15,222,16,183,38,152,255,64,1,222,218,185,6,198,233,176,6,213,221,172,248,254,235,232,250,94,255,240,2,62,14,85,6,81,43,93,4,77,248,34,4,254,11,180,0,72,90,175,0,227,1,252,251,230,253,241,1,29,4,61,0,20,3,57,254,22,0,201,255,224,255,186,254,84,62,3,248,20,3,56,38,110,251,205,252,163,241,135,2,28,254,66,2,96,255,30,1,91,254,33,1,204,31,254,14,190,253,182,248,230,247,155,2,81,209,148,6,111,13,0,5,158,0,8,249,252,4,126,2,50,2,253,7,36,255,84,3,174,253,195,247,151,245,188,10,38,0,91,0,97,5,144,253,102,183,14,254,142,252,36,0,24,2,157,255,62,0,101,235,235,11,231,0,57,231,41,249,182,4,146,249,189,250,234,202,151,5,241,254,70,254,174,85,113,255,224,248,134,254,49,254,48,3,123,1,80,1,221,254,116,253,19,1,10,253,1,1,238,197,232,250,92,28,211,242,225,4,56,248,174,10,251,245,8,244,96,254,120,9,23,1,22,41,206,0,87,253,254,199,154,2,51,7,120,253,14,2,190,7,110,1,172,2,251,3,192,0,8,0,30,254,79,237,86,8,70,249,178,41,179,249,33,0,124,4,226,249,242,39,69,13,155,2,180,251,30,253,116,9,54,200,195,1,90,0,150,215,113,10,151,4,201,241,10,1,202,253,0,0,136,6,58,4,42,1,103,1,15,254,248,6,198,253,22,246,218,9,15,241,121,24,99,0,9,225,88,12,71,43,131,0,224,247,92,0,1,139,12,1,219,254,240,0,254,0,74,255,111,255,47,1,12,0,86,0,84,2,246,0,136,0,252,3,15,250,146,251,115,216,197,233,140,23,137,241,57,239,122,241,169,233,204,253,148,2,191,254,207,251,83,0,4,244,23,24,244,49,6,253,121,31,65,251,75,9,94,8,215,241,9,254,118,250,208,254,119,253,11,254,242,206,243,49,153,14,185,5,148,241,215,250,82,4,144,251,117,253,206,255,72,6,59,0,185,253,82,0,75,1,187,1,14,3,93,0,29,1,54,1,221,113,70,253,204,255,115,252,18,255,34,255,142,255,4,0,138,2,56,255,235,0,237,9,86,2,122,1,248,42,29,12,220,223,154,6,39,239,84,27,245,255,196,245,78,250,108,250,67,2,208,254,20,0,140,254,129,3,90,2,176,1,118,255,178,2,81,2,51,250,136,0,191,0,109,130,4,1,199,0,156,1,88,255,215,255,128,254,150,254,242,255,242,0,110,1,194,254,208,254,8,6,202,1,146,225,4,13,3,236,111,248,100,3,78,49,138,3,149,7,155,18,162,6,95,1,22,255,51,252,206,35,70,26,126,10,248,0,13,14,172,217,112,254,59,16,36,11,97,254,170,8,108,3,143,5,12,15,149,11,102,254,28,7,76,32,240,250,174,2,114,0,15,12,191,11,70,219,137,233,125,242,238,229,162,1,41,16,170,18,56,0,137,250,94,249,226,245,151,32,174,247,231,9,4,24,122,255,167,246,31,45,174,254,223,2,118,2,110,253,46,52,181,3,144,251,39,255,39,252,182,0,10,252,179,5,221,0,33,30,150,250,109,250,46,5,43,2,66,0,134,10,1,250,244,254,228,202,146,2,49,1,90,3,36,2,52,206,186,253,225,251,109,253,133,208,172,3,140,247,42,246,130,255,124,255,182,252,129,2,29,254,66,254,192,235,70,255,1,254,145,4,52,232,17,24,10,12,104,253,11,248,79,3,24,43,230,250,119,249,61,251,220,255,70,7,69,39,12,3,230,254,187,252,249,254,253,1,180,253,154,206,255,252,140,247,85,247,12,2,151,242,219,230,50,15,145,253,171,226,241,0,202,15,8,1,142,250,62,14,243,228,192,235,194,4,60,250,64,247,90,7,182,0,134,242,15,254,108,255,160,0,213,249,167,179,176,255,118,3,145,3,196,2,216,2,137,1,165,253,246,252,86,13,246,252,41,250,181,4,38,9,232,0,206,241,180,255,104,190,84,253,42,5,192,0,64,204,110,253,226,29,123,18,87,255,28,20,123,250,210,11,176,9,114,247,236,3,222,247,237,0,171,0,51,253,2,253,243,253,230,209,64,241,70,217,94,5,78,243,159,1,29,245,81,255,199,251,24,3,212,3,200,44,66,3,202,2,31,252,150,0,77,0,2,9,241,43,14,244,166,242,34,249,17,255,137,255,128,250,195,23,76,239,35,7,124,6,239,8,75,244,192,253,144,1,14,8,154,243,185,231,42,39,198,251,41,0,249,0,42,39,201,231,211,254,24,1,136,39,201,8,15,2,204,253,234,3,110,2,13,13,152,1,54,11,102,50,251,51,177,2,80,1,205,252,213,255,64,3,38,251,145,2,150,255,42,0,99,4,149,0,232,247,78,0,209,254,73,1,241,84,132,247,76,251,192,1,157,5,208,253,136,254,55,1,183,255,153,0,239,252,144,254,54,0,67,254,164,255,120,0,197,255,135,254,146,1,55,2,36,155,4,5,8,5,200,0,159,252,250,250,215,255,186,248,146,1,179,0,222,246,220,240,128,19,224,248,148,216,177,242,188,222,28,242,130,0,193,233,214,22,29,9,179,11,62,8,222,228,185,19,183,246,119,6,165,252,127,237,112,6,119,27,80,227,128,19,224,6,57,253,62,12,27,56,117,252,171,0,77,248,10,244,201,251,88,2,91,2,32,255,72,254,192,211,221,254,105,253,86,7,53,253,92,245,28,1,56,254,38,213,103,243,64,247,252,0,47,252,152,254,217,2,196,253,141,15,79,6,204,255,4,235,207,23,96,217,217,26,10,241,52,19,42,7,211,249,252,211,244,246,114,254,81,5,7,24,176,10,80,248,16,18,76,255,252,254,59,251,255,233,236,250,199,251,103,250,3,254,110,1,124,254,124,6,84,1,203,181,182,2,96,251,211,252,44,5,237,4,223,2,70,255,138,20,185,253,35,255,171,6,149,0,254,3,189,252,65,4,123,11,233,7,165,1,155,1,25,14,27,202,208,1,254,35,158,9,143,231,144,23,119,7,2,5,55,218,206,3,65,253,128,255,182,3,113,1,136,4,94,253,200,254,222,201,54,4,74,226,8,0,226,10,111,1,215,230,200,252,61,255,202,2,228,1,108,0,219,1,33,1,12,252,201,249,128,213,188,254,121,253,105,247,138,40,149,22,227,3,96,254,103,3,40,251,132,254,70,0,155,248,208,29,191,6,116,252,96,253,107,213,62,252,102,227,26,3,212,6,64,234,191,4,213,22,153,218,147,246,145,247,5,12,79,5,96,254,133,24,171,255,72,5,86,242,242,23,101,4,20,255,158,7,33,33,204,2,208,253,225,250,28,255,250,0,72,254,56,235,107,248,18,218,29,18,140,5,154,255,226,223,104,2,50,247,240,253,196,0,221,250,19,253,159,255,227,254,248,193,81,4,118,2,112,1,215,252,29,0,104,249,246,246,233,2,165,249,128,77,180,246,12,16,134,6,203,10,19,1,18,2,236,1,179,253,25,176,151,2,188,243,236,9,194,247,106,254,54,4,176,7,27,253,102,246,234,1,16,254,82,1,69,2,55,4,152,253,154,0,113,39,231,0,28,255,221,1,20,0,92,5,228,44,168,251,180,243,35,2,248,0,92,253,5,32,14,23,237,250,7,2,8,245,9,45,180,255,215,4,248,251,226,253,97,1,209,251,22,1,18,1,221,10,195,225,188,12,151,10,175,0,52,48,86,4,212,246,73,235,160,5,69,2,186,255,6,1,82,217,185,246,18,2,153,5,88,6,61,250,77,252,138,52,38,5,96,249,207,0,198,0,138,4,80,252,143,219,234,251,195,0,150,255,170,2,32,57,170,252,150,246,30,4,242,0,164,254,69,2,207,1,204,2,248,2,154,10,76,5,177,250,33,51,5,10,229,214,142,7,125,2,194,4,136,4,62,3,137,3,16,1,152,1,187,253,110,250,101,2,26,10,6,224,164,14,249,229,20,17,142,255,220,237,182,11,32,219,173,2,219,221,35,13,9,234,123,239,110,228,79,251,202,252,14,7,223,33,168,252,156,253,141,4,86,254,61,1,211,26,176,255,84,228,119,4,186,248,182,10,157,2,38,2,22,0,173,0,205,16,90,215,18,4,166,254,202,250,175,244,135,2,232,2,14,0,198,250,144,249,45,251,222,13,57,254,77,8,164,4,240,66,164,4,130,229,175,252,42,1,226,251,218,219,153,1,56,249,130,5,170,227,159,248,201,1,28,253,22,0,6,1,242,125,121,6,252,246,128,10,161,253,97,2,4,0,150,0,248,254,192,0,116,255,246,0,119,254,180,255,54,197,134,1,201,3,201,1,156,5,119,253,204,1,138,208,79,5,246,3,201,247,192,253,55,0,178,253,113,0,126,250,121,164,182,0,174,246,224,249,136,3,38,255,231,254,68,255,78,255,63,0,211,0,37,2,175,2,219,208,168,255,114,253,210,251,157,204,132,255,71,253,182,1,102,12,164,6,14,1,234,0,223,254,143,253,133,61,220,246,18,33,141,1,148,238,250,251,134,12,57,4,219,250,250,251,184,255,231,1,59,250,178,221,72,27,59,251,91,9,126,12,179,11,230,22,85,251,69,232,4,252,90,252,100,3,42,254,0,252,178,4,26,252,230,250,102,86,88,1,28,2,191,243,221,253,136,9,228,255,222,0,116,1,88,254,57,255,44,4,107,252,151,255,74,239,52,0,213,254,21,27,195,45,248,253,219,244,58,0,129,222,160,1,8,251,104,4,224,255,140,251,175,248,17,254,235,0,31,8,198,254,208,250,201,245,30,177,80,3,239,249,131,1,53,232,138,3,60,216,186,33,6,254,238,15,62,1,159,245,76,6,130,255,112,250,252,255,47,249,169,254,46,1,135,9,158,47,173,3,10,207,108,237,80,255,166,255,241,250,17,4,83,7,62,254,89,0,212,0,50,8,172,6,84,7,225,15,146,6,180,7,204,236,73,252,69,214,163,5,30,213,4,3,11,252,21,255,59,0,213,0,26,255,142,0,192,253,250,1,101,0,44,0,119,255,126,102,209,255,190,254,223,254,25,1,54,10,70,238,122,2,92,4,167,4,169,11,9,253,105,234,38,2,59,8,126,232,251,212,87,254,35,255,133,3,217,0,34,2,213,0,234,7,183,2,50,4,172,247,83,255,128,249,241,252,233,97,186,254,86,0,136,253,118,5,100,18,161,244,72,9,135,0,65,250,120,252,222,246,219,3,144,12,44,238,58,1,76,61,42,255,214,4,230,0,75,255,183,136,218,254,155,0,161,253,218,0,203,254,76,255,10,255,154,255,36,252,124,253,111,0,235,214,188,249,100,251,68,245,167,4,97,205,254,255,20,252,28,0,60,255,182,7,234,252,41,3,98,34,76,251,76,1,180,0,239,240,1,4,146,232,150,218,94,0,211,251,162,246,185,0,131,2,57,250,66,1,240,9,40,49,140,223,240,240,6,5,64,6,21,246,64,245,40,246,145,254,82,252,161,1,203,254,142,247,252,7,134,42,228,6,20,43,226,14,139,11,252,251,7,252,40,249,25,254,163,253,48,0,8,9,144,254,34,249,4,255,115,1,170,77,54,248,139,6,118,21,108,253,123,249,0,1,202,255,83,252,222,16,206,254,95,8,17,1,217,242,240,243,109,25,164,248,232,234,192,253,130,44,107,3,199,1,15,1,38,255,121,5,212,255,40,235,118,208,56,18,179,253,22,242,114,248,210,22,77,5,160,12,169,5,110,254,36,212,160,255,27,250,25,8,41,249,8,3,73,254,7,3,26,243,209,52,187,254,138,255,84,255,155,1,116,254,10,24,105,246,204,255,248,237,15,3,56,207,219,247,185,22,2,251,123,2,79,249,72,11,194,252,137,2,58,29,150,39,187,35,200,14,22,4,114,248,236,245,102,0,89,253,132,255,68,0,145,2,161,1,81,255,0,128,176,255,119,1,83,252,224,0,15,1,24,255,239,5,157,255,88,253,67,0,66,0,150,253,252,0,115,7,1,20,152,9,187,247,84,219,95,250,124,2,188,30,108,223,147,7,60,5,231,5,199,2,130,25,44,249,73,255,90,0,1,10,228,22,148,254,253,19,251,239,68,240,80,252,30,41,252,251,23,4,195,2,84,47,204,206,90,240,154,3,233,251,92,1,53,252,240,254,172,246,179,1,246,0,225,251,148,0,196,248,126,207,29,246,196,13,7,16,168,254,131,6,2,11,32,238,239,254,111,223,183,0,241,1,112,255,139,217,220,254,9,254,68,251,220,16,102,250,206,212,29,244,71,233,43,252,45,3,0,0,50,253,45,254,45,40,195,181,174,255,8,3,168,4,6,4,24,6,56,4,112,255,217,2,94,2,31,255,123,254,69,255,40,2,94,252,68,254,185,232,88,248,221,250,90,10,254,250,154,182,236,6,7,1,130,5,44,3,54,254,36,254,232,2,35,10,86,254,237,255,159,35,177,17,34,250,65,18,91,14,6,29,60,4,202,228,250,253,16,203,30,4,170,9,229,218,17,4,250,19,186,1,111,11,255,1,44,250,217,0,42,253,142,1,246,253,35,0,119,0,180,254,106,0,48,3,181,1,57,251,220,107,9,2,227,255,50,254,111,1,58,252,220,1,1,246,99,242,96,255,207,5,240,254,182,253,130,232,24,255,95,14,184,248,220,4,63,2,1,199,29,254,108,250,20,0,194,30,124,244,179,232,79,9,198,12,234,1,190,10,221,253,70,218,63,250,175,3,29,1,172,246,252,252,210,249,109,12,91,13,68,10,59,255,48,13,30,204,252,225,55,13,70,0,106,251,186,255,209,229,119,227,215,253,4,14,198,252,244,255,182,28,236,241,89,1,74,4,16,15,150,3,246,7,217,255,250,44,182,61,47,5,134,4,180,1,106,252,71,0,185,3,207,3,123,4,174,0,155,1,187,5,83,0,72,238,25,250,230,20,14,243,175,54,18,0,11,16,109,7,66,3,54,10,52,9,143,254,175,3,171,254,52,254,28,17,226,216,236,12,43,242,103,243,147,253,1,33,153,250,129,17,137,250,194,241,88,252,155,3,221,0,90,1,148,30,102,9,205,11,127,236,196,11,105,213,123,248,217,31,126,1,83,250,214,4,89,2,171,4,59,247,24,245,234,239,217,1,34,19,161,50,50,232,17,23,88,5,62,245,209,254,0,3,225,255,5,251,120,5,84,2,210,250,107,2,48,249,121,4,119,240,127,2,223,213,99,249,72,212,227,253,78,254,136,211,7,252,25,56,118,5,9,2,89,243,59,7,21,254,237,0,0,252,234,3,70,244,209,254,223,255,124,230,89,2,114,241,152,30,202,23,133,216,189,3,131,251,177,2,47,5,205,255,153,7,222,3,150,255,83,2,234,0,6,2,36,4,77,0,69,3,208,112,165,255,117,254,237,254,247,254,233,254,39,255,212,254,240,0,225,251,106,254,218,16,165,247,205,24,77,247,148,232,195,3,110,215,21,18,208,253,56,4,134,0,89,123,214,250,253,5,80,247,253,0,51,250,164,255,38,1,183,0,188,253,164,1,172,0,230,252,50,255,170,254,174,254,53,0,171,255,104,252,77,115,49,4,52,252,209,248,236,3,34,1,46,0,204,1,185,255,36,252,195,6,150,254,234,247,8,15,254,255,254,240,222,2,59,251,180,224,80,4,126,26,201,37,58,4,143,222,164,252,169,247,235,249,179,249,81,201,128,6,220,8,222,249,36,253,242,3,110,254,141,251,84,254,144,1,99,4,196,247,0,210,167,254,112,41,221,4,186,243,84,243,148,251,164,6,204,254,37,6,31,2,166,2,40,20,10,244,177,1,143,10,172,252,217,236,168,248,170,6,171,54,161,9,20,237,120,252,108,255,94,1,96,212,126,5,56,1,132,209,141,1,1,3,182,21,182,250,187,0,226,255,231,0,4,252,202,0,116,3,58,255,177,243,194,252,214,222,98,253,49,245,237,5,99,205,235,240,22,245,194,248,76,255,135,0,228,27,7,16,181,238,194,1,238,1,247,251,170,251,215,244,48,43,57,253,224,252,44,14,76,255,172,252,196,215,184,247,62,254,128,56,1,254,47,1,72,250,226,253,167,255,52,255,244,1,112,254,194,254,57,2,216,0,172,1,94,1,181,7,119,255,139,252,254,248,50,252,137,15,54,13,64,183,92,254,101,248,165,0,63,254,115,5,95,188,226,254,6,8,65,254,76,245,167,248,218,253,138,247,80,5,123,232,162,255,148,0,164,2,173,249,55,249,55,209,87,255,128,249,227,225,58,24,190,232,145,6,203,2,249,254,56,0,113,1,77,2,52,2,197,7,81,6,144,249,245,35,63,5,12,211,45,227,49,241,192,243,25,4,180,252,24,0,198,229,56,249,154,233,165,244,152,19,119,8,166,233,70,251,88,24,172,1,163,9,250,242,59,250,57,253,72,26,222,215,190,236,176,231,163,254,58,253,62,6,55,253,84,249,15,254,2,255,55,2,140,252,131,0,0,45,116,252,111,250,186,248,119,203,202,249,99,253,145,2,249,1,236,0,252,255,21,0,78,3,100,0,56,32,201,248,125,255,70,255,181,0,218,252,221,12,208,251,72,251,156,56,19,6,247,5,32,2,136,255,254,254,6,0,159,246,167,48,128,42,67,4,210,246,85,252,28,251,204,253,150,0,142,255,139,5,225,2,60,249,72,254,1,247,30,255,24,2,68,246,195,251,123,216,251,212,202,14,155,20,246,255,175,9,143,0,145,249,247,224,116,3,174,249,8,8,90,50,88,254,98,23,65,250,102,253,198,253,70,250,13,254,64,0,54,2,54,249,129,253,116,44,156,253,87,7,14,6,181,48,213,254,35,250,74,10,12,4,204,11,243,255,126,58,238,247,102,233,149,245,111,21,144,229,212,1,127,254,10,3,219,252,232,253,208,254,206,2,130,1,29,1,122,29,131,2,182,5,145,3,99,18,173,3,246,242,62,255,13,26,115,238,165,34,187,252,144,1,147,252,151,212,70,1,242,246,115,53,232,250,82,248,91,252,56,1,128,0,214,1,216,254,190,254,84,1,154,251,19,7,207,7,69,11,129,12,75,1,66,246,159,15,148,2,176,255,241,247,125,190,199,250,170,1,20,19,118,232,216,255,45,8,86,1,80,255,83,0,134,0,28,3,87,254,26,221,52,8,102,33,160,0,35,255,4,255,54,128,26,5,52,5,159,253,147,255,35,2,80,3,6,2,216,255,47,1,10,255,61,254,127,247,52,253,18,253,1,0,16,173,7,5,233,250,3,8,123,6,221,5,143,254,121,250,18,1,52,1,4,1,115,1,127,250,106,253,77,227,249,27,72,14,176,251,158,34,217,233,90,5,98,4,16,0,108,4,185,68,122,26,31,252,101,2,103,253,188,11,216,12,167,249,225,248,21,252,228,2,22,252,136,252,91,253,215,251,50,157,229,3,96,255,76,255,213,252,188,0,179,254,77,246,72,253,29,5,120,0,200,1,140,255,28,248,128,252,48,28,184,24,46,220,215,32,86,244,108,249,168,2,216,6,84,253,101,2,81,1,139,253,26,210,19,254,188,254,117,252,121,254,29,4,45,55,142,0,164,1,131,248,134,254,108,250,166,255,15,254,92,4,48,254,122,8,37,3,220,249,120,252,196,220,234,253,50,25,22,254,254,41,23,1,253,2,193,3,111,240,114,245,119,9,139,236,58,251,118,6,191,251,147,247,148,7,251,55,129,252,190,6,19,6,122,0,32,242,250,4,170,253,114,252,240,11,88,249,30,25,126,214,246,3,187,221,241,3,144,7,152,254,44,254,251,251,119,221,143,253,164,8,186,8,160,10,166,4,192,255,226,247,80,18,242,33,30,20,62,254,232,2,228,252,227,233,180,254,254,224,110,10,42,240,97,5,198,249,34,45,162,237,209,241,233,2,230,2,166,255,225,250,240,48,200,237,66,3,171,252,6,6,112,33,161,8,251,15,60,11,69,8,90,253,148,6,17,3,48,1,44,31,78,8,210,254,47,32,199,247,48,6,118,46,225,251,145,250,84,2,39,9,86,0,132,1,188,250,17,252,148,5,157,1,241,219,184,215,78,227,172,251,105,5,25,251,142,240,226,2,22,251,154,1,226,0,11,59,221,251,235,239,206,255,8,254,66,249,145,5,10,217,166,254,176,2,208,1,244,0,182,253,80,221,77,3,109,253,164,3,227,250,34,1,227,255,95,254,120,247,243,3,106,218,163,5,49,35,153,7,138,10,60,253,76,41,106,9,176,4,140,17,247,245,164,5,175,10,100,222,226,8,39,240,222,1,57,255,5,5,151,49,33,48,139,244,84,249,174,4,163,2,20,254,208,253,204,255,19,251,85,0,32,254,160,255,184,2,4,253,134,250,120,133,188,253,93,253,114,249,198,255,88,2,246,253,220,254,135,2,220,255,154,0,132,251,181,1,25,6,76,2,91,2,205,29,179,189,29,0,196,252,179,253,105,252,164,250,42,254,67,254,172,1,16,2,196,22,159,254,224,255,11,249,66,253,78,253,228,227,75,243,150,7,248,17,186,208,94,253,16,215,224,246,199,2,130,247,206,226,100,250,61,254,35,228,88,3,164,245,100,7,136,13,222,253,164,2,16,204,252,253,206,202,27,252,170,3,150,6,238,3,78,5,165,250,154,3,22,2,86,255,126,0,255,0,189,252,50,0,177,3,214,251,116,249,3,0,14,4,75,254,174,101,162,1,27,0,188,251,19,254,84,254,162,253,183,251,140,253,42,1,39,1,218,252,183,0,146,0,72,5,172,255,46,253,65,3,189,155,104,12,233,3,190,254,221,246,15,0,37,254,23,251,68,8,108,3,125,2,239,253,172,251,46,1,108,246,22,77,58,0,83,3,117,38,118,4,120,8,194,2,62,43,20,6,32,2,186,11,190,8,122,240,178,10,208,255,124,223,118,247,157,254,171,197,144,8,79,246,140,10,217,1,26,254,249,2,48,255,76,0,178,255,102,0,224,236,98,5,89,48,179,223,28,0,68,4,49,236,36,250,90,251,220,252,61,4,2,253,237,1,22,0,239,251,176,35,46,251,41,208,199,3,112,10,141,252,230,17,7,19,99,7,236,253,73,1,226,0,190,1,202,229,56,1,110,252,136,5,196,248,236,11,112,25,11,35,168,21,119,25,189,253,253,3,15,255,143,3,14,3,128,242,174,39,183,248,101,15,244,207,8,0,216,1,114,3,212,249,249,248,255,251,137,253,129,255,44,196,111,31,56,255,188,248,70,2,245,238,6,251,61,4,208,255,79,9,126,2,224,1,113,1,186,252,195,250,158,1,142,255,197,10,198,4,110,247,190,242,69,25,114,9,226,2,136,249,234,60,190,251,202,0,215,2,255,252,228,1,158,9,11,19,120,6,5,241,19,190,156,20,239,0,214,3,176,248,126,255,133,3,72,5,101,255,75,19,131,223,40,35,199,9,229,1,160,4,220,253,180,250,198,226,68,255,205,249,240,1,32,214,13,39,223,250,145,34,32,20,30,255,164,244,47,1,182,252,154,252,165,0,164,250,151,255,102,255,170,0,120,9,84,246,178,247,119,223,93,1,99,238,8,20,164,255,126,35,161,227,160,1,132,255,85,1,168,255,239,0,52,20,41,2,246,5,192,6,163,7,47,250,61,230,27,212,16,216,118,254,97,252,92,252,162,2,231,2,61,1,20,18,5,33,72,241,241,9,178,13,154,246,148,35,11,22,52,18,20,16,108,246,145,250,102,255,182,255,180,0,150,20,14,225,46,0,38,43,188,23,223,2,242,30,60,255,200,251,165,5,81,253,157,246,240,252,230,2,243,254,14,254,122,23,51,240,29,4,123,3,254,249,101,2,172,255,98,239,67,252,74,18,76,201,2,8,121,253,50,253,45,2,96,245,133,9,5,226,98,46,188,219,34,253,7,3,73,247,105,0,110,1,80,5,158,255,130,255,252,1,87,10,217,2,250,2,154,221,83,215,48,35,211,247,83,4,201,0,141,5,157,4,253,254,140,5,60,3,71,1,92,248,195,253,150,252,98,1,102,10,99,250,112,42,232,219,32,226,134,6,62,6,173,0,182,1,139,254,202,253,246,0,33,209,25,7,157,253,1,0,140,249,84,7,74,5,246,4,235,252,44,1,191,254,57,45,252,253,73,1,91,22,124,18,181,6,176,231,20,235,108,231,142,254,196,241,102,252,206,255,242,255,187,253,238,249,117,249,236,255,59,252,63,111,146,2,14,254,24,254,248,1,167,253,181,1,183,253,11,255,60,255,186,0,25,1,82,255,159,0,45,29,2,23,8,236,54,19,193,220,152,254,40,0,97,244,176,18,75,254,73,6,8,4,199,10,215,254,106,0,56,20,37,239,56,2,192,218,239,250,129,229,43,213,5,5,8,1,74,1,4,254,246,253,112,2,150,2,27,2,80,28,44,202,40,0,92,8,116,247,133,7,244,220,123,4,196,250,102,3,11,3,252,255,155,255,138,254,13,3,101,22,176,233,111,233,32,8,107,3,138,52,241,249,99,243,230,248,142,255,241,4,245,1,124,2,192,253,145,253,11,251,190,11,255,3,94,3,79,5,158,7,76,2,136,167,218,0,74,254,11,6,104,254,180,252,249,254,150,255,162,57,79,253,6,219,46,252,235,255,132,5,43,0,220,7,96,1,140,3,21,1,64,252,21,253,26,255,235,249,36,228,181,233,79,0,86,246,129,8,27,235,206,9,80,206,17,11,152,247,99,249,202,1,197,0,125,253,223,2,88,245,131,252,198,10,76,20,18,242,58,239,206,236,58,251,188,0,76,221,166,231,87,9,18,250,151,2,60,2,71,250,123,4,38,33,245,7,212,9,173,3,204,23,82,45,1,246,90,249,200,248,100,252,46,255,148,255,228,251,168,32,113,226,20,238,87,255,136,13,10,220,50,7,23,239,61,246,171,254,80,2,150,3,154,255,84,1,214,0,13,4,188,254,95,192,68,40,209,255,227,255,60,5,165,253,53,245,220,253,136,1,209,5,107,255,255,252,189,255,214,51,71,247,65,32,46,6,10,4,82,239,148,3,134,17,167,4,154,255,159,0,109,0,232,253,104,253,37,252,151,224,33,249,168,16,32,234,9,202,122,251,176,6,212,9,134,253,248,1,3,2,220,2,210,255,83,253,31,254,149,6,10,249,6,1,240,241,129,57,190,24,5,31,101,0,146,3,163,247,254,255,182,0,61,3,41,255,134,255,181,24,88,241,4,245,82,6,184,13,201,249,76,239,82,27,147,215,213,233,35,250,26,249,99,248,180,1,82,0,36,234,32,10,194,251,12,245,236,9,202,1,218,253,214,248,159,246,117,226,36,9,142,6,14,226,186,17,27,0,193,24,58,14,172,66,190,20,91,4,43,6,114,255,115,254,98,253,218,7,95,3,8,254,77,3,80,3,2,3,139,221,171,7,222,10,162,0,106,4,37,10,125,202,100,240,32,3,195,9,235,251,24,250,70,255,197,255,137,255,72,236,144,26,194,221,16,3,77,228,22,252,79,1,201,7,235,251,89,2,12,7,166,0,63,5,110,0,32,255,199,8,168,254,251,255,60,239,214,22,143,33,186,209,233,250,253,251,223,6,88,255,62,255,255,250,233,1,122,1,51,236,7,243,230,43,137,254,218,252,122,15,188,37,112,244,104,253,213,251,141,253,15,1,181,4,136,4,5,1,141,14,197,30,89,253,22,0,86,2,194,251,92,254,120,8,210,255,64,195,164,1,196,4,52,5,198,255,100,255,97,30,207,237,96,1,212,59,104,237,164,247,239,245,215,250,245,7,141,254,26,251,112,252,103,251,169,250,153,255,220,17,246,218,193,249,38,1,147,1,240,254,229,246,243,238,155,52,233,17,6,246,49,249,33,2,162,0,143,254,186,23,9,44,104,221,17,224,239,9,249,255,58,1,15,248,144,10,37,249,105,250,233,252,236,254,61,4,236,0,153,25,80,7,131,1,32,4,225,255,126,175,159,253,96,2,239,3,68,6,35,250,188,255,241,253,204,0,252,0,229,9,47,253,188,5,188,1,184,255,61,0,47,255,0,2,40,255,42,0,129,1,22,254,152,255,154,142,90,255,237,236,62,245,20,3,82,254,157,252,53,2,125,251,50,2,52,4,221,6,82,244,133,197,200,32,134,3,38,2,102,0,77,230,229,228,193,254,172,0,161,252,211,3,130,8,118,2,160,0,184,3,178,3,141,240,235,5,96,1,253,9,37,235,22,24,236,17,8,248,191,15,233,253,56,246,222,10,152,208,58,5,58,245,202,1,97,253,155,0,86,27,218,245,93,252,116,254,102,252,12,8,191,1,214,255,119,253,236,253,216,253,103,248,92,191,47,3,104,254,141,13,234,239,107,3,7,252,114,212,1,254,6,15,171,211,120,248,243,252,205,10,87,253,55,253,143,2,38,255,160,224,47,254,39,1,55,6,129,254,159,248,91,6,108,0,125,4,209,9,132,1,186,233,179,194,24,0,214,1,30,239,137,14,48,6,16,7,94,1,27,249,148,253,119,244,2,17,64,33,11,207,170,255,70,246,64,255,5,254,232,7,102,15,223,252,132,52,226,2,218,247,162,0,221,7,69,3,56,0,128,254,92,12,188,19,134,4,109,254,255,228,62,239,236,247,238,64,78,245,88,3,188,244,128,246,102,254,101,251,56,254,248,1,177,250,180,1,96,1,49,231,71,1,108,247,34,250,46,1,82,1,185,252,235,0,248,253,3,5,150,10,126,73,208,8,254,255,144,1,20,5,95,251,0,4,96,241,42,242,2,239,5,253,110,7,111,198,61,21,48,0,203,249,232,254,189,255,232,0,228,8,133,5,212,12,204,254,245,3,98,2,3,89,83,253,212,2,12,0,153,254,141,249,220,251,57,2,248,0,252,14,93,2,99,254,52,13,176,250,160,251,139,244,192,246,47,252,151,39,68,48,155,14,221,249,94,254,68,2,154,245,60,211,16,232,51,11,204,44,57,3,127,243,11,254,118,255,13,253,214,253,168,0,245,2,204,253,172,1,170,208,181,196,70,248,176,1,171,253,248,5,222,11,200,253,69,5,207,242,146,3,242,1,160,3,165,255,251,255,232,35,184,11,238,9,125,250,114,2,145,10,5,253,175,12,168,53,218,11,122,8,189,255,172,252,134,254,240,4,45,245,145,246,116,239,126,0,64,248,232,203,192,251,96,254,69,248,248,253,202,9,31,250,38,1,162,246,218,0,220,221,223,240,21,8,162,250,86,0,26,252,245,240,46,4,45,52,187,3,13,12,232,253,166,0,158,3,43,1,132,25,44,5,10,254,134,249,37,7,17,251,189,1,146,248,172,5,69,245,218,191,83,7,237,6,196,1,32,1,104,23,90,6,75,14,107,252,207,8,28,250,100,1,35,2,158,0,9,0,139,255,127,249,173,253,56,56,11,252,49,0,36,240,32,47,82,14,169,244,71,220,116,254,11,239,71,252,198,10,78,255,52,255,50,254,98,0,222,0,218,241,88,208,124,238,162,255,62,222,194,233,194,15,48,253,97,249,239,2,124,249,246,254,169,254,40,1,144,255,124,252,90,241,152,254,234,3,22,227,78,30,202,28,4,13,163,226,255,252,8,251,156,1,85,250,167,255,29,255,188,211,40,254,172,251,118,254,173,254,67,248,90,242,78,47,204,253,186,232,78,253,214,251,126,255,250,2,206,255,80,250,15,250,20,223,226,3,157,252,90,10,225,246,98,1,51,247,4,18,180,207,190,245,61,7,65,2,153,255,45,101,17,255,136,2,167,0,228,254,198,0,172,254,168,251,201,255,14,255,42,255,16,2,112,0,253,254,228,254,6,255,23,0,219,1,12,3,210,253,111,0,148,0,149,246,142,178,122,251,239,10,60,252,44,0,76,251,163,4,60,240,80,7,213,13,0,3,159,0,187,7,54,13,143,255,36,3,3,252,124,14,239,245,225,37,7,45,186,254,110,228,210,16,236,4,198,14,42,13,59,6,193,2,220,8,134,8,229,5,107,4,149,38,164,227,254,254,49,0,150,6,64,250,4,246,75,248,103,168,82,1,230,1,195,3,45,4,222,255,253,251,166,255,143,252,39,254,42,2,74,231,151,252,240,217,173,39,201,251,72,2,233,251,94,248,60,24,112,9,125,252,172,5,170,3,73,254,104,253,135,16,154,36,120,30,170,0,232,36,108,237,175,7,174,2,94,251,124,2,73,249,36,251,228,253,40,253,50,1,14,249,212,224,166,242,126,32,220,248,20,6,159,13,211,39,157,14,2,254,29,8,40,250,217,4,128,1,221,1,229,251,242,30,19,240,47,246,81,3,75,253,46,220,168,16,252,224,89,249,204,1,86,244,74,2,13,0,121,1,13,3,121,228,196,26,186,250,113,29,19,254,129,248,123,1,36,12,197,16,19,33,221,240,63,0,44,0,237,1,216,5,215,249,212,233,246,12,228,25,57,20,182,212,122,4,179,12,121,251,51,254,186,1,226,4,212,0,176,0,2,14,137,0,63,220,52,202,237,223,137,1,146,4,181,6,97,253,42,1,23,255,115,3,3,250,145,1,254,0,20,30,37,237,26,3,121,1,136,254,208,47,130,28,141,9,144,4,206,253,248,5,51,2,165,1,162,253,0,0,160,22,211,251,56,3,144,14,87,245,237,3,38,253,222,16,132,2,184,67,204,249,52,8,147,254,253,1,97,254,100,14,88,220,184,251,74,239,13,6,33,251,143,21,67,43,88,247,116,23,157,241,153,1,38,253,98,254,249,254,33,230,2,32,233,1,131,220,78,1,176,251,210,252,132,5,242,5,135,249,139,228,210,239,6,251,248,253,216,255,138,2,162,248,229,37,192,44,113,226,152,4,196,12,200,11,85,4,139,255,166,252,101,255,31,251,26,255,40,255,105,15,182,35,7,247,134,0,253,245,27,59,89,3,195,249,150,253,150,0,178,253,90,255,155,254,132,1,187,255,193,221,98,11,63,4,65,18,219,199,88,2,126,1,155,248,76,3,14,255,32,2,150,255,56,2,139,251,115,1,103,10,188,248,43,253,130,31,183,250,217,221,63,215,252,248,171,1,183,255,178,0,96,0,212,3,34,254,210,3,231,6,146,23,121,2,198,3,165,2,191,255,140,252,161,1,205,1,62,0,156,252,93,0,156,255,7,2,176,63,86,10,20,251,239,47,116,255,142,0,130,43,132,252,190,247,139,253,172,0,232,2,248,247,64,252,61,0,44,252,34,8,73,254,202,243,252,245,150,4,178,255,254,0,78,255,63,6,76,254,79,74,215,20,106,249,242,252,8,2,233,221,0,1,252,241,194,233,35,48,213,247,231,5,112,253,32,15,66,9,254,252,26,1,199,1,195,253,217,255,165,30,234,206,146,49,100,255,70,254,29,255,63,2,238,254,75,249,120,0,216,255,74,7,123,2,161,0,14,1,15,4,184,12,95,253,241,242,196,16,89,200,230,27,43,237,177,253,94,254,120,1,21,0,60,2,39,2,70,0,96,234,79,0,236,9,7,254,229,254,162,254,1,251,162,249,186,8,164,253,126,20,84,187,50,244,228,251,205,254,226,25,234,10,166,6,83,7,172,248,243,3,192,254,244,4,230,254,48,4,34,56,242,223,194,4,118,2,173,0,62,29,72,59,254,231,39,19,132,253,195,250,80,5,251,249,12,252,246,252,84,0,170,1,132,255,22,253,4,255,179,212,247,6,239,244,41,3,24,253,146,8,0,13,117,27,23,236,70,19,47,244,127,253,47,1,184,254,2,1,226,33,53,0,189,242,207,3,40,217,154,222,48,13,54,253,54,4,162,4,86,2,40,3,90,255,16,253,228,1,32,236,204,5,2,251,130,44,172,248,212,223,39,20,218,248,16,250,201,10,80,2,52,255,176,250,198,1,230,0,82,236,210,249,15,234,66,5,3,248,2,9,100,69,238,1,60,2,118,248,83,1,38,2,16,3,151,0,15,253,100,18,14,244,181,223,209,12,226,251,102,3,79,251,43,248,104,252,125,216,19,21,233,230,226,252,111,1,35,255,80,235,8,245,121,32,43,236,119,6,56,255,114,0,46,0,94,1,186,246,100,3,185,254,121,1,158,218,207,4,42,36,48,34,2,12,197,238,204,254,11,9,168,26,25,243,128,252,94,251,67,2,255,245,232,8,74,2,226,252,139,18,97,242,26,5,39,251,25,254,166,255,204,255,159,12,213,253,218,186,135,245,113,6,239,255,234,254,121,253,127,239,180,10,32,251,14,241,76,5,244,13,14,252,32,63,90,254,48,1,130,15,100,4,195,254,214,253,161,2,89,251,108,12,179,238,45,6,7,6,207,247,112,16,109,219,162,39,104,7,88,11,240,239,108,250,49,255,203,1,221,255,19,21,0,221,69,12,252,42,52,1,103,14,4,6,148,247,176,253,104,6,235,3,232,254,29,3,204,0,254,26,200,252,116,18,121,18,177,21,163,243,227,1,244,255,33,0,180,253,133,254,146,1,215,13,82,218,74,0,131,37,47,254,56,11,193,246,139,252,78,11,123,255,198,10,47,253,145,13,246,203,226,5,192,250,0,2,42,4,148,223,127,44,200,46,79,251,13,0,156,253,165,0,225,248,154,0,133,255,210,4,89,254,145,254,198,255,128,1,127,10,232,9,58,3,79,24,214,6,115,222,102,4,44,38,10,230,251,7,34,7,243,251,30,248,180,2,206,252,153,242,45,254,254,42,79,13,112,3,1,248,193,215,24,24,148,5,205,254,238,255,149,2,4,255,242,2,183,4,19,245,15,244,165,231,99,0,93,252,82,6,180,2,230,10,218,254,80,251,120,233,85,210,71,235,156,255,134,1,241,252,116,210,189,237,254,202,204,10,134,5,238,252,129,1,163,0,206,2,26,3,94,4,59,3,134,253,181,255,80,24,125,15,212,247,160,251,5,231,98,21,70,205,111,240,123,2,224,253,171,248,65,255,0,0,121,0,123,1,13,244,132,0,208,102,47,253,238,4,62,253,165,1,171,255,218,255,153,2,78,2,48,255,60,255,168,0,10,0,247,4,38,255,147,254,45,233,247,232,198,207,46,244,28,23,141,255,145,245,2,252,53,255,194,3,227,3,174,252,15,2,252,253,151,249,196,1,68,0,180,4,228,2,129,1,38,0,240,2,150,0,240,243,128,80,202,255,217,255,221,23,152,12,164,255,197,254,55,17,206,254,37,5,117,254,175,249,144,35,91,242,28,214,13,244,27,1,81,0,193,217,118,243,139,28,107,17,129,253,195,255,128,4,72,255,242,8,142,1,170,244,40,245,168,249,129,4,242,0,95,221,223,241,53,1,99,209,249,240,138,233,163,12,103,255,197,254,126,1,209,0,101,252,24,8,202,1,164,0,47,14,49,12,148,12,196,252,60,222,167,8,33,15,157,48,21,2,137,253,203,255,120,255,40,253,16,255,164,1,54,11,139,236,138,3,56,243,127,18,29,14,108,9,145,240,165,214,221,28,52,2,194,12,188,250,12,2,34,6,211,25,26,13,238,251,70,7,68,7,93,251,129,22,70,249,39,32,252,226,226,233,215,4,185,244,38,255,42,3,217,251,230,58,174,2,186,246,219,254,17,248,11,255,89,17,181,19,76,4,66,26,251,6,181,253,132,254,132,0,4,20,66,207,95,0,50,251,184,5,177,248,161,3,150,5,106,10,72,241,224,10,143,241,210,223,9,255,91,2,42,223,50,5,9,4,25,253,14,246,179,10,88,3,102,206,150,236,242,8,176,251,34,0,232,251,176,255,122,2,73,253,172,255,70,9,39,159,216,251,200,251,2,255,212,252,252,0,210,249,111,254,253,2,79,3,84,1,223,1,165,243,150,0,69,255,240,32,47,10,27,8,104,5,167,1,63,227,234,215,50,247,54,0,41,4,40,0,89,3,222,7,44,236,198,0,145,2,226,1,90,254,119,247,174,252,194,254,164,0,84,253,138,10,16,252,85,68,192,255,124,229,178,232,240,199,211,246,188,9,10,1,53,4,143,7,157,255,174,16,15,9,169,246,11,3,187,0,186,255,236,237,238,239,240,241,242,243,244,245,28,2,0,6,58,246,247,248,249,250,251,252,253,254,255,0,0,0,0,0,0,0,8,8,8,8,8,8,8,8,8,8,5,2,1,3,6,8,8,8,8,8,8,8,8,8,8,0,0,0,0,0,0,0,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,221,31,222,31,223,31,224,31,225,31,226,31,227,31,228,31,229,31,230,31,231,31,242,7,253,0,62,0,14,0,6,0,0,0,2,0,30,0,252,0,248,3,204,31,232,31,233,31,234,31,235,31,236,31,205,31,237,31,238,31,239,31,240,31,241,31,242,31,243,31,244,31,245,31,246,31,247,31,248,31,249,31,250,31,251,31,252,31,253,31,254,31,254,63,255,63,0,0,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,11,8,6,4,3,1,2,5,8,10,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,0,242,31,243,31,244,31,245,31,246,31,247,31,248,31,248,15,254,0,126,0,14,0,6,0,0,0,2,0,30,0,62,0,254,1,249,31,250,31,251,31,252,31,253,31,254,31,254,63,255,63,0,0,0,0,0,0,13,13,13,13,13,13,13,12,8,7,4,3,1,2,5,6,9,13,13,13,13,13,13,14,14,0,0,0,0,0,0,0,228,255,0,0,229,255,0,0,230,255,0,0,231,255,0,0,232,255,0,0,233,255,0,0,234,255,0,0,235,255,0,0,236,255,0,0,237,255,0,0,238,255,0,0,239,255,0,0,240,255,0,0,241,255,0,0,242,255,0,0,243,255,0,0,244,255,0,0,226,255,0,0,252,15,0,0,252,7,0,0,254,1,0,0,126,0,0,0,30,0,0,0,6,0,0,0,0,0,0,0,2,0,0,0,14,0,0,0,62,0,0,0,254,0,0,0,253,7,0,0,253,15,0,0,240,127,0,0,227,255,0,0,245,255,0,0,246,255,0,0,247,255,0,0,248,255,0,0,249,255,0,0,250,255,0,0,246,255,1,0,247,255,1,0,248,255,1,0,249,255,1,0,250,255,1,0,251,255,1,0,252,255,1,0,253,255,1,0,254,255,1,0,255,255,1,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,11,9,7,5,3,1,2,4,6,8,11,12,15,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,17,17,0,0,0,0,0,0,0,237,255,3,0,238,255,3,0,222,255,7,0,223,255,7,0,224,255,7,0,225,255,7,0,226,255,7,0,227,255,7,0,228,255,7,0,229,255,7,0,230,255,7,0,231,255,7,0,232,255,7,0,233,255,7,0,234,255,7,0,235,255,7,0,236,255,7,0,244,255,1,0,247,255,0,0,249,255,0,0,248,255,0,0,251,63,0,0,250,63,0,0,248,63,0,0,250,31,0,0,252,15,0,0,252,7,0,0,254,0,0,0,62,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,30,0,0,0,126,0,0,0,254,1,0,0,253,7,0,0,251,31,0,0,249,63,0,0,252,63,0,0,250,127,0,0,246,255,0,0,245,255,1,0,236,255,3,0,237,255,7,0,238,255,7,0,239,255,7,0,240,255,7,0,241,255,7,0,242,255,7,0,243,255,7,0,244,255,7,0,245,255,7,0,246,255,7,0,247,255,7,0,248,255,7,0,249,255,7,0,250,255,7,0,251,255,7,0,252,255,7,0,253,255,7,0,254,255,7,0,255,255,7,0,0,0,0,0,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,17,16,16,16,14,14,14,13,12,11,8,6,4,2,1,3,5,7,9,11,13,14,14,15,16,17,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,214,255,3,0,215,255,3,0,216,255,3,0,217,255,3,0,218,255,3,0,219,255,3,0,184,255,7,0,185,255,7,0,186,255,7,0,187,255,7,0,188,255,7,0,189,255,7,0,190,255,7,0,191,255,7,0,192,255,7,0,193,255,7,0,194,255,7,0,195,255,7,0,196,255,7,0,197,255,7,0,198,255,7,0,199,255,7,0,200,255,7,0,201,255,7,0,202,255,7,0,203,255,7,0,204,255,7,0,205,255,7,0,206,255,7,0,207,255,7,0,208,255,7,0,209,255,7,0,210,255,7,0,211,255,7,0,230,255,1,0,212,255,3,0,240,255,0,0,233,255,1,0,213,255,3,0,231,255,1,0,241,255,0,0,236,255,0,0,237,255,0,0,238,255,0,0,244,127,0,0,249,63,0,0,247,63,0,0,250,31,0,0,249,31,0,0,251,15,0,0,252,7,0,0,252,3,0,0,253,1,0,0,253,0,0,0,125,0,0,0,61,0,0,0,29,0,0,0,13,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,12,0,0,0,28,0,0,0,60,0,0,0,124,0,0,0,252,0,0,0,252,1,0,0,253], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+389137);
/* memory initializer */ allocate([3,0,0,250,15,0,0,248,31,0,0,246,63,0,0,248,63,0,0,245,127,0,0,239,255,0,0,232,255,1,0,242,255,0,0,212,255,7,0,213,255,7,0,214,255,7,0,215,255,7,0,216,255,7,0,217,255,7,0,218,255,7,0,219,255,7,0,220,255,7,0,221,255,7,0,222,255,7,0,223,255,7,0,224,255,7,0,225,255,7,0,226,255,7,0,227,255,7,0,228,255,7,0,229,255,7,0,230,255,7,0,231,255,7,0,232,255,7,0,233,255,7,0,234,255,7,0,235,255,7,0,236,255,7,0,237,255,7,0,238,255,7,0,239,255,7,0,240,255,7,0,241,255,7,0,242,255,7,0,243,255,7,0,244,255,7,0,245,255,7,0,246,255,7,0,247,255,7,0,248,255,7,0,249,255,7,0,250,255,7,0,251,255,7,0,252,255,7,0,253,255,7,0,254,255,7,0,255,255,7,0,0,0,0,0,18,18,18,18,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,17,18,16,17,18,17,16,16,16,16,15,14,14,13,13,12,11,10,9,8,7,6,5,4,3,2,2,3,4,5,6,7,8,9,10,12,13,14,14,15,16,17,16,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,0,0,0,0,0,0,6,14,43,52,2,67,1,1,13,1,3,1,4,1,2,1,6,14,43,52,2,5,1,1,13,1,3,1,4,1,1,0,92,32,81,63,166,10,134,189,14,190,48,62,80,141,151,60,225,11,19,189,200,152,59,61,0,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,5,162,19,63,205,177,20,63,122,195,21,63,31,215,22,63,187,236,23,63,96,4,25,63,0,30,26,63,0,60,27,63,0,90,28,63,0,122,29,63,0,158,30,63,0,196,31,63,0,234,32,63,0,20,34,63,0,64,35,63,0,108,36,63,0,156,37,63,0,206,38,63,0,2,40,63,0,58,41,63,0,114,42,63,0,172,43,63,0,234,44,63,0,42,46,63,0,108,47,63,0,176,48,63,0,246,49,63,0,62,51,63,0,138,52,63,0,216,53,63,0,40,55,63,0,122,56,63,0,208,57,63,0,38,59,63,0,128,60,63,0,220,61,63,0,60,63,63,0,156,64,63,0,0,66,63,0,104,67,63,0,208,68,63,0,60,70,63,0,170,71,63,0,28,73,63,0,142,74,63,0,4,76,63,0,126,77,63,0,250,78,63,0,120,80,63,0,250,81,63,0,126,83,63,0,4,85,63,0,142,86,63,0,26,88,63,0,170,89,63,0,60,91,63,0,208,92,63,0,104,94,63,0,4,96,63,0,162,97,63,0,66,99,63,0,230,100,63,0,142,102,63,0,56,104,63,0,228,105,63,0,148,107,63,0,72,109,63,0,254,110,63,0,184,112,63,0,116,114,63,0,52,116,63,0,248,117,63,0,190,119,63,0,136,121,63,0,86,123,63,0,38,125,63,0,174,126,63,0,162,127,63,0,254,127,63,0,198,127,63,0,250,126,63,0,152,125,63,0,160,123,63,0,24,121,63,0,252,117,63,0,80,114,63,0,24,110,63,0,84,105,63,0,8,100,63,0,56,94,63,0,228,87,63,0,18,81,63,0,200,73,63,0,6,66,63,0,212,57,63,0,52,49,63,0,44,40,63,0,196,30,63,0,254,20,63,0,224,10,63,0,114,0,63,0,112,235,62,0,116,213,62,0,252,190,62,0,20,168,62,0,200,144,62,0,88,114,62,0,136,66,62,0,72,18,62,0,112,195,61,0,160,67,61,0,0,0,0,0,0,125,63,0,9,122,63,229,26,119,63,148,53,116,63,243,88,113,63,232,132,110,63,89,185,107,63,45,246,104,63,74,59,102,63,152,136,99,63,254,221,96,63,100,59,94,63,178,160,91,63,208,13,89,63,167,130,86,63,31,255,83,63,34,131,81,63,153,14,79,63,109,161,76,63,137,59,74,63,214,220,71,63,63,133,69,63,175,52,67,63,17,235,64,63,80,168,62,63,87,108,60,63,18,55,58,63,109,8,56,63,84,224,53,63,179,190,51,63,119,163,49,63,141,142,47,63,225,127,45,63,97,119,43,63,251,116,41,63,156,120,39,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,16,0,17,0,18,0,19,0,20,0,32,0,33,0,34,0,35,0,48,0,49,0,50,0,64,0,65,0,80,0,0,1,1,1,2,1,3,1,4,1,16,1,17,1,18,1,19,1,32,1,33,1,34,1,48,1,49,1,64,1,0,2,1,2,2,2,3,2,16,2,17,2,18,2,32,2,33,2,48,2,0,3,1,3,2,3,16,3,17,3,32,3,0,4,1,4,16,4,0,5,0,16,1,16,2,16,3,16,4,16,16,16,17,16,18,16,19,16,32,16,33,16,34,16,48,16,49,16,64,16,0,17,1,17,2,17,3,17,16,17,17,17,18,17,32,17,33,17,48,17,0,18,1,18,2,18,16,18,17,18,32,18,0,19,1,19,16,19,0,20,0,32,1,32,2,32,3,32,16,32,17,32,18,32,32,32,33,32,48,32,0,33,1,33,2,33,16,33,17,33,32,33,0,34,1,34,16,34,0,35,0,48,1,48,2,48,16,48,17,48,32,48,0,49,1,49,16,49,0,50,0,64,1,64,16,64,0,65,0,80,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,32,33,34,35,36,37,38,39,40,41,42,43,44,45,48,49,50,51,52,53,54,55,56,57,58,59,60,64,65,66,67,68,69,70,71,72,73,74,75,80,81,82,83,84,85,86,87,88,89,90,96,97,98,99,100,101,102,103,104,105,112,113,114,115,116,117,118,119,120,128,129,130,131,132,133,134,135,144,145,146,147,148,149,150,160,161,162,163,164,165,176,177,178,179,180,192,193,194,195,208,209,210,224,225,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,32,35,0,16,38,33,0,236,8,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,17,0,0,0,72,32,35,0,128,3,32,0,144,43,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,200,123,30,0,200,123,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,72,237,29,0,72,237,29,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,144,128,29,0,144,128,29,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,184,38,29,0,128,215,28,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,200,209,35,0,104,130,35,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,184,36,35,0,168,222,34,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,240,161,34,0,168,101,34,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,128,46,34,0,128,46,34,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,48,255,33,0,48,255,33,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,184,209,33,0,168,171,33,0,0,0,0,0,128,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,232,140,33,0,64,106,33,0,0,0,0,0,128,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,152,40,33,0,112,3,33,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,128,232,32,0,200,205,32,0,0,0,0,0,128,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,0,179,32,0,240,157,32,0,0,0,0,0,128,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,240,131,32,0,128,110,140,0,0,0,0,0,128,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,104,85,32,0,128,60,32,0,0,0,0,0,128,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,32,35,0,96,5,32,0,64,237,31,0,8,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,144,216,31,0,168,198,31,0,12,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,16,176,31,0,208,157,31,0,152,76,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,88,139,31,0,208,122,31,0,16,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,40,108,31,0,64,87,31,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,116,64,17,0,0,0,0,0,0,0,200,45,31,0,8,28,31,0,52,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,116,64,17,0,0,0,0,0,0,0,184,15,31,0,184,0,31,0,252,43,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,48,240,30,0,168,226,30,0,0,44,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,96,213,30,0,128,198,30,0,104,0,0,0,3,0,0,0,0,0,0,0,0,36,254,64,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,120,183,30,0,184,164,30,0,112,0,0,0,3,0,0,0,0,0,0,0,0,36,254,64,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,120,125,30,0,96,110,30,0,28,44,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,17,0,0,0,0,0,0,0,104,97,30,0,160,83,30,0,20,44,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,17,0,0,0,0,0,0,0,48,67,30,0,240,55,30,0,32,44,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,17,0,0,0,0,0,0,0,16,45,30,0,32,35,30,0,24,44,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,17,0,0,0,0,0,0,0,208,27,30,0,208,15,30,0,164,93,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,17,0,0,0,208,27,30,0,224,237,29,0,144,228,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,27,30,0,96,220,29,0,136,211,29,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,27,30,0,184,202,29,0,56,194,29,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,27,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,152,20,33,0,50,2,0,0,208,29,6,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,160,0,0,0,20,0,0,0,140,0,0,0,172,0,0,0,22,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,2,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,3,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,255,255,255,255,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,13,0,0,0,16,0,0,0,0,0,1,0,0,0,0,0,13,16,1,0,1,0,0,0,1,80,1,0,2,0,0,0,0,0,1,0,3,0,0,0,0,0,0,0,0,0,0,0,4,4,4,4,4,4,8,8,8,16,28,36,0,0,0,0,4,4,4,4,4,4,4,8,8,8,8,12,16,20,20,0,4,4,4,4,4,8,8,8,12,12,12,16,16,16,0,0,4,4,4,4,4,4,4,8,8,8,12,12,16,16,20,0,4,4,4,4,4,4,4,4,8,8,12,12,16,20,20,0,152,38,6,0,152,38,6,0,152,38,6,0,184,38,6,0,184,38,6,0,184,38,6,0,200,38,6,0,200,38,6,0,216,38,6,0,216,38,6,0,216,38,6,0,168,38,6,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,12,12,12,12,12,16,16,24,28,36,44,64,64,64,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,12,12,12,12,12,12,12,12,12,12,12,12,12,16,16,16,16,16,16,16,20,20,20,20,24,24,24,28,28,32,36,36,40,44,48,52,56,60,64,80,4,4,4,4,4,4,4,4,4,4,4,4,4,4,8,8,8,8,12,12,12,16,16,16,20,24,24,28,36,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,0,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,12,12,12,12,16,16,20,20,24,24,28,28,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,96,0,0,0,0,0,0,0,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,12,12,12,12,16,16,20,20,24,24,28,28,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,4,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,8,8,8,12,12,12,12,16,16,16,20,20,24,24,28,28,32,36,36,40,44,48,52,52,64,64,64,64,64,0,8,8,8,8,8,8,8,8,8,8,8,12,12,12,12,12,12,12,12,12,16,16,16,16,20,20,20,24,24,28,28,32,36,40,40,44,48,52,56,60,64,64,64,0,0,0,0,0,24,39,6,0,24,39,6,0,112,39,6,0,160,39,6,0,160,39,6,0,216,39,6,0,16,40,6,0,16,40,6,0,64,40,6,0,64,40,6,0,64,40,6,0,72,39,6,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,48,0,52,0,56,0,60,0,68,0,76,0,84,0,92,0,100,0,112,0,124,0,136,0,148,0,164,0,184,0,208,0,236,0,12,1,44,1,76,1,108,1,140,1,172,1,204,1,0,2,0,0,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,48,0,52,0,56,0,64,0,72,0,80,0,88,0,96,0,108,0,120,0,132,0,144,0,160,0,176,0,192,0,212,0,236,0,4,1,32,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,52,0,60,0,68,0,80,0,92,0,104,0,120,0,140,0,164,0,192,0,224,0,0,1,32,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,0,0,4,0,8,0,12,0,16,0,20,0,24,0,32,0,40,0,48,0,64,0,92,0,128,0,0,0,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,36,0,44,0,52,0,60,0,72,0,88,0,108,0,128,0,0,0,4,0,8,0,12,0,16,0,20,0,28,0,36,0,44,0,56,0,68,0,80,0,96,0,112,0,128,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,36,0,44,0,52,0,64,0,76,0,92,0,108,0,128,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,40,0,48,0,60,0,72,0,88,0,108,0,128,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,48,0,52,0,56,0,64,0,72,0,80,0,88,0,96,0,108,0,120,0,132,0,144,0,156,0,172,0,188,0,212,0,240,0,20,1,64,1,128,1,192,1,0,2,64,2,128,2,192,2,0,3,64,3,128,3,192,3,0,4,0,0,0,0,0,0,12,0,24,0,36,0,48,0,60,0,72,0,84,0,96,0,108,0,120,0,132,0,144,0,156,0,172,0,188,0,204,0,220,0,236,0,252,0,12,1,32,1,52,1,72,1,92,1,116,1,140,1,164,1,192,1,220,1,252,1,32,2,68,2,108,2,152,2,200,2,252,2,52,3,112,3,176,3,0,4,0,0,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,48,0,52,0,56,0,64,0,72,0,80,0,88,0,100,0,112,0,124,0,140,0,156,0,172,0,192,0,216,0,240,0,12,1,48,1,88,1,128,1,168,1,208,1,248,1,32,2,72,2,112,2,152,2,192,2,232,2,16,3,56,3,96,3,136,3,176,3,216,3,0,4,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,48,0,56,0,64,0,72,0,80,0,88,0,96,0,108,0,120,0,132,0,144,0,160,0,176,0,196,0,216,0,240,0,8,1,36,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,32,2,64,2,96,2,128,2,160,2,192,2,224,2,0,3,32,3,64,3,96,3,128,3,160,3,0,4,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,48,0,56,0,64,0,72,0,80,0,88,0,96,0,108,0,120,0,132,0,144,0,160,0,176,0,196,0,216,0,240,0,8,1,36,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,32,2,64,2,96,2,128,2,160,2,192,2,224,2,0,3,32,3,64,3,96,3,128,3,160,3,192,3,224,3,0,4,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,52,0,60,0,68,0,76,0,84,0,92,0,100,0,108,0,116,0,124,0,136,0,148,0,160,0,172,0,188,0,204,0,220,0,240,0,4,1,28,1,52,1,80,1,108,1,140,1,176,1,212,1,252,1,40,2,88,2,140,2,192,2,0,3,64,3,128,3,192,3,0,4,0,0,8,0,16,0,24,0,32,0,40,0,48,0,56,0,64,0,72,0,80,0,88,0,100,0,112,0,124,0,136,0,148,0,160,0,172,0,184,0,196,0,212,0,228,0,244,0,4,1,24,1,44,1,64,1,88,1,112,1,140,1,168,1,200,1,236,1,20,2,60,2,104,2,152,2,204,2,4,3,64,3,128,3,192,3,0,4,240,1,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,1,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,6,10,3,7,11,4,8,5,9,12,13,14,15,2,255,255,255,255,2,1,255,255,255,1,2,255,255,255,2,1,255,255,255,1,2,255,255,255,1,2,255,255,255,0,2,255,255,255,0,2,1,4,3,0,1,2,4,3,0,2,1,4,3,2,0,1,3,4,0,4,2,1,3,2,0,255,255,255,2,1,0,4,3,1,2,4,0,3,2,1,0,4,3,2,1,4,3,0,1,2,4,0,3,2,0,255,255,255,2,0,1,4,3,1,2,0,4,3,2,1,0,4,3,2,1,3,4,0,2,4,1,0,3,0,2,255,255,255,0,2,1,3,4,1,2,3,0,4,2,0,1,3,4,2,1,3,0,4,2,0,4,3,1,0,2,255,255,255,0,2,4,1,3,1,4,2,0,3,4,2,0,1,3,2,0,1,4,3,4,2,1,0,3,0,0,0,0,0,0,1,0,0,1,0,2,1,1,2,0,3,0,2,1,1,2,0,3,0,4,1,3,2,2,3,1,4,0,4,1,3,2,2,3,1,4,2,4,3,3,4,2,4,3,3,4,4,4,0,0,0,0,0,0,41,15,0,0,255,16,0,0,26,19,0,0,105,21,0,0,10,24,0,0,2,27,0,0,81,30,0,0,14,34,0,0,53,38,0,0,235,42,0,0,51,48,0,0,4,54,0,0,163,60,0,0,27,68,0,0,105,76,0,0,113,85,0,0,232,95,0,0,8,108,0,0,127,120,0,0,54,136,0,0,151,151,0,0,227,170,0,0,207,191,0,0,155,213,0,0,254,240,0,0,137,12,1,0,47,47,1,0,25,92,1,0,157,135,1,0,54,171,1,0,171,238,1,0,221,40,2,0,200,128,10,0,96,0,0,0,168,45,6,0,80,177,22,0,0,0,0,1,1,1,2,1,0,2,3,1,4,1,5,1,0,3,1,2,2,2,6,1,7,1,8,1,9,1,0,4,0,0,0,1,1,1,0,2,2,1,0,3,0,4,0,5,3,1,4,1,1,2,1,3,0,6,0,7,0,8,0,9,0,0,0,255,255,255,255,254,0,255,255,0,255,0,1,0,1,0,255,1,0,0,255,1,255,0,0,0,255,1,0,0,255,0,0,1,255,1,0,255,255,0,1,1,0,0,255,1,0,1,0,0,1,255,0,0,0,255,1,0,1,0,254,1,0,255,1,0,0,0,1,0,255,0,0,0,255,0,0,0,0,1,1,0,0,255,0,1,0,0,0,0,255,1,1,255,255,254,0,255,1,0,255,0,255,252,255,254,255,254,1,254,0,0,4,254,255,1,1,0,2,1,1,0,2,0,0,0,1,1,0,255,255,255,1,0,255,253,253,1,255,1,254,255,1,255,0,1,2,1,255,255,1,1,1,2,1,0,1,254,254,0,255,254,254,0,255,255,255,0,1,0,255,255,0,255,0,2,1,2,2,1,255,1,0,2,0,255,1,0,0,0,254,0,255,255,1,1,254,0,254,0,1,254,254,1,255,255,3,254,0,253,252,253,2,1,0,3,254,2,3,2,2,255,253,1,0,1,0,0,0,1,254,1,254,254,255,254,254,2,0,252,0,2,255,0,2,2,2,1,0,255,255,1,253,2,2,1,0,3,1,255,1,3,1,0,1,1,2,255,1,255,254,255,0,255,1,255,1,254,254,255,255,253,1,252,253,1,254,0,254,3,255,255,0,2,2,255,253,2,1,0,254,255,253,254,254,1,2,253,0,1,251,254,253,0,254,255,2,0,255,255,0,254,1,3,249,254,254,255,2,255,0,3,1,3,1,0,0,1,2,3,1,2,0,254,254,1,1,2,2,3,4,1,255,2,254,4,0,0,0,4,2,0,254,254,2,252,255,5,254,254,253,2,253,255,3,253,0,4,3,0,1,254,4,4,3,2,2,1,0,255,4,3,3,2,1,0,255,255,3,3,2,2,1,0,255,254,3,2,2,1,0,255,254,253,2,2,1,0,255,255,254,253,2,1,0,0,255,254,253,252,1,0,0,255,254,253,252,252,0,0,255,254,254,253,252,252,2,3,3,3,3,3,3,3,2,2,2,2,2,2,3,3,1,2,2,2,2,2,2,2,0,1,1,1,1,1,1,1,255,0,0,0,0,0,1,1,254,254,255,255,255,255,255,255,253,253,253,253,253,253,254,254,251,252,252,252,252,252,252,253,252,254,255,0,1,2,2,3,252,254,255,0,1,2,3,3,252,253,255,0,1,2,3,3,252,253,255,0,1,2,3,3,251,253,255,0,1,2,3,3,251,253,255,0,1,2,3,3,251,253,255,0,1,1,2,3,251,253,254,255,0,1,2,3,4,4,5,5,6,6,7,7,2,2,2,3,3,4,4,4,0,0,0,0,1,1,1,2,254,254,254,254,255,255,255,0,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,254,254,254,254,254,254,254,255,255,255,255,254,254,254,254,5,3,1,255,254,253,253,253,5,3,1,255,254,253,253,253,5,3,1,255,254,253,253,253,5,3,1,255,254,253,253,253,5,4,1,0,254,253,253,253,6,4,2,0,254,254,253,253,6,4,2,0,255,254,254,253,6,4,2,1,255,254,254,254,255,1,3,3,2,0,253,250,255,1,3,4,3,0,253,250,255,1,4,4,3,1,253,250,255,1,3,4,3,1,253,250,254,1,3,4,3,1,253,250,254,1,3,4,3,1,253,249,254,1,3,3,2,0,253,249,254,0,2,3,2,0,253,250,10,9,8,6,6,5,4,4,6,5,4,3,2,2,2,1,2,1,0,255,254,254,254,255,255,254,253,252,252,252,252,253,254,253,252,252,251,252,252,253,254,254,253,253,253,253,254,254,255,255,255,255,255,255,255,0,1,1,1,1,1,1,1,2,254,255,1,2,4,5,7,8,253,254,0,1,3,5,7,8,252,253,255,0,2,4,6,7,251,252,254,255,1,3,5,7,250,251,253,254,0,2,4,6,250,251,252,254,255,1,3,5,249,250,251,253,254,0,2,3,248,249,251,252,253,255,1,2,11,9,7,5,3,1,255,255,10,8,6,3,1,0,254,254,9,7,5,2,0,254,253,252,8,6,3,1,255,253,252,252,6,4,2,255,253,252,251,251,5,3,0,254,252,251,250,250,3,1,255,253,251,250,249,249,2,0,254,252,250,250,249,249,5,6,7,7,7,8,8,8,3,4,5,5,6,6,6,6,0,2,2,3,4,4,4,5,254,255,0,1,2,2,3,3,252,253,254,255,0,1,1,2,250,251,252,253,254,254,255,0,248,249,250,250,251,252,253,253,246,247,248,248,249,250,250,251,6,5,3,1,255,253,250,248,6,5,4,2,255,253,250,248,6,5,4,2,0,253,250,248,6,5,4,2,0,253,250,248,6,6,4,2,0,253,250,248,6,5,4,2,0,253,250,248,6,5,4,2,0,253,250,248,6,5,4,2,255,253,251,248,11,10,9,8,7,6,5,4,8,8,7,6,5,4,3,2,6,5,4,4,2,2,1,0,3,3,2,1,0,0,255,254,1,1,0,255,254,254,253,253,255,255,254,253,252,252,251,251,253,252,252,251,250,250,249,249,251,251,250,249,248,248,248,248,242,243,244,245,247,249,250,252,244,245,246,247,249,251,253,255,246,247,249,250,253,254,0,2,248,250,252,254,0,2,4,5,251,253,0,2,4,5,7,8,254,0,2,4,6,8,9,10,0,3,5,7,8,10,11,12,3,5,7,8,10,11,12,12,237,237,238,238,239,240,241,242,241,241,242,243,244,245,246,247,245,246,247,248,250,251,252,253,250,251,253,254,255,0,1,2,255,0,2,3,4,5,6,6,4,6,7,8,9,10,10,10,9,10,11,12,13,14,14,14,12,14,14,15,16,16,16,16,22,21,19,17,14,11,9,5,20,19,17,14,11,8,4,1,17,15,13,10,6,3,0,252,13,11,8,5,1,254,251,247,9,6,3,255,252,249,245,243,4,0,253,250,247,244,241,239,254,251,248,245,242,240,238,236,248,246,243,240,239,237,235,234,17,18,18,18,17,16,16,14,16,16,15,15,14,13,12,11,12,12,11,10,9,8,7,5,7,6,6,4,3,2,1,255,1,0,255,254,253,252,251,250,251,250,249,248,247,246,245,244,245,244,243,242,241,240,240,239,240,239,239,238,237,236,236,236,0,0,0,0,255,255,254,253,1,0,0,0,0,255,254,253,1,1,0,0,255,255,254,254,1,1,1,0,0,255,255,254,2,1,1,1,0,255,255,254,2,2,1,1,0,0,255,254,2,2,1,1,1,0,255,255,2,2,1,1,1,0,0,254,0,255,255,0,0,1,2,3,0,255,255,0,1,1,2,2,255,255,255,255,0,1,2,2,255,255,254,255,0,1,1,2,255,254,254,255,0,0,1,2,255,254,254,254,255,0,1,2,255,255,254,255,0,0,1,2,255,255,255,255,0,1,1,2,3,2,2,2,1,1,0,0,3,2,2,2,2,1,0,0,2,2,2,1,1,1,0,0,2,2,1,1,1,0,0,255,1,1,1,0,0,0,255,255,0,0,255,255,255,255,255,255,254,254,254,254,254,254,254,254,254,253,253,253,254,254,254,254,5,2,0,0,255,0,0,0,4,2,0,255,255,255,0,255,4,1,255,255,254,255,255,255,4,1,255,255,254,255,255,255,4,1,255,254,254,255,255,255,4,1,255,254,254,255,255,255,4,1,255,255,255,255,255,255,4,2,0,255,0,0,0,255,254,255,0,1,1,1,1,1,253,255,0,1,1,1,1,1,253,255,0,1,1,1,1,1,253,255,0,1,1,1,1,1,253,254,0,1,2,2,1,1,252,254,0,1,2,2,2,2,251,253,255,1,1,2,1,2,251,253,254,0,1,1,1,1,3,3,1,0,254,252,252,251,3,3,2,0,255,254,253,252,2,2,1,1,0,255,254,254,1,1,1,1,1,0,0,0,0,0,0,1,1,1,1,1,254,255,255,0,0,1,2,2,253,254,254,255,0,1,2,3,253,253,254,255,0,1,2,3,253,253,253,253,253,254,254,254,253,253,254,254,254,255,255,255,254,254,254,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,1,1,2,2,2,2,1,1,1,2,2,3,3,3,2,2,2,2,3,3,3,3,248,249,251,253,254,255,0,255,252,253,255,0,1,2,1,1,255,1,2,3,3,2,2,1,1,2,3,3,2,2,1,0,2,3,3,2,1,0,0,255,1,2,1,0,255,255,255,255,1,1,0,255,255,254,254,255,1,1,0,0,255,255,0,255,252,253,254,0,1,2,3,3,252,253,254,0,1,2,2,2,253,253,254,255,0,1,1,1,254,254,254,255,255,0,0,0,0,255,255,255,255,255,255,255,2,1,1,0,0,255,255,254,3,3,3,1,0,255,254,254,5,4,4,2,1,0,255,254,0,0,0,0,1,2,3,3,0,255,0,0,1,2,3,3,0,255,0,0,1,2,3,2,0,0,0,1,1,2,2,2,2,1,1,1,1,1,1,0,2,2,2,1,0,0,255,254,2,1,0,0,254,253,251,250,0,255,255,253,251,250,248,247,254,0,1,2,2,1,255,252,254,0,2,2,2,1,255,252,254,0,2,2,2,1,255,253,254,0,2,2,2,1,255,253,254,255,2,2,2,1,255,253,254,255,1,2,2,1,255,253,253,255,1,2,2,1,255,253,254,255,1,2,2,1,255,253,255,1,1,255,253,253,0,4,255,1,1,255,253,253,0,4,255,1,1,0,253,253,0,4,255,1,2,0,253,253,0,5,0,1,2,0,253,252,0,4,0,1,2,0,253,252,0,5,0,1,2,0,253,253,0,4,0,1,2,255,254,254,0,4,6,6,5,6,5,5,5,5,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,255,255,255,255,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,2,2,2,2,2,2,2,2,0,1,1,0,0,0,0,0,255,254,254,254,254,254,254,255,253,253,253,253,253,253,253,254,253,252,252,253,253,253,254,254,254,254,254,254,255,255,0,0,0,1,1,1,2,2,3,3,3,4,4,5,5,6,6,6,4,1,254,253,253,255,1,3,4,1,254,252,253,255,1,3,5,1,254,252,253,255,1,4,5,1,254,253,253,255,2,4,5,1,254,253,253,255,2,4,4,0,253,252,253,255,2,4,4,0,253,253,253,255,1,3,3,0,254,253,254,255,1,3,253,252,252,252,252,252,252,252,255,255,255,255,255,255,254,254,2,1,1,2,2,1,1,1,3,3,3,4,4,3,3,3,3,3,3,4,4,4,3,3,1,2,1,2,2,2,2,2,254,254,254,255,255,255,0,0,252,252,252,252,253,253,253,253,255,254,253,253,254,254,255,0,0,255,254,254,254,255,0,1,2,1,255,255,255,255,0,1,3,1,0,255,255,0,0,1,3,2,0,255,0,0,0,1,3,1,0,255,0,0,0,1,3,1,0,255,0,0,0,1,2,1,0,0,0,0,0,1,0,0,0,1,1,2,3,4,0,0,255,0,0,0,2,3,0,255,255,255,255,255,0,1,0,255,255,255,255,255,255,0,0,0,255,255,255,254,254,255,1,0,0,255,255,254,254,255,2,2,1,0,255,255,255,255,3,3,2,1,0,255,255,0,1,0,1,0,0,255,254,255,0,0,0,0,255,255,254,255,0,255,0,0,255,255,255,255,255,255,255,0,0,0,0,0,255,255,255,0,0,0,1,1,255,255,255,0,1,1,2,3,254,254,255,0,1,2,3,4,254,254,255,0,1,2,4,5,253,255,1,0,0,255,0,1,253,0,1,0,255,255,0,2,253,0,1,0,255,255,0,2,254,1,2,0,255,255,0,2,254,1,2,0,255,255,0,2,254,1,2,0,255,255,0,2,255,2,2,0,255,255,0,2,255,1,1,0,255,255,255,1,254,254,255,1,3,4,3,1,254,254,255,0,2,3,2,0,254,254,255,0,1,2,1,255,255,255,255,0,1,2,1,255,255,255,255,0,1,1,0,254,0,255,255,0,1,1,0,255,0,255,255,0,1,1,1,255,0,255,255,0,0,1,0,255,254,255,0,1,1,1,1,1,254,255,0,0,0,0,0,0,254,255,255,0,255,255,254,254,254,255,255,255,255,254,254,253,255,0,1,1,0,255,254,254,1,2,3,3,2,1,0,0,1,2,3,3,3,2,1,0,0,0,1,1,1,1,0,0,0,255,255,255,0,0,0,0,1,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,1,1,1,1,1,255,0,0,1,1,0,0,0,253,254,255,255,255,255,0,255,251,251,252,253,254,254,254,255,1,1,1,1,2,1,0,255,1,1,1,2,1,1,0,255,1,1,1,1,1,1,0,254,2,1,1,1,1,1,0,254,1,1,0,0,0,0,255,253,1,1,0,0,0,255,254,253,1,1,0,0,255,255,254,252,1,0,0,255,254,254,253,252,8,7,5,3,2,1,1,1,2,1,0,0,255,255,254,255,255,255,255,254,254,254,254,255,255,255,255,255,0,255,255,0,0,0,0,1,1,0,0,0,0,0,1,1,1,0,0,0,255,0,0,0,0,0,255,255,254,254,255,255,255,254,254,255,9,4,0,254,254,254,255,255,7,2,255,254,254,255,0,0,4,0,254,254,255,0,1,1,1,254,254,254,255,0,1,1,255,254,254,255,0,1,1,1,255,254,255,0,1,1,1,0,255,255,0,1,1,1,0,255,0,255,0,1,0,0,255,255,0,1,1,1,1,1,0,0,1,2,2,2,1,0,0,0,2,2,2,2,1,0,255,255,1,1,1,0,255,254,254,254,0,0,0,255,254,253,254,254,255,255,255,254,254,254,255,0,255,255,255,255,0,0,1,2,255,255,255,0,1,2,3,4,255,255,0,0,255,254,253,253,255,255,0,0,0,255,255,255,254,254,255,0,1,1,1,1,254,254,254,0,1,2,3,3,255,255,255,0,1,3,3,3,1,0,0,0,1,1,2,2,2,2,1,0,0,255,255,255,3,2,1,0,255,254,253,253,255,255,255,254,254,253,252,251,0,0,0,255,255,253,253,252,1,1,1,0,0,255,254,253,2,2,2,1,1,0,255,255,2,2,2,2,1,1,0,255,2,2,2,2,2,1,0,0,1,1,2,1,1,1,0,0,0,0,1,1,0,0,0,255,254,2,3,1,255,1,1,255,253,2,3,0,255,1,1,255,253,2,3,0,255,1,1,255,252,2,3,0,255,1,1,254,252,1,3,0,255,1,1,254,252,1,3,255,254,1,1,254,253,1,2,0,255,1,1,254,253,1,2,0,255,1,1,255,255,255,255,254,254,254,254,254,1,1,1,1,0,0,0,0,1,2,2,2,2,2,2,2,0,0,1,1,1,2,2,2,254,254,255,255,255,0,0,0,253,253,253,253,253,253,253,254,255,255,255,255,254,254,254,254,4,4,4,4,4,3,3,2,253,253,254,255,0,1,2,5,253,253,253,254,255,1,3,6,253,253,254,254,0,2,3,5,253,254,254,254,0,1,3,5,254,254,254,255,255,1,3,5,254,254,255,255,0,1,2,4,255,255,255,255,0,1,1,4,255,255,255,255,0,1,2,3,0,255,0,1,1,0,255,255,0,0,0,1,2,0,255,255,1,0,255,0,1,0,0,0,1,255,254,255,0,0,0,0,1,254,253,255,0,0,0,1,1,255,253,254,0,1,1,2,1,255,254,255,0,1,1,2,2,0,255,0,1,1,2,2,1,1,1,1,0,0,1,2,255,0,0,255,0,0,0,1,253,254,255,255,255,0,1,1,252,254,255,0,0,1,1,1,253,254,0,0,1,1,1,1,253,255,0,1,1,1,0,0,255,0,1,1,1,0,0,255,0,1,2,2,1,0,0,255,252,252,252,253,254,255,255,255,254,254,254,255,0,0,0,0,255,0,0,0,1,1,1,1,0,0,1,1,1,1,1,1,0,0,1,1,2,2,1,0,0,0,1,1,1,1,1,0,0,0,0,1,1,1,1,0,255,0,0,1,1,1,0,0,1,2,2,2,1,255,254,252,1,1,2,2,1,0,254,252,0,1,1,1,1,0,255,253,255,0,1,1,0,0,255,254,255,0,1,1,1,0,0,255,254,255,0,0,0,0,0,255,255,255,0,1,1,0,0,0,255,0,1,1,1,1,1,0,2,2,0,255,254,255,255,254,1,1,255,254,254,255,255,254,1,1,255,254,254,0,0,255,1,1,0,254,255,1,1,0,1,1,0,255,255,1,2,1,1,1,0,255,255,1,2,1,1,1,0,255,255,1,1,1,1,1,0,255,0,1,1,1,0,0,255,254,252,252,252,252,3,3,3,2,1,0,0,0,3,3,3,3,2,2,2,2,0,0,0,0,0,0,0,1,255,255,255,255,255,255,255,0,0,255,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,255,255,0,255,255,1,2,255,1,1,0,0,0,2,3,255,1,1,0,255,255,1,3,255,1,1,0,254,254,0,1,254,1,0,0,254,254,0,1,253,0,0,0,0,255,1,1,253,0,1,1,0,1,2,1,253,255,0,1,1,1,2,1,252,252,253,0,1,1,1,0,0,252,254,0,1,1,1,0,255,253,255,1,1,1,0,255,255,255,1,1,1,1,0,255,0,1,2,2,1,0,255,0,0,2,2,1,0,255,255,0,1,2,1,0,255,254,255,0,1,2,2,0,255,254,255,1,1,1,1,0,0,255,255,255,255,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,255,255,255,255,255,255,1,0,0,255,255,255,255,255,2,1,0,0,255,255,255,255,5,3,2,1,0,0,0,0,6,5,3,2,1,0,0,0,4,4,3,1,0,0,0,1,3,3,2,1,0,0,0,1,2,2,1,0,255,255,0,1,0,0,0,255,255,255,0,1,0,0,255,255,254,255,0,2,0,255,255,254,254,254,0,1,0,255,255,254,254,254,255,0,0,0,255,254,254,254,255,0,0,0,255,255,255,0,2,3,0,255,254,254,255,255,1,2,1,0,255,255,255,0,0,0,1,1,1,0,0,0,255,255,1,2,1,0,0,255,255,255,255,0,0,0,255,255,255,255,253,254,255,255,0,1,1,2,252,253,255,1,2,3,5,5,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,255,0,0,0,1,255,255,254,254,254,255,255,0,0,0,0,0,0,1,1,1,2,2,2,2,2,3,3,3,1,1,1,1,2,2,1,1,252,253,252,252,252,252,253,253,255,0,1,2,2,3,3,3,255,255,255,255,0,0,0,0,0,0,255,254,254,253,253,254,3,2,1,0,255,254,254,254,4], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+399377);
/* memory initializer */ allocate([3,2,1,1,0,0,0,2,2,1,1,0,1,1,1,0,255,255,255,255,0,0,1,254,254,254,254,254,255,0,0,1,255,0,2,1,254,255,1,1,255,0,2,1,254,254,1,1,255,0,3,2,254,255,1,0,254,0,3,2,254,254,1,0,254,0,3,2,254,254,1,0,254,0,3,1,254,255,1,0,254,0,2,1,254,254,1,0,255,0,2,1,254,255,1,0,1,2,2,3,3,2,2,0,1,1,2,3,3,2,1,0,0,1,2,2,2,2,1,255,0,0,1,1,1,1,1,255,255,0,0,0,0,0,0,255,255,255,255,255,255,255,255,254,254,254,254,254,254,254,255,254,254,254,254,254,254,254,255,0,0,255,254,255,0,3,5,0,0,255,255,255,0,2,4,1,1,0,0,255,255,1,2,1,2,1,1,0,255,255,0,0,1,2,1,0,255,254,254,255,0,1,2,1,0,253,253,254,255,1,2,2,0,254,252,254,255,0,2,2,1,255,253,0,0,0,0,0,0,255,255,0,0,255,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,255,255,255,0,255,255,255,255,255,255,255,0,255,0,0,0,0,255,255,0,0,0,1,1,0,0,0,1,3,3,3,4,3,3,3,3,5,1,254,254,0,0,0,255,4,255,253,255,0,0,0,255,3,255,255,0,1,1,0,255,2,0,0,1,1,1,0,254,1,0,0,1,1,1,0,254,0,255,255,255,0,0,0,255,0,255,255,255,255,0,0,255,2,1,0,0,0,1,0,0,1,0,1,1,1,1,0,0,1,0,0,1,1,0,0,0,1,255,255,0,0,0,0,0,2,0,255,255,255,255,255,0,3,1,255,255,254,254,254,255,4,2,1,0,255,254,254,255,2,1,0,0,255,255,0,0,0,255,255,255,255,0,1,1,0,1,2,2,2,1,255,253,0,0,1,1,1,0,255,254,0,0,0,0,0,0,255,255,0,0,255,0,0,1,1,0,0,0,255,0,1,1,1,1,0,0,0,0,1,1,1,0,0,0,1,1,2,1,255,253,0,0,0,1,1,255,252,251,254,254,254,255,0,2,2,2,0,0,0,0,1,1,1,0,1,1,1,1,1,0,254,253,0,0,1,1,0,255,253,252,255,255,0,1,0,0,254,253,255,255,0,1,1,1,0,255,0,0,0,1,1,1,1,0,1,1,1,1,0,0,0,0,0,1,0,0,1,1,1,2,1,2,0,0,0,0,255,1,0,2,0,255,1,0,255,0,0,1,0,0,2,1,0,1,0,1,255,0,2,2,0,1,255,0,255,255,2,1,1,2,254,254,253,254,0,1,1,1,254,254,253,253,255,255,255,0,253,255,0,1,2,1,1,0,253,255,0,1,2,1,1,1,254,0,0,1,1,1,1,1,255,0,0,0,0,0,0,0,254,0,0,0,0,255,255,0,254,0,0,0,0,0,255,255,253,0,1,1,1,1,0,1,251,254,0,1,2,2,1,2,254,255,255,0,0,1,2,3,0,0,1,1,0,0,1,2,0,0,1,0,255,255,0,1,255,255,255,255,254,254,255,0,254,254,254,254,254,255,0,1,0,0,0,255,0,1,2,2,2,1,0,0,0,1,2,2,2,1,0,255,255,255,0,0,0,1,1,1,1,1,255,252,255,255,0,1,1,1,0,253,254,255,0,0,1,2,2,254,255,0,0,0,0,2,3,255,255,0,0,0,0,1,2,0,0,0,255,254,255,1,1,0,0,0,255,254,254,0,2,1,0,0,255,254,255,1,2,2,1,0,0,0,254,253,254,253,0,0,1,0,254,254,255,255,0,255,1,1,255,255,0,0,0,255,1,1,255,255,0,0,0,1,2,1,255,255,0,1,1,2,3,2,0,0,1,2,255,0,2,1,0,0,2,3,254,255,0,0,255,0,1,2,1,1,0,255,254,254,255,1,1,1,1,255,254,254,0,2,1,1,1,255,255,255,0,2,0,0,0,0,0,0,1,2,255,255,255,0,0,0,1,2,255,254,255,1,1,1,0,0,255,254,255,1,2,2,0,255,255,254,255,2,2,2,0,255,255,255,255,254,255,255,0,1,0,0,255,255,255,0,1,2,1,0,0,0,0,1,1,2,1,1,0,0,1,1,1,1,1,1,0,1,1,0,1,1,1,1,1,1,0,255,255,255,1,2,1,0,255,254,254,253,2,2,1,0,254,253,252,252,252,254,1,1,1,1,0,0,254,0,1,0,0,0,0,0,0,1,1,254,254,255,0,1,2,2,1,254,254,255,1,2,1,2,1,254,254,255,1,2,255,1,1,255,255,255,0,1,254,0,1,1,0,255,255,0,254,0,2,2,1,255,255,0,1,1,0,0,0,1,0,0,254,253,253,254,254,255,0,0,253,252,253,254,255,0,0,0,255,255,0,1,2,3,2,1,0,1,2,3,3,3,2,1,1,1,1,2,1,0,0,255,0,0,0,0,255,255,255,255,0,255,255,0,0,0,0,0,1,1,0,0,255,255,0,2,0,0,1,0,255,255,1,1,254,255,0,1,1,1,1,1,253,253,0,2,2,1,1,0,254,254,0,1,1,1,0,0,1,0,0,0,0,0,255,255,3,1,255,253,254,255,0,1,4,2,255,253,253,255,1,2,0,0,0,255,255,255,255,255,1,2,1,0,0,0,255,255,2,3,3,2,1,0,255,255,3,4,4,2,1,0,255,254,3,3,2,1,0,255,254,254,1,1,0,255,255,254,254,253,0,0,0,255,255,254,254,254,255,255,255,255,255,254,254,255,1,2,2,2,2,1,2,2,0,1,1,1,1,0,0,0,0,0,0,1,1,0,255,254,0,0,0,0,1,0,255,252,1,0,0,0,0,0,254,251,1,0,0,0,0,0,255,252,1,0,255,0,0,0,255,253,0,255,255,0,1,1,1,255,254,255,0,0,255,255,255,254,255,0,0,0,255,255,254,254,0,1,1,0,255,255,255,254,0,1,1,0,0,0,255,255,0,1,0,0,1,1,1,0,1,1,0,0,1,2,2,1,1,1,0,0,1,2,2,1,1,1,0,255,0,1,1,0,4,2,1,0,0,1,1,1,4,2,1,0,0,0,0,1,3,1,0,0,255,255,255,0,1,0,0,255,255,254,255,0,0,0,0,0,255,255,255,0,255,255,0,0,255,255,0,1,254,255,0,255,255,0,0,1,254,254,255,254,255,0,0,1,0,1,1,1,2,1,0,255,255,255,255,0,0,255,254,254,255,0,255,0,0,255,254,255,0,0,0,0,0,0,1,2,0,0,0,0,0,0,2,3,255,0,255,255,255,255,0,3,255,0,0,255,255,254,0,3,0,0,0,0,255,255,1,4,2,2,0,0,0,0,0,1,1,1,255,254,255,254,255,1,255,255,254,254,254,253,254,0,255,0,255,255,255,254,255,1,1,1,0,0,1,0,0,1,2,2,0,0,1,0,0,1,2,2,0,0,0,0,255,255,2,2,0,0,1,0,255,255,255,0,1,1,0,255,255,255,1,2,3,2,1,0,0,0,0,1,1,1,0,255,0,0,254,254,255,0,1,0,0,0,254,254,255,2,2,2,1,0,254,255,0,1,1,0,0,255,255,255,0,0,255,254,255,254,0,1,1,1,0,0,1,1,253,253,253,254,255,255,254,254,255,255,0,1,2,1,0,0,1,1,1,2,2,1,0,0,1,1,1,1,1,0,255,1,1,0,255,255,0,0,255,1,0,255,255,255,0,255,255,1,1,0,255,0,0,255,0,2,2,0,255,0,0,0,0,2,1,0,254,255,0,1,1,0,2,0,255,255,0,1,1,0,1,0,254,255,0,1,0,255,1,0,255,255,0,1,0,255,0,1,1,0,1,1,0,0,254,1,2,1,0,0,0,1,251,0,2,1,0,255,0,1,250,255,2,1,0,255,0,0,5,3,0,255,254,255,255,255,1,1,0,255,255,0,255,255,255,0,1,1,2,2,1,0,254,255,0,1,2,1,1,1,254,255,255,255,0,255,0,1,0,1,0,0,255,255,0,0,0,1,1,1,1,0,0,0,253,254,0,1,1,0,0,255,255,0,1,0,255,0,2,3,255,0,0,254,252,254,255,0,0,1,1,0,254,255,0,255,1,2,3,1,0,1,1,0,255,0,1,1,1,1,1,0,254,253,254,0,0,0,1,0,255,254,254,0,1,0,0,255,3,1,0,0,1,0,255,255,254,255,0,0,255,255,0,0,255,0,0,0,0,1,1,1,255,255,255,0,1,1,1,1,0,254,253,255,1,0,0,0,1,255,253,255,1,1,0,255,3,1,255,1,2,2,0,255,3,1,0,1,2,1,1,0,0,254,254,255,255,0,0,0,1,0,255,255,1,2,1,0,0,255,254,255,1,2,2,1,255,255,255,0,0,1,2,0,254,0,0,0,0,0,1,255,255,0,1,0,255,255,255,255,0,1,1,2,0,254,255,0,1,2,2,2,1,255,255,0,0,1,1,1,0,254,254,255,0,0,255,255,255,255,254,254,0,0,255,0,1,2,2,1,0,0,255,255,0,1,2,2,1,1,255,254,255,255,255,255,2,2,1,0,0,255,254,254,1,2,2,1,0,0,254,254,0,0,0,0,1,1,0,255,0,255,255,255,2,3,2,1,0,254,1,2,255,0,0,1,255,254,2,3,255,0,0,0,0,254,2,3,255,255,0,0,0,255,3,2,254,0,1,0,0,255,3,1,254,0,1,0,0,255,2,1,255,1,0,255,0,0,1,255,254,0,0,255,1,0,0,254,254,255,255,255,1,1,1,1,1,255,255,254,0,0,0,1,1,1,1,1,0,0,0,1,1,1,2,3,1,0,0,255,0,0,1,2,0,255,255,254,255,0,1,2,254,254,254,254,255,0,1,1,255,255,255,255,0,0,0,255,2,2,2,0,255,255,254,252,255,254,255,255,0,1,2,3,255,255,255,255,0,1,2,3,1,0,255,0,255,0,1,2,1,0,0,0,255,0,2,2,1,0,255,255,254,0,1,2,0,254,254,254,253,255,0,1,0,254,254,254,254,255,1,1,0,0,0,0,0,1,2,2,5,6,6,6,7,7,8,8,0,0,0,0,0,1,2,3,253,252,252,251,251,252,253,254,252,252,252,251,252,252,253,253,1,2,2,2,2,3,3,3,2,3,3,4,4,5,5,5,255,0,1,1,2,3,4,4,247,246,247,247,248,249,250,251,252,252,251,250,250,249,249,249,0,255,254,254,253,253,252,252,4,4,3,3,2,1,1,0,7,7,7,6,6,5,4,4,2,4,5,6,4,1,253,250,3,4,5,5,4,0,251,248,2,3,4,4,2,254,249,246,2,2,2,1,0,252,247,244,247,249,253,1,4,4,3,3,246,249,254,3,5,5,3,3,247,250,254,3,6,5,4,3,248,250,255,3,4,4,3,2,251,251,251,251,253,1,4,7,251,251,251,252,254,1,6,8,252,251,252,253,255,3,8,10,253,252,253,254,1,5,9,11,254,254,254,254,254,254,254,254,252,251,251,251,251,251,251,252,253,252,252,252,252,252,252,253,9,10,10,11,11,11,10,10,7,4,1,254,252,250,247,246,9,7,3,0,254,252,248,247,11,8,4,2,0,253,250,248,11,9,5,3,1,254,251,249,243,243,243,244,245,246,248,248,0,1,2,3,4,4,4,3,3,4,5,6,6,6,5,4,3,4,4,4,3,3,3,2,10,10,11,10,9,9,8,7,6,6,6,6,5,4,3,2,0,0,0,255,254,253,252,252,246,246,245,244,243,242,242,242,16,16,17,16,15,13,12,11,255,254,253,252,252,252,252,253,252,251,250,250,250,250,250,250,251,250,250,250,250,250,251,251,243,243,243,244,245,246,248,250,247,248,249,250,252,254,0,1,254,255,1,3,5,7,8,9,5,7,9,11,13,14,15,15,16,14,11,7,2,253,249,247,14,12,8,3,255,250,247,245,11,9,4,0,252,248,245,243,8,5,1,253,250,246,244,242,238,241,247,253,1,6,9,11,239,243,249,255,3,7,11,12,241,245,251,1,5,9,12,13,243,247,253,2,5,9,11,13,22,21,19,15,10,3,252,247,20,18,15,9,2,251,244,239,16,13,8,1,249,242,236,232,10,6,255,248,241,235,231,229,231,233,236,242,249,1,9,14,233,235,240,247,0,9,16,21,236,240,246,255,8,16,22,25,241,245,253,6,14,20,25,27,252,254,0,1,2,2,2,2,251,254,0,2,3,3,3,3,250,252,255,1,2,3,3,3,249,251,254,0,1,1,2,2,2,1,1,1,1,0,254,253,3,3,2,1,0,255,253,252,4,3,2,1,0,254,252,250,5,4,3,1,255,253,251,250,5,6,6,4,2,0,254,253,3,4,4,4,3,1,0,255,254,254,255,255,255,255,254,254,251,252,253,254,254,254,253,253,255,255,255,255,255,255,255,255,253,252,252,252,253,253,253,253,255,255,255,255,255,255,255,254,5,6,6,6,6,5,4,3,4,4,4,4,4,5,6,7,0,255,255,255,255,0,1,2,254,253,253,253,253,254,255,0,253,253,252,252,252,253,254,255,0,254,252,252,254,0,2,3,0,254,253,253,255,2,4,5,255,254,252,253,0,3,5,6,254,253,252,253,255,2,4,5,9,4,0,253,253,255,0,1,8,4,255,252,253,255,1,2,6,2,253,251,252,254,0,1,5,1,253,252,252,254,0,1,5,3,1,255,252,248,246,246,3,3,2,1,0,254,253,252,1,1,1,2,3,2,1,0,255,0,1,2,3,4,3,2,0,1,2,2,1,255,253,253,0,1,1,1,255,254,252,253,253,253,253,253,253,253,255,2,252,252,253,0,3,7,12,14,251,251,250,250,250,250,250,251,2,2,2,1,0,0,0,0,4,4,3,2,1,0,0,0,6,6,5,4,2,2,1,1,249,249,250,253,0,4,7,8,255,254,253,253,254,255,1,2,3,3,1,255,254,254,254,255,6,6,4,2,0,254,254,254,250,251,254,2,5,9,11,12,252,252,254,0,2,4,5,6,253,254,254,254,254,255,0,1,254,254,254,253,253,253,253,254,249,253,1,3,3,0,253,251,250,254,3,5,4,1,253,251,251,255,4,6,5,2,253,252,252,0,5,7,6,3,255,253,0,0,0,0,0,0,0,0,254,254,253,253,253,253,254,255,6,7,8,9,9,8,7,6,252,252,251,251,250,250,251,252,247,248,250,252,0,3,6,6,251,252,255,3,5,6,5,3,1,3,6,6,4,1,254,251,6,7,5,1,253,249,246,245,10,9,5,1,253,250,250,252,5,3,255,251,250,251,254,2,254,252,250,250,252,1,6,10,250,249,249,252,1,7,11,12,6,5,3,2,0,0,0,0,2,1,255,254,253,254,255,255,0,255,254,252,252,254,255,1,0,0,255,254,255,0,2,3,0,255,254,254,254,254,255,255,5,4,2,1,0,0,0,0,6,5,3,1,0,0,0,0,2,0,254,252,252,253,254,254,249,252,0,2,2,2,2,1,249,253,0,0,0,0,0,0,252,255,1,1,0,0,0,1,255,1,2,2,2,2,3,3,254,0,2,2,1,1,1,1,255,1,2,2,1,0,0,255,0,2,4,2,0,255,254,253,1,2,3,1,254,252,250,250,1,2,2,4,5,6,4,1,0,255,255,255,0,0,254,252,0,0,255,254,254,254,252,250,2,1,0,0,1,1,255,253,1,1,1,1,1,2,3,3,0,0,1,0,1,2,4,4,255,255,255,255,0,1,2,3,252,252,251,251,251,253,255,0,250,251,251,252,253,254,255,255,255,0,0,1,1,2,3,3,0,1,1,1,2,2,3,4,0,0,255,255,0,1,2,3,0,1,1,1,0,0,255,255,1,3,3,2,1,255,254,254,254,0,2,2,2,2,1,1,247,248,252,254,1,3,3,3,255,255,255,254,253,253,253,252,0,0,0,255,254,254,253,253,2,2,2,0,255,255,255,255,5,5,4,3,2,2,2,2,6,3,255,252,253,255,1,1,2,255,253,252,255,2,2,0,255,254,254,1,4,4,1,253,254,255,1,4,6,3,253,248,3,3,2,1,255,254,254,254,252,252,254,255,1,3,4,4,252,251,251,252,254,0,2,2,7,7,4,1,255,254,253,254,255,1,3,0,252,250,0,6,254,1,4,1,252,250,255,7,253,1,4,2,253,250,255,6,254,0,3,2,254,251,255,4,1,255,254,1,4,4,255,249,1,255,252,255,5,6,0,250,3,0,252,253,3,6,2,252,3,0,251,252,1,4,1,253,2,2,3,3,3,3,2,2,252,251,250,249,249,249,249,250,1,2,3,3,3,3,2,2,0,0,1,1,1,2,2,1,3,253,253,3,4,254,254,2,3,252,252,4,4,252,252,2,4,252,252,4,4,252,253,3,3,253,252,3,3,253,253,3,254,254,254,254,254,254,255,255,6,7,8,8,8,7,6,5,251,250,249,249,248,249,250,251,1,1,2,2,2,2,1,1,0,0,0,0,0,255,0,0,255,0,0,0,0,255,0,0,254,253,254,254,254,253,253,253,2,3,5,6,4,2,1,0,8,6,2,0,0,0,0,0,4,1,0,0,0,255,255,255,1,255,0,0,0,255,254,253,254,254,255,0,0,254,252,251,3,1,255,254,253,252,251,251,2,1,0,0,1,1,0,0,0,255,255,0,2,2,2,2,255,254,255,1,2,2,2,2,0,255,254,255,255,255,255,0,255,254,254,255,255,0,0,1,2,1,1,2,2,1,1,0,6,5,3,1,0,254,252,252,253,254,255,0,1,1,0,255,0,1,3,4,5,5,3,1,255,255,255,0,1,0,255,254,254,254,254,255,0,255,254,253,0,255,254,254,255,255,0,2,1,255,254,255,255,255,0,2,1,0,254,254,254,254,1,5,1,255,254,254,254,0,5,10,0,0,0,0,0,255,255,255,255,255,255,0,0,0,1,2,1,2,2,3,4,4,6,5,253,253,253,254,254,253,253,253,1,255,254,254,0,3,5,7,2,0,254,253,254,0,2,3,3,1,254,253,253,254,255,255,3,1,0,255,255,255,255,255,1,3,5,4,2,255,253,252,253,254,1,2,1,0,255,254,251,253,0,2,2,1,0,0,253,255,1,2,2,1,0,0,0,255,255,255,1,2,3,4,253,252,252,253,255,0,0,1,254,253,254,255,1,1,1,1,254,254,0,3,4,4,3,2,252,252,253,254,255,1,2,3,0,1,1,1,255,254,253,253,3,4,5,4,2,255,253,253,254,254,0,2,2,2,1,0,252,0,5,7,4,255,252,252,255,2,4,3,0,253,253,254,2,1,0,255,254,254,0,1,0,0,255,254,254,255,1,2,252,253,254,255,0,1,2,2,10,9,5,0,253,252,253,254,1,255,254,254,255,0,0,0,254,254,255,1,1,1,0,255,251,253,0,3,4,2,0,254,254,255,0,1,1,0,255,255,3,2,255,254,254,255,1,1,7,5,255,251,250,254,2,4,254,3,3,253,252,1,2,254,253,3,4,253,252,2,3,254,253,3,4,253,252,2,3,254,252,2,4,254,253,1,2,255,4,3,255,253,253,255,1,2,252,250,252,0,4,5,4,1,0,2,5,6,2,253,251,252,1,1,255,253,251,254,2,4,255,0,1,2,2,3,3,4,255,0,1,1,0,255,255,255,255,0,1,2,2,1,255,254,253,254,255,0,0,255,254,253,1,1,1,1,0,0,1,2,1,0,255,0,0,1,1,0,1,254,252,255,1,2,1,0,1,252,249,253,1,3,2,1,1,1,1,1,1,1,0,255,1,1,1,0,1,2,2,0,1,1,0,0,0,2,0,253,3,2,0,255,255,254,250,247,0,0,0,1,0,0,1,2,1,0,0,0,255,255,0,2,0,1,1,1,255,253,254,0,249,251,1,6,6,2,255,255,3,1,255,253,252,254,1,4,2,0,254,253,252,253,255,2,2,2,1,1,1,0,0,1,1,1,0,0,0,0,0,1,255,1,1,254,251,250,252,255,255,1,4,3,2,0,1,2,255,0,2,3,1,0,0,1,255,0,1,0,0,255,255,0,0,1,2,2,0,254,255,1,254,255,255,254,255,2,6,8,255,255,254,253,254,0,1,2,255,0,0,255,255,0,255,255,2,1,1,1,1,0,0,0,0,0,1,1,1,255,255,1,255,0,2,2,255,253,254,3,0,2,3,0,251,249,254,4,255,0,0,0,255,254,253,253,255,0,255,254,254,254,254,254,1,1,0,0,1,2,0,255,1,2,1,2,5,6,2,0,254,252,253,0,2,2,0,253,3,1,0,1,2,1,254,253,3,1,0,0,0,0,0,255,1,255,254,254,255,1,3,3,3,2,1,2,4,3,1,254,254,252,252,253,255,0,254,253,1,0,255,255,0,1,0,255,3,2,0,0,0,1,1,0,1,1,0,0,0,0,0,0,2,3,3,2,2,2,1,1,0,255,254,253,251,251,251,252,1,1,0,255,0,1,3,3,247,250,254,0,1,1,2,2,250,254,1,2,1,1,0,1,254,1,2,2,1,1,1,1,0,2,2,1,0,1,1,1,1,0,0,0,0,0,255,0,0,0,0,0,255,253,254,0,253,253,253,254,255,3,7,9,1,2,2,2,0,254,252,253,2,0,254,255,3,4,255,250,1,0,254,253,255,3,3,0,0,3,3,0,254,255,1,1,250,255,3,2,255,254,0,1,5,3,0,254,253,0,2,1,1,1,2,2,0,254,252,249,253,254,1,2,2,1,255,252,2,2,0,254,254,0,2,2,0,0,254,253,254,255,0,0,0,0,0,0,0,0,2,2,254,255,0,1,0,1,2,3,252,254,0,0,255,0,2,3,254,254,254,255,255,0,2,4,0,0,0,0,255,255,0,1,0,255,255,255,255,255,0,0,6,4,2,0,255,254,255,255,0,1,1,1,1,255,251,246,1,1,1,1,1,1,0,252,1,0,1,1,1,1,1,255,2,1,1,1,0,0,0,0,253,1,4,3,3,1,255,0,252,0,1,0,255,0,0,0,251,0,2,1,1,1,0,255,255,2,1,254,254,255,0,255,2,4,5,3,0,255,1,2,0,0,1,0,254,254,255,255,254,254,254,254,253,254,255,0,0,0,1,0,0,0,1,2,0,254,254,253,255,2,2,255,1,0,0,0,1,5,3,254,255,255,0,255,0,2,0,251,255,0,1,0,0,2,2,254,3,1,255,255,0,1,1,2,1,0,0,1,1,1,1,1,246,248,254,1,2,1,1,1,255,1,2,1,0,0,0,0,255,255,0,1,2,2,2,1,255,255,255,0,255,253,251,252,1,1,2,1,1,0,0,2,255,254,255,255,255,0,2,4,253,249,251,0,2,0,0,0,3,255,254,1,2,1,1,2,1,254,255,1,2,1,0,1,0,255,0,3,2,255,255,255,2,1,1,0,0,0,0,0,247,249,254,3,3,2,1,1,3,2,0,254,254,255,1,1,0,255,0,0,1,1,0,0,254,255,1,1,1,0,0,0,1,2,1,254,252,253,1,2,1,2,1,254,253,0,3,1,255,255,0,0,1,3,0,252,2,0,255,1,2,254,254,3,2,0,255,2,3,254,252,1,0,1,1,1,2,254,250,254,255,0,0,0,2,0,254,255,255,255,1,2,1,254,253,254,3,255,254,255,255,0,1,2,10,4,0,0,255,254,254,255,3,255,254,255,0,255,255,0,251,2,7,1,252,254,1,0,254,2,3,255,253,0,2,0,2,1,0,0,1,1,255,254,1,254,254,255,255,254,0,0,0,3,254,249,255,3,0,0,1,3,253,251,2,3,255,0,0,2,254,254,4,2,254,0,255,1,255,0,2,255,254,1,4,0,253,252,254,1,2,1,0,0,3,5,3,1,255,254,1,1,1,255,253,255,1,1,1,255,254,254,0,0,255,254,245,253,3,6,246,255,5,7,247,255,6,7,247,255,4,6,5,7,0,242,6,9,2,241,6,9,2,241,4,6,0,242,16,3,251,250,16,1,248,248,14,255,247,247,12,0,248,248,8,12,16,17,254,2,6,9,246,248,252,0,241,242,245,249,249,246,254,16,249,245,253,18,249,245,255,20,250,248,1,19,247,243,240,239,2,254,249,247,11,8,4,255,16,15,11,7,234,254,13,15,232,254,14,16,231,252,13,15,231,250,10,13,26,26,22,16,17,15,9,3,254,250,245,242,236,231,228,228,229,229,231,235,240,241,245,249,3,8,12,13,23,28,31,30,20,16,249,223,22,19,250,221,22,19,250,222,20,17,250,224,236,236,2,38,235,234,2,40,235,234,2,40,236,236,3,38,209,252,24,26,206,253,26,27,206,253,26,27,209,252,24,26,45,6,233,229,48,5,231,228,48,5,230,228,44,6,232,229,226,220,246,76,225,219,245,78,225,219,245,78,225,220,246,77,203,224,35,52,202,222,36,52,202,222,36,52,203,223,34,51,163,222,62,65,163,222,62,66,163,222,62,65,163,222,60,64,249,0,2,2,248,255,3,3,248,0,4,5,250,1,5,5,3,7,11,11,2,2,3,3,1,254,250,249,1,251,245,243,3,254,252,253,7,0,251,251,12,4,251,249,14,6,252,249,18,14,3,254,6,4,0,253,248,251,254,0,240,245,254,2,248,250,7,18,249,248,2,13,252,250,254,6,0,252,253,1,1,253,243,238,0,255,251,249,255,1,6,7,254,4,15,17,241,242,249,254,250,251,255,0,6,6,3,1,15,13,6,1,2,254,245,10,2,255,244,11,3,255,244,11,2,254,245,11,247,14,255,251,247,15,254,251,248,16,254,251,249,15,255,252,2,6,8,8,254,3,9,12,245,251,4,10,237,240,248,0,14,8,249,241,12,7,249,242,8,5,252,247,5,3,255,252,12,242,254,2,13,241,255,3,14,241,255,3,13,242,255,3,0,6,10,243,0,6,10,241,0,7,9,239,1,6,8,240,248,251,15,254,248,250,17,254,248,250,16,253,248,251,15,254,247,245,245,246,9,10,9,8,8,10,10,9,248,247,248,249,9,10,9,7,248,246,246,246,249,246,245,245,11,12,11,8,0,10,7,0,0,7,0,250,0,2,251,250,254,255,252,255,5,0,250,247,2,2,2,1,254,0,5,7,250,251,1,4,3,248,2,255,4,247,3,0,5,249,3,0,7,251,3,0,251,253,2,9,250,253,1,8,250,253,1,7,251,254,0,4,13,8,3,1,253,251,252,255,248,249,253,0,255,1,3,2,3,2,251,244,4,3,254,247,3,4,1,252,3,5,4,255,247,248,252,0,8,6,2,0,10,8,3,0,250,251,253,255,253,247,244,251,0,253,251,0,2,3,2,4,5,8,7,6,255,254,5,12,255,255,5,9,2,1,255,254,2,255,245,239,249,3,3,255,247,3,4,255,246,4,6,255,247,5,7,0,238,249,2,2,248,1,5,3,3,4,1,0,9,5,254,253,254,0,6,8,252,251,251,253,1,254,250,248,10,9,3,255,0,254,254,0,0,252,251,0,254,248,252,8,251,249,6,24,9,1,249,1,9,1,248,1,8,0,246,1,8,255,245,255,8,8,6,3,5,4,3,2,254,253,255,0,246,243,248,252,0,4,2,253,0,6,3,251,3,10,2,244,5,10,252,234,0,252,255,3,1,252,255,5,1,251,0,8,255,250,254,7,255,255,254,252,255,254,252,250,255,255,255,254,1,5,10,9,10,3,0,254,6,255,254,251,3,255,254,250,2,0,0,251,6,3,0,0,6,3,1,1,4,254,254,1,0,247,247,254,245,253,1,2,250,2,4,5,253,2,3,4,254,1,1,2,250,252,255,254,2,255,255,254,10,2,254,254,11,2,252,255,6,0,254,2,3,3,0,0,250,3,3,0,239,255,5,0,255,4,10,11,253,254,0,1,253,252,251,253,255,254,254,255,2,253,247,244,3,3,3,2,2,2,4,4,2,1,255,254,254,9,5,246,253,5,5,251,254,1,2,0,255,254,254,1,254,253,7,254,255,253,7,253,255,254,8,252,254,254,7,253,1,248,253,12,2,254,254,4,1,3,0,251,255,5,2,249,255,3,1,251,249,254,3,1,254,249,254,2,20,3,251,255,5,0,253,254,249,249,0,6,250,0,7,6,2,6,0,249,254,6,249,1,254,7,248,3,254,7,249,3,255,7,250,2,251,254,5,7,4,1,252,248,6,3,254,251,249,251,3,7,255,255,6,5,0,255,1,252,2,1,0,249,1,0,0,252,248,0,3,1,254,1,255,255,1,255,253,1,1,254,1,9,5,2,253,252,255,0,255,253,253,1,3,1,252,0,4,2,2,254,254,12,0,254,251,3,255,0,253,1,253,255,254,1,1,5,3,0,250,252,254,1,0,254,254,2,6,1,252,255,253,251,251,255,3,5,5,4,0,3,1,255,254,1,254,253,2,252,251,253,4,254,253,254,6,0,255,255,7,1,0,0,253,254,254,0,254,253,251,255,254,2,0,255,255,11,9,255,0,1,255,246,255,1,0,250,1,0,1,4,2,251,255,13,254,4,5,0,251,1,6,3,250,254,3,2,251,254,0,254,255,1,1,254,255,254,0,2,5,5,5,7,0,252,248,249,0,2,255,251,255,2,2,253,0,5,3,251,3,8,2,244,8,4,0,254,10,255,252,255,3,250,253,0,252,251,0,0,0,246,252,2,255,250,3,5,255,253,6,4,0,254,4,2,0,8,1,255,0,11,1,253,255,6,254,252,253,254,249,252,0,255,255,255,4,5,6,5,251,247,248,251,2,2,3,2,0,2,6,1,2,0,3,0,1,254,255,254,0,255,253,250,0,0,2,0,4,0,2,1,5,254,0,0,254,247,255,2,0,1,0,246,255,1,8,0,255,254,4,0,1,255,2,255,253,254,2,255,253,255,2,253,0,255,1,0,8,1,255,3,0,1,1,2,0,252,254,0,255,251,1,255,254,255,11,2,1,5,254,254,0,2,252,0,254,1,251,1,0,5,0,1,251,253,0,6,252,2,0,0,253,5,1,0,253,3,0,0,3,254,253,1,1,252,0,8,254,253,254,3,1,2,255,255,1,1,0,2,2,0,1,6,1,255,2,1,0,3,0,237,1,253,254,2,6,5,254,249,253,1,3,1,255,255,0,2,248,255,255,252,1,1,255,2,4,3,2,3,251,1,3,0,0,2,255,1,253,0,0,5,251,254,0,8,252,252,252,6,1,2,1,2,2,2,253,2,4,0,247,0,7,0,245,1,0,0,0,254,3,3,255,250,4,3,253,246,255,2,6,2,7,254,253,5,252,0,3,255,252,2,1,249,2,255,255,3,3,2,2,2,251,249,249,251,5,6,4,2,254,255,0,1,12,13,13,11,249,246,241,239,240,241,244,246,11,15,15,12,2,17,20,15,211,232,2,13,21,20,250,220,12,16,255,229,238,235,10,45,245,236,249,21,43,248,228,0,33,240,228,3,244,238,238,250,236,246,28,55,251,238,235,238,56,30,250,236,222,27,29,234,226,29,26,231,30,34,33,26,231,225,221,223,225,221,220,224,29,36,37,31,185,244,38,34,193,255,42,33,58,37,225,196,55,34,223,195,199,199,22,93,199,198,21,93,59,69,70,62,193,188,188,196,192,185,185,192,63,73,72,62,254,0,7,15,245,246,253,5,251,248,246,246,1,9,14,9,15,8,252,245,12,2,245,244,248,0,19,28,4,255,241,230,241,27,2,242,242,22,1,247,252,250,243,246,250,242,6,47,221,236,6,23,6,9,6,4,250,2,23,234,249,4,28,235,20,234,254,6,22,228,251,8,246,238,240,244,36,19,2,255,253,0,4,8,211,246,23,23,40,15,236,221,252,255,4,1,9,251,223,24,8,3,230,19,255,4,6,253,32,25,243,207,24,24,15,7,239,229,237,249,209,0,39,24,235,250,7,4,255,0,246,243,1,1,5,16,20,5,253,247,255,252,254,250,239,249,1,4,12,7,0,0,3,0,12,11,253,1,0,233,4,17,250,0,6,3,231,0,239,10,8,5,242,4,1,4,13,10,4,2,233,247,1,2,3,253,1,7,1,233,249,20,249,238,2,12,251,252,10,9,4,10,7,232,6,3,4,246,22,242,234,6,0,5,5,255,252,3,245,252,249,31,7,242,251,240,255,42,252,254,247,251,5,248,250,253,42,252,235,251,238,12,20,244,13,243,246,7,248,247,254,238,240,6,40,8,10,255,0,4,253,4,255,243,254,6,1,241,5,3,1,2,252,254,1,3,15,0,247,252,253,252,252,252,253,5,16,253,2,13,3,4,253,248,246,0,250,254,252,255,254,253,250,23,6,250,7,1,4,238,5,1,255,1,241,14,251,6,252,4,2,2,2,6,232,2,7,3,230,0,3,3,5,7,1,6,14,254,238,253,7,5,252,2,250,3,32,1,250,250,250,244,5,220,7,6,9,255,11,0,4,4,5,3,4,15,3,218,10,23,251,214,0,4,4,4,23,17,250,243,243,219,1,29,5,242,255,1,5,0,3,1,0,4,251,2,8,0,0,246,4,7,254,253,246,3,1,1,244,255,13,3,0,255,1,253,0,255,3,1,250,247,3,9,250,1,252,250,8,255,0,8,253,253,0,18,251,255,252,255,248,254,3,252,0,17,255,251,5,254,9,246,1,251,6,251,4,2,2,3,10,242,248,1,255,254,238,255,255,20,1,2,255,1,247,1,255,247,22,252,6,252,8,253,255,7,237,5,249,31,252,252,250,0,251,251,249,248,237,252,1,1,4,32,38,255,248,4,249,248,250,244,255,0,249,1,255,9,255,0,9,255,255,0,2,250,1,253,244,0,2,1,1,1,8,0,9,1,0,2,254,1,245,0,0,8,2,246,255,2,255,0,254,252,0,251,254,255,255,14,253,7,255,5,0,246,1,1,255,251,14,255,254,1,253,254,250,0,0,6,2,3,247,4,4,251,255,255,249,3,8,255,2,252,255,245,11,2,1,0,255,2,3,9,0,2,0,241,3,5,236,3,3,255,3,3,1,255,16,1,2,227,9,2,243,250,255,253,36,255,248,253,2,5,4,2,219,9,11,3,255,1,254,0,1,255,255,255,254,255,1,255,255,0,255,255,0,255,255,255,255,0,255,0,0,0,253,1,255,0,1,255,1,255,2,2,1,1,2,0,0,0,255,1,1,0,0,0,1,255,0,1,255,1,1,0,1,0,255,1,1,0,0,0,254,0,0,254,0,0,254,0,254,255,254,255,0,0,255,0,1,0,1,255,2,2,1,2,2,1,0,1,1,0,1,1,254,1,255,255,1,0,1,255,255,255,1,255,0,255,0,255,0,0,0,254,0,1,0,255,255,0,2,253,1,254,3,255,2,0,2,1,1,255,1,1,0,0,1,1,2,254,1,0,254,255,2,254,254,0,253,0,255,0,255,0,255,0,254,253,1,254,254,255,1,255,255,1,255,1,1,0,254,0,1,1,1,1,2,1,0,0,255,0,0,1,0,1,255,1,0,2,0,0,0,253,1,1,1,253,0,255,0,253,1,253,0,254,1,2,255,253,0,253,1,255,0,255,0,0,1,2,1,1,255,2,253,3,1,0,251,1,0,255,253,1,0,2,0,253,4,2,0,254,1,254,3,254,1,1,0,255,2,5,3,1,255,0,2,253,254,0,0,254,2,253,255,255,2,1,0,254,3,255,1,255,2,4,0,1,0,1,0,255,253,254,255,0,0,2,255,255,2,252,254,3,0,255,251,1,0,1,0,6,254,2,0,1,1,255,255,254,1,254,255,0,2,254,254,255,252,2,255,253,255,254,2,255,2,255,2,0,3,253,253,0,253,0,0,254,4,252,0,255,4,0,254,254,3,254,0,4,5,0,1,0,253,3,3,2,0,0,1,2,251,254,253,0,253,2,254,2,254,4,7,253,4,2,3,2,255,0,253,1,252,253,4,5,2,1,1,0,251,253,5,5,2,1,0,0,250,252,5,5,2,1,0,0,249,252,4,5,2,1,0,0,248,251,3,4,2,1,0,0,248,250,3,4,1,1,1,0,248,250,2,4,2,1,1,0,248,250,2,4,1,1,1,1,255,255,255,255,255,255,255,255,255,254,254,254,254,254,254,254,254,253,253,253,253,253,253,253,254,253,253,253,253,253,252,253,254,254,254,254,254,253,253,254,1,1,1,1,1,0,255,255,4,5,5,5,4,3,3,2,7,7,8,8,8,7,6,5,2,1,2,4,4,0,252,250,1,1,2,5,5,1,251,249,1,2,1,4,5,1,251,248,1,1,1,5,5,0,250,248,0,1,1,5,6,1,250,247,0,0,1,4,5,0,251,248,0,0,1,4,5,0,251,249,0,0,1,4,4,1,252,249,1,2,3,0,253,252,253,255,1,3,4,0,253,252,253,255,2,4,5,1,253,252,253,254,2,5,6,1,253,251,252,254,3,6,6,1,253,251,252,254,3,6,6,1,253,251,252,254,3,6,6,1,253,251,252,254,3,5,5,1,253,252,252,254,2,2,2,2,1,0,0,255,4,4,4,3,2,1,1,0,4,5,4,4,3,3,2,1,4,4,4,4,4,3,2,2,2,3,3,3,3,3,2,1,255,255,255,255,0,0,0,0,251,250,250,251,251,252,253,253,249,247,247,248,249,250,250,251,6,6,6,6,6,5,5,4,4,4,4,3,3,3,3,2,0,255,255,255,254,254,255,255,253,251,250,250,250,250,251,252,253,251,250,249,250,250,251,252,255,254,254,254,254,254,255,255,0,1,1,1,1,1,1,1,3,3,3,3,3,3,3,3,2,1,254,251,252,0,2,5,2,1,254,250,251,0,3,5,2,1,254,250,250,255,3,6,3,2,254,249,250,0,4,7,2,1,254,249,251,0,5,7,2,1,254,250,251,0,4,7,2,1,254,250,252,0,4,6,1,1,254,251,252,0,3,6,246,247,250,252,255,2,3,2,246,247,251,253,0,4,4,3,247,249,253,255,2,5,5,3,249,251,254,0,3,5,5,3,250,253,0,1,4,6,5,3,252,254,1,2,3,5,4,2,254,0,1,2,2,4,3,1,255,1,2,2,2,3,3,1,252,251,251,250,250,250,250,251,253,253,252,252,252,252,252,252,0,0,0,0,255,255,255,255,5,5,6,5,5,4,3,2,5,6,7,7,7,6,5,4,3,3,4,4,4,4,3,2,0,255,0,0,255,255,0,255,253,253,252,252,252,252,253,253,1,254,251,1,5,4,2,0,1,253,250,1,6,5,2,0,0,252,249,0,6,6,2,1,255,251,247,255,6,6,3,1,255,250,246,254,6,6,3,1,255,250,247,254,5,6,3,1,254,250,247,254,5,5,3,1,254,250,249,254,4,4,2,1,251,249,248,247,247,248,249,250,251,250,250,249,249,250,250,251,253,253,253,252,251,251,252,252,255,0,0,255,255,255,255,255,0,1,2,2,2,2,2,1,2,3,4,5,5,5,5,4,3,4,5,6,8,8,8,7,3,4,5,6,7,7,7,6,5,6,7,8,9,10,10,9,3,4,6,7,8,9,9,8,0,1,2,3,4,5,5,5,255,254,255,255,0,1,2,2,254,253,253,253,253,254,255,0,253,252,251,251,251,251,251,252,252,251,251,250,249,249,250,251,253,252,251,250,249,249,250,250,13,7,0,253,253,252,252,251,14,7,0,253,253,252,252,252,15,8,255,252,252,252,251,252,15,8,255,252,252,251,252,253,15,7,255,252,251,251,251,252,14,7,255,252,252,252,252,253,12,6,255,252,252,252,252,253,11,5,255,252,252,252,252,253,239,252,5,4,4,4,3,3,238,251,5,4,4,4,3,3,237,251,6,4,4,4,3,2,236,251,6,4,4,4,3,3,236,252,6,4,4,5,3,3,237,251,6,4,4,5,3,3,238,252,5,4,4,4,3,2,239,251,4,3,4,4,3,3,250,250,250,252,254,1,6,11,250,249,249,252,254,2,8,13,248,248,249,252,254,3,9,14,248,248,249,251,255,4,10,16,248,248,249,251,255,4,10,17,248,248,249,252,0,5,10,16,248,248,250,253,0,4,9,15,249,249,251,253,0,4,8,12,8,7,7,5,2,254,248,242,8,8,7,5,2,254,248,241,8,8,7,5,1,253,247,240,8,8,7,5,1,253,246,239,8,9,8,5,1,253,246,239,8,8,7,4,1,252,246,240,7,7,7,4,1,253,247,242,6,7,6,3,0,253,247,243,5,1,252,252,253,255,0,0,7,2,253,253,254,255,1,0,7,1,253,253,255,0,1,1,6,1,253,254,255,1,1,0,6,0,252,254,255,0,1,0,5,0,252,253,255,0,0,255,5,0,253,255,0,0,0,254,4,1,254,255,0,1,0,255,2,2,1,1,254,250,248,248,1,1,1,1,254,251,248,248,1,1,1,0,255,253,251,251,0,0,0,0,255,255,255,254,0,255,0,0,0,0,1,0,1,0,0,0,1,2,3,2,2,1,1,1,2,3,4,3,3,3,3,3,4,4,5,4,252,252,253,254,0,0,1,1,252,252,253,254,255,0,0,1,254,254,254,255,255,255,0,0,0,1,0,0,0,0,0,255,2,2,2,2,2,2,1,1,3,4,4,4,4,4,4,3,1,1,1,3,3,4,3,3,251,250,251,252,253,253,254,254,252,254,255,255,255,255,0,1,252,254,255,255,255,255,0,1,253,254,255,255,255,0,1,2,252,253,254,255,255,1,3,3,252,253,253,255,255,1,4,5,252,253,254,254,255,1,4,7,254,254,255,255,0,2,6,8,255,0,0,1,1,4,7,8,253,253,253,254,254,255,255,0,255,255,0,1,2,2,3,3,0,1,2,4,5,6,6,5,255,0,2,3,5,6,5,3,255,255,0,2,3,3,2,1,254,254,255,0,255,253,252,252,0,0,255,255,254,252,248,249,1,2,1,0,255,252,250,249,254,4,1,250,0,3,0,0,254,5,1,249,0,3,0,0,253,5,1,248,0,3,255,255,254,6,1,247,0,3,0,255,254,6,2,248,0,4,0,255,253,5,1,249,1,4,0,0,254,4,1,249,0,4,1,0,255,4,1,250,0,3,1,0,0,0,0,3,4,5,4,1,1,1,1,2,3,3,2,0,2,2,1,2,2,1,255,254,4,3,1,1,0,255,253,251,5,3,1,255,254,253,252,250,5,3,0,254,253,251,250,249,4,3,0,254,253,252,251,251,4,3,0,255,254,254,253,253,0,0,0,0,255,251,254,6,0,0,0,1,255,250,254,8,0,0,0,2,0,250,253,9,0,255,0,2,0,249,254,10,0,255,0,2,255,248,253,10,0,255,255,2,255,249,253,9,0,255,0,1,255,250,253,8,0,0,0,1,0,251,254,7,2,3,3,2,1,0,255,255,3,4,3,2,1,0,255,254,3,4,4,2,1,255,254,253,2,3,3,2,0,255,254,253,255,0,1,1,0,255,254,254,251,252,253,255,0,1,1,1,248,248,251,255,1,3,4,3,246,247,251,0,3,5,6,5,251,255,4,5,3,1,0,0,250,255,4,5,2,0,255,254,250,255,5,4,2,255,254,254,249,255,4,4,1,254,253,253,250,255,5,4,1,254,253,253,251,0,4,4,1,255,254,254,252,0,5,4,1,255,255,254,253,1,4,3,1,255,255,254,254,253,254,1,4,6,5,3,253,252,252,0,3,5,4,2,253,251,251,255,2,4,3,1,252,250,252,255,2,4,2,255,254,252,253,1,2,4,2,255,254,252,254,1,3,3,1,254,254,253,254,1,3,3,1,254,254,254,255,1,3,3,0,254,252,252,253,254,255,2,5,7,252,252,253,253,254,1,5,7,254,253,254,253,253,255,3,5,255,255,0,254,253,254,2,4,1,1,1,255,252,253,1,3,4,3,2,255,252,253,255,1,6,4,3,0,253,253,254,0,6,5,3,1,254,253,254,255,12,11,8,4,0,254,254,255,10,9,6,2,255,254,255,0,4,3,2,0,255,255,0,1,255,255,255,255,254,0,1,2,253,251,252,254,254,0,2,3,251,251,252,254,255,0,1,2,251,251,252,254,255,0,1,1,252,252,253,254,254,255,0,0,3,3,2,255,253,252,253,254,3,2,0,254,252,252,253,254,2,2,1,255,253,251,252,253,3,3,3,1,254,253,253,253,4,4,4,3,0,254,254,254,5,5,5,3,0,255,254,254,5,5,4,2,255,254,253,254,3,3,3,0,254,252,252,252,255,255,4,254,254,6,2,251,255,0,4,254,253,6,2,250,255,0,4,254,253,7,3,249,255,255,4,253,252,8,3,249,0,255,4,253,252,7,3,250,255,255,4,253,252,7,3,250,255,255,3,253,252,6,3,250,255,0,3,254,253,6,3,251,1,254,249,2,5,254,255,1,1,254,248,3,6,253,255,2,2,254,247,4,7,252,254,2,3,255,247,5,7,252,255,3,3,255,247,4,7,252,254,2,3,255,249,4,6,252,254,1,2,0,250,4,6,252,255,1,2,0,251,3,4,253,255,1,254,2,2,0,0,255,253,252,254,2,2,1,1,0,254,252,254,2,2,2,2,1,255,254,253,2,3,3,4,2,0,254,253,2,3,2,4,2,0,253,252,1,2,1,2,1,255,253,251,0,1,0,1,1,254,253,252,0,0,0,1,0,254,253,0,0,255,254,254,2,7,8,0,0,255,253,254,1,6,7,0,1,255,253,253,0,4,5,0,1,0,255,255,0,1,3,0,2,1,1,0,255,0,1,254,0,1,2,1,0,255,255,251,254,0,1,1,0,253,253,250,252,255,1,1,255,253,252,252,254,2,5,6,4,3,2,251,253,1,4,4,2,0,0,252,254,0,2,1,255,254,254,254,255,0,1,0,254,253,254,254], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+409617);
/* memory initializer */ allocate([0,0,0,255,255,254,255,254,255,255,0,0,0,1,2,254,254,255,255,0,1,3,4,254,253,254,255,0,2,4,5,2,1,254,254,255,0,1,0,1,0,253,253,255,0,1,0,0,255,253,253,255,1,1,1,0,0,253,255,1,2,3,3,0,255,253,255,1,3,3,3,254,254,252,254,1,3,4,4,253,253,252,254,1,3,3,4,254,253,251,254,1,2,3,3,4,5,3,4,4,4,4,5,3,3,1,0,0,0,0,1,1,1,255,254,253,252,253,254,2,2,0,254,254,252,253,254,2,3,1,255,255,253,253,254,1,2,0,0,255,254,254,255,0,1,0,255,255,253,254,255,1,1,0,255,255,254,254,254,254,255,255,0,1,2,1,0,1,2,3,5,6,5,5,3,1,2,3,4,5,5,4,3,254,254,253,253,254,255,0,0,253,253,252,251,252,253,254,255,255,255,254,254,254,255,0,0,0,1,0,255,255,0,0,1,255,0,255,254,253,254,254,255,7,7,6,5,4,2,255,254,3,3,2,2,1,0,254,253,0,255,255,255,0,255,254,254,255,253,254,255,0,0,0,1,0,254,254,255,255,1,2,2,3,1,255,255,255,1,2,2,3,1,254,253,254,255,1,2,1,254,251,250,251,253,254,0,0,255,254,253,255,0,254,254,0,0,255,255,0,1,255,254,0,0,254,255,0,0,0,254,255,254,253,253,254,255,253,253,255,254,253,253,254,254,253,252,2,2,0,0,0,0,255,254,5,5,3,2,2,2,0,255,8,8,6,5,4,4,2,1,249,248,250,253,255,255,254,255,251,251,253,0,2,1,0,0,255,255,0,3,4,3,1,1,2,1,1,3,4,3,2,2,3,2,0,2,3,2,1,2,4,2,255,255,0,1,1,1,3,2,254,253,254,255,0,1,3,1,253,252,253,254,0,1,252,254,255,2,3,3,1,0,249,251,252,254,0,0,255,254,250,251,251,252,254,254,254,253,255,0,255,255,0,0,0,255,2,3,2,2,2,2,1,0,3,5,4,3,1,0,1,0,3,4,3,2,0,255,255,255,5,5,3,1,0,255,255,255,1,1,0,255,253,251,250,252,1,1,0,0,0,253,253,255,0,255,255,0,1,0,1,3,254,254,253,255,2,2,4,7,254,254,254,0,2,2,3,6,255,0,0,1,1,0,0,3,0,3,3,3,1,254,253,255,1,3,4,3,0,253,251,252,0,2,0,255,253,252,254,254,1,4,2,0,254,253,254,255,3,6,3,1,254,254,0,255,4,7,4,1,254,253,255,0,3,6,3,0,253,253,255,0,1,3,0,255,253,254,1,1,0,1,255,254,253,255,2,2,254,255,253,253,253,255,1,2,3,1,255,0,1,0,0,0,2,255,254,255,1,0,255,255,1,255,254,0,1,0,254,253,0,254,255,1,3,1,253,251,0,254,255,2,5,2,253,251,0,254,255,4,6,3,254,251,0,254,0,4,7,4,254,252,0,254,0,4,6,4,254,252,254,254,253,252,253,254,255,0,1,1,0,255,255,255,0,1,3,3,2,2,1,1,1,1,2,2,2,2,1,0,0,1,0,0,0,0,255,255,255,255,252,252,252,252,252,252,252,253,253,253,254,253,254,255,255,0,3,4,4,5,5,6,6,7,255,254,7,254,252,255,255,0,255,254,9,255,252,255,255,0,255,253,10,255,252,255,255,1,255,253,10,254,253,255,255,2,255,254,10,254,252,255,255,2,255,254,9,254,252,255,255,2,255,254,8,254,252,0,255,1,0,254,7,254,253,255,0,2,3,252,1,3,253,254,1,0,3,251,1,4,253,254,1,0,3,250,2,5,253,255,3,0,3,250,2,5,253,255,2,0,3,250,1,5,252,254,3,0,3,250,1,5,253,254,2,0,2,250,1,4,253,255,1,0,2,250,1,4,254,255,1,0,0,0,1,1,1,0,0,2,0,255,1,1,1,0,0,2,0,255,0,0,0,0,0,2,0,255,0,0,0,0,255,0,1,0,1,0,0,255,254,255,3,1,1,0,0,254,252,253,5,3,2,1,0,253,251,252,5,4,2,0,255,252,251,251,1,0,255,254,254,253,250,247,2,0,255,255,0,0,253,250,1,0,0,255,0,0,254,251,2,1,1,1,1,2,255,253,1,1,2,1,2,2,1,255,1,1,2,1,1,1,1,1,0,0,2,1,0,0,2,2,0,1,2,2,0,0,2,2,252,253,0,1,4,6,4,3,253,254,0,0,2,4,1,0,255,255,0,0,1,1,254,253,1,1,1,0,1,1,253,251,1,1,1,0,1,1,253,251,255,0,0,255,1,1,254,252,255,0,0,255,1,2,0,254,255,0,0,0,2,3,1,0,255,0,3,4,0,252,251,251,0,0,4,5,2,254,253,254,0,255,2,4,2,255,255,0,0,254,255,1,0,254,0,1,1,254,254,0,0,255,255,1,1,254,253,0,1,0,255,0,1,254,254,1,3,1,0,0,1,254,255,2,4,2,0,0,1,2,3,2,0,2,2,1,255,0,1,0,253,1,1,1,255,0,0,254,252,0,2,1,255,2,2,255,251,0,2,1,255,3,4,255,251,0,2,1,254,2,4,0,252,255,0,0,252,0,2,0,252,254,0,0,251,255,2,1,254,1,3,2,1,0,1,0,1,2,255,254,2,0,255,254,1,3,0,255,3,0,254,252,0,3,1,0,5,1,253,251,254,2,1,1,6,1,254,251,254,1,0,1,5,1,255,251,254,0,255,0,3,0,254,252,254,0,255,0,1,255,0,254,0,1,0,1,1,1,2,3,2,1,1,2,255,255,0,1,1,0,1,1,252,253,0,0,1,1,1,2,252,253,0,2,2,2,3,2,251,252,0,1,1,1,1,2,251,252,255,255,254,254,255,0,253,254,0,0,254,253,254,255,2,3,4,4,2,0,0,0,252,254,0,1,0,0,0,0,253,255,1,1,0,0,0,0,254,0,2,2,0,0,0,2,255,1,2,1,255,0,3,5,0,2,1,255,254,0,5,6,0,1,0,253,253,0,4,6,1,1,254,252,252,253,1,2,1,0,254,252,251,252,254,0,255,253,253,253,253,254,255,255,3,2,1,0,0,1,1,1,5,4,3,2,1,1,2,2,2,1,0,254,254,254,255,255,0,0,0,255,254,254,254,254,0,1,3,3,2,1,255,255,0,1,3,4,3,2,1,255,252,253,255,1,0,254,253,253,253,252,249,248,249,252,255,2,0,255,253,252,252,254,0,2,1,0,0,255,253,254,0,2,2,1,1,0,255,255,0,2,1,1,1,1,0,0,0,1,1,1,1,1,1,1,1,1,0,0,1,2,3,3,2,2,0,0,1,3,4,4,3,2,3,3,3,0,255,0,1,2,1,1,1,255,254,255,255,1,254,254,255,253,253,254,254,0,252,252,254,254,254,254,253,0,252,252,255,1,1,0,255,2,253,255,2,3,4,3,3,5,254,0,2,3,3,3,3,3,254,254,0,0,0,0,0,1,0,2,1,255,253,255,3,254,255,0,255,255,253,0,4,254,254,254,254,254,254,1,5,254,253,254,253,255,254,1,4,253,254,0,255,0,255,0,3,251,1,2,1,2,0,0,2,251,2,4,2,3,1,1,3,253,1,2,1,1,0,1,4,254,4,253,252,255,3,3,1,3,4,252,252,255,3,2,0,2,4,253,252,0,2,2,255,1,4,253,254,1,2,1,254,0,2,252,254,1,2,0,253,0,2,253,254,0,1,0,254,2,3,255,255,0,0,0,0,3,2,254,254,254,255,255,255,2,2,2,3,4,3,1,0,255,1,0,1,2,1,255,254,254,2,1,2,1,1,0,255,255,4,3,4,3,2,1,1,1,3,2,2,2,1,1,1,1,255,254,255,0,255,255,255,255,253,253,254,255,254,254,254,254,252,252,253,253,252,252,253,253,2,1,255,253,252,254,3,4,2,2,1,255,253,254,1,2,1,2,3,3,0,254,255,254,255,0,2,4,2,0,255,253,254,254,0,3,3,2,0,253,0,254,253,255,1,2,2,255,3,255,252,251,253,0,2,0,6,3,254,250,251,0,3,1,254,3,254,0,3,254,254,1,253,4,253,0,3,254,255,2,253,5,253,0,4,254,255,2,254,4,252,255,3,253,254,2,253,4,253,0,3,253,255,2,254,5,254,0,3,253,255,2,254,4,253,1,3,254,255,2,254,3,254,1,3,254,0,2,1,0,0,255,1,2,252,255,2,0,0,255,1,2,252,254,1,1,1,255,2,4,254,0,0,255,1,255,2,5,255,1,0,255,0,254,1,5,255,1,0,255,255,254,0,3,253,255,1,1,0,254,0,3,253,255,1,1,0,253,0,3,254,0,1,0,255,1,1,2,4,5,1,0,255,1,1,1,5,7,0,0,254,255,255,0,3,5,0,255,254,255,255,255,2,3,0,255,253,255,255,255,1,2,255,254,252,254,254,254,0,0,255,254,254,255,254,254,0,0,0,255,255,0,255,255,0,0,3,3,0,255,255,1,4,4,2,3,0,254,254,0,1,1,2,3,1,255,255,0,1,0,1,2,0,255,255,255,0,254,0,1,0,255,254,255,0,254,0,1,0,255,254,255,1,0,1,1,255,253,252,253,1,3,1,2,255,253,251,252,1,3,253,254,0,1,1,1,0,254,0,1,1,1,0,0,255,253,1,2,1,1,0,255,255,254,0,255,253,255,255,255,0,255,0,253,250,253,254,255,1,1,2,255,252,253,254,0,2,2,5,4,1,1,0,1,3,2,5,4,2,1,0,255,0,1,254,0,254,251,250,253,0,0,254,0,1,0,255,1,2,2,254,0,1,3,2,2,2,1,254,0,2,4,3,2,1,1,254,0,2,3,2,0,255,0,253,255,1,1,0,255,255,1,252,255,1,0,255,254,0,2,252,255,0,255,255,254,1,4,253,0,0,255,1,1,1,0,253,1,0,255,0,0,255,255,255,3,3,0,1,0,0,1,253,2,2,254,255,0,0,1,251,0,0,254,255,1,0,2,249,254,1,0,1,2,2,2,251,0,3,2,3,3,2,2,253,2,4,1,0,0,254,253,5,2,254,254,0,255,255,255,2,255,252,253,255,254,255,255,0,254,254,1,2,255,0,1,255,254,255,3,3,255,0,2,1,0,0,3,3,254,255,2,2,1,1,3,2,254,254,0,1,0,255,1,1,253,253,254,1,0,1,2,3,0,0,0,252,251,253,0,1,255,254,255,254,253,255,1,2,0,0,0,1,1,2,1,2,1,1,1,3,4,3,1,0,254,255,255,3,3,2,0,254,253,253,254,1,1,0,255,254,252,254,254,2,1,0,0,0,255,0,1,2,1,1,1,1,1,1,3,0,0,0,255,254,255,1,0,254,255,255,254,253,254,0,0,255,0,0,255,254,0,1,1,1,1,0,255,255,1,3,1,2,2,0,254,255,2,3,0,3,1,255,255,1,4,2,254,2,0,253,255,3,5,0,251,1,255,254,0,3,3,255,250,255,0,3,4,2,0,1,2,254,255,0,1,255,254,0,1,254,253,254,253,250,249,250,253,2,2,3,1,255,254,253,254,2,2,3,1,0,0,0,0,2,1,1,0,1,1,0,1,1,0,0,0,0,1,1,2,1,0,255,0,0,2,2,1,1,1,3,1,255,255,255,1,254,255,0,0,254,254,255,2,254,254,1,1,1,0,1,3,254,254,0,255,0,255,0,2,0,0,1,0,255,255,254,1,3,2,2,1,0,254,254,1,5,3,3,2,1,1,1,4,0,253,252,251,252,253,255,1,250,252,255,2,2,0,0,255,252,254,1,3,3,2,2,0,253,254,255,2,3,3,2,0,253,254,254,1,2,1,1,255,254,254,254,0,2,2,1,255,255,255,255,1,2,3,2,0,255,255,254,1,2,2,2,255,0,255,254,0,2,1,0,255,6,4,2,1,0,0,0,1,4,2,255,254,254,254,255,255,2,1,255,254,254,254,254,255,2,2,0,254,254,254,255,0,0,0,255,254,254,255,0,1,253,253,254,255,255,254,255,0,253,254,2,3,2,0,255,254,254,0,4,5,5,2,0,255,5,4,2,0,255,254,255,255,4,3,2,1,0,255,0,255,1,1,0,1,1,0,1,255,254,255,255,0,0,254,254,253,255,0,0,0,255,253,253,251,0,1,1,255,255,254,254,253,255,255,255,254,255,1,3,1,255,254,254,255,2,5,6,5,253,253,254,1,1,254,255,255,1,2,3,4,1,253,255,253,3,2,0,1,255,253,255,253,1,0,255,0,255,255,1,0,1,1,0,1,2,2,5,3,1,1,1,2,2,2,3,0,253,255,254,254,253,253,255,253,255,1,1,0,255,255,0,254,2,0,254,254,2,4,1,254,1,0,254,255,3,5,2,255,255,254,253,254,1,3,1,254,255,254,255,255,0,2,1,255,0,0,1,1,1,2,2,0,0,1,4,4,2,2,3,1,254,255,2,1,254,253,254,253,255,0,1,0,253,252,252,251,4,0,253,252,252,252,254,255,5,0,255,0,255,253,254,255,4,0,0,1,1,0,0,0,0,253,254,255,0,0,1,0,0,254,0,0,1,1,2,1,2,0,0,0,1,1,1,0,2,0,255,255,1,1,1,0,1,255,254,254,0,2,2,2,253,251,254,0,255,253,253,0,0,254,0,2,2,0,0,3,2,255,254,0,0,255,255,2,5,2,255,255,255,255,255,2,5,2,0,255,255,0,255,2,2,1,0,0,0,1,0,2,255,255,1,1,2,2,1,2,253,254,0,0,0,0,254,255,0,3,2,0,254,253,253,253,0,3,3,1,0,0,1,2,255,0,255,254,255,255,1,3,255,0,255,254,255,255,0,2,255,0,255,254,0,0,255,2,255,0,255,254,255,255,254,1,0,1,0,253,255,255,255,2,5,5,2,255,255,255,1,3,0,0,1,255,253,254,0,2,1,1,3,0,254,254,0,1,1,1,3,1,0,0,255,255,0,255,2,1,1,0,255,253,255,254,1,1,1,0,254,252,255,0,2,1,1,0,255,253,1,1,3,2,1,0,254,253,2,2,4,2,1,255,254,252,1,2,2,2,0,254,0,2,255,255,254,253,252,251,253,1,0,1,1,0,255,255,255,1,0,1,1,1,0,0,0,2,0,1,1,2,1,1,1,2,255,255,0,2,2,2,2,3,254,252,252,255,254,254,254,0,1,0,0,1,0,0,0,1,0,255,253,254,0,2,2,1,0,255,254,253,0,1,1,2,1,0,254,253,255,0,0,1,255,0,255,254,0,0,255,0,255,1,1,0,2,2,0,0,0,2,3,1,3,5,3,2,255,1,1,254,0,3,1,1,255,0,0,252,252,255,255,255,255,1,1,0,1,2,1,2,253,0,1,0,1,1,0,2,251,253,255,255,0,1,0,1,252,253,254,253,254,255,255,0,0,0,255,254,254,254,254,0,3,4,2,0,0,0,0,1,2,1,0,0,0,0,255,0,0,1,2,3,4,4,3,2,255,4,7,4,0,0,0,0,255,4,6,3,0,1,1,1,0,3,4,0,255,0,0,1,0,1,1,254,255,0,255,255,255,0,255,255,255,0,0,0,255,255,255,0,0,0,0,0,255,253,253,0,1,255,254,255,253,252,252,254,255,254,254,255,2,2,1,0,1,1,0,253,254,255,0,0,1,1,0,253,254,255,0,1,2,1,1,254,1,2,2,2,3,3,2,255,1,2,1,0,1,1,2,255,0,1,254,252,254,0,1,255,1,1,255,253,254,0,255,253,1,2,0,255,0,1,255,252,255,255,254,254,0,3,4,3,1,1,255,253,254,0,0,0,2,2,2,2,2,1,255,255,1,1,1,3,3,0,254,254,0,255,255,255,0,254,255,255,255,253,252,253,254,254,0,2,255,255,0,1,2,2,3,5,254,255,255,0,0,0,0,1,254,253,2,0,0,1,1,255,255,252,1,254,255,2,2,0,1,252,0,254,254,1,1,255,2,253,1,255,255,1,1,255,3,254,3,1,0,1,1,255,1,253,2,1,0,1,0,255,255,251,1,0,255,0,1,1,0,253,3,3,1,2,3,3,0,255,254,1,5,5,2,255,1,255,254,255,1,1,254,251,1,1,255,254,255,255,255,253,1,1,255,255,255,2,4,3,255,255,255,255,255,0,4,3,255,255,0,1,255,253,255,255,0,0,0,2,2,0,0,255,0,254,253,0,1,1,3,2,2,3,2,1,0,0,254,254,2,3,0,1,1,3,3,2,0,0,253,255,255,2,2,3,254,254,253,1,1,2,1,1,254,255,254,2,1,1,255,254,0,1,0,2,0,0,254,254,0,1,0,2,0,0,254,254,253,254,254,0,255,254,254,253,0,1,255,3,255,1,3,255,0,1,255,3,255,255,2,253,1,1,254,3,255,253,0,253,2,2,254,3,0,254,1,254,1,1,253,3,255,254,1,253,1,1,253,3,0,255,1,254,1,2,255,4,0,255,1,254,0,1,255,3,255,253,0,253,253,253,255,1,2,1,255,254,254,254,0,2,1,0,254,254,253,254,1,2,1,255,254,255,253,254,2,4,0,254,254,1,253,255,2,4,0,254,254,2,255,1,4,3,255,253,254,2,0,2,4,2,255,254,255,2,0,1,2,0,255,0,1,3,3,0,251,1,4,0,0,1,1,254,251,2,5,255,254,1,255,0,0,3,3,1,0,255,254,3,4,254,253,255,0,254,253,3,5,253,253,0,0,254,255,3,2,254,254,2,2,255,2,0,0,255,0,0,0,0,0,253,254,1,3,0,254,254,9,8,4,0,253,252,252,253,9,8,4,255,252,251,251,253,8,7,3,254,251,251,251,252,6,4,1,254,252,251,252,253,244,242,245,252,1,5,6,6,248,246,249,251,254,1,1,1,5,4,3,1,0,0,255,255,13,13,9,6,3,0,255,254,252,252,253,255,1,4,8,11,251,250,252,254,0,3,8,12,249,249,250,252,254,2,7,10,249,249,251,252,254,1,5,8,253,254,255,1,3,6,7,6,2,3,5,7,8,8,6,4,4,5,4,3,1,254,250,249,1,0,254,249,246,242,239,240,251,252,1,8,9,3,253,249,249,250,1,11,12,5,253,248,248,249,0,9,11,5,253,249,248,250,255,5,8,4,254,250,252,251,249,248,247,247,248,250,252,251,250,249,249,250,252,254,0,1,2,3,5,8,10,9,1,2,3,6,9,12,14,13,5,6,6,5,4,3,2,1,5,6,7,7,6,6,6,4,255,0,1,1,3,5,5,5,243,240,239,239,242,246,250,252,9,11,13,16,15,13,12,10,252,251,250,249,249,249,250,251,250,250,249,249,249,249,250,251,254,255,0,0,0,0,0,255,245,243,241,240,240,242,244,246,2,3,4,5,4,3,3,3,6,7,8,8,8,7,6,5,3,4,3,3,3,3,3,3,3,4,4,1,254,249,243,239,5,7,7,5,1,251,243,237,6,8,9,8,5,255,247,240,6,8,10,10,7,2,252,245,18,9,255,246,243,247,252,0,22,12,255,244,241,246,252,2,23,13,0,246,243,247,253,2,20,12,2,250,247,250,254,2,250,250,250,249,249,249,249,250,250,249,248,248,247,247,247,248,253,253,253,253,253,253,253,253,12,15,18,21,21,19,17,14,14,16,18,18,18,16,15,13,5,6,6,5,5,4,4,3,250,249,247,246,246,246,247,249,246,245,243,242,242,243,244,246,229,239,252,5,9,10,10,7,224,237,253,7,11,12,11,8,226,240,254,8,12,12,10,7,233,244,0,7,10,11,9,6,16,17,16,12,6,255,248,244,17,18,15,10,1,248,241,238,15,14,10,4,251,242,236,233,10,8,4,255,247,240,235,234,246,244,244,245,251,4,14,20,245,243,241,244,252,7,19,27,245,243,242,245,253,8,21,28,246,245,244,247,254,8,18,25,255,255,255,1,4,6,6,5,0,0,0,2,4,3,1,254,0,0,2,4,4,255,249,246,0,0,3,5,3,253,245,241,242,243,248,255,3,3,255,252,251,252,255,4,8,8,3,0,3,2,2,3,4,5,3,1,5,3,0,254,254,255,255,255,9,1,250,250,251,253,254,255,12,1,250,250,252,254,255,0,14,4,252,252,254,254,255,255,14,6,255,255,255,255,255,255,4,6,8,10,11,9,7,5,255,255,255,0,0,255,255,254,254,252,252,251,251,251,251,252,254,253,253,252,252,253,254,255,2,3,4,4,3,1,0,0,255,1,4,5,6,5,4,3,248,250,254,2,3,4,4,3,242,243,247,251,254,255,0,0,253,252,251,252,0,7,12,13,253,252,251,251,254,4,9,10,254,253,252,251,252,255,3,4,255,255,254,253,253,254,0,1,9,5,254,248,245,246,249,252,12,10,6,2,0,255,0,0,2,2,3,4,3,1,1,1,247,248,252,0,1,2,1,0,6,8,8,5,1,251,245,243,0,1,2,2,255,252,248,245,253,254,1,3,3,1,255,252,254,255,2,5,6,6,4,1,3,4,5,5,4,1,253,250,5,6,4,2,2,2,0,253,6,5,0,251,251,254,255,254,7,4,253,245,244,249,253,254,1,0,255,255,255,0,0,0,2,3,4,4,5,5,4,3,249,247,247,246,246,247,249,250,3,4,5,6,5,5,5,5,249,249,249,249,250,250,251,252,251,252,253,255,255,255,0,0,253,254,1,4,5,5,5,5,254,255,3,6,9,10,10,9,242,1,10,3,254,0,1,1,240,2,13,3,253,255,1,0,241,2,12,3,252,254,1,1,246,3,10,2,253,255,1,1,0,1,4,2,251,246,253,11,255,1,4,2,250,243,254,15,255,0,3,1,250,244,255,15,255,1,2,1,252,248,0,11,10,5,254,254,2,5,1,252,7,0,248,250,1,5,2,252,2,251,244,249,2,7,4,255,255,249,246,252,4,9,7,2,251,251,252,250,250,251,251,253,255,254,254,252,251,250,251,252,6,7,7,4,0,254,253,253,13,14,13,10,5,1,255,254,1,1,2,2,2,2,2,2,251,250,248,247,247,248,249,250,7,9,10,11,11,9,7,5,255,254,253,253,252,252,252,253,255,255,0,0,0,0,255,255,253,253,252,251,252,253,253,254,2,1,255,253,253,254,255,0,12,12,8,3,1,0,0,1,250,248,248,250,254,2,6,8,1,1,255,254,0,3,5,7,3,3,1,255,255,0,0,2,0,1,0,255,255,255,254,255,1,0,0,0,0,0,2,4,2,1,3,4,3,1,0,2,2,1,0,0,255,255,0,3,5,1,250,244,243,248,255,4,254,0,255,254,255,0,2,3,250,253,254,0,1,1,1,1,247,251,0,4,5,3,1,0,248,253,3,7,8,4,1,0,1,2,2,3,3,1,255,253,4,5,5,6,6,5,2,0,0,0,0,0,1,0,254,252,253,253,252,253,253,252,249,248,14,12,6,255,253,253,0,0,7,5,1,253,251,252,254,255,254,254,254,254,254,254,255,255,250,252,255,1,1,1,0,255,2,2,1,253,250,249,250,253,1,0,255,253,254,1,4,6,0,0,1,2,4,7,8,7,0,0,0,0,255,252,249,248,0,2,1,254,253,253,254,255,255,1,0,253,251,254,0,2,254,255,254,251,252,1,6,9,253,254,253,252,254,5,11,13,252,254,2,6,4,253,246,242,254,255,1,4,4,1,255,254,0,0,255,254,254,0,4,6,2,2,0,253,253,0,5,9,252,252,254,1,6,9,3,249,254,254,254,255,4,8,0,245,1,1,0,0,2,6,255,246,2,2,1,0,2,4,0,249,255,254,253,250,249,248,248,248,2,3,3,1,255,254,253,252,5,5,5,4,3,2,0,255,3,3,3,3,2,2,1,1,3,3,2,254,253,0,7,10,1,2,2,254,251,252,0,3,0,3,4,2,253,251,250,252,0,2,4,4,1,252,249,249,2,4,5,5,5,5,6,6,252,252,253,251,251,253,253,254,253,252,252,251,252,254,254,254,1,1,0,0,2,4,5,4,254,0,3,4,4,3,2,2,247,249,252,0,3,6,6,6,251,251,253,254,0,1,3,4,5,5,2,254,252,250,251,253,1,250,252,7,5,254,254,1,5,251,252,6,4,251,252,1,5,251,252,6,4,251,253,1,1,249,253,8,7,255,253,1,248,249,252,0,2,4,5,5,5,6,5,2,255,251,249,249,5,6,4,1,253,251,250,251,249,249,251,254,1,6,9,10,6,3,0,1,3,0,248,242,3,0,255,1,4,3,0,252,1,0,0,1,2,1,1,1,255,255,1,2,1,255,255,0,1,1,1,1,0,254,253,0,1,2,1,0,254,248,247,252,1,3,3,2,1,253,253,1,0,1,1,1,1,1,4,8,2,5,9,7,2,255,255,1,252,255,1,0,253,252,255,2,253,0,3,3,0,255,0,2,252,255,1,1,254,252,251,252,1,255,254,254,255,2,4,5,2,1,1,0,255,255,0,0,2,3,4,5,4,2,1,0,247,247,250,253,255,255,255,255,250,250,4,7,0,254,255,254,255,254,5,6,255,254,0,255,4,255,1,0,252,254,0,254,7,1,255,254,253,1,3,1,4,2,1,3,3,1,1,2,2,254,252,0,3,1,0,0,1,252,248,252,1,2,1,0,2,253,247,250,0,3,3,2,255,255,0,255,255,0,1,2,3,1,252,248,249,253,1,2,2,255,253,254,255,0,1,0,255,0,5,11,9,3,255,253,255,254,254,255,1,1,1,1,0,255,0,3,6,6,5,5,2,1,255,255,254,251,250,252,2,2,2,1,255,252,251,251,255,253,250,249,250,252,255,1,5,5,3,4,4,3,4,5,255,254,253,254,254,254,0,1,0,0,0,0,0,1,2,3,250,250,252,255,2,2,2,2,250,249,251,254,0,255,255,0,2,2,2,4,4,3,3,4,2,1,0,255,0,0,2,4,12,5,251,248,251,0,2,2,2,253,250,253,0,0,255,254,254,253,255,3,4,1,254,253,2,2,3,4,3,1,255,255,3,2,1,0,1,4,3,0,4,3,0,251,250,0,3,3,2,3,1,249,244,250,1,3,1,3,4,255,250,252,0,1,247,252,2,6,7,4,1,0,249,255,4,6,4,0,253,253,250,0,4,4,1,254,253,254,252,1,3,2,0,254,255,0,0,5,2,251,253,3,1,252,254,4,2,250,253,6,4,253,255,5,3,251,255,7,3,252,255,2,0,250,253,5,3,253,248,253,3,5,3,1,254,254,2,4,4,254,252,253,1,3,2,1,253,251,253,3,4,3,251,250,251,3,10,8,255,251,0,3,2,252,247,249,0,6,251,255,5,7,4,255,253,253,251,251,254,3,6,5,255,252,9,6,0,252,254,1,1,255,255,255,255,1,1,0,255,0,255,0,0,0,0,255,255,0,2,1,254,255,1,1,0,0,12,8,2,255,255,252,249,249,2,1,3,6,7,4,2,0,1,0,255,0,255,252,249,248,0,0,255,0,0,0,255,253,0,0,0,0,1,1,0,254,255,0,1,1,0,0,255,254,0,0,255,253,252,253,255,1,255,0,0,0,1,4,10,12,255,0,254,254,253,253,255,1,253,255,254,252,2,9,9,7,253,0,255,253,0,2,255,1,255,1,254,253,0,255,253,0,0,0,253,254,0,255,255,1,255,254,255,255,254,255,255,254,2,255,254,255,0,1,0,254,3,255,254,2,5,3,255,253,1,251,251,1,6,6,2,0,1,2,0,255,0,1,0,254,251,253,255,0,1,2,1,254,249,251,254,254,254,254,0,1,255,0,1,1,0,3,9,12,0,6,5,1,254,253,0,3,0,6,5,1,1,1,2,3,251,254,254,253,0,0,0,0,250,253,253,254,0,0,255,254,4,4,2,1,0,255,255,0,254,254,0,1,2,1,1,0,2,2,1,255,253,251,247,246,2,1,255,255,1,4,4,1,4,0,254,254,254,254,255,0,7,1,252,253,254,0,1,1,10,5,255,254,0,1,1,0,5,1,253,252,253,255,255,254,2,1,255,253,253,1,1,255,254,255,3,0,255,1,1,0,253,1,7,2,253,254,255,0,254,4,8,255,248,251,0,2,252,255,1,2,1,253,252,254,251,253,254,1,4,4,4,6,253,254,252,253,0,1,1,2,2,2,2,1,2,1,255,255,252,255,0,255,253,253,255,255,1,4,4,2,0,255,254,253,4,6,5,3,2,1,254,252,0,1,1,1,1,255,252,250,1,2,2,255,250,251,255,2,253,254,1,1,252,253,2,5,254,255,2,2,253,252,0,3,254,254,2,6,5,2,1,2,2,253,253,0,0,2,3,1,3,255,1,3,1,2,255,251,251,249,252,254,1,8,8,1,255,0,2,0,253,0,1,253,254,251,251,254,253,255,0,254,255,252,0,4,0,2,4,0,0,0,8,10,2,1,3,255,252,253,2,3,253,253,1,255,1,254,252,2,7,3,254,255,6,4,254,255,2,0,255,3,1,1,254,254,254,251,253,4,250,254,1,1,255,252,254,4,254,255,254,254,0,1,0,254,255,1,0,255,0,0,255,253,0,1,254,252,253,255,0,0,6,8,5,0,0,1,2,3,254,254,2,5,2,0,0,1,2,254,254,255,255,1,2,4,2,255,0,1,0,0,0,1,248,249,255,1,255,255,1,3,0,3,6,2,254,1,2,0,246,249,255,0,253,255,2,1,0,0,2,2,1,1,1,255,3,0,254,254,0,2,1,0,8,1,0,0,254,253,255,0,2,254,2,5,1,254,255,1,253,250,253,255,253,253,255,2,2,0,1,2,2,1,0,0,1,255,255,254,255,0,1,0,15,9,2,255,254,253,253,253,0,253,254,0,0,255,255,255,1,0,1,0,0,255,255,255,0,2,2,254,253,253,249,248,0,2,2,0,1,2,1,1,1,2,2,2,3,1,0,3,1,0,255,254,255,254,0,5,245,250,255,1,2,3,1,253,1,4,3,255,254,1,2,255,2,2,1,255,254,0,1,255,0,0,255,255,0,2,3,2,1,1,2,1,255,1,0,252,0,0,0,254,254,2,4,254,254,253,0,0,255,2,1,250,0,2,5,5,3,2,255,249,4,2,0,0,3,3,1,255,0,255,255,3,6,4,1,255,254,254,0,2,2,0,254,254,255,0,255,251,249,251,255,1,5,255,254,0,2,4,2,251,0,251,254,2,1,2,0,250,6,1,0,1,254,255,4,2,2,253,253,0,255,254,0,0,1,255,0,2,0,0,6,11,2,255,255,0,253,254,3,5,0,254,255,0,255,0,0,253,1,255,255,255,254,255,253,249,1,1,254,254,1,3,1,254,255,2,0,255,255,1,0,0,252,2,3,255,254,254,0,1,245,254,4,5,6,2,255,254,250,254,1,255,253,252,1,9,253,0,3,3,2,253,253,3,1,1,0,0,1,255,254,3,2,0,253,253,0,255,255,3,1,255,253,1,2,250,252,6,0,254,251,254,0,253,254,3,2,2,1,254,254,1,2,255,255,1,1,254,255,6,7,255,1,0,252,254,1,254,253,1,252,0,253,254,2,0,253,0,253,4,3,1,8,7,0,255,253,4,1,252,2,3,254,253,253,6,1,252,1,1,255,255,254,4,253,253,3,0,255,255,1,2,252,2,4,253,255,2,3,255,252,5,4,250,253,2,4,0,250,249,252,248,243,247,248,248,255,6,254,5,22,27,240,249,11,10,238,249,13,10,241,252,12,8,247,255,9,5,254,2,15,240,253,2,19,237,253,2,19,237,254,3,15,242,17,22,22,16,250,249,251,254,244,240,240,244,1,1,255,253,11,239,0,8,14,235,255,9,14,235,254,8,11,240,254,6,7,254,240,11,9,254,235,14,10,255,234,14,8,255,238,10,246,16,3,247,243,20,4,245,242,21,4,246,245,16,3,248,11,4,247,247,15,6,244,242,17,8,244,242,16,10,249,245,4,10,14,13,255,7,15,16,244,249,3,8,236,233,238,246,246,238,230,231,4,1,250,245,13,15,11,3,12,15,13,8,240,237,240,245,7,12,15,11,11,16,16,11,250,247,245,246,18,19,12,5,18,16,5,252,6,0,246,241,247,239,233,234,246,242,255,21,245,239,0,29,245,240,1,30,246,242,0,23,240,239,244,250,237,237,242,249,253,255,1,2,27,35,29,19,219,248,23,23,214,247,28,29,213,246,26,28,218,245,19,22,32,16,240,223,39,20,238,219,38,19,237,218,32,15,239,222,24,9,250,252,255,246,250,3,248,247,255,3,3,7,2,250,255,253,255,0,255,4,2,249,253,11,3,240,1,20,9,238,253,248,6,12,251,246,7,13,250,247,5,7,251,251,2,255,248,12,253,255,246,15,253,1,245,13,252,1,245,8,253,2,9,6,251,244,3,0,248,243,252,252,255,255,252,1,15,18,9,13,14,12,4,3,255,254,254,251,248,251,249,245,247,252,7,251,249,252,14,254,249,252,17,0,248,251,15,1,249,251,246,255,6,4,241,247,2,4,2,255,253,0,25,13,248,246,7,11,253,240,7,11,253,241,6,7,254,247,4,2,253,251,249,255,255,0,247,254,2,6,244,252,6,14,243,250,8,19,238,238,245,251,253,0,3,4,6,8,6,6,6,6,6,6,251,3,13,246,250,1,15,247,250,253,15,250,250,250,10,253,9,1,247,247,11,9,6,5,0,3,8,7,241,242,250,251,245,250,11,19,254,251,247,248,6,2,247,246,6,5,4,5,249,253,8,15,255,3,10,15,5,5,255,254,4,254,235,231,6,250,250,5,8,247,249,9,8,244,249,13,4,242,249,14,252,253,1,1,253,251,254,253,7,0,254,252,20,7,252,252,253,236,250,10,6,0,0,1,5,8,5,255,253,0,0,254,13,6,255,2,5,3,2,3,253,0,3,0,240,248,254,251,254,249,250,0,253,250,253,1,251,255,2,255,255,12,16,5,249,1,9,8,246,254,5,3,250,2,7,3,252,0,255,249,3,4,247,232,0,2,6,3,255,255,4,7,5,3,255,254,3,6,247,2,1,6,243,1,1,8,246,2,1,8,249,1,253,253,2,22,254,253,251,12,254,253,246,2,253,255,252,2,11,12,8,2,251,251,251,248,250,252,0,253,254,255,3,3,12,250,254,255,12,248,254,254,9,249,0,253,4,250,2,254,237,1,12,253,252,4,5,252,6,1,254,255,4,252,254,7,253,252,249,248,252,252,254,0,255,2,14,16,252,254,4,4,255,7,2,251,254,0,255,1,4,253,255,13,6,244,242,8,255,5,4,251,254,5,3,247,254,7,4,244,255,7,4,247,250,253,1,1,11,11,0,250,6,4,254,249,244,246,3,10,254,253,253,254,6,11,14,10,247,245,246,246,2,2,3,2,249,251,249,255,255,2,0,7,255,1,0,9,3,4,251,255,10,255,241,255,4,1,251,2,253,1,255,1,253,1,4,4,2,255,4,10,6,2,255,0,2,2,249,244,252,2,0,253,255,252,255,248,3,255,2,247,4,0,5,251,2,0,8,3,3,2,1,1,4,254,0,3,2,255,4,1,0,6,255,231,255,254,254,252,253,0,255,252,255,255,252,2,0,250,2,25,245,255,5,0,7,0,254,2,10,255,253,4,251,251,254,255,0,6,3,255,254,255,255,1,255,249,244,251,8,6,2,4,2,6,255,250,9,10,255,252,1,0,252,0,3,254,247,251,252,3,4,0,252,3,3,0,245,0,3,2,245,3,7,2,2,252,7,3,1,248,7,1,255,244,4,1,3,247,2,2,2,254,254,9,239,253,3,1,252,7,1,250,5,4,255,3,255,2,0,252,249,8,12,255,254,5,4,251,3,251,248,254,0,0,251,254,254,248,3,27,255,252,253,6,253,1,254,249,4,4,1,255,249,246,249,253,10,10,5,3,254,254,252,253,0,1,5,7,4,254,240,236,0,4,7,8,2,0,254,255,254,1,3,17,253,1,254,255,255,254,255,254,255,251,255,0,5,253,1,0,6,254,0,0,255,254,0,253,245,1,8,255,3,0,0,0,0,2,4,1,2,0,6,1,254,238,253,2,242,0,6,1,251,254,255,1,255,1,0,1,1,7,4,0,255,0,1,252,1,8,3,252,253,4,1,3,250,1,252,1,1,244,3,3,255,246,0,255,2,0,2,1,3,2,2,4,3,0,0,3,2,0,254,1,5,2,251,0,6,255,242,255,254,250,253,253,2,255,4,5,6,255,254,0,4,4,255,251,252,1,245,0,255,2,252,1,2,253,3,255,1,254,15,0,1,255,0,254,1,252,249,1,254,250,255,21,254,2,255,1,21,255,254,0,255,253,1,254,247,254,2,255,2,1,252,255,1,8,2,250,246,255,4,0,252,253,3,3,5,0,255,255,3,2,1,254,254,254,4,3,5,2,252,239,0,254,4,3,249,252,0,3,9,9,2,255,245,250,0,255,5,1,0,1,0,17,5,245,3,254,250,0,2,254,252,1,252,1,2,255,251,255,251,253,253,5,253,254,4,16,2,251,254,5,255,255,0,0,252,1,255,2,5,11,255,255,254,1,252,254,253,255,251,255,10,0,6,1,0,253,0,252,1,0,254,252,3,255,6,9,3,0,254,1,254,0,254,253,254,254,1,0,1,250,1,0,2,1,255,3,254,1,0,255,241,0,255,5,2,6,2,0,2,2,0,244,252,6,0,1,4,255,1,2,1,252,1,254,249,0,0,0,0,255,251,2,11,3,1,3,0,250,0,253,247,252,1,3,255,0,4,1,254,0,7,253,255,6,1,254,6,2,0,255,3,254,254,4,0,2,255,2,242,2,2,2,0,255,254,3,253,242,0,2,3,253,5,1,3,2,1,253,4,242,1,254,11,255,0,255,3,0,255,1,0,2,254,3,253,2,252,255,252,3,255,2,1,3,250,254,2,7,254,1,2,0,254,0,0,255,12,5,255,2,248,255,1,249,2,254,252,2,11,0,245,254,3,1,253,255,0,3,1,255,0,3,0,254,0,250,255,253,12,249,254,0,7,254,1,1,1,2,2,2,255,2,0,2,233,0,4,0,3,2,1,3,252,251,255,5,253,5,10,255,0,0,3,252,1,255,2,251,7,2,250,249,7,3,253,252,249,254,7,8,248,252,3,4,19,17,9,3,242,240,244,248,238,240,248,253,11,14,12,8,7,240,246,20,7,239,246,20,250,18,8,235,249,18,9,236,25,3,236,242,29,7,238,243,227,252,21,14,225,250,20,14,237,230,228,232,31,32,22,10,15,24,31,28,224,224,234,243,2,248,233,230,247,3,27,35,3,11,21,21,8,252,229,222,226,225,12,47,227,226,13,47,38,30,239,210,34,26,237,210,214,206,205,213,34,48,55,48,48,54,51,42,212,204,203,209,4,5,0,250,254,254,0,1,245,250,255,254,1,8,9,1,0,1,250,5,8,1,244,2,7,242,249,8,5,248,0,8,1,4,11,8,244,248,0,251,255,1,0,4,241,248,3,16,17,8,252,250,9,252,243,248,2,6,1,238,255,11,11,244,6,0,2,0,14,6,249,235,1,255,243,236,1,1,10,21,234,251,7,13,245,255,4,12,249,0,14,19,252,3,251,237,230,242,10,15,18,4,250,254,25,19,251,238,236,249,4,2,243,250,255,252,25,37,254,221,5,4,1,1,235,220,2,43,2,254,255,3,8,254,250,255,254,253,2,12,251,254,254,255,253,255,255,251,255,7,8,254,2,7,5,253,1,1,253,248,253,255,253,254,254,253,2,13,15,0,245,250,3,0,0,0,250,247,251,252,18,4,1,3,12,3,0,4,240,253,3,253,239,3,18,2,255,253,255,255,250,16,248,0,247,14,249,0,3,243,14,251,3,243,14,252,249,20,14,233,8,249,248,4,8,241,237,16,246,13,11,253,9,255,1,26,5,241,229,2,236,7,16,252,216,9,31,1,26,244,226,249,40,254,237,4,6,0,0,0,250,254,1,2,0,255,0,250,9,0,254,255,249,8,2,253,255,2,253,2,7,252,254,4,2,0,0,250,253,254,9,2,254,255,0,252,253,253,0,253,250,2,10,4,3,0,246,8,0,0,252,4,255,1,4,2,3,249,247,7,2,1,247,252,255,12,0,0,3,255,7,252,3,242,4,2,244,247,1,11,2,5,1,0,3,1,0,2,0,8,6,237,250,246,249,252,9,7,5,7,6,21,3,253,245,247,251,254,252,247,240,255,254,251,1,36,8,11,19,0,2,5,252,215,255,255,254,255,254,254,1,6,0,4,1,248,1,1,1,0,254,253,4,0,2,255,3,253,1,3,252,1,255,3,0,251,3,4,2,3,254,253,250,255,254,253,254,2,252,8,1,0,249,4,2,6,249,255,1,0,254,2,252,1,8,250,2,255,250,2,0,2,5,4,248,255,255,245,0,9,0,254,2,2,17,251,252,255,255,252,254,254,0,243,9,253,255,12,249,2,0,254,251,2,249,251,20,253,7,7,255,226,3,5,8,1,250,3,255,252,2,254,245,18,0,249,3,14,20,253,238,247,7,254,0,255,254,0,0,255,252,255,1,0,254,2,0,4,1,253,2,1,3,1,251,1,253,0,255,254,7,1,0,253,2,5,0,254,2,251,255,1,255,254,4,255,0,253,5,0,0,3,255,254,252,1,5,255,255,0,255,9,255,254,255,255,254,5,5,255,254,2,253,254,1,2,245,1,2,1,3,2,2,246,255,254,4,2,4,1,4,5,251,1,0,6,245,1,1,0,6,6,0,2,1,241,7,3,5,9,226,2,2,2,222,1,9,2,5,8,8,2,7,2,6,6,2,229,1,4,14,10,14,18,16,18,10,10,14,14,14,16,0,0,0,0,16,14,0,128,129,0,128,129,255,255,255,255,255,255,0,0,96,29,34,0,108,0,0,0,96,73,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,6,7,6,0,0,0,0,243,4,53,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,1,0,4,0,3,0,5,0,3,0,12,0,4,0,13,0,4,0,56,0,6,0,57,0,6,0,58,0,6,0,59,0,6,0,240,0,8,0,241,0,8,0,242,0,8,0,243,0,8,0,244,0,8,0,245,0,8,0,246,0,8,0,247,0,8,0,224,3,10,0,225,3,10,0,226,3,10,0,227,3,10,0,228,3,10,0,229,3,10,0,230,3,10,0,231,3,10,0,232,3,10,0,233,3,10,0,234,3,10,0,235,3,10,0,236,3,10,0,237,3,10,0,238,3,10,0,239,3,10,0,63,0,6,0,168,251,29,0,192,141,29,0,0,0,0,0,0,0,0,0,200,48,29,0,108,0,0,0,48,115,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,2,1,2,1,0,3,5,3,5,3,5,3,0,2,3,2,3,2,3,2,0,6,123,12,1,0,2,11,108,36,8,1,0,9,93,50,6,0,3,16,77,77,16,3,0,6,50,93,9,0,1,8,36,108,11,2,0,1,12,123,6,0,0,0,0,0,0,0,53,53,54,0,0,0,0,0,0,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,18,0,0,0,20,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,8,0,16,0,24,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,176,0,192,0,224,0,0,1,32,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,64,2,128,2,192,2,0,3,128,3,0,4,0,0,0,0,0,0,140,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,255,255,255,255,0,0,0,0,0,213,127,170,254,43,129,84,41,252,86,131,215,2,168,125,82,135,45,248,172,121,211,6,123,174,4,209,133,80,250,47,164,113,219,14,90,143,37,240,141,88,242,39,115,166,12,217,246,35,137,92,8,221,119,162,223,10,160,117,33,244,94,139,157,72,226,55,99,182,28,201,180,97,203,30,74,159,53,224,207,26,176,101,49,228,78,155,230,51,153,76,24,205,103,178,57,236,70,147,199,18,184,109,16,197,111,186,238,59,145,68,107,190,20,193,149,64,234,63,66,151,61,232,188,105,195,22,239,58,144,69,17,196,110,187,198,19,185,108,56,237,71,146,189,104,194,23,67,150,60,233,148,65,235,62,106,191,21,192,75,158,52,225,181,96,202,31,98,183,29,200,156,73,227,54,25,204,102,179,231,50,152,77,48,229,79,154,206,27,177,100,114,167,13,216,140,89,243,38,91,142,36,241,165,112,218,15,32,245,95,138,222,11,161,116,9,220,118,163,247,34,136,93,214,3,169,124,40,253,87,130,255,42,128,85,1,212,126,171,132,81,251,46,122,175,5,208,173,120,210,7,83,134,44,249,10,83,116,97,110,100,97,114,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,58,10,78,65,77,69,32,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+419857);
/* memory initializer */ allocate([32,32,32,32,32,32,68,69,67,79,77,80,79,83,73,84,73,79,78,0,0,0,0,73,110,100,105,118,105,100,117,97,108,32,99,104,97,110,110,101,108,115,58,10,78,65,77,69,32,32,32,32,32,32,32,32,68,69,83,67,82,73,80,84,73,79,78,0,0,0,0,80,105,120,101,108,32,102,111,114,109,97,116,115,58,10,73,46,46,46,46,32,61,32,83,117,112,112,111,114,116,101,100,32,73,110,112,117,116,32,32,102,111,114,109,97,116,32,102,111,114,32,99,111,110,118,101,114,115,105,111,110,10,46,79,46,46,46,32,61,32,83,117,112,112,111,114,116,101,100,32,79,117,116,112,117,116,32,102,111,114,109,97,116,32,102,111,114,32,99,111,110,118,101,114,115,105,111,110,10,46,46,72,46,46,32,61,32,72,97,114,100,119,97,114,101,32,97,99,99,101,108,101,114,97,116,101,100,32,102,111,114,109,97,116,10,46,46,46,80,46,32,61,32,80,97,108,101,116,116,101,100,32,102,111,114,109,97,116,10,46,46,46,46,66,32,61,32,66,105,116,115,116,114,101,97,109,32,102,111,114,109,97,116,10,70,76,65,71,83,32,78,65,77,69,32,32,32,32,32,32,32,32,32,32,32,32,78,66,95,67,79,77,80,79,78,69,78,84,83,32,66,73,84,83,95,80,69,82,95,80,73,88,69,76,10,45,45,45,45,45,0,0,0,0,0,0,70,105,108,116,101,114,115,58,10,32,32,84,46,46,32,61,32,84,105,109,101,108,105,110,101,32,115,117,112,112,111,114,116,10,32,32,46,83,46,32,61,32,83,108,105,99,101,32,116,104,114,101,97,100,105,110,103,10,32,32,46,46,67,32,61,32,67,111,109,109,109,97,110,100,32,115,117,112,112,111,114,116,10,32,32,65,32,61,32,65,117,100,105,111,32,105,110,112,117,116,47,111,117,116,112,117,116,10,32,32,86,32,61,32,86,105,100,101,111,32,105,110,112,117,116,47,111,117,116,112,117,116,10,32,32,78,32,61,32,68,121,110,97,109,105,99,32,110,117,109,98,101,114,32,97,110,100,47,111,114,32,116,121,112,101,32,111,102,32,105,110,112,117,116,47,111,117,116,112,117,116,10,32,32,124,32,61,32,83,111,117,114,99,101,32,111,114,32,115,105,110,107,32,102,105,108,116,101,114,0,0,0,0,0,0,0,79,117,116,112,117,116,58,0,83,117,112,112,111,114,116,101,100,32,102,105,108,101,32,112,114,111,116,111,99,111,108,115,58,10,73,110,112,117,116,58,0,0,0,0,0,0,0,0,66,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,115,58,0,0,0,0,0,0,67,111,100,101,99,115,58,10,32,68,46,46,46,46,46,32,61,32,68,101,99,111,100,105,110,103,32,115,117,112,112,111,114,116,101,100,10,32,46,69,46,46,46,46,32,61,32,69,110,99,111,100,105,110,103,32,115,117,112,112,111,114,116,101,100,10,32,46,46,86,46,46,46,32,61,32,86,105,100,101,111,32,99,111,100,101,99,10,32,46,46,65,46,46,46,32,61,32,65,117,100,105,111,32,99,111,100,101,99,10,32,46,46,83,46,46,46,32,61,32,83,117,98,116,105,116,108,101,32,99,111,100,101,99,10,32,46,46,46,73,46,46,32,61,32,73,110,116,114,97,32,102,114,97,109,101,45,111,110,108,121,32,99,111,100,101,99,10,32,46,46,46,46,76,46,32,61,32,76,111,115,115,121,32,99,111,109,112,114,101,115,115,105,111,110,10,32,46,46,46,46,46,83,32,61,32,76,111,115,115,108,101,115,115,32,99,111,109,112,114,101,115,115,105,111,110,10,32,45,45,45,45,45,45,45,0,0,0,0,0,84,104,105,115,32,102,105,108,116,101,114,32,104,97,115,32,115,117,112,112,111,114,116,32,102,111,114,32,116,105,109,101,108,105,110,101,32,116,104,114,111,117,103,104,32,116,104,101,32,39,101,110,97,98,108,101,39,32,111,112,116,105,111,110,46,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,110,111,110,101,32,40,115,105,110,107,32,102,105,108,116,101,114,41,0,0,0,0,0,0,32,32,32,32,32,32,32,32,100,121,110,97,109,105,99,32,40,100,101,112,101,110,100,105,110,103,32,111,110,32,116,104,101,32,111,112,116,105,111,110,115,41,0,0,0,0,0,0,32,32,32,32,79,117,116,112,117,116,115,58,0,0,0,0,32,32,32,32,32,32,32,32,110,111,110,101,32,40,115,111,117,114,99,101,32,102,105,108,116,101,114,41,0,0,0,0,32,32,32,32,73,110,112,117,116,115,58,0,0,0,0,0,32,32,32,32,115,108,105,99,101,32,116,104,114,101,97,100,105,110,103,32,115,117,112,112,111,114,116,101,100,0,0,0,70,105,108,101,32,102,111,114,109,97,116,115,58,10,32,68,46,32,61,32,68,101,109,117,120,105,110,103,32,115,117,112,112,111,114,116,101,100,10,32,46,69,32,61,32,77,117,120,105,110,103,32,115,117,112,112,111,114,116,101,100,10,32,45,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,0,80,21,0,0,0,255,255,255,127,21,0,0,0,80,0,0,80,20,0,0,0,221,126,121,108,20,0,0,0,255,255,255,127,20,0,0,0,35,194,48,76,19,0,0,0,172,31,30,94,19,0,0,0,99,227,53,84,18,0,0,0,23,51,186,72,17,0,0,0,213,174,170,66,16,0,0,0,52,18,73,114,16,0,0,0,236,74,67,105,15,0,0,0,154,230,232,90,14,0,0,0,84,74,236,76,13,0,0,0,120,105,0,125,13,0,0,0,0,106,255,99,12,0,0,0,20,62,73,89,11,0,0,0,91,164,34,78,10,0,0,0,152,228,117,69,9,0,0,0,228,214,48,104,9,0,0,0,12,117,234,91,8,0,0,0,97,24,134,97,7,0,0,0,97,24,134,97,6,0,0,0,97,24,134,97,5,0,0,0,97,24,134,97,4,0,0,0,97,24,134,97,3,0,0,0,232,240,13,0,224,240,13,0,208,240,13,0,176,240,13,0,112,240,13,0,240,239,13,0,1,0,0,0,0,0,0,0,120,132,31,0,108,0,0,0,224,62,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,3,0,0,22,1,0,0,6,6,0,0,36,6,0,0,0,0,0,0,66,1,0,0,90,0,0,0,106,1,0,0,150,0,0,0,32,0,0,0,0,0,0,0,88,0,0,0,224,65,34,0,108,0,0,0,48,121,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,231,33,0,108,0,0,0,208,69,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,4,4,4,4,8,8,8,8,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,9,9,9,9,10,10,10,10,12,12,12,12,12,12,12,12,20,20,20,20,20,20,20,20,0,0,0,0,0,12,0,36,0,18,0,6,0,18,0,18,0,0,0,0,7,158,0,3,132,1,1,1,128,0,86,165,59,244,129,131,73,128,119,224,0,0,0,0,195,193,66,73,59,250,130,131,73,128,119,224,0,0,0,0,195,194,192,196,0,0,0,0,0,0,0,0,0,0,151,17,6,3,2,1,0,0,0,0,1,0,0,0,0,0,0,0,254,254,0,0,0,0,0,0,112,247,28,0,108,0,0,0,208,60,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,11,12,14,12,10,16,14,13,14,18,17,16,19,24,40,26,24,22,22,24,49,35,37,29,40,58,51,61,60,57,51,56,55,64,72,92,78,64,68,87,69,55,56,80,109,81,87,95,98,103,104,103,62,77,113,121,112,100,120,92,101,103,99,17,18,18,24,21,24,47,26,26,47,99,66,56,66,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,10,7,7,8,7,6,10,8,8,8,11,10,10,11,14,24,16,14,13,13,14,29,21,22,17,24,35,31,37,36,34,31,34,33,38,43,55,47,38,41,52,41,33,34,48,65,49,52,57,59,62,62,62,37,46,68,73,67,60,72,55,61,62,59,10,11,11,14,13,14,28,16,16,28,59,40,34,40,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,6,4,5,6,5,4,6,6,5,6,7,7,6,8,10,16,10,10,9,9,10,20,14,15,12,16,23,20,24,24,23,20,22,22,26,29,37,31,26,27,35,28,22,22,32,44,32,35,38,39,41,42,41,25,31,45,48,45,40,48,37,40,41,40,7,7,7,10,8,10,19,10,10,19,40,26,22,26,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,5,3,4,4,4,3,5,4,4,4,5,5,5,6,7,12,8,7,7,7,7,15,11,11,9,12,17,15,18,18,17,15,17,17,19,22,28,23,19,20,26,21,17,17,24,33,24,26,29,29,31,31,31,19,23,34,36,34,30,36,28,30,31,30,5,5,5,7,6,7,14,8,8,14,30,20,17,20,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,3,2,2,3,2,2,3,3,3,3,4,3,3,4,5,8,5,5,4,4,5,10,7,7,6,8,12,10,12,12,11,10,11,11,13,14,18,16,13,14,17,14,11,11,16,22,16,17,19,20,21,21,21,12,15,23,24,22,20,24,18,20,21,20,3,4,4,5,4,5,9,5,5,9,20,13,11,13,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,13,9,10,11,10,8,13,11,10,11,14,14,13,15,19,32,21,19,18,18,19,39,28,30,23,32,46,41,49,48,46,41,45,44,51,58,74,62,51,54,70,55,44,45,64,87,65,70,76,78,82,83,82,50,62,90,97,90,80,96,74,81,82,79,14,14,14,19,17,19,38,21,21,38,79,53,45,53,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,32,22,24,28,24,20,32,28,26,28,36,34,32,38,48,80,52,48,44,44,48,98,70,74,58,80,116,102,122,120,114,102,112,110,128,144,184,156,128,136,174,138,110,112,160,218,162,174,190,196,206,208,206,124,154,226,242,224,200,240,184,202,206,198,34,36,36,48,42,48,94,52,52,94,198,132,112,132,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,2,1,1,1,1,1,2,1,1,1,2,2,2,2,2,4,3,2,2,2,2,5,4,4,3,4,6,5,6,6,6,5,6,6,6,7,9,8,6,7,9,7,6,6,8,11,8,9,10,10,10,10,10,6,8,11,12,11,10,12,9,10,10,10,2,2,2,2,2,2,5,3,3,5,10,7,6,7,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,2,2,2,2,2,1,2,2,2,2,3,2,2,3,3,6,4,3,3,3,3,7,5,5,4,6,8,7,9,8,8,7,8,8,9,10,13,11,9,10,12,10,8,8,11,15,11,12,13,14,14,15,14,9,11,16,17,16,14,17,13,14,14,14,2,3,3,3,3,3,7,4,4,7,14,9,8,9,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,20,14,15,18,15,13,20,18,16,18,23,21,20,24,30,50,33,30,28,28,30,61,44,46,36,50,73,64,76,75,71,64,70,69,80,90,115,98,80,85,109,86,69,70,100,136,101,109,119,123,129,130,129,78,96,141,151,140,125,150,115,126,129,124,21,23,23,30,26,30,59,33,33,59,124,83,70,83,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,16,11,12,14,12,10,16,14,13,14,18,17,16,19,24,40,26,24,22,22,24,49,35,37,29,40,58,51,61,60,57,51,56,55,64,72,92,78,64,68,87,69,55,56,80,109,81,87,95,98,103,104,103,62,77,113,121,112,100,120,92,101,103,99,17,18,18,24,21,24,47,26,26,47,99,66,56,66,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,10,7,7,8,7,6,10,8,8,8,11,10,10,11,14,24,16,14,13,13,14,29,21,22,17,24,35,31,37,36,34,31,34,33,38,43,55,47,38,41,52,41,33,34,48,65,49,52,57,59,62,62,62,37,46,68,73,67,60,72,55,61,62,59,10,11,11,14,13,14,28,16,16,28,59,40,34,40,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,6,4,5,6,5,4,6,6,5,6,7,7,6,8,10,16,10,10,9,9,10,20,14,15,12,16,23,20,24,24,23,20,22,22,26,29,37,31,26,27,35,28,22,22,32,44,32,35,38,39,41,42,41,25,31,45,48,45,40,48,37,40,41,40,7,7,7,10,8,10,19,10,10,19,40,26,22,26,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,5,3,4,4,4,3,5,4,4,4,5,5,5,6,7,12,8,7,7,7,7,15,11,11,9,12,17,15,18,18,17,15,17,17,19,22,28,23,19,20,26,21,17,17,24,33,24,26,29,29,31,31,31,19,23,34,36,34,30,36,28,30,31,30,5,5,5,7,6,7,14,8,8,14,30,20,17,20,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,3,2,2,3,2,2,3,3,3,3,4,3,3,4,5,8,5,5,4,4,5,10,7,7,6,8,12,10,12,12,11,10,11,11,13,14,18,16,13,14,17,14,11,11,16,22,16,17,19,20,21,21,21,12,15,23,24,22,20,24,18,20,21,20,3,4,4,5,4,5,9,5,5,9,20,13,11,13,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,13,9,10,11,10,8,13,11,10,11,14,14,13,15,19,32,21,19,18,18,19,39,28,30,23,32,46,41,49,48,46,41,45,44,51,58,74,62,51,54,70,55,44,45,64,87,65,70,76,78,82,83,82,50,62,90,97,90,80,96,74,81,82,79,14,14,14,19,17,19,38,21,21,38,79,53,45,53,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,32,22,24,28,24,20,32,28,26,28,36,34,32,38,48,80,52,48,44,44,48,98,70,74,58,80,116,102,122,120,114,102,112,110,128,144,184,156,128,136,174,138,110,112,160,218,162,174,190,196,206,208,206,124,154,226,242,224,200,240,184,202,206,198,34,36,36,48,42,48,94,52,52,94,198,132,112,132,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,2,1,1,1,1,1,2,1,1,1,2,2,2,2,2,4,3,2,2,2,2,5,4,4,3,4,6,5,6,6,6,5,6,6,6,7,9,8,6,7,9,7,6,6,8,11,8,9,10,10,10,10,10,6,8,11,12,11,10,12,9,10,10,10,2,2,2,2,2,2,5,3,3,5,10,7,6,7,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,2,2,2,2,2,1,2,2,2,2,3,2,2,3,3,6,4,3,3,3,3,7,5,5,4,6,8,7,9,8,8,7,8,8,9,10,13,11,9,10,12,10,8,8,11,15,11,12,13,14,14,15,14,9,11,16,17,16,14,17,13,14,14,14,2,3,3,3,3,3,7,4,4,7,14,9,8,9,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,20,14,15,18,15,13,20,18,16,18,23,21,20,24,30,50,33,30,28,28,30,61,44,46,36,50,73,64,76,75,71,64,70,69,80,90,115,98,80,85,109,86,69,70,100,136,101,109,119,123,129,130,129,78,96,141,151,140,125,150,115,126,129,124,21,23,23,30,26,30,59,33,33,59,124,83,70,83,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,255,218,0,12,3,1,0,2,17,3,17,0,63,0,0,0,255,192,0,17,8,0,240,1,64,3,1,34,0,2,17,1,3,17,1,0,0,0,0,0,255,219,0,132,0,5,3,4,4,4,3,5,4,4,4,6,5,5,6,8,13,8,8,7,7,8,16,12,12,10,13,20,17,21,20,19,17,19,19,22,24,31,26,22,23,30,23,19,19,27,37,28,30,32,33,35,35,35,21,26,39,41,38,34,41,31,34,35,34,1,5,6,6,8,7,8,16,8,8,16,34,22,19,22,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,0,0,255,196,1,162,0,0,1,5,1,1,1,1,1,1,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,1,0,3,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,16,0,2,1,3,3,2,4,3,5,5,4,4,0,0,1,125,1,2,3,0,4,17,5,18,33,49,65,6,19,81,97,7,34,113,20,50,129,145,161,8,35,66,177,193,21,82,209,240,36,51,98,114,130,9,10,22,23,24,25,26,37,38,39,40,41,42,52,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,225,226,227,228,229,230,231,232,233,234,241,242,243,244,245,246,247,248,249,250,17,0,2,1,2,4,4,3,4,7,5,4,4,0,1,2,119,0,1,2,3,17,4,5,33,49,6,18,65,81,7,97,113,19,34,50,129,8,20,66,145,161,177,193,9,35,51,82,240,21,98,114,209,10,22,36,52,225,37,241,23,24,25,26,38,39,40,41,42,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,130,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,226,227,228,229,230,231,232,233,234,242,243,244,245,246,247,248,249,250,0,0,0,0,0,1,2,3,6,10,15,21,235,241,246,250,253,254,255,0,0,1,2,3,6,10,15,21,0,255,254,253,250,246,241,235,0,0,8,0,16,0,32,0,48,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,176,0,192,0,208,0,224,0,240,0,0,1,16,1,32,1,48,1,64,1,80,1,96,1,112,1,128,1,144,1,160,1,176,1,192,1,208,1,224,1,240,1,0,2,8,2,16,2,24,2,32,2,40,2,48,2,56,2,64,2,72,2,80,2,88,2,96,2,104,2,112,2,120,2,128,2,136,2,144,2,152,2,160,2,168,2,176,2,184,2,192,2,200,2,208,2,216,2,224,2,232,2,240,2,248,2,0,3,8,3,16,3,24,3,32,3,40,3,48,3,56,3,64,3,72,3,80,3,88,3,96,3,104,3,112,3,120,3,128,3,136,3,144,3,152,3,160,3,168,3,176,3,184,3,192,3,200,3,208,3,216,3,224,3,232,3,240,3,248,3,0,4,64,4,128,4,192,4,0,5,64,5,128,5,192,5,0,6,64,6,128,6,192,6,0,7,64,7,128,7,192,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,20,0,24,0,28,0,32,0,48,0,64,48,110,34,0,108,0,0,0,144,115,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,50,29,0,108,0,0,0,0,0,0,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,27,35,0,108,0,0,0,0,91,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,33,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,208,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,35,0,108,0,0,0,0,91,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,1,3,2,1,1,0,0,0,0,4,8,12,16,20,24,28,32,36,40,44,48,52,56,60,65,69,73,77,81,85,89,93,97,101,105,109,113,117,121,125,130,134,138,142,146,150,154,158,162,166,170,174,178,182,186,190,195,199,203,207,211,215,219,223,227,231,235,239,243,247,251,255,0,0,0,0,3,1,1,1,2,2,2,3,3,3,4,4,0,1,2,3,0,1,2,3,1,2,3,1,2,3,2,3,0,0,0,0,3,1,1,1,2,2,2,3,3,3,4,4,0,1,2,3,0,1,2,3,1,2,3,1,2,3,2,3,128,2,0,0,224,1,0,0,208,2,0,0,224,1,0,0,208,2,0,0,64,2,0,0,96,1,0,0,32,1,0,0,96,1,0,0,240,0,0,0,160,0,0,0,128,0,0,0,0,2,0,0,128,1,0,0,128,2,0,0,96,1,0,0,128,2,0,0,240,0,0,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,8,0,0,0,255,3,1,1,3,0,0,0,2,0,0,0,2,0,0,0,0,63,1,22,2,44,3,90,5,81,7,31,8,86,9,58,10,36,12,68,13,39,14,73,15,53,16,69,17,57,19,88,20,34,21,71,24,46,25,94,26,54,28,75,29,50,32,70,33,92,35,74,38,85,40,56,42,87,43,65,45,59,48,79,49,93,51,89,55,95,61,76,67,83,77,80,0,0,0,0,32,25,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,5,0,0,60,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,32,0,176,137,31,0,8,0,0,0,3,0,0,0,0,0,0,0,0,128,123,64,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,144,211,30,0,176,137,31,0,8,0,0,0,3,0,0,0,0,0,0,0,0,128,123,64,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,200,43,30,0,112,185,29,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,160,86,29,0,112,185,29,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,208,2,29,0,48,180,28,0,28,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,72,177,35,0,48,180,28,0,28,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,208,81,35,0,184,1,35,0,32,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,8,193,34,0,184,1,35,0,32,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,240,131,34,0,208,74,34,0,24,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,31,29,0,108,0,0,0,40,168,6,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,221,95,63,77,78,65,63,218,115,233,62,22,81,243,61,192,237,233,189,75,5,53,190,1,189,208,189,3,210,126,60,191,67,177,61,167,35,160,61,219,220,152,60,59,167,25,189,143,254,87,189,178,241,224,188,161,76,35,60,145,9,248,60,129,4,197,60,101,54,72,59,113,29,99,188,44,102,132,188,100,93,220,187,209,4,138,59,159,117,13,60,58,119,187,59,0,0,0,128,121,35,115,187,237,211,113,187,216,244,160,186,50,174,184,58,137,12,43,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,4,9,1,12,5,13,16,24,20,25,17,28,21,29,32,40,36,41,33,44,37,45,18,26,22,27,19,30,23,31,2,10,6,11,3,14,7,15,48,56,52,57,49,60,53,61,34,42,38,43,35,46,39,47,50,58,54,59,51,62,55,63,152,25,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,227,32,0,248,212,31,0,8,0,0,0,3,0,0,0,252,169,241,210,77,98,80,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,48,13,31,0,248,212,31,0,8,0,0,0,3,0,0,0,252,169,241,210,77,98,80,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,40,94,30,0,64,218,29,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,24,245,64,8,0,1,0,0,0,0,0,168,111,29,0,64,218,29,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,24,245,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,25,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,0,0,0,0,0,0,0,0,0,0,0,242,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,9,31,0,108,0,0,0,144,171,6,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,5,2,3,4,5,6,6,8,8,7,7,8,8,73,110,116,101,114,112,108,97,121,32,77,86,69,32,70,105,108,101,26,0,26,0,0,0,0,0,0,0,255,1,0,0,1,255,0,0,255,0,1,0,255,1,1,0,0,255,1,0,1,255,1,0,255,255,1,0,1,0,255,0,0,1,255,0,1,1,255,0,255,1,255,0,1,255,255,0,255,0,0,1,255,1,0,1,0,255,0,1,0,0,0,0,1,255,0,1,255,255,0,1,255,0,1,1,255,1,1,1,0,255,1,1,1,255,1,1,255,255,1,1,0,0,255,1,1,0,255,1,255,0,255,1,0,1,255,1,1,1,255,1,255,1,255,1,0,255,255,1,1,255,255,1,0,0,0,0,255,255,255,1,1,0,0,255,0,1,0,255,1,1,0,255,255,1,0,255,1,255,0,255,0,0,1,255,1,0,1,255,255,0,1,255,0,1,1,255,1,1,1,255,255,1,1,255,0,255,1,255,1,255,1,255,255,255,1,255,0,0,0,0,1,0,255,255,0,1,255,255,1,1,255,255,255,1,255,255,1,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,1,0,0,0,0,0,0,18,0,9,0,0,0,3,0,6,0,0,15,0,0,0,12,0,0,0,0,24,21,0,0,0,0,0,0,238,0,254,255,0,241,0,2,0,0,3,0,253,247,0,244,0,0,0,0,250,0,0,0,232,235,0,0,56,224,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,1,0,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,96,32,0,120,115,31,0,4,0,0,0,69,90,73,83,104,189,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,232,30,30,0,120,115,31,0,4,0,0,0,69,90,73,83,104,189,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,248,173,29,0,136,77,29,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,248,173,29,0,48,251,28,0,216,171,28,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,173,29,0,208,169,35,0,56,72,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,173,29,0,136,249,34,0,24,246,34,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,184,34,0,104,122,34,0,12,0,0,0,84,65,82,86,88,65,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,17,34,0,104,122,34,0,12,0,0,0,84,65,82,86,88,65,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,224,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,180,28,0,108,0,0,0,8,175,6,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,101,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,5,0,0,254,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,104,32,0,64,121,31,0,4,0,0,0,69,90,73,83,248,196,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,24,34,30,0,64,121,31,0,4,0,0,0,69,90,73,83,248,196,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,48,178,29,0,88,80,29,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,16,253,28,0,24,174,28,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,16,253,28,0,152,171,35,0,56,76,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,16,253,28,0,24,253,34,0,48,189,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,16,253,28,0,184,127,34,0,16,71,34,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,184,127,34,0,152,21,34,0,184,226,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,184,127,34,0,152,190,33,0,40,155,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,184,127,34,0,120,127,33,0,0,66,33,0,40,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,120,127,33,0,88,16,33,0,24,246,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,127,33,0,88,219,32,0,240,191,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,127,33,0,88,168,32,0,224,142,32,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,127,33,0,8,119,32,0,200,95,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,127,33,0,24,76,32,0,16,24,32,0,44,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,36,192,0,0,0,0,0,0,36,64,16,0,1,0,0,0,0,0,120,246,31,0,112,225,31,0,76,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,120,246,31,0,184,206,31,0,216,185,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,246,31,0,208,166,31,0,128,148,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,246,31,0,152,130,31,0,208,114,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,246,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,101,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,212,28,0,108,0,0,0,216,177,6,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,223,255,255,255,255,255,255,255,255,253,207,255,255,255,255,221,252,205,255,255,255,204,203,188,223,255,253,219,201,105,188,255,252,255,185,66,90,205,255,253,220,98,3,155,207,255,253,201,83,74,204,255,255,255,186,154,188,255,255,252,220,188,188,255,255,255,254,204,205,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,240,0,0,0,255,255,223,253,255,255,255,255,255,253,205,255,255,255,252,252,204,207,223,255,255,219,169,155,207,223,255,203,151,103,155,255,255,220,167,66,71,173,255,255,201,99,3,105,191,255,252,167,83,71,172,223,253,220,151,119,140,189,255,255,204,170,171,207,255,255,255,204,204,207,255,255,255,254,255,239,255,255,255,253,255,220,255,223,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,185,175,255,255,255,255,150,86,159,255,255,255,166,67,71,239,255,255,249,83,3,106,255,255,255,166,67,70,175,255,255,255,150,86,159,255,255,255,255,201,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,239,255,255,255,255,255,255,255,255,253,221,255,255,253,255,253,253,255,255,255,255,221,219,188,223,255,255,255,250,67,107,255,223,255,253,163,2,173,255,255,253,251,82,58,223,255,255,255,203,170,206,255,223,255,254,221,223,255,255,255,255,237,253,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,240,0,0,0,255,207,204,255,255,255,255,255,191,255,204,202,255,207,251,170,170,207,203,252,255,170,169,153,172,191,252,169,152,136,153,170,207,202,168,83,88,159,204,204,185,115,2,104,172,207,202,152,83,55,155,172,251,170,151,120,138,251,255,250,187,153,154,171,255,255,235,186,170,172,203,255,191,188,188,207,255,255,207,252,252,255,255,207,160,0,0,0,175,255,255,255,255,255,255,255,254,253,252,255,255,255,252,171,186,252,255,255,255,169,119,120,175,255,255,168,101,69,104,255,252], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+430097);
/* memory initializer */ allocate([251,116,51,53,123,255,255,183,67,35,70,175,255,203,117,51,53,122,204,255,248,101,69,104,172,207,204,168,119,120,191,255,255,255,185,153,252,255,255,255,255,254,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,218,252,255,255,252,251,154,153,186,255,255,251,151,119,119,156,207,252,152,101,69,104,175,255,201,117,51,53,121,255,251,134,67,35,71,159,255,201,117,51,53,123,191,255,168,101,69,104,175,255,250,168,119,120,155,255,255,255,251,153,187,255,255,255,254,206,255,207,255,255,255,255,255,255,255,240,0,0,0,255,255,253,222,255,255,255,255,220,187,188,239,255,255,219,153,137,172,223,255,219,151,102,103,156,255,236,151,101,69,103,172,255,185,101,51,53,105,191,251,134,67,51,70,155,238,185,101,51,53,105,190,253,167,101,69,103,172,223,219,151,102,103,155,223,255,220,169,137,155,207,255,255,220,187,188,222,255,255,255,255,239,239,255,240,0,0,0,255,255,255,255,252,255,255,255,255,251,187,255,255,255,255,170,153,171,255,255,250,152,118,103,172,207,250,167,100,69,103,155,255,248,116,51,52,104,175,251,150,67,51,70,139,255,249,117,67,53,105,191,204,152,101,69,103,154,191,255,152,102,104,143,255,255,255,152,136,175,255,255,255,255,186,186,190,255,255,255,223,255,255,255,192,0,0,0,255,255,255,255,255,255,255,255,255,255,250,255,255,170,255,249,175,255,255,255,255,250,136,127,175,250,255,248,117,85,121,255,255,249,117,50,52,138,255,255,184,67,34,88,255,255,207,149,51,70,122,255,250,255,117,70,121,250,255,175,249,137,138,254,255,255,255,255,175,170,255,255,255,255,250,255,255,255,175,255,255,250,255,250,144,0,0,0,188,186,170,153,170,189,187,186,153,136,137,155,204,186,152,119,119,120,154,186,152,118,101,102,120,171,168,118,85,69,86,121,169,135,85,68,68,103,138,152,117,68,68,69,104,154,135,101,68,69,103,138,169,118,85,69,86,121,171,152,118,85,86,120,154,186,152,119,119,120,154,205,203,169,136,137,170,187,221,202,169,154,171,204,176,0,0,0,189,202,170,170,171,206,220,203,169,136,137,155,205,187,152,135,119,120,171,218,168,118,101,102,120,172,169,118,85,68,86,121,170,151,101,68,68,103,154,168,117,68,52,69,121,154,135,101,68,69,103,154,185,118,85,69,86,121,171,168,118,101,102,120,187,203,168,119,119,120,171,189,203,169,152,153,170,205,253,251,170,171,171,204,192,0,0,0,205,203,170,170,171,206,237,203,169,136,137,171,206,203,152,119,119,120,155,203,168,118,101,86,120,171,169,118,85,69,86,121,186,135,85,68,69,87,138,168,117,68,52,69,120,170,135,101,68,69,103,138,169,118,85,69,86,121,171,168,118,101,102,120,171,203,152,119,119,120,155,205,203,169,136,137,171,205,237,203,170,170,171,205,192,0,0,0,205,203,185,170,187,255,221,203,169,137,137,155,239,187,168,119,119,120,155,252,168,118,85,86,120,171,185,118,85,69,86,121,187,151,101,68,68,87,138,168,117,68,68,69,104,170,135,101,68,69,87,154,185,118,85,69,86,121,187,152,118,85,102,120,171,251,168,119,119,120,171,189,251,169,136,137,172,204,188,203,186,170,170,187,160,0,0,0,172,171,169,170,171,204,220,186,152,136,136,154,189,186,152,119,119,120,155,202,168,118,101,86,120,171,169,118,85,69,86,121,186,135,85,68,69,87,137,152,117,68,68,69,104,154,135,85,68,69,87,137,168,118,85,85,86,121,171,168,118,85,86,120,154,203,168,119,119,120,155,220,203,169,136,137,154,189,203,203,169,169,170,187,176,0,0,0,175,255,191,255,255,255,255,191,255,255,255,255,255,251,191,255,255,255,255,255,255,255,169,175,255,255,255,251,150,86,159,255,255,255,166,50,54,175,255,255,249,99,18,106,255,255,255,150,51,54,191,255,255,255,150,86,154,255,255,255,255,218,154,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,247,86,252,207,255,255,246,50,57,255,255,255,248,98,18,111,255,255,255,246,67,55,255,255,255,255,166,88,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,234,255,255,255,255,255,150,86,159,255,255,255,182,67,54,255,255,255,251,98,18,91,255,255,255,214,66,54,255,255,255,255,150,86,159,255,255,255,255,250,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,143,255,255,255,255,249,67,95,255,255,255,255,163,17,223,255,255,255,255,97,62,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,138,255,255,255,255,248,83,94,255,255,255,255,147,17,143,255,255,255,254,81,57,255,255,255,255,255,136,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,172,187,170,170,172,222,203,186,169,152,153,171,222,186,152,119,119,120,171,234,168,118,101,102,121,172,169,134,84,68,86,121,170,135,101,68,69,87,154,169,117,68,52,69,120,154,135,101,68,69,103,154,185,134,85,69,86,137,172,168,118,101,102,120,154,204,168,135,119,137,155,191,219,169,152,153,155,188,223,203,170,185,171,187,160,0,0,0,188,203,170,154,171,206,205,203,153,136,137,155,205,202,152,119,103,120,155,203,168,118,101,86,120,171,169,118,85,69,86,121,170,135,101,68,69,87,138,152,101,68,68,69,120,170,135,85,68,69,87,138,169,118,85,69,86,121,171,168,118,85,102,120,155,203,168,119,103,120,155,205,219,169,136,137,155,205,220,219,170,169,171,190,176,0,0,0,188,187,170,170,171,205,220,203,153,136,137,171,205,187,152,119,119,120,155,203,168,118,85,86,120,171,169,118,85,68,86,121,170,135,101,68,69,87,138,168,117,68,68,69,104,170,135,85,68,69,103,137,169,118,85,69,86,121,171,168,118,101,102,120,170,203,152,119,119,120,154,189,203,169,136,137,171,187,221,203,170,154,170,187,176,0,0,0,223,236,186,170,189,239,221,203,169,153,154,189,207,219,152,119,119,136,172,222,169,118,85,102,121,159,185,134,85,69,86,137,187,151,101,68,69,103,155,184,117,68,52,69,121,170,151,100,68,69,87,155,201,134,85,68,86,121,188,168,118,85,102,121,191,252,168,135,119,120,170,255,252,170,153,153,172,207,255,203,186,171,188,190,176,0,0,0,188,187,187,155,187,254,205,204,169,153,153,172,237,204,168,135,119,136,171,203,168,118,86,102,121,188,169,134,85,68,86,121,202,151,101,68,68,103,138,169,117,68,52,69,121,187,151,100,68,69,103,154,185,134,84,69,86,137,188,169,118,102,102,121,172,252,168,135,119,121,155,222,220,169,153,154,171,189,189,219,186,170,187,205,176,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,247,127,252,175,255,255,246,50,111,255,255,255,255,98,3,255,255,255,255,255,99,95,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,191,191,255,255,255,255,255,191,255,255,255,255,255,255,204,207,191,255,255,255,255,186,153,187,255,255,252,187,134,86,155,255,255,251,167,66,54,175,255,255,249,98,19,89,255,255,255,166,50,71,175,239,255,255,150,87,154,204,255,255,251,170,170,239,255,255,255,255,251,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,153,155,255,255,255,250,134,86,139,255,255,255,166,66,54,175,255,255,249,82,19,88,255,255,255,165,51,54,159,255,255,254,134,86,139,255,255,255,254,168,154,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,119,127,255,255,255,255,117,69,104,207,255,255,181,67,53,143,255,255,248,67,35,87,207,255,255,165,50,52,143,255,255,255,100,68,111,255,255,255,255,135,152,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,237,175,255,255,255,243,63,255,255,255,255,244,2,255,255,255,255,255,82,55,255,255,255,255,249,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,143,255,255,240,0,0,0,143,248,255,255,255,255,254,239,255,255,255,255,255,136,238,239,255,255,255,255,143,248,103,135,255,255,255,248,118,84,119,239,255,255,132,51,53,127,255,248,134,83,35,87,255,255,255,101,51,53,120,255,255,248,85,68,88,238,238,254,254,103,136,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,252,204,252,255,255,255,188,169,169,207,255,252,186,152,119,137,191,255,185,135,102,103,138,207,186,135,101,68,103,159,251,168,101,67,69,105,207,234,118,67,51,70,143,252,168,101,67,52,104,175,249,151,100,68,87,175,255,250,151,102,103,156,255,255,251,169,153,155,255,255,255,255,203,204,239,255,255,255,255,255,255,255,240,0,0,0,255,253,223,255,255,255,255,237,220,205,207,255,255,204,203,169,154,188,255,253,219,168,118,120,173,255,220,168,101,69,104,191,254,202,117,51,53,122,207,252,166,67,35,71,156,255,201,117,51,53,121,206,253,184,101,69,104,172,223,252,168,118,120,171,223,255,253,186,153,171,207,255,255,253,221,205,223,223,255,255,255,253,255,255,208,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,157,255,175,255,255,255,175,119,138,255,255,255,249,117,69,104,255,255,255,132,51,53,154,255,255,246,67,35,71,255,255,255,117,51,53,122,255,255,248,100,69,105,255,255,255,151,134,120,159,255,255,175,255,175,255,255,255,255,255,223,255,252,255,255,255,255,255,255,175,240,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,238,221,221,221,93,221,77,221,221,214,221,213,221,221,93,221,109,221,221,213,221,221,214,221,221,109,221,221,221,221,221,221,214,221,221,214,213,221,93,109,85,221,13,85,101,221,93,221,102,221,221,221,221,213,213,93,93,214,221,221,221,221,214,213,109,109,109,212,109,221,221,221,221,221,221,221,221,221,221,221,85,214,221,222,224,0,0,0,155,155,169,155,172,204,250,186,187,169,170,191,255,170,170,152,136,136,173,249,153,136,118,102,121,170,153,152,117,84,86,143,250,169,117,67,52,104,171,186,134,83,51,86,138,188,184,100,51,69,121,172,203,134,84,85,103,138,172,202,118,103,120,137,187,255,185,120,136,154,187,159,253,249,171,154,171,170,255,252,250,171,153,170,128,0,0,0,204,188,187,188,187,187,187,188,203,187,187,187,187,187,187,188,203,187,187,187,187,187,180,187,187,187,187,180,68,180,43,188,204,203,187,51,75,187,187,187,180,187,68,59,187,187,187,187,179,180,187,187,187,187,180,68,59,187,187,187,180,179,187,188,204,204,204,203,180,187,187,187,187,187,187,204,204,204,204,204,204,203,204,204,192,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,0,0,0,160,255,35,3,64,0,0,0,224,240,122,11,192,0,0,0,192,163,123,9,64,0,0,0,160,213,252,252,191,0,0,0,32,124,194,201,191,0,0,0,128,168,157,247,63,0,0,0,32,150,137,251,191,0,0,0,224,104,71,239,63,0,0,0,160,192,166,193,191,0,0,0,224,96,112,216,191,0,0,0,64,178,140,209,63,0,0,0,192,169,11,177,63,0,0,0,96,252,138,214,191,0,0,0,160,60,28,216,63,0,0,0,64,157,172,206,191,0,0,0,96,172,148,177,63,0,0,0,64,201,170,0,64,0,0,0,224,178,85,8,192,0,0,0,224,104,163,9,64,0,0,0,0,187,14,6,192,0,0,0,64,63,247,247,63,0,0,0,96,197,239,213,191,0,0,0,192,109,244,230,191,0,0,0,32,230,45,241,63,0,0,0,128,126,92,240,191,0,0,0,128,196,32,226,63,0,0,0,96,5,215,202,191,0,0,0,192,165,188,176,191,0,0,0,192,233,108,186,63,0,0,0,96,225,67,177,191,0,0,0,64,133,72,116,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,4,0,0,0,4,0,0,0,0,0,0,96,1,250,6,64,0,0,0,160,80,42,20,192,0,0,0,160,41,250,24,64,0,0,0,160,194,100,23,192,0,0,0,192,110,167,13,64,0,0,0,0,205,202,240,191,0,0,0,64,170,237,242,191,0,0,0,96,196,230,0,64,0,0,0,192,30,141,254,191,0,0,0,64,225,248,239,63,0,0,0,192,80,224,197,191,0,0,0,128,189,223,212,191,0,0,0,96,172,10,217,63,0,0,0,128,112,51,209,191,0,0,0,32,77,1,185,63,0,0,0,32,135,9,152,191,0,0,0,160,38,107,5,64,0,0,0,128,213,82,19,192,0,0,0,0,203,71,26,64,0,0,0,160,44,212,29,192,0,0,0,96,194,231,26,64,0,0,0,96,133,100,19,192,0,0,0,96,101,84,0,64,0,0,0,0,156,107,230,63,0,0,0,32,75,161,7,192,0,0,0,160,245,81,16,64,0,0,0,64,243,188,16,192,0,0,0,96,66,166,10,64,0,0,0,32,166,241,0,192,0,0,0,0,64,35,236,63,0,0,0,32,188,66,160,191,0,0,0,0,255,31,219,191,0,0,0,0,1,165,222,63,0,0,0,160,208,182,214,191,0,0,0,64,93,101,198,63,0,0,0,0,91,47,175,191,0,0,0,0,57,35,250,63,0,0,0,32,167,23,2,192,0,0,0,192,249,66,3,64,0,0,0,160,200,18,5,192,0,0,0,128,252,38,1,64,0,0,0,32,147,11,253,191,0,0,0,96,83,78,241,63,0,0,0,128,49,127,230,191,0,0,0,160,65,120,196,63,0,0,0,128,250,69,165,63,0,0,0,160,156,211,210,191,0,0,0,160,2,30,208,63,0,0,0,128,66,197,209,191,0,0,0,160,143,52,196,63,0,0,0,0,82,6,186,191,0,0,0,96,231,60,145,63,0,0,0,224,38,71,234,63,0,0,0,160,22,26,240,191,0,0,0,192,13,243,227,63,0,0,0,0,43,183,240,191,0,0,0,224,128,166,228,63,0,0,0,128,110,9,236,191,0,0,0,160,215,181,224,63,0,0,0,0,55,148,229,191,0,0,0,192,80,197,220,63,0,0,0,160,130,209,224,191,0,0,0,160,129,31,214,63,0,0,0,224,11,91,217,191,0,0,0,224,143,37,209,63,0,0,0,224,227,132,210,191,0,0,0,224,184,28,200,63,0,0,0,96,206,113,200,191,0,0,0,192,75,180,186,63,0,0,0,32,255,56,187,191,0,0,0,128,100,250,167,63,0,0,0,96,112,77,164,191,0,0,0,32,49,248,172,63,0,0,0,224,232,57,226,191,0,0,0,0,213,16,218,191,0,0,0,224,78,173,213,191,0,0,0,64,41,20,211,191,0,0,0,160,192,94,200,191,0,0,0,0,1,34,197,191,0,0,0,32,63,61,193,191,0,0,0,160,253,188,184,191,0,0,0,192,162,191,180,191,0,0,0,128,195,160,176,191,0,0,0,224,15,226,171,191,0,0,0,224,187,53,166,191,0,0,0,0,65,189,162,191,0,0,0,32,27,227,154,191,0,0,0,0,177,60,147,191,0,0,0,32,6,107,139,191,0,0,0,64,36,162,130,191,0,0,0,32,120,199,101,191,0,0,0,0,104,148,59,191,0,0,0,192,57,215,215,191,0,0,0,32,56,14,234,191,0,0,0,96,127,154,225,191,0,0,0,0,246,86,222,191,0,0,0,96,59,225,212,191,0,0,0,0,61,60,212,191,0,0,0,224,247,67,205,191,0,0,0,96,80,85,205,191,0,0,0,224,66,11,201,191,0,0,0,0,180,62,199,191,0,0,0,192,219,189,195,191,0,0,0,160,193,13,194,191,0,0,0,224,67,82,190,191,0,0,0,160,52,251,184,191,0,0,0,160,21,149,179,191,0,0,0,128,116,111,177,191,0,0,0,32,131,113,165,191,0,0,0,0,127,231,162,191,0,0,0,192,42,212,147,191,0,0,0,0,94,181,142,191,0,0,0,128,65,165,237,191,0,0,0,224,44,149,239,191,0,0,0,192,110,50,228,191,0,0,0,160,33,161,224,191,0,0,0,32,209,110,217,191,0,0,0,96,178,213,214,191,0,0,0,160,113,5,211,191,0,0,0,96,181,214,208,191,0,0,0,160,255,204,203,191,0,0,0,224,85,194,199,191,0,0,0,64,220,183,195,191,0,0,0,64,110,61,192,191,0,0,0,128,65,120,186,191,0,0,0,64,158,108,181,191,0,0,0,224,95,21,174,191,0,0,0,128,114,2,168,191,0,0,0,160,43,159,156,191,0,0,0,192,6,61,149,191,0,0,0,0,184,46,131,191,0,0,0,96,188,174,120,191,0,0,0,160,237,62,243,191,0,0,0,0,237,28,238,191,0,0,0,128,156,184,229,191,0,0,0,128,176,114,226,191,0,0,0,224,93,0,224,191,0,0,0,96,50,98,220,191,0,0,0,64,175,54,216,191,0,0,0,32,68,199,213,191,0,0,0,96,10,211,210,191,0,0,0,0,89,254,207,191,0,0,0,160,196,203,203,191,0,0,0,160,204,13,200,191,0,0,0,224,30,139,195,191,0,0,0,64,38,17,191,191,0,0,0,0,21,128,185,191,0,0,0,160,33,69,179,191,0,0,0,192,172,250,168,191,0,0,0,192,223,205,165,191,0,0,0,160,228,175,157,191,0,0,0,0,215,78,136,191,0,0,0,0,21,53,8,64,0,0,0,64,132,27,24,192,0,0,0,128,215,99,34,64,0,0,0,32,93,166,39,192,0,0,0,224,198,136,41,64,0,0,0,32,253,213,39,192,0,0,0,160,11,89,34,64,0,0,0,64,36,124,21,192,0,0,0,32,212,58,242,63,0,0,0,160,123,150,3,64,0,0,0,192,79,227,19,192,0,0,0,32,36,40,24,64,0,0,0,64,106,190,23,192,0,0,0,0,245,156,19,64,0,0,0,64,5,108,12,192,0,0,0,32,27,135,1,64,0,0,0,192,2,173,242,191,0,0,0,192,146,98,223,63,0,0,0,128,52,37,197,191,0,0,0,32,108,198,151,63,79,10,38,2,87,25,252,10,246,3,134,7,143,11,245,2,84,250,145,255,211,255,103,254,145,1,33,2,9,6,115,249,75,0,161,253,182,241,144,254,122,238,16,1,129,23,44,254,84,4,32,4,94,2,40,243,235,3,194,252,176,254,132,244,247,0,227,0,164,6,82,1,95,255,62,22,61,1,184,253,134,24,170,244,234,240,37,1,184,242,28,2,177,0,184,252,41,254,195,3,13,255,223,254,77,0,39,0,202,29,77,1,65,2,71,1,153,254,231,3,120,254,107,0,130,5,253,1,41,252,36,0,63,255,188,255,68,226,249,252,78,255,135,5,45,4,254,5,4,251,180,4,103,2,17,8,243,1,124,0,9,1,58,254,182,7,28,25,68,240,78,4,118,250,171,255,208,252,192,255,210,255,158,3,64,252,78,0,215,18,215,255,182,255,86,253,7,253,58,230,12,12,195,249,129,11,163,252,125,243,99,253,123,241,202,254,207,244,89,250,72,0,195,7,108,1,55,19,9,255,94,14,60,255,105,229,129,255,59,252,233,0,123,255,160,15,180,255,74,255,241,14,67,0,188,2,114,248,33,2,93,246,95,250,117,2,81,13,0,2,251,242,27,2,224,236,85,13,221,247,42,2,62,2,214,36,40,1,168,255,235,253,191,254,198,251,59,9,42,0,206,255,230,234,133,255,106,17,106,4,177,10,122,1,229,5,61,243,202,3,179,0,190,247,90,2,223,1,74,254,21,1,83,219,120,4,149,9,135,241,254,240,125,15,226,1,206,4,163,8,231,254,215,248,51,249,117,6,156,252,229,1,100,241,251,20,221,3,158,4,10,0,236,248,233,0,4,4,28,243,90,18,36,6,44,6,160,3,198,254,132,242,62,3,25,250,201,251,42,2,129,2,103,5,105,0,179,251,13,6,152,240,134,3,99,230,237,1,211,243,14,3,69,253,58,237,142,3,253,254,228,255,177,6,156,228,58,2,10,251,166,237,248,255,220,0,57,239,111,4,191,240,177,3,45,254,140,247,117,253,181,0,212,0,159,0,75,2,51,6,77,4,15,228,203,254,66,250,145,251,247,254,186,254,172,0,136,34,214,2,244,252,170,0,242,251,210,1,216,0,252,2,231,0,221,253,152,9,92,254,196,31,230,1,98,3,153,254,23,13,219,248,226,7,160,254,183,250,199,2,133,2,125,4,74,0,46,254,99,253,241,3,14,12,240,0,44,29,74,255,155,7,35,255,240,1,64,254,189,0,143,255,16,253,133,0,42,255,226,250,112,255,246,251,115,20,109,248,152,245,192,0,246,5,240,246,250,2,246,252,101,1,227,4,168,1,31,255,16,252,27,255,160,254,25,242,241,254,211,251,250,4,81,255,112,1,53,25,7,254,31,0,254,29,165,0,94,254,144,255,119,253,141,5,155,2,178,254,17,4,159,254,73,2,13,16,71,4,163,20,173,2,81,253,77,250,30,4,184,19,62,255,172,8,81,0,244,0,205,14,12,0,101,252,77,250,63,1,74,9,203,255,1,16,106,253,124,251,223,0,29,10,221,253,87,19,166,254,236,248,145,255,88,1,127,20,131,1,53,254,214,252,254,3,234,0,214,2,48,7,223,253,136,252,216,2,106,0,3,4,15,254,93,1,8,255,165,43,201,254,126,0,223,1,12,248,9,1,250,250,228,227,1,254,128,0,215,248,240,1,196,29,235,9,239,248,194,3,154,253,148,252,89,3,130,8,130,2,100,251,10,247,143,3,92,15,199,2,207,251,155,250,59,235,237,0,98,254,67,2,178,255,229,255,178,255,242,255,100,0,65,255,142,0,255,255,174,1,74,255,207,0,195,255,184,255,254,236,71,2,235,19,64,253,40,250,41,4,50,255,67,9,216,5,241,6,204,254,194,18,121,250,154,4,90,10,56,1,174,254,6,255,192,255,229,255,165,243,207,253,253,250,184,3,122,252,98,1,61,6,182,255,83,253,62,243,151,252,24,253,167,27,220,2,185,2,38,2,174,250,251,0,34,0,26,253,0,0,105,0,160,253,255,255,219,40,86,3,153,255,93,254,238,8,31,244,50,243,205,255,21,254,69,255,108,16,89,3,195,251,59,246,145,249,84,26,93,2,225,247,212,6,7,2,134,13,106,0,69,253,220,0,153,253,106,254,164,1,18,3,60,2,167,2,218,0,136,252,43,40,129,0,18,247,63,253,178,255,208,19,122,2,190,2,85,231,217,253,205,254,246,224,177,0,151,248,189,253,84,6,125,0,116,0,167,255,204,254,6,252,142,0,6,254,144,253,149,3,245,252,120,2,17,236,58,1,101,255,55,22,77,0,112,255,141,11,80,255,30,0,67,5,86,254,205,255,149,30,177,4,176,253,1,0,9,18,156,234,168,8,158,1,1,5,175,255,89,254,190,254,39,14,191,1,95,3,137,254,23,254,14,2,27,254,159,0,66,4,207,1,145,1,125,255,223,0,94,6,98,246,43,247,111,2,251,3,241,24,173,253,114,253,29,245,77,9,72,1,235,247,34,21,110,254,214,253,198,249,164,252,83,0,109,236,86,252,37,4,163,0,61,242,216,251,191,4,249,2,68,6,128,239,136,3,110,245,43,19,210,248,215,12,210,243,48,254,39,255,93,251,120,229,212,6,199,253,101,2,151,243,3,255,164,0,179,252,27,2,72,254,177,248,38,248,238,246,46,244,222,1,249,8,208,253,75,233,0,3,83,249,148,253,66,0,197,237,37,3,41,255,246,20,70,254,23,255,180,229,89,1,106,0,131,17,184,6,165,10,147,255,186,10,68,255,204,0,113,7,201,4,253,0,198,12,120,7,196,248,0,255,221,239,0,3,144,15,217,1,102,250,28,17,208,0,243,9,27,4,19,13,85,255,117,2,171,246,46,253,9,253,166,0,144,8,69,1,63,255,223,254,79,252,76,254,163,3,72,5,6,27,109,245,37,252,124,11,246,13,39,16,123,243,95,1,159,3,128,0,175,248,226,236,48,237,51,254,184,2,174,249,129,0,228,255,147,8,146,9,73,2,253,9,228,250,100,247,178,253,41,9,115,14,200,254,84,17,94,13,157,253,150,255,169,245,40,249,183,255,210,34,95,253,89,6,82,3,208,2,98,251,11,255,143,255,114,3,33,255,247,236,15,252,11,22,159,255,85,237,101,255,188,1,78,11,148,252,98,234,244,4,124,255,143,252,123,254,102,239,103,255,212,255,218,3,28,7,223,33,150,2,168,254,58,255,139,248,59,4,114,0,194,254,46,4,35,243,137,254,221,25,232,0,99,244,156,255,29,254,239,253,136,255,64,235,166,6,139,2,137,253,229,1,43,22,50,0,108,4,47,254,227,251,115,10,200,249,189,21,12,4,8,245,69,1,231,3,12,2,253,10,247,254,81,1,130,16,2,2,64,2,159,23,175,0,204,0,254,253,151,253,162,255,210,244,218,254,238,6,210,3,128,228,87,255,67,3,195,252,210,8,219,255,193,254,190,10,138,0,223,254,188,251,78,0,8,4,220,16,79,251,40,3,157,231,84,252,40,16,89,0,204,251,121,253,1,255,49,255,227,0,186,255,194,255,54,255,66,0,24,0,36,252,186,218,31,255,29,253,161,0,118,245,117,0,160,253,173,0,139,253,234,6,173,19,25,20,226,9,252,251,5,12,16,254,63,18,189,248,100,8,191,1,121,239,170,0,201,2,67,1,234,2,167,5,168,248,205,19,85,30,20,254,249,252,109,253,254,252,197,255,254,254,164,255,109,249,225,237,65,249,176,247,33,2,60,236,232,9,13,6,236,1,0,251,110,232,197,3,172,12,219,1,72,251,168,2,229,254,39,1,155,254,255,254,217,6,150,254,87,12,106,0,75,255,13,7,179,3,22,252,120,255,244,2,165,4,237,0,133,246,249,254,142,233,13,0,123,8,83,251,193,254,140,254,236,250,82,21,187,3,200,4,106,2,193,251,101,10,22,248,236,255,89,8,86,1,236,15,226,1,65,21,250,255,78,8,113,255,196,249,18,1,241,3,94,0,138,242,142,1,55,4,33,1,250,7,115,3,43,248,192,254,8,15,139,1,216,1,103,2,173,12,241,2,167,248,40,255,38,22,192,255,203,253,0,246,38,6,4,3,16,241,164,3,222,18,158,4,226,251,134,1,216,255,41,7,162,254,151,0,149,0,58,252,194,255,55,253,166,221,175,253,87,0,61,242,13,255,48,2,32,243,244,0,249,252,6,28,237,2,241,254,118,33,99,0,234,4,215,4,23,254,149,255,93,249,157,253,22,4,65,0,3,254,12,2,158,254,0,25,8,255,148,0,86,253,163,255,208,249,195,255,157,17,223,1,110,0,204,27,217,254,224,1,9,6,3,0,127,0,12,247,126,3,237,4,112,231,211,255,102,254,110,254,156,254,89,10,137,2,116,6,125,253,187,25,117,0,108,3,223,255,188,3,210,254,83,6,1,252,157,255,130,1,170,255,14,254,172,2,165,4,146,0,125,1,104,38,159,255,8,1,91,0,83,251,205,1,118,1,124,229,171,1,38,1,88,237,0,0,52,11,79,20,221,17,197,252,181,248,111,2,66,251,195,253,181,251,60,250,50,1,67,253,32,255,91,239,145,251,196,9,106,237,189,5,155,255,20,7,127,255,15,0,248,2,107,255,132,252,119,250,249,2,189,4,95,254,33,6,158,255,139,6,117,255,42,227,135,253,24,10,249,253,149,234,29,0,64,1,129,254,172,253,217,254,155,254,96,254,214,15,55,254,157,254,163,235,184,252,193,254,41,5,88,254,127,255,105,20,181,0,120,245,82,255,61,227,185,254,7,2,92,3,244,235,19,1,115,255,79,19,204,0,56,255,173,11,171,3,134,1,51,254,179,254,118,254,82,255,56,1,127,255,89,28,110,254,92,3,255,255,117,10,133,3,97,2,248,0,167,3,19,254,211,31,33,8,109,251,159,247,24,6,98,6,55,0,46,249,49,2,21,253,163,3,56,253,224,253,30,3,158,255,68,2,195,252,222,253,238,0,252,247,59,255,34,3,11,51,117,1,218,230,135,4,179,252,217,16,19,0,158,2,141,253,80,252,253,4,171,228,159,253,121,7,95,2,58,254,167,255,91,3,213,255,185,255,238,1,169,0,55,253,34,248,34,6,152,237,233,0,239,239,210,0,151,241,251,3,200,0,49,0,8,7,157,253,40,254,210,4,67,2,107,1,122,255,233,0,101,0,93,234,132,7,58,249,42,252,96,252,61,253,42,251,50,6,92,14,133,18,46,245,33,12,174,3,115,248,83,5,32,1,32,246,160,0,229,1,218,255,23,0,113,0,237,255,250,253,146,255,83,255,86,255,77,2,39,254,40,1,98,241,85,4,95,244,69,5,11,23,98,0,58,12,87,3,243,1,3,0,217,243,176,253,60,2,134,252,175,2,185,2,194,0,168,254,115,4,183,12,246,4,109,246,166,7,117,254,11,1,73,252,80,247,60,8,245,255,227,242,42,10,99,9,60,6,236,253,141,10,203,8,63,251,156,247,179,2,11,253,253,247,117,1,172,7,213,5,148,18,222,4,7,239,16,254,203,250,236,255,172,255,234,249,49,1,159,4,212,31,140,253,66,253,62,249,232,0,251,254,172,10,245,0,97,1,95,241,245,3,186,0,6,248,42,3,202,240,95,1,197,9,84,3,66,16,87,254,179,236,0,250,189,8,68,5,78,239,205,10,238,4,224,25,99,3,176,2,92,7,173,12,224,4,144,247,81,2,182,0,20,252,213,251,175,2,253,3,104,252,116,5,14,255,255,244,210,248,233,242,232,3,107,23,155,9,229,254,117,7,172,5,39,238,44,2,44,248,214,255,191,242,206,255,127,254,85,2,215,3,164,1,167,24,220,249,127,249,240,23,104,249,185,235,175,254,153,239,115,1,8,4,172,255,121,8,163,3,120,254,6,255,137,0,63,3,2,32,23,254,164,255,209,0,115,0,173,5,246,0,121,253,168,3,73,4,112,254,85,2,136,1,93,0,227,225,57,253,44,253,3,8,241,1,127,7,148,252,255,252,84,255,156,11,184,3,43,2,151,0,151,253,5,3,232,18,169,241,73,3,244,0,107,253,160,242,190,3,81,0,20,2,197,254,28,3,115,21,252,253,255,255,165,250,237,253,94,234,57,1,43,249,109,9,189,252,185,243,12,255,114,242,174,252,111,239,165,252,182,255,93,8,19,252,35,18,173,254,249,15,163,252,44,230,227,1,184,244,188,253,211,255,78,14,150,3,195,254,12,14,27,253,129,3,238,245,114,253,164,249,183,248,117,2,147,12,214,0,150,248,149,4,99,238,146,6,143,247,185,2,109,255,111,38,239,2,186,251,171,254,99,253,214,250,137,2,192,252,130,254,165,234,212,255,182,13,32,5,32,12,54,255,78,7,101,255,89,2,207,2,234,255,162,254,138,1,81,0,141,1,31,220,82,255,95,1,147,237,158,238,88,14,139,4,47,9,184,6,24,4,59,251,232,254,238,255,241,255,166,2,165,240,99,18,157,255,31,7,233,253,212,248,138,0,142,4,41,244,139,21,82,5,211,4,199,1,83,2,169,241,78,4,93,255,62,0,80,4,45,3,102,3,217,254,192,251,213,254,120,240,37,3,212,226,100,254,195,247,236,0,46,0,124,233,103,2,61,250,85,3,22,3,203,231,56,1,125,2,173,240,90,254,194,251,241,233,110,3,126,250,37,8,205,255,131,244,255,252,193,255,70,3,55,3,229,2,225,10,194,1,165,228,135,255,109,252,60,0,215,255,0,0,217,255,70,34,135,2,247,253,123,1,170,254,168,254,50,3,36,5,32,4,182,0,205,10,45,254,206,30,45,0,23,3,97,254,24,15,132,246,207,8,107,253,192,255,157,6,144,0,248,6,86,251,210,255,192,248,184,4,35,16,146,3,92,31,239,255,147,7,121,250,21,2,35,1,46,254,186,0,63,253,156,2,154,253,3,255,114,247,31,1,89,15,192,5,231,249,5,0,121,3,28,248,158,0,242,255,117,250,58,5,159,254,110,2,202,255,87,0,176,251,161,244,1,2,136,253,253,5,245,254,22,0,167,25,39,1,69,1,227,26,195,3,139,254,163,254,183,0,128,3,53,7,123,251,95,1,145,254,147,4,10,17,252,1,0,22,192,2,116,250,162,248,174,2,110,20,247,255,118,9,230,0,8,1,154,14,242,254,168,254,240,253,88,252,238,8,228,253,178,16,81,1,103,253,225,2,103,6,229,250,195,22,80,2,164,250,100,254,139,5,227,17,79,1,223,0,213,251,144,255,66,254,149,0,95,5,101,255,120,254,68,248,49,2,189,255,85,1,45,27,219,1,185,44,39,0,81,0,254,2,168,248,46,2,122,255,252,224,23,254,249,0,138,252,154,254,194,26,234,10,87,247,87,4,58,251,150,251,206,252,52,4,225,248,97,3,84,247,155,4,140,17,224,0,231,247,174,254,25,235,122,254,133,0,240,1,214,255,240,255,46,0,181,1,66,1,237,254,184,255,48,0,187,254,57,1,84,4,236,251,173,252,90,236,11,4,220,16,255,250,111,252,117,250,83,252,122,7,192,3,218,4,202,0,245,19,219,1,230,4,189,6,32,250,252,255,243,254,91,254,106,255,199,238,158,253,244,249,108,249,207,252,46,255,72,0,89,253,150,255,31,241,143,251,4,0,52,28,161,255,42,3,128,9,181,254,236,1,175,255,138,0,194,255,155,253,132,253,106,0,156,42,144,3,144,0,192,0,227,4,126,240,70,252,121,4,151,4,71,249,206,20,71,249,199,253,179,241,114,251,205,25,24,253,42,250,85,3,134,0,187,12,8,254,52,249,180,0,49,255,109,253,196,0,179,0,150,255,118,0,21,3,190,252,99,40,92,254,70,244,56,254,113,0,35,25,181,3,209,2,107,245,193,249,84,253,124,224,174,0,120,250,198,255,206,3,52,1,42,253,213,4,198,249,7,2,125,255,58,255,141,250,156,4,83,255,82,1,48,234,233,254,20,255,161,26,89,0,36,255,127,15,149,255,65,0,175,9,234,255,130,2,11,28,155,4,27,255,54,255,84,19,167,234,96,6,251,250,140,8,11,248,227,6,124,2,151,16,227,3,152,4,2,0,162,246,212,4,107,253,126,1,205,251,130,0,103,0,69,255,92,2,206,254,181,245,119,247,157,0,7,3,229,24,100,252,222,6,29,244,171,6,36,11,156,247,123,26,120,1,6,252,186,246,35,252,249,0,239,234,224,255,26,2,96,254,12,236,110,253,47,7,163,1,129,4,140,240,151,253,123,248,58,21,114,2,208,5,16,241,140,0,114,1,74,247,137,228,197,7,187,253,127,2,103,239,40,255,201,4,248,252,51,252,226,253,150,244,9,249,130,246,77,243,190,3,241,12,124,2,123,231,119,0,158,252,106,254,100,255,25,237,198,3,43,254,183,21,193,0,120,1,54,237,154,252,163,0,34,16,36,10,155,8,142,255,119,9,146,253,88,254,119,11,237,2,196,9,134,16,94,255,47,250,121,8,220,235,239,2,188,10,192,8,243,249,213,18,175,0,226,8,86,3,177,11,70,3,66,1,153,245,230,252,229,254,158,255,113,5,59,253,106,1,29,1,195,251,51,4,118,1,38,4,112,25,209,242,190,243,99,15,44,14,86,15,118,246,197,7,185,253,254,250,166,248,176,240,15,238,28,2,107,10,101,255,156,0,132,246,205,4,76,254,218,6,255,10,158,249,5,247,131,4,222,3,105,14,38,251,73,12,111,15,45,0,186,0,170,251,1,1,177,254,225,34,21,2,83,255,45,3,21,0,48,6,29,2,212,255,69,5,108,0,213,235,84,253,146,21,156,252,93,233,1,3,71,2,11,11,206,252,81,234,205,5,37,0,137,253,250,254,0,239,236,253,61,0,178,1,239,6,14,35,144,255,172,252,53,251,147,249,4,1,42,1,82,254,95,3,236,240,159,255,67,25,184,254,142,246,195,255,27,251,39,6,30,0,205,233,65,8,205,3,141,254,205,255,235,20,215,1,184,253,20,254,117,247,239,10,6,254,83,17,158,7,169,242,149,254,108,254,173,3,68,10,110,255,178,1,37,11,121,3,122,2,117,22,202,255,126,0,189,0,152,250,133,254,123,243,228,253,184,6,174,3,100,231,226,254,198,255,197,251,198,14,251,0,178,254,76,16,119,2,17,0,83,0,195,2,42,5,201,12,195,253,0,4,32,232,228,253,52,19,155,0,71,251,52,1,30,253,154,247,18,3,88,255,68,0,55,255,192,255,16,253,197,249,28,220,64,1,86,254,111,0,121,247,118,3,31,253,193,0,187,252,147,12,48,23,182,15,252,2,174,255,16,13,169,252,121,14,164,245,253,5,50,255,167,241,211,4,139,4,63,251,111,12,33,5,23,253,154,25,107,27,22,5,81,8,12,1,186,255,110,0,156,1,101,255,89,249,175,236,105,0,87,249,156,1,68,230,89,11,255,4,73,0,114,246,253,233,144,4,158,11,148,1,118,253,9,1,19,249,191,248,148,255,117,253,145,2,200,252,24,13,177,0,155,0,251,4,220,7,31,0,249,255,215,251,14,8,155,1,235,246,48,255,94,231,171,2,13,4,220,251,191,0,69,255,183,253,215,23,53,254,59,2,104,6,75,253,154,3,13,247,25,2,142,7,7,1,7,15,54,255,148,27,136,0,16,17,147,11,248,251,18,0,44,7,112,255,243,240,218,1,213,7,18,5,92,9,57,3,30,247,12,0,175,14,118,254,139,3,234,1,181,11,132,8,222,249,24,252,94,23,127,255,204,252,71,244,124,10,148,251,164,244,77,4,180,19,137,1,155,249,137,1,63,5,49,251,148,1,25,7,183,5,69,254,29,4,184,253,180,225,45,0,243,1,243,239,214,0,23,2,236,242,54,0,198,249,1,27,0,0,162,255,68,34,244,1,13,0,222,2,5,0,30,3,15,250,85,3,174,255,249,254,149,253,22,6,200,1,23,23,160,250,30,4,53,252,5,251,109,255,145,255,100,19,65,1,67,0,112,27,243,253,108,2,115,3,222,251,148,251,15,243,118,2,226,0,199,231,13,252,87,4,204,252,217,254,68,2,124,2,148,9,130,253,184,26,227,254,143,2,222,5,231,251,201,253,73,1,223,255,7,255,58,2,186,0,167,0,12,3,80,4,42,0,197,0,50,39,241,250,48,255,32,0,63,250,204,2,159,0,240,229,211,255,7,2,52,239,10,255,108,14,198,19,209,16,20,253,220,253,181,0,130,254,143,252,80,248,68,2,196,3,92,254,185,254,187,242,208,249,210,10,83,242,123,6,28,251,48,9,6,0,30,0,0,0,239,254,27,0,52,255,27,254,80,254,250,255,176,0,84,254,26,6,104,0,145,230,196,251,157,8,245,255,122,235,124,255,4,254,187,255,117,1,33,250,208,0,198,255,191,20,92,0,58,252,93,230,32,254,232,255,144,5,38,250,91,255,242,17,121,252,5,249,159,254,140,227,142,0,240,3,107,3,35,232,240,255,162,0,31,19,30,0,68,255,51,8,45,6,44,1,253,254,103,252,126,254,24,254,140,0,30,254,223,27,179,255,238,1,60,255,135,12,6,255,154,255,62,1,210,3,161,0,124,28,55,0,189,250,211,245,130,3,41,7,90,2,60,248,118,2,111,255,154,255,98,254,123,255,161,1,165,253,156,0,129,251,117,254,113,2,116,249,86,0,168,2,9,52,66,1,72,233,220,254,33,255,109,16,151,254,135,3,32,255,209,6,95,0,58,230,79,0,19,9,232,255,7,1,10,3,146,0,85,252,22,7,153,7,208,2,111,1,85,244,131,3,199,238,136,0,143,243,170,254,24,243,248,3,28,1,167,254,9,9,109,254,133,1,133,250,43,7,151,0,124,255,90,249,173,254,209,233,234,7,82,244,47,0,204,253,143,1,137,247,112,5,104,5,230,19,118,244,115,17,234,255,233,255,152,1,84,6,101,5,76,9,37,3,124,1,220,255,221,252,253,2,246,252,137,3,56,255,99,253,102,15,33,1,176,0,97,237,223,7,30,242,182,4,183,23,180,0,9,8,208,255,109,1,208,255,137,246,73,2,147,255,238,250,215,9,243,253,179,253,118,1,208,3,83,14,43,8,182,244,91,5,42,253,40,255,253,251,140,255,74,8,149,253,14,241,41,18,143,4,0,0,213,4,2,6,201,9,220,253,235,243,64,5,210,253,121,248,199,0,158,9,47,5,245,17,65,3,180,241,171,254,14,252,172,1,148,0,110,249,130,0,33,6,81,34,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+440337);
/* memory initializer */ allocate([253,248,251,153,246,97,1,133,254,239,12,124,3,125,3,220,245,39,255,189,252,13,247,113,4,13,239,198,255,199,10,223,3,199,13,231,254,94,232,29,251,10,7,8,0,180,240,236,255,116,255,171,2,182,253,50,249,177,0,230,253,108,7,145,8,239,255,208,247,5,1,133,2,83,1,77,0,112,4,247,253,25,2,100,252,100,255,251,254,195,0,25,4,217,255,236,0,119,255,0,0,127,12,225,0,46,0,86,0,41,255,45,2,238,234,17,0,143,3,102,249,208,255,208,255,81,255,245,255,137,253,103,255,122,17,165,254,217,255,223,6,154,0,170,0,76,255,239,254,91,2,178,253,181,235,182,255,253,6,240,0,44,255,175,1,143,9,112,1,180,255,199,254,11,0,146,244,19,0,185,255,208,0,205,255,40,253,244,230,195,255,141,0,144,255,160,20,180,255,83,17,110,254,231,255,46,0,210,0,152,255,172,0,10,241,146,254,233,255,239,0,144,255,137,0,36,26,112,231,48,253,124,255,120,255,40,2,104,249,167,254,223,254,27,254,149,0,174,0,180,0,105,1,20,255,92,0,151,1,6,0,69,9,124,1,89,255,77,3,188,1,190,252,114,219,157,1,234,250,204,1,77,0,34,0,56,0,20,250,113,255,207,0,213,255,225,255,150,255,204,255,147,1,203,254,42,1,168,255,16,6,16,255,248,252,112,2,171,239,170,254,60,237,57,0,233,255,160,0,212,255,213,1,239,255,99,240,41,236,249,254,72,0,181,0,61,4,26,2,157,253,144,254,59,0,52,255,61,255,216,255,55,255,221,252,27,236,112,243,224,1,46,0,39,253,244,0,248,12,185,0,247,1,163,11,96,254,110,0,25,0,140,0,10,254,188,8,188,238,220,255,18,255,234,254,60,0,174,255,171,253,218,0,69,0,161,255,202,247,166,247,252,246,44,241,20,0,45,255,27,255,41,1,81,14,81,0,148,0,35,5,71,238,218,255,186,0,222,243,242,253,90,0,221,255,63,255,210,254,28,233,20,1,204,254,206,0,133,2,1,0,14,255,68,2,209,11,233,245,166,255,255,1,197,254,119,255,15,248,39,239,181,2,229,1,45,255,206,5,156,4,181,0,120,255,204,0,23,0,127,1,199,5,43,255,42,0,32,0,192,255,120,255,165,255,110,255,178,1,231,0,36,0,198,255,74,243,169,245,238,255,89,1,171,0,196,255,84,0,209,0,246,0,181,253,231,36,189,255,69,255,148,255,30,255,54,254,249,253,175,212,90,254,10,254,132,0,79,0,42,1,37,254,100,254,196,0,92,255,77,227,185,0,125,255,113,1,18,0,12,254,132,2,178,254,93,0,179,255,71,0,85,1,238,13,231,254,161,239,111,255,87,0,37,0,50,1,102,242,149,233,161,0,11,255,37,1,208,0,124,1,72,11,31,0,233,255,243,247,171,253,200,255,94,1,151,255,143,4,64,0,86,1,54,14,177,255,150,255,148,0,46,21,49,253,24,255,8,0,117,254,177,12,27,236,34,255,61,253,241,0,62,1,223,2,120,1,78,0,90,255,178,249,247,255,211,242,74,1,252,249,236,7,72,13,247,255,61,1,9,0,39,19,6,1,62,0,222,0,161,255,48,255,192,203,155,255,121,0,42,1,5,0,172,0,150,1,92,255,79,0,172,0,201,7,235,0,229,0,169,4,238,254,56,23,106,252,241,255,24,5,51,1,126,4,127,254,230,252,117,242,148,2,95,8,147,0,233,254,17,253,207,254,28,4,205,0,148,255,60,2,44,255,29,0,206,255,6,0,165,14,238,0,32,248,162,251,207,250,53,252,73,10,7,2,194,0,217,13,245,255,77,0,164,255,191,4,73,254,152,0,161,252,68,6,180,0,254,253,252,0,52,1,125,255,86,252,133,0,122,1,11,0,121,47,51,0,230,1,71,0,36,254,169,253,57,0,129,255,125,10,83,255,74,255,212,1,115,242,174,253,132,254,9,1,145,252,160,254,234,254,203,254,63,2,124,0,62,42,3,253,192,255,198,2,151,255,40,1,2,10,98,0,154,254,44,2,105,11,123,255,251,255,106,254,42,0,240,1,227,251,91,248,189,2,10,1,4,1,71,254,43,0,64,255,255,255,130,247,166,38,166,255,75,255,29,0,50,0,166,252,59,0,66,255,49,0,230,254,96,6,245,5,100,0,181,241,13,0,173,0,16,255,184,20,129,254,7,1,201,254,211,6,169,0,101,247,227,255,150,255,86,1,211,254,66,0,49,0,23,0,89,3,161,253,186,2,82,251,65,255,62,254,173,248,183,254,148,247,156,0,95,0,145,0,129,0,191,254,88,0,25,4,140,15,242,255,65,1,52,250,127,3,226,255,130,247,33,1,165,3,91,252,15,0,71,10,68,0,238,11,221,0,169,255,175,0,200,0,169,3,169,255,16,248,92,1,146,0,140,254,60,0,250,245,169,13,158,255,57,1,24,2,213,254,198,255,11,221,67,1,244,253,181,254,201,2,209,255,104,1,155,0,168,0,175,2,145,250,181,7,158,2,20,3,54,255,127,255,7,236,54,0,154,4,194,4,172,0,118,2,102,255,233,251,72,3,71,0,175,254,91,0,214,0,38,254,112,2,251,252,16,0,130,255,84,1,137,253,30,254,101,255,163,1,50,0,32,213,26,253,243,252,169,0,149,0,33,0,87,255,44,0,98,1,26,0,129,0,77,255,121,5,8,3,101,255,100,240,211,252,82,2,238,0,195,255,168,0,129,254,211,219,38,1,214,1,190,254,66,255,68,252,222,254,27,0,74,254,2,255,27,49,88,1,119,254,200,253,56,0,81,0,171,0,141,255,238,238,49,0,190,254,19,255,76,253,201,255,207,255,221,16,250,255,27,237,100,255,179,0,247,0,174,254,208,255,184,3,219,251,223,255,90,252,250,0,0,255,170,249,15,4,30,253,159,10,236,255,66,255,249,0,137,255,21,255,192,23,123,0,10,254,93,250,86,0,108,249,79,255,128,255,198,255,19,255,127,253,79,255,64,0,144,246,15,0,140,255,191,230,100,254,161,0,163,1,0,3,36,0,113,0,80,252,15,255,112,250,161,255,123,2,6,7,47,247,238,255,230,11,173,0,223,255,49,255,204,255,193,252,158,233,202,255,57,255,194,0,1,255,211,1,45,255,171,252,0,254,99,45,148,0,97,14,5,238,230,254,129,0,51,255,162,253,167,0,50,1,208,1,229,1,65,252,53,255,254,0,151,0,32,229,250,254,60,20,146,2,158,250,150,4,203,255,197,255,223,255,251,243,129,255,33,255,239,255,225,255,114,247,23,0,61,1,87,255,203,0,33,255,34,255,81,235,116,0,80,0,59,245,102,253,49,13,36,254,85,0,138,253,109,255,204,6,81,255,141,255,207,0,240,0,8,255,161,255,8,252,126,15,158,15,169,254,113,237,187,0,143,255,6,255,111,0,2,254,53,255,130,0,89,0,55,1,96,2,35,255,131,254,3,255,153,254,50,247,45,0,224,0,115,255,45,0,237,255,224,1,46,236,29,3,28,238,93,255,110,0,22,255,81,1,6,0,195,2,236,1,139,234,66,245,162,255,149,254,113,0,41,9,88,1,123,1,208,1,106,243,200,255,243,254,250,254,246,255,159,253,68,1,227,11,209,0,20,12,168,253,42,0,153,253,239,255,203,255,30,0,99,4,224,0,81,2,120,2,166,255,172,1,93,4,107,250,171,229,161,255,219,254,153,255,32,245,251,0,152,6,109,2,163,254,35,4,187,251,108,255,191,1,149,0,88,0,92,0,175,2,225,4,80,0,33,1,207,248,221,0,246,255,164,255,56,249,118,0,136,0,138,0,94,255,190,239,145,255,62,0,95,0,166,0,84,255,73,253,155,241,62,22,241,253,240,7,219,253,43,0,155,255,221,0,181,0,33,254,17,30,215,7,129,255,37,3,173,255,233,253,74,5,129,254,253,0,146,253,94,11,225,4,14,3,13,0,42,0,226,3,223,253,75,0,27,254,74,1,240,255,87,1,16,1,243,252,104,1,159,255,231,255,149,252,111,206,145,253,205,254,195,0,0,255,132,210,229,0,180,0,214,255,151,254,132,255,175,255,233,255,52,254,55,248,212,0,134,253,177,252,80,6,222,253,185,253,99,0,216,14,10,0,177,0,110,1,218,23,83,255,9,1,43,255,10,0,84,4,224,254,102,249,19,255,200,254,38,0,32,247,175,1,230,255,78,255,4,253,251,1,99,1,165,2,42,255,208,252,133,207,47,0,12,0,38,1,217,254,180,240,91,253,235,236,6,255,59,254,220,225,222,1,231,0,17,0,8,255,147,0,40,4,125,2,176,255,215,255,9,1,129,254,142,0,116,0,175,11,12,244,41,3,8,8,137,255,158,252,234,255,108,253,233,0,50,1,175,248,139,251,83,27,186,0,26,222,147,255,217,255,151,255,218,2,18,0,178,252,17,1,150,244,210,0,26,0,82,255,114,255,222,3,131,0,76,254,142,5,39,255,176,243,152,12,35,0,59,1,209,255,48,0,35,255,56,2,44,0,182,0,160,6,37,249,63,255,15,2,158,0,213,253,99,242,171,0,56,238,209,255,184,237,95,0,144,255,184,0,80,0,220,255,109,252,87,0,24,0,253,254,49,249,68,0,139,255,149,1,11,0,40,0,192,254,239,255,98,255,122,255,70,255,74,251,46,254,238,4,133,0,2,255,156,255,210,0,57,249,132,253,63,1,46,252,69,0,197,0,247,253,129,234,178,255,224,253,13,252,101,0,23,254,141,254,177,255,60,255,238,255,185,252,67,4,170,2,95,250,185,246,153,251,54,0,61,3,206,254,1,255,129,2,175,241,217,1,176,13,245,251,96,255,45,254,237,254,75,254,79,0,55,203,70,1,132,0,82,0,188,0,106,1,182,255,126,5,210,255,48,11,95,1,210,253,3,251,108,0,164,255,203,255,72,0,215,255,225,255,159,255,97,1,73,0,72,7,49,255,106,0,175,255,166,240,173,0,41,0,229,253,15,254,135,0,242,253,201,252,69,0,246,255,176,0,136,2,82,249,52,2,80,0,237,0,92,248,234,0,11,0,142,0,175,252,20,16,39,254,110,0,129,0,89,8,86,255,121,12,10,0,245,0,71,252,197,252,226,255,211,4,110,1,189,255,54,0,201,253,47,227,157,9,70,2,74,0,60,248,223,255,216,254,18,12,202,255,145,0,52,2,217,254,237,1,254,255,202,254,147,255,62,251,63,255,245,254,245,255,46,254,222,255,68,246,31,1,241,0,37,14,231,253,202,1,101,3,109,252,222,254,14,3,65,0,166,255,133,253,44,7,80,0,7,2,100,3,79,5,38,2,164,255,64,253,110,0,46,255,15,239,136,254,56,255,123,245,6,0,125,1,176,2,44,2,115,3,168,255,162,6,57,4,133,0,106,4,178,255,85,3,88,254,217,255,115,252,213,249,42,245,140,254,20,14,249,253,193,14,190,255,50,5,225,251,111,4,29,252,220,0,204,243,122,0,83,0,21,4,67,253,136,255,112,229,243,254,195,0,173,4,124,21,22,254,77,21,55,255,155,1,55,3,110,255,46,0,252,0,92,245,94,2,100,252,254,249,138,1,92,254,5,25,0,234,83,252,110,254,119,255,216,3,232,255,82,2,216,255,116,255,236,255,204,0,187,4,34,1,88,253,103,0,78,254,218,254,110,6,97,255,8,247,19,255,251,1,189,255,217,220,159,255,147,1,63,250,145,255,22,0,255,254,101,247,168,253,65,2,139,255,48,0,168,8,86,255,168,4,188,2,35,254,142,6,211,3,91,9,187,255,46,249,165,247,218,254,142,239,181,0,140,254,64,1,76,255,9,254,218,253,102,240,85,231,246,1,220,252,80,254,144,255,55,254,8,252,125,2,41,1,164,3,21,2,30,3,229,0,23,252,36,245,87,240,152,4,189,0,217,249,21,0,184,13,164,254,86,250,184,9,207,1,99,2,210,255,85,0,94,0,247,12,31,244,150,254,251,254,2,250,148,248,7,0,249,253,204,255,142,4,82,255,104,255,67,255,97,254,129,2,27,0,228,6,24,1,211,254,160,11,146,0,136,253,182,15,54,248,172,255,195,255,159,249,29,1,73,254,13,3,176,253,143,1,70,237,203,0,217,254,32,0,113,250,216,0,43,245,247,255,5,14,144,240,61,255,161,0,33,255,64,247,162,248,173,245,210,3,113,0,5,252,109,6,213,5,173,252,137,5,182,255,205,2,155,1,119,3,152,250,73,0,117,0,191,255,249,255,133,0,18,0,69,0,11,0,158,255,45,0,41,249,106,245,11,0,116,255,29,0,185,0,71,1,193,2,56,0,152,0,10,32,139,255,157,0,34,254,36,0,204,253,228,3,113,219,61,253,162,2,145,4,14,1,156,0,89,253,15,0,208,2,218,255,168,236,60,255,183,0,156,254,20,252,185,0,108,255,195,255,151,0,27,255,95,255,23,0,254,16,118,253,224,238,235,255,141,3,105,0,241,254,22,246,78,240,12,251,95,1,140,1,66,255,121,255,202,3,87,12,89,252,200,228,125,255,249,251,53,0,82,254,242,0,37,255,128,1,16,11,105,255,152,0,21,229,164,5,193,255,210,255,72,0,141,2,115,15,165,239,191,254,214,254,166,2,41,254,152,2,214,255,226,255,57,3,195,0,133,251,88,245,78,255,255,246,168,2,188,7,109,255,64,1,164,254,211,16,38,3,249,254,196,255,154,255,8,0,155,216,114,2,126,255,11,1,147,253,45,0,99,255,182,1,190,0,78,0,72,6,10,255,126,254,0,1,1,255,19,22,63,254,243,255,198,0,135,243,73,1,12,254,168,250,9,230,97,2,5,254,160,255,222,0,84,251,171,0,244,255,213,254,113,250,186,1,47,0,251,255,230,254,238,255,105,19,28,249,231,0,41,254,180,19,156,1,216,5,110,255,35,0,219,19,28,255,99,1,30,254,217,251,241,4,80,0,2,251,201,4,58,3,134,248,11,3,183,1,1,254,175,239,169,1,218,255,201,255,58,38,237,3,230,253,104,253,127,253,126,2,125,0,5,245,4,9,28,0,123,251,27,255,144,253,45,0,98,1,144,254,131,249,90,0,10,3,184,254,16,1,33,255,86,37,54,3,89,255,244,255,4,252,146,11,68,9,92,252,169,7,118,5,100,10,3,0,235,0,165,1,114,0,229,254,115,1,140,249,73,1,77,254,143,255,240,250,11,254,82,253,41,1,128,254,88,40,216,1,102,2,139,0,3,253,203,254,180,0,39,248,85,255,81,255,243,13,146,0,46,0,180,250,122,255,241,255,90,255,254,7,108,0,119,0,231,254,203,3,41,254,146,251,34,0,152,255,219,0,234,2,33,255,245,0,75,255,12,0,91,255,216,0,232,252,86,0,50,2,241,248,140,255,212,250,78,2,192,254,176,255,71,7,92,254,214,251,70,253,193,244,250,255,182,0,235,246,63,2,97,0,200,245,122,11,95,253,75,253,140,255,113,7,82,254,131,18,244,255,21,243,181,2,29,255,223,0,145,255,38,250,5,0,215,6,220,255,234,0,24,238,70,3,142,254,216,254,206,252,81,1,210,255,39,221,107,3,89,254,240,1,84,251,232,255,10,252,201,3,38,1,237,0,59,249,27,0,239,9,214,5,190,0,201,1,145,250,185,4,19,22,36,2,248,1,174,2,183,244,105,255,213,2,230,1,124,241,227,254,62,3,31,0,12,20,2,3,232,255,30,254,143,254,130,255,240,249,165,254,240,254,125,254,243,218,245,249,91,251,113,1,44,3,55,1,24,2,135,1,105,1,84,249,224,254,162,255,5,8,45,2,157,253,57,238,192,246,173,0,216,1,160,0,199,248,96,0,111,226,183,0,228,1,119,254,166,254,203,254,243,255,249,255,2,0,17,255,155,40,181,253,141,255,2,5,134,253,81,0,90,0,43,253,131,245,66,251,153,238,151,248,169,244,197,252,124,0,167,8,184,2,55,251,183,250,141,254,87,1,165,1,128,253,200,5,106,251,76,0,189,252,52,253,143,253,221,253,226,4,120,245,84,8,220,253,183,1,161,253,152,1,35,255,162,19,96,1,168,254,197,250,166,253,142,249,108,254,54,254,10,254,61,0,92,255,53,0,230,255,164,245,47,255,64,0,28,240,201,2,193,0,139,255,246,250,95,0,170,255,253,253,56,5,20,254,118,6,109,244,79,14,121,239,255,255,201,11,115,1,20,1,249,255,223,254,223,255,202,232,237,0,30,0,74,2,248,254,19,254,179,1,124,254,91,255,194,40,192,0,57,15,218,234,105,1,77,3,253,254,225,1,75,1,138,2,24,255,23,0,3,249,27,0,31,240,252,3,91,239,117,253,102,12,183,3,221,242,65,2,144,255,130,2,103,251,85,249,236,1,6,255,44,251,24,0,142,250,241,248,171,252,145,6,187,255,83,3,65,252,129,233,54,255,30,0,118,242,175,253,38,21,65,0,141,0,193,254,162,2,159,4,101,255,200,254,116,1,13,11,181,255,196,255,198,245,16,255,128,11,137,253,131,239,240,255,211,1,211,0,198,255,55,0,241,253,205,255,96,255,130,2,207,254,132,1,157,1,210,0,175,255,201,242,136,255,144,0,36,255,96,253,72,5,138,253,236,246,89,254,139,224,125,255,112,252,252,254,132,254,214,1,154,0,190,250,143,246,86,254,109,254,119,255,96,255,7,11,97,2,40,255,83,255,183,253,254,253,95,0,54,255,222,0,16,0,136,0,215,6,237,0,191,251,189,3,112,255,250,253,160,1,165,254,196,255,207,0,21,1,0,2,147,251,166,0,143,5,141,252,62,255,152,228,110,248,161,1,254,8,32,252,77,255,226,2,182,255,155,1,50,254,99,254,67,0,234,0,190,254,92,255,209,255,167,255,129,5,134,1,100,251,184,244,143,2,166,7,0,0,222,248,41,254,33,251,51,1,104,0,202,222,58,255,34,255,191,0,25,1,156,252,47,0,55,238,130,9,174,0,7,1,28,11,184,255,171,253,97,251,138,254,163,255,20,13,13,0,173,0,141,24,224,255,43,255,90,7,155,1,160,253,206,253,182,11,37,1,54,0,109,255,136,255,54,3,163,255,167,2,206,0,99,243,1,253,189,249,253,254,202,254,210,16,36,2,247,255,157,255,166,233,184,254,80,255,197,1,82,1,41,218,193,255,76,3,66,1,103,2,205,251,142,254,159,0,223,255,187,231,161,250,229,2,223,252,217,250,233,5,51,5,187,255,142,10,54,254,53,255,103,0,88,18,228,254,209,1,194,255,216,255,112,12,238,0,13,232,34,2,177,6,147,254,232,255,116,0,223,255,48,1,39,3,25,255,35,1,135,3,237,2,2,255,73,208,115,0,221,255,161,255,90,255,64,241,86,255,91,238,105,255,67,0,211,225,154,2,195,253,24,253,49,253,37,0,31,0,117,1,148,0,131,255,15,0,106,255,119,252,214,255,16,1,153,235,138,2,113,20,109,0,45,251,223,3,211,0,242,5,213,253,184,254,204,255,215,20,234,255,156,234,226,243,131,253,218,3,212,1,219,255,92,255,248,254,246,250,242,2,84,252,83,253,162,252,102,28,233,254,71,254,216,1,103,255,45,246,59,15,161,255,104,1,250,2,14,0,178,1,107,2,185,0,26,255,209,4,206,250,80,5,12,253,105,1,145,250,9,255,120,0,11,242,37,1,119,1,38,3,150,21,24,2,137,0,230,1,28,254,13,0,219,255,12,0,252,255,81,0,43,0,10,0,43,0,218,255,141,254,192,255,113,251,139,255,141,254,90,248,90,255,31,2,159,255,173,255,135,1,197,255,161,249,46,1,53,4,128,255,127,253,192,255,21,0,254,245,21,255,86,1,47,228,122,253,207,255,63,252,115,255,46,255,213,253,196,249,36,252,211,2,47,255,255,241,10,0,221,255,27,4,0,0,138,0,173,3,118,236,37,3,193,11,35,0,186,255,1,2,235,255,80,254,32,255,124,214,89,255,235,251,43,10,80,1,104,1,3,2,171,2,213,3,212,11,236,1,225,253,204,248,23,0,226,255,52,0,216,255,191,1,11,0,107,1,161,255,73,6,53,10,243,255,112,254,207,2,95,238,92,253,222,254,200,1,180,254,245,255,251,254,57,254,89,0,211,254,29,1,31,1,202,0,25,1,87,0,54,255,54,250,233,253,106,3,34,254,55,255,107,18,56,3,52,255,145,0,66,11,148,1,48,13,107,1,238,255,129,255,252,2,106,0,90,6,178,0,185,0,22,0,131,253,184,231,119,5,63,252,168,255,215,253,165,255,98,0,39,7,9,0,185,253,229,4,51,249,0,10,129,255,119,255,127,254,173,248,90,0,16,255,140,0,10,5,200,0,150,229,118,1,79,7,26,34,145,255,213,253,12,250,129,247,175,237,9,2,77,255,166,0,219,249,32,4,166,254,247,0,164,255,81,22,49,2,233,0,152,254,224,1,27,253,128,226,28,250,3,1,214,221,68,6,105,5,211,2,46,22,195,8,147,1,82,48,198,13,62,2,118,19,51,2,177,6,199,250,56,5,196,255,134,252,120,247,205,253,131,36,7,3,174,24,141,252,196,5,177,254,224,2,204,253,123,2,75,234,105,2,54,0,1,1,187,254,190,255,199,233,37,4,127,252,90,0,202,32,212,7,240,36,34,255,22,248,55,252,93,0,251,255,102,252,165,230,216,5,255,249,139,2,235,254,242,251,184,23,170,222,34,246,109,6,179,5,35,2,43,9,171,255,7,253,214,227,103,255,158,1,208,23,127,1,64,1,114,1,122,252,55,3,255,11,243,1,37,253,38,0,217,1,157,6,16,219,178,3,194,4,226,251,70,0,111,1,43,254,75,225,111,252,145,1,198,0,173,255,109,3,204,254,185,33,253,0,23,248,133,7,132,5,71,5,152,254,76,252,154,226,65,4,231,226,116,6,141,0,213,255,222,247,44,0,130,0,155,226,55,197,191,250,180,0,63,244,27,238,245,254,5,9,139,250,144,255,193,255,51,1,22,253,243,255,35,0,160,221,101,248,137,251,184,251,234,245,70,251,3,30,25,253,203,249,67,22,176,255,161,250,163,255,29,254,129,0,188,23,45,232,118,1,80,255,130,251,96,254,137,0,43,239,122,248,27,12,82,0,188,252,136,1,113,253,108,0,172,1,33,13,57,1,107,1,110,29,129,4,78,1,214,8,145,254,187,255,211,252,26,218,2,12,171,234,0,0,159,248,23,5,142,223,143,255,91,253,180,2,64,245,12,5,85,255,174,1,1,18,66,247,196,0,125,6,231,255,92,255,226,245,201,236,153,253,249,255,15,253,240,19,77,20,190,255,202,254,59,3,130,255,103,2,70,0,56,254,238,0,170,2,129,253,207,253,113,1,183,0,113,0,174,1,184,252,232,252,142,227,143,226,107,2,67,254,76,2,19,0,219,251,140,2,46,0,93,3,169,37,29,251,215,255,69,253,163,253,147,250,240,0,210,213,221,2,194,0,50,251,188,251,248,253,37,255,7,0,6,2,75,255,226,208,139,2,216,255,104,4,122,254,36,255,74,254,215,1,254,1,120,2,191,254,113,5,123,34,87,243,229,229,94,1,161,7,10,255,186,253,146,234,104,226,99,255,120,3,149,11,233,255,250,2,211,26,113,14,213,255,31,225,86,252,71,8,121,1,231,255,179,2,136,0,43,253,219,29,38,253,232,7,236,228,36,3,53,0,136,1,184,1,80,1,91,24,131,228,48,234,213,249,91,4,221,6,233,3,32,0,218,254,176,253,44,1,4,253,81,221,180,249,179,252,186,6,56,27,128,1,11,1,94,3,78,42,148,254,142,251,207,255,17,4,116,252,144,197,41,3,116,2,130,251,188,250,75,254,37,3,109,3,192,255,17,4,133,20,242,254,230,7,229,4,32,252,7,43,126,10,17,0,80,0,73,250,133,16,80,0,190,252,186,219,155,4,66,0,217,255,192,255,39,240,89,254,116,0,95,250,59,249,240,2,138,6,163,5,245,2,179,243,97,35,62,242,167,15,131,252,155,4,124,254,224,24,34,254,45,17,44,54,76,244,22,3,192,2,5,247,141,232,193,1,222,234,207,7,181,0,241,248,150,254,199,255,198,1,189,246,74,14,27,254,44,255,31,45,255,5,222,1,222,249,234,254,72,2,96,2,165,235,53,27,18,4,88,255,175,254,209,251,72,0,195,1,52,255,24,252,236,251,177,2,186,0,90,255,137,254,210,36,107,1,93,0,51,253,48,1,107,0,173,30,29,251,69,4,180,2,26,253,33,0,64,2,191,1,166,2,196,1,152,1,51,237,199,2,173,253,252,253,172,251,149,7,240,11,37,255,171,242,194,42,233,5,185,246,48,0,104,254,49,0,113,254,24,234,198,255,161,0,200,18,180,1,68,0,213,233,230,0,64,3,52,251,238,24,180,253,224,250,4,3,241,16,107,254,165,234,34,255,102,5,110,8,108,2,184,252,42,3,10,241,48,0,155,255,17,2,146,245,7,255,11,4,60,226,199,251,10,230,189,5,19,4,231,2,17,6,212,253,238,254,68,0,238,0,54,4,146,255,213,235,50,2,223,2,131,223,178,4,211,250,62,252,61,0,184,16,58,2,26,29,9,1,20,250,184,2,225,249,87,253,0,0,32,240,12,6,39,246,145,2,55,2,105,223,155,6,106,250,219,18,39,3,137,3,215,245,9,227,153,3,51,249,107,1,53,1,211,0,247,253,197,11,227,252,136,2,131,241,193,3,150,2,147,1,126,254,49,253,136,233,75,5,61,26,191,0,79,2,141,254,55,251,251,235,32,3,4,255,119,233,77,4,145,2,115,255,73,9,171,250,38,255,142,255,148,0,20,1,102,1,158,254,18,0,225,255,59,219,118,234,78,250,36,255,42,1,154,2,147,2,103,1,212,3,147,250,101,0,220,5,53,18,216,1,8,1,90,226,67,250,41,0,38,0,253,254,166,254,26,254,35,217,44,3,166,1,182,250,99,246,247,247,3,255,14,7,149,255,215,255,0,64,116,255,84,253,45,21,115,7,246,255,135,252,171,248,97,229,206,252,34,233,132,243,129,252,86,249,70,255,8,31,100,0,4,212,35,238,97,254,77,18,139,1,109,232,157,22,42,238,112,2,158,247,58,2,130,0,132,252,105,5,250,254,238,25,236,246,92,1,224,254,95,2,218,249,207,27,243,251,216,255,165,236,78,252,161,235,11,252,48,251,149,252,178,255,113,254,231,0,83,255,28,233,189,0,13,253,183,223,233,2,198,3,202,0,190,248,230,255,110,253,55,0,107,4,200,255,214,11,158,0,158,14,19,251,61,1,253,24,9,2,4,254,246,253,8,248,21,253,6,229,156,252,146,255,49,253,42,10,10,10,174,251,237,252,160,254,252,35,223,253,171,28,57,216,42,253,80,4,162,251,137,249,127,1,90,5,132,5,16,2,175,237,114,254,38,241,86,253,4,213,250,246,75,31,253,8,203,232,0,254,229,14,210,0,99,5,151,196,119,4,216,246,155,9,64,9,172,230,226,247,10,255,127,1,52,255,169,5,59,254,253,249,160,1,252,1,0,228,118,248,183,16,197,1,41,255,216,254,166,254,59,22,56,255,169,252,40,2,33,23,147,255,76,2,23,244,32,5,111,26,178,255,220,227,163,4,14,253,237,251,57,254,156,1,22,254,52,12,239,254,188,5,222,253,40,2,206,254,67,3,249,254,190,227,68,1,62,1,56,251,240,0,198,0,193,0,218,253,84,253,128,207,85,0,67,250,49,254,211,254,180,0,34,1,96,252,1,231,93,252,176,0,54,1,76,253,28,31,52,255,0,2,207,3,241,230,118,254,226,255,136,255,102,6,62,250,131,254,24,23,156,0,194,252,193,253,31,255,17,240,237,252,67,252,223,252,181,0,63,2,92,4,229,252,25,253,43,252,178,1,147,254,204,217,234,248,167,5,57,4,153,0,116,3,249,33,3,1,113,3,107,253,48,251,221,253,208,1,130,3,108,240,36,254,22,3,165,29,243,253,215,252,172,244,9,251,170,0,223,0,70,236,6,246,178,5,102,253,25,2,179,229,212,0,192,1,236,249,179,5,34,3,100,245,175,221,12,43,254,254,205,4,114,4,75,3,252,1,103,0,111,253,249,4,204,31,112,1,163,253,200,26,110,0,89,254,82,21,95,254,225,3,1,1,176,21,209,255,121,5,137,255,216,250,49,24,84,251,56,0,163,255,188,249,45,250,127,252,238,0,55,3,117,16,104,0,145,0,231,251,186,219,230,255,211,252,117,255,243,1,145,215,46,254,253,253,114,251,100,254,22,253,247,1,80,7,17,0,91,209,234,242,148,255,128,227,101,254,203,18,178,248,162,0,219,21,110,253,83,1,120,252,255,26,53,253,16,255,185,255,121,1,139,18,199,255,40,221,9,2,241,2,137,254,95,251,42,5,184,254,5,0,13,2,158,253,127,0,239,5,23,3,16,3,0,192,116,0,17,252,160,254,230,1,65,225,202,0,156,241,125,254,164,2,18,221,55,253,65,254,211,253,135,4,206,3,132,254,97,251,25,4,247,255,70,3,92,252,117,255,115,1,152,6,63,226,168,4,46,9,36,255,50,238,121,10,32,6,102,0,250,4,66,254,161,254,15,6,77,4,221,220,100,235,192,238,83,13,221,0,83,254,156,1,89,6,33,238,254,0,137,253,54,1,134,254,15,38,91,3,166,3,142,0,136,250,247,228,66,25,28,240,104,10,162,1,70,0,28,1,121,252,233,255,10,254,2,17,151,232,125,0,222,255,34,251,102,248,52,255,234,3,226,226,168,255,76,222,145,9,147,53,62,1,201,221,38,1,92,247,138,0,7,253,29,1,106,249,35,1,94,2,180,0,249,2,153,254,69,250,43,1,95,254,151,254,129,252,196,233,127,0,73,252,165,0,1,0,140,1,205,252,124,234,24,1,248,2,101,254,255,251,119,253,104,249,110,231,16,1,239,255,85,226,9,0,51,1,128,0,101,240,137,255,225,1,228,243,1,255,139,2,139,0,92,242,250,255,137,238,196,1,185,255,139,0,231,4,16,232,167,4,70,1,28,0,18,255,94,5,178,254,55,254,188,252,106,215,185,0,152,253,38,13,217,255,183,0,235,255,96,24,117,4,85,1,164,254,226,2,121,0,191,255,126,254,229,255,220,253,81,1,252,255,130,255,59,2,215,8,72,19,187,251,115,254,193,3,2,233,34,253,229,5,108,253,195,255,170,0,241,252,155,239,77,250,138,3,225,255,144,1,31,254,49,2,6,0,233,1,235,234,126,249,41,0,232,253,140,255,57,26,8,5,99,255,140,255,160,16,103,7,15,26,45,7,224,253,252,4,239,7,89,1,71,25,172,255,76,7,42,248,232,250,144,225,190,2,91,251,105,0,251,236,230,254,234,252,171,27,140,253,7,251,252,0,77,255,120,254,96,0,216,225,99,0,12,2,176,223,236,255,164,0,78,254,171,255,84,254,82,5,108,0,223,0,29,4,245,255,63,255,236,235,65,255,97,255,193,0,69,31,217,255,29,254,228,6,219,251,244,254,194,254,144,252,218,1,49,0,248,255,33,255,130,0,255,43,165,0,12,0,213,255,153,255,135,251,180,253,175,255,43,1,73,0,188,1,181,227,125,250,128,253,78,252,16,0,143,252,240,1,99,9,36,254,66,4,218,254,29,0,108,255,109,0,145,0,204,255,247,0,223,253,91,4,229,226,21,254,77,250,141,1,101,222,2,252,214,5,42,1,220,235,154,254,183,251,161,244,167,1,140,2,134,254,203,246,182,255,159,1,145,254,146,1,125,8,102,255,122,0,27,1,72,5,46,1,139,254,81,254,229,254,147,255,192,255,169,254,148,255,55,0,204,198,241,0,37,0,45,253,185,255,48,255,130,255,221,15,97,217,238,1,225,8,7,254,56,240,66,0,218,252,159,251,154,248,15,3,91,250,170,1,204,252,53,249,245,255,138,2,230,254,250,253,124,0,158,227,235,255,160,0,173,254,5,0,48,255,192,45,198,0,203,255,153,3,89,0,99,23,58,237,176,0,92,7,64,0,251,253,121,8,108,0,41,1,145,255,123,254,184,252,151,2,75,0,27,254,2,237,79,255,103,10,27,255,184,31,37,255,206,1,32,12,187,3,128,1,30,5,183,255,8,254,2,1,170,0,252,248,30,254,59,22,75,254,230,222,71,2,107,249,197,252,36,1,191,255,202,7,128,254,105,0,123,0,0,1,174,255,145,254,100,59,128,255,252,254,246,255,169,0,249,0,250,250,31,4,136,0,166,2,61,0,140,5,97,255,241,255,35,255,6,255,107,0,235,255,41,1,54,0,242,0,145,255,212,1,237,0,220,255,97,255,37,0,154,255,24,254,31,238,72,0,241,3,255,255,194,4,231,7,128,253,75,254,254,2,213,254,0,24,184,0,1,252,171,0,124,254,116,3,242,250,192,254,14,34,128,3,217,254,48,252,221,252,20,12,184,6,1,255,182,250,103,253,193,255,30,17,41,0,135,255,99,255,98,1,127,0,75,2,169,253,25,255,228,1,106,255,228,254,14,254,1,254,79,0,127,21,13,0,137,25,249,2,173,249,140,4,157,246,241,11,154,236,212,2,52,4,237,249,121,3,147,254,60,0,72,254,24,228,124,255,27,1,207,254,130,255,54,250,125,0,204,255,223,255,4,5,63,252,75,5,185,3,12,252,29,255,86,0,219,2,242,255,151,193,200,255,149,252,116,249,127,0,244,1,62,13,242,255,193,254,124,253,143,0,249,0,0,214,23,0,54,0,205,251,145,255,168,2,78,249,72,1,212,247,172,252,110,2,181,3,61,0,6,0,239,255,144,0,190,0,216,0,130,0,191,255,27,0,190,254,117,255,43,0,89,0,76,0,172,255,120,216,209,255,111,1,251,254,38,0,50,0,137,16,46,255,14,0,255,255,25,0,250,2,213,254,124,255,177,0,206,3,20,254,111,255,213,255,241,19,118,254,60,255,165,255,231,255,217,1,90,223,36,254,77,2,164,250,2,255,173,246,219,254,208,254,244,14,2,255,63,255,237,1,54,0,148,255,171,221,250,254,23,255,203,252,34,255,202,2,246,4,195,255,124,3,13,0,112,15,220,255,225,249,148,253,130,255,224,251,75,2,134,1,232,255,235,7,11,1,218,0,15,0,200,255,126,255,40,0,39,2,227,255,2,57,233,255,106,0,242,255,84,255,23,1,171,1,15,255,47,1,236,255,20,253,55,0,67,20,86,2,39,255,234,7,131,2,118,0,143,3,87,31,40,1,23,3,39,0,195,245,143,2,228,0,97,253,240,254,80,255,244,25,90,255,248,254,67,215,91,0,173,255,84,253,87,255,168,254,75,8,154,255,179,254,195,254,198,252,74,2,116,0,161,219,189,1,141,0,221,250,10,253,144,0,244,21,107,1,66,0,142,0,95,255,84,253,198,1,72,230,51,255,65,2,205,0,49,1,0,250,243,239,194,254,121,0,189,254,244,251,84,31,122,4,92,240,175,0,224,249,255,249,243,253,236,8,62,0,11,0,128,2,219,4,4,1,152,255,168,254,102,0,144,253,122,0,212,254,10,1,40,232,131,251,156,1,156,250,22,0,137,29,104,1,52,2,142,1,174,254,174,0,180,255,131,0,44,0,86,254,244,255,81,255,143,255,78,0,37,1,136,255,164,255,75,1,221,192,182,255,155,255,82,251,214,254,85,255,212,15,117,255,69,255,131,0,67,1,114,1,112,255,96,255,131,0,228,254,66,255,83,0,110,3,31,198,14,0,196,0,198,0,38,1,136,255,40,0,32,3,49,7,137,1,88,255,81,1,228,253,156,254,130,0,250,35,112,3,48,1,0,247,237,254,114,5,175,38,161,2,194,255,158,237,126,255,18,1,16,2,89,0,54,254,166,255,174,24,123,255,54,1,191,232,170,2,37,0,121,11,141,254,197,0,77,0,72,255,216,4,22,0,241,225,85,255,246,236,92,253,159,251,182,252,126,253,136,4,192,251,160,252,96,1,234,252,26,3,33,3,68,41,15,249,71,4,71,254,182,6,116,0,214,3,244,254,199,0,152,246,6,248,23,1,110,255,133,2,186,250,5,0,106,255,92,252,113,0,25,0,96,253,153,0,158,0,4,232,250,254,142,0,207,18,255,255,88,254,42,3,63,0,88,0,2,254,20,255,124,15,190,255,205,4,240,255,10,253,241,212,131,251,48,0,36,249,167,0,4,9,160,255,114,253,129,253,113,1,35,255,47,0,202,0,73,1,160,254,230,255,237,255,142,51,129,254,124,0,69,251,39,15,168,254,94,248,2,222,32,0,156,3,216,1,17,31,180,2,40,255,97,254,154,243,89,248,167,3,208,15,155,0,97,29,86,3,99,255,131,2,176,14,149,255,24,246,110,2,26,253,89,7,214,8,246,2,56,252,241,254,125,255,129,1,13,236,44,255,12,246,29,0,124,255,6,254,66,255,215,251,58,1,202,0,76,1,30,247,189,2,4,0,234,255,73,254,198,0,247,254,164,255,113,255,204,1,224,255,189,0,78,1,87,0,41,226,45,0,125,254,144,16,207,4,92,0,8,4,179,254,232,254,13,8,40,1,109,1,211,7,86,254,221,255,96,0,194,255,114,3,240,252,227,1,128,255,113,255,218,1,172,53,90,255,184,0,54,253,142,0,22,1,246,21,189,255,26,1,135,2,126,255,225,255,44,1,215,2,216,2,153,1,178,0,167,253,84,0,113,32,66,254,179,0,115,0,209,0,239,254,209,255,140,7,1,255,157,243,154,255,205,1,137,255,90,224,215,252,108,0,112,249,157,243,249,252,68,1,10,255,132,0,229,255,84,0,47,33,211,255,153,0,21,0,152,250,34,1,155,252,38,0,72,254,133,0,255,254,234,255,26,244,12,0,19,245,165,17,142,0,69,6,167,1,67,2,210,253,211,254,255,254,189,2,10,255,44,254,102,248,120,0,65,1,198,2,39,255,53,255,206,255,212,255,22,233,80,0,3,1,232,1,242,2,124,0,251,253,191,2,59,255,146,0,64,2,51,253,247,0,25,16,10,0,90,254,130,245,73,1,159,4,237,56,72,0,45,1,251,7,131,255,116,250,17,251,100,40,90,253,54,251,74,1,194,255,173,0,253,22,200,255,78,255,190,251,152,253,185,3,40,255,85,32,132,255,155,1,78,30,178,255,186,254,18,3,46,0,171,250,213,253,223,1,250,252,192,253,8,0,48,1,134,1,70,255,204,252,72,0,189,255,183,253,62,43,43,255,244,255,88,1,113,254,20,253,106,255,159,10,195,0,20,22,18,18,37,2,222,10,252,255,136,7,226,1,240,3,2,231,75,3,201,1,51,7,13,1,223,4,94,1,107,253,221,255,179,230,143,14,9,9,88,254,117,252,159,1,51,4,120,15,37,250,61,0,82,2,24,253,110,0,182,9,199,3,27,0,113,235,150,253,190,253,57,1,143,27,199,251,227,2,20,254,253,247,61,1,112,0,101,255,208,254,5,254,150,0,253,0,214,255,221,0,92,0,237,254,157,254,210,222,105,253,109,0,26,1,188,252,241,254,100,36,165,0,63,0,85,255,10,0,218,255,76,255,37,255,6,255,100,252,195,253,15,255,54,2,81,255,20,0,198,1,251,0,184,254,236,0,41,255,215,233,0,0,247,254,225,0,98,1,113,0,24,254,174,0,124,255,134,0,68,255,231,4,162,255,201,255,63,255,148,1,248,1,16,3,135,254,157,233,77,1,65,254,222,0,138,0,72,0,0,255,198,255,26,255,87,255,216,2,31,254,95,0,118,254,182,255,23,254,3,255,54,202,61,0,184,0,220,255,161,19,24,255,65,1,253,0,170,242,120,0,48,246,31,3,182,253,162,4,145,251,69,252,202,255,7,0,83,0,0,0,139,20,210,1,42,231,254,0,132,1,45,255,207,0,145,9,123,1,174,1,37,255,70,254,228,0,151,0,43,46,67,0,155,255,239,0,230,254,121,0,242,254,185,4,126,254,41,2,148,255,21,3,250,253,237,0,208,255,241,1,26,35,80,0,40,32,167,255,153,254,221,252,217,1,227,3,108,4,112,2,73,5,207,254,199,2,185,255,230,255,18,0,254,0,23,51,184,255,178,0,238,255,140,255,37,1,155,0,2,255,205,252,90,255,216,252,66,255,150,0,24,239,223,255,242,255,16,1,239,230,78,0,78,0,67,0,54,1,79,255,77,254,225,0,98,2,241,255,1,0,206,229,30,0,1,0,67,255,14,1,235,255,20,1,74,255,77,0,25,255,30,0,140,255,223,225,158,0,88,1,48,2,186,5,247,13,172,255,25,238,20,251,116,1,115,5,153,235,28,1,137,248,59,1,248,246,209,255,49,255,158,1,129,0,36,0,85,0,61,1,131,255,193,255,44,255,180,255,130,0,127,254,157,0,117,0,12,0,12,63,85,255,119,1,47,253,161,0,170,254,182,3,101,253,243,3,15,0,24,2,77,251,15,4,14,255,97,255,240,29,83,254,248,254,227,223,147,255,99,3,182,255,177,255,98,254,32,2,206,0,120,0,67,7,212,255,73,0,42,2,121,0,96,255,129,255,223,255,44,0,232,255,29,1,77,2,30,207,51,0,208,1,17,0,8,1,58,0,51,229,111,1,96,253,227,0,233,10,14,3,114,231,92,254,216,252,33,251,127,3,182,3,253,5,201,251,49,255,121,248,173,236,221,252,184,254,253,29,126,254,0,238,183,254,27,254,61,9,44,250,54,249,134,254,61,253,198,248,84,35,58,1,202,13,61,0,105,11,79,0,36,37,178,251,97,242,46,3,244,244,38,2,95,252,56,253,238,254,202,253,39,246,24,2,216,254,159,255,183,3,88,44,154,253,106,0,170,254,7,252,97,251,99,255,55,254,10,1,109,0,33,2,199,254,247,3,49,27,52,0,32,255,199,8,8,255,76,255,79,48,55,1,2,2,194,4,207,253,14,246,53,243,218,0,89,32,187,0,106,230,160,255,23,252,241,6,89,0,148,3,18,4,143,1,245,254,159,255,32,242,141,1,192,7,10,232,16,3,88,8,190,250,107,2,86,250,2,252,54,251,185,0,50,1,238,254,134,255,87,1,129,0,127,238,19,253,9,253,16,254,81,34,78,255,201,1,167,253,107,3,16,4,244,254,200,249,237,253,195,37,104,1,142,236,13,2,76,254,123,0,226,249,227,0,52,3,74,0,251,255,197,5,154,0,203,249,61,219,248,0,27,254,35,243,78,253,175,0,53,0,235,255,47,1,184,246,106,0,3,2,128,10,111,254,2,251,169,1,28,2,159,254,150,2,219,226,115,254,139,228,48,252,189,1,144,249,164,0,2,255,205,253,44,2,108,3,51,255,116,3,214,0,164,255,3,254,96,0,203,255,102,22,217,254,120,255,211,0,168,0,5,1,182,255,155,1,25,0,197,255,12,14,144,1,64,1,187,255,235,255,238,54,2,254,142,0,24,255,61,6,34,0,240,0,36,254,131,0,4,241,70,255,19,10,252,10,35,250,18,1,125,10,249,10,180,251,136,10,110,254,67,0,138,2,244,248,245,255,40,255,95,26,112,0,199,1,214,227,5,255,205,251,191,252,58,252,163,5,118,255,17,1,18,254,21,6,241,255,173,254,174,255,146,1,206,0,31,0,179,255,162,255,78,0,164,234,77,255,212,255,165,1,163,0,126,254,123,255,66,231,171,1,235,2,135,255,220,254,112,1,193,251,174,254,2,250,156,14,143,252,36,248,252,250,134,3,97,0,177,242,201,253,138,255,60,5,179,255,67,254,130,2,184,0,133,3,171,254,175,255,83,2,125,230,8,255,89,255,36,34,117,1,152,1,23,0,213,41,213,254,148,252,184,253,213,251,20,0,52,238,39,1,92,248,222,3,124,255,104,255,228,15,164,255,142,0,24,250,23,0,209,252,198,1,74,1,181,254,82,35,120,0,156,255,34,0,96,0,152,0,181,212,89,1,201,253,14,254,198,0,219,255,60,36,33,254,99,2,28,245,253,0,80,255,105,2,32,255,248,0,134,1,39,0,25,0,146,255,127,0,243,255,19,26,172,255,115,0,38,1,84,0,146,254,107,254,224,255,147,255,27,215,99,0,17,0,168,255,30,255,60,1,123,255,53,255,196,255,55,1,169,255,181,254,101,1,245,255,158,0,74,0,50,2,8,0,98,1,165,213,142,255,50,255,187,2,151,253,115,255,39,3,87,0,107,255,174,0,199,0,201,255,128,42,180,254,182,0,32,2,139,2,229,255,5,1,66,255,113,253,24,0,69,254,138,253,204,0,207,0,178,239,229,13,89,0,126,254,218,6,27,254,129,255,159,255,40,0,200,250,24,254,79,255,18,253,88,0,240,251,89,247,5,254,169,0,92,11,69,0,204,255,10,33,89,2,174,0,99,6,224,1,181,0,188,11,51,244,76,7,148,254,204,247,0,255,7,244,223,255,213,226,134,252,99,248,236,255,0,219,26,255,177,252,134,253,135,254,216,255,160,4,242,0,9,1,144,27,42,0,16,0,50,236,185,255,44,1,94,251,187,0,81,1,205,250,77,0,39,254,141,12,106,22,114,2,220,9,19,2,233,3,221,252,207,4,197,251,204,253,27,2,191,0,14,254,184,0,91,2,15,249,33,254,250,8,164,253,227,247,122,2,74,18,149,250,149,252,242,1,229,216,83,255,240,2,109,0,186,255,171,0,192,255,251,254,177], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+450577);
/* memory initializer */ allocate([255,37,0,23,255,128,0,190,255,186,255,100,1,202,254,214,0,56,198,6,0,200,0,29,255,59,0,15,255,48,2,26,255,223,1,147,1,234,255,148,0,4,29,110,0,79,255,110,0,94,29,188,246,3,251,223,0,60,253,219,2,183,2,66,253,166,244,0,1,120,251,77,19,121,0,132,251,188,255,88,254,202,249,89,18,193,2,13,2,172,2,61,254,10,255,141,255,44,2,31,2,254,229,128,1,179,253,31,250,12,0,114,0,82,0,36,236,164,0,154,0,217,254,106,0,241,254,216,255,118,254,75,254,141,1,233,254,15,241,226,254,120,2,239,251,113,4,163,255,48,0,192,0,230,232,164,255,21,255,170,2,185,22,66,253,180,0,13,255,37,255,114,252,82,255,110,255,142,0,12,0,187,255,49,255,243,254,203,255,55,2,176,254,114,0,129,37,240,254,242,254,203,1,98,2,254,254,97,0,58,213,141,1,57,0,249,255,229,0,133,6,83,255,83,255,164,255,165,254,123,255,155,254,92,0,132,0,159,253,60,0,132,255,116,0,202,255,155,196,142,0,109,0,103,4,12,1,36,255,80,1,25,253,18,255,227,255,122,252,91,0,243,241,224,254,90,4,43,241,177,249,32,0,217,44,55,0,194,0,239,13,191,248,255,245,19,255,241,255,208,255,24,255,198,255,235,255,37,0,233,253,62,254,89,3,209,7,12,0,48,0,72,3,211,0,126,0,225,18,19,1,176,0,145,255,9,0,144,255,109,254,182,0,40,1,181,0,87,254,242,255,20,1,118,0,16,255,128,1,139,0,223,35,26,255,143,0,108,9,186,255,250,0,207,39,41,3,241,255,255,254,38,251,93,255,99,239,160,254,76,254,8,1,122,236,239,255,41,255,132,5,56,6,88,3,97,255,148,18,88,236,51,1,5,255,194,0,14,25,200,255,249,255,9,254,251,254,122,253,230,251,241,254,190,253,221,254,102,2,130,0,176,254,101,252,136,255,149,0,132,232,17,1,217,254,22,238,137,0,206,0,222,4,242,1,102,2,223,3,208,53,122,0,52,0,108,253,180,255,45,255,35,254,32,255,196,0,155,1,142,1,178,253,52,3,71,254,221,255,42,17,146,19,122,252,253,1,45,0,235,2,11,4,57,254,189,253,105,0,79,4,16,254,31,251,8,255,46,0,117,233,58,255,126,254,224,2,15,0,177,254,171,255,144,253,132,255,68,2,185,254,154,255,238,255,98,3,125,1,169,252,13,6,23,237,117,2,164,3,248,232,72,3,7,248,207,254,242,245,87,1,225,255,244,252,251,252,159,254,147,1,141,248,189,246,213,253,188,254,33,254,49,27,226,254,62,239,114,2,71,252,242,255,111,249,69,254,224,5,146,254,1,2,74,251,102,3,23,36,112,0,43,255,169,1,125,1,10,7,238,2,82,2,61,0,104,255,244,247,219,220,16,253,197,0,19,254,80,255,123,254,177,253,172,11,142,2,100,9,52,255,48,1,233,254,202,0,66,0,71,255,159,1,159,0,22,250,137,229,219,255,199,245,34,251,84,240,184,4,214,253,168,12,113,253,118,254,72,250,160,238,132,1,34,4,148,254,32,249,57,4,210,253,140,255,148,255,99,0,99,252,251,2,235,250,5,255,2,1,223,255,55,1,43,2,227,0,233,254,167,253,121,255,93,253,137,214,87,252,158,0,247,1,4,248,51,4,142,255,182,16,176,220,67,0,204,251,63,253,134,255,235,253,227,12,222,248,220,250,196,2,0,241,28,253,142,254,206,251,87,0,50,254,129,8,103,251,57,0,89,231,86,255,247,252,0,255,179,1,35,1,131,40,174,255,87,254,35,249,60,255,240,14,111,231,62,0,154,17,249,253,241,252,131,4,110,3,39,1,4,248,49,1,186,0,7,1,76,249,30,254,210,233,159,1,149,10,213,0,107,29,96,5,45,3,11,7,190,0,142,1,83,25,145,5,235,0,153,10,8,2,180,244,89,251,186,23,142,2,121,230,64,1,32,253,34,254,3,10,203,254,107,242,101,255,19,1,0,4,134,1,126,254,181,254,219,54,251,0,102,254,216,5,24,0,248,4,208,252,37,2,18,255,71,246,158,0,194,0,1,0,206,254,240,243,248,254,200,0,226,255,248,253,40,254,226,255,48,254,4,253,184,1,109,253,88,0,10,3,225,255,254,248,23,241,168,254,119,3,217,253,115,0,5,253,38,235,90,11,50,0,224,2,160,21,179,251,74,1,107,254,160,1,254,3,163,255,71,0,50,39,56,255,22,251,179,242,224,1,141,0,143,1,244,1,55,1,9,254,45,1,46,17,198,1,102,252,207,3,155,255,249,252,175,255,69,249,53,4,89,3,110,249,45,3,79,3,86,1,236,254,254,13,175,11,195,21,201,2,0,5,84,2,211,250,193,251,87,253,131,5,135,1,64,249,236,1,32,2,232,5,44,253,235,226,86,254,6,0,234,253,197,241,194,249,90,10,190,252,48,8,179,254,67,0,210,6,208,249,21,252,248,4,174,6,130,6,176,0,60,210,73,1,219,248,129,1,34,3,130,254,196,8,248,255,34,255,209,246,113,1,213,251,118,219,37,1,205,255,199,248,12,254,210,246,224,248,198,252,62,254,149,247,200,1,245,0,4,7,64,1,183,255,206,254,134,255,34,1,118,0,214,254,93,253,76,255,196,252,86,0,212,255,165,0,179,1,199,223,1,3,118,2,122,249,6,253,197,1,5,23,3,1,164,255,21,252,154,254,224,255,186,250,233,253,223,254,153,1,210,253,168,254,16,253,149,23,88,253,167,9,69,2,161,254,227,4,61,233,194,0,152,255,47,3,233,4,149,253,243,0,154,1,103,17,55,252,50,0,6,5,11,252,219,254,196,225,73,0,103,2,11,2,107,255,200,252,187,8,35,6,202,3,176,3,170,18,124,255,38,236,83,0,129,0,204,252,221,252,182,2,79,6,139,4,5,2,110,254,176,255,250,2,149,255,93,254,142,0,218,254,34,44,45,1,228,1,255,253,105,0,35,2,106,4,99,239,26,253,120,1,247,249,52,4,20,17,34,9,225,244,239,1,66,255,116,246,163,3,87,25,117,0,7,251,208,5,181,255,190,254,25,254,202,245,5,255,209,4,15,16,191,254,37,255,231,224,245,255,107,0,216,252,194,1,111,0,43,17,89,0,4,3,170,248,154,248,51,4,224,253,5,219,53,254,125,2,74,3,68,252,30,253,100,17,9,3,181,255,47,255,210,254,228,252,17,3,11,227,65,1,137,2,201,255,114,0,43,0,254,251,33,255,157,253,209,0,89,234,14,32,139,3,226,242,172,5,225,253,155,243,13,2,161,255,35,0,37,254,243,253,63,253,199,253,94,1,206,0,148,255,13,250,88,253,229,254,233,245,128,236,197,255,56,252,73,249,66,245,252,22,199,1,29,0,180,1,16,3,155,255,40,255,110,0,100,2,1,254,244,255,98,0,189,255,177,0,70,251,222,0,167,254,243,0,130,206,40,254,26,1,155,247,175,2,185,245,82,17,77,0,247,253,108,254,90,252,212,0,73,253,143,254,114,4,68,5,119,252,245,1,43,1,29,215,250,3,50,3,149,7,31,0,1,1,195,4,176,3,99,255,176,7,143,249,130,255,72,254,169,253,255,255,46,24,14,10,180,254,241,2,195,0,125,255,84,23,215,254,160,2,170,255,113,255,209,254,5,0,135,255,102,255,155,253,165,21,20,250,208,254,194,3,69,0,191,248,46,16,122,255,194,2,128,3,54,251,121,255,202,254,211,219,111,4,147,242,108,2,34,3,223,255,186,253,117,7,127,5,242,0,39,10,3,250,233,254,68,3,134,31,73,251,113,22,200,0,179,255,162,0,13,3,46,254,237,249,225,12,67,252,225,0,10,5,7,0,165,2,41,0,219,253,38,245,120,5,123,1,217,242,113,1,103,2,254,230,15,2,58,0,47,22,142,255,76,255,26,11,88,0,205,245,206,255,115,1,161,0,68,254,14,8,218,255,16,1,142,222,1,3,18,0,223,245,30,255,9,254,65,252,241,250,189,0,141,254,93,253,8,250,158,255,2,2,44,251,116,0,202,0,94,53,60,6,184,254,61,0,239,13,26,254,12,243,231,222,195,254,52,11,93,254,239,255,23,2,59,252,9,254,248,240,174,8,108,2,52,249,2,0,105,25,217,1,215,254,186,255,227,11,205,255,16,250,225,3,22,4,173,7,168,12,179,7,196,255,118,253,203,255,8,255,180,238,147,254,117,241,98,4,111,249,93,6,78,5,239,255,112,4,0,255,40,9,230,254,156,0,127,0,101,255,62,1,255,250,214,251,57,0,135,252,3,255,140,250,189,253,104,252,18,252,14,220,65,253,195,0,66,20,241,0,206,6,228,3,118,0,151,5,63,17,108,246,181,26,8,251,199,253,157,13,72,1,185,1,64,3,41,2,94,0,136,2,92,0,134,254,159,43,7,3,201,1,176,6,232,255,173,3,57,21,147,249,118,8,249,0,201,255,232,248,127,1,223,2,148,252,187,1,200,253,37,1,14,251,51,27,78,255,82,255,94,251,95,4,48,255,53,3,219,5,40,250,133,247,154,5,106,3,133,0,214,226,223,253,145,8,249,252,131,250,75,251,193,253,52,248,123,253,216,253,249,254,157,34,251,253,76,0,32,252,22,1,113,9,167,250,35,0,75,250,137,250,5,2,185,0,177,244,91,1,225,240,60,14,28,1,212,12,244,255,87,255,67,248,172,4,189,255,52,11,142,3,134,0,238,253,150,0,208,250,110,7,22,253,95,1,34,255,10,2,186,233,29,3,148,248,241,0,222,8,252,2,177,254,68,5,163,254,16,3,206,249,231,253,148,0,139,12,100,249,56,0,142,6,191,254,222,254,222,30,69,0,52,0,54,1,81,1,250,0,84,2,14,39,80,1,13,4,163,0,64,0,71,254,78,11,247,251,218,2,50,253,28,251,203,1,125,255,160,30,102,252,213,253,39,22,43,1,177,2,91,4,122,253,7,254,249,254,96,2,18,254,0,0,186,1,246,248,170,253,67,253,168,239,70,0,217,250,166,255,195,35,173,254,0,0,121,0,206,1,223,2,129,253,225,1,125,0,12,27,51,13,171,2,237,11,61,251,13,254,43,4,108,255,111,245,245,255,27,3,139,6,130,3,226,0,208,4,49,0,196,253,163,219,175,8,181,3,255,2,203,252,165,255,51,4,160,254,107,225,42,2,175,253,4,5,11,255,215,4,142,4,123,251,102,235,40,3,103,3,90,250,151,29,115,254,13,253,240,2,97,16,179,0,51,255,219,255,18,253,141,245,105,254,68,253,220,0,179,255,68,6,63,0,205,1,246,216,123,253,163,249,103,0,64,2,132,0,21,39,207,255,19,252,97,0,184,249,3,2,246,255,110,255,170,248,112,3,173,1,9,251,228,3,147,254,76,0,103,254,157,9,29,0,135,4,217,0,160,231,56,255,22,253,118,0,164,248,201,1,208,252,160,253,143,12,244,0,237,2,220,8,20,255,4,251,234,254,112,5,25,249,231,4,62,250,56,224,108,5,254,252,225,0,69,254,10,0,120,254,147,2,162,251,141,249,254,253,89,252,145,255,88,4,205,3,9,255,21,255,46,205,31,253,40,0,115,255,47,20,114,252,23,1,45,254,78,241,79,3,161,240,250,3,130,7,62,3,190,0,253,0,150,251,97,254,115,1,206,2,249,14,12,4,18,235,96,252,98,3,254,253,164,10,50,9,193,1,210,0,182,5,168,2,168,248,194,255,236,42,41,3,166,253,145,0,232,253,114,0,109,255,200,253,121,12,190,254,124,3,131,253,155,250,191,255,249,2,79,6,161,19,185,254,77,19,137,253,151,235,180,4,226,11,230,3,233,251,65,252,150,255,74,6,105,255,120,0,128,251,191,0,30,0,187,46,101,0,18,0,102,254,248,250,114,1,253,252,57,5,224,253,155,253,33,1,139,255,89,6,102,238,22,10,102,249,151,255,52,235,163,255,29,1,113,251,20,242,39,253,74,237,83,2,19,1,40,255,39,255,144,232,170,2,85,255,149,252,224,0,92,255,103,11,28,3,175,255,154,5,186,0,137,254,239,239,77,255,21,1,83,5,59,254,201,9,132,1,208,248,91,255,64,237,214,255,24,230,54,0,33,253,215,253,113,249,149,3,254,255,136,253,161,1,34,254,18,254,247,254,73,0,140,254,152,254,179,0,64,254,9,1,43,1,104,255,45,255,186,49,179,255,162,7,234,253,5,3,12,2,182,1,109,7,195,238,154,254,16,6,8,255,204,249,134,255,129,255,29,21,226,0,175,252,185,226,155,254,167,255,185,0,234,2,83,3,157,2,49,1,9,255,129,13,63,255,95,255,126,2,88,2,98,2,87,3,244,250,142,1,248,5,202,8,115,6,34,223,251,2,249,5,166,254,185,14,145,255,162,230,91,1,26,253,149,7,175,7,70,2,133,234,3,253,206,252,58,7,188,249,13,255,81,252,245,255,116,3,76,244,185,246,242,3,138,254,205,25,225,254,47,236,211,0,10,253,191,2,209,245,235,2,126,255,83,254,79,246,30,19,55,254,153,12,190,3,85,33,30,2,33,24,211,251,70,251,61,252,201,232,170,255,144,5,201,253,59,3,2,254,79,230,254,254,252,255,178,238,115,0,25,21,110,5,98,1,219,6,26,252,84,3,225,3,31,254,218,0,37,252,11,3,95,254,79,2,123,23,16,2,33,1,176,254,210,253,60,0,164,35,82,255,235,0,17,255,112,255,252,254,112,242,234,2,173,18,140,2,33,237,29,253,235,255,96,3,250,246,140,2,235,27,116,0,194,254,206,255,99,242,187,254,167,254,104,233,120,4,95,9,93,250,223,3,242,246,239,252,231,254,49,255,88,250,53,1,233,3,184,3,192,5,243,232,244,252,101,246,238,5,150,38,51,251,158,2,245,253,193,4,92,255,201,255,161,255,243,0,229,30,86,0,228,238,165,252,169,253,73,255,221,246,6,3,70,251,10,254,125,252,53,0,15,4,34,0,183,225,216,254,97,248,49,238,158,4,106,255,62,11,210,236,201,10,55,250,0,8,40,10,16,7,119,244,47,247,62,0,162,0,91,4,214,0,98,238,158,3,243,229,163,5,132,255,193,0,198,254,46,1,187,2,238,255,233,2,85,1,127,3,153,253,217,254,75,255,143,0,85,254,128,25,50,4,154,251,118,1,214,254,6,251,22,0,119,3,1,254,223,251,156,12,210,2,95,2,112,2,161,255,77,43,238,3,236,252,227,254,164,255,62,5,187,254,196,252,42,0,252,241,137,253,192,253,207,17,100,253,242,250,203,6,161,6,121,253,32,9,120,1,136,255,70,5,134,2,187,254,95,0,86,23,7,3,199,0,147,222,163,3,176,254,117,253,207,253,79,254,38,247,127,255,111,253,96,251,67,0,65,2,105,2,88,7,40,2,90,0,151,253,239,254,221,249,199,226,5,1,230,255,236,255,53,254,252,251,57,0,188,222,213,255,214,10,1,0,114,239,168,2,18,243,200,255,104,255,36,2,65,248,152,3,131,3,132,8,205,254,74,247,107,249,26,252,43,8,144,255,21,0,241,249,158,4,249,25,186,254,24,3,26,7,84,226,51,2,52,4,254,28,116,252,244,5,33,255,166,22,38,5,208,242,5,2,66,16,244,2,210,239,240,6,134,1,78,1,212,255,218,0,170,20,24,3,39,0,156,6,30,2,194,255,173,253,78,2,27,0,218,34,221,3,182,0,213,2,112,0,202,1,46,220,24,252,152,4,246,250,133,250,42,253,102,23,215,254,210,4,68,249,167,253,16,2,48,4,184,0,110,255,61,0,173,2,184,4,168,255,45,255,100,1,97,37,149,254,121,255,97,255,219,251,151,255,102,254,198,255,79,1,254,216,212,254,45,255,95,2,187,1,102,254,62,249,184,254,19,1,67,2,37,3,131,3,48,254,238,255,40,1,66,254,92,9,243,255,158,1,66,218,127,254,216,252,181,248,154,0,196,253,23,13,209,248,176,255,133,4,186,254,225,1,111,34,241,251,41,4,62,8,199,4,64,252,223,255,48,254,228,233,234,1,198,254,90,1,218,2,125,254,178,251,0,26,49,253,107,251,199,255,94,251,90,9,236,250,103,253,182,253,217,255,185,255,155,0,160,4,4,0,59,243,179,254,21,253,68,2,23,1,185,253,252,27,71,255,110,0,161,9,172,1,251,1,110,17,147,238,199,0,81,1,243,241,7,255,186,255,88,253,83,234,253,5,149,3,209,254,242,219,81,254,132,255,5,252,113,1,139,0,87,5,151,0,233,251,164,26,105,255,222,0,138,244,207,252,203,3,99,227,44,2,11,4,40,251,43,12,210,250,172,15,252,10,33,4,20,10,251,254,149,15,207,7,88,6,98,9,202,254,11,3,158,254,135,254,107,255,11,4,197,246,102,1,82,14,10,255,152,248,119,1,79,15,144,250,171,2,112,2,16,233,132,2,135,1,32,1,58,255,19,255,68,0,228,254,88,0,8,252,250,0,32,0,164,4,13,255,160,253,192,254,37,255,177,212,31,2,156,0,10,4,87,255,73,255,219,253,190,255,204,2,228,3,96,252,203,254,201,21,229,0,125,0,208,250,67,35,70,253,27,254,98,249,71,3,87,1,193,1,119,6,237,3,29,4,104,254,146,35,186,0,158,2,6,3,58,1,61,2,48,15,142,252,26,0,214,9,235,253,61,255,43,2,81,1,10,255,229,213,25,255,31,0,198,254,83,252,105,4,77,1,177,226,168,0,217,253,237,0,97,255,47,17,165,1,181,2,198,0,60,255,207,253,11,4,220,253,34,4,15,2,33,14,151,254,37,5,73,248,178,245,82,248,136,255,188,254,46,22,52,247,105,253,181,0,239,254,255,243,230,254,146,253,107,1,71,0,184,0,248,252,28,1,20,250,82,254,3,0,169,3,139,33,2,1,220,251,237,249,194,252,174,254,62,1,86,220,146,255,203,1,196,253,70,0,93,0,120,0,234,253,16,5,88,255,29,0,110,252,180,254,27,252,206,252,14,1,13,255,11,2,56,0,185,209,64,254,11,0,102,255,164,0,67,8,243,255,133,253,196,2,105,253,43,0,8,255,84,243,254,0,19,0,155,251,252,1,154,0,249,33,191,0,83,2,41,17,10,245,88,255,132,248,137,1,136,15,129,3,76,249,221,255,76,255,93,2,223,251,86,251,100,0,128,254,219,255,149,255,179,10,49,255,243,26,176,0,81,0,123,252,0,5,122,249,155,255,25,1,123,4,48,0,21,0,105,255,44,251,210,0,98,0,142,255,195,253,4,31,103,255,210,254,205,250,81,1,190,254,198,25,221,1,147,0,25,252,162,243,24,255,16,236,225,252,182,248,198,255,139,239,96,5,181,0,163,2,50,2,126,0,235,0,212,8,224,235,13,255,69,253,60,250,39,16,57,2,55,2,225,2,189,239,101,2,223,251,242,6,34,2,62,254,232,255,69,1,110,1,102,9,217,250,60,0,250,235,49,0,145,2,207,232,62,255,114,3,195,12,178,0,214,254,81,7,134,48,203,1,16,1,195,0,221,248,212,0,222,252,218,2,215,1,20,6,166,1,128,2,236,0,71,0,85,2,151,22,2,21,119,253,244,5,61,3,181,1,161,254,134,255,136,250,71,8,128,255,75,0,115,249,135,253,190,254,18,231,195,253,50,252,136,6,134,254,14,255,124,14,79,0,211,250,141,1,106,255,185,7,186,1,235,2,129,255,22,0,80,235,97,254,50,255,50,1,9,1,189,0,120,1,209,2,33,250,83,254,230,253,136,232,159,255,127,254,198,253,199,254,67,250,37,255,131,249,10,0,112,24,50,251,133,253,228,255,144,239,168,254,138,1,138,0,150,4,86,255,202,252,114,0,193,251,155,255,62,227,84,0,94,3,234,5,85,1,141,255,64,1,136,255,167,249,55,0,49,253,163,5,35,253,191,253,29,28,148,0,26,0,120,0,177,7,76,19,63,241,161,253,139,6,64,0,134,253,172,255,78,1,226,26,124,253,24,255,144,19,196,254,92,255,118,255,240,255,15,0,225,36,182,255,191,255,6,1,66,3,119,4,155,255,178,1,183,254,123,0,52,255,211,255,147,0,22,238,26,253,208,1,132,5,36,2,190,249,200,255,76,5,253,252,7,1,197,2,31,254,63,255,89,1,53,223,215,255,36,0,148,248,78,255,48,3,90,226,31,0,61,244,141,254,118,245,186,8,157,255,0,0,202,2,179,252,141,36,189,2,11,251,69,255,125,239,62,254,183,255,155,249,71,18,118,255,138,238,100,1,136,5,182,5,166,243,197,1,195,255,123,20,15,255,175,246,182,1,55,19,4,255,59,241,150,0,79,1,58,0,71,255,78,7,179,0,192,0,244,245,58,254,77,0,211,18,99,7,21,237,198,247,40,254,254,240,167,0,68,4,97,253,194,0,154,252,139,0,141,255,57,254,196,1,249,253,43,1,0,4,74,1,157,255,181,43,82,0,57,0,175,252,167,0,162,239,127,2,0,3,53,29,114,2,94,0,21,251,209,254,181,0,232,254,57,11,179,253,51,254,55,6,227,255,28,27,16,251,120,0,230,254,97,255,85,241,252,255,195,255,68,216,152,0,244,255,56,255,111,0,233,222,13,255,144,1,182,252,125,6,229,243,244,1,61,254,89,254,63,255,230,0,167,1,7,1,147,19,242,3,20,4,83,237,195,2,84,0,53,232,43,255,73,20,178,1,22,2,76,4,248,253,202,249,75,0,190,254,2,0,216,7,234,253,153,0,81,10,230,5,82,229,10,255,4,0,15,1,75,0,228,250,114,248,255,254,92,26,77,2,211,254,115,2,173,4,124,14,98,17,50,234,224,250,213,244,113,3,173,1,40,2,226,2,142,252,216,3,232,1,156,252,48,254,199,228,209,2,226,247,161,1,23,232,72,255,128,255,96,225,99,10,232,245,2,255,176,0,234,252,41,253,226,1,101,1,104,0,71,254,98,255,44,252,211,17,254,239,62,4,63,251,206,253,241,7,0,2,117,223,78,242,183,255,40,3,140,254,190,249,236,2,143,3,169,253,37,250,58,0,53,1,240,216,141,255,70,0,67,6,24,1,110,255,207,252,5,2,18,0,75,5,135,255,218,239,152,0,236,250,247,0,90,28,159,1,130,0,229,255,60,8,81,1,208,252,176,9,140,1,21,2,66,0,85,255,187,231,47,0,9,12,120,253,94,252,18,7,23,255,79,254,180,253,150,21,58,0,238,255,86,242,131,254,73,31,7,0,205,4,152,0,102,254,201,253,167,1,158,254,207,1,174,255,110,255,204,244,15,1,115,233,134,10,18,252,150,0,143,255,247,253,249,9,234,254,81,2,187,255,139,230,239,252,113,1,77,246,40,255,184,243,135,252,188,6,88,255,97,231,171,0,153,248,226,252,119,255,84,255,22,253,202,255,162,0,161,253,153,1,201,0,228,254,113,255,71,214,67,30,132,251,47,1,58,0,4,0,160,255,27,254,110,255,226,254,191,253,124,253,0,254,236,0,64,2,165,1,93,0,37,1,44,40,254,255,139,255,178,253,222,253,94,1,189,1,211,254,212,254,71,42,32,255,160,255,217,253,108,255,18,4,131,255,224,0,62,253,135,33,61,255,52,0,84,245,200,0,67,17,134,1,102,3,100,0,72,255,233,0,35,24,195,254,40,254,172,7,210,254,238,221,205,9,124,253,232,1,227,243,123,3,3,255,218,255,133,0,241,255,171,250,245,252,156,253,161,2,211,21,66,3,121,1,67,3,30,248,75,0,71,255,57,14,121,0,181,2,63,0,247,1,134,2,249,255,92,1,141,0,225,250,20,2,255,253,95,0,197,254,191,255,178,230,240,255,176,252,46,255,136,255,164,2,5,20,21,2,51,16,146,253,252,255,106,255,29,250,132,255,71,255,245,20,11,1,49,4,129,238,173,0,52,255,188,239,72,252,233,255,8,240,111,5,205,0,200,2,39,254,139,254,35,2,83,253,190,17,207,255,185,255,33,0,241,254,132,0,246,0,68,255,6,0,203,254,118,0,96,0,238,6,158,0,173,255,11,242,151,4,134,255,37,230,115,249,119,251,246,254,168,18,125,13,62,0,166,254,62,254,156,250,103,0,55,254,20,251,185,255,175,16,174,254,142,250,62,25,139,1,135,2,126,9,33,253,188,1,45,7,147,1,144,0,59,234,211,0,0,18,241,255,36,3,70,0,177,7,133,242,118,255,160,254,152,4,85,255,250,253,142,255,168,255,79,1,204,254,192,255,84,254,237,239,62,1,51,255,130,255,82,225,159,253,105,0,144,0,14,1,10,1,65,238,130,235,201,254,75,2,49,1,141,255,116,1,215,2,218,254,158,1,109,3,37,225,155,1,230,253,138,1,23,2,233,0,198,252,73,1,235,1,16,237,118,253,75,1,2,4,116,255,74,25,194,0,55,254,98,0,153,252,11,247,105,3,97,1,44,3,158,17,78,4,123,1,139,2,42,255,146,255,20,0,67,245,152,224,160,255,221,0,221,0,217,255,188,1,232,254,254,10,232,253,181,13,111,0,62,3,82,2,41,2,47,0,252,10,150,248,203,0,159,254,196,255,115,1,181,0,56,3,184,234,41,1,220,1,42,0,123,255,97,0,169,1,138,33,195,254,121,0,197,1,246,3,162,254,175,0,235,2,178,255,225,254,56,233,113,2,74,16,204,254,61,7,30,11,253,255,148,252,23,2,175,1,101,254,165,247,123,232,118,1,42,1,36,6,19,0,27,240,31,6,144,0,3,0,165,21,74,254,152,3,87,0,192,6,230,0,39,3,216,22,99,254,7,0,159,231,214,0,205,0,32,5,93,253,70,0,8,1,114,0,232,255,30,254,184,255,216,254,71,1,249,0,39,43,62,43,18,0,87,252,94,1,22,0,106,1,43,2,47,3,130,0,131,255,63,238,102,10,203,0,194,254,207,254,67,1,121,2,160,1,2,255,45,1,99,0,151,1,169,236,158,18,234,252,54,5,144,3,234,251,162,254,121,255,160,14,22,0,145,249,90,254,105,255,143,255,126,255,167,254,254,255,249,254,18,0,232,255,253,252,222,255,225,253,19,40,183,0,0,0,207,6,243,4,6,246,64,1,99,2,216,251,90,250,107,3,216,252,1,19,208,252,124,13,68,0,70,1,78,255,177,0,246,255,118,255,223,255,163,255,65,0,8,1,185,0,99,255,139,233,110,0,151,1,216,4,70,253,195,255,176,0,21,6,132,232,162,253,213,253,202,1,154,12,85,252,165,3,153,0,224,255,160,3,69,0,22,254,249,249,169,255,236,255,60,255,185,254,167,1,231,30,67,255,178,0,79,1,62,255,203,1,180,214,60,255,174,0,226,254,246,1,239,251,12,0,39,0,155,255,113,240,142,249,170,244,130,1,105,255,27,4,149,253,198,26,80,13,116,4,194,248,13,253,216,255,172,251,34,250,221,0,115,254,119,1,57,4,135,40,133,1,14,1,17,255,55,1,44,255,128,1,213,4,121,244,199,0,161,20,200,255,34,0,64,253,174,3,145,4,33,0,202,254,97,0,64,251,207,11,188,252,184,12,148,1,111,15,255,254,91,8,111,0,179,0,63,32,99,2,16,255,4,255,145,254,5,255,216,254,22,247,189,3,61,0,247,254,208,2,232,0,34,0,146,0,204,0,222,254,61,217,17,2,65,0,184,2,142,11,96,1,244,240,224,4,25,253,117,254,81,23,92,0,124,255,74,251,58,1,83,240,205,2,37,20,254,252,170,248,79,251,66,252,13,2,188,15,116,0,116,26,211,255,194,251,177,254,183,22,51,0,57,0,171,255,3,247,123,255,212,254,7,0,227,0,101,13,205,251,255,238,192,252,30,0,235,4,28,254,195,1,92,2,51,253,109,26,38,1,118,0,102,254,43,1,80,2,251,240,66,0,10,254,128,220,182,255,3,1,194,1,219,1,202,0,0,249,23,0,111,18,197,2,114,254,116,249,161,254,126,252,146,253,145,0,144,250,137,28,246,3,176,255,7,2,239,247,251,5,92,3,88,250,134,0,147,6,177,2,11,28,167,254,185,254,236,3,93,246,172,254,234,250,193,22,117,1,50,0,140,26,58,1,13,0,242,254,86,254,190,2,23,1,216,238,4,254,135,230,60,0,234,254,175,9,79,3,152,254,188,255,100,248,91,0,201,3,165,1,203,1,171,254,132,23,218,253,179,255,81,253,14,253,5,0,109,0,154,1,108,42,73,255,195,254,34,253,169,255,245,1,167,253,158,0,204,22,223,251,212,4,174,252,149,11,182,254,35,2,225,4,12,245,127,0,218,0,57,254,219,252,94,240,108,0,199,253,148,2,20,235,189,251,69,2,67,254,201,254,9,25,254,1,123,229,7,2,71,6,40,1,86,1,112,1,96,250,178,252,205,7,29,255,28,9,242,247,207,237,6,4,202,20,135,0,131,0,170,242,64,1,6,4,243,242,0,255,139,254,43,238,198,4,171,0,148,236,92,250,47,1,205,234,179,1,208,0,251,0,211,1,27,2,136,0,199,0,84,221,61,255,253,252,232,243,228,2,112,1,23,4,22,254,83,0,229,1,168,0,19,2,133,253,223,252,71,252,4,0,161,255,77,226,197,255,231,7,227,2,66,253,7,1,242,219,199,254,27,252,2,254,252,252,156,0,146,15,143,255,142,1,214,245,201,251,195,0,45,255,128,0,125,7,221,0,59,252,11,0,71,0,155,255,180,0,220,255,159,30,112,255,46,253,32,1,173,1,72,22,40,252,2,254,7,3,184,1,199,248,188,250,197,7,44,1,43,0,136,7,245,16,0,241,133,246,233,7,108,253,219,254,23,0,7,255,79,255,185,254,78,225,33,0,245,0,202,250,237,0,81,253,240,10,30,0,153,221,108,254,43,0,183,0,33,1,16,2,254,1,59,255,78,2,162,255,209,234,125,1,37,5,141,0,153,249,80,254,52,226,32,255,56,0,148,225,113,0,134,0,69,27,132,253,244,2,25,253,97,0,159,0,239,4,113,255,131,244,136,245,33,254,115,5,125,249,40,254,32,252,61,254,180,233,166,16,78,1,237,11,76,0,184,253,169,253,236,254,190,13,8,1,186,247,102,1,150,255,143,3,189,19,224,1,186,17,181,3,83,20,153,255,242,255,177,0,187,242,55,0,99,229,168,2,4,249,145,0,219,8,80,4,235,252,54,0,5,1,228,0,118,21,15,0,32,255,192,0,228,2,0,0,208,29,142,1,63,11,174,1,236,223,111,253,47,3,28,255,24,254,166,255,240,250,83,2,163,11,241,255,215,15,4,255,213,240,89,252,26,226,74,1,97,0,40,216,206,1,223,0,7,252,203,254,170,254,132,255,22,251,211,0,95,1,60,1,158,1,165,255,238,255,54,255,182,255,154,1,137,212,70,1,5,1,91,1,241,234,106,0,156,0,74,255,220,255,177,0,145,1,188,2,12,2,193,250,110,254,186,228,63,0,194,0,242,255,82,0,220,255,91,253,119,254,187,0,196,28,5,254,107,251,9,253,81,241,40,253,154,11,54,5,32,0,214,250,107,244,156,0,185,252,126,1,18,231,107,255,106,3,72,5,221,255,13,254,99,0,87,254,210,243,224,255,196,249,232,21,202,252,215,255,158,11,176,253,103,2,241,6,60,9,69,20,181,239,187,253,168,3,241,253,62,1,186,249,217,253,230,20,64,254,216,255,52,29,189,0,63,1,146,250,10,0,103,252,32,39,61,2,215,251,61,3,90,251,234,255,89,239,87,0,50,249,187,254,57,1,68,255,28,2,90,234,68,255,255,1,88,255,250,253,17,0,152,0,174,7,248,245,164,252,175,10,70,251,148,1,112,255,39,229,127,255,178,1,94,244,13,11,208,255,20,220,219,248,3,212,212,5,182,236,10,7,93,0,128,1,60,5,236,0,82,39,219,2,93,3,61,255,109,226,179,255,31,254,68,253,86,18,34,253,83,231,25,1,237,6,175,0,97,234,20,2,31,0,100,27,131,253,254,241,72,4,12,14,59,255,99,225,157,253,33,7,230,255,253,254,3,9,12,0,217,2,90,248,156,0,6,1,118,21,26,0,96,233,182,243,194,1,205,251,41,1,253,1,154,0,156,2,191,0,244,254,207,249,113,1,34,5,75,253,165,2,202,5,198,0,122,1,80,43,173,255,17,9,63,255,198,251,19,244,20,0,241,254,175,50,16,1,90,4,220,1,226,252,203,254,97,255,30,21,147,255,93,253,109,2,252,245,182,43,194,250,168,255,172,1,47,254,231,237,9,254,106,0,24,219,58,254,228,255,110,254,247,4,220,224,242,2,49,255,69,246,6,2,139,241,226,253,12,251,151,253,79,255,211,1,126,255,222,3,247,15,89,3,244,253,66,233,145,0,217,0,233,225,237,254,247,25,175,255,38,2,119,3,79,254,222,252,20,2,131,2,188,0,173,7,104,252,228,254,127,14,172,4,64,221,155,254,142,253,140,3,228,254,62,253,210,249,182,0,25,30,118,255,188,246,98,255,136,252,151,16,29,17,190,229,173,249,238,248,120,2,104,251,194,255,165,16,167,255,9,1,125,5,87,250,123,254,100,228,2,1,12,255,240,254,43,224,37,0,55,254,121,221,171,12,61,239,116,254,161,240,139,3,198,255,84,9,116,252,71,251,133,253,25,254,75,249,77,27,30,237,88,8,202,252,69,253,139,8,160,255,209,217,120,242,27,3,122,2,201,252,99,253,146,0,181,252,15,0,29,255,159,2,61,253,236,216,198,0,81,0,181,249,222,255,177,247,175,246,79,253,110,2,42,7,193,255,195,236,41,255,99,251,254,253,21,30,95,2,238,7,248,254,175,9,145,3,178,0,41,14,62,255,101,2,109,3,128,254,204,225,240,3,69,8,16,2,211,254,28,2,176,255,47,2,28,0,118,29,16,254,122,4,83,230,79,250,109,30,29,255,121,249,180,255,141,254,159,252,115,255,42,0,96,0,21,1,102,254,26,234,72,1,6,221,34,255,0,249,213,3,136,255,118,253,221,8,124,250,14,4,70,255,174,222,248,254,236,8,41,253,231,5,253,237,139,249,193,7,206,255,231,220,11,255,13,243,151,1,109,252,233,255,186,255,30,0,99,253,209,254,134,3,84,0,177,1,217,0,145,223,167,30,183,248,88,253,254,0,218,255,108,1,16,0,50,0,90,0,234,253,215,237,224,252,201,3,199,251,198,1,147,0,194,255,93,34,84,0,112,252,250,253,161,254,76,0,208,253,98,250,117,2,0,64,144,2,151,0,112,3,140,1,166,255,240,2,118,255,163,252,133,37,2,1,72,254,215,230,178,1,133,22,26,1,214,5,252,254,76,255,255,252,187,30,170,255,24,2,250,254,26,255,4,221,225,22,177,253,253,5,162,1,7,254,100,255,141,4,159,1,88,255,32,250,176,254,101,253,15,2,93,22,42,0,173,1,155,6,1,0,85,0,60,255,97,14,36,0,213,1,148,254,47,2,142,3,200,248,3,1,249,0,104,249,5,1,220,255,176,253,100,255,187,255,206,232,76,255,218,254,22,0,121,252,109,5,245,18,121,0,65,20,202,3,186,4,49,2,158,3,216,1,73,255,223,25,101,1,178,255,11,233,91,0,68,255,166,229,110,255,86,1,240,233,113,14,56,5,216,2,187,255,142,1,107,10,201,247,109,7,217,252,2,1,72,0,119,255,85,1,71,0,87,255,152,255,173,255,206,0,92,254,163,4,232,2,120,0,225,235,194,253,72,0,151,222,200,254,140,0,187,255,179,23,109,20,202,0,70,249,92,255,73,0,159,6,216,251,234,0,24,0,17,19,175,252,52,254,193,33,184,254,63,251,130,6,229,254,180,255,212,10,145,1,75,3,108,237,41,1,145,33,111,1,36,253,31,255,58,255,160,240,248,0,76,254,217,1,237,255,71,254,164,0,220,0,246,254,3,0,106,0,12,255,74,233,85,2,102,253,11,255,174,219,157,252,32,254,24,1,216,255,117,255,22,231,148,236,138,252,246,11,235,2,57,248,124,249,89,254,22,2,98,3,183,255,155,230,61,255,68,1,205,255,133,255,42,1,244,1,193,0,22,1,201,222,215,254,10,4,240,255,47,255,27,29,9,2,207,254,215,254,255,249,47,244,177,2,248,0,63,1,17,21,217,5,180,8,251,252,115,255,136,8,0,4,73,238,56,220,168,253,92,252,159,247,229,253,204,1,105,248,169,16,48,246,64,17,208,254,208,6,233,1,150,254,130,3,188,8,80,247,49,0,64,255,76,1,110,1,113,255,73,1,189,225,252,255,51,4,116,0,39,2,19,0,249,255,178,27,87,255,69,3,185,255,141,254,195,1,225,255,218,1,99,3,91,254,64,238,78,0,136,12,219,253,192,7,106,5,96,247,134,250,80,6,189,0,219,255,215,228,155,233,53,6,222,250,16,4,56,250,24,234,67,10,189,13,250,0,250,30,94,0,79,18,242,5,167,21,126,255,50,254,189,29,114,253,135,2,213,231,139,0,86,1,205,19,39,253,128,0,17,0,207,255,176,0,122,0,58,3,247,1,76,0,60,255,223,60,84,50,234,2,154,240,46,3,48,249,238,6,174,254,17,12,98,249,47,2,21,235,18,11,88,250,108,0,183,254,57,253,94,1,171,0,41,1,133,255,160,2,113,2,4,233,166,26,74,3,20,1,242,0,50,247,145,253,178,252,137,9,119,3,238,247,5,252,49,5,107,0,173,255,58,3,189,255,160,254,37,2,137,0,1,252,72,255,245,255,222,53,48,0,115,3,210,13,235,253,79,234,93,3,226,2,76,254,117,235,190,255,107,254,193,14,194,253,226,2,253,0,107,1,180,255,32,1,68,1,175,254,157,0,137,255,159,255,171,0,2,2,116,248,205,235,67,2,249,0,48,4,52,255,62,255,201,254,143,2,184,229,186,0,78,255,99,0,117,22,183,254,163,1,156,3,149,251,86,2,241,255,153,255,27,247,186,0,52,253,226,253,153,0,30,255,57,22,219,0,52,0,122,14,107,252,140,0,176,214,105,255,36,4,133,2,148,1,30,5,75,1,216,0,123,250,114,232,51,236,104,240,86,5,164,3,23,6,169,255,119,30,14,15,178,14,237,251,218,1,160,4,102,0,41,245,81,251,201,251,102,1,193,255,56,38,141,0,107,15,194,0,124,255,180,254,0,254,44,255,49,233,29,255,79,30,39,3,171,253,10,249,108,255,160,254,55,251,76,253,147,0,78,248,180,13,77,252,135,13,59,255,129,18,70,253,66,2,84,255,249,252,231,31,30,12,115,3,110,252,16,0,59,3,114,0,132,248,115,252,162,253,87,0,12,4,77,254,102,0,96,0,142,254,52,255,80,209,21,0,221,1,5,5,137,24,87,3,219,225,131,4,11,254,171,253,55,23,145,0,138,253,178,242,13,0,141,239,167,2,170,25,25,255,102,232,9,254,62,255,157,5,8,22,58,251,245,31,130,1,38,252,9,254,197,4,71,3,251,2,235,254,5,249,45,250,5,0,50,255,42,0,240,10,180,254,231,244,113,255,56,254,134,2,100,253,139,255,115,3,86,0,199,27,242,254,112,2,147,251,204,254,33,254,67,220,112,250,242,0,240,208,8,0,3,9,126,230,239,253,206,1,190,250,103,255,219,16,74,255,93,253,178,255,32,254,207,255,142,1,104,254,96,250,4,32,180,1,207,253,72,255,175,0,7,7,102,255,73,254,47,253,122,8,66,1,155,25,229,253,120,249,139,253,87,244,239,0,219,255,120,29,232,251,39,251,73,28,132,253,252,7,18,253,182,4,83,5,238,253,184,232,86,1,240,226,104,2,116,1,220,17,138,255,87,1,62,4,58,2,92,255,41,2,79,254,50,2,33,0,33,32,21,255,22,255,206,4,234,0,138,3,51,2,183,255,224,40,159,254,124,253,83,250,95,4,237,0,158,2,144,255,171,27,61,254,82,13,151,255,172,12,205,250,102,0,226,2,238,241,76,0,157,1,194,254,10,0,161,234,0,4,177,254,246,0,116,225,92,255,211,9,125,250,161,2,134,23,50,0,197,229,12,1,104,8,73,252,196,255,234,0,219,247,86,1,186,11,87,255,169,9,101,253,66,229,102,3,91,21,150,0,190,255,58,239,213,254,156,253,237,240,177,0,97,1,138,237,35,2,84,1,242,233,26,248,117,0,171,236,209,254,24,1,246,254,151,254,161,2,117,255,251,255,45,228,248,254,243,0,131,235,95,1,144,2,141,19,170,2,149,255,42,1,177,255,127,5,63,254,227,252,99,253,216,253,14,255,179,224,56,0,252,15,47,6,115,240,207,255,220,224,134,1,110,1,225,255,102,4,16,1,0,20,246,255,123,4,158,241,101,255,252,0,163,0,199,1,102,1,22,253,97,245,81,254,188,1,79,254,176,1,155,254,250,20,72,1,253,255,212,6,2,2,30,28,241,253,172,0,145,1,197,255,254,241,163,5,22,2,5,4,27,2,139,14,16,21,37,230,1,246,40,9,26,1,44,252,97,0,195,254,238,252,219,1,58,222,51,1,191,1,221,243,211,0,200,255,16,13,243,249,249,219,198,1,96,1,229,255,205,0,247,1,4,1,140,254,137,253,115,251,113,230,188,1,255,5,148,1,40,249,213,255,91,219,242,2,162,255,34,228,16,8,170,0,30,32,232,254,30,251,165,254,152,6,77,251,239,0,232,251,38,238,144,237,78,254,16,252,201,239,93,247,122,250,6,254,221,234,3,21,216,3,235,17,193,255,143,0,200,3,53,255,195,20,79,2,12,253,204,4,140,254,191,2,173,26,180,255,23,27,211,1,47,12,254,255,15,241,175,0,96,240,60,244,191,225,192,252,234,245,173,0,200,7,184,14,19,1,39,0,91,2,232,253,219,22,218,1,254,0,184,255,6,5,188,252,200,21,77,5,196,13,150,1,2,220,214,253,134,15,160,254,227,6,30,254,146,2,92,6,45,15,146,7,28,24,157,6,193,235,150,0,183,229,214,4,38,4,205,216,84,254,48,0,165,1,71,255,147,2,86,254,135,253,131,0,27,253,206,1,49,254,121,254,63,255,242,254,86,253,169,254,158,208,170,255,108,255,0,1,1,1,1,1,1,2,2,2,2,3,3,3,4,4,5,5,5,6,7,7,8,8,9,10,11,11,12,13,13,14,15,15,16,17,17,18,19,19,20,21,22,22,23,24,25,26,27,27,28,29,30,31,32,33,34,35,36,37,37,38,39,40,41,41,42,43,44,45,45,46,47,48,49,50,51,52,52,53,54,55,55,56,57,57,58,59,59,60,60,60,61,61,61,62,0,1,1,1,1,1,1,2,2,2,2,3,3,3,4,4,4,5,5,5,6,6,7,7,8,8,9,10,10,11,11,12,13,13,14,15,16,17,17,18,19,19,20,21,21,22,22,23,23,24,24,25,25,25,26,26,26,26,27,27,27,27,27,28,28,28,28,28,28,29,29,29,29,29,29,29,29,30,0,0,120,76,31,0,184,154,30,0,4,0,0,0,5,0,0,0,184,7,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,184,152,29,0,184,154,30,0,4,0,0,0,5,0,0,0,184,7,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,151,34,0,108,0,0,0,248,45,7,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,67,31,0,192,145,30,0,28,0,0,0,5,0,0,0,16,255,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,145,29,0,192,145,30,0,28,0,0,0,5,0,0,0,16,255,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,232,51,29,0,192,145,30,0,28,0,0,0,5,0,0,0,16,255,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,136,227,28,0,0,0,0,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,32,223,35,0,112,143,35,0,20,0,0,0,1,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,80,33,0,108,0,0,0,184,46,7,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,83,34,0,108,0,0,0,144,121,9,0,100,66,52], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+460817);
/* memory initializer */ allocate([7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,29,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,2,33,0,168,236,31,0,4,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,16,0,1,0,168,2,33,0,184,27,31,0,120,109,30,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,2,33,0,48,228,29,0,72,120,29,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,2,33,0,88,32,29,0,16,207,28,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,2,33,0,240,203,35,0,48,120,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,2,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,29,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,253,31,0,108,0,0,0,176,48,7,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,179,33,0,176,237,32,0,28,0,0,0,5,0,0,0,16,255,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,145,29,0,176,237,32,0,28,0,0,0,5,0,0,0,16,255,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,232,51,29,0,176,237,32,0,28,0,0,0,5,0,0,0,16,255,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,192,210,32,0,0,0,0,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,32,223,35,0,112,143,35,0,20,0,0,0,1,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,254,33,0,108,0,0,0,120,50,7,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,253,28,0,2,80,1,0,1,0,0,0,8,98,34,0,3,80,1,0,1,0,0,0,216,93,34,0,4,80,1,0,1,0,0,0,136,89,34,0,41,80,1,0,1,0,0,0,216,85,34,0,28,0,0,0,0,0,0,0,192,81,34,0,53,54,50,72,0,0,0,0,112,77,34,0,50,80,1,0,1,0,0,0,240,73,34,0,13,0,0,0,0,0,0,0,184,253,34,0,1,80,1,0,1,0,0,0,248,68,34,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,2,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,9,0,0,202,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,2,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,188,34,0,108,0,0,0,240,124,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,255,0,0,0,0,88,19,31,0,0,5,31,0,4,0,0,0,5,0,0,0,144,244,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,120,230,30,0,0,5,31,0,4,0,0,0,5,0,0,0,144,244,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,32,217,30,0,80,202,30,0,60,6,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,184,127,31,0,80,202,30,0,60,6,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,98,33,0,108,0,0,0,136,54,7,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,3,3,2,3,0,0,0,0,0,0,0,192,179,35,0,108,0,0,0,224,62,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,7,0,0,0,6,0,0,0,1,0,0,0,8,107,16,0,224,190,13,0,128,74,18,0,32,56,18,0,8,107,16,0,192,74,18,0,32,191,13,0,96,180,13,0,176,190,13,0,192,74,18,0,128,74,18,0,128,74,18,0,128,74,18,0,128,74,18,0,128,74,18,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,4,5,7,8,0,0,0,0,176,58,178,58,180,58,182,58,184,58,186,58,188,58,190,58,192,58,194,58,196,58,198,58,200,58,202,58,204,58,206,58,208,58,210,58,212,58,214,58,216,58,218,58,220,58,222,58,224,58,226,58,228,58,230,58,232,58,234,58,236,58,238,58,240,58,242,58,244,58,246,58,248,58,250,58,252,58,254,58,64,5,66,5,68,5,70,5,72,5,74,5,76,5,78,5,88,5,94,5,173,2,84,1,84,7,168,3,86,0,40,0,232,0,74,0,11,0,59,0,19,0,3,0,15,0,5,0,1,0,6,0,0,0,8,0,28,0,4,0,36,0,75,0,233,0,41,0,87,0,169,3,85,7,85,1,174,2,95,5,89,5,79,5,77,5,75,5,73,5,71,5,69,5,67,5,65,5,255,58,253,58,251,58,249,58,247,58,245,58,243,58,241,58,239,58,237,58,235,58,233,58,231,58,229,58,227,58,225,58,223,58,221,58,219,58,217,58,215,58,213,58,211,58,209,58,207,58,205,58,203,58,201,58,199,58,197,58,195,58,193,58,191,58,189,58,187,58,185,58,183,58,181,58,179,58,177,58,96,15,98,15,100,15,102,15,104,15,106,15,108,15,110,15,112,15,114,15,116,15,118,15,120,15,122,15,124,15,126,15,128,15,130,15,132,15,134,15,136,15,138,15,140,15,142,15,144,15,146,15,148,15,150,15,152,15,154,15,156,15,158,15,160,15,162,15,164,15,166,15,168,15,170,15,172,15,174,15,176,15,178,15,180,15,182,15,184,15,186,15,188,15,190,15,160,7,162,7,210,3,234,1,252,0,127,0,28,0,12,0,4,0,52,0,16,0,27,0,9,0,11,0,14,0,1,0,3,0,2,0,15,0,12,0,10,0,0,0,17,0,53,0,5,0,13,0,29,0,60,0,253,0,235,1,211,3,163,7,161,7,191,15,189,15,187,15,185,15,183,15,181,15,179,15,177,15,175,15,173,15,171,15,169,15,167,15,165,15,163,15,161,15,159,15,157,15,155,15,153,15,151,15,149,15,147,15,145,15,143,15,141,15,139,15,137,15,135,15,133,15,131,15,129,15,127,15,125,15,123,15,121,15,119,15,117,15,115,15,113,15,111,15,109,15,107,15,105,15,103,15,101,15,99,15,97,15,208,81,210,81,212,81,214,81,216,81,218,81,220,81,222,81,224,81,226,81,228,81,230,81,232,81,234,81,236,81,238,81,240,81,242,81,244,81,246,81,248,81,250,81,252,81,254,81,192,112,194,112,196,112,198,112,200,112,202,112,204,112,206,112,236,112,234,16,104,56,119,56,118,8,53,28,52,4,52,10,27,14,27,2,27,5,15,7,15,1,128,3,128,0,64,1,193,1,65,0,161,0,226,0,34,0,82,0,114,0,18,0,42,0,58,0,10,0,22,0,30,0,6,0,12,0,0,0,4,0,1,0,13,0,7,0,31,0,23,0,11,0,59,0,43,0,19,0,115,0,83,0,35,0,227,0,162,0,66,0,194,1,65,1,129,0,129,3,140,2,12,1,28,5,28,2,28,14,53,10,53,4,58,28,119,8,116,8,105,56,235,16,237,112,207,112,205,112,203,112,201,112,199,112,197,112,195,112,193,112,255,81,253,81,251,81,249,81,247,81,245,81,243,81,241,81,239,81,237,81,235,81,233,81,231,81,229,81,227,81,225,81,223,81,221,81,219,81,217,81,215,81,213,81,211,81,209,81,100,111,102,111,104,111,106,111,108,111,110,111,112,111,114,111,116,111,118,111,120,111,122,111,124,111,126,111,128,111,130,111,132,111,134,111,136,111,138,111,140,111,142,111,144,111,146,111,148,111,150,111,152,111,154,111,156,111,158,111,160,111,162,111,164,111,166,111,168,111,170,111,172,111,174,111,176,111,178,111,180,111,182,111,180,23,220,55,219,11,239,27,238,5,248,13,248,2,253,6,125,1,127,3,191,0,64,0,192,0,33,0,97,0,17,0,49,0,9,0,25,0,6,0,14,0,4,0,0,0,5,0,15,0,7,0,26,0,10,0,54,0,22,0,110,0,46,0,193,0,65,0,188,1,188,0,122,3,122,1,249,2,249,13,239,5,236,5,216,27,221,55,181,23,183,111,181,111,179,111,177,111,175,111,173,111,171,111,169,111,167,111,165,111,163,111,161,111,159,111,157,111,155,111,153,111,151,111,149,111,147,111,145,111,143,111,141,111,139,111,137,111,135,111,133,111,131,111,129,111,127,111,125,111,123,111,121,111,119,111,117,111,115,111,113,111,111,111,109,111,107,111,105,111,103,111,101,111,84,223,86,223,200,223,202,223,204,223,206,223,208,223,210,223,212,223,214,223,216,223,218,223,220,223,222,223,224,223,226,223,232,15,234,47,168,111,246,111,245,7,247,7,210,55,249,55,248,3,248,11,251,11,235,27,250,1,250,5,250,9,250,13,255,13,255,0,255,2,251,6,124,0,124,1,124,2,127,2,60,0,188,0,60,1,188,1,28,0,92,0,156,0,220,0,12,0,44,0,76,0,108,0,4,0,20,0,36,0,52,0,0,0,8,0,16,0,24,0,30,0,2,0,6,0,10,0,14,0,11,0,7,0,3,0,31,0,25,0,17,0,9,0,1,0,53,0,37,0,21,0,5,0,109,0,77,0,45,0,13,0,221,0,157,0,93,0,29,0,189,1,61,1,189,0,61,0,124,3,125,2,125,1,125,0,252,6,252,4,252,2,252,0,251,13,251,9,251,5,251,1,248,27,232,27,249,11,249,3,250,55,211,55,244,23,246,7,247,111,169,111,235,47,233,15,227,223,225,223,223,223,221,223,219,223,217,223,215,223,213,223,211,223,209,223,207,223,205,223,203,223,201,223,87,223,85,223,0,0,0,0,0,0,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,13,13,13,13,13,13,13,13,13,13,12,11,11,10,9,8,8,7,6,6,5,4,4,3,2,3,3,4,5,5,6,7,8,8,9,10,11,11,12,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,14,14,13,12,11,10,8,7,6,6,5,5,4,4,4,3,3,3,4,4,4,4,5,6,6,7,8,9,11,12,13,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,14,14,14,13,13,12,12,12,11,11,11,10,10,9,9,9,8,8,8,7,7,7,6,6,6,5,5,5,4,4,3,3,3,4,4,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,12,12,12,13,13,13,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,14,14,13,13,12,12,11,11,10,10,9,8,8,7,7,6,6,5,5,4,4,3,2,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,12,12,12,13,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,15,15,15,14,14,14,14,13,13,13,13,12,12,12,12,12,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,5,4,4,4,4,4,4,4,5,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,255,255,255,127,1,0,0,0,255,255,255,127,1,0,0,0,255,255,255,127,2,0,0,0,255,255,255,127,2,0,0,0,255,255,255,127,2,0,0,0,255,255,255,127,2,0,0,0,85,85,85,85,2,0,0,0,85,85,85,85,2,0,0,0,85,85,85,85,2,0,0,0,255,255,255,127,3,0,0,0,255,255,255,127,3,0,0,0,102,102,102,102,3,0,0,0,85,85,85,85,3,0,0,0,73,146,36,73,3,0,0,0,73,146,36,73,3,0,0,0,255,255,255,127,4,0,0,0,102,102,102,102,4,0,0,0,209,69,23,93,4,0,0,0,85,85,85,85,4,0,0,0,73,146,36,73,4,0,0,0,255,255,255,127,5,0,0,0,113,28,199,113,5,0,0,0,102,102,102,102,5,0,0,0,100,33,11,89,5,0,0,0,78,236,196,78,5,0,0,0,68,68,68,68,5,0,0,0,120,120,120,120,6,0,0,0,242,26,202,107,6,0,0,0,209,69,23,93,6,0,0,0,30,133,235,81,6,0,0,0,73,146,36,73,6,0,0,0,255,255,255,127,7,0,0,0,113,28,199,113,7,0,0,0,62,6,231,99,7,0,0,0,129,5,22,88,7,0,0,0,236,115,72,77,7,0,0,0,68,68,68,68,7,0,0,0,120,120,120,120,8,0,0,0,155,6,180,105,8,0,0,0,209,69,23,93,8,0,0,0,30,133,235,81,8,0,0,0,4,222,126,72,8,0,0,0,128,127,128,127,9,0,0,0,14,28,56,112,9,0,0,0,1,58,255,98,9,0,0,0,174,32,38,87,9,0,0,0,181,115,189,76,9,0,0,0,175,213,179,67,9,0,0,0,114,7,40,119,10,0,0,0,105,144,6,105,10,0,0,0,253,161,144,92,10,0,0,0,31,47,131,81,10,0,0,0,247,17,220,71,10,0,0,0,182,189,163,126,11,0,0,0,161,246,140,111,11,0,0,0,84,63,65,98,11,0,0,0,209,196,146,86,11,0,0,0,237,25,75,76,11,0,0,0,169,102,55,67,11,0,0,0,61,214,116,118,12,0,0,0,229,79,91,104,12,0,0,0,235,181,242,91,12,0,0,0,15,55,2,81,12,0,0,0,211,219,94,71,12,0,0,0,216,57,194,125,13,0,0,0,12,217,203,110,13,0,0,0,133,253,161,97,13,0,0,0,201,244,4,86,13,0,0,0,147,59,201,75,13,0,0,0,217,113,197,66,13,0,0,0,174,75,165,117,14,0,0,0,42,187,167,103,14,0,0,0,117,206,82,91,14,0,0,0,146,45,118,80,14,0,0,0,45,145,228,70,14,0,0,0,193,113,235,124,15,0,0,0,29,206,14,110,15,0,0,0,204,26,248,96,15,0,0,0,61,36,111,85,15,0,0,0,252,158,69,75,15,0,0,0,158,58,81,66,15,0,0,0,213,232,219,116,16,0,0,0,23,65,245,102,16,0,0,0,139,16,182,90,16,0,0,0,49,161,235,79,16,0,0,0,243,21,106,70,16,0,0,0,36,192,19,124,17,0,0,0,8,89,81,109,17,0,0,0,77,131,80,96,17,0,0,0,69,146,219,84,17,0,0,0,25,113,195,74,17,0,0,0,255,216,222,65,17,0,0,0,195,232,17,116,18,0,0,0,34,104,67,102,18,0,0,0,247,77,25,90,18,0,0,0,190,174,97,79,18,0,0,0,235,108,240,69,18,0,0,0,20,83,61,123,19,0,0,0,64,113,148,108,19,0,0,0,56,13,170,95,19,0,0,0,11,243,72,84,19,0,0,0,34,86,66,74,19,0,0,0,212,12,109,65,19,0,0,0,208,115,73,115,20,0,0,0,72,205,146,101,20,0,0,0,235,186,125,89,20,0,0,0,83,150,216,78,20,0,0,0,211,154,119,69,20,0,0,0,157,117,104,122,21,0,0,0,79,240,216,107,21,0,0,0,247,210,4,95,21,0,0,0,248,94,183,83,21,0,0,0,69,20,194,73,21,0,0,0,129,9,252,64,21,0,0,0,170,81,130,114,22,0,0,0,175,89,227,100,22,0,0,0,193,39,227,88,22,0,0,0,173,103,80,78,22,0,0,0,154,160,255,68,22,0,0,0,166,9,149,121,23,0,0,0,164,173,30,107,23,0,0,0,48,184,96,94,23,0,0,0,68,198,38,83,23,0,0,0,76,176,66,73,23,0,0,0,198,203,139,64,23,0,0,0,198,203,139,64,23,0,0,0,198,203,139,64,23,0,0,0,198,203,139,64,23,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,1,2,3,4,5,6,7,8,9,10,0,1,0,1,0,1,0,0,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,7,7,8,8,9,9,12,1,0,0,1,0,0,0,42,254,16,0,3,0,0,0,3,0,0,0,1,0,0,0,19,0,0,0,32,0,0,0,41,0,0,0,20,0,0,0,22,0,0,0,69,0,0,0,73,0,0,0,47,0,0,0,66,0,0,0,142,0,0,0,143,0,0,0,41,1,0,0,9,0,0,0,13,0,0,0,172,4,0,0,44,0,0,0,97,5,0,0,230,2,0,0,124,8,0,0,226,2,0,0,92,9,0,0,24,0,0,0,1,0,0,0,22,0,0,0,68,0,0,0,42,0,0,0,7,0,0,0,89,1,0,0,67,1,0,0,40,1,0,0,90,1,0,0,45,1,0,0,43,0,0,0,160,0,0,0,66,1,0,0,42,1,0,0,239,2,0,0,175,4,0,0,125,8,0,0,233,74,0,0,249,67,0,0,103,0,0,0,153,1,0,0,5,43,0,0,131,21,0,0,254,33,0,0,44,254,16,0,4,0,0,0,46,0,0,0,13,1,0,0,10,0,0,0,68,2,0,0,23,0,0,0,69,2,0,0,17,0,0,0,14,1,0,0,44,1,0,0,42,0,0,0,47,0,0,0,33,1,0,0,70,0,0,0,126,8,0,0,186,0,0,0,50,0,0,0,240,135,0,0,220,86,0,0,236,2,0,0,250,67,0,0,111,43,0,0,232,74,0,0,183,2,0,0,43,254,16,0,1,0,0,0,81,0,0,0,16,0,0,0,238,2,0,0,156,11,0,0,118,37,0,0,152,1,0,0,221,86,0,0,205,0,0,0,192,10,0,0,112,1,0,0,239,74,0,0,45,0,0,0,173,4,0,0,255,33,0,0,207,5,0,0,4,43,0,0,41,254,16,0,40,254,16,0,237,2,0,0,116,46,0,0,196,31,2,0,238,74,0,0,227,15,1,0,23,127,8,0,0,0,0,0,151,0,0,0,227,2,0,0,218,10,0,0,117,37,0,0,59,23,0,0,251,67,0,0,117,46,0,0,45,254,16,0,182,21,0,0,108,5,0,0,87,0,0,0,35,1,0,0,32,1,0,0,30,2,0,0,114,1,0,0,177,2,0,0,9,2,21,2,4,5,5,6,6,7,7,7,7,6,7,8,8,9,10,10,11,12,11,12,12,12,12,11,4,5,7,8,9,9,9,9,9,9,8,8,9,9,12,11,12,15,15,13,15,14,13,14,21,5,6,9,10,10,11,10,11,9,9,6,8,9,7,12,10,12,16,15,12,15,14,15,10,21,6,7,11,12,14,14,15,15,14,12,11,15,12,11,14,13,14,21,21,12,16,18,15,17,20,7,8,12,12,14,15,15,16,21,13,11,7,9,9,10,11,10,24,112,30,0,96,30,35,0,60,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,217,34,0,96,30,35,0,60,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,32,230,29,0,104,157,34,0,64,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,16,97,34,0,104,157,34,0,64,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,16,41,34,0,72,249,33,0,68,0,0,0,5,0,0,0,216,207,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,136,168,33,0,176,138,33,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,216,98,33,0,104,36,33,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,240,64,0,0,0,0,0,0,0,0,40,1,33,0,104,36,33,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,240,64,0,0,0,0,0,0,0,0,192,230,32,0,96,203,32,0,72,0,0,0,5,0,0,0,16,177,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,155,32,0,144,130,32,0,76,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,16,105,32,0,144,83,32,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,232,52,32,0,168,1,32,0,192,234,31,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,232,52,32,0,16,177,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,232,52,32,0,32,215,31,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,232,52,32,0,96,196,31,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,232,52,32,0,72,173,31,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,232,52,32,0,248,155,31,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,232,52,32,0,56,138,31,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,232,52,32,0,88,121,31,0,216,106,31,0,100,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,80,80,31,0,240,41,31,0,96,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,160,26,31,0,96,14,31,0,92,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,232,254,30,0,168,238,30,0,88,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,24,225,30,0,40,212,30,0,104,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,0,197,30,0,240,181,30,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,197,30,0,8,159,30,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,197,30,0,192,122,30,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,197,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,230,194,230,193,230,192,230,63,230,62,230,61,230,60,230,59,230,58,230,56,230,55,230,54,230,53,230,52,230,50,230,51,230,32,230,123,115,16,230,17,230,18,230,19,230,20,230,21,230,22,230,23,230,24,230,25,230,26,230,27,230,28,230,29,230,30,230,31,230,195,230,33,230,34,230,35,230,36,230,37,230,38,230,39,230,40,230,41,230,42,230,43,230,44,230,45,230,46,230,47,230,48,230,49,230,223,28,96,14,153,3,231,0,29,0,0,0,1,0,1,0,1,0,2,0,6,0,2,0,7,0,6,0,15,0,56,0,114,0,154,3,196,230,197,230,198,230,199,230,200,230,201,230,202,230,203,230,204,230,205,230,206,230,207,230,208,230,209,230,210,230,211,230,212,230,213,230,214,230,215,230,216,230,217,230,218,230,219,230,220,230,221,230,222,230,223,230,224,230,225,230,226,230,227,230,228,230,229,230,230,230,231,230,232,230,233,230,234,230,235,230,236,230,237,230,238,230,239,230,240,230,241,230,242,230,243,230,244,230,245,230,0,0,0,0,0,0,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,16,15,13,11,8,5,2,1,3,5,6,6,7,7,7,9,10,13,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,18,0,0,0,20,0,0,0,23,0,0,0,26,0,0,0,30,0,0,0,34,0,0,0,38,0,0,0,44,0,0,0,50,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,82,0,0,0,93,0,0,0,106,0,0,0,120,0,0,0,136,0,0,0,155,0,0,0,176,0,0,0,200,0,0,0,226,0,0,0,1,1,0,0,36,1,0,0,75,1,0,0,120,1,0,0,171,1,0,0,228,1,0,0,38,2,0,0,112,2,0,0,196,2,0,0,36,3,0,0,144,3,0,0,11,4,0,0,151,4,0,0,54,5,0,0,234,5,0,0,182,6,0,0,158,7,0,0,165,8,0,0,208,9,0,0,35,11,0,0,164,12,0,0,89,14,0,0,73,16,0,0,124,18,0,0,250,20,0,0,207,23,0,0,6,27,0,0,172,30,0,0,209,34,0,0,132,39,0,0,218,44,0,0,232,50,0,0,199,57,0,0,148,65,0,0,111,74,0,0,123,84,0,0,227,95,0,0,213,108,0,0,135,123,0,0,52,140,0,0,34,159,0,0,158,180,0,0,1,205,0,0,174,232,0,0,24,8,1,0,192,43,1,0,56,84,1,0,39,130,1,0,74,182,1,0,118,241,1,0,160,52,2,0,219,128,2,0,97,215,2,0,149,57,3,0,11,169,3,0,142,39,4,0,38,183,4,0,32,90,5,0,27,19,6,0,16,229,6,0,93,211,7,0,215,225,8,0,213,20,10,0,70,113,11,0,194,252,12,0,163,189,14,0,30,187,16,0,99,253,18,0,186,141,21,0,173,118,24,0,53,196,27,0,228,131,31,0,37,197,35,0,117,153,40,0,176,20,46,0,94,77,52,0,19,93,59,0,216,96,67,0,160,121,76,0,209,204,86,0,222,132,98,0,245,209,111,0,198,234,126,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,7,0,0,0,10,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,26,0,0,0,34,0,0,0,44,0,0,0,56,0,0,0,72,0,0,0,93,0,0,0,120,0,0,0,155,0,0,0,200,0,0,0,1,1,0,0,75,1,0,0,171,1,0,0,38,2,0,0,196,2,0,0,144,3,0,0,151,4,0,0,234,5,0,0,158,7,0,0,208,9,0,0,164,12,0,0,73,16,0,0,250,20,0,0,6,27,0,0,209,34,0,0,218,44,0,0,199,57,0,0,111,74,0,0,227,95,0,0,135,123,0,0,34,159,0,0,1,205,0,0,24,8,1,0,56,84,1,0,74,182,1,0,160,52,2,0,97,215,2,0,11,169,3,0,38,183,4,0,27,19,6,0,93,211,7,0,213,20,10,0,194,252,12,0,30,187,16,0,186,141,21,0,53,196,27,0,37,197,35,0,176,20,46,0,19,93,59,0,160,121,76,0,222,132,98,0,198,234,126,0,0,0,0,0,171,170,170,0,78,117,135,0,101,131,107,0,102,102,102,0,98,70,81,0,10,130,64,0,142,227,56,0,26,39,45,0,119,214,35,0,0,0,0,0,171,170,170,0,78,117,135,0,101,131,107,0,102,102,102,0,98,70,81,0,10,130,64,0,142,227,56,0,26,39,45,0,119,214,35,0,0,0,0,0,120,42,32,0,108,0,0,0,112,72,7,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,154,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,80,5,32,0,1,0,0,0,4,0,0,0,56,237,31,0,4,0,0,0,64,0,0,0,112,216,31,0,255,255,255,255,2,0,0,0,152,198,31,0,2,0,0,0,1,0,0,0,0,176,31,0,255,255,255,255,128,0,0,0,192,157,31,0,8,0,0,0,0,2,0,0,80,139,31,0,255,255,255,255,16,0,0,0,176,122,31,0,255,255,255,255,0,1,0,0,32,108,31,0,20,0,0,0,0,4,0,0,48,87,31,0,20,0,0,0,8,0,0,0,184,45,31,0,8,0,0,0,0,0,0,0,0,0,0,0,145,215,16,186,177,67,19,186,59,178,1,186,48,154,255,185,173,73,0,186,169,35,4,186,225,2,9,186,127,77,15,186,22,215,20,186,37,231,25,186,43,196,32,186,108,122,37,186,111,115,43,186,79,172,49,186,98,248,53,186,193,162,59,186,197,47,62,186,79,15,67,186,141,92,68,186,207,92,73,186,148,128,74,186,80,95,77,186,209,241,75,186,129,145,76,186,163,130,76,186,231,94,75,186,99,9,72,186,251,100,69,186,96,223,63,186,171,37,61,186,125,89,53,186,46,86,46,186,184,61,38,186,185,223,27,186,61,223,17,186,89,227,6,186,12,129,241,185,201,179,214,185,250,143,183,185,159,226,151,185,206,6,92,185,248,169,23,185,222,118,129,184,39,104,98,55,61,130,229,56,210,57,86,57,239,163,154,57,78,27,211,57,26,227,5,58,190,143,35,58,245,129,67,58,72,170,97,58,223,147,129,58,66,117,147,58,96,220,164,58,7,57,182,58,216,106,202,58,229,23,221,58,144,126,240,58,233,7,2,59,144,166,12,59,139,216,22,59,238,98,33,59,65,183,43,59,225,166,54,59,135,33,65,59,202,251,75,59,245,143,86,59,74,145,97,59,217,251,107,59,234,112,118,59,148,121,128,59,23,194,133,59,215,125,138,59,252,75,143,59,198,36,148,59,85,184,152,59,191,16,157,59,156,3,161,59,187,32,165,59,157,115,168,59,158,231,171,59,76,55,175,59,141,151,177,59,92,209,179,59,103,200,181,59,55,76,183,59,75,57,184,59,13,254,184,59,176,198,184,59,112,95,184,59,176,58,183,59,140,140,181,59,205,106,179,59,104,107,176,59,47,189,172,59,148,94,168,59,143,80,163,59,38,165,157,59,194,220,150,59,170,135,143,59,99,44,135,59,37,7,124,59,111,1,104,59,64,81,82,59,189,109,58,59,130,158,32,59,108,222,4,59,155,228,206,58,37,230,142,58,169,227,24,58,54,144,231,55,42,62,15,186,56,160,151,186,108,114,236,186,84,180,34,187,253,71,81,187,15,28,129,187,47,189,154,187,56,84,181,187,219,8,209,187,144,242,237,187,170,4,6,188,159,160,21,188,122,185,37,188,32,97,54,188,152,163,71,188,14,114,89,60,254,197,107,60,208,157,126,60,137,18,137,60,232,253,146,60,145,46,157,60,109,141,167,60,64,38,178,60,35,249,188,60,69,4,200,60,124,64,211,60,14,181,222,60,175,89,234,60,250,43,246,60,254,7,1,61,57,17,7,61,32,40,13,61,6,85,19,61,250,133,25,61,24,196,31,61,241,7,38,61,65,76,44,61,36,160,50,61,254,237,56,61,10,56,63,61,189,126,69,61,173,186,75,61,105,241,81,61,24,30,88,61,76,48,94,61,228,55,100,61,84,34,106,61,182,253,111,61,133,177,117,61,112,69,123,61,103,97,128,61,137,3,131,61,136,148,133,61,254,15,136,61,218,117,138,61,226,180,140,61,235,223,142,61,32,236,144,61,151,215,146,61,171,158,148,61,212,62,150,61,239,193,151,61,10,20,153,61,22,62,154,61,120,61,155,61,90,14,156,61,159,171,156,61,203,25,157,61,113,82,157,61,97,85,157,61,162,31,157,61,177,174,156,61,141,1,156,61,162,24,155,61,62,236,153,61,220,129,152,61,226,208,150,61,236,215,148,61,235,153,146,61,101,21,144,61,66,62,141,61,138,36,138,61,239,177,134,61,83,245,130,61,15,202,125,61,80,2,117,61,33,149,107,61,235,119,97,61,56,171,86,61,34,39,75,61,114,255,62,61,208,20,50,61,244,111,36,61,185,21,22,61,97,255,6,61,55,62,238,60,77,13,205,60,38,100,170,60,164,26,134,60,3,183,64,60,162,47,228,59,45,137,1,59,225,72,82,187,29,110,12,188,212,124,103,188,138,226,162,188,48,138,211,188,72,225,2,189,8,201,28,189,243,107,55,189,33,221,82,189,241,21,111,189,236,5,134,189,196,224,148,189,5,31,164,189,196,184,179,189,120,177,195,189,22,9,212,189,229,185,228,189,166,198,245,189,148,149,3,190,104,114,12,190,231,122,21,190,5,174,30,190,192,8,40,190,190,138,49,190,114,52,59,190,162,3,69,190,220,249,78,190,155,15,89,190,221,74,99,190,133,163,109,190,239,29,120,190,21,91,129,190,190,181,134,190,156,29,140,190,148,146,145,190,162,19,151,190,56,160,156,190,68,55,162,190,228,214,167,190,171,128,173,190,19,50,179,190,213,233,184,62,136,168,190,62,207,107,196,62,28,51,202,62,156,253,207,62,178,203,213,62,90,154,219,62,39,105,225,62,18,56,231,62,68,5,237,62,72,208,242,62,198,150,248,62,191,88,254,62,24,11,2,63,71,229,4,63,196,188,7,63,182,143,10,63,81,93,13,63,241,37,16,63,254,231,18,63,111,164,21,63,72,89,24,63,47,7,27,63,88,172,29,63,174,73,32,63,223,221,34,63,148,104,37,63,43,233,39,63,32,95,42,63,152,202,44,63,12,42,47,63,246,125,49,63,237,197,51,63,59,0,54,63,161,45,56,63,125,77,58,63,199,94,60,63,255,97,62,63,25,86,64,63,177,58,66,63,228,15,68,63,201,212,69,63,165,136,71,63,129,44,73,63,200,190,74,63,173,63,76,63,206,174,77,63,133,11,79,63,115,86,80,63,77,142,81,63,225,178,82,63,47,197,83,63,57,195,84,63,125,174,85,63,81,133,86,63,197,72,87,63,187,247,87,63,68,146,88,63,153,24,89,63,55,139,89,63,14,232,89,63,164,48,90,63,230,100,90,63,179,131,90,63,156,142,90,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+471072);
/* memory initializer */ allocate([248,249,250,251,252,253,254,255,0,1,2,3,4,5,6,7,251,252,253,254,255,0,1,2,3,4,5,6,7,9,11,13,251,253,254,255,0,1,2,3,4,5,6,7,9,11,13,16,250,252,254,255,0,1,2,3,4,5,6,7,9,11,13,16,252,254,255,0,1,2,3,4,5,6,7,9,11,13,16,20,254,255,0,1,2,3,4,5,6,7,9,11,13,16,20,24,28,224,169,63,31,177,151,63,244,87,143,63,0,0,0,0,171,170,170,62,148,94,154,62,211,103,95,62,4,219,235,61,179,96,2,61,0,0,0,0,54,60,53,63,0,0,128,63,28,206,180,63,249,2,21,80,0,0,0,0,0,0,64,63,102,102,102,63,72,225,122,63,48,103,31,0,48,111,140,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,40,62,31,0,48,111,140,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,184,35,31,0,48,111,140,0,12,0,0,0,1,0,0,0,64,75,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,116,31,0,108,0,0,0,168,93,7,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,153,62,205,204,204,62,0,0,0,63,51,51,51,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,255,0,1,0,0,255,0,1,255,255,1,1,1,255,255,1,1,2,0,3,4,0,0,0,128,0,128,0,0,1,0,0,68,172,0,0,34,86,0,0,17,43,0,0,0,119,1,0,128,187,0,0,0,125,0,0,192,93,0,0,128,62,0,0,64,31,0,0,0,0,0,0,0,8,12,0,16,20,24,0,64,31,0,0,128,62,0,0,0,125,0,0,17,43,0,0,34,86,0,0,68,172,0,0,224,46,0,0,192,93,0,0,128,187,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,1,0,0,0,6,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,117,56,0,0,0,0,0,0,8,0,0,0,0,0,0,0,5,0,0,0,115,49,54,0,0,0,0,0,16,0,0,0,0,0,0,0,6,0,0,0,115,51,50,0,0,0,0,0,32,0,0,0,0,0,0,0,7,0,0,0,102,108,116,0,0,0,0,0,32,0,0,0,0,0,0,0,8,0,0,0,100,98,108,0,0,0,0,0,64,0,0,0,0,0,0,0,9,0,0,0,117,56,112,0,0,0,0,0,8,0,0,0,1,0,0,0,0,0,0,0,115,49,54,112,0,0,0,0,16,0,0,0,1,0,0,0,1,0,0,0,115,51,50,112,0,0,0,0,32,0,0,0,1,0,0,0,2,0,0,0,102,108,116,112,0,0,0,0,32,0,0,0,1,0,0,0,3,0,0,0,100,98,108,112,0,0,0,0,64,0,0,0,1,0,0,0,4,0,0,0,240,40,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,225,29,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,29,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,251,29,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,232,29,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,31,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,25,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,62,0,15,1,15,2,15,3,15,4,15,5,15,6,15,7,15,8,15,9,15,10,15,11,15,12,15,13,15,14,15,15,15,16,15,17,15,18,15,19,15,20,15,21,15,22,15,23,15,24,15,25,15,26,15,27,15,28,15,29,15,30,15,31,15,32,15,33,15,34,15,35,15,36,15,37,15,38,15,39,15,40,15,41,15,42,15,43,15,44,15,45,15,46,15,47,15,48,15,49,15,50,15,51,15,52,15,53,15,54,15,55,15,56,15,57,15,58,15,59,15,60,15,61,15,62,15,63,15,128,3,129,3,130,3,131,3,132,3,133,3,134,3,135,3,136,3,137,3,138,3,139,3,140,3,141,3,142,3,143,3,144,3,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,192,0,193,0,194,0,195,0,196,0,197,0,198,0,199,0,200,0,201,0,202,0,203,0,204,0,205,0,206,0,207,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,32,0,33,0,34,0,35,0,12,0,13,0,4,0,0,0,5,0,14,0,15,0,36,0,37,0,38,0,39,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,208,0,209,0,210,0,211,0,212,0,213,0,214,0,215,0,216,0,217,0,218,0,219,0,220,0,221,0,222,0,223,0,160,3,161,3,162,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,170,3,171,3,172,3,173,3,174,3,175,3,176,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,64,15,65,15,66,15,67,15,68,15,69,15,70,15,71,15,72,15,73,15,74,15,75,15,76,15,77,15,78,15,79,15,80,15,81,15,82,15,83,15,84,15,85,15,86,15,87,15,88,15,89,15,90,15,91,15,92,15,93,15,94,15,95,15,96,15,97,15,98,15,99,15,100,15,101,15,102,15,103,15,104,15,105,15,106,15,107,15,108,15,109,15,110,15,111,15,112,15,113,15,114,15,115,15,116,15,117,15,118,15,119,15,120,15,121,15,122,15,123,15,124,15,125,15,126,15,127,15,14,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,6,6,6,6,5,5,4,2,4,5,5,6,6,6,6,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,127,254,0,63,1,63,2,63,3,63,4,63,5,63,6,63,7,63,8,63,9,63,10,63,11,63,12,63,13,63,14,63,15,63,16,63,17,63,18,63,19,63,20,63,21,63,22,63,23,63,24,63,25,63,26,63,27,63,28,63,29,63,30,63,31,63,32,63,33,63,34,63,35,63,36,63,37,63,38,63,39,63,40,63,41,63,42,63,43,63,44,63,45,63,46,63,47,63,48,63,49,63,50,63,51,63,52,63,53,63,54,63,55,63,56,63,57,63,58,63,59,63,60,63,61,63,62,63,63,63,128,15,129,15,130,15,131,15,132,15,133,15,134,15,135,15,136,15,137,15,138,15,139,15,140,15,141,15,142,15,143,15,144,15,145,15,146,15,147,15,148,15,149,15,150,15,151,15,152,15,153,15,154,15,155,15,156,15,157,15,158,15,159,15,192,3,193,3,194,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,202,3,203,3,204,3,205,3,206,3,207,3,224,0,225,0,226,0,227,0,228,0,229,0,230,0,231,0,48,0,49,0,50,0,51,0,8,0,9,0,2,0,0,0,3,0,10,0,11,0,52,0,53,0,54,0,55,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,239,0,208,3,209,3,210,3,211,3,212,3,213,3,214,3,215,3,216,3,217,3,218,3,219,3,220,3,221,3,222,3,223,3,160,15,161,15,162,15,163,15,164,15,165,15,166,15,167,15,168,15,169,15,170,15,171,15,172,15,173,15,174,15,175,15,176,15,177,15,178,15,179,15,180,15,181,15,182,15,183,15,184,15,185,15,186,15,187,15,188,15,189,15,190,15,191,15,64,63,65,63,66,63,67,63,68,63,69,63,70,63,71,63,72,63,73,63,74,63,75,63,76,63,77,63,78,63,79,63,80,63,81,63,82,63,83,63,84,63,85,63,86,63,87,63,88,63,89,63,90,63,91,63,92,63,93,63,94,63,95,63,96,63,97,63,98,63,99,63,100,63,101,63,102,63,103,63,104,63,105,63,106,63,107,63,108,63,109,63,110,63,111,63,112,63,113,63,114,63,115,63,116,63,117,63,118,63,119,63,120,63,121,63,122,63,123,63,124,63,125,63,126,63,127,63,16,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,8,8,8,8,8,8,8,8,6,6,6,6,4,4,3,2,3,4,4,6,6,6,6,8,8,8,8,8,8,8,8,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,160,0,0,0,172,0,0,0,240,0,0,0,64,1,0,0,96,1,0,0,128,2,0,0,192,2,0,0,0,0,0,0,120,0,0,0,132,0,0,0,144,0,0,0,240,0,0,0,32,1,0,0,224,1,0,0,248,255,255,255,246,255,255,255,180,0,0,0,104,1,0,0,64,2,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,17,18,18,18,19,19,19,20,20,20,22,22,22,22,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,20,21,21,22,23,23,23,24,24,24,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,2,2,2,2,3,3,3,3,4,5,5,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,3,3,3,4,4,5,5,5,7,8,9,64,48,96,32,80,48,48,64,64,64,80,48,32,96,48,64,64,80,32,96,48,80,64,48,80,64,80,48,96,32,80,64,0,0,0,0,16,0,0,0,32,0,0,0,16,0,0,0,32,0,0,0,28,0,0,0,32,0,0,0,28,0,0,0,0,0,0,0,32,0,0,0,16,0,0,0,32,0,0,0,32,0,0,0,28,0,0,0,32,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,3,3,3,4,4,4,6,6,6,7,8,8,9,9,10,10,11,11,12,13,14,15,16,17,128,128,128,128,128,128,128,128,128,128,122,96,75,59,47,37,29,23,18,15,13,11,10,9,8,7,6,5,4,3,2,1,1,5,1,0,3,61,29,2,4,60,63,28,13,62,12,1,1,4,5,5,5,7,6,5,4,7,7,6,5,7,5,3,0,0,0,1,0,2,17,0,17,1,17,2,17,5,17,6,34,0,34,1,34,2,34,7,114,2,39,2,34,8,130,2,40,2,18,1,22,1,33,2,0,5,10,3,6,10,7,8,10,4,7,10,6,7,10,8,8,10,8,9,10,9,9,10,9,9,9,2,6,10,4,7,10,7,8,9,5,7,10,6,7,10,8,8,9,8,9,10,8,8,9,9,9,8,6,8,11,6,8,10,7,8,10,6,8,11,7,8,10,8,8,9,8,9,10,9,9,10,9,9,9,7,8,10,7,8,10,7,8,8,7,8,10,7,8,9,7,8,8,8,8,9,8,8,8,7,7,7,0,4,10,3,6,10,7,8,11,3,6,10,5,7,10,9,9,11,9,10,11,9,10,11,11,11,11,2,6,10,4,6,10,7,8,10,4,7,10,6,7,10,8,9,10,8,9,11,9,9,11,10,10,11,6,8,11,6,8,11,8,9,11,7,9,11,7,8,11,9,9,11,9,10,12,10,10,12,11,11,11,8,9,11,8,9,11,9,9,11,9,10,11,9,10,11,9,10,11,10,11,12,10,10,12,10,10,10,0,5,10,3,6,10,7,8,10,4,7,10,6,7,10,8,9,10,8,9,11,8,9,10,10,10,10,2,6,10,4,6,10,7,8,10,4,7,10,5,7,10,8,8,10,8,9,10,8,9,10,9,9,9,5,7,11,6,8,11,7,8,11,6,8,11,7,8,10,8,9,10,8,9,11,9,9,10,10,9,10,7,8,10,7,8,10,8,9,10,8,9,10,8,9,10,8,8,10,9,9,10,9,9,10,9,9,9,0,5,11,3,6,11,8,9,12,4,7,12,6,7,12,9,10,13,10,11,13,10,11,14,12,13,14,1,6,11,4,7,11,8,9,12,5,7,11,6,8,12,9,10,13,10,11,14,10,11,13,12,12,14,6,8,12,7,9,13,9,10,14,7,10,13,8,10,12,11,11,13,11,13,14,11,12,14,13,13,15,9,10,12,9,11,14,10,11,14,11,11,13,10,11,13,11,12,14,12,14,15,13,13,14,13,13,14,0,5,11,3,6,11,7,9,11,4,6,11,5,7,10,9,9,11,8,9,11,9,10,11,11,11,11,2,6,10,3,6,10,7,9,11,4,7,10,5,7,10,8,9,11,8,9,11,9,9,11,11,11,11,5,8,11,6,8,11,8,10,12,6,8,11,7,8,11,9,10,11,9,10,12,9,10,11,11,11,11,8,9,11,8,10,12,9,11,12,8,10,12,9,10,12,10,11,12,10,11,12,10,10,11,11,11,11,0,5,13,2,7,16,9,11,16,4,8,16,7,9,16,12,12,16,12,16,16,12,16,16,16,16,16,1,6,13,4,8,16,9,11,16,6,9,16,7,10,16,13,13,16,13,15,16,12,16,16,16,16,16,7,9,16,8,11,15,11,13,16,10,12,16,10,12,16,16,13,16,16,16,16,14,16,16,16,16,16,12,12,16,12,16,16,16,16,16,13,14,16,12,13,16,16,16,16,16,16,16,14,16,16,16,16,16,0,6,11,3,7,11,8,10,12,4,7,11,6,8,11,10,11,12,9,10,12,10,10,12,12,12,13,1,6,11,4,7,11,8,10,12,4,7,11,6,8,11,10,10,12,9,10,12,10,10,12,13,13,13,6,8,12,7,10,12,10,12,13,7,9,12,8,10,12,11,11,13,11,12,14,11,11,13,13,13,13,9,11,13,10,12,14,12,13,15,10,12,14,11,12,14,13,13,14,12,13,15,13,13,14,14,14,14,0,5,16,2,6,16,10,14,16,4,8,16,7,9,16,11,16,16,11,16,16,16,16,16,16,16,16,1,6,12,4,8,12,12,12,16,6,8,16,8,10,16,16,16,16,16,16,16,16,16,16,12,16,16,7,10,16,8,11,14,16,16,16,10,12,16,10,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,5,11,3,6,11,10,10,12,3,7,11,6,8,11,11,11,12,10,10,12,11,11,13,14,13,14,1,6,11,4,7,11,10,11,13,5,7,11,7,8,11,11,11,13,10,11,13,11,11,12,13,13,14,7,10,12,9,11,13,12,13,14,9,10,13,9,10,13,12,11,13,12,13,16,12,13,13,14,14,14,11,14,16,12,14,15,14,13,16,13,13,15,13,14,16,14,13,16,13,13,16,13,14,15,15,14,15,0,4,16,2,7,16,10,16,16,4,10,16,7,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,6,13,4,11,16,16,16,16,6,10,16,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,16,10,16,16,16,16,16,10,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,5,10,3,6,10,7,8,9,4,6,10,6,7,9,8,8,9,8,8,9,8,9,9,9,9,8,3,6,10,4,6,10,7,7,9,5,7,10,6,7,9,7,7,8,7,8,9,8,8,9,8,8,7,6,8,10,6,8,10,7,8,9,7,8,10,7,8,10,8,8,8,8,9,9,8,8,9,9,8,7,7,8,9,7,8,9,7,7,7,8,8,9,7,8,9,7,7,7,8,8,8,7,7,7,7,6,5,0,5,11,3,6,11,8,9,11,3,6,10,6,7,11,9,9,11,7,9,11,9,9,11,10,10,11,2,6,10,4,7,10,7,9,11,4,7,11,6,7,10,9,9,11,7,9,11,8,9,10,10,10,10,5,8,11,6,8,11,8,9,11,6,8,11,7,8,11,9,9,11,8,10,11,9,9,11,10,10,10,8,9,11,8,9,11,9,9,10,8,9,11,8,9,11,9,9,10,8,9,10,9,9,10,9,9,8,0,5,10,4,6,10,7,8,10,4,6,10,6,7,9,8,8,9,8,8,9,8,9,9,9,9,9,2,6,10,4,6,10,7,7,9,5,7,10,6,7,9,7,7,9,7,8,9,8,8,9,9,8,8,6,8,10,6,8,10,7,8,9,6,8,10,7,8,10,8,8,9,8,9,10,8,8,9,9,9,8,8,8,10,7,8,9,7,8,8,7,8,10,7,8,9,7,7,8,8,8,9,8,8,8,7,7,6,0,5,12,4,7,12,8,10,13,4,7,12,6,8,12,10,10,12,8,9,12,10,10,12,12,12,12,1,6,12,4,7,12,8,9,12,4,7,12,6,8,11,9,10,12,8,9,12,9,10,11,11,11,12,6,8,12,7,9,12,9,10,13,6,9,12,8,9,12,10,10,12,9,10,12,10,10,12,12,12,12,8,10,12,9,10,12,10,10,12,8,10,12,9,10,12,10,10,11,9,10,12,10,10,11,11,10,10,0,5,10,3,6,10,7,8,11,4,6,10,6,7,10,8,9,10,8,8,10,9,9,10,10,10,10,2,6,10,4,6,10,7,8,10,4,7,10,6,7,10,8,8,10,7,8,10,8,8,9,10,9,9,5,8,11,6,8,10,7,9,10,6,8,11,7,8,10,8,8,10,8,9,11,9,9,10,10,9,9,8,9,10,8,9,10,8,9,10,8,9,10,8,8,10,8,8,9,8,9,10,8,8,9,9,8,8,0,6,13,4,7,14,9,11,14,3,7,13,7,8,13,11,11,14,8,10,13,10,11,13,13,13,14,1,6,12,4,8,13,9,10,15,4,8,13,7,8,12,11,11,14,8,10,13,10,10,13,13,13,14,5,9,13,7,9,13,10,11,14,6,10,14,8,10,14,11,11,14,9,11,14,11,11,13,13,13,14,9,10,14,9,11,13,11,12,14,9,11,13,9,11,14,11,12,13,10,12,15,11,11,13,13,12,13,0,5,11,3,6,11,7,9,12,3,6,11,6,7,11,9,9,11,8,9,11,9,9,11,11,11,12,2,6,11,4,6,11,7,9,11,4,7,11,5,7,10,9,9,11,7,8,11,9,9,10,11,11,11,5,8,11,6,8,11,8,9,12,6,8,11,7,8,11,9,9,11,8,9,12,9,9,11,11,11,11,8,10,12,8,10,11,9,10,12,8,10,12,8,9,12,10,10,12,9,10,12,9,9,11,11,10,11,0,6,13,3,8,14,10,12,16,3,8,15,7,9,15,12,13,15,9,11,15,11,12,16,14,16,16,1,7,13,4,8,14,9,11,15,4,8,14,7,9,14,12,13,15,8,10,14,11,11,14,16,14,16,6,9,14,7,10,14,11,13,15,7,10,14,9,10,13,12,12,15,10,11,14,11,11,14,14,14,16,9,11,14,10,11,14,13,14,15,9,12,14,10,12,16,13,14,16,10,13,16,12,12,14,15,14,15,0,6,12,3,7,12,9,11,13,4,7,12,6,8,12,10,11,13,8,10,13,10,11,13,13,13,14,1,6,12,4,7,12,9,10,14,4,7,12,6,7,12,10,11,13,8,9,13,10,10,12,13,13,14,6,9,13,7,9,13,10,12,14,7,9,13,8,10,13,11,11,14,9,11,13,11,11,14,13,13,14,10,12,14,10,12,14,12,13,15,10,12,14,10,12,14,12,13,15,11,13,15,12,12,15,14,14,14,0,6,16,3,8,16,10,13,16,3,8,16,7,9,16,13,16,16,8,10,16,11,13,16,16,16,16,1,7,14,4,8,16,10,12,16,4,8,13,7,9,16,13,14,16,8,10,16,11,11,14,16,16,16,6,9,14,8,10,14,12,16,16,6,10,13,9,11,16,13,14,16,9,12,16,12,11,16,16,16,16,10,12,16,11,12,16,16,14,16,9,12,16,11,12,16,16,15,16,10,13,16,12,13,16,16,16,16,0,10,5,10,7,12,9,11,8,13,9,12,10,13,11,12,16,16,14,15,15,16,13,14,5,12,6,11,9,13,10,11,9,14,9,12,11,14,11,12,16,16,14,15,15,16,13,13,10,15,9,12,12,16,11,12,12,16,10,13,13,16,11,12,16,16,13,14,15,16,13,12,6,12,8,11,8,12,10,11,9,14,10,12,10,13,11,12,15,16,14,15,14,16,13,13,8,13,9,12,10,13,10,12,10,14,9,12,11,14,10,12,15,16,13,15,14,16,13,13,11,16,10,13,13,16,11,12,12,16,11,13,13,16,11,12,16,16,13,14,15,16,12,12,10,16,12,14,10,14,11,12,12,16,13,14,11,14,12,12,16,16,15,16,14,15,13,13,11,16,12,14,11,14,11,12,12,16,12,14,11,14,11,12,16,16,14,15,13,15,13,12,14,16,13,14,13,16,12,12,14,16,13,14,13,16,12,12,16,16,14,14,14,15,12,11,2,10,6,10,7,12,9,11,8,12,9,11,10,13,10,11,15,16,14,15,14,16,13,13,5,12,6,11,9,13,10,11,9,13,9,11,10,13,10,11,15,16,13,14,14,16,13,13,9,15,8,12,12,15,11,11,11,16,10,12,13,15,11,11,15,16,13,14,15,16,12,12,6,12,8,11,8,12,9,11,9,14,9,12,10,13,10,11,15,16,14,15,14,16,13,13,7,13,8,11,9,13,10,11,9,14,9,12,10,13,10,11,14,16,13,14,13,16,12,12,11,16,10,12,12,15,11,11,11,16,10,12,12,15,11,11,15,16,12,13,14,16,12,11,9,15,11,13,9,13,11,12,11,16,12,14,10,14,11,12,16,16,14,15,13,15,12,12,11,16,11,14,10,14,11,12,11,16,12,13,11,14,11,11,15,16,14,15,13,14,12,12,13,16,12,14,13,15,11,11,13,16,12,14,13,15,11,11,16,16,13,14,13,15,11,10,5,12,7,11,8,13,10,11,9,13,9,12,10,14,11,12,16,16,14,15,14,16,13,13,7,13,7,11,9,13,10,11,9,14,9,12,11,14,11,12,16,16,14,14,14,16,13,13,9,15,8,12,12,15,11,12,11,16,10,12,13,16,11,12,16,16,13,14,15,16,12,12,7,13,8,12,9,13,10,11,10,14,10,12,10,14,11,12,16,16,14,15,14,16,13,13,8,14,9,12,10,13,10,11,9,14,9,12,10,14,10,11,15,16,13,14,14,16,12,12,11,16,10,12,12,15,11,12,11,16,10,12,12,15,11,11,15,16,12,14,14,16,12,11,10,16,11,13,9,14,11,12,12,16,12,14,11,14,11,12,16,16,14,16,14,15,13,12,11,16,11,14,10,14,11,12,11,16,12,14,11,14,11,11,15,16,14,15,13,15,12,12,13,16,12,14,13,15,11,11,13,16,12,14,12,14,11,11,15,16,12,13,13,14,11,10,6,13,8,11,9,13,10,11,10,14,10,12,10,13,10,11,15,16,13,13,13,14,12,11,7,13,8,11,9,13,9,11,10,14,9,11,10,13,10,11,15,16,13,13,13,14,11,11,9,14,8,11,10,13,9,10,11,15,9,11,11,13,9,10,15,16,12,13,13,14,10,9,7,13,8,11,9,13,9,11,10,14,10,12,10,13,10,11,15,16,13,13,13,14,11,11,8,13,8,11,9,13,9,10,9,14,9,11,10,13,9,10,14,16,12,13,13,14,11,10,9,14,8,11,10,13,9,9,10,14,8,11,10,13,9,9,14,16,11,12,12,14,10,9,9,14,9,12,8,12,9,10,11,15,10,12,10,13,9,10,15,16,13,13,12,13,11,10,9,14,9,12,9,12,9,10,10,14,10,12,9,12,9,9,14,16,12,13,11,13,10,9,10,14,9,11,10,12,8,8,10,14,9,11,10,12,8,8,12,14,9,10,10,11,8,7,0,9,6,9,6,10,8,9,7,11,8,11,9,11,9,10,14,16,13,14,13,14,12,11,5,11,7,10,8,10,8,9,8,12,8,11,9,12,9,10,14,16,12,13,13,14,11,11,10,14,9,11,11,13,10,10,11,15,9,11,12,13,10,10,15,16,12,12,13,14,11,9,6,11,7,10,7,10,8,9,8,12,9,11,9,11,9,10,14,16,13,13,13,14,11,11,7,12,8,11,8,11,9,9,9,13,9,11,9,12,9,10,14,16,12,13,12,14,11,10,11,14,10,12,11,13,10,10,12,15,10,12,12,13,10,10,15,16,12,12,13,14,10,9,10,14,11,13,9,12,10,10,11,15,12,13,10,12,10,10,14,16,13,14,12,13,11,10,11,14,11,13,10,12,10,10,12,15,11,13,10,12,10,10,15,16,13,13,12,13,11,9,13,16,12,13,12,13,10,9,14,16,12,13,12,13,10,9,16,16,12,12,13,13,10,7,4,10,6,9,7,10,8,9,8,12,9,11,9,11,9,9,14,16,13,13,13,14,11,11,6,11,7,10,8,11,8,9,9,12,9,11,9,12,9,9,14,16,12,13,13,14,11,10,10,14,9,11,11,13,9,9,11,14,9,11,11,13,10,9,14,16,11,12,13,14,10,9,6,11,8,10,7,10,8,9,9,12,9,11,9,11,9,9,14,16,13,13,12,13,11,10,8,12,8,10,8,11,9,9,9,12,9,11,9,11,9,9,14,16,12,13,12,13,11,10,11,14,10,11,11,13,9,9,11,14,10,11,11,13,9,9,14,16,11,12,13,14,10,8,10,14,11,12,9,12,10,10,11,14,11,13,10,12,10,10,14,16,13,14,12,13,11,9,11,14,11,12,10,12,10,10,11,14,11,12,10,12,10,9,14,16,13,13,11,12,10,9,13,16,12,13,12,13,10,9,13,16,11,12,11,13,10,8,15,16,12,12,12,12,9,7,8,12,8,11,9,12,9,10,10,14,10,12,11,13,10,10,16,16,14,14,14,14,12,11,8,13,8,11,9,12,10,10,11,14,10,12,11,13,10,10,16,16,13,14,14,14,12,11,11,14,9,12,11,13,10,10,12,15,10,12,12,14,10,10,15,16,12,12,14,14,11,9,9,13,9,11,9,12,10,10,11,14,10,12,10,12,10,10,15,16,14,14,13,14,12,11,9,13,9,11,10,12,10,10,10,14,10,12,10,12,10,10,15,16,13,13,13,14,11,10,11,15,10,12,11,13,10,10,11,15,10,12,12,13,10,9,15,16,11,12,13,14,10,9,11,15,11,13,10,12,10,10,12,16,12,13,11,13,10,10,16,16,14,14,12,13,11,9,11,15,11,13,10,13,10,10,12,15,12,13,10,12,10,10,14,16,13,13,12,13,10,9,13,16,12,13,12,13,10,9,13,16,11,12,11,13,10,9,14,16,11,12,12,12,9,7,10,15,10,12,11,13,10,10,12,16,12,13,12,13,11,10,16,16,14,14,14,15,12,10,10,14,10,12,10,13,10,10,12,15,11,12,11,13,10,10,16,16,14,13,14,14,11,9,11,14,10,11,11,12,9,9,12,15,10,11,11,13,9,8,16,16,12,12,13,13,10,7,10,15,10,12,10,13,10,10,12,15,11,12,11,13,10,10,16,16,14,13,14,14,11,9,10,14,10,12,10,12,10,10,12,15,11,12,11,13,10,10,16,16,13,13,13,14,11,9,11,14,10,11,10,12,9,8,11,14,9,11,11,12,9,8,14,16,10,11,12,13,9,7,11,15,11,12,10,12,10,9,13,16,11,12,11,12,10,9,16,16,13,13,12,13,10,7,11,15,10,12,10,12,9,8,12,15,11,12,10,12,9,8,14,16,12,12,11,12,9,7,11,14,10,11,10,12,8,7,11,14,9,10,10,11,8,6,12,15,9,9,9,10,7,4,0,6,3,7,3,7,6,7,5,9,6,9,7,9,8,8,16,16,16,16,16,16,16,11,3,8,5,8,6,8,7,7,7,11,7,10,8,10,8,9,16,16,16,16,16,16,14,10,8,16,7,11,10,16,9,9,11,16,9,14,16,16,10,9,16,16,16,16,16,16,16,10,3,8,5,8,5,8,7,7,7,11,8,10,8,10,8,9,16,16,16,16,16,16,16,11,6,10,7,9,7,10,8,8,8,11,8,10,8,11,8,8,16,16,16,16,16,16,11,10,10,16,9,13,11,16,10,9,11,16,9,11,16,16,10,9,16,16,11,16,16,16,11,9,9,16,10,11,8,11,9,9,11,16,12,16,10,16,10,10,16,16,16,16,16,16,16,10,10,16,11,16,10,16,10,10,11,16,11,16,10,16,10,9,16,16,16,16,16,16,11,9,16,16,16,16,16,16,11,9,16,16,16,16,16,16,11,9,16,16,11,16,16,16,9,7,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,2,8,5,9,6,9,8,8,8,12,9,11,9,11,10,10,16,16,14,16,14,16,14,12,5,10,6,9,8,10,8,9,9,12,9,11,10,12,10,10,16,16,14,15,15,16,13,12,10,13,9,12,11,12,10,10,12,15,11,12,12,13,11,10,16,16,15,14,15,16,13,12,6,10,8,10,7,10,8,9,9,13,10,11,10,12,10,10,16,16,14,16,14,16,13,12,7,11,8,11,9,11,9,9,10,13,10,11,10,12,10,9,16,16,14,14,14,15,12,11,11,14,11,12,11,13,10,10,12,15,11,13,12,13,11,10,16,16,14,16,15,15,13,11,10,13,11,12,10,12,10,10,12,15,12,13,11,13,11,11,16,16,15,16,14,15,13,11,11,14,11,13,11,12,11,10,12,16,12,13,12,13,11,10,16,16,15,16,13,15,12,11,13,15,12,13,13,14,11,11,14,16,13,13,13,14,11,11,16,16,15,14,15,15,12,10,3,8,6,9,7,9,8,8,8,12,9,11,9,11,9,9,16,16,15,15,15,16,13,12,6,10,7,9,8,10,8,8,9,12,9,11,10,12,10,9,16,16,14,14,14,15,13,11,10,13,9,11,11,12,10,10,12,14,11,12,12,13,11,10,16,16,14,14,15,15,13,11,6,10,8,10,7,10,8,9,10,12,10,11,10,11,10,9,16,16,14,15,14,15,13,11,8,11,8,10,9,11,9,9,9,13,9,11,10,11,9,9,16,16,13,14,14,14,12,10,11,14,10,12,11,12,10,10,12,14,11,12,12,13,10,10,16,16,13,14,15,15,12,10,10,13,11,12,10,12,10,10,12,14,12,13,11,13,11,10,16,16,15,14,14,14,12,11,11,14,11,12,10,12,10,10,12,15,12,12,11,13,10,10,16,16,14,15,13,14,12,10,13,15,12,13,12,13,11,10,13,16,12,13,12,13,11,10,16,16,13,14,13,15,11,9,6,10,8,10,8,11,9,10,11,13,11,12,11,13,11,10,16,16,16,16,16,16,13,12,8,11,9,11,9,11,10,10,11,14,11,12,11,12,11,10,16,16,15,15,16,16,13,12,11,14,10,12,12,13,11,10,13,16,12,13,13,14,11,11,16,16,15,16,16,16,13,12,8,12,9,11,9,11,10,10,11,14,11,12,11,12,11,10,16,16,16,16,16,16,13,12,9,12,10,11,10,12,10,10,11,14,11,12,11,13,10,10,16,16,15,14,15,15,13,11,12,14,11,13,12,13,11,10,12,15,11,12,13,13,11,10,16,16,14,15,16,15,13,11,11,15,12,13,11,13,11,10,13,16,13,14,12,14,11,11,16,16,16,16,15,15,13,12,12,14,12,13,11,13,11,10,13,15,12,13,11,13,11,10,16,16,15,15,13,15,13,11,13,16,13,13,13,13,12,11,13,16,13,13,13,13,11,10,16,16,13,15,14,14,12,9,9,13,10,12,11,13,11,11,13,16,13,14,13,14,12,11,16,16,16,16,16,16,14,12,10,14,11,13,11,13,11,10,13,16,13,13,13,14,12,11,16,16,16,16,16,16,14,12,11,15,11,13,12,13,11,10,14,16,12,13,13,14,12,10,16,16,15,16,16,16,13,11,10,14,11,12,11,13,11,10,13,16,12,13,12,14,12,11,16,16,16,16,16,16,14,12,11,14,11,12,11,13,11,10,13,15,12,13,12,13,11,10,16,16,15,15,16,16,13,11,12,15,12,13,12,13,11,10,13,16,12,13,13,13,11,10,16,16,14,14,16,15,13,10,12,15,12,13,12,13,11,10,14,16,13,14,13,14,12,11,16,16,16,16,15,16,13,11,12,16,12,13,12,13,11,10,13,16,13,13,12,14,11,10,16,16,15,16,14,15,13,10,12,15,12,14,12,13,11,10,13,16,12,13,12,13,11,10,16,16,13,14,13,14,11,8,0,11,5,11,7,13,10,12,7,13,9,13,10,14,12,13,16,16,15,16,16,16,15,15,4,13,6,12,10,14,11,12,8,14,9,13,11,15,12,13,16,16,15,16,15,16,15,14,9,16,9,13,13,16,12,13,12,16,10,14,14,16,13,13,16,16,14,16,16,16,14,14,5,13,8,13,8,13,11,12,9,14,10,13,10,14,12,13,16,16,15,16,15,16,14,15,7,14,9,13,10,14,11,13,9,15,10,13,11,14,12,13,16,16,14,16,15,16,14,14,11,16,11,14,13,16,12,13,12,16,11,14,14,16,12,13,16,16,14,15,16,16,14,13,10,16,12,15,10,15,12,14,12,16,13,16,11,15,13,14,16,16,16,16,14,16,14,14,11,16,12,15,11,16,12,13,12,16,13,15,12,16,12,13,16,16,16,16,14,16,14,14,14,16,13,15,14,16,13,13,14,16,14,15,14,16,13,13,16,16,15,16,15,16,13,13,2,12,6,11,7,13,10,12,7,13,9,12,10,14,11,12,16,16,15,16,15,16,14,15,5,13,6,12,9,13,10,12,8,14,9,13,11,14,11,13,16,16,14,16,15,16,14,14,9,16,8,13,12,16,11,13,11,16,10,13,13,16,12,13,16,16,13,15,16,16,13,13,5,13,8,12,7,13,10,12,8,14,10,13,10,14,11,13,16,16,14,16,15,16,14,14,7,14,8,12,9,14,11,12,8,14,9,13,10,14,11,12,15,16,14,15,14,16,13,14,11,16,10,13,13,16,12,13,11,16,10,13,13,16,12,13,16,16,13,15,15,16,13,13,9,16,12,15,9,14,11,13,11,16,13,15,11,14,12,13,16,16,15,16,14,16,14,14,11,16,12,14,11,15,12,13,11,16,12,14,11,15,12,13,16,16,15,16,14,16,13,13,13,16,13,15,13,16,12,13,14,16,13,15,13,16,12,12,16,16,14,15,14,16,12,12,4,13,7,12,8,14,11,12,9,14,10,13,11,14,12,13,16,16,15,16,16,16,15,15,6,14,7,12,10,14,11,12,9,15,10,13,11,15,12,13,16,16,15,16,16,16,14,14,9,16,8,13,12,16,11,13,12,16,10,14,13,16,12,13,16,16,14,16,16,16,14,14,6,14,8,13,8,14,11,13,9,15,10,13,11,14,12,13,16,16,15,16,16,16,14,14,7,15,9,13,10,14,11,13,9,15,10,13,11,14,11,13,16,16,14,16,15,16,14,14,10,16,10,13,12,16,12,13,11,16,10,13,13,16,12,13,16,16,13,14,15,16,13,13,9,16,12,14,9,14,11,13,12,16,12,15,11,15,12,13,16,16,16,16,15,16,14,14,10,16,12,15,11,15,12,13,11,16,12,14,11,15,12,13,16,16,14,16,13,16,13,13,13,16,13,15,13,16,12,13,13,16,12,14,13,16,12,12,15,16,13,14,13,16,12,12,6,14,8,13,9,14,10,12,10,15,10,12,11,14,11,12,16,16,14,14,14,16,13,13,7,15,8,13,9,14,10,12,10,15,10,13,11,14,11,12,16,16,14,14,14,16,13,12,9,16,8,12,11,14,10,11,11,16,10,13,11,14,10,11,16,16,13,14,14,16,12,11,7,14,9,13,9,14,10,12,10,16,10,13,11,14,11,12,16,16,14,14,14,15,13,12,7,14,9,13,9,14,10,12,9,14,10,12,10,14,11,12,15,16,13,14,14,15,12,12,9,15,9,12,11,14,10,11,10,15,9,12,11,14,10,11,14,16,11,13,13,15,11,11,9,16,10,13,9,14,10,11,11,16,11,13,10,14,10,11,16,16,14,15,13,15,12,12,9,16,10,13,9,13,10,11,10,15,10,13,10,13,10,11,14,16,13,14,12,14,11,11,11,16,10,13,11,13,9,10,11,14,10,12,10,13,9,9,13,15,10,11,11,12,9,8,0,10,5,10,6,11,8,10,7,12,8,11,9,12,9,10,14,16,13,13,13,14,12,11,5,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,11,11,9,15,8,12,11,14,10,10,11,16,9,12,12,14,10,10,14,16,11,12,13,14,11,10,5,12,8,11,7,11,9,10,8,13,9,11,9,12,9,10,14,16,12,13,13,14,11,11,7,13,8,11,9,12,9,10,9,13,9,11,9,12,9,10,14,16,12,13,12,13,11,10,11,15,10,12,12,14,10,10,12,16,10,12,12,14,10,10,14,16,11,12,13,14,10,9,10,15,11,13,9,13,10,10,11,15,12,13,10,12,10,10,14,16,13,14,12,13,11,10,11,16,11,13,10,13,10,10,11,16,11,13,10,13,10,10,14,16,13,14,12,13,11,9,13,16,12,13,12,14,11,10,14,16,12,13,12,14,10,9,16,16,12,13,13,13,10,8,3,11,6,10,7,11,9,10,8,12,8,11,9,12,9,10,14,16,13,13,13,14,11,11,5,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,11,10,9,14,8,11,11,14,10,10,11,15,9,11,12,14,10,10,14,16,11,12,13,14,11,9,6,12,8,11,7,11,9,10,8,13,9,11,9,12,9,10,14,16,12,13,13,13,11,10,7,13,8,11,8,12,9,10,9,13,9,11,9,12,9,9,14,16,12,13,12,13,11,10,10,15,9,12,11,14,10,10,11,15,9,11,11,13,10,9,14,16,11,12,13,14,10,9,9,15,11,13,9,12,10,10,11,15,11,13,9,12,10,10,14,16,13,14,12,13,11,10,10,15,11,13,10,13,10,10,11,15,11,13,10,12,10,10,14,16,12,13,11,12,10,9,13,16,12,13,12,14,10,9,13,16,11,12,12,13,10,9,14,16,11,12,12,13,9,8,7,13,8,12,9,13,10,11,10,14,10,12,11,13,11,11,16,16,13,14,14,14,12,11,8,14,8,12,9,13,10,10,10,14,10,12,11,13,10,10,16,16,13,13,14,14,12,11,10,15,9,12,11,14,10,10,12,16,10,12,12,14,10,10,16,16,12,13,14,15,11,10,8,14,9,12,9,13,10,11], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+482552);
/* memory initializer */ allocate([10,15,10,12,10,13,10,11,16,16,13,14,14,14,12,11,8,14,9,12,9,13,10,10,10,14,10,12,10,13,10,10,15,16,13,13,13,14,11,10,10,15,10,12,12,14,10,10,11,16,9,12,12,14,10,10,14,16,11,12,13,14,10,9,11,16,11,13,10,13,10,10,12,16,12,13,10,13,11,10,15,16,14,14,12,13,11,10,11,16,11,13,10,13,10,10,11,16,12,13,10,12,10,10,14,16,13,14,11,13,11,9,13,16,12,13,12,14,10,10,12,16,11,12,12,13,10,9,14,16,11,12,11,12,9,8,10,16,10,13,11,14,11,11,12,16,11,13,12,14,11,11,16,16,14,13,14,14,12,10,10,15,10,13,10,13,10,11,12,16,11,13,11,13,11,10,16,16,14,13,14,14,12,10,11,15,9,12,11,13,10,9,12,16,10,12,12,13,10,9,16,16,12,12,13,14,10,8,10,16,10,13,10,14,11,11,12,16,11,13,12,14,11,10,16,16,14,13,14,14,12,10,9,15,9,12,10,13,10,10,11,16,10,12,11,13,10,10,16,16,13,13,13,14,11,9,10,15,9,11,11,13,9,9,11,15,9,11,11,13,9,8,14,16,10,11,13,13,10,8,11,16,11,13,10,13,10,9,13,16,11,13,11,13,10,9,16,16,13,13,13,13,10,8,11,16,10,12,10,13,10,9,11,16,11,12,10,12,9,9,15,16,12,13,11,12,10,8,11,16,10,12,11,12,9,8,11,15,9,11,10,12,9,7,13,15,9,9,10,10,7,5,0,7,3,8,4,9,7,8,5,10,7,10,8,11,8,9,16,16,16,16,16,16,11,10,2,10,4,9,7,10,7,8,7,16,7,10,9,16,8,9,16,16,16,16,16,16,11,10,8,16,7,10,10,16,9,8,10,16,9,11,16,16,9,9,16,16,16,16,16,16,11,9,3,10,6,9,6,11,8,8,7,16,8,10,9,16,9,9,16,16,16,16,16,16,11,10,5,16,7,10,8,11,8,8,8,16,8,10,9,16,8,8,16,16,11,16,16,16,10,9,9,16,9,11,11,16,9,9,11,16,9,11,11,16,9,8,16,16,10,16,16,16,10,9,8,16,10,16,8,16,10,9,12,16,11,16,10,16,10,9,16,16,16,16,16,16,12,10,10,16,11,16,10,16,10,9,11,16,11,16,10,16,10,9,16,16,16,16,16,16,11,9,16,16,16,16,16,16,10,9,16,16,11,16,16,16,10,9,16,16,10,11,11,16,9,7,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,2,9,6,9,6,10,8,9,8,12,9,11,9,12,10,10,16,16,14,14,15,15,13,12,5,11,7,10,8,11,9,9,9,13,9,11,10,12,10,10,15,16,14,14,14,16,12,11,10,14,9,11,11,13,10,10,12,15,10,12,12,13,11,10,16,16,14,15,14,15,12,11,5,11,8,10,7,11,9,9,9,13,9,12,9,12,10,10,15,16,13,14,13,16,12,11,7,12,8,11,9,11,9,10,9,13,9,11,10,12,9,9,16,16,13,14,13,14,11,11,10,14,10,12,11,13,10,10,11,16,11,12,12,13,10,10,16,16,13,14,13,14,12,11,10,14,11,13,10,13,10,11,12,16,12,13,10,12,11,11,16,16,14,15,13,14,12,11,11,15,11,13,11,13,10,10,12,15,12,13,11,13,11,10,15,16,14,15,13,15,12,11,12,16,12,13,12,14,11,11,13,16,12,13,12,14,11,10,16,16,13,14,13,14,11,10,3,10,6,9,7,10,8,9,9,12,9,11,10,12,9,10,15,16,14,14,14,14,12,11,6,11,7,10,8,10,9,9,9,13,9,11,10,12,9,9,15,16,13,14,14,15,12,11,10,14,9,11,11,12,10,10,12,14,10,12,11,13,10,10,15,16,13,14,14,16,12,11,6,11,8,10,7,11,9,9,9,13,9,11,9,12,9,9,15,16,14,14,13,14,12,11,7,11,8,11,8,11,9,9,9,12,9,11,9,12,9,9,15,16,13,13,13,14,11,10,10,13,10,12,11,13,10,10,11,15,10,12,11,13,10,10,14,16,12,13,13,14,11,10,10,14,11,12,9,12,10,10,11,15,11,13,10,13,10,10,15,16,14,14,13,14,12,11,10,14,10,12,10,12,10,10,11,15,11,12,10,12,10,10,15,16,13,14,12,14,11,10,12,16,11,13,12,14,11,10,12,16,12,13,11,13,10,10,15,16,12,14,12,14,11,9,7,12,9,11,9,12,10,10,11,14,11,12,11,13,11,11,16,16,15,16,15,16,13,12,8,12,9,11,9,12,10,10,11,14,11,12,11,13,10,10,16,16,14,15,15,16,13,12,11,14,10,12,11,13,10,10,12,16,11,13,12,14,11,10,16,16,14,15,14,16,12,11,8,13,9,11,9,12,10,10,11,14,11,12,11,13,10,10,16,16,15,15,14,15,13,12,9,13,9,12,9,12,10,10,11,14,10,12,10,12,10,10,16,16,14,15,14,14,12,11,11,15,11,12,11,13,11,10,12,16,11,12,12,13,11,10,16,16,13,15,14,15,11,11,11,16,11,13,10,13,11,11,12,16,12,14,11,13,11,11,16,16,14,15,14,15,13,11,11,16,11,13,11,13,11,10,12,16,12,13,10,13,11,10,16,16,14,14,12,14,12,10,12,16,12,14,12,14,11,11,13,16,12,14,12,14,11,10,15,16,12,14,12,14,11,9,9,14,11,13,11,13,11,11,13,16,12,14,13,14,12,11,16,16,16,16,16,16,14,12,9,14,10,12,10,13,11,11,12,16,12,13,13,14,11,11,16,16,16,16,16,14,13,12,10,15,11,13,11,14,11,10,13,16,12,13,12,15,11,10,16,16,14,16,15,16,13,11,10,14,10,13,11,14,11,11,13,16,12,13,12,14,11,11,16,16,16,16,15,16,13,12,10,14,10,12,10,13,10,11,12,15,12,13,12,13,11,10,16,16,14,14,15,15,13,11,11,16,11,13,11,14,11,10,12,16,11,13,12,14,11,10,16,16,13,14,14,15,12,10,11,16,12,13,11,14,11,10,13,16,13,14,12,14,11,11,16,16,15,16,15,15,12,11,11,16,12,13,11,14,11,10,13,16,12,13,11,14,11,10,16,16,14,15,13,14,12,10,12,16,12,14,12,14,10,10,12,16,11,13,11,14,10,10,14,16,11,13,12,13,10,8,0,12,6,13,7,14,11,14,8,14,10,14,11,15,13,15,16,16,16,16,16,16,16,16,5,14,7,13,10,16,12,14,9,16,10,14,12,16,13,16,16,16,16,16,16,16,16,16,10,16,9,14,14,16,13,16,12,16,11,16,16,16,14,16,16,16,16,16,16,16,16,16,5,14,9,14,8,14,12,14,9,16,11,14,11,16,13,16,16,16,16,16,16,16,16,16,8,16,10,14,11,16,12,14,10,16,11,15,12,16,13,16,16,16,16,16,16,16,16,16,12,16,12,16,14,16,14,16,13,16,12,16,15,16,14,16,16,16,16,16,16,16,16,16,10,16,13,16,11,16,14,16,13,16,14,16,13,16,14,16,16,16,16,16,16,16,16,16,12,16,14,16,13,16,14,16,13,16,14,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,15,16,16,16,14,16,16,16,16,16,16,16,16,16,1,12,6,12,8,14,11,13,8,14,10,13,11,14,13,14,16,16,16,16,16,16,16,16,5,14,7,13,10,14,11,14,9,16,10,14,12,16,13,15,16,16,16,16,16,16,16,16,9,16,9,14,13,16,13,14,12,16,11,15,14,16,13,16,16,16,16,16,16,16,16,16,5,14,9,13,8,14,12,14,9,16,11,14,11,16,13,14,16,16,16,16,16,16,16,16,7,15,9,14,10,16,12,14,9,16,10,14,11,16,12,14,16,16,16,16,16,16,15,16,11,16,11,15,14,16,13,15,12,16,11,15,14,16,13,14,16,16,14,16,16,16,14,16,10,16,13,16,10,16,13,16,12,16,14,16,12,16,13,16,16,16,16,16,16,16,16,16,11,16,13,16,12,16,13,16,12,16,13,16,12,16,13,16,16,16,16,16,16,16,15,16,14,16,14,16,16,16,14,16,15,16,14,16,14,16,14,16,16,16,16,16,16,16,14,14,4,14,8,13,9,16,12,14,9,16,11,14,11,16,13,16,16,16,16,16,16,16,16,16,6,15,8,13,10,16,12,14,10,16,11,14,12,16,13,16,16,16,16,16,16,16,16,16,9,16,9,14,13,16,13,15,12,16,11,16,14,16,13,16,16,16,16,16,16,16,16,16,6,16,9,14,9,16,12,14,10,16,11,15,12,16,13,15,16,16,16,16,16,16,16,16,8,16,10,14,11,16,12,14,10,16,11,14,12,16,13,15,16,16,16,16,16,16,16,16,11,16,11,15,14,16,13,15,12,16,11,15,14,16,13,14,16,16,14,16,16,16,14,16,10,16,13,16,10,16,13,15,13,16,14,16,12,16,14,16,16,16,16,16,16,16,16,16,11,16,13,16,12,16,13,16,12,16,13,16,11,16,13,16,16,16,16,16,15,16,15,16,14,16,14,16,15,16,14,16,14,16,14,16,14,16,14,14,16,16,14,16,15,16,14,14,6,16,9,14,10,16,12,14,10,16,11,13,12,16,13,14,16,16,16,16,16,16,14,14,7,16,9,14,10,16,12,13,11,16,11,14,12,16,12,14,16,16,16,16,16,16,14,14,9,16,9,14,12,16,11,13,12,16,11,14,12,16,12,13,16,16,14,16,16,16,13,14,7,16,10,14,10,16,12,14,11,16,11,14,11,16,12,14,16,16,16,16,16,16,14,14,8,16,10,14,10,16,11,13,10,16,11,13,11,16,12,13,16,16,14,16,16,16,14,14,10,16,9,13,12,16,11,13,11,16,10,13,12,16,11,12,16,16,13,15,15,16,13,13,9,16,11,14,9,16,11,13,12,16,12,16,12,16,12,13,16,16,16,16,15,16,14,14,10,16,11,14,10,16,11,13,11,16,12,14,10,15,11,13,16,16,15,16,13,16,13,13,12,16,11,13,12,16,11,12,12,16,11,13,11,14,11,11,13,16,12,13,12,14,11,11,0,10,5,10,6,11,8,10,7,12,8,11,8,12,9,10,14,16,13,13,13,14,12,11,4,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,11,11,9,15,8,12,12,14,10,11,11,16,9,12,12,14,10,10,14,16,11,13,13,15,11,11,4,12,8,11,6,11,9,10,8,13,9,11,8,12,9,10,14,16,12,13,13,14,11,11,7,13,8,11,9,12,9,10,8,13,9,11,9,12,9,10,14,16,12,13,12,13,11,10,11,16,10,12,12,14,10,11,11,16,10,12,12,14,10,10,15,16,11,13,13,14,11,10,10,16,11,13,9,13,10,11,11,15,12,13,10,12,10,11,15,16,13,14,12,13,11,11,11,16,11,13,10,13,10,11,12,16,11,13,10,13,10,10,15,16,13,14,12,13,11,10,13,16,12,13,13,14,11,11,14,16,12,13,12,14,11,10,16,16,13,13,13,14,11,9,3,11,6,10,6,11,9,10,8,12,8,11,9,12,9,10,14,16,13,13,13,13,12,11,5,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,11,11,9,15,8,11,11,14,10,10,11,15,9,11,12,14,10,10,14,16,11,12,13,14,11,10,5,12,8,11,7,11,9,10,8,13,9,11,9,12,9,10,14,16,12,13,13,13,11,11,7,13,8,11,8,12,9,10,8,13,8,11,9,12,9,9,13,16,11,13,12,13,11,10,10,15,9,12,11,14,10,10,11,15,9,11,11,13,10,10,14,16,11,12,13,14,10,10,9,16,11,13,9,12,10,10,11,16,11,13,9,12,10,10,15,16,13,14,12,13,11,10,11,16,11,13,10,13,10,10,11,15,11,13,9,12,10,10,14,16,12,13,11,13,10,10,13,16,12,13,12,14,11,10,13,16,11,13,12,13,10,10,14,16,11,12,12,13,10,9,7,14,8,12,9,13,10,11,10,14,10,12,11,13,11,11,16,16,14,14,14,14,12,12,7,14,8,12,9,13,10,11,10,14,10,12,11,13,10,11,16,16,13,13,14,14,12,11,10,15,9,12,12,14,10,10,12,16,9,12,12,14,10,10,16,16,12,13,14,15,12,11,8,14,9,12,9,13,10,11,10,15,10,12,10,13,10,11,16,16,14,14,14,14,12,11,8,14,9,12,9,13,10,11,10,14,10,12,10,13,10,10,15,16,13,13,13,14,12,11,10,15,10,12,12,14,10,10,11,16,9,12,12,14,10,10,14,16,11,12,13,14,11,10,11,16,11,14,9,13,10,11,12,16,12,14,10,13,11,11,16,16,14,15,13,14,12,11,11,16,12,14,10,13,11,11,11,16,11,13,10,13,10,10,15,16,13,14,12,13,11,10,13,16,12,14,13,14,11,10,12,16,11,13,12,13,10,10,14,16,11,12,11,13,10,9,10,16,10,13,11,14,11,11,12,16,11,13,12,14,11,11,16,16,14,13,14,15,12,11,10,16,10,13,10,14,11,11,12,16,11,13,11,14,11,11,16,16,14,13,14,14,12,11,11,15,9,12,11,14,10,10,13,16,10,12,12,14,10,10,16,16,13,13,14,14,11,10,10,16,10,13,11,14,11,11,12,16,11,13,12,14,11,11,16,16,14,14,14,14,12,11,9,16,10,13,10,14,11,11,11,15,11,12,11,13,11,11,16,16,13,13,14,14,12,10,10,15,9,12,11,14,10,10,11,16,9,11,11,13,10,9,15,16,11,12,13,14,10,9,11,16,11,13,10,13,10,10,13,16,12,13,11,13,10,10,16,16,14,14,13,13,11,10,11,16,11,13,10,13,10,10,12,16,11,13,10,13,10,10,15,16,13,13,12,13,11,9,11,16,11,12,11,13,10,9,11,15,10,11,11,12,9,8,13,15,10,10,10,11,8,7,0,9,3,8,5,9,7,8,5,11,6,9,8,11,8,9,16,16,16,16,16,16,11,10,2,10,4,9,7,10,7,8,7,16,7,10,9,11,8,9,16,16,11,16,16,16,11,10,7,16,7,10,10,16,8,9,10,16,8,10,11,16,9,9,16,16,16,16,16,16,11,10,3,11,6,9,6,11,8,8,7,16,8,10,8,11,8,9,16,16,15,16,16,16,11,10,5,11,7,9,8,11,8,8,7,16,7,10,8,11,8,8,16,16,11,16,16,16,10,9,9,16,8,11,11,16,9,9,10,16,8,11,11,16,9,9,16,16,10,16,16,16,10,9,8,16,10,11,8,16,9,9,11,16,11,16,10,16,10,9,16,16,16,16,16,16,11,10,9,16,10,16,10,16,9,9,10,16,10,16,9,16,9,9,16,16,16,16,15,16,10,9,16,16,11,16,16,16,10,10,13,16,11,16,11,16,10,9,16,16,10,11,11,16,9,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,6,10,7,11,9,10,8,12,9,12,9,12,10,10,16,16,14,16,14,15,13,12,5,12,7,10,9,11,9,10,9,13,9,12,10,13,10,10,16,16,14,15,14,14,13,12,10,15,10,12,12,14,11,11,12,16,11,13,12,14,11,11,16,16,14,16,15,16,13,12,6,12,8,11,8,11,10,10,9,13,10,12,10,12,10,10,15,16,13,15,13,14,12,12,7,13,9,11,9,12,10,10,9,14,10,12,10,13,10,10,15,16,13,15,13,14,12,11,11,15,11,13,12,14,11,11,12,16,11,13,12,14,11,11,16,16,13,15,14,16,12,11,10,16,12,14,10,13,11,11,12,16,12,14,11,13,11,11,16,16,15,16,14,16,13,12,11,16,12,14,11,14,11,11,12,16,12,14,11,14,11,11,16,16,14,15,13,15,12,12,13,16,13,15,13,15,12,12,13,16,12,15,12,15,11,11,16,16,13,16,13,15,12,11,4,11,7,10,7,11,9,10,9,13,9,12,10,12,10,10,15,16,14,15,14,15,13,12,6,12,7,11,9,11,9,10,9,13,9,12,10,12,10,10,15,16,14,15,14,15,12,12,10,15,9,12,12,13,11,11,12,15,11,13,12,14,11,11,16,16,13,15,14,16,12,12,6,12,8,11,8,11,9,10,9,14,10,12,10,12,10,10,14,16,13,14,13,14,12,12,8,13,9,11,9,12,10,10,9,13,9,12,9,12,9,10,14,16,13,14,13,14,12,11,11,15,11,13,11,14,11,11,12,16,10,13,12,13,11,10,15,16,12,15,13,16,12,11,10,15,11,13,10,13,11,11,12,16,12,14,11,13,11,11,16,16,14,15,13,16,13,12,11,16,11,14,11,13,11,11,12,16,12,14,10,13,11,11,15,16,13,16,12,14,12,11,12,16,12,14,12,15,11,11,13,16,12,14,12,14,11,11,15,16,13,15,13,15,11,10,7,13,9,12,10,13,11,11,11,15,12,13,12,13,11,11,16,16,15,16,16,16,14,13,8,13,9,12,10,13,11,11,12,15,11,13,12,13,11,11,16,16,14,15,15,16,13,12,11,16,11,13,12,14,11,11,13,16,12,14,13,15,12,11,16,16,14,16,15,16,13,12,9,15,10,13,10,13,11,11,12,15,11,13,11,13,11,11,16,16,14,16,16,16,13,12,9,14,10,13,10,13,11,11,11,14,11,13,11,13,11,11,16,16,14,16,14,16,12,12,11,16,11,14,12,14,12,11,12,16,11,13,13,14,11,11,16,16,13,15,14,16,12,11,12,16,12,14,11,14,11,11,13,16,13,14,12,15,12,11,16,16,16,16,14,16,13,12,12,16,12,14,11,14,12,11,12,16,12,15,11,14,11,11,16,16,14,16,13,15,12,12,13,16,13,16,13,16,12,12,13,16,12,15,12,16,11,11,14,16,12,15,12,15,11,10,9,16,11,14,12,14,12,12,13,16,13,15,14,16,12,12,16,16,16,16,16,16,14,13,10,16,11,14,12,14,12,12,13,16,13,14,13,16,12,12,16,16,15,16,16,16,13,12,11,16,11,14,12,15,12,11,13,16,12,14,13,16,12,11,16,16,14,16,16,16,13,12,11,16,11,14,12,14,12,12,13,16,12,15,13,16,12,12,16,16,16,16,16,16,14,13,10,16,11,14,11,15,11,11,13,16,12,14,12,14,12,11,16,16,14,16,16,16,13,12,11,16,11,15,12,15,12,11,13,16,11,14,13,15,12,11,16,16,13,16,14,16,12,11,12,16,12,15,11,15,12,11,14,16,13,15,12,16,12,11,16,16,15,16,14,16,13,12,11,16,12,15,11,15,11,11,13,16,13,16,11,15,11,11,16,16,14,16,13,15,12,11,12,16,12,15,12,16,11,11,12,16,11,15,12,14,11,11,13,16,12,13,11,13,10,9,0,13,6,13,8,14,12,16,8,16,11,16,12,16,14,16,16,16,16,16,16,16,16,16,4,16,7,14,11,16,13,16,9,16,11,16,12,16,14,16,16,16,16,16,16,16,16,16,10,16,10,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,10,16,8,16,13,16,10,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,8,16,10,16,11,16,13,16,10,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,12,16,12,16,16,16,16,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,11,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,13,16,16,16,14,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,13,7,13,8,16,12,16,8,16,10,16,11,16,13,16,16,16,16,16,16,16,16,16,4,16,7,14,10,16,12,16,9,16,10,16,12,16,14,16,16,16,16,16,16,16,16,16,10,16,9,16,14,16,14,16,13,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,9,16,8,16,12,16,9,16,11,16,11,16,13,16,16,16,16,16,16,16,16,16,7,16,10,16,11,16,13,16,9,16,11,16,11,16,13,16,16,16,16,16,16,16,16,16,12,16,12,16,16,16,14,16,13,16,12,16,16,16,14,16,16,16,16,16,16,16,16,16,10,16,13,16,11,16,14,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,12,16,14,16,13,16,14,16,13,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,16,8,16,9,16,13,16,10,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,6,16,8,16,11,16,13,16,10,16,11,16,13,16,14,16,16,16,16,16,16,16,16,16,9,16,9,16,13,16,13,16,13,16,12,16,16,16,14,16,16,16,16,16,16,16,16,16,6,16,10,16,10,16,13,16,10,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,8,16,10,16,11,16,13,16,10,16,11,16,12,16,14,16,16,16,16,16,16,16,16,16,11,16,11,16,16,16,14,16,12,16,11,16,16,16,14,16,16,16,16,16,16,16,16,16,10,16,13,16,10,16,13,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,12,16,13,16,12,16,14,16,12,16,15,16,12,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,10,16,10,16,13,16,11,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,8,16,9,16,11,16,12,16,11,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,9,16,9,16,12,16,12,16,13,16,11,16,13,16,13,16,16,16,16,16,16,16,16,16,8,16,10,16,10,16,12,16,11,16,12,16,12,16,13,16,16,16,16,16,16,16,16,16,8,16,10,16,11,16,12,16,10,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,10,16,10,14,12,16,12,16,11,16,10,14,13,16,12,14,16,16,14,16,16,16,14,16,9,16,12,16,10,16,12,16,13,16,13,16,12,16,13,16,16,16,16,16,16,16,16,16,10,16,12,16,11,16,12,16,11,16,12,16,11,16,12,15,16,16,16,16,16,16,16,16,13,16,12,16,13,16,12,13,12,16,12,16,12,16,12,13,16,16,13,14,13,16,13,13,0,10,5,10,5,10,8,10,6,11,8,11,8,11,9,10,14,16,13,14,13,14,12,12,4,12,5,10,8,12,9,10,7,12,8,11,9,12,9,10,14,16,12,13,13,14,12,12,9,16,8,12,12,14,10,11,11,16,9,12,12,14,11,11,14,16,12,13,14,15,12,12,4,12,7,11,6,11,9,10,8,12,9,11,8,11,9,10,14,16,12,14,13,14,12,12,7,13,8,11,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,12,13,11,11,11,16,10,12,12,14,11,11,12,16,10,12,12,14,11,11,16,16,12,13,14,15,12,11,10,16,11,14,9,13,10,11,11,16,12,14,10,13,11,11,15,16,13,14,13,14,12,12,11,16,12,14,10,13,11,11,12,16,12,14,11,13,11,11,15,16,13,14,13,14,12,11,14,16,13,14,13,15,12,12,14,16,12,14,13,15,11,11,16,16,13,14,14,15,12,11,3,11,5,10,6,11,9,10,7,12,8,11,9,11,9,10,14,16,13,13,13,14,12,12,5,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,12,12,9,16,8,11,11,14,10,11,11,16,9,12,12,14,10,11,15,16,12,13,14,15,12,11,5,12,7,11,6,11,9,10,8,13,9,11,8,11,9,10,14,16,12,14,13,13,12,12,7,13,8,11,8,12,9,10,8,12,8,11,9,12,9,10,13,16,12,13,12,13,11,11,10,16,9,12,12,14,10,11,11,15,9,12,12,14,10,11,14,16,11,13,13,14,11,11,9,16,11,14,8,13,10,11,11,16,12,13,10,13,10,11,16,16,13,15,13,14,12,12,11,16,11,14,10,13,10,11,11,16,11,13,10,13,10,11,14,16,13,14,12,13,11,11,14,16,12,14,13,15,11,11,13,16,12,13,12,14,11,11,14,16,12,13,12,13,11,10,6,14,8,12,9,13,10,11,10,14,10,12,11,13,11,12,16,16,14,14,14,14,13,12,7,14,8,12,9,13,10,11,10,14,10,12,11,13,11,11,16,16,13,14,14,15,13,12,10,16,8,12,12,14,10,11,12,16,10,12,13,15,11,11,16,16,13,14,15,16,12,12,8,15,9,13,9,13,10,11,10,15,10,13,10,13,11,11,16,16,14,14,14,14,13,12,8,15,9,12,10,13,10,11,10,14,10,12,10,13,10,11,16,16,13,14,13,14,12,12,10,16,10,13,12,15,11,11,11,16,9,12,12,14,11,11,14,16,11,13,14,16,12,11,10,16,12,14,9,13,11,11,12,16,12,14,11,13,11,11,16,16,15,16,14,14,13,12,11,16,12,14,11,14,11,11,11,16,12,14,10,13,11,11,15,16,13,15,12,14,12,11,14,16,13,14,13,16,12,12,12,16,12,13,12,14,11,11,14,16,11,12,12,13,10,10,9,16,10,14,11,15,12,12,12,16,11,13,12,15,12,12,16,16,14,13,15,15,13,12,10,16,10,14,11,15,11,12,12,16,11,13,12,14,12,12,16,16,14,13,15,14,13,12,11,16,9,12,12,14,11,11,13,16,11,13,13,15,11,11,16,16,14,14,16,16,12,12,10,16,10,14,11,14,11,12,12,16,11,13,12,14,12,12,16,16,14,14,15,15,13,12,10,16,10,13,11,14,11,12,11,16,11,13,11,14,11,12,16,16,14,14,14,14,13,12,11,16,10,12,12,15,11,11,12,16,9,12,12,14,10,11,16,16,12,13,14,15,11,11,11,16,12,14,10,14,11,11,13,16,12,14,12,14,11,11,16,16,15,15,14,15,12,12,11,16,12,14,11,14,11,11,12,16,12,14,11,13,11,11,16,16,14,14,13,14,12,11,12,16,11,13,12,14,10,10,12,15,11,12,12,13,10,10,14,15,11,11,12,12,10,9,0,8,3,8,5,9,7,8,5,10,6,10,8,11,8,9,16,16,15,16,16,16,11,11,2,10,4,9,7,10,7,8,7,16,7,10,9,11,8,9,16,16,15,16,16,16,11,11,7,16,6,11,10,16,9,10,10,16,9,11,11,16,9,10,16,16,16,16,16,16,16,11,3,10,6,9,5,10,7,9,7,16,8,10,8,11,8,9,16,16,16,16,16,16,11,11,5,11,7,10,8,11,8,9,7,14,7,10,8,11,8,9,16,16,11,16,16,16,10,11,9,16,9,11,11,16,9,10,10,16,8,11,11,16,9,10,16,16,11,16,16,16,11,10,8,16,9,16,7,16,9,10,11,16,11,16,10,16,10,10,16,16,16,16,16,16,16,11,9,16,10,16,9,16,9,10,10,16,10,16,9,16,9,10,16,16,16,16,11,16,11,11,16,16,16,16,16,16,10,10,11,16,11,16,11,16,10,10,16,16,11,16,11,16,10,9,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,6,10,7,11,9,10,8,12,9,12,9,12,10,10,15,16,14,15,14,16,13,12,5,12,7,11,8,11,9,10,9,13,9,12,10,12,10,10,16,16,14,15,13,16,13,12,10,15,10,13,12,14,11,11,12,16,11,13,12,14,11,11,16,16,14,16,14,16,13,12,5,12,8,11,7,11,9,10,9,13,10,12,9,12,10,10,14,16,14,15,13,14,13,12,7,13,9,12,9,12,10,10,9,13,9,12,9,12,10,10,14,16,13,14,13,15,12,12,11,16,11,13,12,14,11,11,12,16,11,14,12,14,11,11,16,16,14,16,14,16,13,12,10,16,11,14,10,13,11,11,12,16,12,14,11,13,11,11,15,16,15,16,14,16,13,12,11,16,12,14,11,14,11,12,12,16,12,14,11,14,11,11,15,16,14,16,13,16,13,12,13,16,13,16,13,16,12,12,13,16,13,16,13,16,12,12,16,16,14,15,14,16,13,12,4,11,7,10,7,11,9,10,9,13,9,11,9,12,10,10,15,16,14,15,14,15,13,12,6,12,7,11,8,11,9,10,9,13,9,12,10,12,10,10,15,16,13,14,14,15,12,12,10,14,10,12,12,13,11,11,12,16,11,13,12,14,11,11,16,16,14,15,15,16,13,12,6,12,8,11,8,11,9,10,9,13,10,12,9,12,10,10,16,16,14,15,13,14,12,12,8,13,9,11,9,12,9,10,9,13,9,12,9,12,9,10,14,16,13,14,13,14,12,11,11,15,11,13,12,14,11,11,11,16,10,13,12,14,11,11,15,16,13,15,14,16,12,11,10,16,12,13,10,13,11,11,11,16,12,14,10,13,11,11,16,16,14,16,13,16,13,12,11,16,12,14,10,14,11,11,11,16,12,14,10,13,11,11,16,16,14,16,12,15,12,11,13,16,13,15,13,15,12,12,13,16,12,15,12,15,12,11,15,16,13,16,13,16,12,11,8,14,9,12,10,13,11,11,11,16,11,13,11,13,11,11,16,16,16,16,16,16,14,13,9,14,10,12,10,13,11,11,11,16,11,13,12,13,11,11,16,16,15,16,15,16,14,12,11,16,11,13,12,14,12,11,13,16,12,14,13,14,12,11,16,16,15,16,16,16,14,13,9,14,10,13,10,13,11,11,11,16,11,13,11,13,11,11,16,16,15,16,14,15,14,13,9,14,10,13,10,13,11,11,11,15,11,13,11,13,11,11,16,16,14,16,14,16,13,12,12,16,12,14,13,14,12,11,12,16,11,14,12,15,12,11,16,16,13,16,15,16,13,11,11,16,12,14,11,14,12,11,13,16,13,15,12,14,12,12,16,16,16,16,14,16,14,13,12,16,13,15,11,14,12,12,12,16,13,14,11,15,12,11,16,16,15,16,13,15,13,12,13,16,13,15,13,16,12,12,13,16,13,15,13,15,12,12,15,16,13,16,13,15,11,10,10,16,12,14,12,15,12,12,14,16,13,15,13,16,13,12,16,16,16,16,16,16,15,13,10,16,12,14,12,15,12,12,13,16,13,15,13,15,13,12,16,16,16,16,16,16,14,13,11,16,12,15,13,16,12,12,14,16,13,16,13,16,12,12,16,16,15,16,15,16,14,12,11,16,12,14,12,16,12,12,14,16,13,15,13,15,13,12,16,16,16,16,16,16,15,13,11,16,12,14,12,15,12,12,13,16,12,14,12,15,12,12,16,16,16,16,16,16,14,12,12,16,12,15,13,16,12,12,13,16,12,15,13,15,12,11,16,16,14,16,15,16,13,12,12,16,13,16,12,16,12,12,15,16,14,16,13,16,12,12,16,16,16,16,16,16,14,13,12,16,13,15,12,16,12,12,13,16,13,15,12,15,12,12,16,16,15,16,14,16,13,12,13,16,13,16,12,16,12,12,13,16,12,16,12,15,12,12,14,16,12,14,12,14,11,10,0,16,6,16,8,16,16,16,9,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,4,16,7,16,11,16,16,16,10,16,11,16,13,16,16,16,16,16,16,16,16,16,16,16,10,16,10,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,10,16,9,16,16,16,10,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,12,16,16,16,10,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,16,7,16,8,16,13,16,9,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,4,16,7,16,11,16,13,16,9,16,11,16,13,16,16,16,16,16,16,16,16,16,16,16,9,16,9,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,4,16,10,16,8,16,16,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,7,16,10,16,11,16,16,16,9,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,12,16,12,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,11,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,13,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,16,8,16,10,16,16,16,10,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,6,16,8,16,11,16,16,16,10,16,12,16,15,16,16,16,16,16,16,16,16,16,16,16,9,16,9,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,10,16,10,16,16,16,11,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,11,16,16,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,11,16,12,16,16,16,16,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,12,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,10,16,11,16,16,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,8,16,9,16,11,16,13,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,9,16,9,16,13,16,12,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,10,16,10,16,14,16,12,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,9,16,11,16,11,16,13,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,13,16,12,16,12,16,11,16,16,16,13,16,16,16,16,16,16,16,16,16,9,16,12,16,10,16,13,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,10,16,13,16,11,16,13,16,12,16,13,16,12,16,13,16,16,16,16,16,16,16,16,16,13,16,13,16,16,16,12,16,13,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,0,10,4,10,5,11,9,11,6,11,8,11,8,12,10,12,15,16,13,15,14,15,13,14,4,12,5,11,8,12,9,11,7,13,8,12,9,13,10,12,15,16,13,15,14,16,13,14,10,16,9,13,12,16,11,13,11,16,10,14,13,16,12,13,16,16,14,16,15,16,14,15,4,12,7,12,6,12,9,11,8,13,9,12,9,12,10,12,15,16,13,15,14,15,13,14,7,13,8,12,9,13,10,12,8,13,9,12,9,13,10,12,14,16,13,15,13,15,13,14,12,16,11,14,13,16,12,13,12,16,11,14,13,16,12,13,16,16,14,16,15,16,14,15,10,16,12,16,10,14,12,13,12,16,13,16,11,14,12,13,16,16,16,16,15,16,14,15,12,16,13,16,11,15,12,13,13,16,13,16,12,15,12,14,16,16,16,16,14,16,13,14,16,16,14,16,14,16,13,15,16,16,14,16,14,16,13,15,16,16,16,16,16,16,14,16,2,11,5,11,6,11,9,11,7,12,8,11,9,12,10,12,15,16,14,14,14,14,13,14,4,13,6,11,8,12,9,11,8,13,8,12,10,13,10,12,15,16,13,15,14,15,13,14,9,16,8,13,12,15,11,12,11,16,10,14,13,16,12,13,16,16,14,16,16,16,14,15,5,13,8,12,7,12,9,11,8,13,9,12,9,12,10,12,16,16,14,15,14,15,13,13,7,13,8,12,9,13,10,12,8,13,8,12,9,13,10,12,14,16,13,14,13,15,12,13,11,16,10,14,13,16,12,13,11,16,10,13,12,15,11,13,14,16,12,14,14,16,13,14,10,16,12,15,9,14,11,13,12,16,12,16,11,14,12,13,16,16,15,16,16,16,14,15], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+492792);
/* memory initializer */ allocate([11,16,12,15,11,15,12,13,12,16,12,15,11,14,12,13,16,16,14,16,13,15,13,14,15,16,14,16,14,16,13,14,14,16,13,16,14,16,13,14,16,16,14,16,14,16,13,14,7,15,8,13,9,14,11,13,10,14,10,13,11,14,12,13,16,16,15,16,15,16,15,14,7,16,8,13,10,14,11,13,11,15,10,13,12,14,12,13,16,16,16,16,16,16,15,15,10,16,9,13,13,16,12,13,13,16,11,14,14,16,13,14,16,16,16,16,16,16,15,16,8,16,10,14,9,14,11,13,11,16,11,14,11,14,12,13,16,16,16,16,16,16,14,15,8,16,10,14,10,14,11,13,10,15,10,14,11,14,12,13,16,16,14,16,15,16,14,14,11,16,10,14,13,16,12,13,11,16,10,13,13,16,12,13,16,16,13,16,16,16,14,14,11,16,12,16,10,15,12,13,14,16,14,16,12,16,13,14,16,16,16,16,16,16,16,16,12,16,13,16,11,16,12,14,12,16,13,16,11,14,12,13,16,16,16,16,14,16,14,14,15,16,14,16,16,16,13,14,13,16,13,15,14,16,13,14,14,16,13,14,14,15,13,14,9,16,11,16,12,16,13,14,12,16,12,15,13,16,13,14,16,16,16,15,16,16,15,15,10,16,10,16,12,16,12,14,12,16,12,14,13,16,13,14,16,16,16,16,16,16,15,15,11,16,10,14,14,16,12,13,14,16,12,16,14,16,13,14,16,16,16,16,16,16,16,15,10,16,12,16,11,16,12,14,13,16,12,15,13,16,13,14,16,16,16,16,16,16,16,15,10,16,11,16,12,16,12,14,12,16,12,15,13,16,13,14,16,16,16,16,16,16,14,14,11,16,10,14,14,16,12,13,13,16,11,14,14,16,12,13,16,16,15,16,16,16,14,14,12,16,13,16,11,16,12,14,15,16,14,16,13,16,13,14,16,16,16,16,16,16,14,16,12,16,13,16,12,16,12,14,13,16,13,16,12,16,12,13,16,16,16,16,16,16,14,15,13,16,13,16,14,16,12,13,13,16,13,14,14,16,12,13,16,16,14,14,14,15,13,13,0,9,3,9,5,9,7,9,5,10,7,11,8,11,9,10,16,16,16,16,16,16,16,16,2,11,4,10,7,11,8,10,7,16,7,11,9,16,9,11,16,16,16,16,16,16,16,16,8,16,7,16,11,16,10,11,11,16,10,16,16,16,11,16,16,16,16,16,16,16,16,16,2,11,6,10,6,10,8,10,7,16,8,16,8,11,9,11,16,16,16,16,16,16,16,16,5,13,7,11,8,11,9,11,6,12,8,12,8,12,9,11,16,16,16,16,16,16,16,16,10,16,10,16,12,16,10,13,10,16,9,16,11,16,11,12,16,16,16,16,16,16,16,16,8,16,10,16,8,16,10,12,11,16,12,16,10,16,11,16,16,16,16,16,16,16,16,16,10,16,11,16,10,16,11,16,11,16,12,16,10,16,11,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,5,10,6,10,9,10,7,12,9,12,9,12,10,10,16,16,15,16,14,16,13,13,5,12,7,11,8,11,9,10,8,13,9,12,10,12,10,11,16,16,16,16,14,16,13,12,10,16,10,13,12,14,12,12,12,16,11,14,13,15,12,12,16,16,16,15,16,16,14,13,5,12,8,11,7,11,9,10,8,13,10,12,9,12,10,10,15,16,14,15,14,14,13,13,7,13,9,12,9,12,10,10,9,13,10,13,10,13,10,10,14,16,14,15,14,16,13,12,11,16,12,14,12,15,12,12,12,16,12,15,13,16,12,12,16,16,15,16,16,16,14,13,10,16,12,14,10,14,12,12,12,16,13,14,11,14,12,12,16,16,16,16,14,16,14,13,11,16,12,14,11,14,12,12,12,16,13,16,11,15,12,12,16,16,16,16,14,16,14,13,13,16,14,16,14,16,13,13,13,16,13,16,13,16,13,12,16,16,16,16,16,16,13,13,4,11,7,10,7,11,9,10,8,12,9,12,9,12,10,11,15,16,14,15,14,16,13,13,6,12,7,11,8,11,9,10,9,13,9,12,10,12,10,10,16,16,15,16,15,16,13,12,10,16,10,13,12,14,12,11,12,16,11,14,13,14,12,12,16,16,16,14,16,16,14,13,6,12,8,11,7,11,9,10,9,14,10,12,9,12,10,10,15,16,14,16,14,16,14,13,7,13,9,12,9,12,10,10,9,13,9,12,9,12,10,10,14,16,13,14,14,16,12,11,11,16,11,14,12,14,12,12,12,16,11,14,12,14,12,11,16,16,13,16,14,16,13,12,10,16,12,14,10,14,11,11,12,16,13,14,11,14,12,12,16,16,16,16,14,16,13,13,11,16,12,16,11,14,12,12,12,16,12,14,11,14,12,11,16,16,15,16,13,15,13,12,13,16,14,16,13,16,13,12,13,16,13,16,13,16,13,12,16,16,14,16,14,16,12,11,8,13,10,12,10,13,11,11,11,14,12,14,12,14,12,12,16,16,16,16,16,16,14,13,9,14,10,13,10,13,11,11,12,16,12,13,12,13,12,11,16,16,16,16,16,16,15,14,12,16,11,14,13,15,12,12,13,16,12,15,14,15,13,12,16,16,16,16,16,16,15,13,9,14,11,13,10,13,11,11,11,16,12,14,12,14,12,12,16,16,16,16,16,16,16,13,10,15,11,13,11,14,12,11,11,16,12,14,11,14,12,11,16,16,16,16,16,16,14,12,12,16,12,14,13,15,13,12,12,16,12,14,13,15,12,12,16,16,14,16,16,16,14,12,12,16,13,16,11,14,12,12,14,16,14,16,12,16,13,12,16,16,16,16,16,16,16,13,12,16,13,16,12,16,13,12,12,16,13,16,12,16,12,12,16,16,16,16,14,16,14,12,14,16,14,16,14,16,14,13,13,16,13,16,13,16,13,12,16,16,13,16,13,16,12,11,9,16,12,15,13,16,13,12,13,16,14,16,14,16,14,13,16,16,16,16,16,16,16,14,10,16,12,15,12,15,13,12,13,16,14,16,13,16,13,12,16,16,16,16,16,16,16,13,12,16,12,16,13,16,13,12,14,16,13,16,14,16,13,12,16,16,16,16,16,16,16,13,11,16,12,15,12,16,13,12,14,16,14,16,13,16,13,13,16,16,16,16,16,16,15,13,11,16,12,16,12,16,13,12,13,16,13,15,13,16,13,12,16,16,16,16,16,16,15,13,12,16,12,16,13,16,13,12,13,16,12,16,13,16,13,12,16,16,14,16,16,16,14,12,12,16,14,16,11,16,13,12,14,16,14,16,13,16,13,12,16,16,16,16,16,16,16,13,12,16,13,16,12,16,13,12,13,16,13,16,12,16,13,12,16,16,16,16,14,16,14,12,13,16,13,16,13,16,13,13,13,16,12,16,12,16,12,12,14,16,13,15,13,16,12,11,8,10,10,10,10,10,11,10,10,11,10,10,10,10,10,6,12,12,13,12,13,12,13,11,13,13,13,12,13,12,12,8,14,13,16,13,15,13,16,12,16,16,16,14,16,13,14,10,12,13,12,12,13,13,13,12,13,13,12,12,13,12,12,8,13,14,14,12,14,14,14,12,14,15,14,12,14,13,13,8,16,16,16,12,16,16,16,13,16,16,16,13,16,14,14,9,14,16,13,13,16,16,16,14,15,16,14,13,15,15,14,10,16,16,14,13,16,16,16,13,16,16,16,13,16,15,14,10,16,16,16,11,16,16,16,12,16,16,16,12,16,16,15,9,12,13,13,13,12,12,14,12,12,14,13,12,12,12,12,8,14,14,16,14,13,12,14,12,14,15,14,13,13,12,13,8,16,16,16,15,16,13,16,13,16,16,16,15,16,13,15,10,14,16,14,14,14,14,15,13,14,16,14,13,13,13,13,9,16,16,16,14,16,14,16,12,16,16,14,13,14,13,13,8,16,16,16,14,16,14,16,13,16,16,16,14,16,14,14,9,16,16,16,16,16,16,16,16,16,16,16,14,16,16,14,10,16,16,16,14,16,16,16,13,16,16,16,14,16,15,14,9,16,16,16,13,16,16,16,12,16,16,16,13,16,15,15,8,14,16,16,16,14,14,16,14,16,16,16,15,13,13,14,10,16,16,16,16,15,13,16,13,16,16,16,16,16,13,14,10,16,16,16,16,16,11,16,12,16,16,16,16,16,12,16,9,16,16,16,16,16,16,16,15,16,16,16,16,16,14,14,10,16,16,16,16,16,15,16,13,16,16,16,15,16,13,14,9,16,16,16,16,16,13,16,12,16,16,16,16,16,13,14,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,16,16,16,16,16,16,16,14,16,16,16,16,16,16,14,9,16,16,16,14,16,15,16,11,16,16,16,14,16,14,14,8,12,13,13,13,13,13,14,12,12,13,12,12,12,12,12,8,14,14,16,14,15,14,16,13,14,15,14,13,14,13,13,9,16,16,16,15,16,16,16,14,16,16,16,14,16,14,16,10,14,15,14,14,15,14,15,13,14,14,13,12,13,13,13,9,15,16,15,14,16,16,16,13,15,16,14,12,14,13,13,8,16,16,16,14,16,16,16,13,16,16,16,13,16,14,14,9,16,16,16,16,16,16,16,15,16,16,13,13,16,16,14,10,16,16,16,14,16,16,16,14,16,16,15,13,16,14,14,9,16,16,16,12,16,16,16,13,16,16,16,12,16,16,15,8,13,14,14,14,14,14,16,13,13,14,14,13,12,12,12,8,16,16,16,14,15,14,16,13,15,16,14,13,13,12,13,8,16,16,16,16,16,14,16,14,16,16,16,14,16,13,14,9,15,16,16,15,16,15,16,13,14,16,14,13,13,13,12,8,16,16,16,14,16,14,15,12,15,15,14,12,13,12,12,7,16,16,16,14,16,14,16,12,16,16,16,13,16,13,13,7,16,16,16,16,16,16,16,14,16,16,14,14,16,14,13,9,16,16,16,14,16,16,16,13,16,16,14,12,16,13,12,7,16,16,16,12,16,16,16,11,16,16,15,12,16,13,13,6,16,16,16,16,16,16,16,15,16,16,16,15,13,13,14,10,16,16,16,16,16,14,16,14,16,16,16,16,14,13,14,9,16,16,16,16,16,13,16,13,16,16,16,16,16,12,14,8,16,16,16,16,16,16,16,14,16,16,16,14,14,13,13,9,16,16,16,16,16,14,16,13,16,16,16,13,14,12,12,7,16,16,16,16,16,13,16,12,16,16,16,13,14,12,13,6,16,16,16,16,16,16,16,16,16,16,16,16,16,15,14,9,16,16,16,16,16,16,16,13,16,16,16,13,15,13,12,7,16,16,16,13,16,14,16,11,16,16,16,12,16,12,12,5,14,16,15,16,16,16,16,15,14,15,14,14,13,14,13,10,16,16,16,16,16,16,16,16,16,16,16,14,16,14,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,16,14,16,14,14,15,14,13,10,16,16,16,16,16,16,16,15,16,16,14,13,16,14,14,9,16,16,16,16,16,16,16,16,16,16,16,14,16,16,15,9,16,16,16,16,16,16,16,16,16,16,12,13,16,16,13,10,16,16,16,16,16,16,16,16,16,16,13,13,16,16,13,9,16,16,16,14,16,16,16,14,16,16,15,12,16,16,14,8,16,16,16,16,16,16,16,16,14,16,15,14,13,13,13,9,16,16,16,16,16,16,16,14,16,16,16,14,14,13,13,9,16,16,16,16,16,16,16,16,16,16,16,16,16,14,15,9,16,16,16,16,16,16,16,15,15,16,14,14,14,13,13,9,16,16,16,16,16,16,16,13,16,16,14,12,13,12,12,7,16,16,16,16,16,16,16,13,16,16,16,13,16,13,13,7,16,16,16,16,16,16,16,16,16,16,13,13,16,14,13,9,16,16,16,15,16,16,16,13,16,16,13,12,14,13,12,6,16,16,16,13,16,16,16,12,16,16,14,10,15,12,12,5,16,16,16,16,16,16,16,16,16,16,16,16,12,13,13,9,16,16,16,16,16,16,16,14,16,16,16,15,13,12,13,8,16,16,16,16,16,14,16,14,16,16,16,16,15,12,14,8,16,16,16,16,16,16,16,16,16,16,16,14,13,13,13,8,16,16,16,16,16,16,16,13,16,16,15,13,12,11,12,6,16,16,16,15,16,14,16,12,16,16,16,12,13,10,12,5,16,16,16,16,16,16,16,16,16,16,14,14,13,14,12,8,16,16,16,16,16,16,16,13,16,16,13,12,13,12,10,5,16,16,16,13,16,13,16,10,16,16,13,10,13,10,10,1,2,7,7,8,7,8,9,8,7,9,8,8,8,8,9,7,6,9,10,10,10,10,11,10,10,11,11,11,10,11,11,9,9,11,12,12,12,13,14,13,13,14,14,13,13,13,14,11,6,10,9,10,10,11,11,11,10,11,10,11,11,11,11,9,6,9,10,10,10,11,12,11,10,12,11,11,11,11,11,8,9,11,12,12,12,13,13,13,12,14,14,13,13,13,13,10,9,13,11,13,13,14,14,13,13,14,13,13,14,14,14,12,9,12,12,12,12,14,14,13,13,14,13,13,13,14,13,11,8,12,12,11,12,14,14,12,13,14,14,13,13,13,14,11,6,10,10,11,9,10,12,11,10,12,11,11,10,11,11,9,7,10,10,11,10,11,12,11,11,12,11,11,11,11,11,9,9,12,13,13,12,12,14,13,13,14,14,13,14,13,14,11,8,11,11,12,11,12,12,12,11,13,12,12,12,12,12,10,7,10,10,11,10,11,12,11,10,12,11,11,11,11,11,8,9,11,12,12,12,12,13,12,12,13,13,12,13,12,13,10,10,13,13,14,14,14,15,14,14,15,14,15,14,14,14,12,9,12,12,13,12,13,14,13,12,13,13,12,13,13,13,10,9,12,12,12,12,13,14,12,12,14,13,12,13,13,13,10,9,12,13,13,11,13,14,13,13,14,14,14,12,13,13,11,10,12,13,13,12,12,14,13,13,14,14,14,13,13,14,11,10,13,14,14,13,12,15,13,14,14,14,14,15,13,14,11,11,14,14,14,13,14,15,14,14,15,15,14,13,14,14,12,10,13,12,13,12,12,14,13,13,14,13,13,13,13,13,10,10,12,13,13,13,12,14,12,13,14,14,13,13,13,13,10,13,15,16,16,15,15,16,16,15,16,15,16,16,16,16,14,11,14,14,14,14,14,15,14,14,15,15,14,14,14,15,11,10,13,13,13,13,13,14,12,13,14,14,13,13,13,13,10,6,10,10,11,10,11,12,11,10,12,10,11,10,11,11,9,8,11,11,12,11,12,13,12,11,12,12,12,12,12,12,10,11,13,14,14,13,14,15,14,13,15,15,14,14,14,15,12,7,11,10,12,11,12,12,12,11,12,11,12,11,12,12,10,7,10,10,11,10,11,12,11,11,12,11,11,11,11,11,9,10,12,13,13,12,13,14,13,13,14,13,13,13,13,13,10,10,13,12,14,13,14,14,14,13,14,12,14,15,14,14,11,10,12,12,12,12,13,14,13,13,14,13,12,13,13,13,10,9,12,13,13,13,14,14,13,13,14,14,13,13,13,13,10,7,10,10,11,10,11,12,11,10,12,12,11,9,11,11,9,7,10,11,11,10,11,12,11,10,12,12,11,11,11,11,9,10,12,13,13,13,13,15,13,13,14,13,13,13,13,13,10,8,11,11,11,11,11,12,11,11,12,12,11,11,12,11,9,6,9,9,10,9,10,10,10,9,11,10,10,9,10,10,7,8,10,11,11,11,11,12,11,11,12,12,11,11,11,11,8,10,13,13,13,13,14,14,13,13,14,13,13,13,13,13,11,8,11,11,11,11,12,12,11,11,12,11,11,11,11,11,8,8,11,11,11,11,12,12,10,11,12,12,11,11,11,11,8,10,13,13,13,12,13,14,13,12,14,14,14,10,13,13,11,10,12,12,13,12,13,14,12,12,13,13,13,12,12,13,10,11,13,14,14,13,13,14,13,13,15,14,13,13,13,13,10,10,12,13,13,12,13,14,13,13,14,14,13,12,13,13,11,8,11,11,11,11,11,12,11,11,12,12,11,11,11,11,8,9,11,12,12,11,11,12,11,12,12,12,11,12,11,11,8,12,15,14,14,14,15,15,14,14,15,15,14,14,14,15,12,10,12,12,12,12,12,13,12,12,13,13,12,12,12,12,9,9,11,11,11,11,11,12,10,11,12,12,11,11,11,11,7,10,13,13,13,13,14,15,14,13,14,14,14,12,14,15,12,11,14,14,14,14,15,15,14,14,15,15,15,14,15,15,12,13,16,16,16,15,16,16,16,15,16,16,16,16,16,16,14,10,13,13,14,13,15,14,14,13,15,13,14,14,14,14,12,10,13,13,13,13,13,14,13,13,14,13,13,13,13,14,11,12,14,14,14,14,15,15,14,14,15,15,14,15,14,14,12,11,14,14,15,14,15,15,14,14,15,12,14,15,16,15,12,11,13,13,14,13,14,14,14,14,14,13,13,14,14,14,11,11,14,14,14,14,15,15,14,14,16,14,13,14,14,14,11,10,13,13,13,12,14,14,14,12,15,14,14,11,13,13,12,10,12,13,14,12,13,14,13,13,14,14,13,12,13,13,11,12,14,14,15,14,15,16,15,15,15,15,15,14,14,15,12,10,13,13,13,12,13,14,13,13,14,13,13,12,13,13,11,9,11,11,12,11,12,12,11,11,12,12,11,11,11,11,9,10,12,12,12,12,12,13,12,12,13,13,12,13,12,12,9,11,13,13,15,14,14,15,14,14,15,14,14,14,14,14,11,10,12,12,12,12,12,13,12,12,13,11,11,12,12,12,8,9,12,12,11,12,12,13,11,12,12,12,11,12,11,11,8,10,13,13,14,12,14,15,14,13,15,15,14,10,13,13,11,11,13,14,13,13,14,14,13,13,14,14,14,11,13,13,11,12,14,14,14,14,14,15,14,15,16,15,14,13,13,14,11,11,14,13,14,13,14,15,14,13,15,14,14,11,13,13,11,9,12,12,12,11,12,13,11,12,13,12,11,10,11,11,8,10,12,12,12,12,12,13,11,12,12,12,11,11,11,11,8,12,15,14,15,14,15,16,15,15,15,15,14,14,14,14,12,10,12,12,12,12,12,13,11,12,13,12,11,11,11,11,8,8,10,10,10,10,10,11,9,10,11,10,9,10,9,9,5,12,12,11,9,11,10,11,9,11,11,10,9,9,8,9,5,14,13,14,11,14,11,13,10,14,13,12,10,12,10,11,6,16,13,16,12,16,12,16,11,16,14,16,12,15,12,13,8,14,14,12,11,14,12,13,10,13,13,11,10,12,11,10,6,16,15,14,11,16,13,14,10,15,14,13,10,13,11,11,7,16,16,16,11,16,14,16,11,16,16,15,12,15,13,13,8,16,16,13,12,16,16,15,12,16,16,12,11,15,13,12,8,16,16,14,11,16,16,16,11,16,16,14,11,15,14,13,8,16,16,15,10,16,16,16,10,16,16,15,11,16,14,14,8,14,14,14,12,13,11,13,10,13,13,12,11,11,10,10,6,16,15,16,13,13,11,14,11,15,14,13,11,12,10,11,7,16,15,16,14,16,11,16,11,16,16,16,13,16,12,13,8,16,16,14,13,15,13,14,11,14,15,13,11,13,11,11,7,16,16,15,13,15,13,14,11,16,15,14,11,13,11,11,7,16,16,16,13,16,13,16,11,16,16,16,12,16,12,13,8,16,16,16,14,16,16,16,13,16,16,14,13,15,14,13,9,16,16,16,13,16,16,16,12,16,16,14,12,15,13,13,8,16,16,16,12,16,16,16,11,16,16,15,12,16,13,13,7,16,16,16,16,13,12,16,12,16,16,14,13,12,11,12,8,16,16,16,15,14,11,16,11,16,16,16,13,14,11,13,8,16,16,16,16,15,10,16,11,16,16,16,14,15,11,13,8,16,16,16,16,16,14,16,13,16,16,14,14,14,12,13,9,16,16,16,15,16,13,16,12,16,16,16,13,14,12,13,8,16,16,16,14,16,12,16,11,16,16,16,13,15,12,13,7,16,16,16,16,16,16,16,14,16,16,16,15,16,14,13,9,16,16,16,16,16,16,16,12,16,16,16,14,16,13,13,8,16,16,16,14,16,14,16,10,16,16,16,13,16,13,13,7,14,14,13,12,13,12,13,11,12,13,11,10,11,10,10,6,16,16,15,13,16,13,15,11,14,14,13,11,13,11,11,7,16,16,16,14,16,14,16,12,16,16,16,13,16,13,14,9,16,16,13,13,15,14,14,11,13,14,11,11,12,11,11,7,16,16,15,12,16,14,15,11,14,14,12,11,13,11,11,7,16,16,16,13,16,14,16,12,16,16,14,12,16,13,13,8,16,16,14,14,16,16,16,13,16,16,12,11,15,13,12,8,16,16,15,13,16,16,16,12,16,16,13,11,16,13,12,8,16,16,16,11,16,16,16,11,16,16,14,11,16,14,13,7,16,16,15,13,14,13,14,11,14,14,12,11,11,10,11,7,16,16,16,13,14,12,15,11,15,14,13,11,12,11,11,7,16,16,16,14,16,13,16,12,16,16,16,13,14,12,13,8,16,16,15,13,15,14,14,12,14,14,12,11,12,11,11,7,16,16,14,12,15,13,14,11,15,14,13,11,12,11,11,6,16,16,16,13,16,13,16,11,16,15,14,11,14,11,12,6,16,16,16,14,16,16,16,13,16,16,13,12,14,13,12,8,16,16,15,13,16,14,15,11,16,16,13,11,14,12,11,6,16,16,16,12,16,14,15,11,16,16,13,10,14,12,12,6,16,16,16,16,16,14,16,13,16,16,14,13,12,11,12,8,16,16,16,16,16,13,16,12,16,16,15,13,13,11,12,8,16,16,16,15,16,12,16,12,16,16,16,14,14,11,13,7,16,16,16,16,16,15,16,13,16,16,14,13,13,12,12,8,16,16,16,14,15,13,15,11,16,15,14,12,13,11,11,6,16,16,16,14,16,12,15,11,16,16,15,12,14,11,12,6,16,16,16,16,16,16,16,13,16,16,15,13,14,13,12,8,16,16,16,14,16,14,16,12,16,16,14,12,13,12,11,6,16,16,16,13,16,13,15,10,16,16,14,11,14,11,11,5,16,16,15,14,16,16,16,13,14,14,12,12,12,12,12,8,16,16,16,15,16,16,16,14,16,16,14,13,14,13,13,9,16,16,16,16,16,16,16,14,16,16,16,14,16,13,15,9,16,16,14,15,16,16,16,14,14,16,12,12,13,13,12,8,16,16,16,14,16,16,16,13,16,15,13,12,14,12,12,8,16,16,16,16,16,16,16,13,16,16,14,12,16,13,13,8,16,16,16,15,16,16,16,14,16,16,11,11,15,14,12,8,16,16,16,14,16,16,16,13,16,16,12,11,15,13,12,8,16,16,16,13,16,16,16,12,16,16,13,10,16,13,12,7,16,16,16,16,16,15,16,13,14,16,13,13,12,12,12,8,16,16,16,15,16,14,16,13,16,16,14,13,13,12,12,8,16,16,16,16,16,15,16,13,16,16,16,13,15,12,14,8,16,16,16,15,16,16,16,13,14,16,13,12,12,12,11,8,16,16,16,14,16,14,16,12,14,14,13,11,13,11,11,6,16,16,16,14,16,14,16,12,16,15,14,11,14,11,12,6,16,16,16,15,16,16,16,14,16,16,12,12,14,13,11,8,16,16,15,14,16,16,16,12,16,15,12,11,13,12,11,6,16,16,16,13,16,14,16,11,16,14,13,10,14,11,11,5,16,16,16,16,16,16,16,14,14,16,15,13,11,11,11,8,16,16,16,16,16,15,16,13,16,16,16,13,12,11,12,7,16,16,16,16,16,13,16,12,16,16,16,13,13,11,13,7,16,16,16,16,16,16,16,13,16,16,14,13,12,12,11,7,16,16,16,15,16,14,15,12,16,14,13,12,12,11,11,6,16,16,16,14,16,13,15,11,16,14,14,11,13,10,11,5,16,16,16,16,16,16,16,13,16,16,13,12,12,12,11,7,16,16,16,14,16,14,15,12,16,15,12,11,12,11,10,5,16,16,16,13,16,13,14,10,16,14,12,9,12,10,9,3,2,6,6,7,6,7,8,7,7,8,7,8,7,8,8,5,5,8,9,9,9,9,12,10,10,11,10,10,10,11,11,8,9,10,13,12,13,12,15,13,13,14,13,14,13,13,14,11,5,10,9,10,10,10,12,10,10,12,10,11,11,11,11,8,6,9,10,9,10,11,12,10,10,12,11,11,10,11,11,8,9,11,12,11,12,13,14,12,13,14,14,12,13,13,13,11,10,13,11,12,14,14,15,13,13,15,12,13,14,14,14,12,9,12,12,12,13,13,15,13,13,14,13,13,14,13,15,11,8,11,12,10,12,13,14,12,13,14,14,13,13,13,14,11,5,9,10,10,9,10,12,11,10,12,11,11,9,11,11,9,6,10,10,11,10,10,12,11,11,12,11,11,11,11,11,9,9,11,13,13,12,11,14,12,13,15,13,13,14,13,14,11,8,11,11,12,11,12,13,12,12,13,12,13,12,12,12,10,7,10,10,11,10,11,12,11,11,12,11,11,11,11,12,9,9,12,12,12,12,12,14,12,13,14,13,13,13,13,13,11,11,14,13,15,15,16,16,15,15,16,15,15,16,16,15,13,10,12,13,13,13,14,15,13,13,14,13,13,14,14,14,11,9,12,12,12,13,13,14,12,13,14,14,13,13,13,14,11,9,13,13,13,11,12,15,13,13,15,14,14,11,13,14,11,10,13,13,13,12,12,15,13,13,15,14,14,13,13,14,11,10,12,13,13,12,11,14,12,13,15,13,13,13,13,14,11,11,14,15,15,13,14,16,14,14,16,16,14,14,15,15,13,10,13,13,13,12,13,14,13,13,14,14,14,13,13,14,11,10,12,13,13,13,12,14,13,13,14,14,13,13,13,13,11,13,15,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,15,15,15,14,15,16,14,15,16,16,15,16,15,15,13,10,12,12,12,13,13,14,12,13,14,13,13,13,13,13,11,6,10,10,11,10,11,12,11,10,12,11,11,10,11,11,9,8,11,12,12,12,12,13,12,12,13,12,13,12,13,13,10,11,13,15,14,15,14,16,14,15,16,16,14,15,15,15,13,7,11,10,12,11,11,13,11,11,13,10,11,12,12,12,10,7,11,11,11,11,11,13,11,11,13,11,12,12,12,12,9,10,12,13,13,13,13,15,13,14,15,14,14,14,14,15,11,10,13,12,14,14,14,15,13,13,15,12,13,15,15,14,12,10,13,12,12,13,13,15,14,13,15,13,13,14,14,14,11,10,13,13,12,13,14,15,13,13,15,13,13,14,14,14,11,7,10,11,11,10,11,12,11,10,12,12,12,9,11,12,9,7,11,11,11,11,11,13,11,11,13,12,12,11,12,12,9,10,12,14,13,13,13,16,13,14,16,14,14,13,13,14,11,8,11,11,12,11,12,13,12,12,13,12,12,12,12,12,10,6,9,9,10,9,10,11,10,10,11,10,10,10,10,10,8,8,11,11,11,12,11,13,11,12,13,12,12,12,12,12,10,11,14,13,14,14,14,16,14,14,16,14,14,15,15,14,12,9,12,11,12,12,12,13,12,12,13,12,12,12,12,12,10,8,11,11,11,11,11,13,11,12,12,12,12,12,12,12,9,10,13,14,13,11,13,14,14,13,15,15,14,10,13,14,11,10,13,13,13,12,13,14,13,13,14,14,14,13,13,13,11,10,13,14,13,13,12,15,13,14,15,14,14,14,13,14,12,11,14,14,14,13,13,15,14,14,15,14,15,13,14,14,12,9,11,12,12,11,11,13,12,12,13,12,12,12,12,12,10,9,11,12,12,12,11,13,11,12,13,12,12,12,12,12,10,13,15,15,16,15,16,16,15,16,16,16,15,15,15,16,14,10,13,13,13,13,13,14,13,13,14,13,13,13,13,13,11,8,11,11,11,11,11,12,11,11,12,12,11,12,11,12,9,11,14,14,15,14,15,15,14,13,15,14,15,12,14,15,13,12,15,15,15,15,15,16,15,15,16,16,16,15,16,15,13,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,14,13,15,14,14,16,14,14,16,13,14,15,14,15,12,11,14,13,14,14,14,16,15,14,16,14,14,15,15,15,12,13,15,15,15,15,16,16,15,16,16,16,15,16,16,16,13,11,14,13,14,14,14,15,14,14,16,12,14,16,16,14,12,11,14,14,14,14,15,16,15,14,16,13,14,16,15,14,12,12,14,14,14,14,14,16,14,15,16,14,14,14,15,15,12,11,14,14,14,13,14,16,15,13,16,15,15,11,14,14,12,11,14,14,15,14,14,16,14,14,15,14,14,13,15,15,12,13,15,16,15,15,15,16,15,16,16,16,16,15,15,16,13,11,14,14,14,14,14,15,14,14,16,14,14,14,15,14,12,9,12,12,12,12,12,13,12,12,13,12,13,12,12,12,10,11,13,13,13,13,13,14,13,13,14,13,14,13,13,14,11,12,15,14,15,15,15,16,15,14,16,14,14,16,16,14,13,10,12,12,12,12,12,14,12,13,13,12,12,13,13,13,10,10,12,12,12,12,12,14,12,12,13,12,12,12,12,12,10,10,14,14,14,12,14,16,14,13,16,16,16,10,13,14,12,11,14,14,14,13,14,16,14,14,16,15,14,12,13,14,12,12,14,14,14,14,14,16,14,14,16,15,15,14,14,15,12,12,14,15,15,14,15,16,14,15,15,15,15,13,15,14,12,9,12,12,12,12,13,13,12,12,13,13,12,11,12,12,10,10,12,12,12,12,12,13,12,12,13,12,12,12,12,12,10,13,15,15,15,15,16,16,16,16,16,16,16,15,16,15,13,10,12,12,13,12,13,13,12,13,14,13,13,12,13,13,10,7,10,10,10,10,10,11,10,10,11,10,10,10,10,10,7,10,10,9,8,9,8,9,7,9,9,8,7,8,7,7,4,13,11,12,9,12,9,12,9,12,11,11,9,10,9,9,6,15,12,15,11,14,10,14,10,14,13,13,11,13,11,12,7,13,12,11,9,12,11,12,9,12,12,10,9,10,10,9,6,14,13,12,10,13,12,13,9,13,12,11,10,12,11,10,6,16,14,14,10,15,13,14,10,15,15,14,11,14,12,12,8,15,14,12,11,15,14,13,11,14,14,11,10,13,12,11,8,15,16,13,11,16,14,14,11,15,15,12,10,14,13,12,8,16,15,14,10,16,14,14,10,16,15,14,10,14,13,12,7,13,12,12,11,11,9,12,9,12,12,11,10,10,9,9,6,13,13,14,12,12,10,12,10,14,13,12,11,11,10,10,7,16,14,16,13,14,11,15,10,16,15,14,12,14,11,12,8,14,14,13,12,13,12,13,10,13,13,12,11,11,10,10,7,15,14,14,12,14,12,13,10,14,13,12,11,12,11,11,7,16,15,16,13,15,13,15,10,16,15,14,12,14,12,12,7,15,16,14,13,16,14,14,12,15,15,12,12,13,12,12,8,16,16,14,13,16,14,14,11,15,15,14,11,14,12,12,8,16,16,15,12,16,14,15,10,16,16,13,12,14,13,12,7,14,14,14,13,13,11,13,11,14,14,13,12,11,10,11,8,16,15,16,13,13,11,14,11,15,14,14,13,12,11,12,8,15,15,16,14,14,10,14,10,16,15,15,13,14,10,12,8,16,16,16,14,15,13,14,12,15,15,13,13,13,12,12,8,16,16,16,14,15,13,14,11,16,16,14,13,13,12,12,8,16,16,16,14,16,12,15,11,16,15,15,13,14,12,12,8,16,16,16,16,16,15,15,13,16,16,14,13,14,13,12,9,16,16,16,14,16,15,15,11,16,16,14,13,15,13,12,8,16,16,16,14,16,14,14,10,16,16,15,13,14,12,12,7,12,12,12,11,12,11,12,10,11,11,10,9,9,9,9,6,14,13,14,12,13,12,13,10,13,13,12,10,12,10,11,7,16,14,16,13,15,13,16,12,15,14,14,12,14,12,13,8,14,14,13,11,14,12,13,11,12,12,10,10,11,10,10,7,14,14,13,12,14,12,13,11,13,13,12,10,12,11,10,7,16,15,15,12,16,14,15,11,16,14,13,11,14,12,12,8,16,16,13,13,16,15,14,12,14,14,11,11,13,12,11,8,16,16,14,12,16,14,14,12,15,14,12,11,14,12,12,8,16,15,14,11,16,15,15,11,16,15,13,11,14,13,12,8,14,13,13,12,13,11,13,10,12,13,11,10,10,10,10,7,15,14,14,13,13,12,13,11,14,13,12,11,12,10,11,7,16,15,16,14,15,12,15,11,16,14,14,12,14,11,12,8,14,15,13,12,14,13,13,11,13,13,11,11,11,10,10,7,14,14,14,12,14,13,13,10,14,13,12,10,12,10,10,6,16,15,15,13,16,13,15,11,15,14,13,11,13,11,11,7,16,16,14,13,16,15,14,12,15,15,12,11,13,12,11,8,16,16,14,13,16,14,14,11,15,14,12,11,13,12,11,7,16,16,15,12,16,14,14,11,15,15,13,11,14,12,11,6,16,15,15,14,14,12,14,12,13,14,13,12,11,11,11,8,16,16,16,14,14,12,15,12,15,14,14,12,12,11,12,8,16,16,16,15,14,12,15,12,16,15,14,13,13,11,12,8,16,16,16,15,15,14,15,12,14,14,13,12,12,11,11,8,16,16,15,14,14,12,14,11,14,14,13,12,12,11,11,7,16,16,16,14,15,12,14,11,15,15,14,12,13,11,12,7,16,16,16,16,16,15,16,13,15,15,14,12,13,12,11,8,16,16,16,14,15,14,14,12,16,15,13,12,13,12,11,7,16,16,16,13,16,13,14,10,16,15,14,11,13,11,11,6,14,15,13,13,14,13,14,12,12,13,11,11,11,11,10,8,16,16,15,13,16,14,16,13,14,14,13,12,13,12,12,8,16,16,16,14,16,14,16,13,16,14,15,13,15,13,13,9,15,15,14,14,15,14,14,12,13,14,11,11,12,12,11,8,15,16,15,13,15,14,14,12,14,14,12,11,13,12,12,8,16,16,16,13,16,15,15,13,16,15,14,11,15,12,13,8,16,16,14,13,16,15,15,13,14,14,10,11,14,12,11,8,16,16,15,13,16,16,15,13,15,14,12,11,14,13,12,8,16,16,15,13,16,15,16,12,16,14,13,10,15,13,12,7,15,15,15,14,14,14,15,12,13,14,12,12,11,11,11,8,16,15,16,14,15,13,15,12,14,14,13,12,12,11,12,8,16,16,16,15,16,14,16,13,16,15,14,12,14,11,13,8,16,16,15,14,16,14,15,13,14,14,12,11,12,11,11,8,15,16,15,14,15,14,14,12,14,13,12,11,12,11,11,7,16,16,16,14,16,13,16,12,15,14,13,11,13,11,12,7,16,16,15,14,16,15,15,13,14,15,11,11,13,12,11,8,16,16,15,13,16,14,15,12,15,14,12,11,13,11,11,7,16,16,15,13,16,14,16,12,15,14,13,10,13,11,11,6,16,16,16,14,14,14,15,13,14,14,14,12,11,11,11,8,16,16,16,14,15,14,16,13,15,14,14,13,12,11,11,7,16,16,16,16,15,13,16,12,15,15,14,12,13,10,12,7,16,16,16,14,15,15,14,13,14,14,13,12,12,11,11,8,16,15,16,14,16,13,15,12,14,14,13,12,12,10,10,6,16,15,16,14,16,13,16,11,16,14,13,11,13,10,11,6,16,16,16,15,16,16,15,13,14,16,12,12,12,12,10,7,16,16,16,14,16,14,14,12,15,15,12,11,12,11,10,6,16,16,16,13,16,13,15,10,15,14,13,10,13,10,10,4,1,6,6,7,6,7,9,8,7,9,7,8,7,8,8,6,6,9,10,10,10,10,12,11,10,12,11,11,11,11,12,9,9,10,13,11,13,12,14,13,14,14,14,14,14,14,14,12,6,10,9,10,10,11,13,11,11,13,10,12,11,12,12,9,6,10,10,10,10,11,13,11,11,13,12,12,11,12,12,9,9,11,13,12,13,14,15,13,14,16,14,14,14,14,15,12,10,13,11,13,14,14,16,14,14,15,13,14,15,15,16,12,9,13,12,12,14,14,16,14,14,15,14,14,15,15,15,12,8,11,12,11,13,14,15,13,13,15,14,14,13,15,15,11,6,10,10,11,9,10,13,11,10,13,11,12,10,12,12,9,6,10,10,11,11,10,13,11,11,13,11,12,12,12,13,10,9,12,13,13,13,12,16,13,14,15,14,14,15,14,15,12,8,12,12,13,12,13,15,14,13,15,13,14,13,13,14,11,7,11,11,12,11,12,13,12,12,13,12,13,12,13,13,10,9,12,13,13,13,13,16,13,13,15,14,14,14,15,15,12,11,15,14,15,15,16,16,16,15,16,15,16,16,16,16,14,10,13,13,14,14,14,16,15,14,16,15,15,15,15,16,13,9,12,13,13,13,14,16,14,13,15,14,14,14,16,15,12,10,13,14,14,11,13,16,14,14,16,15,15,12,14,15,12,10,13,14,14,12,12,16,15,14,16,15,15,14,14,16,12,9,12,13,14,13,11,16,13,14,15,13,14,14,14,15,12,11,15,16,16,14,16,16,16,16,16,16,16,16,16,16,14,10,13,14,14,13,14,16,15,14,16,16,16,14,15,16,13,10,13,13,14,13,13,16,13,13,14,14,15,15,14,15,13,13,15,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,16,16,16,15,16,16,16,16,16,16,16,16,16,16,14,10,12,13,14,13,13,14,13,13,14,13,14,14,14,15,12,6,10,11,11,10,11,13,12,11,13,11,12,11,12,12,10,8,12,13,13,12,13,14,14,13,15,14,14,14,14,15,12,12,14,16,15,15,15,16,15,16,16,16,16,16,16,16,14,7,11,11,12,12,12,14,13,12,14,11,12,13,13,13,11,8,11,12,12,12,12,14,13,12,14,12,13,13,14,14,11,11,13,14,14,14,14,16,15,15,16,15,15,16,16,16,13,10,14,12,14,14,15,16,15,13,16,12,14,16,16,15,13,10,13,13,14,14,15,16,15,14,16,14,15,15,16,16,12,10,13,14,13,14,14,16,15,14,16,15,15,14,16,16,13,7,11,11,11,10,12,14,13,11,14,13,13,10,12,13,10,8,11,12,12,11,12,14,13,12,15,13,13,12,13,14,11,11,13,14,14,14,14,16,15,14,16,15,16,16,16,16,14,8,12,12,13,12,13,15,14,12,15,13,13,13,14,14,11,6,10,10,11,10,11,13,12,11,13,11,12,11,12,12,9,9,12,13,13,13,13,14,13,13,15,14,14,14,14,14,12,11,15,14,15,14,15,16,16,16,16,15,16,16,16,16,14,9,13,12,13,13,13,15,14,13,14,13,14,14,15,14,12,9,12,12,12,12,13,14,13,13,14,13,13,13,13,14,11,10,13,15,14,12,14,16,14,14,16,15,15,12,14,16,12,10,14,14,14,13,14,16,15,14,16,16,16,13,14,16,13,11,13,14,14,14,13,16,14,14,16,15,15,15,15,16,13,11,15,15,15,14,15,16,16,15,16,16,16,14,16,16,13,9,13,13,13,12,13,15,14,13,15,14,14,13,14,15,11,9,12,12,13,12,12,14,13,13,14,13,14,14,14,14,11,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,14,14,15,15,14,16,16,14,16,14,15,15,16,16,12,9,12,12,13,12,12,14,12,12,14,13,13,13,13,14,11,11,14,14,16,14,16,16,16,13,16,14,16,14,16,16,13,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,15,14,16,14,15,16,16,15,16,14,15,16,16,16,13,11,15,14,16,15,16,16,16,15,16,15,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,11,14,13,14,15,14,16,15,14,16,12,14,16,16,15,13,11,14,14,16,14,15,16,16,15,16,14,15,16,16,16,14,12,14,14,15,14,16,16,15,14,16,15,15,15,16,16,13,11,14,15,15,13,15,16,16,14,16,16,16,12,15,15,13,11,15,16,16,15,16,16,16,15,16,16,16,14,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,15,14,16,15,16,16,16,16,16,16,16,16,16,16,13,10,13,13,14,14,14,16,15,14,16,14,15,14,14,15,12,12,15,14,16,14,15,16,15,15,16,15,15,16,15,16,13,12,16,14,16,15,16,16,16,16,16,14,15,16,16,16,14,10,13,13,14,14,13,16,14,13,16,13,14,15,15,15,12,10,13,13,14,13,13,16,14,14,15,14,14,14,14,15,12,10,14,15,14,13,15,16,15,14,16,16,16,11,14,16,12,11,14,14,16,14,15,16,15,15,16,16,16,13,15,16,13,12,15,15,15,15,15,16,16,16,16,16,16,16,15,16,13,12,16,16,16,15,16,16,16,16,16,16,16,14,16,16,13,10,13,14,14,13,14,16,14,13,16,15,14,12,14,16,11,10,13,13,14,13,14,16,14,14,15,14,14,13,14,14,11,13,16,15,16,16,16,16,16,16,16,16,16,16,16,16,14,11,13,14,15,14,14,16,15,14,16,14,15,14,15,16,12,8,11,11,11,11,12,13,12,11,13,11,12,11,12,12,9,8,8,8,7,8,7,8,6,8,8,7,6,7,6,6,4,11,10,11,9,11,9,11,8,11,10,10,9,10,8,9,6,13,11,13,10,12,10,13,9,13,12,13,10,12,10,11,7,11,11,10,9,11,10,11,9,10,11,9,8,10,9,9,6,12,12,11,9,12,11,12,9,12,12,11,9,11,10,10,7,14,13,13,10,15,12,13,10,15,13,13,10,13,12,12,8,13,13,11,10,14,13,12,10,13,13,10,10,12,11,10,8,15,14,13,10,14,13,13,10,14,13,12,10,13,12,11,8,14,14,13,10,16,13,13,10,15,14,13,10,13,12,12,8,11,11,11,10,10,9,10,9,10,10,10,9,9,8,9,6,12,12,12,11,11,9,12,9,12,12,11,10,11,9,10,7,14,13,14,12,13,10,13,10,15,13,14,12,12,10,12,8,13,13,12,11,12,11,12,10,12,12,11,10,11,10,10,7,14,13,13,11,13,12,12,10,13,13,12,11,12,10,10,7,16,15,15,12,14,12,13,10,15,14,13,12,13,12,12,8,15,15,13,13,14,14,14,12,14,14,12,11,13,12,11,8], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+503032);
/* memory initializer */ allocate([15,16,14,12,15,14,13,11,15,15,13,12,13,12,11,8,16,15,15,12,16,14,14,10,15,15,14,12,14,12,12,8,13,13,13,13,11,10,12,10,12,13,12,11,10,10,10,8,14,13,14,13,12,10,13,10,14,14,13,12,12,10,11,8,15,14,16,14,13,10,14,10,16,14,14,13,13,10,12,8,15,15,14,14,14,13,13,12,14,14,13,12,12,11,11,9,15,15,15,14,14,12,14,11,15,14,13,13,13,11,11,8,16,15,16,14,15,12,14,11,16,16,15,13,14,12,12,8,16,16,16,14,15,14,14,12,15,15,14,13,13,12,11,9,16,16,15,15,16,14,14,11,16,16,14,13,14,12,12,8,16,16,16,13,15,13,14,10,16,16,15,13,14,12,12,8,11,11,11,10,11,10,11,9,10,10,9,8,9,9,9,6,12,12,13,11,12,11,12,10,12,12,11,10,11,10,10,7,15,13,15,12,14,13,14,11,14,13,13,11,13,11,12,8,12,13,12,11,13,11,12,10,11,12,10,9,11,10,10,7,14,13,13,11,14,12,13,11,12,12,11,10,12,11,10,7,15,14,15,12,15,13,15,11,15,14,13,11,13,12,12,8,14,14,13,12,15,14,13,12,13,13,11,10,13,12,11,8,16,15,13,12,15,14,14,12,14,14,12,11,14,12,11,8,16,15,14,12,16,15,15,11,15,14,13,11,14,13,12,8,12,12,12,11,12,11,12,10,11,11,11,10,10,9,9,7,13,13,14,12,13,11,13,11,13,12,12,11,11,10,10,7,15,14,16,13,14,12,14,11,14,14,14,12,13,11,12,8,13,13,13,12,13,12,13,11,12,12,11,10,11,10,10,7,14,14,13,12,13,12,13,10,13,13,11,10,12,10,10,7,16,15,15,13,15,12,14,11,15,14,13,11,13,11,11,7,15,16,14,13,15,14,14,12,14,14,12,11,13,12,11,8,16,15,14,13,15,14,14,11,14,14,12,11,13,12,11,7,16,15,15,12,16,14,14,11,15,14,13,11,14,12,11,7,14,15,14,14,13,12,13,12,13,13,12,12,11,10,11,8,15,15,15,14,13,12,14,12,14,14,13,12,12,11,11,8,16,15,16,14,14,12,15,12,16,14,14,13,13,11,12,8,15,15,15,14,14,13,14,12,14,14,13,12,12,11,11,8,15,15,15,14,14,13,14,12,14,14,13,12,12,11,11,7,16,15,16,14,15,12,15,11,15,14,14,12,13,11,12,7,16,16,16,15,16,15,14,13,15,15,13,12,13,12,11,9,16,16,16,14,15,14,14,12,15,15,13,12,14,12,11,8,16,16,16,14,16,14,14,11,15,15,14,12,14,12,11,7,13,13,13,12,13,12,13,11,11,12,11,10,10,10,10,8,15,14,14,13,14,13,14,12,13,13,12,11,13,11,11,8,16,15,16,14,16,14,16,13,15,14,14,12,14,12,13,9,14,15,13,13,14,13,14,12,12,13,11,11,12,11,11,8,15,15,14,13,15,14,14,12,13,13,12,11,13,12,11,8,16,16,16,13,16,15,16,13,15,14,14,12,14,13,13,9,14,15,13,13,16,15,15,13,13,14,11,11,13,12,11,9,16,16,14,13,16,15,16,13,14,14,12,11,14,13,12,8,16,16,15,12,16,15,15,12,15,14,13,11,14,13,12,8,14,14,14,13,14,13,14,12,12,13,12,11,11,11,11,8,15,15,15,14,14,13,15,12,14,13,13,12,12,11,11,8,16,16,16,15,15,14,16,13,15,14,14,12,14,12,12,9,15,15,14,14,14,14,14,13,13,14,12,11,12,11,11,8,15,15,15,13,15,14,14,12,13,13,12,11,12,11,11,7,16,15,16,14,16,14,15,12,15,14,14,12,13,12,12,8,16,16,15,14,16,15,15,13,14,14,12,11,13,12,11,8,16,16,15,13,16,14,14,12,14,15,12,11,13,12,11,7,16,16,16,13,16,15,15,12,15,14,13,11,14,12,11,7,15,15,15,14,13,13,14,13,13,14,13,12,11,11,11,8,16,16,16,14,15,13,15,12,14,14,14,13,12,11,12,8,16,16,16,14,15,13,15,12,15,14,14,12,13,11,12,8,15,16,16,14,15,14,15,13,14,14,12,12,11,11,11,8,16,15,15,14,15,14,14,12,14,14,13,12,12,11,11,7,16,16,16,13,15,13,15,12,15,14,14,12,13,11,11,7,16,16,16,15,15,16,15,13,14,14,12,12,12,12,11,8,16,16,16,14,16,14,14,12,15,15,13,11,12,11,10,7,16,16,15,13,16,14,14,11,15,14,13,10,13,11,10,5,1,6,6,7,6,7,9,7,6,9,7,8,7,8,8,5,5,8,10,10,10,10,12,11,11,12,11,11,11,12,12,9,9,10,12,11,13,12,15,13,14,15,15,14,14,15,15,12,6,10,9,10,10,11,13,12,11,13,11,12,12,12,12,10,6,10,10,10,11,11,13,11,11,13,12,12,11,12,12,10,9,12,13,12,13,13,16,13,14,16,15,14,14,15,16,12,9,13,11,13,14,14,16,15,14,16,13,15,15,15,15,12,9,13,12,13,14,15,16,15,14,16,15,15,15,15,16,12,8,12,12,11,13,14,15,13,13,15,14,14,14,14,14,12,6,10,10,11,9,10,13,11,11,13,12,12,10,12,12,9,6,10,11,11,11,10,13,12,11,13,12,12,12,12,13,10,9,12,13,13,13,12,16,13,14,16,14,15,16,14,15,12,8,12,13,13,13,13,16,14,13,16,13,14,14,14,14,12,7,11,11,12,11,12,14,13,12,14,13,13,12,13,13,11,9,12,13,13,13,13,15,14,14,16,16,15,15,15,16,12,11,16,14,16,16,16,16,16,16,16,16,16,16,16,16,14,10,14,14,15,15,16,16,16,14,16,14,16,16,16,16,13,9,13,13,13,14,14,16,14,14,16,15,14,14,16,16,13,9,13,14,14,11,13,16,14,13,16,15,16,13,14,15,12,10,13,14,15,13,12,16,14,14,16,15,15,14,14,16,13,9,12,13,14,12,11,15,13,13,15,13,14,15,14,16,12,11,15,16,16,14,16,16,16,15,16,16,16,16,16,16,13,11,14,14,15,13,14,16,15,15,16,16,16,16,16,16,13,10,12,13,14,13,13,16,14,14,14,14,16,15,14,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,9,12,13,14,13,13,16,13,13,15,15,16,15,15,16,12,6,11,11,12,10,12,13,12,11,13,11,12,11,12,13,10,9,12,13,13,13,13,16,14,14,15,14,14,14,14,14,12,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,14,7,11,11,12,12,12,14,13,12,14,11,13,13,13,13,11,8,12,12,13,12,13,14,13,13,14,13,13,13,14,14,11,11,14,14,15,16,15,16,16,15,16,16,16,16,16,16,13,10,14,12,14,15,15,16,16,14,16,12,15,16,16,16,13,11,14,13,15,15,15,16,16,14,16,14,14,16,16,16,13,11,14,14,14,15,16,16,16,16,16,16,15,16,16,16,13,7,11,12,11,10,12,14,13,12,14,13,13,10,12,13,10,8,12,12,13,12,12,15,13,13,14,13,13,13,13,14,11,11,13,15,16,14,15,16,16,16,16,16,16,16,16,16,13,9,12,13,13,13,13,15,14,13,15,13,14,13,14,14,12,7,11,11,11,11,11,13,12,11,13,11,12,11,12,12,10,9,12,13,13,13,13,16,13,14,16,15,14,14,14,16,12,12,14,14,16,16,16,16,16,16,16,15,16,16,16,16,14,10,13,13,14,14,14,16,15,14,16,14,14,16,15,15,12,9,12,13,13,13,15,16,14,13,16,14,13,13,14,14,11,10,14,15,14,12,14,16,15,13,16,16,16,12,14,16,12,11,14,14,14,14,14,16,15,15,16,16,16,14,15,16,13,11,14,14,16,14,13,16,15,14,16,15,16,15,15,16,13,12,16,16,16,14,16,16,16,16,16,16,16,15,16,16,14,10,13,14,14,13,14,16,14,13,16,15,15,13,14,14,12,9,12,13,14,13,12,16,14,13,16,14,14,14,14,15,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,15,15,16,16,16,16,16,16,16,16,16,16,16,16,13,9,12,13,13,13,13,14,13,12,15,14,14,14,14,14,11,11,14,14,16,14,16,16,16,13,16,14,16,14,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,14,14,16,16,15,16,16,15,16,14,16,16,16,16,14,12,15,15,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,10,14,12,15,15,15,16,16,14,16,12,14,16,16,15,14,12,15,14,16,16,16,16,16,15,16,14,16,16,16,16,14,12,15,15,15,15,16,16,16,16,16,16,15,16,16,16,14,11,15,15,16,14,16,16,16,14,16,16,16,13,16,16,13,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,11,15,14,16,14,14,16,15,14,16,15,16,15,16,16,12,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,12,16,15,16,16,16,16,16,16,16,15,16,16,16,16,14,10,14,13,14,15,14,16,15,14,16,13,16,16,16,15,13,10,14,14,14,13,14,16,15,15,16,14,14,14,16,16,12,10,14,15,14,13,16,16,15,13,16,16,16,12,14,16,12,11,16,16,16,14,15,16,16,16,16,16,16,14,16,16,13,12,15,14,16,15,16,16,16,16,16,16,16,16,14,16,14,13,16,16,16,16,16,16,16,16,16,16,16,15,16,16,14,11,14,14,14,14,15,16,14,14,16,16,16,13,15,15,12,10,14,13,14,14,14,16,15,14,16,15,15,14,14,16,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,12,14,14,16,16,16,16,16,16,16,15,16,16,16,16,13,8,11,11,12,12,12,13,12,11,13,12,12,12,13,12,10,5,6,6,6,6,6,7,6,6,7,6,6,6,6,6,4,9,9,9,8,9,8,10,8,10,10,9,9,9,8,9,6,11,10,12,10,11,10,12,9,12,11,11,10,11,10,11,8,9,10,9,8,10,10,10,9,9,10,8,8,9,9,8,7,10,11,10,9,11,11,11,9,11,11,10,9,10,10,10,7,13,12,12,10,13,12,13,10,13,12,12,11,13,12,11,9,11,12,10,10,12,12,11,10,11,12,10,10,11,11,10,8,12,12,11,10,13,13,13,10,13,13,12,11,13,12,11,9,12,12,12,10,13,13,13,10,13,13,12,10,13,12,12,9,9,9,10,10,9,8,10,9,9,10,9,9,8,8,9,6,10,11,11,11,10,9,11,9,11,11,11,10,10,9,10,7,12,12,13,12,12,10,13,10,13,13,13,12,12,11,11,9,11,12,11,11,11,11,11,10,11,12,10,10,10,10,10,8,12,12,12,11,12,11,11,10,12,12,11,11,11,11,10,8,14,13,13,12,13,12,13,10,14,14,13,12,13,12,12,9,13,14,13,12,13,13,13,12,13,13,12,12,12,12,11,9,14,14,13,12,13,13,13,11,14,14,13,12,13,12,12,9,14,15,14,12,15,13,13,11,15,14,14,12,14,13,12,9,11,11,12,12,10,10,12,11,11,12,11,11,10,10,10,8,12,12,14,13,11,10,12,11,13,13,13,12,12,10,11,9,13,13,14,14,12,10,13,11,14,14,14,13,12,11,12,9,13,13,13,13,12,13,13,12,13,14,12,12,12,12,11,9,13,14,14,13,13,12,13,11,14,14,13,12,13,12,12,9,14,14,14,14,14,12,13,11,15,15,15,13,14,12,12,9,14,15,15,13,14,14,13,12,13,14,13,13,12,12,11,10,16,16,15,14,15,14,13,11,15,15,14,13,13,13,12,9,15,15,15,13,14,13,13,11,15,15,15,13,14,13,12,9,8,9,9,9,9,9,10,9,8,10,9,9,8,8,9,7,11,11,11,11,11,11,12,10,11,11,11,10,10,10,10,8,13,13,14,12,13,12,14,11,13,13,13,12,13,11,12,9,10,11,10,11,11,11,12,10,10,11,10,10,10,10,10,8,12,12,12,11,12,12,12,11,11,12,11,10,11,11,10,8,14,13,14,12,14,13,14,12,14,13,13,11,13,12,12,9,12,13,12,12,13,13,13,12,12,13,11,11,12,12,11,9,13,14,13,12,14,14,14,12,14,13,12,11,13,12,12,9,14,14,13,12,15,14,15,12,14,14,13,11,13,13,12,9,10,11,11,11,10,10,12,10,10,11,10,10,9,9,10,7,12,12,13,12,12,11,12,11,12,12,12,11,11,10,10,8,14,13,14,13,14,12,13,12,14,13,14,12,13,11,12,9,12,13,12,12,12,12,12,11,11,12,11,10,10,10,10,8,12,12,12,12,12,12,12,11,12,12,11,10,11,10,10,7,14,14,14,12,14,12,14,11,14,13,13,11,13,11,11,8,13,15,13,13,14,14,14,12,13,14,12,12,12,12,11,9,14,15,13,12,14,13,13,11,13,13,12,11,13,12,11,8,15,15,15,12,15,14,14,11,14,14,13,11,13,12,12,8,12,13,13,13,12,12,13,12,12,13,12,12,11,11,11,9,13,14,15,14,13,12,14,12,13,13,14,12,12,11,12,9,14,14,15,14,14,12,14,12,14,14,14,13,13,11,12,9,13,14,14,14,13,13,14,13,13,13,12,12,12,12,11,9,14,14,14,13,13,13,13,12,13,14,13,12,12,11,11,8,15,14,15,14,14,13,14,11,15,14,14,12,13,11,12,8,14,15,14,14,15,14,14,13,14,15,13,13,12,12,11,10,16,15,14,14,14,14,13,12,14,14,13,12,13,12,11,9,15,15,15,14,16,14,14,11,15,15,14,12,13,12,11,8,11,12,11,12,12,12,12,11,10,11,10,10,10,10,10,8,13,13,13,13,13,13,14,12,12,12,12,12,12,11,12,9,14,14,14,13,15,13,15,13,14,14,14,12,14,12,13,10,12,13,12,13,13,13,13,12,11,12,11,11,12,11,11,9,14,14,13,13,14,14,14,12,12,13,12,11,13,12,12,9,14,14,15,13,15,15,15,13,15,13,13,12,14,12,13,10,13,15,12,13,14,14,14,13,12,13,11,11,13,12,11,10,14,15,14,13,15,14,15,13,14,14,12,11,13,13,12,9,14,15,14,13,15,14,15,13,14,14,13,11,14,13,12,9,12,13,13,13,12,13,13,12,11,12,12,11,11,11,11,9,13,14,14,13,14,13,14,12,13,13,13,12,12,11,11,9,15,15,16,14,15,14,14,13,15,14,14,13,13,12,13,10,13,14,14,13,13,14,14,13,12,13,12,12,11,11,11,9,14,14,14,13,14,13,14,12,13,13,12,11,12,11,11,8,15,15,15,13,15,14,14,12,14,13,13,12,13,12,12,9,14,15,14,14,15,15,14,13,13,14,12,12,13,12,12,9,15,15,14,13,15,14,14,13,14,14,12,11,13,12,11,8,15,16,14,13,15,15,15,12,14,14,13,11,14,12,12,8,12,14,13,13,13,13,14,12,12,13,12,12,10,11,11,9,14,15,15,14,13,13,15,13,13,14,14,12,12,11,12,9,15,15,16,14,14,13,15,13,14,14,14,13,13,11,12,9,14,15,14,14,14,14,14,13,13,14,13,12,12,12,11,9,14,15,15,14,14,14,14,12,13,14,13,12,12,11,11,8,15,15,15,14,14,13,15,12,15,14,14,12,13,11,11,8,14,16,14,14,14,15,14,13,13,14,12,12,12,12,11,9,15,15,15,14,15,14,14,12,14,14,13,12,12,11,11,8,15,15,14,13,15,13,14,12,14,14,13,11,13,11,11,7,1,5,6,7,6,7,9,8,6,9,8,8,7,8,8,6,5,8,10,10,10,11,13,12,11,13,12,12,12,12,13,10,8,10,13,12,13,13,16,14,14,16,16,14,16,16,16,12,5,10,9,11,11,12,13,12,11,13,11,12,12,12,13,10,6,10,11,11,11,12,14,12,11,13,13,13,12,13,13,11,8,12,13,12,14,14,16,14,14,16,16,16,16,16,16,13,9,13,11,14,14,16,16,16,14,16,14,16,16,16,16,13,9,13,13,13,14,16,16,16,16,14,16,16,16,16,16,14,8,12,13,12,13,14,16,14,14,16,16,16,14,16,16,13,5,10,11,12,9,11,13,12,11,13,13,13,11,12,13,10,6,10,11,12,11,11,14,13,12,14,12,13,13,13,13,11,9,12,14,15,13,13,16,16,14,16,16,16,16,16,16,13,8,13,13,14,13,14,16,16,14,16,14,16,14,16,14,13,7,11,12,13,12,12,14,13,12,14,13,14,13,14,14,12,9,13,14,14,14,14,16,16,16,16,16,16,16,16,16,13,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,15,14,16,16,16,16,16,16,16,16,16,16,16,16,14,9,13,14,14,14,16,16,16,14,16,16,16,16,16,16,14,9,13,14,15,11,13,16,14,14,16,16,16,13,14,16,13,9,13,14,16,13,13,16,16,14,16,16,16,16,15,16,14,8,12,13,16,13,12,16,14,13,16,14,16,16,16,16,13,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,16,16,14,16,16,16,16,16,16,16,16,16,16,14,9,13,16,16,14,14,16,16,14,16,16,16,16,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,13,14,15,14,14,16,14,13,16,16,16,14,16,16,14,6,11,11,12,11,12,14,13,11,14,12,13,12,13,13,11,9,13,13,14,13,14,16,16,14,16,16,16,15,16,16,13,11,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,7,11,11,13,12,13,16,14,12,16,12,14,14,14,14,12,8,12,12,13,12,14,16,14,13,16,14,14,14,14,14,12,11,15,15,16,16,16,16,16,16,16,16,16,16,16,16,14,10,14,13,16,16,16,16,16,14,16,14,16,16,16,16,16,10,16,14,16,16,16,16,16,16,16,16,16,16,16,16,14,10,16,14,16,16,16,16,16,16,16,16,16,16,16,16,14,7,11,12,12,11,13,16,14,12,15,14,14,11,13,13,12,8,12,12,13,13,13,16,14,13,16,13,15,13,14,14,12,11,14,16,16,16,16,16,16,16,16,16,16,16,16,16,14,8,12,13,14,13,14,16,16,14,16,14,16,14,16,15,13,6,11,11,12,11,12,13,13,11,13,12,13,12,13,13,11,9,13,14,14,14,14,16,14,14,16,16,16,16,16,14,13,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,13,14,14,16,16,16,14,16,14,16,16,16,16,13,9,13,14,13,13,16,16,14,13,16,16,16,13,16,14,13,10,14,14,16,13,16,16,16,16,16,16,16,13,14,16,14,11,16,16,16,14,16,16,16,16,16,16,16,16,16,16,14,10,14,16,16,14,14,16,16,16,16,16,16,16,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,14,14,14,16,16,16,14,16,16,16,14,16,16,13,9,13,13,16,14,14,16,16,14,16,14,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,13,14,14,13,16,16,14,13,16,14,16,14,14,16,12,10,14,14,16,16,16,16,16,13,16,16,16,14,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,14,16,16,16,16,16,16,16,16,16,16,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,13,16,16,16,16,16,14,16,12,16,16,16,16,14,11,16,16,16,16,16,16,16,16,16,15,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,14,16,16,16,14,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,16,16,16,16,16,16,16,14,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,15,14,16,16,16,16,16,16,16,14,16,16,16,16,14,10,14,14,14,14,16,16,16,16,16,16,16,16,16,16,13,10,14,16,16,13,16,16,16,14,16,16,16,12,16,16,14,11,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,15,14,16,14,16,16,16,16,16,16,16,14,16,16,13,10,15,14,16,15,16,16,16,16,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,14,14,16,16,16,16,16,16,16,16,16,16,16,16,14,8,12,12,13,12,14,14,14,12,16,13,14,12,14,14,11,0,3,3,4,3,5,5,5,2,5,4,6,4,6,6,6,0,2,3,4,2,5,6,7,3,6,5,7,4,7,8,8,0,3,4,4,3,4,5,5,3,5,4,5,4,5,5,3,0,3,3,4,3,4,5,5,3,5,4,6,3,5,6,5,0,4,4,4,4,5,5,4,4,5,4,5,4,4,4,2,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,6,6,5,6,5,6,4,6,6,5,4,4,4,4,1,0,4,4,4,4,5,5,4,4,5,5,4,4,4,4,2,0,4,3,4,3,4,5,4,3,5,4,5,3,5,5,5,0,2,3,4,2,5,6,7,3,6,5,7,4,7,8,8,0,4,4,4,4,4,5,4,4,5,4,4,3,4,4,3,0,3,3,4,3,4,5,5,3,5,4,6,3,5,6,5,0,4,4,4,4,4,5,4,4,5,5,5,4,4,4,2,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,5,6,5,5,5,6,4,6,6,5,4,5,4,4,1,0,4,4,4,4,4,5,4,4,5,5,4,4,4,5,2,0,3,3,4,3,4,4,5,3,5,4,5,4,5,5,5,0,2,3,4,2,4,6,7,3,6,5,7,5,7,8,8,0,4,4,4,4,4,5,4,3,5,4,4,4,4,4,3,0,3,3,4,3,3,6,6,3,6,4,6,3,6,6,5,0,4,4,4,3,4,5,4,4,5,4,4,4,4,4,3,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,5,5,5,5,5,6,4,5,6,5,5,5,4,4,1,0,4,4,4,4,4,6,4,4,6,5,4,4,4,4,2,0,3,3,4,3,4,4,5,3,5,4,5,4,5,5,5,0,2,3,4,2,4,7,6,3,7,5,7,5,7,7,7,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,3,3,3,3,4,6,6,3,6,4,6,3,6,6,5,0,3,4,4,3,4,5,4,4,5,4,5,4,5,4,3,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,4,5,4,4,4,5,4,4,5,5,4,4,4,4,2,0,4,4,4,4,5,5,4,4,5,5,4,4,4,4,2,0,3,3,4,3,4,5,6,2,5,4,7,4,6,6,7,0,2,3,4,2,4,6,7,3,7,5,7,5,7,7,7,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,2,3,4,3,4,6,5,3,6,4,6,4,6,6,6,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,4,4,4,4,5,5,4,4,5,5,4,4,4,4,2,0,3,4,4,4,4,5,4,4,5,4,4,4,4,4,3,0,5,8,3,6,9,6,7,9,4,6,9,6,7,9,8,8,9,7,8,9,8,9,9,9,9,9,2,6,9,4,7,9,7,8,9,5,7,9,6,7,9,8,8,9,7,8,9,8,9,9,9,9,8,5,8,10,6,8,10,8,9,9,7,8,10,7,9,10,8,9,9,8,9,10,9,9,10,9,9,9,7,9,10,8,9,10,8,8,9,8,9,10,8,9,10,8,8,9,8,9,9,8,9,9,8,8,7,0,4,9,2,6,10,7,8,10,3,6,10,6,7,10,9,9,10,8,9,11,9,10,11,10,11,11,2,6,10,4,7,10,8,9,10,5,7,10,7,8,10,9,9,10,9,10,11,10,10,11,11,11,11,6,9,11,7,9,11,9,10,12,8,9,11,8,10,11,10,10,11,10,11,12,11,11,12,11,11,11,9,11,12,10,11,12,10,11,12,10,11,12,10,11,12,11,11,12,11,12,12,11,12,12,12,11,11,0,4,9,3,6,9,6,8,9,4,6,9,5,7,9,8,8,9,7,8,10,8,9,10,9,9,9,2,6,9,4,7,9,7,8,9,5,7,9,6,7,10,8,9,9,7,9,10,8,9,10,9,9,9,5,8,10,6,8,10,8,9,10,7,8,10,7,9,11,9,9,10,8,9,10,9,10,10,10,10,9,7,9,10,8,9,11,8,9,10,8,9,11,8,9,11,9,9,10,9,9,10,9,9,10,9,9,8,0,4,9,2,5,10,7,8,11,3,6,10,6,7,10,9,10,11,8,9,11,9,10,11,11,11,12,2,6,10,4,7,10,8,9,11,5,7,10,6,8,10,9,10,11,9,10,12,10,10,12,11,12,12,6,9,11,8,9,12,9,11,13,8,10,12,9,10,12,11,11,12,10,12,13,11,12,13,13,12,13,10,11,13,10,12,13,11,12,13,11,12,13,11,12,13,12,12,13,12,13,14,13,13,14,13,13,13,0,4,9,3,6,9,7,8,10,3,6,9,5,7,10,8,9,10,7,9,10,8,9,10,10,10,10,2,6,9,4,7,10,7,9,10,4,7,10,6,8,10,8,9,10,8,9,10,9,9,10,10,10,10,5,8,11,7,9,11,8,10,11,7,9,11,8,9,11,9,10,11,9,10,11,10,10,11,11,11,11,8,10,11,9,10,11,9,10,11,9,10,12,9,10,12,10,11,11,9,10,11,10,11,11,10,10,10,0,4,10,3,6,11,8,10,12,3,6,11,6,8,11,10,11,13,9,10,13,11,12,14,13,13,14,1,6,10,5,8,12,9,10,13,5,8,11,7,9,12,11,11,13,10,12,13,11,12,14,14,13,15,7,10,12,9,11,14,11,12,15,9,11,13,10,11,14,12,12,14,12,14,16,13,13,16,14,14,16,12,13,15,12,14,15,13,14,16,13,14,16,14,14,16,14,15,16,14,16,16,15,16,16,15,15,16,0,4,9,2,6,9,7,9,11,3,6,10,6,7,10,9,10,11,7,9,10,9,10,11,11,11,12,2,6,10,4,7,10,8,9,11,5,7,10,7,8,10,9,10,11,8,9,11,9,10,11,11,12,11,6,9,11,7,10,12,9,11,12,7,10,12,9,10,12,11,11,12,9,11,12,10,11,12,12,12,12,9,11,12,9,11,13,11,12,13,9,11,13,10,12,13,11,12,13,11,12,13,11,12,13,12,13,12,0,4,11,2,6,12,9,11,16,4,7,12,7,9,15,11,12,16,10,11,16,11,13,16,16,16,16,1,6,11,5,8,16,9,12,16,6,9,15,8,10,16,12,13,16,12,14,16,12,16,16,16,16,16,8,11,14,10,12,16,12,16,16,10,13,16,12,16,16,13,14,16,14,16,16,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,0,5,9,3,6,10,8,10,12,3,6,10,6,8,10,10,11,12,8,9,11,10,10,12,13,13,13,1,6,10,5,8,11,9,11,13,5,8,11,7,9,11,11,11,13,8,9,11,10,10,12,13,13,14,6,9,12,8,11,13,11,13,15,8,10,13,10,11,13,12,13,15,10,12,13,12,12,13,14,14,14,9,12,14,11,13,15,13,15,16,11,13,15,12,14,15,14,15,16,13,14,15,14,14,15,15,16,16,0,4,16,2,7,16,10,13,16,3,8,16,7,10,16,16,16,16,12,16,16,15,16,16,16,16,16,1,7,16,6,9,16,10,16,16,7,12,16,9,13,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,16,11,13,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,4,9,3,6,11,9,12,16,3,6,10,6,8,11,12,13,16,8,9,12,10,11,13,16,16,16,1,6,10,5,8,12,10,13,16,5,8,11,8,9,13,13,14,16,9,10,14,11,12,15,16,16,16,6,10,13,9,12,16,14,16,16,9,12,14,11,13,16,16,16,16,12,14,16,14,16,16,16,16,16,11,16,16,13,16,16,16,16,16,12,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,4,16,2,8,16,10,16,16,3,9,16,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,7,16,5,10,16,16,16,16,7,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,15,16,10,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,3,9,3,7,11,11,15,16,3,6,11,7,9,12,16,16,16,8,10,16,11,16,16,16,16,16,1,6,11,6,9,15,16,16,16,5,8,16,9,11,16,16,16,16,10,16,16,16,16,16,16,16,16,7,11,16,11,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,4,16,2,8,16,16,16,16,3,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,7,16,5,12,16,16,16,16,6,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,4,8,3,6,8,6,7,8,4,6,8,6,7,8,7,8,8,7,8,8,8,8,8,8,8,8,3,6,8,4,6,9,7,7,8,5,7,9,6,7,9,8,8,8,7,8,8,8,8,8,8,8,7,6,8,9,7,8,9,7,8,9,7,8,9,7,8,9,8,8,9,8,8,9,8,9,9,8,8,8,8,9,9,8,9,9,7,8,8,8,9,9,8,9,9,8,8,8,7,8,8,8,8,8,7,7,6,0,4,9,3,6,9,7,8,10,3,6,9,5,7,10,9,9,10,7,8,10,8,9,10,10,10,10,2,6,9,4,7,10,8,9,10,4,7,10,6,7,10,9,9,10,7,8,10,8,9,10,10,10,10,6,8,10,7,9,11,9,10,11,7,9,11,8,9,11,10,10,11,8,9,11,9,10,11,11,11,10,8,10,11,9,10,11,9,10,11,8,10,11,9,10,11,10,10,11,8,10,11,9,10,10,10,10,9,0,4,8,3,6,8,6,7,9,4,6,8,5,7,8,8,8,9,7,7,8,8,8,8,8,9,8,3,6,8,4,6,9,7,7,9,5,6,9,6,7,9,8,8,9,7,8,8,8,8,8,8,8,8,6,8,9,7,8,10,7,8,9,7,8,10,7,8,10,8,8,9,7,8,9,8,9,9,9,9,8,7,9,10,8,9,10,8,8,8,8,9,10,8,9,9,8,8,8,7,8,8,8,8,8,8,7,6,0,4,9,3,6,10,8,9,11,3,5,9,5,7,10,9,10,11,7,8,10,9,9,11,11,11,12,2,5,10,4,7,10,8,9,11,4,6,10,6,7,10,9,10,11,7,9,10,9,9,11,11,11,11,6,8,11,7,9,11,9,10,12,7,9,11,8,9,12,10,10,12,8,10,11,10,10,11,12,11,11,8,10,12,9,11,12,10,11,12,9,10,12,10,11,12,11,11,12,9,10,12,10,10,11,11,11,10,0,4,8,3,6,9,7,8,9,4,6,8,5,7,9,8,9,9,7,8,9,8,8,9,9,9,9,2,6,9,4,6,9,7,8,10,5,7,9,6,7,9,8,8,9,7,8,9,8,8,9,9,9,9,6,8,10,7,8,10,8,9,10,6,8,10,8,8,10,9,9,10,8,9,10,9,9,10,10,10,9,8,9,10,8,9,10,8,9,10,8,9,10,9,9,10,9,9,9,8,9,9,8,9,9,9,9,8,0,4,10,3,6,10,8,10,12,2,6,10,6,8,11,10,11,12,7,9,11,9,10,12,12,13,13,2,6,10,4,7,11,9,10,13,4,7,11,7,8,11,10,11,12,8,9,12,10,10,12,12,12,13,6,9,12,8,10,13,10,12,14,7,10,13,9,10,13,11,11,13,9,11,13,11,11,13,13,13,13,9,11,13,10,12,14,11,12,14,9,11,14,11,12,14,12,12,14,9,12,13,11,12,13,13,12,12,0,4,9,3,6,9,7,8,10,3,6,9,6,7,9,9,9,10,7,8,9,8,9,10,10,10,11,2,6,9,4,7,10,7,9,10,4,7,10,6,7,10,9,9,10,7,8,10,8,9,10,10,10,10,6,8,11,7,9,11,8,10,11,6,9,11,8,9,11,9,9,11,8,9,11,9,10,11,11,10,10,8,10,11,9,10,11,9,10,11,8,10,11,9,10,11,10,10,11,8,10,11,9,10,11,10,10,10,0,4,12,3,7,12,10,11,14,3,6,12,7,9,13,12,13,14,8,11,13,11,12,14,14,14,14,1,7,12,5,8,13,10,12,14,4,8,13,8,9,13,12,13,14,9,11,14,11,12,14,14,14,14,7,10,14,9,11,14,11,13,16,8,11,14,10,12,14,13,13,16,10,12,15,12,13,15,15,15,15,10,13,15,12,13,14,13,15,15,10,13,15,12,13,15,13,14,15,10,13,14,12,13,14,14,14,14,0,4,9,3,6,10,7,9,11,3,5,9,5,7,10,9,10,12,7,8,10,9,10,11,11,12,12,2,6,10,4,7,10,7,9,12,4,7,10,6,7,11,9,10,12,7,9,11,9,9,11,11,11,12,5,8,11,7,9,12,9,10,13,6,9,12,8,9,12,10,10,12,8,10,12,10,10,12,12,12,12,8,10,12,9,11,13,10,11,13,9,11,13,10,11,13,11,11,13,9,11,12,10,11,12,11,11,12,0,4,12,3,7,13,10,12,15,3,7,13,7,9,14,12,12,13,8,11,14,11,13,15,15,14,14,1,6,13,5,8,13,10,13,15,4,8,13,8,9,14,13,13,15,8,11,14,12,12,15,15,14,14,7,10,13,9,11,13,12,14,16,8,11,14,10,12,15,13,13,16,10,12,15,12,13,15,15,14,15,11,12,14,12,14,14,13,15,15,10,12,14,12,13,15,14,15,15,10,13,13,12,13,15,14,14,15,0,5,10,3,7,11,9,11,14,3,7,11,7,8,12,11,12,14,7,9,12,10,11,14,13,14,16,1,7,11,5,8,12,9,11,15,4,8,12,7,9,13,11,12,15,8,10,13,10,11,14,14,14,16,6,9,13,8,11,14,10,13,16,7,10,14,9,11,15,12,13,16,9,11,15,12,12,15,14,14,16,10,12,14,11,13,15,12,14,16,10,12,15,11,13,16,13,14,16,10,13,16,12,13,15,14,15,16,0,5,16,3,8,14,11,13,14,2,8,14,8,10,16,13,13,14,9,13,16,12,13,16,16,14,16,1,7,14,6,10,14,12,16,16,5,9,14,9,11,16,15,16,16,10,12,16,13,13,16,16,14,16,8,11,14,11,13,14,14,14,16,8,12,14,11,13,16,16,16,16,10,12,15,13,14,16,16,16,16,11,14,14,14,15,16,16,15,16,10,13,16,13,14,14,16,16,16,10,13,16,13,14,16,16,16,16,0,5,11,3,7,13,9,12,16,3,7,12,6,9,14,11,13,16,7,10,16,11,12,16,16,16,16,1,6,12,5,9,16,9,13,16,4,8,16,7,10,16,12,15,16,7,11,16,11,12,16,16,16,16,6,10,15,8,11,16,11,14,16,7,11,16,10,12,16,13,16,16,9,13,16,13,14,16,16,16,16,10,12,16,12,16,16,16,16,16,11,13,16,13,16,16,16,16,16,12,16,16,16,16,16,16,16,16,0,5,16,3,8,16,12,12,16,2,8,16,8,10,16,13,13,16,9,13,16,12,13,16,16,16,16,1,8,16,6,10,16,12,16,16,5,9,16,9,11,16,13,16,16,9,12,14,12,12,16,16,16,16,8,11,13,11,12,16,14,16,16,8,12,16,11,13,16,16,15,16,9,13,14,12,13,16,16,16,16,10,12,13,14,13,16,16,16,16,9,13,16,13,12,16,16,16,16,10,12,16,14,15,16,16,16,16,0,7,5,7,5,7,6,6,7,10,7,9,8,9,8,7,12,14,11,12,12,12,11,9,6,9,6,8,7,9,7,7,8,11,8,9,9,10,9,8,13,15,12,12,12,13,11,9,10,13,9,10,11,12,9,8,12,14,10,11,12,13,10,9,16,16,12,12,14,13,11,9,6,9,7,9,7,9,8,7,9,11,9,10,9,10,9,8,14,16,12,12,13,13,11,9,8,11,8,10,9,10,9,8,10,13,10,11,10,11,9,8,14,16,12,12,13,13,11,9,12,14,10,11,12,13,10,9,13,16,11,12,13,13,10,9,16,16,13,12,14,14,11,9,11,13,11,12,10,11,10,9,13,14,12,12,11,12,10,9,16,16,13,13,13,13,11,9,12,15,12,12,11,12,10,9,13,16,13,13,12,12,11,9,16,16,14,13,13,13,11,9,14,16,13,13,13,14,11,9,16,16,13,13,14,14,11,9,16,16,13,13,14,13,11,8,4,9,6,8,6,9,7,7,8,11,8,9,9,10,8,8,13,15,12,12,13,13,11,9,7,10,7,9,8,10,8,8,9,12,9,10,10,11,9,8,14,16,12,12,13,13,11,9,11,13,9,10,11,12,9,8,12,14,10,11,12,13,10,9,16,16,13,12,14,14,11,9,7,10,8,9,8,10,8,8,10,12,10,11,10,11,9,8,14,16,13,13,13,13,11,9,9,12,9,10,9,11,9,8,11,13,10,11,10,11,10,9,15,16,13,13,13,13,11,9,12,14,11,11,12,13,10,9,13,16,11,12,13,13,10,9,16,16,12,12,14,13,11,8,11,14,11,12,10,11,10,9,13,15,12,13,11,12,10,9,16,16,14,13,13,13,11,9,12,15,12,13,11,12,10,9,13,16,13,13,12,12,11,9,16,16,14,13,13,13,11,9,15,16,13,13,13,13,11,9,16,16,13,13,13,13,11,9,16,16,13,12,13,13,10,7,8,11,8,10,9,11,9,9,10,13,10,11,11,12,10,9,15,16,13,13,14,14,12,10,9,12,9,11,10,11,9,9,12,14,11,11,11,12,10,9,16,16,13,13,14,14,12,10,12,14,10,11,12,13,10,9,14,16,11,12,13,14,10,9,16,16,13,13,15,14,11,9,9,12,10,11,9,11,10,9,12,14,11,12,11,12,10,9,16,16,14,13,14,14,12,10,11,14,10,12,11,12,10,9,12,15,11,12,12,13,11,10,16,16,14,13,14,14,12,10,13,16,11,12,13,14,11,9,14,16,12,12,13,14,11,9,16,16,13,13,14,14,11,9,12,15,12,13,10,12,10,9,14,16,13,13,11,12,11,10,16,16,14,14,14,13,12,9,13,16,13,13,12,13,11,10,14,16,13,13,12,13,11,10,16,16,14,14,13,13,12,9,15,16,13,13,13,14,11,9,16,16,13,13,13,14,11,9,16,16,13,12,13,13,10,8,10,13,10,11,10,12,10,9,12,14,11,12,12,13,11,10,16,16,13,13,14,14,12,9,11,14,10,11,11,12,10,9,13,16,11,12,12,13,11,10,16,16,14,13,14,14,12,9,12,15,10,11,12,13,9,8,14,16,11,11,13,14,10,8,16,16,12,12,14,14,10,8,11,14,11,12,11,12,10,9,13,16,12,13,12,13,11,10,16,16,14,13,14,14,12,9,12,15,11,12,11,13,10,10,13,16,12,13,12,13,11,10,16,16,14,13,14,14,12,9,13,16,11,11,13,13,10,8,14,16,11,12,13,14,10,8,16,16,12,12,14,14,10,8,12,15,12,13,10,11,10,9,14,16,13,13,11,12,10,9,16,16,14,13,13,13,11,8,13,16,12,13,11,12,10,9,14,16,13,13,12,12,10,9,16,16,14,13,13,12,10,8,14,16,12,12,12,13,10,8,14,16,12,12,12,13,10,7,16,16,11,11,12,11,8,5,0,7,4,8,5,8,7,8,6,10,7,10,8,10,9,9,13,16,12,13,13,14,12,12,4,10,6,9,8,11,8,9,8,12,8,11,10,12,10,10,14,16,12,13,14,15,12,12,9,14,9,11,12,14,11,11,11,15,10,12,13,14,11,11,15,16,13,14,15,16,13,12,5,10,7,10,7,10,9,9,8,12,9,11,10,11,10,10,14,16,13,14,14,14,12,12,8,12,8,11,10,12,10,10,10,14,10,12,11,13,10,11,15,16,13,14,14,15,13,12,11,16,10,12,13,15,11,11,13,16,11,13,14,15,12,12,16,16,14,14,16,16,13,12,11,15,11,13,11,13,11,11,13,16,12,14,12,13,12,12,16,16,14,15,15,15,13,12,12,16,12,14,12,14,12,12,14,16,13,14,13,14,12,12,16,16,14,16,16,16,13,12,14,16,13,14,15,16,13,12,16,16,14,15,16,16,13,12,16,16,15,16,16,16,13,12,2,9,5,8,6,9,8,9,7,11,8,10,9,11,9,10,13,16,12,13,14,14,12,12,5,11,6,10,9,11,9,9,9,13,9,11,10,12,10,10,14,16,12,14,14,15,12,12,9,14,9,11,12,14,10,11,11,16,10,12,13,14,11,11,16,16,13,14,15,16,13,12,6,11,7,10,8,11,9,9,9,13,9,11,10,12,10,10,14,16,13,14,14,14,12,12,8,13,8,11,10,12,10,10,10,13,10,12,11,13,10,11,14,16,13,14,14,15,12,12,11,15,10,12,13,15,11,11,12,16,11,13,13,15,12,11,16,16,13,14,15,16,13,12,11,15,11,13,10,13,11,11,13,16,12,14,12,13,12,11,16,16,14,15,15,15,13,12,12,16,12,13,12,14,12,12,13,16,12,14,13,14,12,12,16,16,14,15,15,15,13,12,14,16,13,14,15,16,12,12,16,16,13,14,15,16,12,12,16,16,14,15,16,16,13,12,6,12,7,10,9,12,9,10,9,13,9,12,11,13,11,11,14,16,13,14,15,15,13,12,8,13,8,11,10,13,10,10,10,14,10,12,12,14,11,11,15,16,13,14,16,16,13,12,10,15,9,12,12,15,11,11,12,16,11,13,14,16,12,12,16,16,14,14,16,16,13,12,8,13,9,11,10,12,10,11,11,14,11,12,11,13,11,11,16,16,14,15,15,16,13,12,10,14,10,12,11,13,11,11,11,15,11,13,12,14,11,11,15,16,13,14,15,16,13,12,12,16,11,13,13,16,12,12,13,16,11,13,14,16,12,12,16,16,13,14,16,16,13,12,12,16,12,14,11,13,11,11,13,16,13,14,12,14,12,12,16,16,15,16,16,16,14,13,13,16,12,14,12,14,12,12,14,16,13,14,13,14,12,12,16,16,14,16,14,16,13,12,15,16,13,15,15,16,13,12,15,16,13,15,14,16,13,12,16,16,14,15,15,16,13,11,8,13,8,11,10,13,10,11,11,15,10,12,12,14,11,11,15,16,13,14,15,15,13,12,9,14,9,12,11,14,10,11,11,16,10,12,13,14,11,11,16,16,13,14,15,16,13,12,11,15,9,12,12,14,10,10,12,16,11,12,14,15,11,11,16,16,13,14,16,16,12,11,9,14,10,12,11,13,11,11,12,16,11,13,12,14,11,11,16,16,14,14,15,15,13,12,10,15,10,12,12,14,11,11,12,16,11,13,13,14,11,11,16,16,14,14,15,16,13,12,12,16,10,12,13,15,11,11,13,16,11,13,14,15,11,11], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+513272);
/* memory initializer */ allocate([16,16,13,13,15,16,12,11,12,16,11,13,10,13,11,11,14,16,13,14,12,14,11,11,16,16,15,16,14,15,13,11,13,16,12,14,12,14,11,11,13,16,12,14,12,14,11,11,16,16,14,15,14,14,12,11,14,16,12,13,13,15,11,11,14,16,12,13,13,14,11,11,15,16,12,13,13,13,10,9,0,7,4,7,5,7,6,6,6,10,7,8,8,9,8,7,13,14,11,12,12,12,11,9,5,9,6,8,7,9,7,7,8,11,8,9,9,10,9,8,13,16,12,12,12,13,11,9,10,13,8,10,11,12,9,9,12,14,10,11,12,13,10,9,15,16,12,12,14,14,11,9,6,10,7,9,7,9,8,7,8,11,9,10,9,10,9,8,14,16,12,12,13,12,11,9,8,11,8,10,9,10,9,8,10,13,10,11,10,11,9,9,14,16,12,12,13,13,11,9,12,15,10,11,12,13,10,9,13,16,11,12,13,13,10,9,16,16,12,13,14,14,11,9,10,14,11,12,9,11,10,9,12,15,12,13,11,12,11,9,16,16,13,13,13,13,11,9,12,15,12,13,11,12,11,9,13,16,12,13,12,13,11,10,16,16,13,13,13,13,11,9,14,16,13,13,13,14,11,10,16,16,13,13,13,14,11,10,16,16,13,13,14,14,11,9,4,9,6,8,6,9,7,7,8,11,8,9,9,10,9,8,13,15,12,12,13,13,11,9,6,10,7,9,8,10,8,8,9,12,9,10,10,11,9,8,14,16,12,12,13,13,11,10,10,13,8,10,11,12,9,9,12,15,10,11,12,13,10,9,16,16,12,12,14,14,11,9,7,11,8,9,7,10,8,8,9,12,10,11,9,11,9,9,14,16,12,13,13,13,11,10,9,12,9,10,9,11,9,9,10,13,10,11,10,11,10,9,14,16,12,13,13,13,11,9,12,15,10,11,12,13,10,9,13,16,11,12,13,13,10,9,16,16,12,12,14,14,11,9,10,14,11,12,9,11,10,9,12,16,12,13,11,12,11,9,16,16,14,14,13,13,11,9,12,16,12,13,11,12,10,10,13,16,12,13,11,12,11,10,16,16,13,13,13,13,11,9,14,16,13,13,13,14,11,9,15,16,13,13,13,14,11,9,16,16,13,13,13,13,10,8,7,11,8,10,9,11,9,9,10,13,10,11,11,12,10,10,15,16,13,13,14,14,12,10,9,13,9,11,10,12,10,9,11,14,10,12,12,13,10,10,16,16,13,13,14,14,12,10,11,15,9,11,12,13,10,9,13,16,11,12,13,14,11,10,16,16,13,13,15,15,11,10,9,13,10,11,9,11,10,9,11,14,11,12,11,12,11,10,16,16,14,14,14,14,12,10,10,14,10,12,11,12,10,10,12,15,11,12,12,13,11,10,16,16,13,13,14,14,12,10,13,16,11,12,13,14,11,10,13,16,11,12,13,14,11,10,16,16,12,13,14,14,11,9,11,15,12,13,10,12,10,10,13,16,13,14,11,13,11,10,16,16,14,14,14,14,12,10,13,16,13,13,11,13,11,10,14,16,13,14,12,13,11,10,16,16,14,14,13,13,12,10,15,16,13,14,14,14,11,10,15,16,13,13,13,14,11,10,16,16,12,13,13,13,10,8,9,13,10,11,10,12,10,10,12,15,11,12,12,13,11,10,16,16,14,13,14,14,12,10,10,14,10,12,11,13,10,10,13,16,11,12,12,14,11,10,16,16,13,13,14,14,12,10,12,16,9,11,12,14,10,9,13,16,10,12,13,14,10,9,16,16,12,12,14,14,11,9,10,14,11,12,10,12,10,10,13,16,12,13,12,13,11,10,16,16,14,14,14,14,12,10,11,16,11,12,11,13,11,10,13,16,12,13,12,14,11,10,16,16,14,14,14,14,12,10,13,16,11,12,13,14,10,9,14,16,11,12,13,14,10,9,16,16,12,12,14,14,10,8,12,16,12,13,10,12,10,9,14,16,13,13,11,12,11,9,16,16,14,14,13,13,11,9,13,16,12,13,11,12,10,9,14,16,13,13,11,13,11,9,16,16,14,14,13,13,11,9,14,16,12,13,12,13,10,8,14,16,12,12,12,13,10,8,15,16,11,11,11,12,9,6,0,7,4,7,5,8,7,8,5,10,7,10,8,10,9,10,13,16,12,14,14,14,13,12,4,10,6,9,8,11,9,9,8,12,8,11,10,12,10,10,14,16,13,14,14,15,13,12,9,14,9,12,12,14,11,11,12,16,11,13,13,15,12,12,15,16,14,15,15,16,13,13,5,10,7,10,7,10,9,9,8,12,9,11,9,11,10,10,14,16,13,14,14,15,13,12,7,12,8,11,10,12,10,10,10,13,10,12,11,13,11,11,15,16,13,15,14,16,13,13,11,16,11,13,13,16,12,12,13,16,12,14,14,16,12,12,16,16,14,16,16,16,14,13,11,15,12,14,11,13,11,12,13,16,12,14,12,14,12,12,16,16,14,16,14,16,13,13,13,16,12,14,12,14,12,12,14,16,13,15,13,15,13,13,16,16,15,16,16,16,14,13,15,16,13,16,15,16,13,13,16,16,14,16,16,16,14,13,16,16,16,16,16,16,14,13,2,9,5,8,6,9,8,9,7,11,8,10,9,11,9,10,14,16,13,14,14,15,13,12,5,11,6,10,9,11,9,10,8,13,9,11,11,12,10,11,14,16,13,14,14,16,13,13,9,15,9,12,12,14,11,11,12,16,11,13,13,15,12,12,16,16,14,15,16,16,14,13,6,11,7,10,8,11,9,10,9,13,9,12,10,12,10,11,14,16,13,14,14,15,13,13,8,12,8,11,10,12,10,11,9,13,10,12,11,13,11,11,14,16,13,14,14,16,13,13,12,16,11,13,13,15,12,12,13,16,11,13,14,16,12,12,16,16,14,15,16,16,13,13,11,15,11,14,10,13,11,12,13,16,13,15,12,14,12,12,16,16,15,16,15,16,14,13,12,16,12,14,12,14,12,12,13,16,13,15,13,14,12,13,16,16,15,16,15,16,13,13,15,16,13,16,15,16,13,13,16,16,14,16,16,16,13,13,16,16,15,16,16,16,14,13,5,12,7,10,9,12,10,10,9,13,9,12,11,13,11,11,15,16,13,14,15,15,13,13,7,13,8,11,10,13,10,11,10,14,10,12,12,14,11,12,16,16,14,15,16,16,14,13,10,16,9,12,13,15,11,12,13,16,11,13,14,16,12,12,16,16,14,16,16,16,14,13,8,13,9,12,9,12,10,11,11,15,11,13,11,13,11,12,16,16,14,16,16,16,14,13,9,14,10,12,11,13,11,12,11,15,11,13,12,14,12,12,16,16,14,16,15,16,14,13,12,16,11,14,14,16,12,12,13,16,12,14,14,16,13,13,16,16,13,15,16,16,14,13,11,16,12,14,10,13,12,12,13,16,13,15,12,14,12,13,16,16,16,16,16,16,14,14,13,16,13,15,12,15,12,13,13,16,13,15,12,15,13,13,16,16,15,16,14,16,14,13,16,16,14,16,16,16,14,13,15,16,14,16,15,16,14,13,16,16,14,16,15,16,13,12,8,14,9,12,10,14,11,12,11,16,10,13,12,14,12,12,16,16,14,15,15,16,14,13,9,15,9,12,12,14,11,12,12,16,11,13,13,15,12,12,16,16,14,15,16,16,14,13,11,16,9,12,13,15,11,11,13,16,11,13,14,16,12,12,16,16,14,14,16,16,13,12,9,15,10,13,11,14,11,12,12,16,11,14,12,14,12,12,16,16,14,16,16,16,14,13,10,16,10,13,12,15,12,12,12,16,12,14,13,15,12,12,16,16,14,16,16,16,14,13,12,16,11,13,13,16,12,12,13,16,11,13,14,16,12,12,16,16,13,14,16,16,13,12,11,16,12,14,10,13,11,12,13,16,13,15,12,14,12,12,16,16,16,16,15,16,13,12,12,16,12,15,12,14,12,12,13,16,13,15,12,14,12,12,16,16,15,16,14,15,13,12,14,16,13,14,13,16,12,12,13,16,12,14,13,15,12,12,14,16,12,13,13,14,11,10,0,7,4,7,5,7,6,6,6,10,7,8,8,9,8,8,13,14,11,12,12,12,11,10,5,9,6,8,7,9,7,7,8,11,8,9,9,10,9,8,13,16,12,12,13,13,11,10,10,14,8,10,11,13,9,9,12,15,10,11,12,13,10,10,16,16,12,13,14,14,11,10,5,10,7,9,6,9,8,8,8,11,9,10,9,10,9,8,14,16,12,12,13,13,11,10,8,12,8,10,9,10,9,9,10,13,9,11,10,11,9,9,14,16,12,13,13,13,11,10,12,16,10,12,12,13,10,10,13,16,11,12,13,14,11,10,16,16,12,13,14,14,11,10,10,14,11,13,9,11,10,10,12,16,12,13,11,12,11,10,16,16,13,14,13,13,12,10,12,16,12,13,11,13,11,10,13,16,12,13,12,13,11,10,16,16,13,14,13,14,12,10,14,16,13,14,13,14,12,11,16,16,13,14,14,15,12,11,16,16,13,14,14,14,11,10,3,9,5,8,6,9,7,7,8,11,8,10,9,10,9,8,14,15,12,12,13,13,11,10,6,11,6,9,8,10,8,8,9,12,9,10,10,11,9,9,14,16,12,13,13,13,11,10,10,14,8,11,12,13,9,9,12,16,10,11,12,13,10,10,16,16,12,13,14,14,11,10,6,11,8,10,7,10,8,8,9,12,10,11,9,11,9,9,14,16,12,13,13,13,12,10,9,12,9,11,9,11,9,9,10,13,10,11,10,12,10,9,14,16,12,13,13,13,11,10,12,16,10,12,12,14,10,10,13,16,10,12,13,14,11,10,16,16,12,13,14,14,11,10,10,15,11,13,9,11,10,10,12,16,12,13,11,12,11,10,16,16,14,14,13,14,12,10,12,16,12,13,11,13,11,10,13,16,12,13,11,13,11,10,16,16,13,14,13,13,12,10,14,16,13,14,14,14,11,11,15,16,13,14,13,14,11,10,16,16,13,13,13,14,11,9,7,12,8,11,9,11,9,10,10,14,10,12,11,12,11,10,16,16,13,13,14,14,12,11,9,13,9,11,10,12,10,10,11,15,10,12,12,13,11,10,16,16,13,14,14,14,12,11,11,16,9,11,12,14,10,10,13,16,10,12,13,14,11,10,16,16,13,14,16,16,12,11,9,13,10,12,9,12,10,10,11,15,11,13,11,13,11,11,16,16,14,14,14,14,13,11,10,14,10,12,11,13,11,10,12,16,11,13,12,13,11,11,16,16,13,14,14,14,12,11,13,16,11,13,13,14,11,11,13,16,11,13,13,14,11,11,16,16,12,13,14,15,12,10,11,16,12,14,10,12,11,10,13,16,13,14,11,13,11,11,16,16,15,16,14,14,13,11,13,16,13,14,12,13,11,11,13,16,13,14,12,13,11,11,16,16,14,14,13,14,12,11,15,16,13,14,14,16,12,11,14,16,13,14,13,14,12,11,16,16,12,13,13,14,11,9,9,14,10,12,10,13,11,11,12,16,12,13,12,14,12,11,16,16,14,14,14,14,13,11,10,16,10,13,12,14,11,11,13,16,12,13,13,14,12,11,16,16,14,14,15,15,13,11,12,16,9,12,13,14,10,10,14,16,11,12,13,15,11,10,16,16,13,13,15,16,11,10,10,16,11,13,11,13,11,11,13,16,12,14,12,14,12,11,16,16,14,14,14,14,13,11,11,16,11,13,12,14,11,11,13,16,12,14,13,14,12,11,16,16,14,14,14,15,13,11,13,16,11,13,13,14,11,10,14,16,11,13,13,14,11,10,16,16,12,13,14,15,11,9,12,16,12,14,10,13,11,10,14,16,13,14,11,13,11,10,16,16,14,15,13,14,12,10,13,16,13,14,11,13,11,10,14,16,13,14,12,13,11,10,16,16,14,14,13,13,11,10,14,16,12,13,13,14,11,9,14,16,12,13,12,13,10,9,14,16,11,11,12,12,9,7,0,7,3,8,5,8,7,9,5,10,7,10,8,11,10,10,14,16,14,15,14,16,14,14,4,10,6,10,8,11,9,10,8,12,9,11,10,12,11,11,15,16,14,16,15,16,14,14,10,16,10,13,13,16,12,13,13,16,12,14,14,16,13,13,16,16,16,16,16,16,14,15,4,10,7,10,7,10,9,10,8,12,9,12,10,12,11,12,14,16,14,16,15,16,14,14,8,12,9,12,10,13,11,12,10,14,11,13,11,14,12,13,16,16,14,16,16,16,14,15,12,16,12,14,14,16,13,14,14,16,13,16,16,16,14,14,16,16,16,16,16,16,16,16,11,16,12,16,11,14,13,13,13,16,13,16,13,15,13,14,16,16,16,16,16,16,15,16,13,16,13,16,13,16,13,14,14,16,14,16,14,16,14,15,16,16,16,16,16,16,16,16,16,16,15,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,2,9,5,9,6,10,8,10,7,11,8,11,9,12,10,11,14,16,14,16,15,16,14,14,5,11,6,10,9,12,10,11,9,13,9,12,11,13,11,12,16,16,14,16,16,16,14,14,10,16,9,13,13,16,12,13,13,16,12,14,14,16,13,13,16,16,16,16,16,16,16,14,5,11,8,11,7,11,10,11,9,13,10,13,10,13,11,12,16,16,14,16,16,16,14,14,8,13,9,12,10,13,11,12,10,14,10,13,11,14,12,12,16,16,14,16,15,16,14,14,12,16,12,14,14,16,13,14,14,16,12,16,15,16,13,14,16,16,15,16,16,16,15,15,11,16,12,16,10,14,12,13,13,16,14,16,13,16,13,14,16,16,16,16,16,16,15,16,13,16,13,16,13,16,13,14,14,16,14,16,13,16,13,14,16,16,16,16,16,16,15,16,16,16,15,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,5,13,7,12,9,13,11,12,10,14,10,13,11,13,12,13,16,16,16,16,16,16,16,15,7,14,8,12,11,14,11,12,11,16,11,13,13,16,13,13,16,16,16,16,16,16,16,16,11,16,10,14,14,16,12,13,13,16,12,15,16,16,14,14,16,16,16,16,16,16,16,16,8,14,10,13,9,13,11,12,11,16,12,14,12,14,13,13,16,16,16,16,16,16,16,16,10,16,11,14,12,14,12,13,11,16,12,14,12,15,13,13,16,16,15,16,16,16,15,16,13,16,12,16,15,16,14,14,13,16,12,16,16,16,14,14,16,16,14,16,16,16,14,16,11,16,13,16,10,14,12,13,14,16,14,16,13,16,14,14,16,16,16,16,16,16,16,16,13,16,14,16,13,16,14,15,13,16,14,16,13,16,14,15,16,16,16,16,15,16,15,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,15,16,16,16,15,16,16,16,14,14,8,16,10,14,11,16,12,13,12,16,12,14,13,16,13,14,16,16,16,16,16,16,16,14,10,16,10,14,12,16,12,13,13,16,12,15,14,16,13,14,16,16,16,16,16,16,16,15,11,16,10,13,13,16,12,13,14,16,12,14,15,16,13,13,16,16,16,16,16,16,15,14,10,16,11,14,11,16,12,13,13,16,13,16,13,16,13,14,16,16,16,16,16,16,16,15,11,16,12,14,13,16,13,14,13,16,13,16,14,16,13,14,16,16,16,16,16,16,16,15,13,16,12,14,14,16,13,13,13,16,12,15,14,16,13,13,16,16,14,16,16,16,14,13,11,16,12,16,11,15,12,13,14,16,14,16,13,16,13,14,16,16,16,16,16,16,14,14,12,16,13,16,12,16,13,14,13,16,14,16,13,16,13,14,16,16,16,16,14,16,14,14,14,16,13,16,14,16,13,13,13,16,13,16,14,16,13,13,15,16,13,14,13,15,12,12,0,7,4,6,4,7,6,7,6,9,7,8,7,9,8,8,13,14,12,12,12,13,11,11,5,9,5,8,7,9,7,8,8,11,8,10,9,10,9,9,13,15,12,13,12,13,11,11,9,14,8,11,11,13,10,10,11,15,10,12,12,13,10,11,14,16,12,13,14,14,12,11,5,9,7,9,6,9,8,8,8,11,8,10,8,10,9,9,13,16,12,13,13,13,11,11,7,11,8,10,9,11,9,9,9,13,9,11,10,11,10,10,14,16,12,13,13,13,12,11,11,16,10,12,12,14,11,11,13,16,11,13,13,14,11,11,16,16,13,14,14,15,12,11,10,15,11,13,9,12,10,10,12,16,12,13,11,12,11,11,15,16,13,14,13,14,12,11,12,16,12,14,11,13,11,11,13,16,12,14,12,13,12,11,16,16,13,14,14,14,12,11,14,16,13,14,14,15,12,12,16,16,13,14,14,16,12,12,16,16,14,14,14,15,12,11,3,9,5,8,6,9,7,8,7,11,8,10,9,10,9,9,13,14,12,13,13,13,12,11,6,11,6,9,8,10,8,9,9,12,8,10,10,11,9,10,14,16,12,13,13,14,12,11,9,14,8,11,11,13,10,10,12,16,10,12,12,14,11,11,16,16,12,13,14,15,12,11,6,11,8,10,7,10,8,9,9,12,9,11,9,11,10,10,14,16,13,13,13,14,12,11,8,12,9,11,9,11,9,10,10,13,9,11,10,12,10,10,14,16,12,13,13,14,12,11,12,16,10,12,12,14,11,11,12,16,10,12,13,14,11,11,15,16,12,13,14,14,11,11,10,15,11,13,9,12,10,10,12,16,12,14,11,13,11,11,16,16,14,14,14,14,12,11,12,16,12,14,11,13,11,11,13,16,12,14,11,13,11,11,16,16,13,14,13,14,12,11,14,16,13,14,14,15,12,11,14,16,13,14,13,15,12,11,16,16,13,14,13,14,11,10,6,13,8,11,9,12,10,10,10,14,10,12,11,13,11,11,16,16,13,14,14,14,13,12,8,14,8,12,10,13,10,11,11,15,10,12,12,13,11,11,16,16,14,14,15,16,13,12,11,16,9,12,12,14,11,11,13,16,11,13,13,16,11,11,16,16,13,14,16,16,13,12,8,14,10,12,9,12,10,11,11,15,11,13,11,13,11,11,16,16,14,15,14,15,13,12,10,15,10,13,11,13,11,11,11,15,11,13,12,13,11,11,16,16,13,15,14,15,13,12,12,16,11,13,13,15,11,11,13,16,11,13,13,15,11,11,16,16,12,14,14,16,12,11,11,16,12,14,10,13,11,11,13,16,13,15,12,14,12,12,16,16,15,16,14,15,13,12,12,16,13,14,12,14,12,12,13,16,13,14,12,14,12,12,16,16,14,15,13,14,12,12,15,16,13,15,14,16,12,12,14,16,13,14,13,15,12,12,15,16,12,13,13,14,11,10,9,15,10,13,11,14,11,12,12,16,12,14,12,14,12,12,16,16,14,14,14,15,13,12,10,16,10,13,12,14,12,12,13,16,12,14,13,15,12,12,16,16,14,14,15,16,13,12,11,16,9,12,13,15,11,11,14,16,11,13,14,16,11,11,16,16,13,14,16,16,12,11,10,16,11,14,11,14,12,12,13,16,13,14,12,14,12,12,16,16,14,15,15,15,13,12,11,16,12,14,12,15,12,12,13,16,12,14,13,15,12,12,16,16,14,15,15,16,13,12,12,16,11,13,13,15,11,11,13,16,11,13,13,15,11,11,16,16,12,13,14,16,12,10,11,16,12,14,10,13,11,11,14,16,13,14,12,14,11,11,16,16,15,16,14,14,12,11,12,16,13,14,11,14,11,11,13,16,13,14,12,14,11,11,16,16,14,15,13,14,12,11,14,16,12,14,13,14,11,10,13,16,12,13,12,14,11,10,14,16,11,12,12,12,10,8,0,8,4,9,5,9,8,10,6,11,8,11,9,12,11,12,16,16,16,16,16,16,16,16,4,11,6,11,9,12,10,12,9,13,10,13,11,16,12,13,16,16,16,16,16,16,16,16,11,16,11,16,16,16,14,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,4,11,8,12,7,12,10,12,8,13,10,13,10,13,12,14,16,16,16,16,16,16,16,16,8,13,10,14,11,16,12,14,11,16,12,16,12,16,13,16,16,16,16,16,16,16,16,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,14,16,12,16,16,16,13,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,5,10,7,11,9,11,8,12,9,12,10,13,12,13,16,16,16,16,16,16,16,16,5,12,7,12,10,13,11,12,9,16,10,13,12,16,13,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,14,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,6,12,9,13,8,12,11,13,10,16,11,16,11,16,13,16,16,16,16,16,16,16,16,16,9,16,10,14,11,16,12,16,10,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,14,16,13,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,14,16,11,16,14,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,9,13,10,16,12,14,11,16,12,16,12,16,13,16,16,16,16,16,16,16,16,16,8,16,9,14,12,16,13,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,16,16,12,16,10,16,16,16,14,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,10,16,12,16,12,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,10,16,12,16,13,16,14,16,11,16,13,16,13,16,16,16,16,16,16,16,16,16,16,16,14,16,13,16,16,16,16,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,11,16,14,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,12,16,13,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,10,16,11,16,13,16,14,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,12,16,13,16,13,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,14,16,16,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,12,16,16,16,14,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,11,16,13,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,13,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,14,16,16,16,14,15,0,7,3,7,4,7,6,7,6,9,7,9,7,9,8,9,13,14,12,13,13,13,12,12,4,9,5,9,7,9,8,9,7,11,8,10,9,11,9,10,13,16,12,14,13,14,12,12,9,14,8,12,12,14,10,11,11,16,10,13,13,14,11,12,15,16,13,14,14,16,12,12,5,10,7,9,6,9,8,9,8,11,8,11,8,10,9,10,14,16,12,14,13,14,12,12,7,12,8,11,9,11,9,10,9,13,9,12,10,12,10,11,14,16,12,14,13,14,12,12,12,16,11,13,13,15,11,12,13,16,11,14,13,15,12,12,15,16,13,15,14,16,13,13,10,15,12,14,9,13,11,12,12,16,12,14,11,13,12,12,15,16,13,15,14,15,13,13,12,16,12,14,12,14,12,12,13,16,13,14,12,14,12,12,16,16,14,15,14,16,13,13,15,16,13,15,14,16,12,13,16,16,14,16,14,16,13,13,16,16,14,16,15,16,13,13,3,9,5,9,6,9,8,9,7,11,8,10,9,11,9,10,14,15,13,14,13,14,12,12,5,11,6,10,8,11,9,10,9,12,9,11,10,12,10,11,14,16,13,14,14,15,13,13,9,15,8,12,12,14,10,11,12,16,10,13,13,15,11,12,15,16,13,14,14,16,13,13,6,11,8,11,7,10,9,10,9,13,10,12,9,12,10,11,14,16,13,14,14,14,13,13,8,13,9,12,9,12,10,11,9,13,9,12,10,12,10,11,14,16,12,14,13,14,12,12,12,16,11,13,13,15,11,12,12,16,11,13,13,15,11,12,14,16,12,14,14,15,12,12,10,15,11,14,9,13,11,12,12,16,12,14,11,14,12,12,16,16,14,16,14,15,13,13,12,16,12,14,11,14,12,12,12,16,13,14,11,14,12,12,15,16,14,15,13,15,12,13,14,16,13,15,14,16,13,13,14,16,13,15,14,16,12,13,15,16,13,15,13,15,12,12,6,13,8,12,9,12,10,11,10,14,11,13,11,13,12,12,15,16,14,15,15,15,14,13,8,14,9,12,11,13,11,12,11,15,11,13,12,14,12,12,16,16,14,15,15,16,14,14,10,16,9,13,12,15,11,12,13,16,11,14,13,16,12,12,16,16,14,15,16,16,13,13,8,14,10,13,9,13,11,12,11,15,12,14,11,14,12,12,16,16,15,16,15,16,14,14,10,15,10,13,11,14,11,12,11,15,11,14,12,14,12,12,15,16,14,15,14,16,13,13,12,16,11,14,13,16,12,12,12,16,11,14,13,15,12,12,15,16,12,14,15,16,13,13,11,16,12,14,10,14,11,12,13,16,13,16,12,14,12,13,16,16,16,16,15,16,14,13,12,16,13,15,12,14,12,13,13,16,13,15,12,14,12,13,16,16,14,16,13,15,13,13,15,16,14,16,14,16,13,13,14,16,13,15,13,16,13,13,14,16,12,14,13,14,12,12,9,16,11,14,11,15,12,13,13,16,12,14,12,15,13,13,16,16,14,15,15,15,14,13,11,16,11,14,12,16,12,13,13,16,12,14,13,16,13,13,16,16,14,15,16,16,14,13,11,16,10,13,13,16,11,12,14,16,11,14,14,16,12,12,16,16,14,14,16,16,13,12,11,16,12,14,11,15,12,13,13,16,13,15,13,16,13,13,16,16,15,16,15,16,14,13,11,16,12,15,12,16,12,13,13,16,13,15,13,16,13,13,16,16,15,16,15,16,14,13,12,16,11,14,13,16,12,12,13,16,11,14,13,16,12,12,16,16,13,14,15,16,12,12,11,16,12,14,10,14,11,12,14,16,13,15,12,15,12,12,16,16,16,16,14,15,13,12,12,16,13,15,12,14,12,12,13,16,13,15,12,14,12,12,16,16,14,16,14,15,12,12,14,16,13,15,13,16,11,12,13,16,12,14,13,15,11,11,14,16,12,13,12,13,11,10,0,8,4,9,5,10,9,11,5,11,9,12,9,13,12,16,16,16,16,16,16,16,16,16,4,11,6,12,9,13,11,13,9,16,10,16,12,16,13,16,16,16,16,16,16,16,16,16,12,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,12,8,13,7,12,11,16,8,16,11,16,11,16,15,16,16,16,16,16,16,16,16,16,8,16,10,16,11,16,13,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,6,11,7,12,10,13,7,12,10,13,10,16,12,16,16,16,16,16,16,16,16,16,5,13,7,12,10,16,12,16,10,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,11,16,11,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,5,13,9,16,8,16,12,16,9,16,12,16,11,16,16,16,16,16,16,16,16,16,16,16,9,16,11,16,12,16,13,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,9,16,10,16,13,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,8,16,9,16,12,16,13,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,11,16,13,16,12,16,13,16,13,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,13,16,16,16,11,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,7,16,11,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,11,16,13,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,7,4,8,4,8,7,8,6,10,7,10,8,10,9,10,13,16,13,15,13,15,13,14,4,10,5,10,7,10,9,10,7,12,8,11,9,12,10,11,13,16,13,15,13,16,13,14,9,16,9,13,12,16,11,13,11,16,11,14,13,16,12,14,15,16,14,16,15,16,14,14,4,10,7,10,6,10,9,10,8,12,9,12,9,11,10,12,13,16,13,16,14,16,13,14,7,12,8,12,9,12,10,12,9,13,10,13,10,13,11,12,14,16,13,16,14,16,13,14,12,16,11,14,13,16,12,14,13,16,12,16,14,16,13,14,16,16,14,16,15,16,14,14,10,16,12,15,10,14,12,13,12,16,13,16,12,14,13,14,15,16,14,16,14,16,14,14,12,16,13,16,12,16,13,14,13,16,13,16,13,16,13,14,16,16,14,16,15,16,14,15,15,16,14,16,15,16,13,15,16,16,14,16,15,16,14,15,16,16,16,16,16,16,15,15,2,9,5,10,6,10,8,10,7,11,8,11,9,11,10,11,14,16,13,15,14,15,14,14,5,11,6,11,8,12,9,11,8,13,9,12,10,13,11,12,14,16,13,15,14,16,14,14,9,16,8,13,12,16,11,13,12,16,11,14,13,16,12,13,16,16,14,16,15,16,14,15,5,12,8,11,7,11,9,11,9,13,10,13,10,13,11,12,14,16,14,16,14,16,14,15,8,13,9,13,10,13,11,12,9,13,10,13,10,13,11,13,13,16,13,15,13,16,13,14,12,16,11,14,13,16,12,14,12,16,11,14,13,16,12,14,14,16,13,16,14,16,13,14,10,16,12,15,9,14,11,13,12,16,13,16,12,15,12,14,16,16,15,16,15,16,14,14,12,16,13,16,12,16,12,14,12,16,13,16,12,15,13,14,15,16,14,16,14,16,14,14,15,16,14,16,14,16,14,15,14,16,13,16,14,16,13,14,16,16,14,16,14,16,13,14,6,14,9,13,9,14,11,12,10,14,11,13,11,14,12,13,16,16,15,16,15,16,14,15,8,15,9,13,11,14,11,13,11,16,11,14,12,15,12,14,16,16,15,16,16,16,15,16,10,16,9,14,12,16,12,13,13,16,11,15,14,16,13,14,16,16,15,16,16,16,15,16,8,15,10,13,10,14,11,13,11,16,12,14,12,14,12,14,16,16,16,16,16,16,15,16,10,16,11,14,11,15,12,13,11,16,11,14,12,15,12,14,16,16,14,16,15,16,14,15,12,16,11,15,13,16,13,14,12,16,11,14,13,16,13,14,15,16,13,16,16,16,14,15,10,16,12,15,10,15,12,13,13,16,13,16,12,16,13,14,16,16,16,16,16,16,15,15,12,16,13,16,12,16,13,14,12,16,13,16,12,16,13,14,16,16,15,16,14,16,14,15,15,16,14,16,15,16,14,15,14,16,13,16,14,16,13,14,14,16,13,15,14,16,13,14,9,16,11,16,11,16,12,14,13,16,12,16,13,16,13,14,16,16,15,16,16,16,15,15,11,16,11,16,12,16,13,14,13,16,12,16,13,16,13,14,16,16,15,16,16,16,15,15,11,16,10,15,13,16,12,13,14,16,12,16,14,16,13,14,16,16,15,16,16,16,14,14,11,16,12,16,11,16,13,14,13,16,13,16,13,16,13,14,16,16,16,16,16,16,15,15,11,16,12,16,12,16,13,14,13,16,13,16,13,16,13,14,16,16,15,16,16,16,15,14,12,16,12,15,13,16,12,14,13,16,12,16,14,16,13,14,16,16,14,16,16,16,14,14,11,16,12,16,11,16,12,14,14,16,14,16,12,16,13,14,16,16,16,16,16,16,15,14,12,16,13,16,12,16,12,14,13,16,13,16,12,16,13,14,16,16,16,16,15,16,14,14,14,16,13,16,14,16,12,14,13,16,13,16,13,16,12,13,15,16,13,14,14,15,13,13,0,8,4,10,5,11,10,16,5,12,9,16,10,16,16,16,16,16,16,16,16,16,16,16,4,12,7,12,9,16,12,16,9,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,12,9,16,8,16,12,16,8,16,11,16,11,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,12,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,11,6,12,7,16,11,16,7,16,10,16,11,16,16,16,16,16,16,16,16,16,16,16,5,16,7,16,10,16,12,16,9,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,10,16,8,16,12,16,9,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,9,16,11,16,12,16,16,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,9,16,10,16,16,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,9,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,11,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,10,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,9,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,8,4,10,5,9,8,10,6,11,8,12,8,11,10,13,14,16,14,16,14,16,16,16,3,11,5,11,8,12,10,12,7,12,9,13,10,13,11,13,14,16,14,16,16,16,16,16,9,16,9,16,12,16,12,16,11,16,11,16,14,16,13,16,16,16,16,16,16,16,16,16,4,11,7,12,6,11,10,12,8,13,9,13,9,13,11,14,13,16,14,16,14,16,16,16,7,13,9,13,9,13,11,13,9,14,10,16,11,16,12,16,15,16,14,16,16,16,16,16,12,16,12,16,14,16,13,16,13,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,10,16,13,16,12,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,12,16,13,16,13,16,14,16,13,16,14,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,2,10,5,11,6,11,9,11,7,12,9,13,9,13,11,13,14,16,16,16,16,16,16,16,4,12,6,12,8,13,10,13,8,13,9,13,11,16,12,16,16,16,16,16,16,16,16,16,9,16,8,16,12,16,12,16,12,16,11,16,13,16,13,16,16,16,16,16,16,16,16,16,5,12,8,13,7,13,10,13,8,14,10,14,10,14,12,14,16,16,16,16,16,16,16,16,7,14,9,16,10,16,11,14,8,14,10,16,11,16,12,16,13,16,14,16,16,16,16,16,11,16,11,16,13,16,13,16,12,16,12,16,14,16,14,16,16,16,16,16,16,16,16,16,9,16,12,16,10,16,12,16,12,16,13,16,12,16,14,16,16,16,16,16,16,16,16,16,12,16,13,16,12,16,14,16,12,16,13,16,12,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,8,16,9,16,11,13,10,16,11,16,11,16,13,16,16,16,16,16,16,16,16,16,7,16,9,16,10,16,12,16,11,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,10,16,9,16,12,16,13,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,7,16,10,16,9,16,12,16,11,16,12,16,12,16,13,16,16,16,16,16,16,16,16,16,9,16,11,16,11,16,12,16,11,16,12,16,13,16,13,16,16,16,16,16,16,16,16,16,12,16,12,16,14,16,14,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,10,16,13,16,13,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,12,16,13,16,12,16,14,16,12,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,11,16,11,16,13,16,12,16,13,16,13,16,15,16,16,16,16,16,16,16,16,16,10,16,11,16,13,16,13,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,11,16,11,16,14,16,13,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,12,16,13,16,13,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,11,16,12,16,13,16,14,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,12,16,12,16,14,16,14,16,14,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,11,16,14,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,12,16,14,16,13,16,14,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,10,4,12,5,16,11,16,6,16,10,16,11,16,16,16,16,16,16,16,16,16,16,16,3,16,7,16,10,16,16,16,9,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,16,10,16,9,16,16,16,9,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,12,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,16,6,16,8,16,16,16,8,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,5,16,8,16,11,16,16,16,10,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,11,16,9,16,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,12,16,16,16,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,9,16,11,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,11,16,15,16,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+523512);
/* memory initializer */ allocate([15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,9,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,3,3,3,3,3,4,4,4,4,4,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,6,0,0,60,0,67,0,76,0,85,0,96,0,108,0,121,0,136,0,152,0,171,0,192,0,216,0,242,0,16,1,49,1,85,1,127,1,176,1,225,1,32,2,94,2,171,2,255,2,86,3,195,3,50,4,188,4,112,5,30,6,172,6,186,7,163,8,1,0,0,0,2,0,0,1,8,48,0,0,64,48,0,0,8,48,0,0,8,192,0,0,0,8,0,0,8,1,0,0,16,48,0,0,32,48,0,0,8,240,0,0,8,48,0,1,47,0,98,0,139,1,47,6,191,24,255,35,0,0,0,0,6,7,9,11,13,14,0,0,1,3,3,4,4,5,6,6,6,7,7,7,8,8,9,9,9,9,10,10,10,11,11,11,10,10,10,12,13,14,15,15,1,2,3,5,5,6,6,7,7,8,8,9,10,10,10,11,11,11,12,12,13,13,13,13,13,13,13,14,16,16,16,16,1,2,3,4,5,6,8,8,9,9,10,10,11,12,12,12,13,13,14,14,14,14,16,16,14,16,16,16,14,16,16,16,1,2,3,4,5,6,8,8,9,9,10,10,11,12,12,12,13,13,16,16,16,16,16,16,16,16,14,12,16,16,16,16,1,2,3,4,5,7,7,8,8,9,10,10,12,11,13,12,15,13,14,13,12,15,14,13,12,12,10,11,16,16,16,16,1,2,4,4,5,5,6,7,7,7,8,8,8,9,9,10,10,10,10,11,11,11,11,12,11,11,11,13,14,15,16,16,1,2,3,5,5,6,6,7,7,8,9,9,9,10,10,10,11,11,12,12,12,12,13,13,12,12,13,14,16,16,16,16,1,2,3,4,6,6,7,7,8,8,9,9,10,10,11,12,12,12,13,13,13,14,14,15,14,14,16,16,16,16,16,16,1,2,3,4,5,6,8,8,9,9,10,10,11,11,12,12,13,13,15,15,16,16,16,16,16,16,16,16,16,16,16,16,1,2,3,4,5,6,7,8,9,10,11,13,14,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,2,3,4,5,6,7,8,10,10,11,11,13,12,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,2,3,4,5,6,7,8,10,10,10,11,14,13,15,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,7,9,9,8,9,8,9,8,9,9,8,8,8,8,8,4,7,10,11,10,11,10,12,10,12,11,11,10,11,10,10,7,10,11,15,12,15,12,15,12,15,14,14,12,14,12,14,9,7,11,10,10,12,11,11,10,11,12,10,10,11,10,10,7,8,12,12,11,13,12,12,10,13,13,12,10,12,11,11,7,11,13,15,11,15,13,15,12,16,14,14,12,15,13,13,9,10,15,11,12,15,14,14,12,15,15,12,12,14,14,12,9,11,15,13,12,16,15,14,12,15,15,13,12,15,14,13,9,13,15,14,10,16,15,16,11,16,16,15,12,16,15,15,9,7,11,11,11,11,10,11,10,11,12,11,10,10,10,10,7,9,12,13,12,12,11,13,10,13,13,12,11,12,10,11,7,12,13,16,14,15,12,16,12,16,15,15,13,15,12,14,9,9,13,13,12,13,12,13,11,13,13,12,11,12,11,11,7,9,13,13,12,13,12,13,11,13,13,13,11,12,11,11,7,12,14,15,13,16,13,15,11,16,14,15,12,15,12,13,8,12,16,14,14,16,15,15,13,16,15,14,13,15,14,13,9,12,15,14,13,15,14,15,12,16,15,14,12,14,13,13,8,13,16,16,12,16,14,16,11,16,16,15,12,16,14,14,8,10,15,15,15,12,12,14,12,14,15,15,14,12,12,13,9,11,15,16,14,13,12,15,12,16,15,15,14,14,12,13,9,14,15,16,16,15,11,16,12,16,16,16,15,16,12,15,9,12,16,16,15,14,14,14,13,16,16,15,14,14,13,13,9,12,15,15,14,14,13,15,12,16,15,14,13,14,13,13,8,13,16,16,15,16,12,16,11,16,16,16,14,16,13,14,8,14,16,16,16,16,16,15,14,16,16,16,15,16,15,14,11,13,16,16,15,16,15,15,12,16,16,16,14,15,14,14,9,14,16,16,13,16,14,16,10,16,16,16,13,16,14,14,8,7,12,11,11,11,11,12,10,11,11,10,10,10,10,10,7,9,13,13,12,13,12,13,11,13,13,12,11,12,11,11,8,12,14,16,14,16,14,16,13,16,14,15,13,15,13,14,9,9,13,12,12,13,12,13,11,12,13,11,10,12,11,11,7,9,13,13,12,13,12,13,11,13,13,12,11,12,11,11,7,12,14,16,13,16,14,15,12,15,15,14,12,15,13,13,8,11,15,13,14,15,15,14,13,15,15,12,12,14,14,12,9,11,15,14,13,15,14,14,12,15,14,13,11,14,13,12,8,13,16,15,12,16,15,16,12,16,16,14,11,15,14,14,8,8,13,13,12,12,12,13,11,12,13,12,11,11,10,10,7,9,13,14,12,13,12,13,11,13,13,13,11,12,11,11,7,12,14,16,14,15,13,15,12,15,15,15,13,14,12,13,8,9,13,13,12,13,12,13,11,13,13,12,11,12,11,11,7,9,13,12,12,13,12,12,10,13,13,12,10,12,10,10,6,11,14,14,12,14,12,14,11,14,14,13,11,13,11,12,7,12,16,14,14,15,15,14,13,15,15,13,12,14,13,12,8,11,14,13,12,14,13,13,11,14,14,13,11,13,12,11,7,11,14,14,12,15,13,14,11,15,14,13,11,14,12,12,6,11,16,15,15,13,14,15,13,14,15,15,13,12,12,12,9,12,15,15,14,14,13,15,12,15,15,14,13,13,11,12,8,13,16,16,15,16,13,16,13,16,16,15,14,14,12,14,8,11,16,15,14,14,14,14,13,15,15,14,13,13,12,12,8,11,14,14,13,13,12,14,11,14,14,13,12,12,11,11,7,12,14,15,13,14,12,14,11,15,14,14,12,13,11,12,7,13,16,16,16,16,15,16,14,16,16,15,14,15,14,13,9,12,15,14,13,15,13,14,12,15,15,13,12,13,12,12,7,11,15,14,12,14,13,14,10,15,14,13,11,13,11,11,5,10,15,15,15,15,14,15,13,12,14,12,12,12,13,12,9,12,16,16,15,16,15,16,14,14,15,14,13,14,13,13,9,14,16,16,16,16,16,16,15,16,16,16,14,16,14,15,11,11,15,15,14,15,15,15,14,14,15,12,12,13,13,12,9,12,15,15,14,16,14,15,13,14,14,13,12,14,13,12,8,13,16,16,15,16,16,16,14,16,16,15,12,16,14,14,9,13,16,14,16,16,16,16,15,15,16,11,12,16,15,12,9,13,16,15,14,16,15,16,14,15,16,12,11,15,14,13,8,13,16,16,13,16,16,16,13,16,16,13,11,16,14,14,8,11,15,15,15,14,14,15,13,13,15,14,13,12,12,12,9,11,15,16,14,15,14,15,13,14,14,14,13,13,12,13,8,13,16,16,16,16,15,16,14,16,16,16,13,15,12,14,9,11,16,15,14,14,14,15,13,14,14,13,12,13,12,11,8,11,14,14,13,14,13,14,12,13,13,12,11,12,11,11,7,12,15,15,13,15,14,15,12,15,14,14,11,13,12,12,7,13,16,15,15,16,16,16,14,15,16,12,12,14,14,12,8,11,15,14,13,15,13,14,12,14,14,12,11,13,12,11,6,11,14,14,12,15,13,14,11,15,14,12,10,13,11,11,5,12,16,16,16,15,15,16,15,14,16,15,15,10,12,12,9,13,16,16,16,15,14,16,13,15,15,15,14,12,11,13,8,14,16,16,16,16,14,16,13,16,16,16,14,14,11,14,8,13,16,16,15,15,15,15,14,15,16,14,13,12,12,11,8,11,15,15,13,14,13,14,12,14,14,13,12,12,11,11,6,11,15,15,13,15,12,14,11,14,14,13,11,12,10,11,5,13,16,16,15,16,16,16,14,16,16,14,14,14,13,11,8,11,14,14,13,14,13,14,11,14,14,12,11,12,11,10,5,10,13,13,11,13,12,13,9,13,13,12,9,12,10,10,3,5,7,7,7,7,7,8,7,7,8,7,7,7,7,7,4,7,9,11,9,11,9,11,9,11,10,10,9,10,9,10,6,11,11,14,11,14,11,14,11,15,13,14,12,14,12,13,9,6,11,10,9,11,10,11,9,11,11,9,9,10,10,9,6,8,11,11,10,12,11,12,10,12,12,11,10,12,11,11,7,11,13,14,11,15,13,15,11,15,14,14,12,14,13,13,9,10,14,11,11,15,14,13,12,14,14,11,11,14,13,12,9,11,14,13,11,15,14,14,11,15,15,13,11,14,14,13,9,12,14,14,10,16,15,16,11,16,16,15,11,16,15,14,9,6,10,11,10,10,9,11,9,10,11,10,10,9,9,9,6,9,12,12,11,12,10,12,10,12,12,12,11,11,10,11,7,12,13,15,13,14,11,15,11,15,15,14,13,14,12,14,9,9,12,12,11,12,11,12,11,12,13,11,11,12,11,11,7,9,12,12,11,13,11,12,10,13,13,12,11,12,11,11,7,12,14,15,12,15,12,14,11,15,15,14,12,14,13,13,8,12,15,14,13,15,14,14,13,16,16,14,13,15,14,13,9,12,15,14,13,15,14,14,12,15,15,13,12,14,13,13,9,13,15,15,12,16,14,15,11,16,16,15,12,15,14,14,9,10,14,14,14,12,11,13,12,14,15,14,13,12,11,12,9,12,14,15,14,13,11,14,12,15,15,15,14,13,11,13,9,13,15,16,15,14,11,16,11,16,16,16,14,15,12,15,9,12,15,15,14,14,14,14,13,15,15,14,14,14,13,13,9,12,15,15,14,14,13,14,12,15,15,14,13,14,13,13,9,13,15,16,14,15,13,16,11,16,16,15,14,15,13,14,9,14,16,16,16,16,16,15,14,16,16,16,16,16,16,14,11,14,16,16,14,16,15,15,12,16,16,16,14,15,14,14,9,14,16,16,14,16,14,16,11,16,16,16,14,16,14,14,9,6,11,10,10,10,10,11,10,10,11,9,9,9,9,9,6,9,12,12,11,13,11,13,11,12,12,11,11,12,11,11,7,12,14,16,13,16,14,16,13,15,14,15,12,15,13,14,9,8,12,11,11,12,12,12,11,11,12,10,10,11,11,10,7,9,12,12,11,13,12,13,11,13,12,11,10,12,11,11,7,12,14,15,12,15,14,15,12,15,14,14,12,14,13,13,9,11,15,13,13,15,14,14,13,14,15,11,11,14,14,12,9,11,14,13,12,15,14,14,12,14,14,12,11,14,13,12,8,13,15,15,12,16,15,15,12,15,15,14,11,15,14,14,8,8,12,12,11,11,11,12,11,11,12,11,11,10,10,10,7,9,13,13,12,13,11,13,11,12,13,12,11,11,10,11,7,12,14,15,14,15,13,15,12,15,14,14,13,14,12,13,9,9,13,12,12,12,12,12,11,12,13,11,11,11,11,10,7,9,12,12,11,12,11,12,10,12,12,11,10,11,10,10,7,11,13,14,12,14,12,14,11,14,13,13,11,13,11,12,7,12,15,14,13,15,14,14,13,15,15,13,12,13,13,12,9,11,14,13,12,14,13,13,11,14,14,12,11,13,12,11,7,11,14,14,12,14,13,14,11,14,14,13,11,13,12,12,7,11,15,15,14,13,13,14,13,14,15,14,13,11,11,12,9,12,15,15,14,14,12,14,12,14,14,14,13,12,11,12,8,13,16,16,15,15,12,16,13,16,15,15,14,14,12,14,9,12,15,15,14,14,14,14,13,15,15,14,13,12,12,12,9,11,14,14,13,13,12,13,11,14,13,13,12,12,11,11,7,12,14,15,13,14,12,14,11,15,14,13,12,13,11,12,7,13,16,16,15,16,15,15,14,16,16,15,14,14,14,12,9,12,15,14,13,14,13,14,12,15,14,13,12,13,12,12,8,12,14,14,13,15,13,14,11,14,14,13,12,13,12,12,6,10,14,14,13,14,14,14,13,12,13,12,12,12,12,11,9,12,15,15,14,15,14,16,14,14,14,13,12,14,13,13,9,14,16,16,16,16,16,16,15,16,16,16,14,16,14,16,11,11,15,14,14,15,14,14,14,13,14,11,12,13,13,12,9,12,15,14,14,15,14,15,13,14,14,13,12,14,13,13,9,13,16,16,14,16,15,16,14,16,15,15,12,16,14,14,9,13,16,14,15,16,16,16,14,14,16,11,12,15,14,12,9,13,16,15,14,16,15,16,14,15,15,12,11,15,14,13,9,14,16,16,13,16,16,16,14,16,15,13,11,16,14,14,9,11,15,15,14,14,14,14,13,13,14,13,13,11,11,11,9,12,15,15,14,15,14,15,13,14,14,13,13,13,12,12,9,13,16,16,16,16,14,16,14,16,15,16,14,15,12,14,9,11,15,14,14,15,14,14,13,14,14,12,12,12,12,11,8,11,14,14,13,14,13,13,12,13,13,12,11,12,11,11,7,12,14,15,13,15,13,14,13,14,14,13,12,13,12,12,8,13,16,15,15,16,15,15,14,15,16,12,12,14,14,11,9,12,15,14,13,15,13,14,12,14,14,12,11,13,12,11,7,12,14,14,13,15,13,14,12,15,14,13,10,13,12,12,6,12,16,16,15,14,14,15,14,13,15,14,14,10,11,11,9,13,16,16,15,15,14,15,14,15,15,15,14,12,11,12,8,14,16,16,16,16,14,16,14,16,15,15,14,14,11,14,8,12,16,16,15,15,14,15,14,14,16,14,14,12,12,11,8,11,14,14,13,14,13,14,12,14,14,13,12,12,11,11,7,12,14,15,13,14,13,14,12,14,14,13,12,13,11,12,6,14,16,16,16,16,16,15,14,16,16,14,13,13,13,11,8,12,15,15,13,15,13,14,12,14,14,13,12,13,12,10,6,11,14,13,12,14,12,13,10,14,13,12,10,12,10,10,4,4,6,6,6,6,6,7,6,6,7,6,6,6,6,6,3,6,9,10,9,10,9,11,9,10,10,10,9,10,9,10,6,10,11,14,11,14,11,14,11,14,13,14,11,14,11,13,9,6,10,9,9,10,10,10,9,10,11,9,9,10,10,9,6,8,11,11,9,12,11,12,10,12,12,11,10,12,11,11,7,11,13,14,11,15,13,15,11,15,14,14,11,15,13,14,9,10,13,11,11,14,14,13,11,14,14,11,11,13,13,11,9,11,14,12,11,15,14,14,11,15,15,13,11,14,14,13,9,12,14,13,10,16,15,16,11,16,16,14,11,16,14,14,9,6,10,10,10,9,9,10,9,10,11,10,10,9,9,9,6,8,11,12,11,11,10,12,10,12,12,12,11,11,10,11,7,11,13,15,13,14,11,15,11,15,14,14,13,14,12,14,9,8,12,12,12,12,12,12,11,12,13,11,11,11,11,11,8,9,12,12,11,12,12,13,11,13,13,12,11,12,11,11,8,11,14,15,13,14,13,15,11,15,15,14,13,15,13,14,9,12,16,14,14,15,15,14,12,15,16,14,13,14,14,13,10,11,15,14,13,15,14,15,12,15,16,14,13,15,14,13,9,13,15,15,12,16,15,16,12,16,16,15,13,15,14,14,9,10,14,14,14,11,11,13,11,14,14,14,13,11,11,11,9,11,14,15,14,13,11,14,12,15,15,15,14,13,11,13,9,13,14,16,15,14,11,16,12,16,16,16,14,15,12,15,10,12,16,15,15,14,14,14,12,16,16,14,14,14,13,13,10,12,15,15,14,14,13,14,12,15,16,14,14,14,13,13,9,13,16,16,14,16,13,16,12,16,16,16,14,16,13,15,10,14,16,16,16,16,16,15,14,16,16,16,16,16,16,14,11,13,16,16,15,16,16,16,13,16,16,16,15,16,15,14,10,14,16,16,14,16,14,16,12,16,16,16,15,16,15,15,10,6,10,10,10,10,10,11,10,9,10,9,9,9,9,9,6,9,12,12,11,12,11,13,11,12,12,11,10,12,11,11,8,12,14,15,14,15,14,16,13,15,14,14,12,15,13,14,10,8,12,11,11,12,12,12,11,11,12,10,10,11,11,10,7,9,12,12,11,13,12,13,11,12,13,11,10,12,12,11,8,11,14,14,13,15,14,15,13,15,14,14,12,15,13,14,9,11,15,12,13,15,15,14,13,14,15,11,11,14,14,12,9,11,14,13,13,15,14,15,13,15,15,13,11,15,14,13,9,13,15,15,12,16,15,16,13,16,15,14,11,16,15,14,9,8,12,12,11,11,11,12,11,11,12,11,11,9,10,10,7,9,12,13,12,12,11,13,11,12,13,12,12,11,11,11,8,12,14,15,14,15,13,16,13,15,14,15,13,14,12,14,9,9,13,12,12,12,12,13,12,12,13,11,11,11,11,10,8,9,12,12,12,12,12,13,11,12,13,11,11,12,11,11,7,11,13,14,13,14,13,15,12,14,14,14,12,14,12,13,8,12,15,14,14,15,15,14,13,15,16,13,13,14,14,12,9,11,14,13,13,14,14,14,12,14,15,13,12,14,13,12,8,11,14,14,13,15,14,15,12,15,15,14,12,14,13,13,8,11,14,14,14,13,13,14,13,13,14,14,13,11,11,11,9,11,15,15,14,14,13,15,13,14,15,14,14,13,11,13,9,13,16,16,16,15,13,16,13,16,16,16,15,15,12,15,10,11,15,15,15,14,14,14,13,15,15,14,14,13,13,12,9,11,14,14,13,13,13,14,12,14,14,13,13,13,12,12,8,12,15,15,14,15,13,15,12,15,15,14,13,14,12,13,8,13,16,16,16,16,16,16,14,16,16,15,15,15,15,13,10,12,15,15,14,15,14,15,13,15,16,14,13,14,14,13,9,12,15,15,14,15,14,15,12,15,15,14,13,14,13,13,8,10,14,13,13,14,13,14,13,11,13,11,11,11,11,11,9,12,15,16,14,15,14,16,14,14,14,14,13,14,13,13,10,14,16,16,16,16,16,16,16,16,15,16,13,16,14,16,11,11,15,14,14,15,14,15,14,13,14,11,12,13,13,11,9,12,15,15,14,15,15,16,14,14,14,13,12,14,13,13,9,13,16,16,15,16,16,16,15,16,15,15,12,16,14,15,10,12,16,14,15,16,16,16,14,14,16,11,12,14,15,12,9,13,16,15,14,16,16,16,14,15,16,13,12,15,15,13,9,14,16,16,14,16,16,16,15,16,16,14,12,16,15,15,10,11,14,14,14,14,14,14,13,12,14,13,13,11,11,11,9,11,15,15,14,14,14,16,14,14,14,14,13,13,12,13,9,13,16,16,16,16,15,16,15,16,15,16,14,15,13,15,10,11,15,15,14,14,14,15,14,14,15,13,13,12,13,11,9,11,14,14,13,14,14,14,13,13,14,13,12,13,12,12,8,12,15,15,14,16,14,16,14,15,15,15,13,14,13,14,9,13,16,15,16,16,16,16,15,15,16,13,13,14,14,12,9,12,15,14,14,15,15,15,13,14,15,13,12,14,13,12,8,12,15,14,14,15,15,15,13,15,15,14,12,14,13,13,8,12,16,15,15,13,14,15,14,13,15,14,14,10,11,11,9,12,16,16,15,15,14,16,14,15,15,15,14,13,12,13,9,14,16,16,16,16,14,16,15,16,15,16,15,14,12,15,10,12,16,15,15,15,15,15,14,15,16,14,14,12,13,11,9,11,15,15,14,14,14,15,13,14,15,14,13,13,12,12,8,12,15,15,14,15,14,15,13,15,15,14,13,14,12,13,8,14,16,16,16,16,16,16,15,16,16,14,14,14,14,11,9,12,15,15,14,15,15,15,13,15,15,14,13,14,13,12,8,11,14,14,13,14,13,14,12,13,14,13,12,13,12,12,7,2,6,6,5,6,6,7,6,6,7,6,6,6,6,6,3,6,9,10,9,10,9,11,9,10,10,10,9,10,9,10,7,10,11,14,11,14,11,14,11,14,13,14,12,14,12,13,9,6,10,9,9,10,10,10,9,10,11,9,9,10,10,9,7,8,11,11,9,12,11,12,10,12,12,11,10,12,11,11,8,11,13,14,11,16,13,15,12,16,14,14,12,15,13,14,10,10,13,11,11,14,14,13,11,13,14,11,11,13,13,11,9,11,13,13,11,15,14,14,12,15,15,13,12,15,14,13,10,12,14,14,11,16,15,16,12,16,16,15,12,16,15,15,10,6,10,10,10,9,9,10,9,10,11,10,10,9,9,9,7,8,11,12,11,11,10,12,10,12,12,12,11,11,10,11,8,12,13,16,13,14,11,16,12,16,15,15,13,14,12,14,10,9,13,12,12,12,12,12,11,13,13,12,12,12,12,11,8,10,13,13,12,13,12,13,11,14,14,13,12,13,12,12,9,12,14,16,13,15,13,15,12,16,16,16,13,16,14,14,10,12,16,14,14,16,15,14,13,16,16,14,14,15,15,13,11,12,16,15,14,16,15,15,12,16,16,15,14,16,15,14,10,14,16,16,14,16,15,16,13,16,16,16,14,16,16,15,11,10,14,14,13,11,11,13,12,14,14,13,13,11,11,12,9,12,14,16,14,13,11,14,12,16,15,15,14,14,12,13,10,13,14,16,15,14,11,16,12,16,16,16,15,16,13,15,11,12,16,15,15,14,14,14,13,16,16,15,15,14,14,13,11,13,16,16,15,14,14,15,13,16,16,16,15,15,14,14,11,14,16,16,15,16,14,16,13,16,16,16,15,16,14,15,11,15,16,16,16,16,16,16,14,16,16,16,16,16,16,14,12,15,16,16,16,16,16,16,13,16,16,16,16,16,16,15,12,15,16,16,15,16,15,16,13,16,16,16,16,16,16,16,11,6,10,10,10,10,10,11,10,9,10,9,9,9,9,9,7,9,12,13,12,13,12,14,12,12,12,12,11,12,11,11,8,12,14,16,14,16,14,16,14,15,14,15,13,16,13,14,11,8,12,11,11,12,12,12,11,11,12,10,10,11,11,10,8,10,13,13,12,14,13,14,12,13,13,12,11,13,12,12,9,12,15,15,13,16,15,16,14,16,15,15,12,16,14,15,10,11,15,13,13,16,15,14,13,14,15,11,12,14,14,12,10,12,16,14,13,16,16,16,14,16,15,13,12,15,15,14,10,14,16,16,14,16,16,16,14,16,16,15,13,16,16,15,11,8,12,12,12,11,11,12,11,11,12,11,11,9,10,10,8,10,13,14,13,13,12,14,12,13,13,13,12,12,11,12,9,13,15,16,15,16,14,16,14,16,15,16,14,15,13,15,11,10,13,13,13,13,13,13,12,13,14,12,12,12,12,11,9,10,13,13,13,13,13,14,12,13,14,13,12,12,12,12,9,12,15,15,14,16,14,16,13,16,15,15,13,15,13,14,10,13,16,15,15,16,16,15,14,16,16,13,14,15,15,12,10,12,16,14,14,16,16,15,13,16,16,14,13,15,14,13,10,13,16,16,14,16,15,16,13,16,16,16,13,16,15,15,10,11,15,15,14,13,13,14,13,13,15,14,14,11,12,12,10,12,15,16,15,14,13,16,14,16,15,16,14,13,12,13,10,14,16,16,16,16,14,16,14,16,16,16,16,16,13,16,11,12,16,16,16,15,15,15,14,15,16,14,14,13,14,12,10,12,16,16,15,15,14,16,13,16,16,15,14,14,13,13,10,13,16,16,15,16,14,16,13,16,16,16,15,16,14,15,10,15,16,16,16,16,16,16,15,16,16,16,16,16,16,13,12,14,16,16,16,16,16,16,14,16,16,16,15,16,15,14,11,14,16,16,15,16,16,16,13,16,16,16,15,16,15,14,10,10,14,13,13,13,13,14,13,11,13,11,11,11,11,11,9,12,15,16,15,16,15,16,14,14,14,14,13,14,13,14,11,15,16,16,16,16,16,16,16,16,16,16,14,16,14,16,12,11,15,14,14,15,15,15,14,13,14,11,12,13,13,12,10,13,16,15,15,16,16,16,15,15,15,13,12,15,14,13,10,14,16,16,16,16,16,16,16,16,16,16,13,16,16,16,12,13,16,14,15,16,16,16,15,14,16,11,12,15,15,12,10,14,16,16,16,16,16,16,16,16,16,13,13,16,16,14,11,15,16,16,16,16,16,16,16,16,16,16,13,16,16,16,11,11,15,15,14,13,14,14,14,13,14,13,13,11,12,11,10,12,16,16,16,16,15,16,15,15,15,15,14,13,12,14,10,15,16,16,16,16,16,16,16,16,16,16,15,16,14,16,12,12,16,15,15,16,16,16,14,14,15,13,13,13,13,12,10,12,16,16,15,15,15,16,14,14,15,14,13,14,13,13,10,14,16,16,16,16,16,16,15,16,16,16,14,16,14,15,11,14,16,16,16,16,16,16,16,16,16,14,14,15,15,12,11,13,16,16,15,16,16,16,14,16,16,14,13,16,14,13,10,14,16,16,16,16,16,16,15,16,16,16,14,16,14,15,10,12,16,16,15,14,15,16,14,13,15,14,14,11,12,12,10,13,16,16,16,16,15,16,16,16,16,16,15,13,12,14,11,15,16,16,16,16,16,16,16,16,16,16,16,16,13,16,11,14,16,16,16,16,16,16,15,16,16,15,15,13,14,12,11,13,16,16,16,16,16,16,15,16,16,16,14,14,13,13,10,14,16,16,16,16,16,16,15,16,16,16,15,15,14,14,10,15,16,16,16,16,16,16,16,16,16,15,16,15,16,13,11,14,16,16,16,16,16,16,14,16,16,15,14,15,14,13,10,12,15,15,14,15,14,16,14,14,16,15,13,14,13,13,9,2,5,5,5,5,5,6,6,5,6,5,6,5,6,6,4,6,8,10,8,10,9,11,9,10,10,10,9,10,9,10,8,10,11,13,11,13,11,14,11,14,13,13,12,13,12,13,10,6,10,8,9,10,10,10,9,10,11,9,9,10,10,9,7,8,11,11,10,12,11,12,10,12,12,11,10,12,12,11,9,11,13,14,11,15,14,15,12,16,14,14,12,15,14,14,11,10,13,11,11,14,13,13,12,13,14,11,11,13,13,12,10,11,14,13,11,16,14,14,12,15,15,14,12,15,14,14,11,12,14,14,11,16,16,16,13,16,16,16,13,16,16,15,12,6,10,10,10,8,9,10,9,10,11,10,10,9,9,9,8,8,11,12,12,11,10,12,11,12,12,12,12,12,11,12,9,11,13,16,14,14,12,15,12,16,15,16,14,14,13,14,11,9,13,12,12,12,12,12,11,13,13,12,12,12,12,11,10,10,13,13,12,13,12,13,11,14,14,13,13,13,13,12,10,13,14,16,14,15,14,16,13,16,16,16,14,16,14,15,12,12,16,14,14,16,15,14,13,16,16,14,14,15,15,13,12,13,16,15,14,16,16,15,13,16,16,15,14,16,16,14,12,14,16,16,14,16,16,16,14,16,16,16,16,16,16,16,12,10,13,14,13,11,11,13,12,13,14,13,13,11,12,12,10,11,14,15,15,13,12,14,13,16,16,16,15,14,13,14,11,12,14,16,16,14,12,16,13,16,16,16,16,15,13,16,12,12,16,15,16,14,15,14,14,16,16,15,16,14,14,13,12,13,16,16,16,16,14,16,13,16,16,16,16,16,14,15,12,14,16,16,16,16,14,16,14,16,16,16,16,16,15,16,13,15,16,16,16,16,16,16,15,16,16,16,16,16,16,15,13,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,13,15,16,16,16,16,16,16,14,16,16,16,16,16,16,16,13,6,10,10,10,10,10,10,10,8,10,9,9,8,9,9,7,9,12,13,12,13,12,13,12,12,12,12,11,12,11,12,10,12,14,16,14,16,14,16,14,16,15,15,14,16,14,15,12,8,12,11,11,12,12,12,11,11,12,10,10,11,12,10,9,10,13,13,12,14,13,14,12,13,13,12,11,13,13,12,10,13,15,16,14,16,16,16,14,16,15,15,13,16,15,15,12,11,15,13,13,15,15,15,14,14,14,11,12,14,14,12,11,13,16,14,14,16,16,16,14,16,15,13,13,16,14,14,11,14,16,16,14,16,16,16,15,16,16,16,14,16,16,16,12,8,12,12,12,11,11,12,12,11,12,11,11,9,10,10,9,10,13,14,13,13,12,14,13,13,13,13,13,12,11,12,10,13,15,16,15,16,14,16,14,16,16,16,15,16,13,15,12,10,14,13,13,13,13,13,13,13,14,12,12,12,12,11,10,10,13,13,13,13,13,14,12,13,14,13,12,13,12,12,10,13,16,16,14,16,15,16,14,16,16,15,14,16,14,15,11,13,16,15,16,16,16,15,14,16,16,14,14,15,15,13,12,13,16,15,14,16,16,16,14,16,16,14,14,15,15,14,11,14,16,16,15,16,16,16,14,16,16,16,15,16,16,15,12,11,14,15,14,13,13,14,14,13,15,14,14,11,12,12,11,13,16,16,16,14,14,16,14,16,16,16,15,14,13,14,12,14,16,16,16,16,14,16,16,16,16,16,16,16,14,16,13,13,16,16,16,15,16,15,15,16,16,15,16,14,14,13,12,13,16,16,15,15,14,16,14,16,16,16,15,14,14,14,11,14,16,16,16,16,16,16,15,16,16,16,16,16,15,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,15,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,9,13,13,13,13,13,14,13,10,12,11,12,11,12,11,10,12,15,16,15,16,16,16,16,14,14,14,13,14,13,14,12,14,16,16,16,16,16,16,16,16,16,16,15,16,16,16,14,11,15,14,14,15,14,15,14,13,14,11,12,13,13,12,11,13,16,16,15,16,16,16,15,15,15,14,13,16,15,14,12,15,16,16,16,16,16,16,16,16,16,16,14,16,16,16,13,12,16,14,15,16,16,16,16,14,16,11,13,15,16,13,12,14,16,16,16,16,16,16,16,16,16,14,14,16,16,15,12,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,13,11,15,14,14,13,14,15,14,12,14,13,13,11,12,12,11,13,16,16,16,16,15,16,16,15,15,15,15,14,13,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,13,13,16,16,16,16,16,16,15,14,16,13,14,13,14,13,11,13,16,16,16,16,16,16,15,15,16,15,14,14,14,14,11,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,14,16,16,16,16,16,16,16,16,16,14,15,16,16,13,12,14,16,16,16,16,16,16,16,16,16,14,14,16,16,15,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,11,16,16,15,13,15,16,15,13,15,15,15,11,12,12,11,14,16,16,16,16,16,16,16,16,16,16,16,14,14,15,12,15,16,16,16,16,16,16,16,16,16,16,16,16,14,16,13,14,16,16,16,16,16,16,16,16,16,15,16,14,14,13,12,14,16,16,16,16,16,16,16,16,16,16,16,14,14,14,12,14,16,16,16,16,16,16,16,16,16,16,16,16,15,16,12,15,16,16,16,16,16,16,16,16,16,16,16,15,16,14,13,14,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,12,14,14,14,14,15,16,14,14,16,15,14,14,15,14,11,1,5,5,6,5,6,7,7,5,7,6,7,5,6,6,6,6,9,10,9,10,9,11,10,11,11,11,10,11,10,11,9,10,11,14,12,14,12,16,12,16,13,16,13,14,13,16,12,6,10,9,9,10,11,11,10,10,11,9,10,10,11,10,9,8,11,11,10,13,12,13,12,13,13,12,12,13,13,13,11,11,13,16,12,16,16,16,13,16,16,16,14,16,16,16,13,10,14,11,12,14,14,13,13,13,16,12,13,14,16,13,12,11,14,13,12,16,16,16,14,16,16,14,14,16,16,16,13,12,14,16,12,16,16,16,16,16,16,16,16,16,16,16,14,6,10,10,11,9,9,11,10,10,11,11,11,9,10,10,9,9,12,13,12,12,11,13,12,13,13,13,13,12,12,13,11,12,13,16,16,16,13,16,14,16,16,16,16,16,14,16,13,9,13,13,13,13,13,13,13,13,14,13,13,13,13,12,11,10,14,14,13,14,13,14,13,16,16,14,15,14,14,14,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,14,16,11,12,14,13,14,16,16,16,12,13,13,12,12,16,16,16,13,13,16,14,16,16,16,16,16,14,16,13,13,16,16,16,16,13,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,10,10,10,10,11,11,11,9,11,9,10,9,10,10,9,9,13,13,13,13,13,14,13,12,13,13,12,13,12,13,11,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,8,13,12,12,13,13,13,13,11,13,10,12,12,13,12,11,10,14,13,13,16,16,16,14,14,14,13,13,14,14,14,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,11,16,13,16,16,16,16,16,14,16,12,13,16,16,14,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,13,13,13,11,12,13,13,11,13,12,13,10,12,12,11,10,14,16,16,14,13,16,14,14,16,16,14,13,13,14,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,10,16,14,16,14,14,14,14,13,16,13,14,13,14,12,12,10,14,14,14,14,16,16,14,14,16,14,14,14,14,14,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,13,16,16,16,14,16,16,16,12,14,14,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,14,13,14,13,14,16,16,11,13,12,13,11,13,12,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,14,16,16,16,16,16,13,16,12,13,14,16,13,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,14,16,12,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,14,16,16,16,13,16,14,16,12,13,13,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,14,16,16,16,14,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,14,16,16,16,14,16,16,16,12,16,14,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,1,5,5,6,5,6,7,8,5,7,6,8,6,7,7,7,5,9,10,10,10,10,12,11,10,11,11,11,10,11,12,10,9,11,13,12,13,12,16,14,16,14,16,16,16,13,16,13,5,10,9,10,10,11,11,11,10,11,9,11,10,11,11,10,8,11,11,11,12,13,13,13,12,13,12,12,13,13,13,12,11,13,16,13,16,16,16,16,16,16,16,16,16,16,16,16,9,14,11,12,14,16,13,14,13,16,12,14,16,16,13,13,11,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,11,14,14,13,16,16,16,16,16,16,16,16,16,16,16,16,5,10,11,11,9,10,11,11,10,12,11,12,9,11,11,11,8,12,13,13,11,11,14,13,13,14,13,16,12,12,13,12,11,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,9,13,12,13,12,13,13,14,13,16,13,16,13,16,13,13,10,14,13,14,13,13,16,14,16,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,14,16,16,11,12,14,16,13,16,16,16,12,14,13,13,11,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,12,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,10,10,11,10,11,12,12,8,11,10,11,9,11,11,11,9,12,13,13,13,13,16,16,12,13,13,13,13,13,16,13,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,13,11,13,12,13,13,14,11,13,10,13,12,14,12,12,10,14,13,14,16,16,16,16,13,16,13,14,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,16,16,16,16,13,16,12,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,13,13,13,11,13,14,16,11,13,13,14,10,12,12,12,10,14,16,16,13,16,16,16,13,16,16,16,13,13,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,14,16,13,16,16,16,13,16,13,16,13,16,13,14,10,16,16,16,14,16,16,16,14,16,16,16,13,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,13,16,16,16,14,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,14,13,16,13,16,16,16,10,14,12,14,11,13,13,13,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,12,16,12,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,13,16,13,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,14,16,16,16,12,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,14,16,16,16,14,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,16,16,16,16,14,16,16,16,16,16,16,14,0,6,6,3,6,4,5,3,6,5,4,3,3,4,4,3,0,6,6,4,6,4,5,3,6,5,4,3,4,4,4,2,0,7,7,4,7,5,5,4,7,5,5,4,5,4,4,1,0,7,7,5,7,5,6,4,7,6,5,3,5,4,4,1,0,6,6,3,6,3,5,4,6,5,3,4,3,4,4,3,0,6,6,4,6,4,4,4,6,4,4,3,4,4,4,2,0,6,6,4,6,4,5,4,6,5,4,3,4,4,3,2,0,7,7,5,7,5,6,4,7,6,5,3,5,4,4,1,0,6,6,3,6,3,5,4,6,5,3,4,3,4,4,3,0,5,5,3,5,4,5,4,5,5,4,4,4,4,4,2,0,6,6,4,6,4,5,3,6,5,4,3,4,4,4,2,0,7,7,5,7,5,6,4,7,6,5,3,5,4,4,1,0,6,6,3,6,3,5,4,6,5,3,4,3,4,4,3,0,5,5,3,5,4,5,4,5,5,4,4,4,4,4,2,0,6,6,4,6,4,5,3,6,5,4,3,4,4,4,2,0,7,7,4,7,5,6,4,7,6,5,4,4,4,4,1,0,5,5,3,5,3,5,4,5,5,3,4,3,4,4,4,0,5,5,3,5,4,5,4,5,5,3,4,3,4,4,3,0,6,6,4,6,4,5,4,6,5,4,3,4,4,3,2,0,7,7,4,7,5,6,4,7,6,5,4,4,4,4,1,0,5,5,3,5,3,5,4,5,5,3,4,3,4,4,4,0,5,5,3,5,4,5,4,5,5,3,4,3,4,4,3,0,5,5,3,5,4,4,4,5,4,4,4,3,4,4,3,0,6,6,4,6,4,5,4], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+533752);
/* memory initializer */ allocate([6,5,4,3,4,4,3,2,0,4,4,3,4,3,5,5,4,5,3,5,3,5,4,5,0,4,4,3,4,4,5,4,4,5,3,5,3,5,4,4,0,4,4,3,4,4,5,4,4,5,4,4,3,4,4,4,0,4,4,3,5,4,5,4,5,5,4,4,3,4,4,3,0,0,16,0,0,0,1,0,0,0,17,0,0,0,0,0,0,0,0,1,0,1,1,2,0,1,1,2,1,2,2,3,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,17,18,19,20,20,21,22,22,23,23,24,24,25,25,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,15,16,17,18,18,19,20,20,21,21,22,22,23,23,0,32,16,48,2,34,18,50,1,33,17,49,3,35,19,51,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,22,22,23,23,23,24,24,25,25,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,0,9,9,9,9,9,9,9,9,0,2,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,2,0,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,0,1,9,9,9,9,9,9,9,0,2,1,6,4,8,5,7,3,1,0,2,6,5,4,3,8,7,2,8,0,1,7,4,3,6,5,2,0,1,3,8,5,4,7,6,2,0,1,4,6,7,8,3,5,0,1,5,2,6,3,8,4,7,0,1,6,2,4,7,5,8,3,2,7,0,1,4,8,6,3,5,2,8,0,1,7,3,4,5,6,1,0,9,9,9,9,9,9,9,1,2,5,6,3,0,4,8,7,1,6,2,5,3,0,4,8,7,2,1,7,6,8,3,5,0,4,1,2,5,3,6,8,4,7,0,1,6,2,0,4,5,8,7,3,1,5,2,6,3,8,4,0,7,1,6,0,2,4,5,7,3,8,2,1,7,6,0,8,5,4,3,1,2,7,8,3,4,5,6,0,9,9,9,9,9,9,9,9,9,0,2,1,8,7,6,5,4,3,1,2,0,6,5,7,4,8,3,2,8,7,1,0,6,4,3,5,2,0,8,1,3,7,5,4,6,2,0,4,1,7,8,6,3,5,2,0,1,5,8,4,6,7,3,2,0,6,1,4,7,8,5,3,2,7,8,1,0,5,4,6,3,2,8,7,1,0,4,3,6,5,9,9,9,9,9,9,9,9,9,0,2,1,3,5,8,6,4,7,1,0,2,5,3,6,4,8,7,2,8,1,0,3,5,7,6,4,3,2,5,8,1,4,6,7,0,4,2,0,6,1,5,8,3,7,5,3,1,2,8,6,4,0,7,1,6,0,2,4,5,8,3,7,2,7,0,1,5,4,8,6,3,2,8,3,5,1,0,7,6,4,9,9,9,9,9,9,9,9,9,2,0,6,1,4,7,5,8,3,1,6,2,0,4,5,3,7,8,2,8,7,6,4,0,1,5,3,4,2,1,0,6,8,3,5,7,4,2,6,0,1,5,7,8,3,1,2,5,0,6,3,4,7,8,6,4,0,1,2,7,5,3,8,2,7,4,6,0,1,8,5,3,2,8,7,4,6,1,3,5,0,9,9,9,9,9,9,9,9,9,5,1,2,3,6,8,0,4,7,1,5,6,3,2,0,4,8,7,2,1,5,3,6,8,7,4,0,5,3,1,2,6,8,4,7,0,1,6,2,4,5,8,0,3,7,5,1,3,6,2,0,8,4,7,1,6,5,2,0,4,3,7,8,2,7,1,6,5,0,8,3,4,2,5,1,3,6,8,4,0,7,9,9,9,9,9,9,9,9,9,1,6,2,0,5,4,3,7,8,1,6,5,4,2,3,0,7,8,2,1,6,7,4,8,5,3,0,2,1,6,5,8,4,3,0,7,6,4,1,2,0,5,7,8,3,1,6,5,2,3,0,4,8,7,6,1,4,0,2,7,5,3,8,2,7,4,6,1,5,0,8,3,2,1,6,8,4,7,3,5,0,9,9,9,9,9,9,9,9,9,2,0,4,7,6,1,8,5,3,6,1,2,0,4,7,5,8,3,2,7,8,0,1,6,4,3,5,2,4,0,8,3,1,7,6,5,4,2,7,0,6,1,8,5,3,2,1,0,8,5,6,7,4,3,2,6,4,1,7,0,5,8,3,2,7,4,0,8,6,1,5,3,2,8,7,4,1,0,3,6,5,9,9,9,9,9,9,9,9,9,2,0,8,1,3,4,6,5,7,1,2,0,6,8,5,7,3,4,2,8,7,1,0,3,6,5,4,8,3,2,5,1,0,4,7,6,2,0,4,8,5,1,7,6,3,2,1,0,8,5,3,6,4,7,2,1,6,0,8,4,5,7,3,2,7,8,4,0,6,1,5,3,2,8,3,0,7,4,1,6,5,0,0,0,0,0,0,0,1,1,0,1,1,0,2,2,0,0,3,3,0,1,2,2,1,0,4,4,0,3,1,1,3,0,5,5,0,2,2,1,4,4,1,0,6,3,2,1,5,2,3,5,1,6,0,0,7,4,2,2,4,3,3,6,1,1,6,7,0,0,8,5,2,4,3,2,5,3,4,1,7,4,4,7,1,8,0,6,2,3,5,5,3,2,6,1,8,2,7,7,2,8,1,5,4,4,5,3,6,6,3,8,2,4,6,5,5,6,4,2,8,7,3,3,7,6,5,5,6,7,4,4,7,8,3,3,8,7,5,8,4,5,7,4,8,6,6,7,6,5,8,8,5,6,7,8,6,7,7,6,8,8,7,7,8,8,8,0,0,0,0,0,0,6,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,1,0,0,0,176,222,35,0,108,0,0,0,168,235,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,76,33,0,108,0,0,0,168,235,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,3,3,3,3,3,6,6,6,6,6,6,6,6,9,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,15,208,82,8,0,192,82,8,0,6,6,5,5,4,41,41,41,41,40,40,40,40,40,40,76,6,6,5,5,4,41,41,41,41,40,40,40,40,40,40,76,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,3,3,0,0,0,0,0,0,0,0,0,0,0,2,2,3,3,3,3,0,0,0,0,0,0,0,0,0,0,2,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,3,3,3,3,3,3,3,4,5,6,7,8,9,10,11,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,3,2,3,2,1,0,0,0,0,0,0,0,0,0,0,0,3,0,1,3,2,5,4,0,0,0,0,0,0,0,0,0,7,6,5,4,3,2,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,80,67,77,85,0,0,0,0,1,0,0,0,6,0,1,0,64,31,0,0,1,0,0,0,3,0,0,0,71,83,77,0,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,4,0,0,0,71,55,50,51,0,0,0,0,1,0,0,0,53,80,1,0,64,31,0,0,1,0,0,0,5,0,0,0,68,86,73,52,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,6,0,0,0,68,86,73,52,0,0,0,0,1,0,0,0,0,0,0,0,128,62,0,0,1,0,0,0,7,0,0,0,76,80,67,0,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,8,0,0,0,80,67,77,65,0,0,0,0,1,0,0,0,7,0,1,0,64,31,0,0,1,0,0,0,9,0,0,0,71,55,50,50,0,0,0,0,1,0,0,0,28,16,1,0,64,31,0,0,1,0,0,0,10,0,0,0,76,49,54,0,0,0,0,0,1,0,0,0,1,0,1,0,68,172,0,0,2,0,0,0,11,0,0,0,76,49,54,0,0,0,0,0,1,0,0,0,1,0,1,0,68,172,0,0,1,0,0,0,12,0,0,0,81,67,69,76,80,0,0,0,1,0,0,0,24,80,1,0,64,31,0,0,1,0,0,0,13,0,0,0,67,78,0,0,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,14,0,0,0,77,80,65,0,0,0,0,0,1,0,0,0,0,80,1,0,255,255,255,255,255,255,255,255,14,0,0,0,77,80,65,0,0,0,0,0,1,0,0,0,1,80,1,0,255,255,255,255,255,255,255,255,15,0,0,0,71,55,50,56,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,16,0,0,0,68,86,73,52,0,0,0,0,1,0,0,0,0,0,0,0,17,43,0,0,1,0,0,0,17,0,0,0,68,86,73,52,0,0,0,0,1,0,0,0,0,0,0,0,34,86,0,0,1,0,0,0,18,0,0,0,71,55,50,57,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,25,0,0,0,67,101,108,66,0,0,0,0,0,0,0,0,0,0,0,0,144,95,1,0,255,255,255,255,26,0,0,0,74,80,69,71,0,0,0,0,0,0,0,0,8,0,0,0,144,95,1,0,255,255,255,255,28,0,0,0,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,1,0,255,255,255,255,31,0,0,0,72,50,54,49,0,0,0,0,0,0,0,0,4,0,0,0,144,95,1,0,255,255,255,255,32,0,0,0,77,80,86,0,0,0,0,0,0,0,0,0,1,0,0,0,144,95,1,0,255,255,255,255,32,0,0,0,77,80,86,0,0,0,0,0,0,0,0,0,2,0,0,0,144,95,1,0,255,255,255,255,33,0,0,0,77,80,50,84,0,0,0,0,2,0,0,0,0,0,2,0,144,95,1,0,255,255,255,255,34,0,0,0,72,50,54,51,0,0,0,0,0,0,0,0,5,0,0,0,144,95,1,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,88,1,35,0,108,0,0,0,192,67,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,71,71,32,86,65,71,32,87,65,68,80,88,65,68,80,88,77,65,32,0,0,0,0,18,16,1,0,71,65,68,80,32,68,65,82,82,65,68,80,1,0,1,0,80,67,77,66,0,0,1,0,80,67,77,32,0,0,0,0,0,0,0,0,192,130,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,33,0,240,207,33,0,16,0,0,0,5,0,0,0,160,168,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,248,243,31,0,240,207,33,0,16,0,0,0,5,0,0,0,160,168,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,32,210,28,0,200,138,33,0,24,0,0,0,5,0,0,0,88,231,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,104,205,35,0,200,138,33,0,24,0,0,0,5,0,0,0,88,231,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,152,121,35,0,8,99,33,0,28,0,0,0,5,0,0,0,240,33,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,176,30,35,0,8,99,33,0,28,0,0,0,5,0,0,0,240,33,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,136,36,33,0,64,1,33,0,44,0,0,0,5,0,0,0,224,230,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,136,203,32,0,64,1,33,0,44,0,0,0,5,0,0,0,224,230,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,32,177,32,0,136,155,32,0,64,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,130,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,73,32,0,108,0,0,0,0,88,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,144,30,0,108,0,0,0,32,116,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,4,5,6,8,9,10,11,12,13,14,15,16,32,64,73,65,82,76,0,73,65,82,84,0,73,67,77,83,0,73,67,77,84,0,73,67,79,80,0,73,67,82,68,0,73,67,82,80,0,73,68,73,77,0,73,68,80,73,0,73,69,78,71,0,73,71,78,82,0,73,75,69,89,0,73,76,71,84,0,73,76,78,71,0,73,77,69,68,0,73,78,65,77,0,73,80,76,84,0,73,80,82,68,0,73,80,82,84,0,73,84,82,75,0,73,83,66,74,0,73,83,70,84,0,73,83,72,80,0,73,83,77,80,0,73,83,82,67,0,73,83,82,70,0,73,84,67,72,0,0,0,0,0,0,0,0,0,0,176,30,29,0,108,0,0,0,0,91,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,27,0,0,0,30,0,0,0,29,0,0,0,3,0,0,0,2,0,0,0,62,0,0,0,64,0,0,0,44,0,0,0,48,0,0,0,46,0,0,0,50,0,0,0,255,255,255,255,0,0,0,0,11,0,0,0,2,0,0,0,28,0,0,0,42,0,0,0,36,1,0,0,0,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,0,248,0,0,224,7,0,0,31,0,0,0,0,0,0,0,0,15,0,0,240,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,75,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,75,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,75,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,152,255,255,255,116,0,0,0,0,0,0,0,116,0,0,0,24,0,0,0,80,0,0,0,24,0,0,0,0,0,0,0,152,255,255,255,116,0,0,0,0,0,0,0,116,0,0,0,1,0,1,1,1,2,2,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,5,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,5,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,64,13,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,13,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,3,0,0,0,0,0,0,0,0,0,0,166,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,34,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,114,30,0,112,231,29,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,56,122,29,0,112,231,29,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,34,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,240,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,76,32,0,108,0,0,0,152,95,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,5,0,0,0,2,0,0,0,3,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,12,0,0,0,13,0,0,0,10,0,0,0,11,0,0,0,14,0,0,0,15,0,0,0,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,14,15,16,16,0,0,0,0,14,15,16,16,0,0,0,0,63,102,240,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,1,0,0,0,232,3,0,0,1,2,4,8,16,32,64,128,27,54,0,0,0,0,0,0,64,44,30,0,200,185,29,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,216,86,29,0,8,3,29,0,12,0,0,0,5,0,0,0,136,180,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,136,177,35,0,24,82,35,0,16,0,0,0,84,65,82,86,32,2,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,30,0,108,0,0,0,176,97,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,143,35,0,0,0,0,0,128,116,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,17,1,0,180,128,128,255,168,44,136,255,145,147,44,255,133,63,52,255,63,193,204,255,51,109,212,255,28,212,120,255,0,0,0,0,64,32,32,16,16,8,8,8,8,4,0,0,0,0,0,0,6,5,5,4,4,3,3,3,3,2,0,0,0,0,0,0,6,5,5,4,4,3,3,3,3,2,0,0,0,0,0,0,68,172,0,0,255,255,255,255,1,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,1,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,255,255,255,255,3,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,9,0,0,0,255,255,255,255,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,255,255,255,255,4,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,9,0,0,0,3,0,0,0,8,0,0,0,2,0,0,0,7,0,0,0,1,0,0,0,6,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,3,0,0,0,27,0,0,0,29,0,0,0,28,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,14,0,0,0,255,255,255,255,28,0,0,0,255,255,255,255,10,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,70,0,0,0,80,0,0,0,76,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,82,0,0,0,61,1,0,0,255,255,255,255,0,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,4,0,0,0,33,0,0,0,5,0,0,0,14,0,0,0,34,0,0,0,13,0,0,0,12,0,0,0,64,1,0,0,35,0,0,0,44,1,0,0,43,1,0,0,82,0,0,0,61,1,0,0,8,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,33,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,82,0,0,0,61,1,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,39,1,0,0,40,1,0,0,41,1,0,0,42,1,0,0,2,0,0,0,3,0,0,0,8,0,0,0,6,0,0,0,5,0,0,0,14,0,0,0,0,0,0,0,12,0,0,0,43,1,0,0,35,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,8,0,0,0,32,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,70,0,0,0,80,0,0,0,76,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,98,0,0,0,100,0,0,0,102,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,33,0,0,0,7,0,0,0,6,0,0,0,64,1,0,0,12,0,0,0,13,0,0,0,34,0,0,0,14,0,0,0,82,0,0,0,84,0,0,0,86,0,0,0,58,1,0,0,60,1,0,0,88,0,0,0,61,1,0,0,63,1,0,0,255,255,255,255,0,0,0,0,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,39,1,0,0,41,1,0,0,40,1,0,0,42,1,0,0,42,0,0,0,68,0,0,0,36,1,0,0,38,1,0,0,255,255,255,255,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,54,0,0,0,56,0,0,0,58,0,0,0,35,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,255,255,255,255,6,0,0,0,0,0,0,0,8,0,0,0,5,0,0,0,4,0,0,0,7,0,0,0,33,0,0,0,82,0,0,0,255,255,255,255,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,2,0,0,0,3,0,0,0,27,0,0,0,29,0,0,0,28,0,0,0,30,0,0,0,255,255,255,255,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,33,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,33,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,70,0,0,0,80,0,0,0,76,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,98,0,0,0,100,0,0,0,102,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,33,0,0,0,7,0,0,0,6,0,0,0,8,0,0,0,32,0,0,0,255,255,255,255,3,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,39,1,0,0,41,1,0,0,40,1,0,0,42,1,0,0,255,255,255,255,0,0,0,0,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,39,1,0,0,41,1,0,0,40,1,0,0,42,1,0,0,42,0,0,0,68,0,0,0,36,1,0,0,38,1,0,0,255,255,255,255,0,0,0,0,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,29,0,0,0,27,0,0,0,41,1,0,0,39,1,0,0,40,1,0,0,42,1,0,0,255,255,255,255,0,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,14,0,0,0,34,0,0,0,13,0,0,0,12,0,0,0,64,1,0,0,5,0,0,0,33,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,82,0,0,0,61,1,0,0,8,0,0,0,255,255,255,255,8,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,4,0,0,0,33,0,0,0,5,0,0,0,25,0,0,0,26,0,0,0,64,1,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,5,0,0,0,33,0,0,0,4,0,0,0,7,0,0,0,255,255,255,255,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,28,0,0,0,255,255,255,255,43,1,0,0,255,255,255,255,44,1,0,0,255,255,255,255,35,0,0,0,255,255,255,255,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,32,0,0,0,255,255,255,255,31,0,0,0,255,255,255,255,5,0,0,0,43,1,0,0,255,255,255,255,0,0,0,0,4,0,0,0,44,1,0,0,255,255,255,255,0,0,0,0,0,0,0,0,35,0,0,0,255,255,255,255,0,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,255,255,255,255,6,0,0,0,7,0,0,0,33,0,0,0,0,0,0,0,35,0,0,0,4,0,0,0,44,1,0,0,12,0,0,0,13,0,0,0,34,0,0,0,14,0,0,0,5,0,0,0,43,1,0,0,54,0,0,0,104,0,0,0,55,0,0,0,103,0,0,0,56,0,0,0,106,0,0,0,57,0,0,0,105,0,0,0,58,0,0,0,108,0,0,0,59,0,0,0,107,0,0,0,8,0,0,0,66,0,0,0,32,0,0,0,31,0,0,0,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,42,0,0,0,68,0,0,0,41,0,0,0,67,0,0,0,36,1,0,0,38,1,0,0,35,1,0,0,37,1,0,0,82,0,0,0,61,1,0,0,88,0,0,0,87,0,0,0,63,1,0,0,62,1,0,0,255,255,255,255,4,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,8,0,0,0,255,255,255,255,12,0,0,0,10,0,0,0,10,0,0,0,8,0,0,0,8,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,4,0,0,0,0,3,5,7,11,15,5,6,7,8,9,10,11,12,14,16,134,255,255,255,240,255,255,255,67,0,0,0,138,0,0,0,197,0,0,0,249,0,0,0,41,1,0,0,82,1,0,0,121,1,0,0,156,1,0,0,188,1,0,0,218,1,0,0,245,1,0,0,15,2,0,0,40,2,0,0,255,255,255,127,131,255,255,255,79,0,0,0,177,0,0,0,245,0,0,0,43,1,0,0,92,1,0,0,143,1,0,0,255,255,255,127,7,0,0,0,217,0,0,0,74,1,0,0,255,255,255,127,4,1,0,0,255,255,255,127,0,1,0,1,0,1,0,1,0,1,0,1,3,1,6,1,9,1,13,1,16,1,19,1,22,1,26,1,29,1,32,1,36,1,39,1,43,1,47,1,50,1,54,1,58,1,61,1,65,1,69,1,73,1,77,1,81,1,85,1,89,1,93,1,97,1,102,1,106,1,110,1,115,1,119,1,123,1,128,1,133,1,137,1,142,1,147,1,152,1,157,1,161,1,166,1,172,1,177,1,182,1,187,1,192,1,198,1,203,1,209,1,214,1,220,1,226,1,232,1,237,1,243,1,249,1,255,1,70,0,110,0,160,0,208,0,253,0,60,1,122,1,183,1,243,1,47,2,108,2,168,2,228,2,32,3,93,3,152,3,212,3,0,0,0,0,0,0,70,0,110,0,160,0,208,0,253,0,60,1,122,1,183,1,243,1,47,2,108,2,168,2,228,2,32,3,93,3,152,3,212,3,0,0,0,0,0,0,249,255,255,255,241,255,255,255,225,255,255,255,193,255,255,255,0,0,0,0,0,0,0,0,0,0,0,2,0,4,0,6,4,8,4,10,4,12,4,14,4,16,4,18,4,20,4,22,20,24,20,26,56,28,0,0,0,0,1,4,11,32,81,230,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,160,64,0,0,64,65,102,102,18,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,64,0,0,168,65,0,0,96,66,0,0,29,67,0,0,0,0,0,0,1,2,0,1,2,3,4,5,6,0,1,1,2,2,3,3,4,5,6,7,8,9,10,11,11,12,13,13,13,14,0,1,1,2,2,2,3,3,4,4,5,5,6,6,7,8,8,9,10,10,11,12,13,14,15,16,17,18,19,20,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,29,30,0,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,7,7,7,8,8,9,9,9,10,10,11,11,11,12,12,13,13,13,13,14,14,14,15,15,15,15,16,16,16,17,17,17,18,18,18,19,19,20,20,20,21,21,22,22,23,23,24,25,26,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,42,43,44,44,45,45,46,47,47,48,48,49,49,50,50,50,51,51,51,52,52,52,53,53,53,54,54,54,55,55,55,56,56,56,57,57,57,57,58,58,58,58,59,59,59,59,60,60,60,60,60,61,61,61,61,61,61,61,62,0,0,1,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,25,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,0,0,1,0,2,1,3,0,4,1,5,0,1,6,7,8,0,1,2,2,3,3,4,0,0,0,0,0,0,57,180,200,62,229,208,66,63,41,92,143,63,86,14,189,63,250,126,234,63,70,182,11,64,190,159,34,64,233,38,57,64,20,174,79,64,162,69,102,64,186,73,124,64,76,55,137,64,2,43,151,64,0,0,0,0,150,67,11,63,20,174,135,63,98,16,200,63,29,90,4,64,68,139,36,64,166,155,68,64,207,247,99,64,113,61,130,64,10,215,147,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,219,249,62,63,90,100,187,63,31,133,11,64,176,114,56,64,66,96,101,64,172,28,138,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,196,128,63,0,0,0,64,80,141,63,64,61,10,127,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,22,169,63,244,253,44,64,121,233,126,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,24,212,63,139,108,95,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,100,251,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,0,1,2,2,2,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+543992);
/* memory initializer */ allocate([5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,253,253,253,253,253,253,253,254,254,254,255,40,14,65,18,221,21,79,25,1,29,186,32,108,36,24,40,202,43,174,47,79,52,252,57,130,65,199,76,225,94,216,127,0,0,205,12,156,25,0,32,102,38,205,44,0,48,51,51,102,54,154,57,205,60,0,64,51,67,102,70,154,73,205,76,159,0,206,0,12,1,93,1,163,1,226,1,42,2,125,2,221,2,74,3,201,3,90,4,1,5,193,5,158,6,156,7,193,8,17,10,147,11,80,13,79,15,155,17,63,20,72,23,199,26,203,30,105,35,185,40,222,48,135,63,150,82,93,107,204,0,185,1,208,1,185,7,101,3,53,4,48,4,246,11,1,5,151,18,111,6,3,6,53,7,108,27,61,7,122,2,203,7,32,9,47,9,40,60,101,10,141,4,142,10,60,15,150,10,149,39,123,12,216,6,170,13,64,10,79,14,81,3,144,15,65,22,118,16,71,13,63,17,24,5,87,18,8,8,0,21,206,17,10,21,164,2,142,21,2,92,191,21,114,30,12,22,245,11,40,22,233,5,69,23,34,9,133,25,36,4,148,26,110,23,164,26,231,6,25,27,253,14,109,28,158,1,137,28,105,10,42,29,40,44,6,31,26,3,71,31,190,7,71,31,86,5,134,32,33,12,144,32,202,18,4,34,18,31,29,35,231,8,71,35,31,4,31,36,240,13,67,36,95,6,182,37,167,24,83,38,45,10,136,39,171,2,159,39,83,16,5,40,154,7,95,40,194,4,228,40,232,38,155,41,184,11,199,42,250,5,217,42,170,20,195,43,1,9,61,44,234,13,251,45,98,26,63,46,57,7,165,46,143,17,178,46,18,5,199,46,119,59,201,46,115,3,210,46,26,11,150,48,93,8,49,49,81,14,92,49,175,32,114,49,58,6,86,50,68,10,184,50,78,19,90,51,91,4,168,51,12,2,29,52,91,12,87,52,131,7,237,52,73,23,38,53,121,5,87,53,95,9,214,53,69,15,44,54,171,42,146,55,187,6,152,55,123,11,198,55,104,29,103,56,246,17,115,56,216,3,122,56,217,8,200,57,123,5,226,57,117,13,51,58,77,22,169,58,2,60,200,58,154,7,221,58,95,10,45,60,119,37,45,60,239,15,210,60,15,28,71,61,238,8,75,61,88,6,83,61,252,11,156,61,29,20,252,61,181,4,98,62,184,2,121,63,0,14,210,63,125,7,40,64,0,10,99,64,86,17,145,64,10,25,236,64,190,46,199,65,76,34,134,66,234,11,137,66,149,71,196,66,32,6,227,66,77,20,199,67,65,8,222,67,212,3,158,68,102,102,201,68,72,15,231,68,255,127,231,70,191,30,21,71,212,9,26,71,17,22,247,72,211,12,242,73,90,5,71,75,189,53,117,75,24,16,4,76,181,7,198,76,34,39,52,77,136,26,200,77,15,20,72,78,25,11,242,82,121,77,30,6,52,5,41,6,229,13,255,11,90,25,97,16,179,39,144,17,230,9,155,19,136,17,210,21,254,60,93,22,142,5,53,25,68,2,68,26,175,26,233,29,199,13,136,31,51,8,40,32,199,20,123,34,71,34,12,38,52,11,128,38,185,5,103,39,200,48,1,40,101,17,107,42,218,25,57,44,3,14,153,44,8,7,123,45,124,9,198,45,220,3,24,48,229,19,235,48,221,32,30,49,102,102,57,49,68,13,116,51,87,6,229,51,119,9,106,52,199,23,147,52,10,50,88,53,23,14,31,55,169,17,64,55,205,4,89,56,79,7,95,56,66,28,109,56,18,11,36,57,52,39,12,58,88,68,57,59,45,14,105,59,187,22,195,59,208,8,158,60,114,18,47,61,36,4,143,61,36,31,67,62,188,46,148,62,180,11,214,62,171,6,137,64,158,16,192,64,80,24,254,65,76,9,10,66,169,2,61,67,214,32,202,68,90,13,231,69,149,20,248,70,228,45,54,71,39,6,175,72,255,127,40,73,180,84,193,74,239,9,222,75,177,25,246,75,1,16,250,75,96,35,147,79,37,58,143,194,245,61,0,0,0,63,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,16,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,32,0,0,0,38,0,0,0,45,0,0,0,54,0,0,0,64,0,0,0,76,0,0,0,91,0,0,0,108,0,0,0,128,0,0,0,152,0,0,0,181,0,0,0,215,0,0,0,0,1,0,0,48,1,0,0,106,1,0,0,175,1,0,0,0,2,0,0,97,2,0,0,212,2,0,0,93,3,0,0,0,4,0,0,194,4,0,0,168,5,0,0,186,6,0,0,0,8,0,0,131,9,0,0,80,11,0,0,116,13,0,0,0,16,0,0,7,19,0,0,161,22,0,0,233,26,0,0,0,32,0,0,14,38,0,0,65,45,0,0,209,53,0,0,0,64,0,0,28,76,0,0,130,90,0,0,162,107,0,0,0,128,0,0,56,152,0,0,5,181,0,0,69,215,0,0,0,0,1,0,112,48,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,32,0,0,0,24,0,0,0,8,0,0,0,24,0,0,0,16,0,0,0,32,0,0,0,16,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,32,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,4,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,24,0,0,0,16,0,0,0,16,0,0,0,32,0,0,0,16,0,0,0,8,0,0,0,24,0,0,0,8,0,0,0,8,0,0,0,24,0,0,0,16,0,0,0,4,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,8,0,0,0,9,0,0,0,6,0,0,0,6,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,32,0,0,0,38,0,0,0,46,0,0,0,54,0,0,0,64,0,0,0,76,0,0,0,91,0,0,0,108,0,0,0,128,0,0,0,152,0,0,0,181,0,0,0,216,0,0,0,0,1,0,0,49,1,0,0,106,1,0,0,175,1,0,0,0,2,0,0,97,2,0,0,212,2,0,0,93,3,0,0,0,4,0,0,194,4,0,0,168,5,0,0,186,6,0,0,0,8,0,0,132,9,0,0,81,11,0,0,117,13,0,0,0,16,0,0,7,19,0,0,161,22,0,0,233,26,0,0,0,32,0,0,14,38,0,0,65,45,0,0,209,53,0,0,0,64,0,0,28,76,0,0,131,90,0,0,163,107,0,0,0,128,0,0,56,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,9,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,17,0,0,0,20,0,0,0,24,0,0,0,29,0,0,0,34,0,0,0,41,0,0,0,48,0,0,0,57,0,0,0,68,0,0,0,81,0,0,0,96,0,0,0,114,0,0,0,136,0,0,0,162,0,0,0,192,0,0,0,228,0,0,0,16,1,0,0,67,1,0,0,128,1,0,0,201,1,0,0,31,2,0,0,134,2,0,0,0,3,0,0,145,3,0,0,62,4,0,0,12,5,0,0,0,6,0,0,35,7,0,0,124,8,0,0,23,10,0,0,0,12,0,0,69,14,0,0,248,16,0,0,46,20,0,0,0,24,0,0,139,28,0,0,241,33,0,0,93,40,0,0,0,48,0,0,21,57,0,0,226,67,0,0,186,80,0,0,0,96,0,0,42,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,245,255,12,0,32,0,46,255,183,3,36,15,219,252,106,1,100,255,53,0,245,255,109,68,117,183,138,13,193,184,187,138,107,184,183,230,157,57,0,5,126,57,196,151,95,186,4,118,8,186,36,77,5,59,252,88,77,58,57,33,138,187,92,56,70,186,148,116,0,60,90,72,128,184,62,58,92,188,243,100,33,59,226,15,178,60,41,165,255,187,48,162,11,189,92,22,154,60,243,132,94,61,30,146,50,189,8,138,203,189,190,63,7,62,19,177,237,62,0,0,0,0,0,0,0,0,0,0,0,0,104,126,8,0,64,126,8,0,24,127,8,0,128,128,8,0,0,0,0,0,0,0,16,0,12,0,33,0,78,0,0,0,0,0,0,0,186,73,177,72,184,53,193,191,205,65,10,125,52,197,145,63,109,250,55,88,205,173,177,191,166,110,219,181,140,237,152,63,153,235,184,10,247,4,181,191,191,34,199,239,208,36,159,63,91,53,58,173,252,174,183,191,68,122,31,129,30,238,161,63,231,43,80,164,94,100,185,191,182,27,183,119,145,50,163,63,43,65,144,205,159,192,236,63,62,0,3,61,0,7,60,0,6,64,0,6,63,0,6,62,3,4,19,0,4,18,0,4,17,0,4,16,0,4,70,0,2,20,0,4,0,0,0,0,15,3,1,60,0,1,61,0,1,62,0,1,15,2,1,63,0,1,64,0,1,65,0,1,15,1,1,66,0,1,67,0,1,68,0,1,15,0,1,69,0,1,16,0,2,70,0,4,0,252,0,253,0,0,0,0,0,0,0,0,0,0,0,0,0,253,254,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,4,0,0,3,2,0,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,253,3,0,0,254,0,3,0,0,0,0,0,0,0,251,0,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,3,6,253,252,0,253,253,3,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,3,61,0,7,60,0,6,64,0,6,63,0,6,62,3,4,0,0,1,16,0,4,52,0,1,48,0,7,56,0,3,49,0,6,57,0,3,32,0,7,58,0,2,33,0,7,1,0,1,17,0,4,53,0,1,49,6,1,34,0,2,2,0,1,18,0,4,54,0,1,50,0,7,58,2,1,55,0,1,51,0,7,59,0,3,34,2,5,35,0,7,3,0,1,19,0,4,0,0,0,0,0,10,0,191,255,197,255,12,0,110,0,34,0,122,255,157,0,104,0,172,255,222,255,141,255,23,0,155,255,3,0,45,0,155,255,240,255,197,255,28,0,211,255,134,0,189,255,22,0,61,0,227,255,226,0,230,255,201,255,77,255,157,0,205,255,36,255,163,255,219,255,60,0,118,0,74,0,208,255,161,255,75,255,111,0,36,0,204,255,41,255,78,0,144,255,39,0,239,255,209,255,33,255,19,0,12,0,158,255,114,255,130,0,54,0,129,255,21,0,244,255,39,0,208,255,12,0,128,0,6,0,89,255,82,0,154,255,177,255,55,0,212,255,48,0,236,255,203,255,8,0,195,255,11,0,186,255,99,255,88,255,20,0,200,255,182,255,78,0,33,0,193,255,83,255,254,255,181,255,203,255,110,255,77,0,66,0,227,255,9,0,181,255,65,0,119,0,213,255,76,0,233,0,98,0,125,0,100,255,229,255,78,0,247,255,170,0,176,0,143,0,108,255,249,255,27,0,120,255,5,0,27,0,18,0,139,0,204,0,7,0,72,255,59,255,52,0,253,255,78,0,67,255,8,0,191,255,62,0,3,61,0,7,60,0,6,64,0,6,63,0,6,62,3,4,0,0,1,16,0,4,52,0,1,48,0,7,56,0,3,33,0,4,1,0,1,17,0,4,32,0,7,19,0,1,34,0,7,2,0,1,18,0,4,33,4,3,49,0,3,57,0,3,35,0,7,3,0,1,19,1,2,36,0,6,4,0,1,20,0,4,53,0,1,49,3,4,22,0,3,37,0,7,5,0,1,21,0,4,36,6,1,39,0,3,7,0,1,23,0,3,38,0,7,6,0,1,22,3,1,24,0,1,54,0,1,50,0,7,58,0,3,39,3,4,9,0,1,25,0,4,40,0,7,8,0,1,24,1,3,42,0,4,10,0,1,26,0,4,41,0,7,59,0,2,43,0,7,11,0,1,27,0,3,42,4,3,44,0,2,12,0,1,28,0,4,55,0,1,51,0,7,59,2,1,45,0,6,13,0,1,29,0,4,44,2,5,31,0,3,46,0,7,14,0,1,30,0,4,45,6,1,70,0,2,47,0,7,15,0,1,0,0,0,0,0,0,104,1,222,0,52,3,73,4,89,2,63,1,120,6,198,0,92,2,1,2,16,6,141,0,111,5,155,0,170,9,5,1,13,1,17,3,183,5,134,2,99,4,191,0,223,7,223,0,17,3,76,3,178,4,243,3,212,3,39,3,198,11,25,3,58,2,180,0,111,4,102,5,10,3,0,1,109,7,179,0,39,3,110,2,181,5,202,1,207,4,178,0,236,7,53,3,131,1,159,3,216,5,236,3,120,3,136,1,198,8,85,1,39,1,182,5,132,4,182,2,254,3,217,1,178,8,84,5,210,0,222,1,5,4,252,3,210,2,181,0,194,6,251,0,218,2,232,1,185,5,37,1,23,5,70,1,35,10,131,1,202,1,72,2,33,6,230,2,5,4,173,0,118,7,239,1,93,2,135,4,244,4,207,2,205,3,134,2,56,11,172,1,187,1,78,1,67,3,185,5,144,3,138,0,180,6,186,1,108,2,10,3,36,5,194,1,162,4,79,1,166,5,129,6,230,1,26,4,139,6,251,3,112,3,22,1,166,8,202,0,27,2,28,6,118,4,21,2,216,3,135,1,82,8,65,4,92,1,55,1,44,3,121,4,40,2,205,1,34,7,7,1,89,2,163,2,194,6,172,0,243,5,193,0,145,9,21,1,78,1,156,2,37,3,161,5,39,5,207,0,148,6,142,3,70,2,38,5,123,5,74,4,211,3,64,3,140,10,79,5,112,2,228,0,12,5,211,3,32,3,195,0,178,8,29,1,218,2,94,3,1,6,89,2,91,4,253,1,160,10,98,1,218,0,143,4,188,4,2,6,50,4,247,0,138,6,174,6,66,1,94,8,239,4,9,3,213,3,44,2,71,8,174,6,193,0,84,2,11,4,189,3,182,2,141,1,205,7,253,0,231,2,91,2,48,6,65,1,66,5,90,1,173,8,196,2,195,1,220,2,16,4,135,5,160,4,230,0,61,7,151,3,54,1,125,6,89,6,194,2,88,3,75,3,86,11,190,2,211,1,92,1,84,4,24,4,91,3,50,1,172,7,207,1,48,2,245,3,145,5,21,2,118,4,122,2,87,9,111,3,141,1,60,4,65,5,164,6,208,3,248,0,95,7,165,4,132,2,39,8,238,4,91,2,109,3,38,2,155,8,27,5,225,0,27,1,16,5,99,1,31,2,87,1,25,8,18,1,204,0,75,4,26,6,11,2,108,5,161,0,224,10,18,1,112,0,81,3,78,7,175,0,165,4,160,0,210,5,64,4,201,3,91,4,147,2,250,12,134,4,49,4,111,12,83,5,5,2,223,0,204,6,223,0,192,2,131,1,77,10,234,0,180,2,237,3,7,5,74,6,184,3,20,2,89,9,134,2,234,1,40,2,83,6,145,2,77,3,158,2,248,6,232,8,191,0,239,6,16,1,52,11,174,3,184,3,68,10,199,5,22,1,67,2,29,6,218,0,46,3,180,0,75,9,187,0,20,1,164,5,175,4,199,4,176,4,93,1,193,11,51,1,56,1,76,3,106,7,50,1,95,3,214,1,149,6,217,4,1,2,191,6,199,2,185,8,61,4,96,3,70,13,15,2,158,1,184,1,76,5,100,2,196,3,147,0,125,8,226,2,209,1,12,5,109,3,213,6,80,4,177,2,57,8,31,5,68,2,96,3,103,7,240,2,140,2,97,2,205,5,163,6,2,2,120,5,130,1,83,8,165,3,30,3,169,9,218,3,78,1,104,1,95,5,142,1,109,2,20,1,135,8,24,1,55,1,90,4,102,5,39,3,4,5,175,0,45,10,124,2,230,0,48,3,203,6,152,1,50,4,176,0,83,6,96,4,16,3,91,5,192,1,234,11,165,4,112,3,223,11,141,4,168,1,241,0,136,6,186,0,47,3,77,1,128,9,68,1,72,2,5,4,113,4,10,6,247,3,73,2,150,8,227,3,62,2,69,2,210,6,135,2,221,2,228,2,146,7,201,6,91,1,174,6,117,1,125,9,19,3,37,4,135,9,158,5,185,0,24,2,209,5,178,0,191,2,216,0,130,8,231,1,154,0,141,5,134,5,226,3,79,4,96,1,0,12,217,1,152,1,51,3,7,8,168,0,230,3,98,1,125,7,116,4,153,2,7,7,225,3,165,8,210,4,119,2,187,11,250,2,117,1,108,2,238,5,169,1,145,3,44,1,174,7,68,3,146,1,161,4,180,3,105,5,97,4,43,2,10,7,229,5,218,1,118,3,96,7,98,2,227,2,73,2,207,4,75,9,149,2,55,5,205,0,163,8,55,3,54,3,176,9,155,4,255,0,37,1,136,3,219,0,151,0,187,4,167,5,242,1,214,1,253,0,23,6,177,0,11,6,226,3,90,9,242,0,91,0,45,3,89,3,78,2,166,3,46,5,97,7,26,1,45,3,216,1,33,4,214,5,194,1,243,12,115,8,103,7,26,2,20,2,119,5,218,0,146,0,16,6,219,6,114,2,54,3,202,0,19,5,151,2,194,2,196,6,96,10,145,1,162,1,233,2,250,2,14,4,71,2,212,6,210,6,5,5,15,2,145,4,34,5,62,3,44,2,68,8,49,4,17,9,41,1,58,2,213,3,147,1,212,1,79,4,204,6,243,0,213,2,179,0,231,4,218,1,94,5,82,5,130,7,144,3,29,1,179,3,162,3,188,2,81,2,92,5,117,7,64,2,76,2,148,3,86,4,92,4,224,0,159,10,97,6,172,8,146,1,8,2,37,4,192,1,146,1,72,5,219,5,7,3,152,2,77,2,57,4,215,2,33,3,158,8,117,8,133,4,54,2,34,3,143,3,92,4,50,1,167,6,0,7,68,3,143,2,231,3,37,4,14,4,42,1,41,8,86,4,217,6,105,1,55,1,202,3,239,0,9,1,207,4,215,5,61,2,54,2,6,1,33,6,37,1,61,5,120,4,223,8,32,2,214,0,109,3,79,3,207,2,26,3,104,5,19,8,18,1,191,2,176,2,75,4,26,5,135,1,131,11,232,7,134,6,215,1,13,2,221,4,34,1,8,1,21,6,32,6,39,3,206,2,143,1,169,4,173,2,115,3,58,6,169,10,252,2,244,1,242,2,41,3,84,4,29,2,112,6,243,5,105,5,102,2,172,4,185,4,79,3,89,1,194,8,162,5,211,6,199,0,48,2,68,4,194,0,93,1,229,4,117,6,251,1,113,2,98,1,96,5,175,1,163,4,185,5,116,8,104,3,104,1,206,3,240,3,186,2,192,2,66,5,66,8,196,1,208,2,48,3,216,4,65,4,183,1,171,9,218,5,248,7,80,1,206,2,189,4,187,0,195,1,170,5,88,5,117,3,80,2,66,2,107,4,19,2,93,3,63,7,228,6,220,5,188,1,202,3,167,3,135,3,168,1,151,6,97,6,78,4,25,3,129,3,36,4,129,3,185,0,219,7,181,4,63,7,71,1,118,0,151,3,111,0,171,1,184,1,47,5,185,0,213,1,50,0,248,4,91,0,124,3,59,0,235,6,193,0,222,0,158,0,76,4,127,0,59,3,55,0,210,3,23,3,153,2,47,0,188,2,121,5,158,2,91,3,121,7,24,4,215,1,215,0,22,4,125,0,133,2,42,1,63,6,160,0,81,2,39,0,163,4,206,1,237,2,85,1,240,5,255,1,34,1,24,3,141,3,106,1,241,2,81,0,87,4,34,4,7,2,253,0,60,3,71,3,173,2,29,2,141,5,234,4,130,1,130,0,194,3,119,0,30,2,131,1,151,5,185,0,14,2,51,0,151,4,4,1,63,3,167,0,192,6,254,1,17,1,181,1,148,4,113,0,3,3,144,0,98,4,239,2,107,2,119,0,236,1,252,4,146,2,183,2,90,7,103,2,159,1,200,0,250,3,88,0,169,2,83,1,156,5,69,1,43,2,122,0,18,4,229,1,58,3,89,1,94,5,231,2,127,1,250,3,237,3,102,1,192,2,86,0,21,5,74,2,85,2,241,0,64,3,109,2,43,2,61,2,224,5,71,3,112,135,8,0,112,133,8,0,112,131,8,0,112,130,8,0,112,129,8,0,0,0,0,0,0,0,0,57,0,0,16,57,0,0,32,57,0,0,48,57,0,0,80,57,0,0,96,57,0,0,128,57,0,0,144,57,0,0,160,57,0,0,184,57,0,0,200,57,0,0,224,57,0,0,0,58,0,0,16,58,0,0,32,58,0,0,52,58,0,0,72,58,0,0,100,58,0,0,128,58,0,0,142,58,0,0,160,58,0,0,180,58,0,0,202,58,0,0,226,58,0,0,254,58,0,0,14,59,0,0,32,59,0,0,51,59,0,0,73,59,0,0,97,59,0,0,125,59,0,0,142,59,0,0,159,59,0,128,178,59,0,128,200,59,0,0,225,59,0,128,252,59,0,128,13,60,0,192,30,60,0,64,50,60,0,0,72,60,0,128,96,60,0,192,123,60,0,64,141,60,0,128,158,60,0,224,177,60,0,128,199,60,0,224,223,60,0,64,251,60,0,240,12,61,0,32,30,61,0,112,49,61,0,16,71,61,0,80,95,61,0,144,122,61,0,152,140,61,0,192,157,61,0,0,177,61,0,152,198,61,0,208,222,61,0,0,250,61,0,0,0,0,35,174,152,255,0,0,0,0,208,255,255,255,192,255,255,255,0,0,126,64,0,0,74,64,0,0,32,64,0,0,0,64,0,0,204,63,0,0,160,63,0,0,128,63,0,0,72,63,0,0,32,63,0,0,0,63,0,0,208,62,0,0,160,62,0,0,128,62,0,0,64,62,0,0,32,62,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,2,2,2,2,3,3,2,2,3,3,3,3,4,4,4,4,5,5,4,4,6,6,6,6,6,6,6,6,0,0,0,0,6,5,6,5,0,0,0,0,0,1,2,3,8,9,11,255,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,0,13,5,1,4,1,0,7,12,9,17,1,0,5,3,33,32,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,0,1,2,3,6,5,4,7,7,3,1,2,7,6,5,4,7,5,4,1,4,3,3,4,5,4,5,2,2,3,2,6,6,5,6,1,4,2,3,7,7,5,6,1,4,3,2,7,7,6,3,2,7,5,4,1,7,1,0,0,0,8,48,2,32,0,48,0,0,0,48,2,0,1,0,1,0,8,48,3,32,0,48,3,0,0,0,0,0,0,0,0,0,102,102,134,64,1,0,0,0,102,102,134,64,2,0,0,0,102,102,134,64,3,0,0,0,102,102,134,64,4,0,0,0,102,102,134,64,5,0,0,0,102,102,134,64,6,0,0,0,102,102,134,64,7,0,0,0,102,102,134,64,8,0,0,0,102,102,134,64,9,0,0,0,102,102,134,64,10,0,0,0,102,102,134,64,8,0,0,0,51,51,211,64,16,0,0,0,51,51,211,64,24,0,0,0,51,51,211,64,32,0,0,0,51,51,211,64,40,0,0,0,51,51,211,64,48,0,0,0,51,51,211,64,56,0,0,0,51,51,211,64,64,0,0,0,205,204,204,64,80,0,0,0,0,0,192,64,96,0,0,0,51,51,179,64,112,0,0,0,102,102,166,64,128,0,0,0,102,102,166,64,160,0,0,0,102,102,166,64,136,252,28,0,108,0,0,0,16,75,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,208,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,4,0,0,184,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,97,34,0,192,41,34,0,228,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,208,249,33,0,192,41,34,0,228,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,168,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,139,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,0,0,0,0,184,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,80,32,0,108,0,0,0,120,140,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,4,53,63,0,0,128,63,243,4,53,63,0,0,0,0,243,4,53,191,0,0,128,191,243,4,53,191,0,0,128,63,243,4,53,63,0,0,0,0,243,4,53,191,0,0,128,191,243,4,53,191,0,0,0,0,243,4,53,63,195,85,102,61,249,233,0,62,155,80,76,62,155,232,161,62,182,179,228,62,108,134,33,63,24,89,75,63,0,0,128,63,120,36,161,63,200,221,202,63,53,71,15,64,194,98,74,64,66,97,160,64,94,47,254,64,42,67,142,65,55,62,79,59,156,68,184,59,10,215,35,60,57,173,145,60,226,134,1,61,195,85,102,61,173,173,162,61,21,202,229,61,6,75,34,62,187,62,101,62,155,232,161,62,180,212,203,62,206,77,0,63,108,134,33,63,24,89,75,63,0,0,128,63,120,36,161,63,200,221,202,63,193,100,255,63,191,194,32,64,194,98,74,64,82,240,142,64,7,232,201,64,163,153,14,65,150,109,73,65,42,67,142,65,114,251,252,65,192,239,96,66,0,0,200,66,244,211,49,67,39,29,158,67,0,0,128,63,59,223,111,63,147,87,87,63,229,213,25,63,79,59,188,62,0,0,0,0,180,200,22,191,0,0,128,191,2,6,10,14,18,22,26,30,34,246,250,254,51,57,15,21,27,33,39,45,54,66,78,42,102,66,78,90,102,114,126,90,253,255,1,3,5,7,10,14,18,22,0,0,0,0,0,0,0,0,0,0,188,181,182,62,253,66,18,63,210,23,109,63,175,223,152,63,219,15,201,63,233,214,12,64,219,15,73,64,64,55,34,0,108,0,0,0,224,116,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,9,11,13,14,15,63,7,7,11,12,14,15,63,63,9,11,13,14,15,63,63,63,11,11,13,14,63,63,63,63,11,13,14,63,63,63,63,63,13,14,63,63,63,63,63,63,13,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,4,5,6,7,9,11,13,15,5,5,7,8,11,13,15,17,6,7,9,11,13,15,15,17,7,7,9,11,13,15,17,19,7,9,11,13,14,16,19,23,9,11,13,14,16,19,23,29,9,11,13,15,17,21,28,35,11,13,16,17,21,28,35,41,4,4,5,5,6,7,7,9,4,4,5,6,7,7,9,9,5,5,6,7,7,9,9,10,5,5,6,7,7,9,9,10,5,6,7,7,8,9,10,12,6,7,7,8,9,10,12,15,6,7,7,9,10,11,14,17,7,7,9,10,11,14,17,21,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,4,4,4,4,4,4,5,5,4,4,4,4,4,5,5,6,4,4,4,4,5,5,6,7,4,4,4,4,5,6,7,7,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,0,144,35,0,97,112,99,111,4,0,0,0,8,0,0,0,44,1,0,0,242,0,0,0,220,0,0,0,194,0,0,0,0,0,0,0,96,49,35,0,97,112,99,115,1,0,0,0,9,0,0,0,208,2,0,0,48,2,0,0,234,1,0,0,184,1,0,0,1,0,0,0,96,234,34,0,97,112,99,110,1,0,0,0,6,0,0,0,26,4,0,0,40,3,0,0,198,2,0,0,120,2,0,0,2,0,0,0,16,171,34,0,97,112,99,104,1,0,0,0,6,0,0,0,30,6,0,0,192,4,0,0,46,4,0,0,182,3,0,0,3,0,0,0,64,111,34,0,97,112,52,104,1,0,0,0,6,0,0,0,46,9,0,0,36,7,0,0,64,6,0,0,145,5,0,0,3,0,0,0,0,0,0,0,84,6,0,0,140,10,0,0,187,23,0,0,0,36,0,0,0,1,8,9,2,3,10,11,16,17,24,25,18,19,26,27,4,5,12,20,13,6,7,14,21,28,29,22,15,23,30,31,32,33,40,48,41,34,35,42,49,56,57,50,43,36,37,44,51,58,59,52,45,38,39,46,53,60,61,54,47,55,62,63,102,102,109,112,101,103,0,0,208,7,0,0,0,0,0,0,0,0,0,0,0,48,31,0,1,0,0,0,40,29,31,0,2,0,0,0,64,17,31,0,3,0,0,0,32,2,31,0,157,255,255,255,0,0,0,0,0,0,0,0,136,223,35,0,1,0,0,0,8,144,35,0,2,0,0,0,104,49,35,0,3,0,0,0,112,234,34,0,157,255,255,255,0,0,0,0,0,0,0,0,24,112,31,0,1,0,0,0,144,93,31,0,2,0,0,0,136,51,31,0,3,0,0,0,0,32,31,0,4,0,0,0,216,18,31,0,157,255,255,255,0,0,0,0,1,0,0,0,96,19,31,0,2,0,0,0,64,5,31,0,3,0,0,0,152,244,30,0,157,255,255,255,0,0,0,0,66,0,0,0,208,187,32,0,66,2,0,0,240,164,32,0,77,0,0,0,96,140,32,0,88,0,0,0,80,115,32,0,100,0,0,0,136,92,32,0,110,0,0,0,152,68,32,0,110,8,0,0,56,13,32,0,122,0,0,0,0,243,31,0,122,8,0,0,0,223,31,0,144,0,0,0,88,204,31,0,244,0,0,0,216,182,31,0,244,8,0,0,168,163,31,0,44,0,0,0,248,145,31,0,157,255,255,255,0,0,0,0,20,0,0,0,224,19,31,0,30,0,0,0,184,5,31,0,40,0,0,0,96,245,30,0,50,0,0,0,16,231,30,0,60,0,0,0,184,217,30,0,157,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,89,85,86,0,0,0,0,0,255,255,255,255,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,5,1,0,0,0,0,62,134,138,49,62,117,61,39,62,23,131,22,62,0,0,0,62,78,35,201,61,212,139,138,61,175,66,13,61,134,138,49,62,175,65,118,62,248,247,103,62,41,196,80,62,134,138,49,62,63,126,11,62,74,43,192,61,21,239,67,61,117,61,39,62,248,247,103,62,122,130,90,62,76,167,68,62,117,61,39,62,81,102,3,62,243,4,181,61,211,144,56,61,23,131,22,62,41,196,80,62,76,167,68,62,197,251,48,62,23,131,22,62,94,131,236,61,193,233,162,61,209,26,38,61,0,0,0,62,134,138,49,62,117,61,39,62,23,131,22,62,0,0,0,62,78,35,201,61,212,139,138,61,175,66,13,61,78,35,201,61,63,126,11,62,81,102,3,62,94,131,236,61,78,35,201,61,117,8,158,61,201,181,89,61,173,249,221,60,212,139,138,61,74,43,192,61,243,4,181,61,193,233,162,61,212,139,138,61,201,181,89,61,26,246,21,61,53,230,152,60,175,66,13,61,21,239,67,61,211,144,56,61,209,26,38,61,175,66,13,61,173,249,221,60,53,230,152,60,12,229,27,60,4,0,8,0,12,0,16,0,24,0,32,0,48,0,64,0,80,0,96,0,128,0,160,0,192,0,224,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,0,1,80,149,62,7,68,168,62,240,107,196,62,12,176,207,62,246,179,224,62,246,11,182,62,252,111,165,62,250,155,152,62,15,68,134,62,2,160,74,62,0,240,255,255,154,249,255,255,114,252,255,255,138,253,255,255,30,254,255,255,122,254,255,255,197,254,255,255,0,255,255,255,197,254,255,255,122,254,255,255,30,254,255,255,138,253,255,255,114,252,255,255,154,249,255,255,0,240,255,255,0,0,0,0,32,0,0,0,26,0,0,0,21,0,0,0,17,0,0,0,13,0,0,0,9,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,254,255,255,255,251,255,255,255,247,255,255,255,243,255,255,255,239,255,255,255,235,255,255,255,230,255,255,255,224,255,255,255,230,255,255,255,235,255,255,255,239,255,255,255,243,255,255,255,247,255,255,255,251,255,255,255,254,255,255,255,0,0,0,0,2,0,0,0,5,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,21,0,0,0,26,0,0,0,32,0,0,0,0,0,0,0,205,204,76,63,154,153,25,63,205,204,76,62,12,2,171,62,37,6,1,63,96,229,48,63,136,111,29,0,112,25,29,0,168,200,28,0,0,0,0,0,0,24,0,32,0,0,0,0,83,119,58,57,229,83,87,57,20,168,120,57,114,146,143,57,95,203,165,57,215,116,191,57,38,23,221,57,173,79,255,57,22,106,19,58,67,59,42,58,140,148,68,58,226,1,99,58,111,18,131,58,14,92,151,58,142,201,174,58,92,215,201,58,40,21,233,58,111,148,6,59,13,105,27,59,15,119,51,59,55,62,79,59,13,82,111,59,119,46,138,59,204,145,159,59,156,68,184,59,20,202,212,59,176,185,245,59,45,225,13,60,10,215,35,60,17,51,61,60,241,123,90,60,51,77,124,60,57,173,145,60,139,57,168,60,80,67,194,60,210,84,224,60,226,134,1,61,72,147,21,61,21,186,44,61,63,118,71,61,195,85,102,61,77,254,132,61,14,148,153,61,120,89,177,61,205,204,204,61,213,127,236,61,119,141,8,62,64,176,29,62,135,24,54,62,237,71,82,62,36,212,114,62,4,53,140,62,155,232,161,62,26,248,186,62,155,232,215,62,207,83,249,62,154,245,15,63,224,61,38,63,17,249,63,63,215,175,93,63,0,0,128,63,229,207,147,63,213,176,170,63,80,28,197,63,169,158,227,63,244,108,3,64,150,196,23,64,68,66,47,64,194,98,74,64,33,182,105,64,97,241,134,64,97,212,155,64,0,243,179,64,88,205,207,64,85,247,239,64,230,141,10,65,0,0,32,65,223,195,56,65,10,93,85,65,100,99,118,65,42,67,142,65,49,72,164,65,188,181,189,65,214,18,219,65,114,251,252,65,213,17,18,66,185,173,40,66,121,201,66,66,192,239,96,66,87,224,129,66,149,250,149,66,96,49,173,66,0,0,200,66,214,244,230,66,38,90,5,67,30,254,25,67,244,211,49,67,62,90,77,67,43,35,109,67,197,235,136,67,39,29,158,67,74,150,182,67,39,217,210,67,216,123,243,67,216,149,12,68,109,88,34,68,59,121,59,68,183,125,88,68,0,0,122,68,6,89,144,68,176,176,166,68,166,125,192,68,241,72,222,68,103,88,0,69,251,53,20,69,183,38,43,69,113,164,69,69,220,59,100,69,184,199,131,69,103,45,152,69,78,187,175,69,136,238,202,69,137,87,234,69,147,78,7,70,0,64,28,70,72,111,52,70,219,92,80,70,16,157,112,70,151,237,138,70,128,110,160,70,121,67,185,70,101,240,213,70,142,13,247,70,106,165,14,71,166,185,36,71,193,56,62,71,34,170,91,71,42,170,125,71,182,118,146,71,55,34,169,71,0,80,195,71,25,139,225,71,9,58,2,72,42,98,22,72,252,168,45,72,32,138,72,72,88,148,103,72,63,182,133,72,121,104,154,72,196,78,178,72,16,232,205,72,241,198,237,72,85,74,9,73,90,138,30,73,99,20,55,73,197,106,83,73,0,0,128,63,211,144,56,63,21,239,67,63,201,181,89,63,0,0,128,63,193,233,162,63,94,131,236,63,248,247,103,64,211,144,56,63,129,16,5,63,175,66,13,63,210,245,28,63,211,144,56,63,88,232,106,63,56,132,170,63,117,61,39,64,21,239,67,63,175,66,13,63,26,246,21,63,203,160,38,63,21,239,67,63,103,96,121,63,243,4,181,63,134,138,49,64,201,181,89,63,210,245,28,63,203,160,38,63,177,37,57,63,201,181,89,63,212,139,138,63,78,35,201,63,234,69,69,64,0,0,128,63,211,144,56,63,21,239,67,63,201,181,89,63,0,0,128,63,193,233,162,63,94,131,236,63,248,247,103,64,193,233,162,63,88,232,106,63,103,96,121,63,212,139,138,63,193,233,162,63,91,89,207,63,23,131,22,64,186,158,147,64,94,131,236,63,56,132,170,63,243,4,181,63,78,35,201,63,94,131,236,63,23,131,22,64,122,130,90,64,162,79,214,64,248,247,103,64,117,61,39,64,134,138,49,64,234,69,69,64,248,247,103,64,186,158,147,64,162,79,214,64,114,49,82,65,51,83,20,54,39,35,217,22,218,14,167,9,70,6,20,4,167,2,185,1,0,96,0,72,0,54,128,40,96,30,200,22,22,17,209,12,156,9,53,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,235,17,63,133,235,17,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,51,179,62,0,0,0,63,0,0,0,63,0,0,64,63,205,204,76,62,0,0,0,63,133,235,17,63,0,0,64,63,29,128,128,255,0,0,0,0,200,146,29,0,108,0,0,0,64,120,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,85,85,255,0,255,255,15,255,51,255,85,0,255,15,255,51,255,85,255,0,128,0,0,0,8,0,0,0,136,0,0,0,34,0,0,0,170,0,0,0,85,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,1,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,1,0,1,0,0,0,0,0,1,0,1,1,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,1,0,0,0,0,1,1,1,0,0,0,0,0,1,1,1,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,1,0,0,0,0,1,0,0,1,1,0,0,0,1,0,1,0,0,0,0,0,1,0,1,0,1,0,0,0,1,0,1,1,0,0,0,0,1,0,1,1,1,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,1,0,0,0,1,1,0,1,0,0,0,0,1,1,0,1,1,0,0,0,1,1,1,0,0,0,0,0,1,1,1,0,1,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,1,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,1,0,0,1,0,0,1,0,0,0,0,1,0,0,1,0,1,0,0,1,0,0,1,1,0,0,0,1,0,0,1,1,1,0,0,1,0,1,0,0,0,0,0,1,0,1,0,0,1,0,0,1,0,1,0,1,0,0,0,1,0,1,0,1,1,0,0,1,0,1,1,0,0,0,0,1,0,1,1,0,1,0,0,1,0,1,1,1,0,0,0,1,0,1,1,1,1,0,0,1,1,0,0,0,0,0,0,1,1,0,0,0,1,0,0,1,1,0,0,1,0,0,0,1,1,0,0,1,1,0,0,1,1,0,1,0,0,0,0,1,1,0,1,0,1,0,0,1,1,0,1,1,0,0,0,1,1,0,1,1,1,0,0,1,1,1,0,0,0,0,0,1,1,1,0,0,1,0,0,1,1,1,0,1,0,0,0,1,1,1,0,1,1,0,0,1,1,1,1,0,0,0,0,1,1,1,1,0,1,0,0,1,1,1,1,1,0,0,0,1,1,1,1,1,1,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,1,0,0,0,0,1,0,0,1,0,0,0,0,1,1,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,1,0,1,0,0,0,1,1,0,0,1,0,0,0,1,1,1,0,1,0,0,1,0,0,0,0,1,0,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,0,1,0,1,1,0,1,0,0,1,1,0,0,0,1,0,0,1,1,0,1,0,1,0,0,1,1,1,0,0,1,0,0,1,1,1,1,0,1,0,1,0,0,0,0,0,1,0,1,0,0,0,1,0,1,0,1,0,0,1,0,0,1,0,1,0,0,1,1,0,1,0,1,0,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,0,1,0,1,1,1,0,1,0,1,1,0,0,0,0,1,0,1,1,0,0,1,0,1,0,1,1,0,1,0,0,1,0,1,1,0,1,1,0,1,0,1,1,1,0,0,0,1,0,1,1,1,0,1,0,1,0,1,1,1,1,0,0,1,0,1,1,1,1,1,0,1,1,0,0,0,0,0,0,1,1,0,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+554232);
/* memory initializer */ allocate([0,1,1,0,0,0,1,0,0,1,1,0,0,0,1,1,0,1,1,0,0,1,0,0,0,1,1,0,0,1,0,1,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,1,0,1,1,0,1,0,0,0,0,1,1,0,1,0,0,1,0,1,1,0,1,0,1,0,0,1,1,0,1,0,1,1,0,1,1,0,1,1,0,0,0,1,1,0,1,1,0,1,0,1,1,0,1,1,1,0,0,1,1,0,1,1,1,1,0,1,1,1,0,0,0,0,0,1,1,1,0,0,0,1,0,1,1,1,0,0,1,0,0,1,1,1,0,0,1,1,0,1,1,1,0,1,0,0,0,1,1,1,0,1,0,1,0,1,1,1,0,1,1,0,0,1,1,1,0,1,1,1,0,1,1,1,1,0,0,0,0,1,1,1,1,0,0,1,0,1,1,1,1,0,1,0,0,1,1,1,1,0,1,1,0,1,1,1,1,1,0,0,0,1,1,1,1,1,0,1,0,1,1,1,1,1,1,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,1,0,0,0,0,0,1,1,1,0,0,0,0,1,0,0,1,0,0,0,0,1,0,1,1,0,0,0,0,1,1,0,1,0,0,0,0,1,1,1,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,1,1,0,0,0,1,0,1,0,1,0,0,0,1,0,1,1,1,0,0,0,1,1,0,0,1,0,0,0,1,1,0,1,1,0,0,0,1,1,1,0,1,0,0,0,1,1,1,1,1,0,0,1,0,0,0,0,1,0,0,1,0,0,0,1,1,0,0,1,0,0,1,0,1,0,0,1,0,0,1,1,1,0,0,1,0,1,0,0,1,0,0,1,0,1,0,1,1,0,0,1,0,1,1,0,1,0,0,1,0,1,1,1,1,0,0,1,1,0,0,0,1,0,0,1,1,0,0,1,1,0,0,1,1,0,1,0,1,0,0,1,1,0,1,1,1,0,0,1,1,1,0,0,1,0,0,1,1,1,0,1,1,0,0,1,1,1,1,0,1,0,0,1,1,1,1,1,1,0,1,0,0,0,0,0,1,0,1,0,0,0,0,1,1,0,1,0,0,0,1,0,1,0,1,0,0,0,1,1,1,0,1,0,0,1,0,0,1,0,1,0,0,1,0,1,1,0,1,0,0,1,1,0,1,0,1,0,0,1,1,1,1,0,1,0,1,0,0,0,1,0,1,0,1,0,0,1,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,1,0,1,0,1,1,0,0,1,0,1,0,1,1,0,1,1,0,1,0,1,1,1,0,1,0,1,0,1,1,1,1,1,0,1,1,0,0,0,0,1,0,1,1,0,0,0,1,1,0,1,1,0,0,1,0,1,0,1,1,0,0,1,1,1,0,1,1,0,1,0,0,1,0,1,1,0,1,0,1,1,0,1,1,0,1,1,0,1,0,1,1,0,1,1,1,1,0,1,1,1,0,0,0,1,0,1,1,1,0,0,1,1,0,1,1,1,0,1,0,1,0,1,1,1,0,1,1,1,0,1,1,1,1,0,0,1,0,1,1,1,1,0,1,1,0,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,1,1,1,0,0,0,0,1,0,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,0,1,1,0,0,0,1,0,1,1,1,0,0,0,1,1,0,1,1,0,0,0,1,1,1,1,1,0,0,1,0,0,0,1,1,0,0,1,0,0,1,1,1,0,0,1,0,1,0,1,1,0,0,1,0,1,1,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,1,1,1,0,0,1,1,1,0,1,1,0,0,1,1,1,1,1,1,0,1,0,0,0,0,1,1,0,1,0,0,0,1,1,1,0,1,0,0,1,0,1,1,0,1,0,0,1,1,1,1,0,1,0,1,0,0,1,1,0,1,0,1,0,1,1,1,0,1,0,1,1,0,1,1,0,1,0,1,1,1,1,1,0,1,1,0,0,0,1,1,0,1,1,0,0,1,1,1,0,1,1,0,1,0,1,1,0,1,1,0,1,1,1,1,0,1,1,1,0,0,1,1,0,1,1,1,0,1,1,1,0,1,1,1,1,0,1,1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,1,1,1,0,0,0,1,1,1,1,1,0,0,1,0,0,1,1,1,0,0,1,0,1,1,1,1,0,0,1,1,0,1,1,1,0,0,1,1,1,1,1,1,0,1,0,0,0,1,1,1,0,1,0,0,1,1,1,1,0,1,0,1,0,1,1,1,0,1,0,1,1,1,1,1,0,1,1,0,0,1,1,1,0,1,1,0,1,1,1,1,0,1,1,1,0,1,1,1,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,1,1,1,1,0,0,1,0,1,1,1,1,0,0,1,1,1,1,1,1,0,1,0,0,1,1,1,1,0,1,0,1,1,1,1,1,0,1,1,0,1,1,1,1,0,1,1,1,1,1,1,1,1,0,0,0,1,1,1,1,1,0,0,1,1,1,1,1,1,0,1,0,1,1,1,1,1,0,1,1,1,1,1,1,1,1,0,0,1,1,1,1,1,1,0,1,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,2,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,2,0,0,0,0,0,2,2,0,0,0,0,0,0,2,2,2,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,2,0,0,0,0,2,0,2,0,0,0,0,0,2,0,2,2,0,0,0,0,2,2,0,0,0,0,0,0,2,2,0,2,0,0,0,0,2,2,2,0,0,0,0,0,2,2,2,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,2,0,0,0,0,2,0,0,2,2,0,0,0,2,0,2,0,0,0,0,0,2,0,2,0,2,0,0,0,2,0,2,2,0,0,0,0,2,0,2,2,2,0,0,0,2,2,0,0,0,0,0,0,2,2,0,0,2,0,0,0,2,2,0,2,0,0,0,0,2,2,0,2,2,0,0,0,2,2,2,0,0,0,0,0,2,2,2,0,2,0,0,0,2,2,2,2,0,0,0,0,2,2,2,2,2,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,2,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,2,0,0,2,0,0,2,0,0,0,0,2,0,0,2,0,2,0,0,2,0,0,2,2,0,0,0,2,0,0,2,2,2,0,0,2,0,2,0,0,0,0,0,2,0,2,0,0,2,0,0,2,0,2,0,2,0,0,0,2,0,2,0,2,2,0,0,2,0,2,2,0,0,0,0,2,0,2,2,0,2,0,0,2,0,2,2,2,0,0,0,2,0,2,2,2,2,0,0,2,2,0,0,0,0,0,0,2,2,0,0,0,2,0,0,2,2,0,0,2,0,0,0,2,2,0,0,2,2,0,0,2,2,0,2,0,0,0,0,2,2,0,2,0,2,0,0,2,2,0,2,2,0,0,0,2,2,0,2,2,2,0,0,2,2,2,0,0,0,0,0,2,2,2,0,0,2,0,0,2,2,2,0,2,0,0,0,2,2,2,0,2,2,0,0,2,2,2,2,0,0,0,0,2,2,2,2,0,2,0,0,2,2,2,2,2,0,0,0,2,2,2,2,2,2,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,2,0,0,0,0,2,0,0,2,0,0,0,0,2,2,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,2,0,2,0,0,0,2,2,0,0,2,0,0,0,2,2,2,0,2,0,0,2,0,0,0,0,2,0,0,2,0,0,2,0,2,0,0,2,0,2,0,0,2,0,0,2,0,2,2,0,2,0,0,2,2,0,0,0,2,0,0,2,2,0,2,0,2,0,0,2,2,2,0,0,2,0,0,2,2,2,2,0,2,0,2,0,0,0,0,0,2,0,2,0,0,0,2,0,2,0,2,0,0,2,0,0,2,0,2,0,0,2,2,0,2,0,2,0,2,0,0,0,2,0,2,0,2,0,2,0,2,0,2,0,2,2,0,0,2,0,2,0,2,2,2,0,2,0,2,2,0,0,0,0,2,0,2,2,0,0,2,0,2,0,2,2,0,2,0,0,2,0,2,2,0,2,2,0,2,0,2,2,2,0,0,0,2,0,2,2,2,0,2,0,2,0,2,2,2,2,0,0,2,0,2,2,2,2,2,0,2,2,0,0,0,0,0,0,2,2,0,0,0,0,2,0,2,2,0,0,0,2,0,0,2,2,0,0,0,2,2,0,2,2,0,0,2,0,0,0,2,2,0,0,2,0,2,0,2,2,0,0,2,2,0,0,2,2,0,0,2,2,2,0,2,2,0,2,0,0,0,0,2,2,0,2,0,0,2,0,2,2,0,2,0,2,0,0,2,2,0,2,0,2,2,0,2,2,0,2,2,0,0,0,2,2,0,2,2,0,2,0,2,2,0,2,2,2,0,0,2,2,0,2,2,2,2,0,2,2,2,0,0,0,0,0,2,2,2,0,0,0,2,0,2,2,2,0,0,2,0,0,2,2,2,0,0,2,2,0,2,2,2,0,2,0,0,0,2,2,2,0,2,0,2,0,2,2,2,0,2,2,0,0,2,2,2,0,2,2,2,0,2,2,2,2,0,0,0,0,2,2,2,2,0,0,2,0,2,2,2,2,0,2,0,0,2,2,2,2,0,2,2,0,2,2,2,2,2,0,0,0,2,2,2,2,2,0,2,0,2,2,2,2,2,2,0,0,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,2,2,0,0,0,0,0,2,0,2,0,0,0,0,0,2,2,2,0,0,0,0,2,0,0,2,0,0,0,0,2,0,2,2,0,0,0,0,2,2,0,2,0,0,0,0,2,2,2,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,2,2,0,0,0,2,0,2,0,2,0,0,0,2,0,2,2,2,0,0,0,2,2,0,0,2,0,0,0,2,2,0,2,2,0,0,0,2,2,2,0,2,0,0,0,2,2,2,2,2,0,0,2,0,0,0,0,2,0,0,2,0,0,0,2,2,0,0,2,0,0,2,0,2,0,0,2,0,0,2,2,2,0,0,2,0,2,0,0,2,0,0,2,0,2,0,2,2,0,0,2,0,2,2,0,2,0,0,2,0,2,2,2,2,0,0,2,2,0,0,0,2,0,0,2,2,0,0,2,2,0,0,2,2,0,2,0,2,0,0,2,2,0,2,2,2,0,0,2,2,2,0,0,2,0,0,2,2,2,0,2,2,0,0,2,2,2,2,0,2,0,0,2,2,2,2,2,2,0,2,0,0,0,0,0,2,0,2,0,0,0,0,2,2,0,2,0,0,0,2,0,2,0,2,0,0,0,2,2,2,0,2,0,0,2,0,0,2,0,2,0,0,2,0,2,2,0,2,0,0,2,2,0,2,0,2,0,0,2,2,2,2,0,2,0,2,0,0,0,2,0,2,0,2,0,0,2,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,2,2,0,2,0,2,2,0,0,2,0,2,0,2,2,0,2,2,0,2,0,2,2,2,0,2,0,2,0,2,2,2,2,2,0,2,2,0,0,0,0,2,0,2,2,0,0,0,2,2,0,2,2,0,0,2,0,2,0,2,2,0,0,2,2,2,0,2,2,0,2,0,0,2,0,2,2,0,2,0,2,2,0,2,2,0,2,2,0,2,0,2,2,0,2,2,2,2,0,2,2,2,0,0,0,2,0,2,2,2,0,0,2,2,0,2,2,2,0,2,0,2,0,2,2,2,0,2,2,2,0,2,2,2,2,0,0,2,0,2,2,2,2,0,2,2,0,2,2,2,2,2,0,2,0,2,2,2,2,2,2,2,2,0,0,0,0,0,0,2,2,0,0,0,0,0,2,2,2,0,0,0,0,2,0,2,2,0,0,0,0,2,2,2,2,0,0,0,2,0,0,2,2,0,0,0,2,0,2,2,2,0,0,0,2,2,0,2,2,0,0,0,2,2,2,2,2,0,0,2,0,0,0,2,2,0,0,2,0,0,2,2,2,0,0,2,0,2,0,2,2,0,0,2,0,2,2,2,2,0,0,2,2,0,0,2,2,0,0,2,2,0,2,2,2,0,0,2,2,2,0,2,2,0,0,2,2,2,2,2,2,0,2,0,0,0,0,2,2,0,2,0,0,0,2,2,2,0,2,0,0,2,0,2,2,0,2,0,0,2,2,2,2,0,2,0,2,0,0,2,2,0,2,0,2,0,2,2,2,0,2,0,2,2,0,2,2,0,2,0,2,2,2,2,2,0,2,2,0,0,0,2,2,0,2,2,0,0,2,2,2,0,2,2,0,2,0,2,2,0,2,2,0,2,2,2,2,0,2,2,2,0,0,2,2,0,2,2,2,0,2,2,2,0,2,2,2,2,0,2,2,0,2,2,2,2,2,2,2,2,0,0,0,0,0,2,2,2,0,0,0,0,2,2,2,2,0,0,0,2,0,2,2,2,0,0,0,2,2,2,2,2,0,0,2,0,0,2,2,2,0,0,2,0,2,2,2,2,0,0,2,2,0,2,2,2,0,0,2,2,2,2,2,2,0,2,0,0,0,2,2,2,0,2,0,0,2,2,2,2,0,2,0,2,0,2,2,2,0,2,0,2,2,2,2,2,0,2,2,0,0,2,2,2,0,2,2,0,2,2,2,2,0,2,2,2,0,2,2,2,0,2,2,2,2,2,2,2,2,0,0,0,0,2,2,2,2,0,0,0,2,2,2,2,2,0,0,2,0,2,2,2,2,0,0,2,2,2,2,2,2,0,2,0,0,2,2,2,2,0,2,0,2,2,2,2,2,0,2,2,0,2,2,2,2,0,2,2,2,2,2,2,2,2,0,0,0,2,2,2,2,2,0,0,2,2,2,2,2,2,0,2,0,2,2,2,2,2,0,2,2,2,2,2,2,2,2,0,0,2,2,2,2,2,2,0,2,2,2,2,2,2,2,2,0,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,4,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,4,0,0,0,0,0,4,4,0,0,0,0,0,0,4,4,4,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,4,0,0,0,0,4,0,4,0,0,0,0,0,4,0,4,4,0,0,0,0,4,4,0,0,0,0,0,0,4,4,0,4,0,0,0,0,4,4,4,0,0,0,0,0,4,4,4,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,4,0,0,0,0,4,0,0,4,4,0,0,0,4,0,4,0,0,0,0,0,4,0,4,0,4,0,0,0,4,0,4,4,0,0,0,0,4,0,4,4,4,0,0,0,4,4,0,0,0,0,0,0,4,4,0,0,4,0,0,0,4,4,0,4,0,0,0,0,4,4,0,4,4,0,0,0,4,4,4,0,0,0,0,0,4,4,4,0,4,0,0,0,4,4,4,4,0,0,0,0,4,4,4,4,4,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,4,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,4,0,0,4,0,0,4,0,0,0,0,4,0,0,4,0,4,0,0,4,0,0,4,4,0,0,0,4,0,0,4,4,4,0,0,4,0,4,0,0,0,0,0,4,0,4,0,0,4,0,0,4,0,4,0,4,0,0,0,4,0,4,0,4,4,0,0,4,0,4,4,0,0,0,0,4,0,4,4,0,4,0,0,4,0,4,4,4,0,0,0,4,0,4,4,4,4,0,0,4,4,0,0,0,0,0,0,4,4,0,0,0,4,0,0,4,4,0,0,4,0,0,0,4,4,0,0,4,4,0,0,4,4,0,4,0,0,0,0,4,4,0,4,0,4,0,0,4,4,0,4,4,0,0,0,4,4,0,4,4,4,0,0,4,4,4,0,0,0,0,0,4,4,4,0,0,4,0,0,4,4,4,0,4,0,0,0,4,4,4,0,4,4,0,0,4,4,4,4,0,0,0,0,4,4,4,4,0,4,0,0,4,4,4,4,4,0,0,0,4,4,4,4,4,4,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,4,0,4,0,0,0,0,4,0,0,4,0,0,0,0,4,4,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,4,0,4,0,0,0,4,4,0,0,4,0,0,0,4,4,4,0,4,0,0,4,0,0,0,0,4,0,0,4,0,0,4,0,4,0,0,4,0,4,0,0,4,0,0,4,0,4,4,0,4,0,0,4,4,0,0,0,4,0,0,4,4,0,4,0,4,0,0,4,4,4,0,0,4,0,0,4,4,4,4,0,4,0,4,0,0,0,0,0,4,0,4,0,0,0,4,0,4,0,4,0,0,4,0,0,4,0,4,0,0,4,4,0,4,0,4,0,4,0,0,0,4,0,4,0,4,0,4,0,4,0,4,0,4,4,0,0,4,0,4,0,4,4,4,0,4,0,4,4,0,0,0,0,4,0,4,4,0,0,4,0,4,0,4,4,0,4,0,0,4,0,4,4,0,4,4,0,4,0,4,4,4,0,0,0,4,0,4,4,4,0,4,0,4,0,4,4,4,4,0,0,4,0,4,4,4,4,4,0,4,4,0,0,0,0,0,0,4,4,0,0,0,0,4,0,4,4,0,0,0,4,0,0,4,4,0,0,0,4,4,0,4,4,0,0,4,0,0,0,4,4,0,0,4,0,4,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,4,0,4,4,0,4,0,0,0,0,4,4,0,4,0,0,4,0,4,4,0,4,0,4,0,0,4,4,0,4,0,4,4,0,4,4,0,4,4,0,0,0,4,4,0,4,4,0,4,0,4,4,0,4,4,4,0,0,4,4,0,4,4,4,4,0,4,4,4,0,0,0,0,0,4,4,4,0,0,0,4,0,4,4,4,0,0,4,0,0,4,4,4,0,0,4,4,0,4,4,4,0,4,0,0,0,4,4,4,0,4,0,4,0,4,4,4,0,4,4,0,0,4,4,4,0,4,4,4,0,4,4,4,4,0,0,0,0,4,4,4,4,0,0,4,0,4,4,4,4,0,4,0,0,4,4,4,4,0,4,4,0,4,4,4,4,4,0,0,0,4,4,4,4,4,0,4,0,4,4,4,4,4,4,0,0,4,4,4,4,4,4,4,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,4,4,0,0,0,0,0,4,0,4,0,0,0,0,0,4,4,4,0,0,0,0,4,0,0,4,0,0,0,0,4,0,4,4,0,0,0,0,4,4,0,4,0,0,0,0,4,4,4,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,4,4,0,0,0,4,0,4,0,4,0,0,0,4,0,4,4,4,0,0,0,4,4,0,0,4,0,0,0,4,4,0,4,4,0,0,0,4,4,4,0,4,0,0,0,4,4,4,4,4,0,0,4,0,0,0,0,4,0,0,4,0,0,0,4,4,0,0,4,0,0,4,0,4,0,0,4,0,0,4,4,4,0,0,4,0,4,0,0,4,0,0,4,0,4,0,4,4,0,0,4,0,4,4,0,4,0,0,4,0,4,4,4,4,0,0,4,4,0,0,0,4,0,0,4,4,0,0,4,4,0,0,4,4,0,4,0,4,0,0,4,4,0,4,4,4,0,0,4,4,4,0,0,4,0,0,4,4,4,0,4,4,0,0,4,4,4,4,0,4,0,0,4,4,4,4,4,4,0,4,0,0,0,0,0,4,0,4,0,0,0,0,4,4,0,4,0,0,0,4,0,4,0,4,0,0,0,4,4,4,0,4,0,0,4,0,0,4,0,4,0,0,4,0,4,4,0,4,0,0,4,4,0,4,0,4,0,0,4,4,4,4,0,4,0,4,0,0,0,4,0,4,0,4,0,0,4,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,4,4,0,4,0,4,4,0,0,4,0,4,0,4,4,0,4,4,0,4,0,4,4,4,0,4,0,4,0,4,4,4,4,4,0,4,4,0,0,0,0,4,0,4,4,0,0,0,4,4,0,4,4,0,0,4,0,4,0,4,4,0,0,4,4,4,0,4,4,0,4,0,0,4,0,4,4,0,4,0,4,4,0,4,4,0,4,4,0,4,0,4,4,0,4,4,4,4,0,4,4,4,0,0,0,4,0,4,4,4,0,0,4,4,0,4,4,4,0,4,0,4,0,4,4,4,0,4,4,4,0,4,4,4,4,0,0,4,0,4,4,4,4,0,4,4,0,4,4,4,4,4,0,4,0,4,4,4,4,4,4,4,4,0,0,0,0,0,0,4,4,0,0,0,0,0,4,4,4,0,0,0,0,4,0,4,4,0,0,0,0,4,4,4,4,0,0,0,4,0,0,4,4,0,0,0,4,0,4,4,4,0,0,0,4,4,0,4,4,0,0,0,4,4,4,4,4,0,0,4,0,0,0,4,4,0,0,4,0,0,4,4,4,0,0,4,0,4,0,4,4,0,0,4,0,4,4,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,4,4,4,0,0,4,4,4,0,4,4,0,0,4,4,4,4,4,4,0,4,0,0,0,0,4,4,0,4,0,0,0,4,4,4,0,4,0,0,4,0,4,4,0,4,0,0,4,4,4,4,0,4,0,4,0,0,4,4,0,4,0,4,0,4,4,4,0,4,0,4,4,0,4,4,0,4,0,4,4,4,4,4,0,4,4,0,0,0,4,4,0,4,4,0,0,4,4,4,0,4,4,0,4,0,4,4,0,4,4,0,4,4,4,4,0,4,4,4,0,0,4,4,0,4,4,4,0,4,4,4,0,4,4,4,4,0,4,4,0,4,4,4,4,4,4,4,4,0,0,0,0,0,4,4,4,0,0,0,0,4,4,4,4,0,0,0,4,0,4,4,4,0,0,0,4,4,4,4,4,0,0,4,0,0,4,4,4,0,0,4,0,4,4,4,4,0,0,4,4,0,4,4,4,0,0,4,4,4,4,4,4,0,4,0,0,0,4,4,4,0,4,0,0,4,4,4,4,0,4,0,4,0,4,4,4,0,4,0,4,4,4,4,4,0,4,4,0,0,4,4,4,0,4,4,0,4,4,4,4,0,4,4,4,0,4,4,4,0,4,4,4,4,4,4,4,4,0,0,0,0,4,4,4,4,0,0,0,4,4,4,4,4,0,0,4,0,4,4,4,4,0,0,4,4,4,4,4,4,0,4,0,0,4,4,4,4,0,4,0,4,4,4,4,4,0,4,4,0,4,4,4,4,0,4,4,4,4,4,4,4,4,0,0,0,4,4,4,4,4,0,0,4,4,4,4,4,4,0,4,0,4,4,4,4,4,0,4,4,4,4,4,4,4,4,0,0,4,4,4,4,4,4,0,4,4,4,4,4,4,4,4,0,4,4,4,4,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,8,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,8,0,0,0,0,0,8,8,0,0,0,0,0,0,8,8,8,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,8,0,0,0,0,8,0,8,0,0,0,0,0,8,0,8,8,0,0,0,0,8,8,0,0,0,0,0,0,8,8,0,8,0,0,0,0,8,8,8,0,0,0,0,0,8,8,8,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,8,0,0,0,0,8,0,0,8,8,0,0,0,8,0,8,0,0,0,0,0,8,0,8,0,8,0,0,0,8,0,8,8,0,0,0,0,8,0,8,8,8,0,0,0,8,8,0,0,0,0,0,0,8,8,0,0,8,0,0,0,8,8,0,8,0,0,0,0,8,8,0,8,8,0,0,0,8,8,8,0,0,0,0,0,8,8,8,0,8,0,0,0,8,8,8,8,0,0,0,0,8,8,8,8,8,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,8,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,8,0,0,8,0,0,8,0,0,0,0,8,0,0,8,0,8,0,0,8,0,0,8,8,0,0,0,8,0,0,8,8,8,0,0,8,0,8,0,0,0,0,0,8,0,8,0,0,8,0,0,8,0,8,0,8,0,0,0,8,0,8,0,8,8,0,0,8,0,8,8,0,0,0,0,8,0,8,8,0,8,0,0,8,0,8,8,8,0,0,0,8,0,8,8,8,8,0,0,8,8,0,0,0,0,0,0,8,8,0,0,0,8,0,0,8,8,0,0,8,0,0,0,8,8,0,0,8,8,0,0,8,8,0,8,0,0,0,0,8,8,0,8,0,8,0,0,8,8,0,8,8,0,0,0,8,8,0,8,8,8,0,0,8,8,8,0,0,0,0,0,8,8,8,0,0,8,0,0,8,8,8,0,8,0,0,0,8,8,8,0,8,8,0,0,8,8,8,8,0,0,0,0,8,8,8,8,0,8,0,0,8,8,8,8,8,0,0,0,8,8,8,8,8,8,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,8,0,8,0,0,0,0,8,0,0,8,0,0,0,0,8,8,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,8,0,8,0,0,0,8,8,0,0,8,0,0,0,8,8,8,0,8,0,0,8,0,0,0,0,8,0,0,8,0,0,8,0,8,0,0,8,0,8,0,0,8,0,0,8,0,8,8,0,8,0,0,8,8,0,0,0,8,0,0,8,8,0,8,0,8,0,0,8,8,8,0,0,8,0,0,8,8,8,8,0,8,0,8,0,0,0,0,0,8,0,8,0,0,0,8,0,8,0,8,0,0,8,0,0,8,0,8,0,0,8,8,0,8,0,8,0,8,0,0,0,8,0,8,0,8,0,8,0,8,0,8,0,8,8,0,0,8,0,8,0,8,8,8,0,8,0,8,8,0,0,0,0,8,0,8,8,0,0,8,0,8,0,8,8,0,8,0,0,8,0,8,8,0,8,8,0,8,0,8,8,8,0,0,0,8,0,8,8,8,0,8,0,8,0,8,8,8,8,0,0,8,0,8,8,8,8,8,0,8,8,0,0,0,0,0,0,8,8,0,0,0,0,8,0,8,8,0,0,0,8,0,0,8,8,0,0,0,8,8,0,8,8,0,0,8,0,0,0,8,8,0,0,8,0,8,0,8,8,0,0,8,8,0,0,8,8,0,0,8,8,8,0,8,8,0,8,0,0,0,0,8,8,0,8,0,0,8,0,8,8,0,8,0,8,0,0,8,8,0,8,0,8,8,0,8,8,0,8,8,0,0,0,8,8,0,8,8,0,8,0,8,8,0,8,8,8,0,0,8,8,0,8,8,8,8,0,8,8,8,0,0,0,0,0,8,8,8,0,0,0,8,0,8,8,8,0,0,8,0,0,8,8,8,0,0,8,8,0,8,8,8,0,8,0,0,0,8,8,8,0,8,0,8,0,8,8,8,0,8,8,0,0,8,8,8,0,8,8,8,0,8,8,8,8,0,0,0,0,8,8,8,8,0,0,8,0,8,8,8,8,0,8,0,0,8,8,8,8,0,8,8,0,8,8,8,8,8,0,0,0,8,8,8,8,8,0,8,0,8,8,8,8,8,8,0,0,8,8,8,8,8,8,8,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,8,8,0,0,0,0,0,8,0,8,0,0,0,0,0,8,8,8,0,0,0,0,8,0,0,8,0,0,0,0,8,0,8,8,0,0,0,0,8,8,0,8,0,0,0,0,8,8,8,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,8,8,0,0,0,8,0,8,0,8,0,0,0,8,0,8,8,8,0,0,0,8,8,0,0,8,0,0,0,8,8,0,8,8,0,0,0,8,8,8,0,8,0,0,0,8,8,8,8,8,0,0,8,0,0,0,0,8,0,0,8,0,0,0,8,8,0,0,8,0,0,8,0,8,0,0,8,0,0,8,8,8,0,0,8,0,8,0,0,8,0,0,8,0,8,0,8,8,0,0,8,0,8,8,0,8,0,0,8,0,8,8,8,8,0,0,8,8,0,0,0,8,0,0,8,8,0,0,8,8,0,0,8,8,0,8,0,8,0,0,8,8,0,8,8,8,0,0,8,8,8,0,0,8,0,0,8,8,8,0,8,8,0,0,8,8,8,8,0,8,0,0,8,8,8,8,8,8,0,8,0,0,0,0,0,8,0,8,0,0,0,0,8,8,0,8,0,0,0,8,0,8,0,8,0,0,0,8,8,8,0,8,0,0,8,0,0,8,0,8,0,0,8,0,8,8,0,8,0,0,8,8,0,8,0,8,0,0,8,8,8,8,0,8,0,8,0,0,0,8,0,8,0,8,0,0,8,8,0,8,0,8,0,8,0,8,0,8,0,8,0,8,8,8,0,8,0,8,8,0,0,8,0,8,0,8,8,0,8,8,0,8,0,8,8,8,0,8,0,8,0,8,8,8,8,8,0,8,8,0,0,0,0,8,0,8,8,0,0,0,8,8,0,8,8,0,0,8,0,8,0,8,8,0,0,8,8,8,0,8,8,0,8,0,0,8,0,8,8,0,8,0,8,8,0,8,8,0,8,8,0,8,0,8,8,0,8,8,8,8,0,8,8,8,0,0,0,8,0,8,8,8,0,0,8,8,0,8,8,8,0,8,0,8,0,8,8,8,0,8,8,8,0,8,8,8,8,0,0,8,0,8,8,8,8,0,8,8,0,8,8,8,8,8,0,8,0,8,8,8,8,8,8,8,8,0,0,0,0,0,0,8,8,0,0,0,0,0,8,8,8,0,0,0,0,8,0,8,8,0,0,0,0,8,8,8,8,0,0,0,8,0,0,8,8,0,0,0,8,0,8,8,8,0,0,0,8,8,0,8,8,0,0,0,8,8,8,8,8,0,0,8,0,0,0,8,8,0,0,8,0,0,8,8,8,0,0,8,0,8,0,8,8,0,0,8,0,8,8,8,8,0,0,8,8,0,0,8,8,0,0,8,8,0,8,8,8,0,0,8,8,8,0,8,8,0,0,8,8,8,8,8,8,0,8,0,0,0,0,8,8,0,8,0,0,0,8,8,8,0,8,0,0,8,0,8,8,0,8,0,0,8,8,8,8,0,8,0,8,0,0,8,8,0,8,0,8,0,8,8,8,0,8,0,8,8,0,8,8,0,8,0,8,8,8,8,8,0,8,8,0,0,0,8,8,0,8,8,0,0,8,8,8,0,8,8,0,8,0,8,8,0,8,8,0,8,8,8,8,0,8,8,8,0,0,8,8,0,8,8,8,0,8,8,8,0,8,8,8,8,0,8,8,0,8,8,8,8,8,8,8,8,0,0,0,0,0,8,8,8,0,0,0,0,8,8,8,8,0,0,0,8,0,8,8,8,0,0,0,8,8,8,8,8,0,0,8,0,0,8,8,8,0,0,8,0,8,8,8,8,0,0,8,8,0,8,8,8,0,0,8,8,8,8,8,8,0,8,0,0,0,8,8,8,0,8,0,0,8,8,8,8,0,8,0,8,0,8,8,8,0,8,0,8,8,8,8,8,0,8,8,0,0,8,8,8,0,8,8,0,8,8,8,8,0,8,8,8,0,8,8,8,0,8,8,8,8,8,8,8,8,0,0,0,0,8,8,8,8,0,0,0,8,8,8,8,8,0,0,8,0,8,8,8,8,0,0,8,8,8,8,8,8,0,8,0,0,8,8,8,8,0,8,0,8,8,8,8,8,0,8,8,0,8,8,8,8,0,8,8,8,8,8,8,8,8,0,0,0,8,8,8,8,8,0,0,8,8,8,8,8,8,0,8,0,8,8,8,8,8,0,8,8,8,8,8,8,8,8,0,0,8,8,8,8,8,8,0,8,8,8,8,8,8,8,8,0,8,8,8,8,8,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,16,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,16,0,0,0,0,0,16,16,0,0,0,0,0,0,16,16,16,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,16,0,0,0,0,16,0,16,0,0,0,0,0,16,0,16,16,0,0,0,0,16,16,0,0,0,0,0,0,16,16,0,16,0,0,0,0,16,16,16,0,0,0,0,0,16,16,16,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,16,0,0,0,0,16,0,0,16,16,0,0,0,16,0,16,0,0,0,0,0,16,0,16,0,16,0,0,0,16,0,16,16,0,0,0,0,16,0,16,16,16,0,0,0,16,16,0,0,0,0,0,0,16,16,0,0,16,0,0,0,16,16,0,16,0,0,0,0,16,16,0,16,16,0,0,0,16,16,16,0,0,0,0,0,16,16,16,0,16,0,0,0,16,16,16,16,0,0,0,0,16,16,16,16,16,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,16,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,16,0,0,16,0,0,16,0,0,0,0,16,0,0,16,0,16,0,0,16,0,0,16,16,0,0,0,16,0,0,16,16,16,0,0,16,0,16,0,0,0,0,0,16,0,16,0,0,16,0,0,16,0,16,0,16,0,0,0,16,0,16,0,16,16,0,0,16,0,16,16,0,0,0,0,16,0,16,16,0,16,0,0,16,0,16,16,16,0,0,0,16,0,16,16,16,16,0,0,16,16,0,0,0,0,0,0,16,16,0,0,0,16,0,0,16,16,0,0,16,0,0,0,16,16,0,0,16,16,0,0,16,16,0,16,0,0,0,0,16,16,0,16,0,16,0,0,16,16,0,16,16,0,0,0,16,16,0,16,16,16,0,0,16,16,16,0,0,0,0,0,16,16,16,0,0,16,0,0,16,16,16,0,16,0,0,0,16,16,16,0,16,16,0,0,16,16,16,16,0,0,0,0,16,16,16,16,0,16,0,0,16,16,16,16,16,0,0,0,16,16,16,16,16,16,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,16,0,16,0,0,0,0,16,0,0,16,0,0,0,0,16,16,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,16,0,16,0,0,0,16,16,0,0,16,0,0,0,16,16,16,0,16,0,0,16,0,0,0,0,16,0,0,16,0,0,16,0,16,0,0,16,0,16,0,0,16,0,0,16,0,16,16,0,16,0,0,16,16,0,0,0,16,0,0,16,16,0,16,0,16,0,0,16,16,16,0,0,16,0,0,16,16,16,16,0,16,0,16,0,0,0,0,0,16,0,16,0,0,0,16,0,16,0,16,0,0,16,0,0,16,0,16,0,0,16,16,0,16,0,16,0,16,0,0,0,16,0,16,0,16,0,16,0,16,0,16,0,16,16,0,0,16,0,16,0,16,16,16,0,16,0,16,16,0,0,0,0,16,0,16,16,0,0,16,0,16,0,16,16,0,16,0,0,16,0,16,16,0,16,16,0,16,0,16,16,16,0,0,0,16,0,16,16,16,0,16,0,16,0,16,16,16,16,0,0,16,0,16,16,16,16,16,0,16,16,0,0,0,0,0,0,16,16,0,0,0,0,16,0,16,16,0,0,0,16,0,0,16,16,0,0,0,16,16,0,16,16,0,0,16,0,0,0,16,16,0,0,16,0,16,0,16,16,0,0,16,16,0,0,16,16,0,0,16,16,16,0,16,16,0,16,0,0,0,0,16,16,0,16,0,0,16,0,16,16,0,16,0,16,0,0,16,16,0,16,0,16,16,0,16,16,0,16,16,0,0,0,16,16,0,16,16,0,16,0,16,16,0,16,16,16,0,0,16,16,0,16,16,16,16,0,16,16,16,0,0,0,0,0,16,16,16,0,0,0,16,0,16,16,16,0,0,16,0,0,16,16,16,0,0,16,16,0,16,16,16,0,16,0,0,0,16,16,16,0,16,0,16,0,16,16,16,0,16,16,0,0,16,16,16,0,16,16,16,0,16,16,16,16,0,0,0,0,16,16,16,16,0,0,16,0,16,16,16,16,0,16,0,0,16,16,16,16,0,16,16,0,16,16,16,16,16,0,0,0,16,16,16,16,16,0,16,0,16,16,16,16,16,16,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,16,16,0,0,0,0,0,16,0,16,0,0,0,0,0,16,16,16,0,0,0,0,16,0,0,16,0,0,0,0,16,0,16,16,0,0,0,0,16,16,0,16,0,0,0,0,16,16,16,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,16,16,0,0,0,16,0,16,0,16,0,0,0,16,0,16,16,16,0,0,0,16,16,0,0,16,0,0,0,16,16,0,16,16,0,0,0,16,16,16,0,16,0,0,0,16,16,16,16,16,0,0,16,0,0,0,0,16,0,0,16,0,0,0,16,16,0,0,16,0,0,16,0,16,0,0,16,0,0,16,16,16,0,0,16,0,16,0,0,16,0,0,16,0,16,0,16,16,0,0,16,0,16,16,0,16,0,0,16,0,16,16,16,16,0,0,16,16,0,0,0,16,0,0,16,16,0,0,16,16,0,0,16,16,0,16,0,16,0,0,16,16,0,16,16,16,0,0,16,16,16,0,0,16,0,0,16,16,16,0,16,16,0,0,16,16,16,16,0,16,0,0,16,16,16,16,16,16,0,16,0,0,0,0,0,16,0,16,0,0,0,0,16,16,0,16,0,0,0,16,0,16,0,16,0,0,0,16,16,16,0,16,0,0,16,0,0,16,0,16,0,0,16,0,16,16,0,16,0,0,16,16,0,16,0,16,0,0,16,16,16,16,0,16,0,16,0,0,0,16,0,16,0,16,0,0,16,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,16,16,0,16,0,16,16,0,0,16,0,16,0,16,16,0,16,16,0,16,0,16,16,16,0,16,0,16,0,16,16,16,16,16,0,16,16,0,0,0,0,16,0,16,16,0,0,0,16,16,0,16,16,0,0,16,0,16,0,16,16,0,0,16,16,16,0,16,16,0,16,0,0,16,0,16,16,0,16,0,16,16,0,16,16,0,16,16,0,16,0,16,16,0,16,16,16,16,0,16,16,16,0,0,0,16,0,16,16,16,0,0,16,16,0,16,16,16,0,16,0,16,0,16,16,16,0,16,16,16,0,16,16,16,16,0,0,16,0,16,16,16,16,0,16,16,0,16,16,16,16,16,0,16,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,16,16,0,0,0,0,0,16,16,16,0,0,0,0,16,0,16,16,0,0,0,0,16,16,16,16,0,0,0,16,0,0,16,16,0,0,0,16,0,16,16,16,0,0,0,16,16,0,16,16,0,0,0,16,16,16,16,16,0,0,16,0,0,0,16,16,0,0,16,0,0,16,16,16,0,0,16,0,16,0,16,16,0,0,16,0,16,16,16,16,0,0,16,16,0,0,16,16,0,0,16,16,0,16,16,16,0,0,16,16,16,0,16,16,0,0,16,16,16,16,16,16,0,16,0,0,0,0,16,16,0,16,0,0,0,16,16,16,0,16,0,0,16,0,16,16,0,16,0,0,16,16,16,16,0,16,0,16,0,0,16,16,0,16,0,16,0,16,16,16,0,16,0,16,16,0,16,16,0,16,0,16,16,16,16,16,0,16,16,0,0,0,16,16,0,16,16,0,0,16,16,16,0,16,16,0,16,0,16,16,0,16,16,0,16,16,16,16,0,16,16,16,0,0,16,16,0,16,16,16,0,16,16,16,0,16,16,16,16,0,16,16,0,16,16,16,16,16,16,16,16,0,0,0,0,0,16,16,16,0,0,0,0,16,16,16,16,0,0,0,16,0,16,16,16,0,0,0,16,16,16,16,16,0,0,16,0,0,16,16,16,0,0,16,0,16,16,16,16,0,0,16,16,0,16,16,16,0,0,16,16,16,16,16,16,0,16,0,0,0,16,16,16,0,16,0,0,16,16,16,16,0,16,0,16,0,16,16,16,0,16,0,16,16,16,16,16,0,16,16,0,0,16,16,16,0,16,16,0,16,16,16,16,0,16,16,16,0,16,16,16,0,16,16,16,16,16,16,16,16,0,0,0,0,16,16,16,16,0,0,0,16,16,16,16,16,0,0,16,0,16,16,16,16,0,0,16,16,16,16,16,16,0,16,0,0,16,16,16,16,0,16,0,16,16,16,16,16,0,16,16,0,16,16,16,16,0,16,16,16,16,16,16,16,16,0,0,0,16,16,16,16,16,0,0,16,16,16,16,16,16,0,16,0,16,16,16,16,16,0,16,16,16,16,16,16,16,16,0,0,16,16,16,16,16,16,0,16,16,16,16,16,16,16,16,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,32,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,32,0,0,0,0,0,32,32,0,0,0,0,0,0,32,32,32,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,32,0,0,0,0,32,0,32,0,0,0,0,0,32,0,32,32,0,0,0,0,32,32,0,0,0,0,0,0,32,32,0,32,0,0,0,0,32,32,32,0,0,0,0,0,32,32,32,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,32,0,0,0,0,32,0,0,32,32,0,0,0,32,0,32,0,0,0,0,0,32,0,32,0,32,0,0,0,32,0,32,32,0,0,0,0,32,0,32,32,32,0,0,0,32,32,0,0,0,0,0,0,32,32,0,0,32,0,0,0,32,32,0,32,0,0,0,0,32,32,0,32,32,0,0,0,32,32,32,0,0,0,0,0,32,32,32,0,32,0,0,0,32,32,32,32,0,0,0,0,32,32,32,32,32,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,32,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,32,0,0,32,0,0,32,0,0,0,0,32,0,0,32,0,32,0,0,32,0,0,32,32,0,0,0,32,0,0,32,32,32,0,0,32,0,32,0,0,0,0,0,32,0,32,0,0,32,0,0,32,0,32,0,32,0,0,0,32,0,32,0,32,32,0,0,32,0,32,32,0,0,0,0,32,0,32,32,0,32,0,0,32,0,32,32,32,0,0,0,32,0,32,32,32,32,0,0,32,32,0,0,0,0,0,0,32,32,0,0,0,32,0,0,32,32,0,0,32,0,0,0,32,32,0,0,32,32,0,0,32,32,0,32,0,0,0,0,32,32,0,32,0,32,0,0,32,32,0,32,32,0,0,0,32,32,0,32,32,32,0,0,32,32,32,0,0,0,0,0,32,32,32,0,0,32,0,0,32,32,32,0,32,0,0,0,32,32,32,0,32,32,0,0,32,32,32,32,0,0,0,0,32,32,32,32,0,32,0,0,32,32,32,32,32,0,0,0,32,32,32,32,32,32,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,32,0,32,0,0,0,0,32,0,0,32,0,0,0,0,32,32,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,32,0,32,0,0,0,32,32,0,0,32,0,0,0,32,32,32,0,32,0,0,32,0,0,0,0,32,0,0,32,0,0,32,0,32,0,0,32,0,32,0,0,32,0,0,32,0,32,32,0,32,0,0,32,32,0,0,0,32,0,0,32,32,0,32,0,32,0,0,32,32,32,0,0,32,0,0,32,32,32,32,0,32,0,32,0,0,0,0,0,32,0,32,0,0,0,32,0,32,0,32,0,0,32,0,0,32,0,32,0,0,32,32,0,32,0,32,0,32,0,0,0,32,0,32,0,32,0,32,0,32,0,32,0,32,32,0,0,32,0,32,0,32,32,32,0,32,0,32,32,0,0,0,0,32,0,32,32,0,0,32,0,32,0,32,32,0,32,0,0,32,0,32,32,0,32,32,0,32,0,32,32,32,0,0,0,32,0,32,32,32,0,32,0,32,0,32,32,32,32,0,0,32,0,32,32,32,32,32,0,32,32,0,0,0,0,0,0,32,32,0,0,0,0,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+564472);
/* memory initializer */ allocate([0,32,32,0,0,0,32,0,0,32,32,0,0,0,32,32,0,32,32,0,0,32,0,0,0,32,32,0,0,32,0,32,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,32,0,32,32,0,32,0,0,0,0,32,32,0,32,0,0,32,0,32,32,0,32,0,32,0,0,32,32,0,32,0,32,32,0,32,32,0,32,32,0,0,0,32,32,0,32,32,0,32,0,32,32,0,32,32,32,0,0,32,32,0,32,32,32,32,0,32,32,32,0,0,0,0,0,32,32,32,0,0,0,32,0,32,32,32,0,0,32,0,0,32,32,32,0,0,32,32,0,32,32,32,0,32,0,0,0,32,32,32,0,32,0,32,0,32,32,32,0,32,32,0,0,32,32,32,0,32,32,32,0,32,32,32,32,0,0,0,0,32,32,32,32,0,0,32,0,32,32,32,32,0,32,0,0,32,32,32,32,0,32,32,0,32,32,32,32,32,0,0,0,32,32,32,32,32,0,32,0,32,32,32,32,32,32,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,32,32,0,0,0,0,0,32,0,32,0,0,0,0,0,32,32,32,0,0,0,0,32,0,0,32,0,0,0,0,32,0,32,32,0,0,0,0,32,32,0,32,0,0,0,0,32,32,32,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,32,32,0,0,0,32,0,32,0,32,0,0,0,32,0,32,32,32,0,0,0,32,32,0,0,32,0,0,0,32,32,0,32,32,0,0,0,32,32,32,0,32,0,0,0,32,32,32,32,32,0,0,32,0,0,0,0,32,0,0,32,0,0,0,32,32,0,0,32,0,0,32,0,32,0,0,32,0,0,32,32,32,0,0,32,0,32,0,0,32,0,0,32,0,32,0,32,32,0,0,32,0,32,32,0,32,0,0,32,0,32,32,32,32,0,0,32,32,0,0,0,32,0,0,32,32,0,0,32,32,0,0,32,32,0,32,0,32,0,0,32,32,0,32,32,32,0,0,32,32,32,0,0,32,0,0,32,32,32,0,32,32,0,0,32,32,32,32,0,32,0,0,32,32,32,32,32,32,0,32,0,0,0,0,0,32,0,32,0,0,0,0,32,32,0,32,0,0,0,32,0,32,0,32,0,0,0,32,32,32,0,32,0,0,32,0,0,32,0,32,0,0,32,0,32,32,0,32,0,0,32,32,0,32,0,32,0,0,32,32,32,32,0,32,0,32,0,0,0,32,0,32,0,32,0,0,32,32,0,32,0,32,0,32,0,32,0,32,0,32,0,32,32,32,0,32,0,32,32,0,0,32,0,32,0,32,32,0,32,32,0,32,0,32,32,32,0,32,0,32,0,32,32,32,32,32,0,32,32,0,0,0,0,32,0,32,32,0,0,0,32,32,0,32,32,0,0,32,0,32,0,32,32,0,0,32,32,32,0,32,32,0,32,0,0,32,0,32,32,0,32,0,32,32,0,32,32,0,32,32,0,32,0,32,32,0,32,32,32,32,0,32,32,32,0,0,0,32,0,32,32,32,0,0,32,32,0,32,32,32,0,32,0,32,0,32,32,32,0,32,32,32,0,32,32,32,32,0,0,32,0,32,32,32,32,0,32,32,0,32,32,32,32,32,0,32,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,32,32,0,0,0,0,0,32,32,32,0,0,0,0,32,0,32,32,0,0,0,0,32,32,32,32,0,0,0,32,0,0,32,32,0,0,0,32,0,32,32,32,0,0,0,32,32,0,32,32,0,0,0,32,32,32,32,32,0,0,32,0,0,0,32,32,0,0,32,0,0,32,32,32,0,0,32,0,32,0,32,32,0,0,32,0,32,32,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,32,32,32,0,0,32,32,32,0,32,32,0,0,32,32,32,32,32,32,0,32,0,0,0,0,32,32,0,32,0,0,0,32,32,32,0,32,0,0,32,0,32,32,0,32,0,0,32,32,32,32,0,32,0,32,0,0,32,32,0,32,0,32,0,32,32,32,0,32,0,32,32,0,32,32,0,32,0,32,32,32,32,32,0,32,32,0,0,0,32,32,0,32,32,0,0,32,32,32,0,32,32,0,32,0,32,32,0,32,32,0,32,32,32,32,0,32,32,32,0,0,32,32,0,32,32,32,0,32,32,32,0,32,32,32,32,0,32,32,0,32,32,32,32,32,32,32,32,0,0,0,0,0,32,32,32,0,0,0,0,32,32,32,32,0,0,0,32,0,32,32,32,0,0,0,32,32,32,32,32,0,0,32,0,0,32,32,32,0,0,32,0,32,32,32,32,0,0,32,32,0,32,32,32,0,0,32,32,32,32,32,32,0,32,0,0,0,32,32,32,0,32,0,0,32,32,32,32,0,32,0,32,0,32,32,32,0,32,0,32,32,32,32,32,0,32,32,0,0,32,32,32,0,32,32,0,32,32,32,32,0,32,32,32,0,32,32,32,0,32,32,32,32,32,32,32,32,0,0,0,0,32,32,32,32,0,0,0,32,32,32,32,32,0,0,32,0,32,32,32,32,0,0,32,32,32,32,32,32,0,32,0,0,32,32,32,32,0,32,0,32,32,32,32,32,0,32,32,0,32,32,32,32,0,32,32,32,32,32,32,32,32,0,0,0,32,32,32,32,32,0,0,32,32,32,32,32,32,0,32,0,32,32,32,32,32,0,32,32,32,32,32,32,32,32,0,0,32,32,32,32,32,32,0,32,32,32,32,32,32,32,32,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,64,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,64,0,0,0,0,0,64,64,0,0,0,0,0,0,64,64,64,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,64,0,0,0,0,64,0,64,0,0,0,0,0,64,0,64,64,0,0,0,0,64,64,0,0,0,0,0,0,64,64,0,64,0,0,0,0,64,64,64,0,0,0,0,0,64,64,64,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,64,0,0,0,0,64,0,0,64,64,0,0,0,64,0,64,0,0,0,0,0,64,0,64,0,64,0,0,0,64,0,64,64,0,0,0,0,64,0,64,64,64,0,0,0,64,64,0,0,0,0,0,0,64,64,0,0,64,0,0,0,64,64,0,64,0,0,0,0,64,64,0,64,64,0,0,0,64,64,64,0,0,0,0,0,64,64,64,0,64,0,0,0,64,64,64,64,0,0,0,0,64,64,64,64,64,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,64,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,64,0,0,64,0,0,64,0,0,0,0,64,0,0,64,0,64,0,0,64,0,0,64,64,0,0,0,64,0,0,64,64,64,0,0,64,0,64,0,0,0,0,0,64,0,64,0,0,64,0,0,64,0,64,0,64,0,0,0,64,0,64,0,64,64,0,0,64,0,64,64,0,0,0,0,64,0,64,64,0,64,0,0,64,0,64,64,64,0,0,0,64,0,64,64,64,64,0,0,64,64,0,0,0,0,0,0,64,64,0,0,0,64,0,0,64,64,0,0,64,0,0,0,64,64,0,0,64,64,0,0,64,64,0,64,0,0,0,0,64,64,0,64,0,64,0,0,64,64,0,64,64,0,0,0,64,64,0,64,64,64,0,0,64,64,64,0,0,0,0,0,64,64,64,0,0,64,0,0,64,64,64,0,64,0,0,0,64,64,64,0,64,64,0,0,64,64,64,64,0,0,0,0,64,64,64,64,0,64,0,0,64,64,64,64,64,0,0,0,64,64,64,64,64,64,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,64,0,64,0,0,0,0,64,0,0,64,0,0,0,0,64,64,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,64,0,64,0,0,0,64,64,0,0,64,0,0,0,64,64,64,0,64,0,0,64,0,0,0,0,64,0,0,64,0,0,64,0,64,0,0,64,0,64,0,0,64,0,0,64,0,64,64,0,64,0,0,64,64,0,0,0,64,0,0,64,64,0,64,0,64,0,0,64,64,64,0,0,64,0,0,64,64,64,64,0,64,0,64,0,0,0,0,0,64,0,64,0,0,0,64,0,64,0,64,0,0,64,0,0,64,0,64,0,0,64,64,0,64,0,64,0,64,0,0,0,64,0,64,0,64,0,64,0,64,0,64,0,64,64,0,0,64,0,64,0,64,64,64,0,64,0,64,64,0,0,0,0,64,0,64,64,0,0,64,0,64,0,64,64,0,64,0,0,64,0,64,64,0,64,64,0,64,0,64,64,64,0,0,0,64,0,64,64,64,0,64,0,64,0,64,64,64,64,0,0,64,0,64,64,64,64,64,0,64,64,0,0,0,0,0,0,64,64,0,0,0,0,64,0,64,64,0,0,0,64,0,0,64,64,0,0,0,64,64,0,64,64,0,0,64,0,0,0,64,64,0,0,64,0,64,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,64,0,64,64,0,64,0,0,0,0,64,64,0,64,0,0,64,0,64,64,0,64,0,64,0,0,64,64,0,64,0,64,64,0,64,64,0,64,64,0,0,0,64,64,0,64,64,0,64,0,64,64,0,64,64,64,0,0,64,64,0,64,64,64,64,0,64,64,64,0,0,0,0,0,64,64,64,0,0,0,64,0,64,64,64,0,0,64,0,0,64,64,64,0,0,64,64,0,64,64,64,0,64,0,0,0,64,64,64,0,64,0,64,0,64,64,64,0,64,64,0,0,64,64,64,0,64,64,64,0,64,64,64,64,0,0,0,0,64,64,64,64,0,0,64,0,64,64,64,64,0,64,0,0,64,64,64,64,0,64,64,0,64,64,64,64,64,0,0,0,64,64,64,64,64,0,64,0,64,64,64,64,64,64,0,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,64,64,0,0,0,0,0,64,0,64,0,0,0,0,0,64,64,64,0,0,0,0,64,0,0,64,0,0,0,0,64,0,64,64,0,0,0,0,64,64,0,64,0,0,0,0,64,64,64,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,64,64,0,0,0,64,0,64,0,64,0,0,0,64,0,64,64,64,0,0,0,64,64,0,0,64,0,0,0,64,64,0,64,64,0,0,0,64,64,64,0,64,0,0,0,64,64,64,64,64,0,0,64,0,0,0,0,64,0,0,64,0,0,0,64,64,0,0,64,0,0,64,0,64,0,0,64,0,0,64,64,64,0,0,64,0,64,0,0,64,0,0,64,0,64,0,64,64,0,0,64,0,64,64,0,64,0,0,64,0,64,64,64,64,0,0,64,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,64,64,0,64,0,64,0,0,64,64,0,64,64,64,0,0,64,64,64,0,0,64,0,0,64,64,64,0,64,64,0,0,64,64,64,64,0,64,0,0,64,64,64,64,64,64,0,64,0,0,0,0,0,64,0,64,0,0,0,0,64,64,0,64,0,0,0,64,0,64,0,64,0,0,0,64,64,64,0,64,0,0,64,0,0,64,0,64,0,0,64,0,64,64,0,64,0,0,64,64,0,64,0,64,0,0,64,64,64,64,0,64,0,64,0,0,0,64,0,64,0,64,0,0,64,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,64,64,0,64,0,64,64,0,0,64,0,64,0,64,64,0,64,64,0,64,0,64,64,64,0,64,0,64,0,64,64,64,64,64,0,64,64,0,0,0,0,64,0,64,64,0,0,0,64,64,0,64,64,0,0,64,0,64,0,64,64,0,0,64,64,64,0,64,64,0,64,0,0,64,0,64,64,0,64,0,64,64,0,64,64,0,64,64,0,64,0,64,64,0,64,64,64,64,0,64,64,64,0,0,0,64,0,64,64,64,0,0,64,64,0,64,64,64,0,64,0,64,0,64,64,64,0,64,64,64,0,64,64,64,64,0,0,64,0,64,64,64,64,0,64,64,0,64,64,64,64,64,0,64,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,64,64,0,0,0,0,0,64,64,64,0,0,0,0,64,0,64,64,0,0,0,0,64,64,64,64,0,0,0,64,0,0,64,64,0,0,0,64,0,64,64,64,0,0,0,64,64,0,64,64,0,0,0,64,64,64,64,64,0,0,64,0,0,0,64,64,0,0,64,0,0,64,64,64,0,0,64,0,64,0,64,64,0,0,64,0,64,64,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,64,64,64,0,0,64,64,64,0,64,64,0,0,64,64,64,64,64,64,0,64,0,0,0,0,64,64,0,64,0,0,0,64,64,64,0,64,0,0,64,0,64,64,0,64,0,0,64,64,64,64,0,64,0,64,0,0,64,64,0,64,0,64,0,64,64,64,0,64,0,64,64,0,64,64,0,64,0,64,64,64,64,64,0,64,64,0,0,0,64,64,0,64,64,0,0,64,64,64,0,64,64,0,64,0,64,64,0,64,64,0,64,64,64,64,0,64,64,64,0,0,64,64,0,64,64,64,0,64,64,64,0,64,64,64,64,0,64,64,0,64,64,64,64,64,64,64,64,0,0,0,0,0,64,64,64,0,0,0,0,64,64,64,64,0,0,0,64,0,64,64,64,0,0,0,64,64,64,64,64,0,0,64,0,0,64,64,64,0,0,64,0,64,64,64,64,0,0,64,64,0,64,64,64,0,0,64,64,64,64,64,64,0,64,0,0,0,64,64,64,0,64,0,0,64,64,64,64,0,64,0,64,0,64,64,64,0,64,0,64,64,64,64,64,0,64,64,0,0,64,64,64,0,64,64,0,64,64,64,64,0,64,64,64,0,64,64,64,0,64,64,64,64,64,64,64,64,0,0,0,0,64,64,64,64,0,0,0,64,64,64,64,64,0,0,64,0,64,64,64,64,0,0,64,64,64,64,64,64,0,64,0,0,64,64,64,64,0,64,0,64,64,64,64,64,0,64,64,0,64,64,64,64,0,64,64,64,64,64,64,64,64,0,0,0,64,64,64,64,64,0,0,64,64,64,64,64,64,0,64,0,64,64,64,64,64,0,64,64,64,64,64,64,64,64,0,0,64,64,64,64,64,64,0,64,64,64,64,64,64,64,64,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,128,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,128,0,0,0,0,0,128,128,0,0,0,0,0,0,128,128,128,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,128,0,0,0,0,128,0,128,0,0,0,0,0,128,0,128,128,0,0,0,0,128,128,0,0,0,0,0,0,128,128,0,128,0,0,0,0,128,128,128,0,0,0,0,0,128,128,128,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,128,0,0,0,0,128,0,0,128,128,0,0,0,128,0,128,0,0,0,0,0,128,0,128,0,128,0,0,0,128,0,128,128,0,0,0,0,128,0,128,128,128,0,0,0,128,128,0,0,0,0,0,0,128,128,0,0,128,0,0,0,128,128,0,128,0,0,0,0,128,128,0,128,128,0,0,0,128,128,128,0,0,0,0,0,128,128,128,0,128,0,0,0,128,128,128,128,0,0,0,0,128,128,128,128,128,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,128,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,128,0,0,128,0,0,128,0,0,0,0,128,0,0,128,0,128,0,0,128,0,0,128,128,0,0,0,128,0,0,128,128,128,0,0,128,0,128,0,0,0,0,0,128,0,128,0,0,128,0,0,128,0,128,0,128,0,0,0,128,0,128,0,128,128,0,0,128,0,128,128,0,0,0,0,128,0,128,128,0,128,0,0,128,0,128,128,128,0,0,0,128,0,128,128,128,128,0,0,128,128,0,0,0,0,0,0,128,128,0,0,0,128,0,0,128,128,0,0,128,0,0,0,128,128,0,0,128,128,0,0,128,128,0,128,0,0,0,0,128,128,0,128,0,128,0,0,128,128,0,128,128,0,0,0,128,128,0,128,128,128,0,0,128,128,128,0,0,0,0,0,128,128,128,0,0,128,0,0,128,128,128,0,128,0,0,0,128,128,128,0,128,128,0,0,128,128,128,128,0,0,0,0,128,128,128,128,0,128,0,0,128,128,128,128,128,0,0,0,128,128,128,128,128,128,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,128,0,128,0,0,0,0,128,0,0,128,0,0,0,0,128,128,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,128,0,128,0,0,0,128,128,0,0,128,0,0,0,128,128,128,0,128,0,0,128,0,0,0,0,128,0,0,128,0,0,128,0,128,0,0,128,0,128,0,0,128,0,0,128,0,128,128,0,128,0,0,128,128,0,0,0,128,0,0,128,128,0,128,0,128,0,0,128,128,128,0,0,128,0,0,128,128,128,128,0,128,0,128,0,0,0,0,0,128,0,128,0,0,0,128,0,128,0,128,0,0,128,0,0,128,0,128,0,0,128,128,0,128,0,128,0,128,0,0,0,128,0,128,0,128,0,128,0,128,0,128,0,128,128,0,0,128,0,128,0,128,128,128,0,128,0,128,128,0,0,0,0,128,0,128,128,0,0,128,0,128,0,128,128,0,128,0,0,128,0,128,128,0,128,128,0,128,0,128,128,128,0,0,0,128,0,128,128,128,0,128,0,128,0,128,128,128,128,0,0,128,0,128,128,128,128,128,0,128,128,0,0,0,0,0,0,128,128,0,0,0,0,128,0,128,128,0,0,0,128,0,0,128,128,0,0,0,128,128,0,128,128,0,0,128,0,0,0,128,128,0,0,128,0,128,0,128,128,0,0,128,128,0,0,128,128,0,0,128,128,128,0,128,128,0,128,0,0,0,0,128,128,0,128,0,0,128,0,128,128,0,128,0,128,0,0,128,128,0,128,0,128,128,0,128,128,0,128,128,0,0,0,128,128,0,128,128,0,128,0,128,128,0,128,128,128,0,0,128,128,0,128,128,128,128,0,128,128,128,0,0,0,0,0,128,128,128,0,0,0,128,0,128,128,128,0,0,128,0,0,128,128,128,0,0,128,128,0,128,128,128,0,128,0,0,0,128,128,128,0,128,0,128,0,128,128,128,0,128,128,0,0,128,128,128,0,128,128,128,0,128,128,128,128,0,0,0,0,128,128,128,128,0,0,128,0,128,128,128,128,0,128,0,0,128,128,128,128,0,128,128,0,128,128,128,128,128,0,0,0,128,128,128,128,128,0,128,0,128,128,128,128,128,128,0,0,128,128,128,128,128,128,128,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,128,128,0,0,0,0,0,128,0,128,0,0,0,0,0,128,128,128,0,0,0,0,128,0,0,128,0,0,0,0,128,0,128,128,0,0,0,0,128,128,0,128,0,0,0,0,128,128,128,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,128,128,0,0,0,128,0,128,0,128,0,0,0,128,0,128,128,128,0,0,0,128,128,0,0,128,0,0,0,128,128,0,128,128,0,0,0,128,128,128,0,128,0,0,0,128,128,128,128,128,0,0,128,0,0,0,0,128,0,0,128,0,0,0,128,128,0,0,128,0,0,128,0,128,0,0,128,0,0,128,128,128,0,0,128,0,128,0,0,128,0,0,128,0,128,0,128,128,0,0,128,0,128,128,0,128,0,0,128,0,128,128,128,128,0,0,128,128,0,0,0,128,0,0,128,128,0,0,128,128,0,0,128,128,0,128,0,128,0,0,128,128,0,128,128,128,0,0,128,128,128,0,0,128,0,0,128,128,128,0,128,128,0,0,128,128,128,128,0,128,0,0,128,128,128,128,128,128,0,128,0,0,0,0,0,128,0,128,0,0,0,0,128,128,0,128,0,0,0,128,0,128,0,128,0,0,0,128,128,128,0,128,0,0,128,0,0,128,0,128,0,0,128,0,128,128,0,128,0,0,128,128,0,128,0,128,0,0,128,128,128,128,0,128,0,128,0,0,0,128,0,128,0,128,0,0,128,128,0,128,0,128,0,128,0,128,0,128,0,128,0,128,128,128,0,128,0,128,128,0,0,128,0,128,0,128,128,0,128,128,0,128,0,128,128,128,0,128,0,128,0,128,128,128,128,128,0,128,128,0,0,0,0,128,0,128,128,0,0,0,128,128,0,128,128,0,0,128,0,128,0,128,128,0,0,128,128,128,0,128,128,0,128,0,0,128,0,128,128,0,128,0,128,128,0,128,128,0,128,128,0,128,0,128,128,0,128,128,128,128,0,128,128,128,0,0,0,128,0,128,128,128,0,0,128,128,0,128,128,128,0,128,0,128,0,128,128,128,0,128,128,128,0,128,128,128,128,0,0,128,0,128,128,128,128,0,128,128,0,128,128,128,128,128,0,128,0,128,128,128,128,128,128,128,128,0,0,0,0,0,0,128,128,0,0,0,0,0,128,128,128,0,0,0,0,128,0,128,128,0,0,0,0,128,128,128,128,0,0,0,128,0,0,128,128,0,0,0,128,0,128,128,128,0,0,0,128,128,0,128,128,0,0,0,128,128,128,128,128,0,0,128,0,0,0,128,128,0,0,128,0,0,128,128,128,0,0,128,0,128,0,128,128,0,0,128,0,128,128,128,128,0,0,128,128,0,0,128,128,0,0,128,128,0,128,128,128,0,0,128,128,128,0,128,128,0,0,128,128,128,128,128,128,0,128,0,0,0,0,128,128,0,128,0,0,0,128,128,128,0,128,0,0,128,0,128,128,0,128,0,0,128,128,128,128,0,128,0,128,0,0,128,128,0,128,0,128,0,128,128,128,0,128,0,128,128,0,128,128,0,128,0,128,128,128,128,128,0,128,128,0,0,0,128,128,0,128,128,0,0,128,128,128,0,128,128,0,128,0,128,128,0,128,128,0,128,128,128,128,0,128,128,128,0,0,128,128,0,128,128,128,0,128,128,128,0,128,128,128,128,0,128,128,0,128,128,128,128,128,128,128,128,0,0,0,0,0,128,128,128,0,0,0,0,128,128,128,128,0,0,0,128,0,128,128,128,0,0,0,128,128,128,128,128,0,0,128,0,0,128,128,128,0,0,128,0,128,128,128,128,0,0,128,128,0,128,128,128,0,0,128,128,128,128,128,128,0,128,0,0,0,128,128,128,0,128,0,0,128,128,128,128,0,128,0,128,0,128,128,128,0,128,0,128,128,128,128,128,0,128,128,0,0,128,128,128,0,128,128,0,128,128,128,128,0,128,128,128,0,128,128,128,0,128,128,128,128,128,128,128,128,0,0,0,0,128,128,128,128,0,0,0,128,128,128,128,128,0,0,128,0,128,128,128,128,0,0,128,128,128,128,128,128,0,128,0,0,128,128,128,128,0,128,0,128,128,128,128,128,0,128,128,0,128,128,128,128,0,128,128,128,128,128,128,128,128,0,0,0,128,128,128,128,128,0,0,128,128,128,128,128,128,0,128,0,128,128,128,128,128,0,128,128,128,128,128,128,128,128,0,0,128,128,128,128,128,128,0,128,128,128,128,128,128,128,128,0,128,128,128,128,128,128,128,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+574712);
/* memory initializer */ allocate([8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,176,141,35,0,108,0,0,0,48,115,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,2,0,0,0,8,0,0,0,1,0,0,0,10,0,0,0,1,0,0,0,12,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,11,0,0,0,16,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,24,0,0,0,11,0,0,0,20,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,80,0,0,0,33,0,0,0,18,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,64,0,0,0,33,0,0,0,160,0,0,0,99,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,9,0,0,0,1,0,0,0,11,0,0,0,2,0,0,0,11,0,0,0,4,0,0,0,11,0,0,0,8,0,0,0,45,0,0,0,16,0,0,0,2,0,0,0,24,0,0,0,27,0,0,0,32,0,0,0,9,0,0,0,33,0,0,0,255,255,255,255,0,0,0,0,9,0,0,0,1,0,0,0,11,0,0,0,2,0,0,0,11,0,0,0,4,0,0,0,11,0,0,0,8,0,0,0,62,0,0,0,12,0,0,0,46,0,0,0,15,0,0,0,46,0,0,0,16,0,0,0,3,0,0,0,24,0,0,0,30,0,0,0,32,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,154,153,153,62,205,204,12,63,51,51,51,63,205,204,76,63,102,102,102,63,0,0,128,63,154,153,153,63,60,0,0,0,0,0,185,9,60,0,0,0,0,0,97,20,1,0,27,24,0,0,113,15,0,0,124,40,1,0,141,36,255,255,139,34,1,0,180,36,0,0,162,22,255,255,64,42,2,0,86,45,254,255,40,47,0,0,168,33,1,0,138,47,0,0,104,56,0,0,107,30,255,255,153,53,0,0,29,71,0,0,135,56,0,0,191,61,1,0,171,59,0,0,168,52,255,255,199,71,255,255,0,0,1,0,186,43,255,255,210,50,1,0,148,73,254,255,130,79,1,0,105,63,255,255,0,0,60,0,0,0,0,0,98,47,0,0,73,52,1,0,170,69,1,0,139,81,0,0,236,85,1,0,0,0,1,0,101,71,255,255,73,83,1,0,170,53,255,255,150,74,255,255,163,79,255,255,0,0,0,0,16,82,60,0,0,0,254,255,23,89,0,0,28,62,1,0,0,0,0,0,69,70,255,255,243,86,1,0,75,95,1,0,98,90,0,0,140,93,1,0,213,89,2,0,76,88,255,255,86,101,0,0,134,102,1,0,233,98,0,0,55,103,0,0,253,93,0,0,111,106,60,0,0,0,255,255,228,99,1,0,110,93,1,0,74,101,2,0,40,103,255,255,105,74,1,0,221,106,255,255,218,95,60,0,0,0,255,255,5,98,0,0,133,111,1,0,0,0,0,0,9,89,255,255,59,100,0,0,193,114,0,0,68,118,0,0,86,102,1,0,249,87,255,255,247,112,0,0,248,106,1,0,210,117,255,255,0,0,0,0,173,94,255,255,110,117,0,0,3,85,1,0,197,120,60,0,0,0,0,0,52,122,0,0,249,114,1,0,197,104,1,0,239,111,0,0,95,122,2,0,79,120,1,0,157,122,0,0,66,126,1,0,16,124,254,255,86,124,0,0,56,105,255,255,204,121,1,0,155,120,0,0,225,108,255,255,221,118,1,0,74,121,0,0,0,0,0,0,168,124,1,0,123,123,0,0,77,123,0,0,213,99,0,0,125,122,60,0,0,0,1,0,96,115,1,0,57,113,255,255,104,105,255,255,99,123,2,0,116,120,254,255,157,121,0,0,35,118,255,255,22,120,255,255,90,125,60,0,0,0,2,0,182,120,60,0,0,0,0,0,75,117,0,0,114,113,60,0,0,0,0,0,12,124,0,0,233,95,0,0,36,100,254,255,37,119,60,0,0,0,255,255,177,115,0,0,185,119,60,0,0,0,0,0,90,114,2,0,207,118,0,0,88,107,0,0,237,121,255,255,243,109,0,0,136,119,1,0,164,123,2,0,140,113,60,0,0,0,1,0,155,111,1,0,58,112,1,0,190,122,0,0,97,110,0,0,221,96,60,0,0,0,0,0,0,0,60,0,0,0,0,0,89,86,0,0,204,108,60,0,0,0,60,0,0,0,255,255,150,94,0,0,66,96,0,0,9,91,60,0,0,0,60,0,0,0,1,0,99,89,0,0,97,84,60,0,0,0,2,0,50,100,60,0,0,0,254,255,21,122,254,255,56,98,0,0,78,70,98,57,254,44,244,4,54,245,216,233,90,29,220,255,8,245,31,244,215,18,136,11,23,223,201,14,175,5,131,8,66,222,115,31,200,247,81,250,9,3,84,4,174,246,206,8,148,254,93,253,200,247,158,23,206,233,48,4,51,12,61,236,192,20,230,246,111,241,12,27,206,240,163,2,16,249,29,0,161,39,66,118,247,14,59,240,156,11,231,251,21,252,173,9,28,244,255,10,72,247,217,6,180,249,178,6,16,249,7,6,15,252,173,1,86,255,216,1,15,251,128,8,109,245,219,9,170,249,88,1,58,3,6,250,188,6,134,249,165,6,240,247,84,10,11,244,81,11,69,248,45,2,12,3,166,250,74,3,143,2,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,229,28,0,108,0,0,0,208,120,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,220,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,220,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,100,33,0,108,0,0,0,144,127,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,53,33,0,0,12,33,0,51,115,174,103,80,93,251,83,149,75,6,68,57,61,26,55,151,49,161,44,0,64,0,32,0,16,0,8,0,4,0,2,0,1,128,0,64,0,32,0,72,220,30,0,32,110,140,0,4,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,168,190,30,0,32,110,140,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,187,0,0,0,119,1,0,68,172,0,0,0,125,0,0,0,1,0,2,3,3,4,4,5,6,7,8,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,7,0,0,0,3,1,0,0,7,1,0,0,3,6,0,0,7,6,0,0,15,6,0,0,55,6,0,0,63,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,20,24,0,0,0,0,8,0,0,0,0,8,0,0,0,0,8,32,0,0,0,8,0,0,0,1,8,16,0,0,0,8,0,0,0,2,8,1,0,0,0,8,0,0,0,16,8,2,0,0,0,6,0,0,0,6,32,0,0,6,0,0,1,6,16,0,0,6,0,0,2,6,0,16,0,6,0,32,0,6,0,2,0,6,0,1,0,6,1,0,0,6,0,0,32,6,2,0,0,6,0,0,16,6,16,0,32,6,1,0,2,6,32,0,16,6,2,0,1,6,32,16,0,6,0,18,0,6,0,2,1,6,2,1,0,6,0,33,0,6,0,1,2,6,0,32,16,6,0,0,33,6,0,0,18,6,0,1,32,6,18,0,0,6,0,16,32,6,1,32,0,6,2,16,0,6,16,32,0,6,1,2,0,6,33,0,0,6,0,2,16,6,32,1,0,6,0,34,0,6,16,2,0,6,0,16,2,6,17,0,0,6,0,17,0,6,34,0,0,6,32,0,2,6,16,0,1,6,0,32,1,6,2,32,0,6,1,16,0,6,1,0,32,6,0,32,2,6,1,32,2,6,16,1,0,6,2,0,16,6,0,16,1,6,16,1,32,6,32,2,16,6,0,0,34,6,16,0,2,6,0,2,32,6,32,2,0,6,0,0,17,6,2,16,1,6,0,1,16,6,0,2,17,4,1,2,4,2,1,4,1,0,4,16,32,4,32,16,4,32,0,4,17,0,4,2,0,4,18,0,4,0,33,4,34,0,4,0,18,4,33,0,4,2,17,4,0,1,4,16,2,4,2,32,4,32,17,4,1,16,4,33,16,4,16,0,4,16,34,4,32,32,4,0,34,4,1,34,4,32,1,4,2,2,4,0,32,4,0,16,4,0,17,4,34,1,4,17,32,4,18,1,4,18,32,4,17,2,4,16,16,4,1,1,4,2,33,4,32,18,4,1,18,4,34,17,4,33,18,4,34,16,4,33,2,4,32,2,4,16,1,4,0,2,4,16,33,4,1,32,4,17,34,4,18,33,4,34,32,4,2,16,4,2,34,4,17,16,4,34,2,4,32,33,4,1,17,4,17,1,4,16,18,4,2,18,4,32,34,4,33,32,4,1,33,4,18,2,4,33,17,4,18,34,4,18,16,4,34,33,4,16,17,4,33,1,4,17,18,4,18,17,4,102,102,4,34,34,4,17,33,4,17,17,4,33,34,4,0,0,4,34,18,4,18,18,4,33,33,4,66,0,4,0,4,4,64,0,4,48,0,4,49,0,4,0,3,4,0,20,4,0,19,4,1,36,4,32,19,4,1,66,4,20,32,4,66,2,4,19,0,4,0,36,4,49,32,4,34,19,4,17,36,4,18,102,4,48,1,4,2,19,4,18,66,4,64,16,4,64,2,4,1,4,4,36,0,4,66,16,4,33,19,4,19,18,4,49,33,4,33,36,4,0,64,4,16,36,4,16,66,4,50,1,4,17,66,4,32,49,4,18,64,2,0,2,16,2,32,2,48,2,64,2,80,2,96,2,112,2,1,2,17,2,33,2,49,2,65,2,81,2,97,2,113,2,2,2,18,2,34,2,50,2,66,2,82,2,98,2,114,2,3,2,19,2,35,2,51,2,67,2,83,2,99,2,115,2,4,2,20,2,36,2,52,2,68,2,84,2,100,2,116,2,5,2,21,2,37,2,53,2,69,2,85,2,101,2,117,2,6,2,22,2,38,2,54,2,70,2,86,2,102,2,118,2,7,2,23,2,39,2,55,2,71,2,87,2,103,2,119,0,0,0,0,0,0,0,6,0,0,0,6,0,0,0,6,0,0,1,6,0,0,16,6,0,0,17,6,0,1,0,6,0,1,1,6,0,1,16,6,0,1,17,6,0,16,0,6,0,16,1,6,0,16,16,6,0,16,17,6,0,17,0,6,0,17,1,6,0,17,16,6,0,17,17,6,1,0,0,6,1,0,1,6,1,0,16,6,1,0,17,6,1,1,0,6,1,1,1,6,1,1,16,6,1,1,17,6,1,16,0,6,1,16,1,6,1,16,16,6,1,16,17,6,1,17,0,6,1,17,1,6,1,17,16,6,1,17,17,6,16,0,0,6,16,0,1,6,16,0,16,6,16,0,17,6,16,1,0,6,16,1,1,6,16,1,16,6,16,1,17,6,16,16,0,6,16,16,1,6,16,16,16,6,16,16,17,6,16,17,0,6,16,17,1,6,16,17,16,6,16,17,17,6,17,0,0,6,17,0,1,6,17,0,16,6,17,0,17,6,17,1,0,6,17,1,1,6,17,1,16,6,17,1,17,6,17,16,0,6,17,16,1,6,17,16,16,6,17,16,17,6,17,17,0,6,17,17,1,6,17,17,16,4,0,0,4,0,1,4,0,2,4,0,3,4,0,16,4,0,17,4,0,18,4,0,19,4,0,32,4,0,33,4,0,34,4,0,35,4,0,48,4,0,49,4,0,50,4,0,51,4,1,0,4,1,1,4,1,2,4,1,3,4,1,16,4,1,17,4,1,18,4,1,19,4,1,32,4,1,33,4,1,34,4,1,35,4,1,48,4,1,49,4,1,50,4,1,51,4,2,0,4,2,1,4,2,2,4,2,3,4,2,16,4,2,17,4,2,18,4,2,19,4,2,32,4,2,33,4,2,34,4,2,35,4,2,48,4,2,49,4,2,50,4,2,51,4,3,0,4,3,1,4,3,2,4,3,3,4,3,16,4,3,17,4,3,18,4,3,19,4,3,32,4,3,33,4,3,34,4,3,35,4,3,48,4,3,49,4,3,50,4,3,51,4,16,0,4,16,1,4,16,2,4,16,3,4,16,16,4,16,17,4,16,18,4,16,19,4,16,32,4,16,33,4,16,34,4,16,35,4,16,48,4,16,49,4,16,50,4,16,51,4,17,0,4,17,1,4,17,2,4,17,3,4,17,16,4,17,17,4,17,18,4,17,19,4,17,32,4,17,33,4,17,34,4,17,35,4,17,48,4,17,49,4,17,50,4,17,51,4,18,0,4,18,1,4,18,2,4,18,3,4,18,16,4,18,17,4,18,18,4,18,19,4,18,32,4,18,33,4,18,34,4,18,35,4,18,48,4,18,49,4,18,50,4,18,51,4,19,0,4,19,1,4,19,2,4,19,3,4,19,16,4,19,17,4,19,18,4,19,19,4,19,32,4,19,33,4,19,34,4,19,35,4,19,48,4,19,49,4,19,50,4,19,51,2,0,2,16,2,32,2,48,2,64,2,80,2,96,2,112,2,1,2,17,2,33,2,49,2,65,2,81,2,97,2,113,2,2,2,18,2,34,2,50,2,66,2,82,2,98,2,114,2,3,2,19,2,35,2,51,2,67,2,83,2,99,2,115,2,4,2,20,2,36,2,52,2,68,2,84,2,100,2,116,2,5,2,21,2,37,2,53,2,69,2,85,2,101,2,117,2,6,2,22,2,38,2,54,2,70,2,86,2,102,2,118,2,7,2,23,2,39,2,55,2,71,2,87,2,103,2,119,8,0,0,0,0,8,0,0,0,0,8,16,0,0,0,8,1,0,0,0,8,0,16,0,0,8,0,1,0,0,8,0,0,16,0,8,0,0,1,0,8,0,0,0,16,8,0,0,0,1,6,0,0,0,6,16,0,0,6,1,0,0,6,0,16,0,6,0,1,0,6,0,0,1,6,0,0,16,6,0,0,2,6,0,0,32,6,32,16,0,6,0,2,1,6,0,32,16,6,2,1,0,6,17,0,0,6,0,32,0,6,0,2,0,6,32,0,0,6,1,16,0,6,2,0,0,6,1,0,2,6,16,0,32,6,0,1,2,6,16,1,0,6,0,16,32,6,16,16,0,6,16,0,1,6,32,0,16,6,2,0,1,6,1,1,0,6,1,0,16,6,0,17,0,6,16,0,2,6,0,1,16,6,0,0,17,6,16,0,16,6,1,0,1,6,0,0,34,6,2,1,1,6,16,32,16,6,1,2,1,6,32,16,16,6,1,0,32,6,0,16,1,6,33,16,0,6,16,2,1,6,18,1,0,6,1,32,16,6,1,2,0,6,16,32,0,6,0,16,2,6,0,1,32,6,0,2,33,6,0,2,32,6,0,0,18,6,0,0,33,6,32,17,0,6,0,1,1,6,17,16,0,6,0,32,18,6,0,32,17,6,32,16,2,6,2,1,32,6,0,34,17,6,0,16,16,6,2,17,0,6,0,33,16,6,0,2,3,6,32,16,1,6,0,18,1,4,17,0,4,0,34,4,32,0,4,1,16,4,2,32,4,0,32,4,2,0,4,16,1,4,0,17,4,2,1,4,2,33,4,0,2,4,32,2,4,1,1,4,16,16,4,16,2,4,34,0,4,16,0,4,1,0,4,33,0,4,18,0,4,0,16,4,32,18,4,1,17,4,0,1,4,1,2,4,17,2,4,17,1,4,16,32,4,32,1,4,34,17,4,0,18,4,32,16,4,34,1,4,1,32,4,0,33,4,16,17,4,33,16,4,16,34,4,2,3,4,18,1,4,32,17,4,17,16,4,32,48,4,17,32,4,2,16,4,34,16,4,17,17,4,48,32,4,48,0,4,1,34,4,1,18,4,2,17,4,3,2,4,3,0,4,16,33,4,18,32,4,0,0,4,18,33,4,33,17,4,2,34,4,16,18,4,49,0,4,32,32,4,0,3,4,2,2,4,34,32,4,1,33,4,33,2,4,33,18,4,17,34,4,0,48,4,18,17,4,32,34,4,49,32,4,33,48,4,34,2,4,34,34,4,32,49,4,19,2,4,3,16,4,17,18,4,0,19,4,33,1,4,18,3,4,19,0,4,19,16,4,2,19,4,48,1,4,18,16,4,34,19,4,3,18,4,49,1,4,48,34,4,0,49,4,1,49,4,2,35,4,1,48,4,17,33,4,34,33,4,1,19,4,16,3,4,34,3,4,48,33,4,33,49,4,51,0,4,19,18,4,17,49,4,48,2,4,18,2,4,17,19,4,18,34,4,32,50,4,16,19,4,34,49,4,33,32,4,1,51,4,51,16,4,32,19,4,49,34,4,19,48,4,1,3,4,17,51,4,32,33,4,19,49,4,3,34,4,49,2,4,0,36,2,0,2,16,2,32,2,48,2,64,2,80,2,96,2,1,2,17,2,33,2,49,2,65,2,81,2,97,2,2,2,18,2,34,2,50,2,66,2,82,2,98,2,3,2,19,2,35,2,51,2,67,2,83,2,99,2,4,2,20,2,36,2,52,2,68,2,84,2,100,2,5,2,21,2,37,2,53,2,69,2,85,2,101,2,6,2,22,2,38,2,54,2,70,2,86,2,102,255,0,1,0,0,0,0,0,2,2,2,1,2,2,2,2,2,1,2,2,0,0,0,0,2,2,2,1,2,2,2,2,1,2,2,2,0,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,109,29,155,5,66,213,68,230,128,226,20,29,175,247,87,178,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,232,253,28,0,96,175,28,0,1,128,9,128,25,128,49,128,81,128,121,128,169,128,225,128,33,129,105,129,185,129,17,130,113,130,217,130,73,131,193,131,65,132,201,132,89,133,241,133,145,134,57,135,233,135,161,136,97,137,41,138,249,138,209,139,177,140,153,141,137,142,129,143,129,144,137,145,153,146,177,147,209,148,249,149,41,151,97,152,161,153,233,154,57,156,145,157,241,158,89,160,201,161,65,163,193,164,73,166,217,167,113,169,17,171,185,172,105,174,33,176,225,177,169,179,121,181,81,183,49,185,25,187,9,189,1,191,1,193,9,195,25,197,49,199,81,201,121,203,169,205,225,207,33,210,105,212,185,214,17,217,113,219,217,221,73,224,193,226,65,229,201,231,89,234,241,236,145,239,57,242,233,244,161,247,97,250,41,253,249,255,209,2,177,5,153,8,137,11,129,14,129,17,137,20,153,23,177,26,209,29,249,32,41,36,97,39,161,42,233,45,57,49,145,52,241,55,89,59,201,62,65,66,193,69,73,73,217,76,113,80,17,84,185,87,105,91,33,95,225,98,169,102,121,106,81,110,49,114,25,118,9,122,1,126,204,4,227,5,225,4,19,4,240,4,12,3,249,3,9,3,251,3,6,3,252,3,3,3,253,2,3,2,254,2,3,2,255,2,2,2,255,2,2,2,198,3,214,4,210,4,37,5,220,4,29,4,227,4,25,4,233,4,20,4,239,4,16,4,244,4,12,3,246,4,7,3,252,4,3,3,255,3,1,3,197,3,211,5,206,4,38,4,217,4,32,4,226,4,25,3,233,3,20,3,236,3,16,3,243,3,10,3,249,3,3,3,0,3,255,3,2,3,255,2,56,37,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,90,34,0,0,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,37,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,1,0,0,0,0,0,0,0,0,0,0,90,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,15,31,0,108,0,0,0,48,13,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,1,2,0,3,1,2,1,3,1,2,2,3,1,0,2,3,1,0,0,2,1,0,1,2,1,1,2,3,0,1,2,3,0,1,0,2,1,1,0,2,0,1,1,2,0,0,1,2,0,0,0,1,1,1,1,2,0,0,0,0,40,15,33,0,136,245,31,0,28,0,0,0,5,0,0,0,144,34,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,160,114,30,0,136,245,31,0,28,0,0,0,5,0,0,0,144,34,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,224,231,29,0,152,122,29,0,32,0,0,0,5,0,0,0,176,34,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,216,210,28,0,152,122,29,0,32,0,0,0,5,0,0,0,176,34,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,232,205,35,0,96,122,35,0,36,0,0,0,5,0,0,0,56,31,35,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,80,218,34,0,0,158,34,0,40,0,0,0,5,0,0,0,56,31,35,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,184,97,34,0,0,42,34,0,44,0,0,0,82,76,79,67,216,249,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,94,32,0,108,0,0,0,120,14,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,1,0,16,16,2,0,32,16,2,0,64,16,4,0,8,16,1,0,16,16,2,0,32,16,2,0,64,16,4,0,8,16,1,0,16,48,2,0,32,48,2,0,64,48,4,0,64,50,4,0,0,0,0,0,8,16,1,0,16,48,2,0,32,48,2,0,64,48,4,0,64,50,4,0,0,0,0,0,140,32,0,0,1,0,0,128,193,17,0,0,0,0,0,0,52,12,0,0,0,0,0,176,76,9,0,0,195,109,219,182,130,7,0,0,102,39,118,226,76,6,0,0,243,123,239,189,108,5,0,0,24,0,0,192,195,4,0,0,64,6,231,99,62,4,0,0,129,33,11,217,96,16,33,0,56,231,32,0,128,2,0,0,5,0,0,0,152,139,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,136,246,31,0,40,204,32,0,132,2,0,0,5,0,0,0,152,139,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,120,177,32,0,232,155,32,0,136,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,120,177,32,0,232,130,32,0,160,105,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,177,32,0,112,84,32,0,168,55,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,177,32,0,208,2,32,0,88,235,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,177,32,0,152,215,31,0,24,197,31,0,32,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,152,215,31,0,248,173,31,0,88,156,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,152,215,31,0,168,138,31,0,232,121,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,152,215,31,0,80,107,31,0,192,82,31,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,248,42,31,0,0,27,31,0,212,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,240,14,31,0,128,255,30,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,240,14,31,0,112,239,30,0,40,110,140,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,14,31,0,208,212,30,0,40,110,140,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,14,31,0,160,197,30,0,40,110,140,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,14,31,0,80,107,31,0,40,110,140,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,14,31,0,128,182,30,0,160,160,30,0,216,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,102,32,0,108,0,0,0,192,16,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,108,30,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,240,32,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+584966);
/* memory initializer */ allocate([200,215,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,204,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,215,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,64,66,15,0,1,0,0,0,7,0,8,0,2,0,47,0,32,0,2,0,6,0,3,0,5,0,4,0,60,0,8,0,4,0,69,0,50,0,67,0,41,0,51,0,49,0,59,0,53,0,6,0,6,0,40,0,55,0,43,0,54,0,42,0,62,0,7,0,8,0,63,0,48,0,52,0,61,0,77,0,78,0,72,0,7,0,10,0,85,0,56,0,86,0,68,0,74,0,73,0,81,0,5,0,12,0,82,0,95,0,80,0,94,0,91,0,5,0,14,0,90,0,89,0,88,0,103,0,87,0,8,0,16,0,1,0,0,0,15,0,35,0,33,0,58,0,64,0,84,0,5,0,32,0,102,0,118,0,134,0,150,0,166,0,5,0,34,0,101,0,114,0,130,0,146,0,162,0,5,0,36,0,100,0,126,0,142,0,158,0,174,0,5,0,38,0,99,0,122,0,138,0,154,0,170,0,6,0,20,0,11,0,39,0,19,0,31,0,27,0,23,0,5,0,40,0,46,0,71,0,66,0,76,0,93,0,5,0,56,0,98,0,117,0,133,0,149,0,165,0,5,0,58,0,97,0,113,0,129,0,145,0,161,0,5,0,60,0,96,0,125,0,141,0,157,0,173,0,5,0,62,0,111,0,121,0,137,0,153,0,169,0,6,0,44,0,10,0,38,0,18,0,30,0,26,0,22,0,8,0,64,0,14,0,13,0,12,0,34,0,45,0,57,0,79,0,83,0,5,0,80,0,110,0,116,0,132,0,148,0,164,0,5,0,82,0,109,0,112,0,128,0,144,0,160,0,5,0,84,0,108,0,124,0,140,0,156,0,172,0,5,0,86,0,107,0,120,0,136,0,152,0,168,0,6,0,68,0,9,0,37,0,17,0,29,0,25,0,21,0,5,0,88,0,44,0,70,0,65,0,75,0,92,0,5,0,104,0,106,0,115,0,131,0,147,0,163,0,5,0,106,0,105,0,127,0,143,0,159,0,175,0,5,0,108,0,104,0,123,0,139,0,155,0,171,0,5,0,110,0,119,0,135,0,151,0,167,0,183,0,6,0,92,0,8,0,36,0,16,0,28,0,24,0,20,0,0,0,0,0,0,0,9,0,67,68,1,2,3,4,5,6,7,9,2,14,13,9,12,11,0,10,15,8,9,4,18,19,23,17,22,20,21,66,65,8,10,44,42,40,54,52,56,64,78,4,12,36,32,72,80,5,14,16,28,24,60,84,13,16,135,109,144,156,120,97,148,121,101,122,123,89,124,4,18,125,126,127,112,6,36,50,48,62,70,76,74,4,38,35,47,87,95,5,40,31,27,39,59,83,13,42,129,108,159,155,130,96,147,131,100,132,133,88,134,4,44,113,114,115,116,8,62,43,41,55,53,51,71,79,77,4,64,34,46,86,94,5,66,30,26,38,58,82,13,68,139,107,158,154,140,111,146,141,99,142,143,103,128,4,70,105,90,91,92,6,88,49,63,61,69,75,73,4,90,33,45,85,93,5,92,29,25,37,57,81,13,94,149,106,157,153,150,110,145,151,98,136,137,102,138,4,96,117,118,119,104,0,0,0,8,0,7,6,5,4,3,2,1,0,9,2,15,14,13,12,11,10,9,8,23,9,4,53,52,51,58,40,55,54,57,56,8,10,22,20,18,16,30,50,95,94,7,12,28,24,73,36,32,62,67,13,16,127,123,135,131,143,139,151,103,102,101,100,99,98,4,18,83,75,79,71,5,36,44,42,49,93,92,7,38,27,39,72,35,47,61,66,13,42,126,122,134,130,142,138,150,97,96,111,110,109,108,4,44,82,74,78,70,8,62,21,19,17,31,29,48,91,90,7,64,26,38,87,34,46,60,65,13,68,125,121,133,129,141,137,149,107,106,105,104,119,118,4,70,81,85,77,69,5,88,43,41,63,89,88,7,90,25,37,86,33,45,59,64,13,94,124,120,132,128,140,136,148,117,116,115,114,113,112,4,96,80,84,76,68,0,0,0,0,0,0,8,0,7,6,15,4,5,3,2,0,9,2,14,13,8,12,10,1,9,11,29,9,4,57,58,50,56,60,59,49,71,70,8,10,17,19,23,21,31,24,32,52,7,12,36,82,69,46,42,48,77,11,16,109,97,133,121,101,89,125,113,93,117,105,3,18,81,73,65,4,36,28,26,38,54,7,38,35,83,68,45,41,63,76,11,42,108,96,132,120,100,88,124,112,92,116,104,3,44,80,72,64,8,62,16,18,22,20,30,39,47,51,7,64,34,84,67,44,40,62,75,11,68,107,111,131,135,99,103,123,127,91,115,119,3,70,95,87,79,4,88,27,25,37,53,7,90,33,85,66,43,55,61,74,11,94,106,110,130,134,98,102,122,126,90,114,118,3,96,94,86,78,0,0,0,0,1,0,0,0,7,0,8,0,2,0,24,0,33,0,39,0,12,0,6,0,5,0,4,0,13,0,8,0,4,0,65,0,79,0,64,0,78,0,51,0,61,0,71,0,70,0,7,0,6,0,52,0,55,0,44,0,54,0,53,0,43,0,42,0,7,0,8,0,60,0,59,0,58,0,57,0,56,0,75,0,74,0,6,0,10,0,73,0,72,0,86,0,87,0,85,0,84,0,8,0,16,0,11,0,10,0,9,0,8,0,28,0,27,0,49,0,69,0,6,0,32,0,83,0,91,0,99,0,107,0,115,0,123,0,6,0,34,0,82,0,103,0,111,0,119,0,127,0,135,0,6,0,20,0,38,0,23,0,34,0,19,0,3,0,15,0,5,0,40,0,32,0,41,0,63,0,67,0,77,0,6,0,56,0,81,0,90,0,98,0,106,0,114,0,122,0,6,0,58,0,80,0,102,0,110,0,118,0,126,0,134,0,6,0,44,0,26,0,22,0,36,0,18,0,2,0,14,0,5,0,64,0,45,0,40,0,50,0,48,0,68,0,6,0,80,0,95,0,89,0,97,0,105,0,113,0,121,0,6,0,82,0,94,0,101,0,109,0,117,0,125,0,133,0,6,0,68,0,37,0,21,0,35,0,17,0,1,0,31,0,5,0,88,0,47,0,46,0,62,0,66,0,76,0,6,0,104,0,93,0,88,0,96,0,104,0,112,0,120,0,6,0,106,0,92,0,100,0,108,0,116,0,124,0,132,0,6,0,92,0,25,0,20,0,29,0,16,0,0,0,30,0,0,0,0,0,0,0,0,0,8,0,7,6,0,3,5,4,2,1,9,2,13,12,8,11,10,15,9,14,23,9,4,71,56,60,70,59,57,58,69,76,8,10,16,18,22,20,30,38,44,42,6,12,75,48,52,40,34,26,9,16,101,89,93,117,105,81,85,109,97,2,18,67,78,4,36,28,36,46,87,6,38,74,63,51,55,33,25,9,42,100,88,92,116,104,80,84,108,96,2,44,64,79,8,62,31,17,21,19,29,37,43,41,6,64,73,62,50,54,32,24,9,68,99,103,91,115,119,95,83,107,111,2,70,66,77,4,88,27,35,45,86,6,90,72,61,49,53,47,39,9,94,98,102,90,114,118,94,82,106,110,2,96,65,68,0,0,0,0,8,0,0,1,2,3,4,5,6,7,8,2,8,9,10,11,12,13,14,15,7,4,70,51,43,71,50,60,49,8,10,23,22,21,20,19,47,54,59,6,12,48,42,35,29,30,31,7,16,92,84,82,100,79,72,88,2,18,67,68,4,36,18,46,53,58,6,38,63,41,34,26,27,28,7,42,91,83,81,99,78,87,103,2,44,65,66,4,62,17,45,52,57,6,64,62,40,33,39,24,25,7,68,90,80,95,98,77,86,102,2,70,75,64,4,88,16,44,56,69,6,90,61,55,32,36,37,38,7,94,89,94,93,97,76,85,101,2,96,73,74,0,0,0,8,0,7,6,5,4,3,2,1,0,8,2,15,14,13,12,11,10,9,8,7,4,51,35,34,50,33,49,32,8,10,23,22,21,20,19,18,43,42,8,12,54,55,40,41,24,25,26,27,7,16,92,68,67,84,66,65,80,2,18,53,52,4,36,17,16,48,63,7,42,91,64,79,83,78,77,95,2,44,62,61,4,62,31,30,60,59,8,64,44,45,46,47,36,37,38,39,7,68,90,76,75,82,74,73,94,2,70,58,57,4,88,29,28,56,71,7,94,89,72,87,81,86,85,93,2,96,70,69,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,93,0,58,0,91,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,101,0,102,0,96,0,7,0,10,0,109,0,64,0,110,0,92,0,98,0,97,0,105,0,5,0,12,0,106,0,119,0,104,0,118,0,115,0,5,0,14,0,114,0,113,0,112,0,127,0,111,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,88,0,108,0,1,0,18,0,126,0,11,0,24,0,134,0,145,0,147,0,169,0,186,0,42,1,58,1,226,0,207,0,117,1,77,1,11,0,26,0,142,0,162,0,151,0,181,0,203,0,33,1,105,1,55,1,188,0,98,1,100,1,11,0,28,0,135,0,153,0,157,0,183,0,224,0,64,1,126,1,16,1,193,0,99,1,88,1,11,0,30,0,132,0,146,0,136,0,182,0,206,0,12,1,71,1,255,0,189,0,103,1,78,1,11,0,32,0,5,1,196,0,102,1,184,1,19,1,37,1,26,1,140,1,158,1,183,1,200,1,11,0,34,0,234,0,223,0,127,1,194,1,217,0,0,1,35,1,123,1,159,1,179,1,212,1,11,0,36,0,34,1,204,0,108,1,185,1,2,1,220,0,22,1,125,1,162,1,191,1,223,1,11,0,38,0,237,0,199,0,97,1,199,1,3,1,232,0,11,1,114,1,150,1,171,1,222,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,4,0,22,0,79,0,78,0,77,0,76,0,6,0,40,0,35,0,54,0,95,0,90,0,100,0,117,0,1,0,42,0,125,0,11,0,48,0,131,0,156,0,158,0,177,0,246,0,51,1,111,1,251,0,197,0,53,1,70,1,11,0,50,0,120,0,154,0,148,0,178,0,227,0,75,1,107,1,249,0,192,0,80,1,89,1,11,0,52,0,122,0,150,0,141,0,170,0,221,0,27,1,66,1,236,0,201,0,90,1,57,1,11,0,54,0,121,0,164,0,138,0,168,0,231,0,62,1,110,1,14,1,194,0,79,1,73,1,11,0,56,0,29,1,205,0,142,1,192,1,32,1,244,0,23,1,143,1,166,1,182,1,213,1,11,0,58,0,46,1,222,0,137,1,206,1,242,0,238,0,25,1,128,1,164,1,176,1,214,1,11,0,60,0,7,1,211,0,118,1,205,1,240,0,252,0,69,1,101,1,135,1,168,1,209,1,11,0,62,0,241,0,208,0,119,1,196,1,10,1,18,1,50,1,149,1,160,1,180,1,208,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,4,0,46,0,75,0,74,0,73,0,72,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,103,0,107,0,1,0,66,0,124,0,11,0,72,0,155,0,160,0,161,0,185,0,250,0,87,1,155,1,59,1,4,1,116,1,139,1,11,0,74,0,143,0,172,0,174,0,187,0,247,0,68,1,157,1,115,1,21,1,131,1,95,1,11,0,76,0,139,0,171,0,173,0,209,0,1,1,122,1,144,1,83,1,254,0,152,1,121,1,11,0,78,0,130,0,163,0,137,0,191,0,212,0,93,1,133,1,63,1,200,0,113,1,82,1,11,0,80,0,31,1,219,0,145,1,202,1,67,1,36,1,94,1,165,1,172,1,187,1,219,1,11,0,82,0,38,1,216,0,148,1,207,1,52,1,48,1,56,1,163,1,175,1,189,1,220,1,11,0,84,0,72,1,230,0,153,1,193,1,39,1,61,1,74,1,151,1,170,1,186,1,210,1,11,0,86,0,40,1,202,0,136,1,197,1,28,1,20,1,15,1,124,1,174,1,177,1,201,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,4,0,70,0,87,0,86,0,85,0,84,0,6,0,88,0,34,0,53,0,94,0,89,0,99,0,116,0,1,0,90,0,123,0,11,0,96,0,128,0,175,0,159,0,180,0,229,0,41,1,92,1,44,1,184,0,104,1,85,1,11,0,98,0,129,0,166,0,165,0,195,0,215,0,76,1,84,1,45,1,253,0,120,1,96,1,11,0,100,0,140,0,152,0,167,0,190,0,225,0,86,1,109,1,8,1,214,0,134,1,91,1,11,0,102,0,133,0,144,0,149,0,179,0,218,0,60,1,132,1,65,1,210,0,147,1,81,1,11,0,104,0,9,1,198,0,112,1,188,1,13,1,24,1,49,1,173,1,167,1,178,1,221,1,11,0,106,0,47,1,228,0,129,1,204,1,239,0,6,1,233,0,106,1,154,1,161,1,211,1,11,0,108,0,235,0,213,0,138,1,195,1,245,0,17,1,43,1,156,1,169,1,190,1,215,1,11,0,110,0,248,0,176,0,130,1,198,1,243,0,30,1,54,1,141,1,146,1,181,1,203,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,4,0,94,0,83,0,82,0,81,0,80,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,11,0,24,0,118,0,129,0,131,0,153,0,170,0,26,1,42,1,210,0,191,0,101,1,61,1,11,0,26,0,126,0,146,0,135,0,165,0,187,0,17,1,89,1,39,1,172,0,82,1,84,1,11,0,28,0,119,0,137,0,141,0,167,0,208,0,48,1,110,1,0,1,177,0,83,1,72,1,11,0,30,0,116,0,130,0,120,0,166,0,190,0,252,0,55,1,239,0,173,0,87,1,62,1,11,0,32,0,245,0,180,0,86,1,168,1,3,1,21,1,10,1,124,1,142,1,167,1,184,1,11,0,34,0,218,0,207,0,111,1,178,1,201,0,240,0,19,1,107,1,143,1,163,1,196,1,11,0,36,0,18,1,188,0,92,1,169,1,242,0,204,0,6,1,109,1,146,1,175,1,207,1,11,0,38,0,221,0,183,0,81,1,183,1,243,0,216,0,251,0,98,1,134,1,155,1,206,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,11,0,48,0,115,0,140,0,142,0,161,0,230,0,35,1,95,1,235,0,181,0,37,1,54,1,11,0,50,0,104,0,138,0,132,0,162,0,211,0,59,1,91,1,233,0,176,0,64,1,73,1,11,0,52,0,106,0,134,0,125,0,154,0,205,0,11,1,50,1,220,0,185,0,74,1,41,1,11,0,54,0,105,0,148,0,122,0,152,0,215,0,46,1,94,1,254,0,178,0,63,1,57,1,11,0,56,0,13,1,189,0,126,1,176,1,16,1,228,0,7,1,127,1,150,1,166,1,197,1,11,0,58,0,30,1,206,0,121,1,190,1,226,0,222,0,9,1,112,1,148,1,160,1,198,1,11,0,60,0,247,0,195,0,102,1,189,1,224,0,236,0,53,1,85,1,119,1,152,1,193,1,11,0,62,0,225,0,192,0,103,1,180,1,250,0,2,1,34,1,133,1,144,1,164,1,192,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,11,0,72,0,139,0,144,0,145,0,169,0,234,0,71,1,139,1,43,1,244,0,100,1,123,1,11,0,74,0,127,0,156,0,158,0,171,0,231,0,52,1,141,1,99,1,5,1,115,1,79,1,11,0,76,0,123,0,155,0,157,0,193,0,241,0,106,1,128,1,67,1,238,0,136,1,105,1,11,0,78,0,114,0,147,0,121,0,175,0,196,0,77,1,117,1,47,1,184,0,97,1,66,1,11,0,80,0,15,1,203,0,129,1,186,1,51,1,20,1,78,1,149,1,156,1,171,1,203,1,11,0,82,0,22,1,200,0,132,1,191,1,36,1,32,1,40,1,147,1,159,1,173,1,204,1,11,0,84,0,56,1,214,0,137,1,177,1,23,1,45,1,58,1,135,1,154,1,170,1,194,1,11,0,86,0,24,1,186,0,120,1,181,1,12,1,4,1,255,0,108,1,158,1,161,1,185,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,11,0,96,0,112,0,159,0,143,0,164,0,213,0,25,1,76,1,28,1,168,0,88,1,69,1,11,0,98,0,113,0,150,0,149,0,179,0,199,0,60,1,68,1,29,1,237,0,104,1,80,1,11,0,100,0,124,0,136,0,151,0,174,0,209,0,70,1,93,1,248,0,198,0,118,1,75,1,11,0,102,0,117,0,128,0,133,0,163,0,202,0,44,1,116,1,49,1,194,0,131,1,65,1,11,0,104,0,249,0,182,0,96,1,172,1,253,0,8,1,33,1,157,1,151,1,162,1,205,1,11,0,106,0,31,1,212,0,113,1,188,1,223,0,246,0,217,0,90,1,138,1,145,1,195,1,11,0,108,0,219,0,197,0,122,1,179,1,229,0,1,1,27,1,140,1,153,1,174,1,199,1,11,0,110,0,232,0,160,0,114,1,182,1,227,0,14,1,38,1,125,1,130,1,165,1,187,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,10,0,24,0,134,0,153,0,7,1,86,1,143,1,154,0,106,0,177,0,61,1,9,1,10,0,26,0,128,0,167,0,14,1,95,1,129,1,160,0,105,0,213,0,73,1,3,1,2,0,28,0,123,0,147,0,2,0,30,0,131,0,143,0,10,0,32,0,90,1,118,0,170,0,201,0,40,1,112,1,250,0,28,1,85,1,135,1,10,0,34,0,89,1,104,0,166,0,196,0,25,1,118,1,242,0,13,1,71,1,134,1,14,0,36,0,141,0,171,0,35,1,108,1,229,0,210,0,52,1,228,0,206,0,200,0,2,1,39,1,57,1,105,1,14,0,38,0,144,0,188,0,26,1,110,1,217,0,216,0,53,1,218,0,193,0,182,0,245,0,31,1,44,1,111,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,10,0,48,0,139,0,169,0,11,1,92,1,133,1,163,0,116,0,189,0,87,1,12,1,10,0,50,0,120,0,161,0,249,0,83,1,141,1,152,0,114,0,230,0,78,1,47,1,2,0,52,0,125,0,138,0,2,0,54,0,112,0,129,0,10,0,56,0,93,1,122,0,162,0,203,0,32,1,116,1,22,1,18,1,56,1,121,1,10,0,58,0,101,1,126,0,165,0,214,0,42,1,106,1,252,0,4,1,65,1,122,1,14,0,60,0,150,0,199,0,10,1,99,1,211,0,180,0,29,1,241,0,195,0,198,0,243,0,19,1,67,1,119,1,14,0,62,0,142,0,191,0,0,1,97,1,208,0,220,0,58,1,237,0,190,0,212,0,255,0,48,1,62,1,115,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,10,0,72,0,159,0,168,0,46,1,100,1,139,1,178,0,132,0,185,0,74,1,30,1,10,0,74,0,158,0,181,0,36,1,102,1,140,1,176,0,133,0,235,0,75,1,20,1,2,0,76,0,130,0,157,0,2,0,78,0,124,0,136,0,10,0,80,0,98,1,121,0,194,0,246,0,66,1,123,1,16,1,17,1,76,1,142,1,10,0,82,0,103,1,140,0,186,0,236,0,77,1,120,1,34,1,45,1,82,1,131,1,14,0,84,0,155,0,227,0,63,1,113,1,253,0,254,0,94,1,248,0,224,0,239,0,240,0,37,1,59,1,127,1,14,0,86,0,156,0,209,0,41,1,117,1,225,0,215,0,70,1,247,0,197,0,184,0,232,0,33,1,54,1,109,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,10,0,96,0,148,0,164,0,8,1,84,1,132,1,183,0,117,0,205,0,80,1,5,1,10,0,98,0,146,0,174,0,1,1,79,1,128,1,173,0,113,0,187,0,64,1,23,1,2,0,100,0,127,0,151,0,2,0,102,0,119,0,137,0,10,0,104,0,96,1,135,0,172,0,238,0,50,1,125,1,6,1,15,1,72,1,126,1,10,0,106,0,91,1,115,0,179,0,219,0,49,1,124,1,21,1,38,1,81,1,130,1,14,0,108,0,145,0,192,0,51,1,114,1,234,0,223,0,68,1,244,0,202,0,204,0,251,0,43,1,69,1,104,1,14,0,110,0,149,0,221,0,55,1,107,1,226,0,222,0,60,1,231,0,207,0,175,0,233,0,24,1,27,1,88,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,2,0,24,0,124,0,115,0,2,0,26,0,150,0,117,0,2,0,28,0,129,0,114,0,2,0,30,0,121,0,131,0,14,0,32,0,161,0,1,1,87,1,199,0,177,0,47,1,204,0,173,0,168,0,4,1,21,1,51,1,82,1,128,0,14,0,34,0,194,0,30,1,91,1,222,0,214,0,60,1,236,0,152,0,166,0,242,0,28,1,52,1,88,1,142,0,14,0,36,0,169,0,17,1,97,1,202,0,189,0,55,1,240,0,200,0,171,0,5,1,53,1,40,1,89,1,130,0,14,0,38,0,198,0,19,1,93,1,187,0,163,0,26,1,193,0,195,0,175,0,234,0,9,1,33,1,72,1,119,0,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,2,0,48,0,139,0,104,0,2,0,50,0,135,0,118,0,2,0,52,0,112,0,127,0,2,0,54,0,140,0,141,0,14,0,56,0,179,0,20,1,84,1,225,0,223,0,65,1,235,0,190,0,182,0,15,1,54,1,59,1,96,1,125,0,14,0,58,0,153,0,8,1,73,1,232,0,209,0,67,1,231,0,165,0,191,0,23,1,34,1,56,1,111,1,134,0,14,0,60,0,167,0,13,1,85,1,205,0,197,0,42,1,224,0,160,0,170,0,3,1,24,1,61,1,101,1,148,0,14,0,62,0,203,0,16,1,86,1,227,0,192,0,43,1,233,0,172,0,183,0,0,1,27,1,70,1,99,1,106,0,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,2,0,72,0,144,0,120,0,2,0,74,0,157,0,123,0,2,0,76,0,145,0,138,0,2,0,78,0,132,0,154,0,14,0,80,0,241,0,63,1,109,1,252,0,253,0,75,1,254,0,230,0,220,0,7,1,29,1,58,1,108,1,156,0,14,0,82,0,247,0,35,1,83,1,249,0,250,0,76,1,11,1,196,0,207,0,12,1,48,1,68,1,100,1,158,0,14,0,84,0,210,0,44,1,92,1,243,0,237,0,77,1,246,0,206,0,219,0,10,1,62,1,79,1,107,1,159,0,14,0,86,0,239,0,50,1,110,1,221,0,226,0,41,1,251,0,184,0,178,0,2,1,36,1,49,1,90,1,116,0,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,2,0,96,0,143,0,126,0,2,0,98,0,137,0,122,0,2,0,100,0,149,0,105,0,2,0,102,0,133,0,136,0,14,0,104,0,162,0,31,1,81,1,244,0,229,0,66,1,218,0,180,0,186,0,6,1,18,1,32,1,95,1,146,0,14,0,106,0,212,0,38,1,102,1,248,0,228,0,78,1,215,0,174,0,176,0,14,1,37,1,45,1,98,1,147,0,14,0,108,0,185,0,71,1,80,1,211,0,213,0,57,1,245,0,181,0,188,0,255,0,25,1,69,1,94,1,151,0,14,0,110,0,201,0,39,1,103,1,216,0,208,0,64,1,238,0,164,0,155,0,217,0,22,1,46,1,74,1,113,0,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,13,0,32,0,122,0,154,0,170,0,218,0,10,1,138,0,106,0,182,0,230,0,22,1,178,0,226,0,18,1,13,0,34,0,134,0,166,0,190,0,238,0,30,1,150,0,118,0,186,0,234,0,26,1,198,0,246,0,38,1,13,0,36,0,130,0,162,0,194,0,242,0,34,1,146,0,114,0,206,0,254,0,46,1,202,0,250,0,42,1,13,0,38,0,142,0,174,0,214,0,6,1,54,1,158,0,126,0,210,0,2,1,50,1,222,0,14,1,62,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,13,0,56,0,121,0,153,0,169,0,217,0,9,1,137,0,105,0,181,0,229,0,21,1,177,0,225,0,17,1,13,0,58,0,133,0,165,0,189,0,237,0,29,1,149,0,117,0,185,0,233,0,25,1,197,0,245,0,37,1,13,0,60,0,129,0,161,0,193,0,241,0,33,1,145,0,113,0,205,0,253,0,45,1,201,0,249,0,41,1,13,0,62,0,141,0,173,0,213,0,5,1,53,1,157,0,125,0,209,0,1,1,49,1,221,0,13,1,61,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,13,0,80,0,120,0,152,0,168,0,216,0,8,1,136,0,104,0,180,0,228,0,20,1,176,0,224,0,16,1,13,0,82,0,132,0,164,0,188,0,236,0,28,1,148,0,116,0,184,0,232,0,24,1,196,0,244,0,36,1,13,0,84,0,128,0,160,0,192,0,240,0,32,1,144,0,112,0,204,0,252,0,44,1,200,0,248,0,40,1,13,0,86,0,140,0,172,0,212,0,4,1,52,1,156,0,124,0,208,0,0,1,48,1,220,0,12,1,60,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,13,0,104,0,135,0,167,0,183,0,231,0,23,1,151,0,119,0,179,0,227,0,19,1,191,0,239,0,31,1,13,0,106,0,131,0,163,0,187,0,235,0,27,1,147,0,115,0,199,0,247,0,39,1,195,0,243,0,35,1,13,0,108,0,143,0,175,0,207,0,255,0,47,1,159,0,127,0,203,0,251,0,43,1,215,0,7,1,55,1,13,0,110,0,139,0,171,0,211,0,3,1,51,1,155,0,123,0,223,0,15,1,63,1,219,0,11,1,59,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,13,0,32,0,114,0,186,0,210,0,234,0,2,1,106,0,126,0,162,0,170,0,198,0,222,0,246,0,14,1,13,0,34,0,122,0,194,0,218,0,242,0,10,1,118,0,134,0,174,0,182,0,206,0,230,0,254,0,22,1,9,0,36,0,130,0,138,0,146,0,154,0,178,0,202,0,226,0,250,0,18,1,9,0,38,0,142,0,150,0,158,0,166,0,190,0,214,0,238,0,6,1,30,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,13,0,56,0,113,0,185,0,209,0,233,0,1,1,105,0,125,0,161,0,169,0,197,0,221,0,245,0,13,1,13,0,58,0,121,0,193,0,217,0,241,0,9,1,117,0,133,0,173,0,181,0,205,0,229,0,253,0,21,1,9,0,60,0,129,0,137,0,145,0,153,0,177,0,201,0,225,0,249,0,17,1,9,0,62,0,141,0,149,0,157,0,165,0,189,0,213,0,237,0,5,1,29,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,13,0,80,0,112,0,184,0,208,0,232,0,0,1,104,0,124,0,160,0,168,0,196,0,220,0,244,0,12,1,13,0,82,0,120,0,192,0,216,0,240,0,8,1,116,0,132,0,172,0,180,0,204,0,228,0,252,0,20,1,9,0,84,0,128,0,136,0,144,0,152,0,176,0,200,0,224,0,248,0,16,1,9,0,86,0,140,0,148,0,156,0,164,0,188,0,212,0,236,0,4,1,28,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,13,0,104,0,127,0,199,0,223,0,247,0,15,1,119,0,123,0,175,0,183,0,195,0,219,0,243,0,11,1,13,0,106,0,135,0,207,0,231,0,255,0,23,1,115,0,131,0,171,0,179,0,203,0,227,0,251,0,19,1,9,0,108,0,143,0,151,0,159,0,167,0,191,0,215,0,239,0,7,1,31,1,9,0,110,0,139,0,147,0,155,0,163,0,187,0,211,0,235,0,3,1,27,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,9,0,32,0,106,0,122,0,154,0,186,0,218,0,134,0,166,0,198,0,230,0,9,0,34,0,105,0,130,0,162,0,194,0,226,0,142,0,174,0,206,0,238,0,9,0,36,0,104,0,138,0,170,0,202,0,234,0,150,0,182,0,214,0,246,0,9,0,38,0,119,0,146,0,178,0,210,0,242,0,158,0,190,0,222,0,254,0,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,9,0,56,0,118,0,121,0,153,0,185,0,217,0,133,0,165,0,197,0,229,0,9,0,58,0,117,0,129,0,161,0,193,0,225,0,141,0,173,0,205,0,237,0,9,0,60,0,116,0,137,0,169,0,201,0,233,0,149,0,181,0,213,0,245,0,9,0,62,0,115,0,145,0,177,0,209,0,241,0,157,0,189,0,221,0,253,0,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,9,0,80,0,114,0,120,0,152,0,184,0,216,0,132,0,164,0,196,0,228,0,9,0,82,0,113,0,128,0,160,0,192,0,224,0,140,0,172,0,204,0,236,0,9,0,84,0,112,0,136,0,168,0,200,0,232,0,148,0,180,0,212,0,244,0,9,0,86,0,127,0,144,0,176,0,208,0,240,0,156,0,188,0,220,0,252,0,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,9,0,104,0,126,0,135,0,167,0,199,0,231,0,131,0,163,0,195,0,227,0,9,0,106,0,125,0,143,0,175,0,207,0,239,0,139,0,171,0,203,0,235,0,9,0,108,0,124,0,151,0,183,0,215,0,247,0,147,0,179,0,211,0,243,0,9,0,110,0,123,0,159,0,191,0,223,0,255,0,155,0,187,0,219,0,251,0,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,7,0,7,6,5,4,3,2,1,8,2,0,15,14,13,12,11,10,9,9,4,23,22,21,20,19,18,17,16,8,8,6,31,30,29,28,27,86,85,84,6,8,83,82,81,80,127,126,9,10,26,24,38,36,34,32,46,44,42,4,12,40,52,48,95,5,14,60,56,68,91,111,3,16,191,176,177,4,18,103,123,124,125,3,20,188,189,190,4,22,99,120,121,122,3,24,185,186,187,4,26,107,133,134,135,3,28,198,199,184,4,30,119,130,131,132,3,32,195,196,197,4,34,115,143,128,129,6,36,64,78,76,74,72,245,4,38,55,51,63,94,5,40,59,71,67,90,110,3,42,192,193,194,4,44,102,140,141,142,3,46,205,206,207,4,48,98,137,138,139,3,50,202,203,204,4,52,106,150,151,136,3,54,215,200,201,4,56,118,147,148,149,3,58,212,213,214,4,60,114,144,145,146,9,62,25,39,37,35,33,47,45,43,41,4,64,54,50,62,93,5,66,58,70,66,89,109,3,68,209,210,211,4,70,101,157,158,159,3,72,222,223,208,4,74,97,154,155,156,3,76,219,220,221,4,78,105,167,152,153,3,80,216,217,218,4,82,117,164,165,166,3,84,229,230,231,4,86,113,161,162,163,6,88,79,77,75,73,87,244,4,90,53,49,61,92,5,92,57,69,65,88,108,3,94,226,227,228,4,96,100,174,175,160,3,98,239,224,225,4,100,96,171,172,173,3,102,236,237,238,4,104,104,168,169,170,3,106,233,234,235,4,108,116,181,182,183,3,110,246,247,232,4,112,112,178,179,180,0,0,8,0,0,1,2,3,4,5,6,7,9,2,23,8,9,10,11,12,13,14,15,9,4,57,58,62,56,60,59,61,71,70,8,10,22,21,20,19,18,17,42,41,7,12,38,50,84,37,36,85,83,1,16,66,1,18,67,1,20,68,1,22,69,10,24,145,144,156,153,154,163,161,192,206,195,10,26,158,159,157,152,155,165,160,205,204,194,7,28,167,166,162,164,196,207,193,5,36,26,25,54,53,89,7,38,35,49,81,34,33,82,80,1,42,78,1,44,79,1,46,64,1,48,65,10,50,103,102,98,111,96,105,119,185,199,188,10,52,100,101,99,110,97,107,118,198,197,187,7,54,109,108,104,106,189,184,186,8,62,16,31,30,29,28,27,40,55,7,64,32,48,94,47,46,95,93,1,68,74,1,70,75,1,72,76,1,74,77,10,76,117,116,112,125,126,135,133,178,176,181,10,78,114,115,113,124,127,121,132,191,190,180,7,80,123,122,134,120,182,177,179,5,88,24,39,52,51,88,7,90,45,63,91,44,43,92,90,1,94,86,1,96,87,1,98,72,1,100,73,10,102,131,130,142,139,140,149,147,171,169,174,10,104,128,129,143,138,141,151,146,168,183,173,7,106,137,136,148,150,175,170,172,0,0,0,0,0,0,56,180,35,0,108,0,0,0,208,69,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,250,34,0,200,187,34,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,32,0,0,0,0,126,34,0,200,69,34,0,96,20,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,126,34,0,160,225,33,0,0,190,33,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,126,34,0,192,154,33,0,8,127,33,0,0,0,0,0,128,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,126,34,0,192,63,33,0,240,15,33,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,126,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,95,32,0,224,75,32,0,52,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,248,21,32,0,8,246,31,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,1,0,0,0,248,21,32,0,56,225,31,0,128,206,31,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,248,21,32,0,192,185,31,0,120,166,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,248,21,32,0,64,148,31,0,72,130,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,248,21,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,178,29,0,120,109,140,0,4,0,0,0,1,0,0,0,112,23,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,136,253,28,0,208,174,28,0,16,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,24,172,35,0,120,109,140,0,24,0,0,0,84,65,82,86,240,77,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,192,33,0,56,156,33,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,16,192,33,0,88,128,33,0,48,69,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,16,192,33,0,0,19,33,0,208,246,32,0,60,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+595256);
/* memory initializer */ allocate([112,39,65,1,0,0,0,0,0,0,0,144,220,32,0,72,192,32,0,64,0,0,0,1,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,61,31,0,64,35,31,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,8,22,31,0,64,8,31,0,8,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,216,247,30,0,80,233,30,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,48,219,30,0,88,206,30,0,16,0,0,0,2,0,0,0,64,75,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,112,189,30,0,56,177,30,0,20,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,207,30,0,0,41,30,0,128,0,0,0,5,0,0,0,200,182,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,1,0,0,0,0,0,0,0,136,84,29,0,16,1,29,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,168,178,28,0,152,175,35,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,200,80,35,0,168,0,35,0,32,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,1,0,0,0,40,192,34,0,64,131,34,0,32,74,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,40,192,34,0,24,24,34,0,72,228,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,40,192,34,0,80,192,33,0,200,156,33,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,192,128,33,0,160,69,33,0,40,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,176,19,33,0,112,247,32,0,44,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,16,64,1,0,0,0,208,220,32,0,216,192,32,0,16,169,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,208,220,32,0,0,144,32,0,56,120,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,208,220,32,0,208,96,32,0,184,76,32,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,208,220,32,0,48,26,32,0,32,247,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,208,220,32,0,16,226,31,0,80,207,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,208,220,32,0,208,186,31,0,0,168,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,208,220,32,0,88,149,31,0,200,131,31,0,52,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,216,115,31,0,232,102,31,0,96,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,8,62,31,0,136,35,31,0,64,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,40,22,31,0,152,8,31,0,76,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,240,247,30,0,136,233,30,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,112,219,30,0,192,206,30,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,240,189,30,0,128,177,30,0,104,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,208,139,30,0,152,115,30,0,108,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,136,103,30,0,208,89,30,0,112,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,104,75,30,0,136,62,30,0,120,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,192,34,0,192,131,34,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,192,34,0,200,74,34,0,224,24,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,192,34,0,248,228,33,0,192,192,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,192,34,0,48,157,33,0,16,129,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,192,34,0,232,69,33,0,240,19,33,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,192,34,0,224,247,32,0,40,221,32,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,192,34,0,0,193,32,0,64,169,32,0,12,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,192,95,64,1,0,0,0,0,0,0,0,200,144,32,0,216,120,32,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,56,97,32,0,80,77,32,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,160,26,32,0,232,247,31,0,24,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,88,35,0,56,5,35,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,192,239,64,1,0,0,0,0,0,0,0,184,196,34,0,168,136,34,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,192,239,64,1,0,0,0,0,0,0,0,24,78,34,0,128,27,34,0,16,0,0,0,2,0,0,0,64,66,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,249,31,0,208,228,31,0,88,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,120,209,31,0,216,188,31,0,92,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,112,169,31,0,120,151,31,0,96,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,216,133,31,0,72,117,31,0,100,0,0,0,1,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,48,64,0,0,0,0,0,0,191,64,1,0,0,0,0,0,0,0,48,104,31,0,80,68,31,0,104,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,112,64,0,0,0,0,0,0,174,64,1,0,0,0,0,0,0,0,208,36,31,0,112,23,31,0,108,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,56,10,31,0,0,0,0,0,80,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,208,249,30,0,136,234,30,0,84,0,0,0,1,0,0,0,114,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,64,221,30,0,224,207,30,0,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,64,221,30,0,112,191,30,0,168,178,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,64,221,30,0,112,223,32,0,56,146,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,64,221,30,0,112,191,30,0,168,178,30,0,112,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,136,117,30,0,112,105,30,0,120,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,136,91,30,0,32,77,30,0,124,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,199,34,0,0,0,0,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,255,255,216,65,1,0,0,0,0,0,0,0,104,139,34,0,184,80,34,0,80,0,0,0,1,0,0,0,32,161,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,250,31,0,104,229,31,0,32,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,1,0,0,0,0,0,0,0,40,210,31,0,216,189,31,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,240,169,31,0,216,151,31,0,40,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,9,29,0,176,187,28,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,210,31,0,88,190,31,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,210,31,0,72,170,31,0,24,152,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,210,31,0,136,134,31,0,232,117,31,0,104,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,160,104,31,0,120,70,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,210,31,0,48,37,31,0,216,23,31,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,210,31,0,0,11,31,0,104,250,30,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,210,31,0,80,235,30,0,152,221,30,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,210,31,0,152,208,30,0,40,192,30,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,210,31,0,48,179,30,0,248,147,30,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,210,31,0,104,118,30,0,8,106,30,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,210,31,0,96,92,30,0,224,77,30,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,92,30,0,200,63,30,0,56,52,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,92,30,0,208,41,30,0,168,32,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,92,30,0,64,26,30,0,216,1,30,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,92,30,0,128,233,29,0,56,226,29,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,92,30,0,0,217,29,0,24,208,29,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,96,92,30,0,112,199,29,0,200,191,29,0,60,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,128,183,29,0,152,176,29,0,68,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,224,111,64,1,0,0,0,0,0,0,0,128,169,29,0,40,148,29,0,64,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,224,111,64,1,0,0,0,0,0,0,0,216,124,29,0,80,117,29,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,136,110,29,0,40,104,29,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,16,97,29,0,240,91,29,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,96,85,29,0,96,79,29,0,88,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,152,72,29,0,232,53,29,0,96,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,248,35,29,0,232,30,29,0,100,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,192,24,29,0,96,18,29,0,120,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,82,34,0,168,30,34,0,104,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,64,236,33,0,8,111,140,0,108,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,11,35,0,232,200,34,0,188,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,16,142,34,0,40,83,34,0,192,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,64,31,34,0,176,236,33,0,208,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,187,35,0,224,97,35,0,20,0,0,0,1,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,70,30,0,160,205,29,0,48,4,0,0,84,65,82,86,200,101,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,72,16,29,0,136,191,28,0,56,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,224,188,35,0,16,100,35,0,60,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,224,188,35,0,192,13,35,0,128,203,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,224,188,35,0,160,143,34,0,64,85,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,224,188,35,0,48,32,34,0,32,238,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,224,188,35,0,216,200,33,0,240,163,33,0,36,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,24,134,33,0,176,85,33,0,104,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,48,25,33,0,136,251,32,0,108,4,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,96,225,32,0,240,197,32,0,40,4,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,232,172,32,0,176,149,32,0,112,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,208,125,32,0,216,100,32,0,116,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,239,33,0,144,201,33,0,8,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,40,164,33,0,96,134,33,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,1,0,0,0,0,0,0,0,152,86,33,0,152,27,33,0,28,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,232,251,32,0,240,225,32,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,81,32,0,160,41,32,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,224,252,31,0,120,231,31,0,8,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,192,211,31,0,112,192,31,0,12,0,0,0,2,0,0,0,128,150,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,48,171,31,0,40,153,31,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,190,31,0,64,110,140,0,4,0,0,0,1,0,0,0,64,31,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,240,193,7,143,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,208,29,0,168,104,29,0,8,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,183,64,2,0,0,0,0,0,0,0,208,18,29,0,128,193,28,0,12,0,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,183,64,2,0,0,0,0,0,0,0,128,191,35,0,104,103,35,0,24,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,16,35,0,168,205,34,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,128,146,34,0,112,87,34,0,8,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,171,31,0,96,153,31,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,241,33,0,0,203,33,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,165,33,0,216,135,33,0,4,0,0,0,1,0,0,0,112,23,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,216,88,33,0,48,29,33,0,8,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,248,252,32,0,0,227,32,0,16,0,0,0,84,65,82,86,224,199,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,25,31,0,32,13,31,0,80,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,148,34,0,200,89,34,0,24,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,96,36,34,0,216,242,33,0,32,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,26,30,0,176,6,30,0,208,107,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,223,29,0,0,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,167,33,0,216,137,33,0,4,0,0,0,69,90,73,83,112,96,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,96,34,33,0,216,137,33,0,4,0,0,0,69,90,73,83,112,96,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,255,32,0,120,229,32,0,24,0,0,0,84,65,82,86,40,202,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,176,32,0,120,229,32,0,24,0,0,0,84,65,82,86,40,202,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,154,32,0,200,129,32,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,96,103,32,0,200,129,32,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,240,82,32,0,160,50,32,0,48,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,33,35,0,120,219,34,0,4,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,159,34,0,208,98,34,0,8,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,168,43,34,0,168,252,33,0,12,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,208,33,0,248,169,33,0,16,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,240,139,33,0,64,102,33,0,4,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,168,38,33,0,56,2,33,0,8,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,128,231,32,0,128,204,32,0,12,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,32,178,32,0,144,156,32,0,4,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,8,131,32,0,0,106,32,0,8,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,84,32,0,8,57,32,0,12,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,184,3,32,0,200,235,31,0,16,4,0,0,5,0,0,0,112,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,28,33,0,80,253,31,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,0,0,72,28,33,0,128,38,31,0,248,119,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,72,28,33,0,168,234,29,0,160,125,29,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,72,28,33,0,184,36,29,0,104,213,28,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,72,28,33,0,216,207,35,0,200,126,35,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,72,28,33,0,208,34,35,0,152,220,34,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,72,28,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,39,31,0,128,120,30,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,215,28,0,200,15,31,0,208,22,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,200,0,31,0,200,15,31,0,208,22,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,208,209,35,0,72,240,30,0,48,25,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,192,226,30,0,72,240,30,0,48,25,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,176,130,35,0,104,213,30,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,144,198,30,0,104,213,30,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,160,128,29,0,128,183,30,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,200,164,30,0,128,183,30,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,24,44,31,0,136,125,30,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,152,110,30,0,136,125,30,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,96,237,29,0,120,97,30,0,12,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,216,83,30,0,120,97,30,0,12,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,240,3,32,0,64,67,30,0,20,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,40,56,30,0,64,67,30,0,20,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,200,38,29,0,32,45,30,0,16,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,88,35,30,0,32,45,30,0,16,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,40,124,30,0,224,27,30,0,24,0,0,0,65,76,72,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,0,0,232,15,30,0,232,237,29,0,224,27,30,0,24,0,0,0,65,76,72,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,0,0,232,15,30,0,16,39,33,0,168,228,29,0,32,0,0,0,65,76,72,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,0,0,232,15,30,0,104,220,29,0,168,228,29,0,32,0,0,0,65,76,72,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,0,0,232,15,30,0,152,211,29,0,192,202,29,0,56,0,0,0,4,0,0,0,205,59,127,102,158,160,230,63,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,72,194,29,0,192,202,29,0,56,0,0,0,4,0,0,0,205,59,127,102,158,160,230,63,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,160,186,29,0,24,179,29,0,52,0,0,0,4,0,0,0,205,59,127,102,158,160,230,63,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,96,171,29,0,224,159,29,0,52,0,0,0,4,0,0,0,205,59,127,102,158,160,230,63,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,16,129,29,0,168,120,29,0,60,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,96,113,29,0,104,106,29,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,64,143,192,0,0,0,0,0,64,143,64,8,0,0,0,0,0,0,0,208,99,29,0,104], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+605517);
/* memory initializer */ allocate([106,29,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,64,143,192,0,0,0,0,0,64,143,64,8,0,0,0,0,0,0,0,32,94,29,0,168,87,29,0,68,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,143,64,8,0,0,0,0,0,0,0,40,81,29,0,240,73,29,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,8,0,0,0,40,81,29,0,232,65,29,0,240,73,29,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,8,0,0,0,40,81,29,0,200,39,29,0,144,32,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,40,81,29,0,184,26,29,0,112,20,29,0,96,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,248,13,29,0,224,7,29,0,88,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,81,64,8,0,0,0,248,13,29,0,168,3,29,0,200,253,28,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,48,248,28,0,80,240,28,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,224,215,28,0,48,209,28,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,232,201,28,0,88,195,28,0,0,0,0,0,128,0,0,0,65,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,104,190,28,0,240,185,28,0,0,0,0,0,128,0,0,0,69,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,40,181,28,0,56,175,28,0,0,0,0,0,128,0,0,0,70,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,0,242,35,0,24,234,35,0,0,0,0,0,128,0,0,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,0,210,35,0,24,204,35,0,0,0,0,0,128,0,0,0,66,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,56,198,35,0,176,192,35,0,0,0,0,0,128,0,0,0,67,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,104,187,35,0,152,182,35,0,0,0,0,0,128,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,248,13,29,0,8,178,35,0,80,172,35,0,252,21,0,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,208,166,35,0,32,156,35,0,0,22,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,64,8,0,0,0,0,0,0,0,32,131,35,0,104,120,35,0,4,22,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,0,0,0,0,112,113,35,0,96,105,35,0,8,22,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,0,0,0,0,104,98,35,0,96,105,35,0,8,22,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,0,0,0,0,152,92,35,0,96,83,35,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,152,92,35,0,144,78,35,0,16,70,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,152,92,35,0,216,59,35,0,128,37,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,152,92,35,0,24,30,35,0,224,23,35,0,24,22,0,0,3,0,0,0,0,0,0,0,0,0,52,64,0,0,0,0,0,0,46,64,0,0,0,0,0,128,64,64,8,0,0,0,0,0,0,0,72,18,35,0,104,12,35,0,32,22,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,0,0,0,0,136,7,35,0,136,2,35,0,36,22,0,0,4,0,0,0,0,0,0,224,255,255,239,71,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,8,0,0,0,0,0,0,0,32,254,34,0,56,248,34,0,40,22,0,0,4,0,0,0,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,160,242,34,0,16,223,34,0,44,22,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,40,217,34,0,136,211,34,0,48,22,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,208,206,34,0,0,202,34,0,52,22,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,112,198,34,0,96,194,34,0,56,22,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,0,0,0,0,0,0,152,189,34,0,232,185,34,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,8,0,0,0,152,189,34,0,176,180,34,0,88,162,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,152,189,34,0,16,157,34,0,16,152,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,152,189,34,0,112,147,34,0,192,142,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,152,189,34,0,152,138,34,0,8,133,34,0,16,22,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,8,0,0,0,152,138,34,0,192,128,34,0,144,124,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,152,138,34,0,0,119,34,0,32,102,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,152,138,34,0,192,96,34,0,64,92,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,152,138,34,0,144,88,34,0,24,84,34,0,20,22,0,0,1,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,48,64,8,0,0,0,0,0,0,0,208,79,34,0,40,76,34,0,248,21,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,64,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,242,29,0,16,132,29,0,212,175,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,10,0,0,0,0,0,0,0,80,42,29,0,88,218,28,0,116,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,80,42,29,0,40,213,35,0,80,134,35,0,120,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,39,35,0,24,225,34,0,124,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,120,163,34,0,104,103,34,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,48,48,34,0,232,0,34,0,132,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,94,29,0,224,87,29,0,60,22,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,10,0,0,0,48,94,29,0,56,81,29,0,0,74,29,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,48,94,29,0,96,66,29,0,8,40,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,48,94,29,0,168,32,29,0,8,27,29,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,48,94,29,0,168,20,29,0,8,14,29,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,48,94,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,135,29,0,104,109,140,0,196,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,216,220,28,0,24,216,35,0,48,137,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,216,220,28,0,224,41,35,0,232,227,34,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,216,220,28,0,120,165,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,216,220,28,0,128,105,34,0,104,109,140,0,188,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,88,49,34,0,24,216,35,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,88,49,34,0,224,41,35,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,88,49,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,108,34,0,96,52,34,0,48,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,45,35,0,136,231,34,0,216,1,0,0,1,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,64,17,0,0,0,0,0,0,0,192,168,34,0,0,0,0,0,20,0,0,0,1,0,0,0,5,128,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,64,22,224,64,17,0,0,0,192,168,34,0,152,108,34,0,0,0,0,0,0,0,0,0,128,0,0,0,5,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,168,34,0,160,52,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,168,34,0,128,4,34,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,168,34,0,120,214,33,0,0,0,0,0,0,0,0,0,128,0,0,0,178,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,168,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,225,28,0,192,220,35,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,34,0,88,5,34,0,48,182,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,72,215,33,0,224,178,33,0,52,182,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,254,29,0,144,144,29,0,88,23,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,48,35,0,200,233,34,0,28,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,6,34,0,88,216,33,0,128,79,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,32,64,17,0,0,0,0,0,0,0,192,179,33,0,0,0,0,0,184,79,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,17,0,0,0,192,179,33,0,0,144,35,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,179,33,0,184,146,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,179,33,0,96,234,34,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,179,33,0,8,113,33,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,179,33,0,64,111,34,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,179,33,0,152,48,33,0,88,8,33,0,172,79,0,0,5,0,0,0,40,238,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,17,0,0,0,0,0,0,0,248,210,32,0,168,183,32,0,160,79,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,64,17,0,0,0,0,0,0,0,192,161,32,0,24,136,32,0,176,79,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,16,64,17,0,0,0,192,161,32,0,128,111,32,0,0,0,0,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,161,32,0,0,144,35,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,161,32,0,184,146,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,161,32,0,96,234,34,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,161,32,0,8,113,33,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,161,32,0,40,89,32,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,192,161,32,0,120,65,32,0,144,9,32,0,168,79,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,52,29,0,208,228,28,0,40,21,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,64,17,0,0,0,0,0,0,0,208,223,35,0,112,144,35,0,44,21,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,223,35,0,96,145,35,0,8,4,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,71,31,0,232,148,30,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,73,31,0,208,150,30,0,4,0,0,0,5,0,0,0,168,4,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,150,29,0,8,56,29,0,112,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,32,232,28,0,88,225,35,0,120,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,112,147,35,0,240,51,35,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,147,35,0,248,236,34,0,96,173,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,112,147,35,0,128,113,34,0,112,57,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,112,147,35,0,176,8,34,0,184,217,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,112,147,35,0,120,181,33,0,200,147,33,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,112,147,35,0,160,114,33,0,48,50,33,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,248,9,33,0,112,239,32,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,24,212,32,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,192,184,32,0,160,162,32,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,204,29,0,208,195,29,0,168,11,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,4,31,0,48,244,30,0,112,10,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,49,32,0,24,78,31,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,168,156,30,0,24,78,31,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,8,9,30,0,232,153,29,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,56,59,29,0,232,153,29,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,217,30,0,112,202,30,0,56,29,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,64,186,30,0,32,170,30,0,56,29,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,240,34,0,88,178,34,0,112,8,0,0,1,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,178,34,0,128,117,34,0,120,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,20,64,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,61,29,0,88,237,28,0,84,5,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,82,31,0,48,160,30,0,16,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,24,0,1,0,88,82,31,0,24,12,30,0,80,156,29,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,88,82,31,0,128,61,29,0,32,237,28,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,88,82,31,0,72,231,35,0,176,152,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,88,82,31,0,112,57,35,0,184,240,34,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,88,82,31,0,80,178,34,0,48,117,34,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,88,82,31,0,40,61,34,0,64,12,34,0,8,1,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,54,32,0,160,82,31,0,4,0,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,0,0,0,0,0,0,32,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,163,31,0,8,146,31,0,104,37,64,0,1,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,64,9,0,0,0,0,0,0,0,32,128,31,0,200,112,31,0,96,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,8,64,9,0,0,0,32,128,31,0,112,94,31,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,32,128,31,0,40,52,31,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,32,128,31,0,160,32,31,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,32,128,31,0,152,19,31,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,32,128,31,0,120,5,31,0,224,244,30,0,100,37,64,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,184,230,30,0,0,0,0,0,120,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,32,64,9,0,0,0,0,0,0,0,128,217,30,0,0,0,0,0,124,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,32,64,9,0,0,0,0,0,0,0,208,202,30,0,152,186,30,0,116,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,20,64,9,0,0,0,8,171,30,0,232,129,30,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,171,30,0,96,113,30,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,171,30,0,168,100,30,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,171,30,0,24,87,30,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,171,30,0,32,70,30,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,171,30,0,136,59,30,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,171,30,0,144,48,30,0,40,38,30,0,128,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,8,64,9,0,0,0,144,48,30,0,216,29,30,0,0,0,0,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,144,48,30,0,224,19,30,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,144,48,30,0,24,242,29,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,144,48,30,0,32,231,29,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,144,48,30,0,208,222,29,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,144,48,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,92,32,0,48,69,32,0,96,150,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,202,30,0,200,186,30,0,104,0,0,0,5,0,0,0,112,109,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,155,35,0,128,59,35,0,68,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,62,34,0,72,14,34,0,0,58,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,30,0,176,171,30,0,248,111,4,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,68,32,0,80,94,31,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,68,29,0,56,243,28,0,108,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,238,35,0,40,158,35,0,112,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,136,61,35,0,8,244,34,0,120,1,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,64,64,17,0,0,0,0,0,0,0,24,182,34,0,152,120,34,0,116,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,64,64,17,0,0,0,0,0,0,0,0,64,34,0,128,15,34,0,124,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,121,33,0,56,56,33,0,72,14,0,0,1,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,10,0,0,0,112,121,33,0,24,14,33,0,40,244,32,0,0,0,0,0,128,0,0,0,255,255,255,127,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,112,121,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,14,33,0,136,244,32,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,80,217,32,0,40,190,32,0,44,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,0,16,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,161,35,0,224,63,35,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,230,32,0,0,8,0,0,168,0,0,0,224,202,32,0,0,0,0,0,184,176,32,0,0,8,0,0,146,0,0,0,80,154,32,0,192,129,32,0,72,103,32,0,0,8,0,0,146,0,0,0,80,154,32,0,192,129,32,0,168,82,32,0,0,8,0,0,146,0,0,0,80,154,32,0,192,129,32,0,232,48,32,0,0,8,0,0,146,0,0,0,80,154,32,0,192,129,32,0,48,255,31,0,0,8,0,0,212,0,0,0,56,233,31,0,0,0,0,0,128,213,31,0,0,8,0,0,112,0,0,0,232,193,31,0,0,0,0,0,64,172,31,0,0,8,0,0,46,0,0,0,136,154,31,0,0,0,0,0,160,136,31,0,0,8,0,0,26,0,0,0,232,119,31,0,0,0,0,0,0,106,31,0,0,8,0,0,18,1,0,0,16,74,31,0,0,0,0,0,136,38,31,0,0,8,0,0,24,1,0,0,0,25,31,0,0,0,0,0,120,12,31,0,0,8,0,0,208,0,0,0,56,252,30,0,0,0,0,0,120,236,30,0,0,8,0,0,114,0,0,0,248,222,30,0,0,0,0,0,48,210,30,0,0,8,0,0,104,0,0,0,168,194,30,0,0,0,0,0,0,180,30,0,0,8,0,0,106,0,0,0,200,149,30,0,0,0,0,0,56,119,30,0,0,8,0,0,52,1,0,0,168,106,30,0,0,0,0,0,176,92,30,0,0,8,0,0,162,0,0,0,88,78,30,0,0,0,0,0,64,64,30,0,0,8,0,0,40,1,0,0,232,61,30,0,0,0,0,0,216,41,30,0,1,0,0,0,86,0,0,0,144,32,30,0,216,41,30,0,56,26,30,0,1,0,0,0,86,0,0,0,144,32,30,0,216,41,30,0,16,1,30,0,0,0,0,0,170,7,0,0,208,247,29,0,0,0,0,0,16,226,29,0,1,0,0,0,116,0,0,0,248,223,29,0,208,207,29,0,40,199,29,0,5,0,0,0,62,0,0,0,72,191,29,0,16,183,29,0,192,175,29,0,6,0,0,0,32,76,78,0,104,173,29,0,192,175,29,0,32,168,29,0,9,64,12,0,16,0,0,0,208,137,29,0,200,122,29,0,16,110,29,0,2,0,0,0,152,44,80,0,40,103,29,0,0,0,0,0,128,96,29,0,2,0,0,0,248,72,71,0,168,90,29,0,0,0,0,0,192,89,29,0,9,128,12,0,20,0,0,0,120,78,29,0,48,77,29,0,48,77,29,0,9,128,12,0,20,0,0,0,120,78,29,0,48,77,29,0,32,49,29,0,9,128,8,0,84,1,0,0,200,46,29,0,64,30,29,0,112,23,29,0,5,32,8,0,66,1,0,0,80,17,29,0,216,9,29,0,32,5,29,0,5,32,8,0,36,1,0,0,224,0,29,0,136,251,28,0,48,246,28,0,9,128,8,0,76,1,0,0,104,224,28,0,64,211,28,0,16,204,28,0,133,64,8,0,156,0,0,0,232,197,28,0,32,192,28,0,200,187,28,0,1,64,13,0,160,0,0,0,248], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+615757);
/* memory initializer */ allocate([182,28,0,224,177,28,0,144,171,28,0,1,64,9,0,168,0,0,0,224,242,35,0,32,239,35,0,8,214,35,0,1,68,8,0,176,0,0,0,144,205,35,0,240,199,35,0,64,194,35,0,1,64,13,0,8,0,0,0,176,188,35,0,152,184,35,0,16,179,35,0,6,64,4,0,84,0,0,0,88,174,35,0,0,0,0,0,8,169,35,0,5,64,5,0,72,0,0,0,80,159,35,0,152,184,35,0,40,139,35,0,5,128,6,0,88,0,0,0,168,121,35,0,152,115,35,0,16,107,35,0,1,32,0,0,96,0,0,0,96,101,35,0,32,95,35,0,216,85,35,0,9,128,8,0,220,0,0,0,224,79,35,0,56,71,35,0,0,62,35,0,5,32,8,0,118,0,0,0,88,39,35,0,184,30,35,0,144,24,35,0,6,0,0,0,48,236,129,0,112,19,35,0,0,0,0,0,136,13,35,0,6,0,0,0,40,236,129,0,160,8,35,0,0,0,0,0,120,3,35,0,5,0,0,0,98,0,0,0,224,254,34,0,8,249,34,0,88,244,34,0,6,0,0,0,160,149,6,0,112,225,34,0,0,0,0,0,224,217,34,0,5,0,0,0,100,0,0,0,160,212,34,0,112,207,34,0,32,203,34,0,6,0,0,0,16,236,129,0,24,199,34,0,0,0,0,0,248,194,34,0,6,0,0,0,24,236,129,0,96,190,34,0,0,0,0,0,88,186,34,0,6,64,4,0,80,0,0,0,248,181,34,0,104,111,140,0,168,157,34,0,1,32,8,0,242,0,0,0,192,152,34,0,240,147,34,0,136,143,34,0,5,0,0,0,216,0,0,0,80,139,34,0,104,111,140,0,232,133,34,0,133,0,0,0,248,223,139,0,160,129,34,0,104,111,140,0,232,124,34,0,5,1,0,0,104,48,27,0,112,120,34,0,248,102,34,0,96,97,34,0,6,0,0,0,32,212,133,0,0,93,34,0,0,0,0,0,248,88,34,0,133,0,0,0,48,172,21,0,240,84,34,0,160,80,34,0,64,77,34,0,6,64,8,0,192,0,0,0,128,72,34,0,0,0,0,0,0,68,34,0,9,128,8,0,172,1,0,0,232,63,34,0,104,111,140,0,136,47,34,0,5,1,0,0,232,145,20,0,64,41,34,0,248,102,34,0,80,38,34,0,5,1,0,0,224,145,20,0,96,35,34,0,248,102,34,0,0,32,34,0,6,0,0,0,184,115,124,0,64,29,34,0,112,26,34,0,176,22,34,0,6,128,8,0,92,1,0,0,232,18,34,0,0,0,0,0,96,15,34,0,133,128,8,0,100,1,0,0,72,0,34,0,0,0,0,0,104,249,33,0,1,132,8,0,228,0,0,0,16,246,33,0,184,30,35,0,192,241,33,0,13,128,12,0,244,0,0,0,192,237,33,0,8,234,33,0,176,229,33,0,5,128,10,0,4,1,0,0,144,227,33,0,176,229,33,0,16,225,33,0,5,32,8,0,194,0,0,0,144,227,33,0,176,229,33,0,192,222,33,0,5,32,8,0,206,0,0,0,80,210,33,0,192,222,33,0,208,207,33,0,9,128,8,0,108,1,0,0,16,205,33,0,40,203,33,0,88,200,33,0,9,128,8,0,116,1,0,0,216,196,33,0,80,193,33,0,200,191,33,0,129,128,4,0,124,1,0,0,96,189,33,0,104,111,140,0,144,186,33,0,5,0,0,0,138,0,0,0,112,172,33,0,88,168,33,0,120,166,33,0,5,0,0,0,138,0,0,0,112,172,33,0,88,168,33,0,248,164,33,0,5,0,0,0,62,1,0,0,80,163,33,0,80,193,33,0,88,160,33,0,2,0,0,0,32,147,8,0,232,157,33,0,0,0,0,0,232,155,33,0,5,32,8,0,128,0,0,0,192,153,33,0,80,193,33,0,64,152,33,0,13,128,4,0,96,0,0,0,96,141,33,0,80,193,33,0,136,138,33,0,6,0,0,0,104,6,132,0,232,136,33,0,0,0,0,0,8,136,33,0,1,1,0,0,208,94,10,0,64,134,33,0,48,132,33,0,16,130,33,0,17,32,8,0,42,0,0,0,104,128,33,0,184,30,35,0,232,126,33,0,25,128,12,0,44,0,0,0,128,122,33,0,192,106,33,0,152,100,33,0,25,130,12,0,52,0,0,0,32,95,33,0,136,89,33,0,96,86,33,0,25,128,8,0,28,1,0,0,144,82,33,0,96,86,33,0,248,73,33,0,29,128,12,0,60,0,0,0,104,69,33,0,96,63,33,0,96,57,33,0,145,0,0,0,56,172,79,0,160,45,33,0,184,30,35,0,96,37,33,0,22,0,0,0,160,147,77,0,184,33,33,0,0,0,0,0,112,29,33,0,18,64,12,0,196,0,0,0,56,27,33,0,0,0,0,0,200,23,33,0,149,0,0,0,0,118,39,0,96,21,33,0,128,96,29,0,16,19,33,0,29,128,8,0,36,1,0,0,88,15,33,0,88,14,33,0,32,6,33,0,17,32,12,0,28,1,0,0,120,1,33,0,48,77,29,0,112,255,32,0,20,0,0,0,154,0,0,0,16,253,32,0,0,0,0,0,200,251,32,0,20,0,0,0,154,0,0,0,16,253,32,0,0,0,0,0,88,250,32,0,17,32,8,0,144,0,0,0,152,248,32,0,56,247,32,0,144,245,32,0,145,128,8,0,148,1,0,0,176,244,32,0,128,96,29,0,144,235,32,0,29,128,8,0,156,1,0,0,16,231,32,0,40,229,32,0,72,227,32,0,22,0,0,0,32,236,129,0,152,225,32,0,0,0,0,0,80,224,32,0,22,0,0,0,8,236,129,0,40,222,32,0,0,0,0,0,184,220,32,0,20,0,0,0,192,0,0,0,192,218,32,0,0,0,0,0,104,217,32,0,21,0,0,0,248,0,0,0,192,218,32,0,0,209,32,0,32,204,32,0,17,32,8,0,20,1,0,0,208,201,32,0,40,203,33,0,248,199,32,0,29,128,8,0,44,1,0,0,72,198,32,0,192,196,32,0,80,194,32,0,29,128,8,0,52,1,0,0,152,192,32,0,192,196,32,0,80,191,32,0,29,128,8,0,60,1,0,0,72,198,32,0,192,196,32,0,120,190,32,0,149,128,12,0,68,1,0,0,168,181,32,0,104,111,140,0,112,177,32,0,149,0,0,0,216,219,13,0,24,176,32,0,128,174,32,0,24,173,32,0,21,32,8,0,68,1,0,0,120,171,32,0,8,234,33,0,216,169,32,0,22,0,0,0,208,55,70,0,224,168,32,0,0,0,0,0,248,167,32,0,22,128,8,0,20,1,0,0,240,166,32,0,0,0,0,0,128,160,32,0,21,32,8,0,26,1,0,0,192,155,32,0,112,153,32,0,80,151,32,0,29,128,8,0,12,1,0,0,232,149,32,0,168,148,32,0,248,145,32,0,17,32,8,0,184,0,0,0,192,143,32,0,104,142,32,0,248,141,32,0,29,128,4,0,104,0,0,0,112,134,32,0,216,130,32,0,120,129,32,0,29,128,4,0,112,0,0,0,80,127,32,0,0,0,0,0,16,126,32,0,33,32,8,0,236,0,0,0,160,123,32,0,184,30,35,0,144,121,32,0,33,32,8,0,130,0,0,0,0,120,32,0,40,118,32,0,16,117,32,0,161,128,12,0,36,0,0,0,88,109,32,0,192,106,33,0,128,105,32,0,161,128,12,0,28,0,0,0,16,103,32,0,240,101,32,0,40,101,32,0,34,64,12,0,200,0,0,0,176,99,32,0,0,0,0,0,40,98,32,0,33,32,12,0,142,0,0,0,8,96,32,0,48,77,29,0,104,94,32,0,37,32,8,0,68,1,0,0,240,93,32,0,8,234,33,0,176,87,32,0,161,0,0,0,96,48,27,0,72,84,32,0,176,82,32,0,120,81,32,0,45,128,12,0,252,0,0,0,224,80,32,0,96,63,33,0,200,79,32,0,37,32,12,0,178,0,0,0,0,78,32,0,168,76,32,0,176,75,32,0,33,32,8,0,24,0,0,0,248,72,32,0,40,203,33,0,200,63,32,0,165,128,4,0,164,1,0,0,144,52,32,0,0,0,0,0,152,49,32,0,2,66,12,0,204,0,0,0,240,43,32,0,0,0,0,0,80,41,32,0,1,34,12,0,102,0,0,0,176,37,32,0,48,77,29,0,136,29,32,0,5,34,8,0,68,1,0,0,240,25,32,0,8,234,33,0,112,21,32,0,6,130,4,0,132,1,0,0,208,15,32,0,0,0,0,0,32,8,32,0,9,130,4,0,140,1,0,0,160,2,32,0,136,89,33,0,128,255,31,0,21,0,0,0,148,0,0,0,40,254,31,0,176,252,31,0,8,251,31,0,21,0,0,0,252,0,0,0,168,248,31,0,232,246,31,0,200,245,31,0,6,0,0,0,24,158,77,0,192,244,31,0,104,111,140,0,104,239,31,0,5,65,8,0,188,0,0,0,48,235,31,0,168,233,31,0,96,232,31,0,5,65,8,0,184,0,0,0,56,231,31,0,168,233,31,0,168,229,31,0,6,0,8,0,32,6,71,0,120,227,31,0,104,111,140,0,8,226,31,0,13,128,8,0,236,0,0,0,216,224,31,0,40,224,31,0,192,218,31,0,37,32,8,0,68,1,0,0,136,215,31,0,16,214,31,0,208,212,31,0,21,32,8,0,68,1,0,0,136,215,31,0,144,211,31,0,56,210,31,0,37,32,8,0,76,0,0,0,144,208,31,0,64,30,29,0,72,207,31,0,21,32,8,0,76,0,0,0,0,206,31,0,64,30,29,0,32,205,31,0,5,34,8,0,76,0,0,0,192,200,31,0,64,30,29,0,16,197,31,0,5,32,8,0,76,0,0,0,40,195,31,0,80,193,33,0,32,193,31,0,5,48,12,0,250,0,0,0,0,192,31,0,48,77,29,0,64,190,31,0,18,64,12,0,208,0,0,0,24,188,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,113,31,0,40,110,31,0,64,107,31,0,0,0,0,0,96,58,31,0,248,255,255,255,184,34,31,0,0,0,0,0,24,21,31,0,8,0,0,0,48,7,31,0,16,0,0,0,16,247,30,0,24,0,0,0,232,232,30,0,32,0,0,0,192,218,30,0,40,0,0,0,104,191,32,0,48,0,0,0,6,14,43,52,4,1,1,1,13,1,2,1,1,1,9,0,8,209,31,0,108,0,0,0,208,69,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,93,17,0,248,211,18,0,184,85,17,0,240,156,16,0,184,38,17,0,72,160,18,0,48,252,18,0,40,206,17,0,168,142,16,0,208,207,17,0,136,207,17,0,248,207,17,0,112,208,17,0,32,208,17,0,72,208,17,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,7,0,0,0,15,0,0,0,31,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,7,0,0,0,15,0,0,0,31,0,0,0,63,0,0,0,127,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,0,0,0,2,4,10,20,0,0,0,0,4,12,20,28,28,20,12,4,12,36,60,84,84,60,36,12,20,60,100,140,140,100,60,20,28,84,140,196,196,140,84,28,28,84,140,196,196,140,84,28,20,60,100,140,140,100,60,20,12,36,60,84,84,60,36,12,4,12,20,28,28,20,12,4,16,48,48,16,48,144,144,48,48,144,144,48,16,48,48,16,0,0,0,0,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,8,4,4,4,4,4,4,4,4,0,0,0,0,0,4,4,4,8,8,8,12,12,16,16,16,20,20,20,24,24,20,20,20,16,16,16,12,12,8,8,8,4,4,4,0,0,4,8,8,12,12,16,20,20,24,28,28,32,32,36,40,40,36,32,32,28,28,24,20,20,16,12,12,8,8,4,0,0,4,8,12,16,20,24,28,28,32,36,40,44,48,52,56,56,52,48,44,40,36,32,28,28,24,20,16,12,8,4,0,4,8,12,16,20,24,28,32,40,44,48,52,56,60,64,68,68,64,60,56,52,48,44,40,32,28,24,20,16,12,8,4,4,8,12,20,24,32,36,40,48,52,56,64,68,76,80,84,84,80,76,68,64,56,52,48,40,36,32,24,20,12,8,4,4,8,16,24,28,36,44,48,56,60,68,76,80,88,96,100,100,96,88,80,76,68,60,56,48,44,36,28,24,16,8,4,4,12,20,28,32,40,48,56,64,72,80,88,92,100,108,116,116,108,100,92,88,80,72,64,56,48,40,32,28,20,12,4,4,12,20,28,40,48,56,64,72,80,88,96,108,116,124,132,132,124,116,108,96,88,80,72,64,56,48,40,28,20,12,4,4,16,24,32,44,52,60,72,80,92,100,108,120,128,136,148,148,136,128,120,108,100,92,80,72,60,52,44,32,24,16,4,4,16,28,36,48,56,68,80,88,100,112,120,132,140,152,164,164,152,140,132,120,112,100,88,80,68,56,48,36,28,16,4,4,16,28,40,52,64,76,88,96,108,120,132,144,156,168,180,180,168,156,144,132,120,108,96,88,76,64,52,40,28,16,4,8,20,32,44,56,68,80,92,108,120,132,144,156,168,180,192,192,180,168,156,144,132,120,108,92,80,68,56,44,32,20,8,8,20,32,48,60,76,88,100,116,128,140,156,168,184,196,208,208,196,184,168,156,140,128,116,100,88,76,60,48,32,20,8,8,20,36,52,64,80,96,108,124,136,152,168,180,196,212,224,224,212,196,180,168,152,136,124,108,96,80,64,52,36,20,8,8,24,40,56,68,84,100,116,132,148,164,180,192,208,224,240,240,224,208,192,180,164,148,132,116,100,84,68,56,40,24,8,8,24,40,56,68,84,100,116,132,148,164,180,192,208,224,240,240,224,208,192,180,164,148,132,116,100,84,68,56,40,24,8,8,20,36,52,64,80,96,108,124,136,152,168,180,196,212,224,224,212,196,180,168,152,136,124,108,96,80,64,52,36,20,8,8,20,32,48,60,76,88,100,116,128,140,156,168,184,196,208,208,196,184,168,156,140,128,116,100,88,76,60,48,32,20,8,8,20,32,44,56,68,80,92,108,120,132,144,156,168,180,192,192,180,168,156,144,132,120,108,92,80,68,56,44,32,20,8,4,16,28,40,52,64,76,88,96,108,120,132,144,156,168,180,180,168,156,144,132,120,108,96,88,76,64,52,40,28,16,4,4,16,28,36,48,56,68,80,88,100,112,120,132,140,152,164,164,152,140,132,120,112,100,88,80,68,56,48,36,28,16,4,4,16,24,32,44,52,60,72,80,92,100,108,120,128,136,148,148,136,128,120,108,100,92,80,72,60,52,44,32,24,16,4,4,12,20,28,40,48,56,64,72,80,88,96,108,116,124,132,132,124,116,108,96,88,80,72,64,56,48,40,28,20,12,4,4,12,20,28,32,40,48,56,64,72,80,88,92,100,108,116,116,108,100,92,88,80,72,64,56,48,40,32,28,20,12,4,4,8,16,24,28,36,44,48,56,60,68,76,80,88,96,100,100,96,88,80,76,68,60,56,48,44,36,28,24,16,8,4,4,8,12,20,24,32,36,40,48,52,56,64,68,76,80,84,84,80,76,68,64,56,52,48,40,36,32,24,20,12,8,4,4,8,12,16,20,24,28,32,40,44,48,52,56,60,64,68,68,64,60,56,52,48,44,40,32,28,24,20,16,12,8,4,0,4,8,12,16,20,24,28,28,32,36,40,44,48,52,56,56,52,48,44,40,36,32,28,28,24,20,16,12,8,4,0,0,4,8,8,12,12,16,20,20,24,28,28,32,32,36,40,40,36,32,32,28,28,24,20,20,16,12,12,8,8,4,0,0,4,4,4,8,8,8,12,12,16,16,16,20,20,20,24,24,20,20,20,16,16,16,12,12,8,8,8,4,4,4,0,0,0,0,0,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,8,4,4,4,4,4,4,4,4,0,0,0,0,0,4,4,8,8,12,12,16,16,12,12,8,8,4,4,0,4,8,16,20,28,32,40,44,44,40,32,28,20,16,8,4,4,16,24,36,44,56,64,76,76,64,56,44,36,24,16,4,8,20,36,48,64,76,92,104,104,92,76,64,48,36,20,8,8,28,44,64,80,100,116,136,136,116,100,80,64,44,28,8,12,32,56,76,100,120,144,164,164,144,120,100,76,56,32,12,12,40,64,92,116,144,168,196,196,168,144,116,92,64,40,12,16,44,76,104,136,164,196,224,224,196,164,136,104,76,44,16,16,44,76,104,136,164,196,224,224,196,164,136,104,76,44,16,12,40,64,92,116,144,168,196,196,168,144,116,92,64,40,12,12,32,56,76,100,120,144,164,164,144,120,100,76,56,32,12,8,28,44,64,80,100,116,136,136,116,100,80,64,44,28,8,8,20,36,48,64,76,92,104,104,92,76,64,48,36,20,8,4,16,24,36,44,56,64,76,76,64,56,44,36,24,16,4,4,8,16,20,28,32,40,44,44,40,32,28,20,16,8,4,0,4,4,8,8,12,12,16,16,12,12,8,8,4,4,0,0,0,1,0,82,65,87,65,1,80,1,0,76,65,77,69,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,1,0,65,76,65,87,6,0,1,0,85,76,65,87,1,80,1,0,77,80,51,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,0,1,2,4,1,2,3,4,208,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,23,31,0,108,0,0,0,0,91,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,128,128,0,0,0,0,0,0,0,0,0,0,0,0,0,128,128,128,0,0,0,0,0,0,0,0,30,0,0,0,86,80,51,32,30,0,0,0,86,80,51,48,30,0,0,0,86,80,51,49,91,0,0,0,86,80,53,32,91,0,0,0,86,80,53,48,92,0,0,0,86,80,54,32,92,0,0,0,86,80,54,48,92,0,0,0,86,80,54,49,92,0,0,0,86,80,54,50,141,0,0,0,86,80,56,48,13,0,0,0,88,86,73,68,14,0,0,0,82,71,66,51,0,0,0,0,0,0,0,0,1,80,1,0,77,80,51,32,2,80,1,0,65,65,67,32,2,80,1,0,65,65,67,80,2,80,1,0,86,76,66,32,36,80,1,0,83,80,88,32,2,0,1,0,80,67,77,32,0,0,0,0,0,0,0,0,5,11,17,5,11,17,0,0,10,20,34,10,20,34,0,0,0,1,2,3,4,5,6,7,8,10,12,14,16,18,20,22,24,28,32,36,40,44,48,52,56,64,72,80,88,96,104,112,30,51,22,54,3,7,252,38,14,55,46,81,22,58,253,2,52,31,249,51,15,44,74,30,85,239,10,33,18,80,28,62,10,32,23,69,72,26,35,17,73,60,8,56,2,6,254,251,51,4,11,50,66,76,21,44,33,47,1,26,64,48,57,40,38,16,246,228,92,22,238,29,246,5,243,49,19,24,70,34,61,48,30,14,250,25,58,33,42,60,67,17,54,17,22,30,67,44,247,50,245,43,40,32,59,82,13,49,242,55,60,36,48,49,31,47,15,12,4,65,1,23,29,39,45,254,84,69,0,72,37,57,27,41,241,240,35,31,14,61,24,0,27,24,16,41,55,34,53,9,56,12,25,29,53,5,20,236,248,20,13,28,253,78,38,16,11,62,46,29,21,24,46,65,43,233,89,18,74,21,38,244,19,12,237,8,15,33,4,57,9,248,36,35,26,28,7,83,63,79,75,11,3,87,37,47,34,40,39,19,20,42,27,34,39,77,13,42,59,64,45,255,32,37,45,251,53,250,7,36,50,23,6,32,9,235,18,71,27,52,231,31,35,42,255,68,63,52,26,43,66,37,41,25,40,70,254,127,94,188,0,32,101,189,254,255,138,60,0,72,24,190,0,60,135,190,0,160,202,189,0,180,131,62,2,128,164,60,0,236,56,191,0,20,227,190,0,96,107,190,0,96,44,62,0,36,240,62,255,95,114,61,0,112,27,190,0,116,211,62,2,0,83,188,0,208,8,62,0,4,223,62,0,48,195,189,0,144,21,191,0,12,201,62,0,224,170,189,0,24,131,190,0,248,105,62,0,48,133,62,0,232,39,191,0,8,49,62,0,160,177,189,0,32,85,189,0,128,149,61,0,196,146,190,0,84,183,190,0,48,134,61,0,64,192,189,0,16,88,62,0,36,145,190,0,90,57,191,0,224,78,61,0,208,217,189,0,16,65,190,0,48,152,62,0,0,84,62,0,136,152,190,0,176,192,190,0,156,245,62,0,80,204,189,0,32,167,62,0,192,149,190,0,148,144,190,0,68,133,62,0,32,185,190,0,184,97,62,255,255,3,189,0,208,190,190,1,0,26,189,1,240,202,61,0,112,110,62,0,216,69,62,0,0,20,62,255,63,175,188,0,192,73,190,0,116,161,62,0,112,43,190,0,92,179,62,0,144,182,190,0,74,41,191,250,255,229,187,0,0,86,62,0,104,137,62,0,148,172,190,255,31,59,189,0,8,1,62,0,160,210,61,0,240,149,61,0,48,59,190,0,20,195,62,0,32,90,62,1,0,58,61,254,127,61,60,0,32,135,190,1,64,192,188,0,144,98,190,0,96,152,62,0,132,185,190,0,84,160,190,0,8,15,190,0,240,230,189,0,0,71,190,0,152,176,62,0,0,192,60,0,232,96,62,2,128,227,188,0,66,45,191,0,80,184,189,0,192,17,62,0,208,141,190,0,164,3,63,255,191,78,189,0,112,247,62,0,76,190,62,0,170,27,191,0,200,63,62,0,144,27,190,248,255,208,59,255,255,231,60,0,240,31,190,0,64,27,63,0,128,95,62,0,192,130,61,0,36,163,190,0,144,180,61,0,48,30,62,0,176,143,189,0,0,167,189,0,192,209,190,0,180,203,190,0,208,239,189,0,208,97,62,0,24,61,62,0,184,48,190,1,0,26,61,255,191,125,189,8,0,142,59,0,96,249,61,0,36,174,62,0,32,131,62,1,224,88,189,0,24,210,62,0,152,44,62,0,10,67,191,0,200,13,62,0,216,70,190,0,104,92,190,0,100,227,190,255,31,167,189,0,92,144,190,254,127,153,188,0,248,30,62,0,176,191,190,0,176,229,190,0,168,220,62,0,104,125,190,0,68,255,62,0,40,24,62,0,96,195,62,0,88,82,62,0,148,200,190,0,148,40,191,0,212,223,190,0,128,5,62,255,95,81,189,0,148,204,62,0,160,91,62,255,31,71,189,0,80,172,62,1,224,216,61,0,128,97,191,0,208,157,190,0,132,197,62,0,216,153,62,0,216,198,62,0,192,186,61,0,196,186,190,2,128,134,188,0,216,107,190,0,108,133,62,0,32,65,62,0,240,95,190,0,232,54,190,0,88,152,190,0,64,200,61,255,79,221,61,0,28,4,191,9,0,72,58,0,200,7,62,0,32,227,61,0,160,118,190,0,144,127,62,5,0,98,60,255,159,41,189,0,64,74,189,0,238,18,63,0,88,140,62,0,64,141,62,0,120,230,62,0,224,166,190,0,144,228,61,0,0,31,188,0,244,148,62,1,128,9,61,0,146,53,191,255,255,71,61,0,184,222,62,0,32,158,61,0,20,141,190,2,192,142,188,0,80,172,189,255,255,36,189,0,76,7,191,0,32,150,189,1,64,84,61,0,192,90,62,0,40,64,190,0,144,144,61,255,127,246,188,0,60,167,62,0,92,138,62,0,96,143,190,0,232,51,62,0,192,8,61,0,216,154,62,1,160,32,189,0,188,164,62,0,8,115,190,255,159,175,61,0,240,195,190,0,80,188,61,1,64,148,189,0,184,55,62,0,70,3,191,0,192,128,190,0,168,74,62,0,144,68,190,0,120,41,62,0,96,217,62,0,88,200,62,254,255,234,188,0,32,56,62,0,0,127,62,0,14,68,191,0,160,86,190,0,50,28,63,0,128,189,62,0,184,188,62,0,192,55,189,1,176,218,61,0,200,35,190,0,64,90,189,0,188,145,62,255,127,131,189,0,96,189,190,0,104,143,190,0,240,240,189,1,160,48,61,0,160,164,189,255,31,72,61,2,64,251,188,134,0,224,185,0,144,175,62,5,0,34,188,0,96,178,62,0,124,166,62,0,160,38,190,0,240,195,62,1,192,4,61,1,80,254,61,0,192,18,190,0,180,178,190,0,168,59,190,0,164,150,62,0,188,226,62,0,112,64,63,0,38,44,191,0,96,249,189,0,236,142,62,0,156,152,190,0,104,75,62,0,12,154,62,0,64,104,62,0,144,187,190,0,148,166,190,0,86,19,191,0,104,42,190,0,80,224,62,0,160,170,61,0,64,35,62,0,196,135,62,0,56,120,190,1,224,240,189,0,80,44,190,0,8,18,190,0,72,237,62,0,192,241,61,0,30,14,191,0,128,206,188,0,136,18,190,247,255,146,59,1,64,225,60,0,100,156,190,0,172,53,63,0,244,230,62,0,22,42,63,0,188,46,191,0,240,255,189,0,80,187,61,0,40,88,190,0,160,115,190,0,168,76,63,0,64,180,190,0,160,127,190,0,176,63,62,0,96,67,190,0,192,152,61,0,32,156,61,0,92,147,190,0,16,190,190,0,128,72,190,254,63,145,188,0,48,43,190,0,136,5,62,0,64,22,62,0,252,216,62,1,192,18,61,0,32,234,61,1,192,82,61,0,224,228,62,0,144,183,61,5,0,96,60,0,146,11,191,0,248,1,190,0,216,88,62,0,192,73,61,0,8,157,62,0,224,225,189,0,64,72,62,0,8,142,190,0,248,107,62,0,72,31,62,0,160,69,190,0,188,131,190,0,72,54,62,0,160,18,189,0,128,79,189,0,0,142,189,0,144,194,189,0,48,160,189,0,160,116,62,0,84,163,190,255,191,251,60,255,255,135,187,0,248,28,63,0,88,190,62,0,168,9,190,0,24,31,190,0,200,68,190,0,12,194,190,0,184,76,62,255,127,215,60,0,192,0,190,0,192,132,62,1,128,200,188,0,180,151,62,0,140,208,190,0,128,49,190,0,240,120,62,0,64,217,189,0,216,23,62,0,16,180,61,0,240,63,190,1,64,100,189,255,255,69,189,0,128,214,61,0,160,148,190,0,72,45,191,0,60,144,190,0,112,213,190,255,191,93,61,0,112,110,190,0,176,195,61,0,176,183,189,0,192,26,190,0,112,2,62,0,64,184,62,0,56,148,62,0,36,157,62,0,80,117,62,1,208,142,61,0,188,159,190,0,240,60,190,0,40,100,62,0,48,93,190,0,224,112,62,0,80,30,191,0,64,5,190,0,60,135,62,0,72,242,62,0,96,135,190,0,112,198,62,0,176,49,62,0,168,133,190,0,112,132,190,0,96,251,189,0,60,152,190,0,112,157,61,0,88,62,62,0,224,181,189,0,172,159,62,255,159,89,61,0,240,222,189,0,152,24,190,0,152,100,190,0,224,174,189,0,224,74,62,0,16,74,62,0,208,65,190,0,200,148,62,0,216,130,62,0,212,248,190,0,48,64,62,254,127,92,60,0,160,178,62,0,120,92,62,0,88,75,62,0,24,63,62,253,127,100,188,0,160,185,189,0,144,198,190,0,16,139,62,0,176,80,190,0,116,164,190,0,160,116,190,0,188,138,62,0,128,127,62,0,64,162,61,255,47,153,61,0,108,2,191,0,80,209,61,0,106,21,63,0,184,71,190,0,16,62,190,251,255,62,188,0,164,241,62,0,176,101,62,0,208,197,190,1,224,24,189,1,0,188,189,0,48,143,61,0,176,26,62,0,0,83,62,255,127,116,189,0,32,214,190,0,128,250,61,255,95,63,189,0,160,81,189,1,0,236,189,0,188,4,191,255,255,38,189,0,188,226,62,0,16,36,191,0,72,46,62,253,63,183,60,0,248,105,62,0,184,109,190,0,168,165,190,0,16,16,190,0,4,152,190,0,176,75,190,1,64,227,60,0,176,86,190,0,156,5,191,0,160,69,190,255,79,149,189,0,40,251,62,0,96,100,190,255,31,103,61,0,96,6,62,0,48,85,190,0,254,85,191,0,144,167,189,0,52,137,62,46,0,112,186,255,175,193,189,0,0,47,62,0,88,138,190,0,252,154,62,0,32,97,61,0,224,195,61,0,240,175,189,0,128,174,60,0,248,183,62,0,128,94,62,0,168,29,190,0,0,79,189,255,191,222,60,0,240,38,62,0,64,221,62,0,128,209,61,0,0,209,190,0,168,93,62,1,192,172,61,1,64,228,189,0,156,204,190,0,32,102,189,0,96,209,189,0,192,27,191,0,172,172,62,0,224,129,189,0,136,242,190,0,52,168,190,0,192,86,61,0,16,73,62,0,248,67,190,0,212,45,191,0,176,37,62,1,64,82,61,0,48,100,190,255,143,197,61,0,184,120,62,0,112,230,190,0,80,180,61,0,232,15,62,0,160,103,62,5,0,36,188,0,36,186,62,0,104,75,190,0,120,155,190,0,248,118,190,0,26,19,191,0,172,135,62,0,0,50,61,1,160,200,189,0,76,244,190,0,24,115,190,0,224,63,62,1,208,182,61,255,255,228,188,9,0,72,59,1,48,178,189,0,52,198,190,255,255,3,61,0,16,224,61,0,144,214,190,254,191,132,188,0,244,240,190,0,124,194,62,0,112,93,190,0,164,245,62,0,72,77,190,0,22,32,191,0,196,137,190,2,192,235,188,6,0,220,59,0,216,148,190,0,200,124,190,0,0,33,190,0,104,133,190,0,112,153,62,0,132,144,62,1,32,184,189,0,128,43,190,0,104,239,190,0,88,128,190,0,240,128,190,0,44,235,190,255,191,110,61,0,132,148,62,0,32,116,62,0,16,56,190,0,228,137,62,0,16,219,61,1,64,140,189,0,96,47,190,0,128,215,189,0,202,13,191,0,156,216,190,0,208,155,189,0,168,121,62,0,144,197,62,0,224,44,62,0,248,136,62,0,48,49,62,0,88,183,62,0,64,98,190,0,52,157,190,0,232,145,190,0,0,49,189,0,216,27,62,0,208,46,190,0,100,201,190,0,224,12,61,0,96,221,189,0,160,156,190,0,108,135,62,0,208,151,189,0,168,11,62,3,0,46,188,0,88,143,62,0,32,52,61,0,160,99,189,0,192,17,191,0,192,9,61,3,128,27,188,0,196,6,63,0,248,226,190,0,240,144,62,1,64,97,189,0,184,110,190,0,240,152,190,255,223,81,189,0,96,137,62,0,108,180,190,0,176,158,190,0,100,177,62,0,128,74,190,0,84,228,62,0,0,13,62,0,60,232,62,0,104,76,62,0,136,218,62,0,0,33,62,15,0,168,58,0,72,115,62,0,220,209,62,0,216,128,62,3,0,240,187,1,16,254,189,0,80,222,190,255,255,131,187,0,84,175,62,0,172,185,62,0,152,64,62,0,128,190,189,0,224,210,189,0,160,98,61,0,16,162,190,0,208,18,62,0,104,179,62,0,156,166,62,255,159,106,61,0,96,246,189,0,212,132,190,0,0,80,190,0,224,40,190,0,200,235,190,0,240,163,189,0,250,1,63,0,144,37,62,0,156,145,62,0,0,166,61,0,160,67,190,0,148,197,62,0,240,39,190,0,84,130,190,0,176,79,62,0,72,84,190,0,64,129,189,0,164,168,62,0,240,25,62,0,192,90,189,0,24,156,62,1,144,238,189,0,156,194,62,0,112,77,190,0,140,222,62,3,128,60,60,0,16,183,62,0,160,6,190,0,198,44,63,255,127,85,61,0,236,142,62,0,228,201,190,0,202,64,63,0,224,8,190,0,104,122,62,0,80,216,62,0,184,40,191,8,0,179,187,0,0,15,189,0,224,11,190,0,224,169,189,0,208,233,190,0,52,139,62,0,96,2,62,0,138,28,63,0,0,214,61,0,164,147,190,46,0,112,58,0,24,124,62,0,88,6,62,1,224,104,61,0,184,49,62,0,56,215,62,0,96,174,61,0,64,123,62,0,16,66,62,0,168,67,190,0,248,25,190,1,64,191,60,0,196,12,63,0,124,165,62,0,232,36,190,2,64,250,188,0,52,223,62,0,64,49,62,0,76,28,63,0,64,125,62,0,172,170,62,0,16,28,62,0,160,31,62,0,128,186,62,0,176,155,190,0,56,8,190,254,255,139,59,0,224,42,61,0,224,169,190,0,48,175,62,0,64,255,189,2,128,226,188,255,223,113,61,0,244,160,190,0,72,41,62,0,220,176,62,1,224,6,189,0,72,0,62,0,48,252,189,0,224,6,190,255,223,66,61,0,228,230,190,0,112,67,190,0,244,180,62,0,248,109,190,0,16,176,190,0,176,230,61,0,48,33,190,1,0,88,61,0,218,63,63,0,56,92,62,0,96,174,61,0,12,217,190,0,0,72,190,0,180,180,62,0,144,129,62,0,24,33,62,0,8,52,191,0,24,93,190,0,76,182,62,0,184,16,62,1,32,240,61,0,88,34,62,0,224,123,190,0,192,143,61,255,63,174,60,0,160,1,62,0,224,130,61,255,191,251,189,0,32,30,62,0,236,243,190,255,191,125,61,0,254,22,63,0,40,27,190,0,160,19,189,0,180,230,190,254,255,136,188,0,160,240,190,0,216,131,62,0,48,57,62,0,112,136,61,0,184,7,62,0,164,45,63,1,224,232,61,0,240,231,61,0,224,60,189,0,144,159,189,0,28,187,190,1,48,138,189,0,196,161,190,0,48,37,62,0,244,214,62,0,192,226,61,0,224,188,190,0,136,158,62,0,236,193,190,0,200,21,63,5,0,129,59,0,176,252,61,255,63,12,61,0,128,94,190,0,120,3,190,0,140,240,190,255,95,112,61,0,20,128,190,0,84,140,62,0,4,39,63,0,72,176,190,0,112,27,190,0,240,15,62,0,140,171,62,0,152,147,62,0,48,203,61,0,20,176,62,0,216,11,62,0,192,113,190,251,127,13,60,253,63,215,60,0,200,67,190,0,128,74,62,255,191,147,189,0,240,159,61,0,128,13,61,1,0,12,189,141,255,175,57,0,128,108,190,0,56,63,62,0,128,109,61,255,63,28,61,255,223,48,189,1,192,96,61,0,208,176,61,0,60,15,63,0,0,130,189,0,160,211,61,0,144,129,62,255,191,111,61,0,208,250,61,0,200,130,190,0,108,175,190,0,144,186,190,0,40,90,190,1,160,80,189,2,128,227,60,0,16,156,61,0,64,89,190,0,0,191,189,0,200,66,62,0,196,207,190,253,127,67,188,0,56,75,62,0,236,180,190,0,128,151,189,0,224,77,62,0,112,176,61,0,52,227,190,0,224,233,61,0,104,122,62,0,136,41,190,1,32,80,189,252,127,102,188,0,208,142,62,0,104,63,190,0,16,153,61,0,96,13,61,0,112,203,190,0,168,92,62,0,192,102,190,0,4,203,190,0,96,76,189,0,158,19,191,0,224,130,61,0,198,30,63,0,240,9,190,0,0,50,61,0,224,95,190,2,128,228,188,0,88,4,63,0,64,141,190,0,180,199,62,0,224,201,61,248,255,241,187,0,88,160,62,213,255,255,57,0,116,238,190,0,52,151,62,1,0,205,189,0,160,142,190,1,64,19,61,0,64,128,62,0,240,62,191,0,204,129,190,0,64,7,189,0,176,159,62,255,191,128,60,0,40,239,62,0,24,93,62,0,176,148,61,0,184,215,190,0,252,9,191,0,8,12,190,0,176,41,190,0,104,176,190,0,32,253,61,255,15,229,189,254,127,30,60,0,8,177,62,1,0,108,189,0,108,178,62,0,176,52,62,0,180,201,190,255,191,211,61,0,136,58,62,0,240,83,62,0,82,23,63,1,192,236,189,0,64,151,189,0,240,212,61,0,112,181,62,0,32,106,190,2,0,147,60,0,208,51,62,0,40,51,190,0,176,248,61,0,208,223,61,0,0,128,191,5,0,98,188,0,120,89,62,0,108,138,190,0,224,139,62,0,200,189,190,0,188,211,62,0,20,205,190,250,255,225,59,0,196,134,62,0,12,201,62,0,42,39,63,0,32,213,62,0,112,14,190,0,164,72,63,0,108,158,190,0,136,78,62,0,144,201,190,0,178,112,63,0,112,118,190,0,160,99,61,0,56,123,190,0,0,95,189,0,126,68,191,0,104,70,190,0,32,226,189,0,136,51,190,0,232,35,62,254,63,179,60,0,216,50,62,255,223,49,189,0,90,17,191,0,220,209,190,0,164,136,62,255,159,239,61,16,0,98,187,1,0,93,189,0,160,191,62,0,124,208,190,0,240,25,190,255,255,135,188,0,224,43,61,0,192,58,189,0,208,4,190,0,0,246,61,0,112,172,61,0,96,229,189,0,24,180,62,1,112,210,61,0,132,131,190,0,12,248,62,0,32,4,61,0,116,145,62,0,128,63,190,0,196,185,62,1,96,6,189,0,100,165,62,0,120,48,62,0,36,247,62,0,76,159,62,255,159,74,189,0,208,2,62,0,224,6,63,0,32,209,61,255,223,115,61,0,192,117,61,0,72,78,62,2,0,244,59,0,220,139,62,0,160,121,62,0,32,203,62,1,128,139,60,0,212,181,190,0,192,232,61,0,208,10,190,0,68,250,62,0,224,29,190,0,96,187,189,254,63,214,188,0,200,236,62,0,246,56,191,0,176,100,62,0,56,116,62,0,132,131,190,0,96,174,189,254,255,168,188,0,156,176,190,2,64,188,188,0,202,77,191,0,96,165,189,0,240,1,190,0,64,141,189,0,200,118,62,0,136,182,190,255,191,195,189,0,200,149,62,0,224,108,62,0,72,43,190,0,0,0,0,0,48,120,190,0,52,158,62,0,16,151,62,0,0,86,190,0,176,46,62,0,32,157,189,0,104,19,190,1,64,100,61,0,248,82,62,0,248,3,191,1,192,1,189,0,16,250,190,0,40,81,190,0,216,16,62,1,0,149,61,0,70,68,191,0,72,102,190,0,120,83,62,255,127,5,61,218,255,95,58,1,0,249,60,0,124,243,62,0,92,196,62,160,225,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,19,33,0,0,247,31,0,52,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,120,35,31,0,120,115,30,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,56,232,29,0,120,115,30,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,32,123,29,0,8,35,29,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,32,123,29,0,136,211,28,0,8,35,29,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,32,123,29,0,104,206,35,0,16,124,35,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,32,123,29,0,56,32,35,0,208,218,34,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,32,123,29,0,232,158,34,0,40,98,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,32,123,29,0,120,42,34,0,200,251,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,32,123,29,0,88,208,33,0,0,247,31,0,72,194,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,184,169,33,0,120,115,30,0,60,193,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,168,139,33,0,120,115,30,0,60,193,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,200,101,33,0,8,35,29,0,64,193,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,200,101,33,0,224,37,33,0,8,35,29,0,64,193,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,200,101,33,0,104,206,35,0,16,124,35,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,101,33,0,56,32,35,0,208,218,34,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,101,33,0,232,158,34,0,40,98,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,101,33,0,120,42,34,0,200,251,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,101,33,0,232,1,33,0,80,231,32,0,92,131,1,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,64,204,32,0,152,177,32,0,80,130,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,40,156,32,0,152,177,32,0,80,130,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,240,130,32,0,192,105,32,0,84,130,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,240,130,32,0,120,84,32,0,192,105,32,0,84,130,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,240,130,32,0,104,206,35,0,16,124,35,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,130,32,0,56,32,35,0,208,218,34,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,130,32,0,232,158,34,0,40,98,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,130,32,0,120,42,34,0,200,251,33,0,0,0,0,0,128,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+625997);
/* memory initializer */ allocate([16,0,1,0,240,130,32,0,56,56,32,0,32,3,32,0,112,68,2,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,176,235,31,0,160,215,31,0,100,67,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,64,197,31,0,160,215,31,0,100,67,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,8,174,31,0,136,156,31,0,104,67,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,8,174,31,0,176,138,31,0,136,156,31,0,104,67,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,8,174,31,0,104,206,35,0,16,124,35,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,174,31,0,56,32,35,0,208,218,34,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,174,31,0,232,158,34,0,40,98,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,174,31,0,120,42,34,0,200,251,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,174,31,0,8,122,31,0,88,107,31,0,132,5,3,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,176,83,31,0,8,43,31,0,120,4,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,144,27,31,0,8,43,31,0,120,4,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,248,14,31,0,152,255,30,0,124,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,248,14,31,0,120,239,30,0,152,255,30,0,124,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,248,14,31,0,104,206,35,0,16,124,35,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,14,31,0,56,32,35,0,208,218,34,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,14,31,0,232,158,34,0,40,98,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,14,31,0,120,42,34,0,200,251,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,14,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,225,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,2,0,0,0,0,0,0,0,0,0,0,90,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,121,32,0,108,0,0,0,88,176,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,29,33,0,108,0,0,0,16,96,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,27,91,48,59,51,48,59,52,48,109,78,69,88,84,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,192,124,35,0,0,0,0,0,116,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,233,29,0,108,0,0,0,64,186,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,128,128,255,0,0,0,0,12,128,128,255,0,0,0,0,0,1,2,2,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,3,2,1,2,0,0,0,0,3,2,1,2,0,0,0,0,2,4,0,0,0,0,0,0,3,5,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,72,0,6,14,43,52,2,5,1,1,13,1,3,1,4,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,6,1,0,14,0,0,0,0,0,1,0,6,14,43,52,4,1,1,2,13,1,3,1,2,4,64,1,14,0,0,0,0,80,1,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,1,1,14,0,0,0,0,0,1,0,6,14,43,52,1,1,1,255,75,70,65,65,0,13,77,79,14,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,14,6,6,2,2,1,0,0,233,3,0,0,192,93,0,0,210,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,24,0,0,0,208,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,233,3,0,0,48,117,0,0,66,6,0,0,65,6,0,0,66,6,0,0,65,6,0,0,66,6,0,0,0,0,0,0,233,3,0,0,96,234,0,0,33,3,0,0,33,3,0,0,33,3,0,0,33,3,0,0,32,3,0,0,0,0,0,0,1,0,0,0,25,0,0,0,128,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,50,0,0,0,192,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,17,1,0,6,14,43,52,4,1,1,2,13,1,3,1,2,4,96,1,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,65,1,14,0,0,0,25,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,5,0,0,14,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,81,0,6,14,43,52,4,1,1,3,4,1,2,2,1,1,16,0,6,14,43,52,4,1,1,3,4,1,2,2,1,1,17,0,6,14,43,52,4,1,1,3,4,1,2,2,1,2,2,0,6,14,43,52,4,1,1,3,4,1,2,2,1,2,3,0,6,14,43,52,4,1,1,3,4,1,2,2,1,3,2,0,6,14,43,52,4,1,1,3,4,1,2,2,1,3,3,0,6,14,43,52,4,1,1,3,4,1,2,2,1,4,2,0,6,14,43,52,4,1,1,3,4,1,2,2,1,4,3,0,6,14,43,52,4,1,1,3,4,1,2,2,1,5,2,0,6,14,43,52,4,1,1,3,4,1,2,2,1,5,3,0,6,14,43,52,2,5,1,1,13,1,2,1,1,5,1,0,100,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,1,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,2,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,3,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,4,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,1,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,2,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,3,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,4,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,4,2,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,4,4,0,104,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,48,0,26,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,24,0,32,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,55,0,38,0,0,0,64,0,0,0,2,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,54,0,86,0,0,0,64,0,0,0,1,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,15,0,8,0,0,0,56,0,0,0,5,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,17,0,22,0,0,0,80,0,0,0,3,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,68,0,10,0,0,0,128,0,0,0,6,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,66,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,40,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,41,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,81,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,72,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,71,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,58,0,40,0,0,0,80,0,0,0,8,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,59,0,40,0,0,0,80,0,0,0,8,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,20,0,52,0,0,0,56,0,0,0,4,0,0,0,6,14,43,52,2,83,1,1,13,1,4,1,2,2,0,0,62,0,0,0,36,0,0,0,9,0,0,0,6,14,43,52,2,83,1,1,13,1,2,1,1,16,1,0,74,0,0,0,72,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,60,0,0,6,14,43,52,1,1,1,1,1,1,21,2,0,0,0,0,2,59,0,0,6,14,43,52,1,1,1,2,7,2,1,16,2,4,0,0,5,59,0,0,6,14,43,52,1,1,1,2,3,1,2,1,5,0,0,0,6,59,0,0,6,14,43,52,1,1,1,2,6,1,1,4,6,4,0,0,3,59,0,0,6,14,43,52,1,1,1,2,6,1,1,4,2,1,0,0,9,59,0,0,6,14,43,52,1,1,1,5,1,2,2,3,0,0,0,0,10,59,0,0,6,14,43,52,1,1,1,5,1,2,2,16,2,1,0,0,11,59,0,0,6,14,43,52,1,1,1,5,1,2,2,16,2,2,0,0,9,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,1,0,0,0,1,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,2,1,0,0,2,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,3,1,0,0,4,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,5,1,0,0,5,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,7,0,0,0,6,60,0,0,6,14,43,52,1,1,1,2,7,2,1,16,2,3,0,0,1,25,0,0,6,14,43,52,1,1,1,2,6,1,1,4,5,1,0,0,2,25,0,0,6,14,43,52,1,1,1,2,6,1,1,4,5,2,0,0,1,39,0,0,6,14,43,52,1,1,1,2,6,1,1,6,1,0,0,0,7,63,0,0,6,14,43,52,1,1,1,4,1,3,4,4,0,0,0,0,1,68,0,0,6,14,43,52,1,1,1,1,1,1,21,16,0,0,0,0,5,68,0,0,6,14,43,52,1,1,1,2,7,2,1,16,1,3,0,0,4,68,0,0,6,14,43,52,1,1,1,2,7,2,1,16,2,5,0,0,3,68,0,0,6,14,43,52,1,1,1,2,6,1,1,4,6,5,0,0,1,71,0,0,6,14,43,52,1,1,1,2,6,1,1,4,2,3,0,0,1,72,0,0,6,14,43,52,1,1,1,2,1,7,1,1,0,0,0,0,4,72,0,0,6,14,43,52,1,1,1,2,1,4,1,3,0,0,0,0,1,75,0,0,6,14,43,52,1,1,1,2,5,48,4,5,0,0,0,0,2,75,0,0,6,14,43,52,1,1,1,2,7,2,1,3,1,3,0,0,3,72,0,0,6,14,43,52,1,1,1,2,6,1,1,4,2,4,0,0,1,2,0,0,6,14,43,52,1,1,1,2,4,7,1,0,0,0,0,0,2,2,0,0,6,14,43,52,1,1,1,2,7,2,2,1,1,3,0,0,1,16,0,0,6,14,43,52,1,1,1,2,6,1,1,4,6,9,0,0,1,18,0,0,6,14,43,52,1,1,1,2,7,2,1,3,1,4,0,0,1,17,0,0,6,14,43,52,1,1,1,2,6,1,1,3,1,0,0,0,2,17,0,0,6,14,43,52,1,1,1,2,6,1,1,3,2,0,0,0,1,21,0,0,6,14,43,52,1,1,1,2,7,2,1,3,1,5,0,0,2,21,0,0,6,14,43,52,1,1,1,2,4,4,1,1,2,6,0,0,3,21,0,0,6,14,43,52,1,1,1,1,4,4,1,1,5,0,0,0,1,63,0,0,6,14,43,52,1,1,1,4,6,1,1,4,6,11,0,0,6,48,0,0,6,14,43,52,1,1,1,5,6,1,1,3,5,0,0,0,1,48,0,0,6,14,43,52,1,1,1,1,4,6,1,1,0,0,0,0,4,48,0,0,6,14,43,52,1,1,1,2,6,1,1,4,1,2,0,0,12,50,0,0,6,14,43,52,1,1,1,1,4,1,3,1,4,0,0,0,13,50,0,0,6,14,43,52,1,1,1,2,4,1,3,2,5,0,0,0,3,50,0,0,6,14,43,52,1,1,1,1,4,1,5,2,2,0,0,0,2,50,0,0,6,14,43,52,1,1,1,1,4,1,5,2,1,0,0,0,9,50,0,0,6,14,43,52,1,1,1,1,4,1,5,1,12,0,0,0,8,50,0,0,6,14,43,52,1,1,1,1,4,1,5,1,11,0,0,0,14,50,0,0,6,14,43,52,1,1,1,1,4,1,1,1,1,0,0,0,1,50,0,0,6,14,43,52,1,1,1,2,4,1,6,1,0,0,0,0,18,50,0,0,6,14,43,52,1,1,1,2,4,1,3,1,6,0,0,0,1,51,0,0,6,14,43,52,1,1,1,2,4,1,5,3,10,0,0,0,2,51,0,0,6,14,43,52,1,1,1,1,4,1,5,1,5,0,0,0,2,61,0,0,6,14,43,52,1,1,1,4,4,2,3,1,4,0,0,0,3,61,0,0,6,14,43,52,1,1,1,5,4,2,3,1,1,1,0,0,7,61,0,0,6,14,43,52,1,1,1,5,4,2,1,1,4,0,0,0,1,61,0,0,6,14,43,52,1,1,1,4,4,2,3,3,4,0,0,0,6,61,0,0,6,14,43,52,1,1,1,2,4,2,4,2,0,0,0,0,11,63,0,0,6,14,43,52,1,1,1,5,5,48,4,6,0,0,0,0,12,63,0,0,6,14,43,52,1,1,1,5,7,2,1,3,1,10,0,0,13,63,0,0,6,14,43,52,1,1,1,5,7,2,2,1,1,2,0,0,5,63,0,0,6,14,43,52,1,1,1,4,4,6,2,1,0,0,0,0,6,63,0,0,6,14,43,52,1,1,1,4,1,3,4,5,0,0,0,0,8,63,0,0,6,14,43,52,1,1,1,4,4,4,4,1,1,0,0,0,9,63,0,0,6,14,43,52,1,1,1,5,4,4,4,1,6,0,0,0,10,63,0,0,6,14,43,52,1,1,1,5,4,4,4,2,5,0,0,0,0,128,0,0,6,14,43,52,1,1,1,5,4,1,6,2,1,11,0,0,7,128,0,0,6,14,43,52,1,1,1,5,4,1,6,2,1,10,0,0,9,61,0,0,6,14,43,52,1,1,1,5,4,2,3,3,5,0,0,0,10,61,0,0,6,14,43,52,1,1,1,5,4,2,3,2,1,0,0,0,0,0,0,0,6,14,43,52,0,0,0,0,6,14,43,52,4,1,1,10,4,1,2,2,1,50,0,0,14,0,0,0,28,0,0,0,6,14,43,52,4,1,1,7,4,1,2,2,3,1,1,0,14,0,0,0,89,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,0,0,14,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,66,0,2,0,0,0,0,0,0,0,12,0,1,0,1,0,0,0,0,0,1,0,1,0,0,0,25,0,0,0,15,0,0,0,100,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,1,2,1,1,13,1,3,1,0,0,0,0,6,14,43,52,4,1,1,2,13,1,3,1,2,4,96,1,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,3,4,1,2,2,1,0,0,0,142,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,6,3,0,6,14,43,52,1,2,1,1,13,1,3,1,22,1,3,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,66,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,6,1,0,6,14,43,52,1,2,1,1,13,1,3,1,22,1,1,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,132,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,1,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,1,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,1,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,138,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,2,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,2,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,2,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,138,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,3,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,3,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,3,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,138,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,4,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,4,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,4,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,138,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,5,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,5,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,5,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,138,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,6,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,6,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,6,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,138,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,127,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,0,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,64,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,1,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,65,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,2,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,80,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,3,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,81,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,4,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,96,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,5,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,97,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,6,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,98,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,7,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,99,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,8,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,1,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,3,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,4,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,7,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,8,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,9,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,16,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,17,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,18,0,0,128,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,19,0,0,128,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,4,1,7,13,1,3,1,2,126,1,0,6,14,43,52,4,1,1,7,13,1,3,1,2,11,1,0,67,72,85,75,67,72,85,75,67,72,85,75,67,72,85,75,6,14,43,52,1,1,1,9,6,1,1,2,2,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,40,0,6,14,43,52,1,2,1,1,14,4,3,1,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,71,0,0,0,0,0,255,255,255,255,254,255,255,255,253,255,255,255,252,255,255,255,251,255,255,255,250,255,255,255,249,255,255,255,248,255,255,255,247,255,255,255,246,255,255,255,245,255,255,255,244,255,255,255,243,255,255,255,242,255,255,255,241,255,255,255,240,255,255,255,0,0,0,0,5,6,9,10,0,0,0,0,0,0,0,255,255,0,1,0,0,1,255,255,1,255,255,1,1,1,0,254,254,0,2,0,0,2,255,254,1,254,254,255,2,255,254,1,2,1,255,2,1,2,254,254,2,254,254,2,2,2,0,253,253,0,3,0,0,3,255,253,1,253,253,255,3,255,253,1,3,1,255,3,1,3,254,253,2,253,253,254,3,254,253,2,3,2,254,3,2,3,0,252,252,0,4,0,0,4,255,252,1,252,252,255,4,255,4,1,255,4,1,4,253,253,253,3,3,3,254,252,252,254,4,254,252,2,254,4,2,4,253,252,3,252,4,253,251,0,252,3,253,4,3,4,255,251,251,255,251,1,255,5,254,251,2,251,5,254,5,2,252,252,252,4,253,251,251,253,251,3,3,5,250,0,0,6,250,255,250,1,1,6,2,250,250,2,2,6,251,252,5,4,4,5,250,253,6,3,249,0,255,249,5,251,249,1,255,7,4,250,6,4,254,249,249,2,253,249,7,253,3,7,6,251,0,248,255,248,249,252,248,1,4,7,2,248,254,8,6,6,248,3,5,249,251,7,8,252,0,247,247,255,1,9,7,250,249,6,251,248,251,8,247,3,9,252,7,249,8,250,6,8,10,1,246,2,9,251,10,253,248,249,246,252,6,247,245,0,11,1,245,254,254,11,7,247,249,9,10,6,252,11,8,247,8,9,5,11,7,246,12,253,11,6,247,247,8,10,5,12,245,7,13,2,6,244,10,9,245,8,249,12,0,14,14,254,247,11,250,13,242,252,251,242,5,14,241,255,242,250,3,241,11,245,249,14,251,15,8,242,15,6,3,16,7,241,240,5,0,17,240,250,246,14,240,7,12,13,240,8,239,6,238,3,249,17,15,11,16,10,2,237,3,237,245,240,238,8,237,250,2,236,239,245,246,238,8,19,235,255,236,7,252,21,21,5,15,16,2,234,246,236,234,5,20,245,249,234,244,20,23,251,13,236,24,254,241,19,245,22,16,19,23,246,238,238,247,232,24,246,253,26,233,13,238,236,17,21,252,27,27,6,1,228,245,26,239,233,7,28,11,229,29,5,233,237,228,245,235,22,226,7,239,26,229,16,13,29,19,230,10,225,242,226,20,229,227,18,240,225,228,234,21,226,231,28,26,227,25,224,224,224,224,84,34,0,8,32,34,0,16,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,16,238,33,0,8,32,34,0,16,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,192,200,33,0,192,163,33,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,134,33,0,232,84,33,0,20,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,3,13,1,3,1,2,127,1,0,48,234,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,6,5,8,4,3,1,2,0,2,3,4,5,6,7,1,8,0,0,0,0,0,0,0,2,2,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,5,1,2,0,0,0,0,0,0,0,0,0,0,0,0,1,5,1,1,1,1,2,0,0,0,0,0,0,0,0,0,3,1,1,1,1,1,1,1,2,0,0,0,0,0,0,1,2,3,0,4,17,5,18,33,49,65,6,19,81,97,7,34,113,20,50,129,145,161,8,35,66,177,193,21,82,209,240,36,51,98,114,130,9,10,22,23,24,25,26,37,38,39,40,41,42,52,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,225,226,227,228,229,230,231,232,233,234,241,242,243,244,245,246,247,248,249,250,0,1,2,3,17,4,5,33,49,6,18,65,81,7,97,113,19,34,50,129,8,20,66,145,161,177,193,9,35,51,82,240,21,98,114,209,10,22,36,52,225,37,241,23,24,25,26,38,39,40,41,42,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,130,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,226,227,228,229,230,231,232,233,234,242,243,244,245,246,247,248,249,250,0,0,0,0,0,2,1,3,3,2,4,3,5,5,4,4,0,0,1,125,0,2,1,2,4,4,3,4,7,5,4,4,0,1,2,119,144,14,29,0,108,0,0,0,168,235,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,8,29,0,108,0,0,0,168,235,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,62,63,72,157,32,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,186,28,0,168,183,35,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,120,93,35,0,72,8,35,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,8,29,0,108,0,0,0,184,213,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,110,100,0,0,0,0,0,40,234,33,0,88,197,33,0,48,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,120,93,35,0,72,8,35,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,35,32,0,108,0,0,0,144,70,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,29,34,0,108,0,0,0,128,214,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,176,0,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,168,169,31,0,108,0,0,0,96,73,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,5,30,0,108,0,0,0,240,121,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,1,0,136,88,1,0,0,250,0,0,128,187,0,0,68,172,0,0,0,125,0,0,192,93,0,0,34,86,0,0,128,62,0,0,224,46,0,0,17,43,0,0,64,31,0,0,182,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,100,29,0,1,0,0,0,216,94,29,0,2,0,0,0,160,88,29,0,3,0,0,0,8,82,29,0,4,0,0,0,136,74,29,0,5,0,0,0,192,67,29,0,6,0,0,0,88,41,29,0,7,0,0,0,88,33,29,0,8,0,0,0,136,27,29,0,9,0,0,0,72,21,29,0,10,0,0,0,168,14,29,0,11,0,0,0,144,8,29,0,12,0,0,0,64,4,29,0,13,0,0,0,184,254,28,0,14,0,0,0,112,250,28,0,15,0,0,0,152,242,28,0,157,255,255,255,0,0,0,0,224,209,28,0,232,202,28,0,100,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,104,196,28,0,16,191,28,0,188,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,254,1,2,0,0,0,0,104,217,28,0,108,0,0,0,184,216,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,6,0,3,0,7,0,4,0,28,0,5,0,29,0,5,0,5,0,6,0,4,0,6,0,123,0,7,0,124,0,7,0,35,0,8,0,34,0,8,0,250,0,8,0,251,0,8,0,254,0,8,0,255,0,8,0,31,0,14,0,30,0,14,0,29,0,14,0,28,0,14,0,27,0,14,0,26,0,14,0,25,0,14,0,24,0,14,0,23,0,14,0,22,0,14,0,21,0,14,0,20,0,14,0,19,0,14,0,18,0,14,0,17,0,14,0,16,0,14,0,24,0,15,0,23,0,15,0,22,0,15,0,21,0,15,0,20,0,15,0,19,0,15,0,18,0,15,0,17,0,15,0,16,0,15,0,2,0,3,0,6,0,5,0,121,0,7,0,39,0,8,0,32,0,8,0,22,0,13,0,21,0,13,0,31,0,15,0,30,0,15,0,29,0,15,0,28,0,15,0,27,0,15,0,26,0,15,0,25,0,15,0,19,0,16,0,18,0,16,0,17,0,16,0,16,0,16,0,5,0,5,0,7,0,7,0,252,0,8,0,12,0,10,0,20,0,13,0,7,0,5,0,38,0,8,0,28,0,12,0,19,0,13,0,6,0,6,0,253,0,8,0,18,0,12,0,7,0,6,0,4,0,9,0,18,0,13,0,6,0,7,0,30,0,12,0,20,0,16,0,4,0,7,0,21,0,12,0,5,0,7,0,17,0,12,0,120,0,7,0,17,0,13,0,122,0,7,0,16,0,13,0,33,0,8,0,26,0,16,0,37,0,8,0,25,0,16,0,36,0,8,0,24,0,16,0,5,0,9,0,23,0,16,0,7,0,9,0,22,0,16,0,13,0,10,0,21,0,16,0,31,0,12,0,26,0,12,0,25,0,12,0,23,0,12,0,22,0,12,0,31,0,13,0,30,0,13,0,29,0,13,0,28,0,13,0,27,0,13,0,31,0,16,0,30,0,16,0,29,0,16,0,28,0,16,0,27,0,16,0,1,0,6,0,6,0,4,0,0,0,0,0,0,0,0,0,56,152,30,0,1,0,0,0,208,5,30,0,2,0,0,0,48,151,29,0,3,0,0,0,168,56,29,0,4,0,0,0,168,232,28,0,5,0,0,0,224,225,35,0,156,255,255,255,152,147,35,0,156,255,255,255,152,147,35,0,157,255,255,255,0,0,0,0,152,232,28,0,176,225,35,0,176,55,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,17,0,0,0,0,0,0,0,136,147,35,0,40,52,35,0,116,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,8,237,34,0,136,173,34,0,164,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,144,113,34,0,144,57,34,0,168,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,9,34,0,248,217,33,0,112,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,128,181,33,0,248,147,33,0,120,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,184,114,33,0,168,50,33,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,184,114,33,0,32,10,33,0,240,239,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,184,114,33,0,80,212,32,0,224,184,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,184,114,33,0,240,162,32,0,88,138,32,0,0,0,0,0,128,0,0,0,4], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+636248);
/* memory initializer */ allocate([17,0,0,0,184,114,33,0,104,113,32,0,152,90,32,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,184,114,33,0,200,66,32,0,24,11,32,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,152,241,31,0,120,220,31,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,184,202,31,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,184,180,31,0,224,161,31,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,144,56,29,0,108,0,0,0,144,219,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,2,0,4,0,4,0,5,0,5,0,6,0,7,0,38,0,8,0,33,0,8,0,10,0,10,0,29,0,12,0,24,0,12,0,19,0,12,0,16,0,12,0,26,0,13,0,25,0,13,0,24,0,13,0,23,0,13,0,31,0,14,0,30,0,14,0,29,0,14,0,28,0,14,0,27,0,14,0,26,0,14,0,25,0,14,0,24,0,14,0,23,0,14,0,22,0,14,0,21,0,14,0,20,0,14,0,19,0,14,0,18,0,14,0,17,0,14,0,16,0,14,0,24,0,15,0,23,0,15,0,22,0,15,0,21,0,15,0,20,0,15,0,19,0,15,0,18,0,15,0,17,0,15,0,16,0,15,0,3,0,3,0,6,0,6,0,37,0,8,0,12,0,10,0,27,0,12,0,22,0,13,0,21,0,13,0,31,0,15,0,30,0,15,0,29,0,15,0,28,0,15,0,27,0,15,0,26,0,15,0,25,0,15,0,19,0,16,0,18,0,16,0,17,0,16,0,16,0,16,0,5,0,4,0,4,0,7,0,11,0,10,0,20,0,12,0,20,0,13,0,7,0,5,0,36,0,8,0,28,0,12,0,19,0,13,0,6,0,5,0,15,0,10,0,18,0,12,0,7,0,6,0,9,0,10,0,18,0,13,0,5,0,6,0,30,0,12,0,20,0,16,0,4,0,6,0,21,0,12,0,7,0,7,0,17,0,12,0,5,0,7,0,17,0,13,0,39,0,8,0,16,0,13,0,35,0,8,0,26,0,16,0,34,0,8,0,25,0,16,0,32,0,8,0,24,0,16,0,14,0,10,0,23,0,16,0,13,0,10,0,22,0,16,0,8,0,10,0,21,0,16,0,31,0,12,0,26,0,12,0,25,0,12,0,23,0,12,0,22,0,12,0,31,0,13,0,30,0,13,0,29,0,13,0,28,0,13,0,27,0,13,0,31,0,16,0,30,0,16,0,29,0,16,0,28,0,16,0,27,0,16,0,1,0,6,0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,0,152,232,28,0,176,225,35,0,176,55,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,17,0,0,0,0,0,0,0,136,147,35,0,40,52,35,0,116,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,8,237,34,0,136,173,34,0,164,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,144,113,34,0,144,57,34,0,168,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,184,114,33,0,168,50,33,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,184,114,33,0,32,10,33,0,240,239,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,184,114,33,0,80,212,32,0,224,184,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,184,114,33,0,240,162,32,0,88,138,32,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,184,114,33,0,104,113,32,0,152,90,32,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,184,114,33,0,200,66,32,0,24,11,32,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,152,241,31,0,120,220,31,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,184,202,31,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,184,180,31,0,224,161,31,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,1,2,3,4,5,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,255,255,255,255,48,4,31,0,108,0,0,0,128,226,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,172,0,0,128,187,0,0,168,147,0,0,0,125,0,0,63,170,153,67,255,255,127,67,56,62,85,67,153,160,49,67,203,245,19,67,240,126,246,66,135,83,205,66,103,8,171,66,144,119,142,66,54,88,109,66,21,180,69,66,227,174,36,66,138,45,9,66,118,136,228,65,22,93,190,65,184,145,158,65,200,21,132,65,116,12,92,65,216,75,55,65,168,174,24,65,220,92,254,64,22,225,211,64,199,125,176,64,140,3,147,64,94,235,116,64,92,3,76,64,97,240,41,64,78,142,13,64,157,211,235,63,99,112,196,63,65,161,163,63,240,76,136,63,73,18,99,63,103,37,61,63,24,142,29,63,133,61,3,63,43,164,218,62,188,31,182,62,171,180,151,62,99,188,124,62,44,134,82,62,206,92,47,62,215,18,18,62,91,90,243,61,83,181,202,61,35,218,168,61,137,166,140,61,127,81,106,61,194,46,67,61,88,149,34,61,198,109,7,61,128,158,225,60,183,239,187,60,33,140,156,60,164,102,130,60,48,62,89,60,139,245,52,60,72,188,22,60,150,30,251,59,124,45,209,59,175,61,174,59,172,35,145,59,234,203,113,59,110,105,73,59,173,197,39,59,64,192,11,59,217,209,232,58,48,239,193,58,38,139,161,58,10,144,134,58,26,45,96,58,3,188,58,58,209,139,27,58,35,145,1,58,128,218,215,57,67,205,179,57,124,197,149,57,110,131,121,57,255,214,79,57,102,32,45,57,9,54,16,57,5,64,240,56,169,31,200,56,251,178,166,56,111,219,138,56,166,84,103,56,168,177,64,56,166,130,32,56,183,179,5,56,13,190,222,55,68,138,185,55,35,141,154,55,254,188,128,55,19,121,86,55,221,166,50,55,66,208,20,55,228,234,247,54,177,130,206,54,239,4,172,54,234,73,143,54,166,182,110,54,253,215,70,54,10,162,37,54,20,248,9,54,226,217,229,53,39,118,191,53,215,123,159,53,205,216,132,53,89,81,93,53,122,90,56,53,22,144,25,53,106,212,255,52,234,25,213,52,91,130,177,52,154,220,147,52,248,84,118,52,145,48,77,52,72,235,42,52,78,95,14,52,205,47,237,51,108,146,197,51,217,146,164,51,46,22,137,51,140,97,100,51,172,60,62,51,184,118,30,51,75,255,3,51,253,230,219,50,165,44,183,50,42,194,86,84,192,227,50,84,249,2,21,84,98,63,248,83,18,201,206,83,143,63,172,83,191,122,143,83,1,8,111,83,193,27,71,83,125,218,37,83,25,39,10,83,56,40,230,82,103,183,191,82,50,178,159,82,20,6,133,82,198,156,93,82,78,153,56,82,108,196,25,82,205,21,0,82,139,98,213,81,218,190,177,81,255,14,148,81,237,168,118,81,129,118,77,81,137,37,43,81,212,143,14,81,164,128,237,80,194,213,197,80,240,202,164,80,231,68,137,80,98,175,100,80,130,125,62,80,185,172,30,80,71,44,4,80,238,49,220,79,16,107,183,79,169,200,152,79,45,136,126,79,43,5,84,79,213,155,48,79,149,28,19,79,18,21,245,78,26,38,204,78,82,13,170,78,106,166,141,78,199,251,107,78,216,145,68,78,31,189,35,78,39,100,8,78,245,56,227,77,158,69,189,77,237,168,157,77,223,83,131,77,104,201,90,77,193,62,54,77,130,206,23,77,111,231,252,76,7,170,210,76,172,122,175,76,183,43,146,76,205,131,115,76,217,215,74,76,229,246,40,76,125,190,12,76,103,121,234,75,0,80,195,75,9,177,162,75,215,132,135,75,238,196,97,75,185,15,60,75,203,166,28,75,218,124,2,75,48,99,217,74,93,20,181,74,244,213,150,74,91,73,123,74,28,81,81,74,92,91,46,74,100,60,17,74,24,245,241,73,188,139,201,73,64,226,167,73,13,216,139,73,128,249,104,73,55,16,66,73,169,166,33,73,244,166,6,73,71,83,224,72,208,219,186,72,79,166,155,72,52,167,129,72,67,255,87,72,226,235,51,72,254,222,21,72,237,173,249,71,101,250,207,71,227,61,173,71,153,78,144,71,240,104,112,71,191,65,72,71,96,207,38,71,22,243,10,71,13,124,231,70,122,210,192,70,253,157,160,70,125,202,133,70,254,227,94,70,223,169,57,70,118,167,26,70,236,210,0,70,156,157,214,69,76,197,178,69,156,233,148,69,32,21,120,69,224,165,78,69,61,34,44,69,83,98,15,69,81,223,238,68,221,249,198,68,66,190,165,68,149,15,138,68,11,1,102,68,197,150,63,68,3,151,31,68,111,239,4,68,14,119,221,67,226,121,184,67,106,146,222,66,0,0,128,71,171,170,170,70,205,204,76,70,37,73,18,70,57,142,227,69,137,136,136,69,8,33,4,69,32,8,130,68,4,2,1,68,128,128,128,67,33,64,0,67,13,32,128,66,249,15,0,66,253,7,128,65,25,4,0,65,163,1,128,64,163,1,0,64,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,4,0,0,0,8,0,0,0,0,0,0,0,1,0,2,3,1,3,4,5,4,6,2,2,5,7,3,3,6,7,6,6,7,5,5,5,6,5,2,3,6,5,3,2,0,1,1,1,0,0,0,0,3,3,1,2,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,2,1,1,1,1,1,1,0,1,2,3,1,1,1,1,3,0,0,0,0,0,0,1,2,4,5,6,7,9,10,11,12,13,14,15,16,16,8,3,2,2,3,5,7,8,10,12,14,14,14,14,11,9,6,4,2,0,0,0,0,0,0,68,172,0,0,128,187,0,0,168,147,0,0,0,125,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,2,3,4,5,5,6,7,8,9,10,11,12,13,14,15,16,17,18,38,39,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,40,38,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,62,63,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,107,123,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,6,7,8,9,0,1,10,10,10,10,10,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,9,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,11,11,3,4,10,11,12,13,14,26,15,27,16,0,1,5,6,7,8,9,10,11,17,12,18,19,20,21,22,23,24,25,28,26,27,28,29,30,29,30,31,32,33,34,35,36,25,37,26,27,28,29,30,31,20,21,22,23,14,15,16,17,11,7,4,3,5,12,13,18,19,20,21,24,25,26,27,32,33,34,35,36,37,38,39,38,39,40,41,42,43,44,45,46,31,32,47,33,34,35,36,37,38,39,40,41,13,14,42,15,16,17,18,2,19,3,4,5,43,44,48,49,45,46,47,48,49,50,51,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,49,63,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,4,5,6,7,0,0,11,11,10,10,10,10,10,9,10,9,10,12,12,11,11,11,11,11,11,11,10,11,10,10,10,10,10,10,10,10,9,10,10,10,10,10,9,9,9,9,9,9,9,9,8,9,8,8,8,8,8,8,7,7,7,7,6,6,6,6,5,4,3,2,3,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,10,10,9,10,10,10,10,10,10,10,10,10,11,11,10,11,11,11,11,12,11,12,12,12,10,10,9,9,10,10,10,10,10,10,10,9,9,9,9,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,0,0,0,1,2,8,9,3,4,5,6,7,10,11,12,13,10,11,12,13,14,10,11,12,13,14,10,11,12,8,9,6,4,3,5,7,10,11,13,14,15,15,16,17,18,15,19,16,17,18,19,14,15,16,17,8,9,10,11,12,18,19,13,14,15,0,1,2,3,4,5,6,7,8,8,9,10,11,12,9,10,11,12,13,14,15,16,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,17,18,19,20,21,22,23,13,14,15,16,17,9,10,11,12,13,14,15,2,3,0,0,10,10,10,9,9,10,10,10,10,10,9,9,9,9,8,8,8,8,8,7,7,7,7,7,6,6,6,5,5,4,3,2,3,4,5,5,6,6,6,7,7,7,7,8,7,8,8,8,8,9,9,9,9,10,10,10,10,10,9,9,10,10,10,9,9,8,8,8,8,8,8,8,7,7,7,7,7,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,8,9,9,0,0,0,1,2,3,4,5,4,3,4,5,5,6,4,5,4,3,5,6,7,7,6,7,8,9,5,6,7,4,5,6,7,0,1,2,3,4,4,5,4,5,6,5,6,7,8,9,10,11,12,13,14,15,7,8,9,6,7,5,6,7,2,3,0,0,9,9,9,9,8,8,7,6,6,6,5,5,4,4,3,2,3,4,4,5,6,6,6,6,7,8,8,9,9,9,9,8,8,7,7,7,6,6,5,5,5,4,4,4,4,4,4,4,4,4,4,4,5,5,5,6,6,7,7,7,8,8,0,0,0,1,2,2,2,2,3,3,4,5,3,3,3,2,3,0,1,2,2,3,3,4,5,6,7,4,5,3,2,3,0,0,7,7,6,5,4,3,3,2,3,3,4,5,6,7,7,6,6,5,4,4,3,3,3,3,3,4,4,5,6,6,0,0,64,96,81,80,95,66,65,79,78,49,48,63,32,113,112,98,97,111,110,83,82,94,93,67,77,51,50,62,61,34,33,47,46,17,16,31,128,114,127,126,99,109,68,76,35,45,18,30,0,15,130,129,143,142,115,125,100,108,84,92,52,60,36,44,19,29,2,1,14,131,141,116,124,20,28,3,13,132,140,4,12,0,0,0,0,0,0,0,15,29,28,27,26,25,24,23,22,21,20,19,18,35,34,33,32,31,30,29,28,27,26,25,24,23,22,21,20,19,18,17,16,15,14,13,25,24,23,22,21,20,19,18,17,16,15,14,13,12,23,22,21,20,19,18,17,16,15,14,13,12,11,10,9,8,7,6,5,9,8,7,6,5,4,3,2,3,2,1,0,0,0,0,0,0,0,0,4,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,0,0,0,0,0,0,0,48,65,64,49,63,32,47,80,79,50,62,33,16,82,81,95,94,66,78,34,46,17,31,30,97,96,111,67,77,51,61,35,45,18,1,0,15,98,110,83,93,19,29,2,14,99,109,3,13,0,0,0,0,0,0,0,7,13,12,11,10,9,8,15,14,13,12,11,10,19,18,17,16,15,14,13,12,11,10,9,17,16,15,14,13,12,11,10,9,8,7,6,5,9,8,7,6,5,4,3,2,3,2,1,0,0,0,0,0,0,0,0,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,9,9,9,9,0,0,0,0,0,0,0,2,3,15,4,0,5,12,18,13,6,7,19,21,20,8,9,14,21,15,10,3,11,16,12,1,13,16,22,17,14,18,15,16,22,19,23,17,8,18,24,20,19,20,23,21,15,22,25,23,16,17,26,24,27,18,28,21,9,22,29,25,10,7,11,26,30,23,12,24,31,19,32,27,33,20,17,24,34,25,18,26,25,26,27,27,35,28,13,29,36,28,28,30,31,29,19,30,37,31,20,2,21,21,22,4,23,32,38,33,24,22,39,29,40,25,26,34,41,35,27,3,28,23,29,5,2,3,15,4,0,5,12,13,14,6,7,15,30,16,16,8,17,18,19,9,3,10,17,11,1,12,20,21,22,13,23,18,14,19,24,25,20,15,16,26,27,21,17,22,28,14,29,30,31,15,18,32,31,33,19,34,18,19,20,35,32,21,15,22,33,36,23,24,25,37,20,38,34,39,21,16,40,41,42,17,43,23,26,24,44,45,27,28,25,46,47,26,29,27,48,18,49,50,51,19,2,20,21,22,4,23,52,53,54,24,22,55,35,56,25,26,57,58,59,27,3,28,23,29,5,0,0,0,0,0,0,12,11,10,11,13,11,9,8,9,11,11,8,7,8,11,11,9,8,9,11,12,11,10,11,13,11,9,8,9,11,9,6,6,7,9,8,6,4,6,8,9,6,6,7,9,11,9,8,9,11,10,8,7,8,10,8,6,4,6,8,7,4,3,4,7,8,6,4,6,8,10,8,7,8,10,11,9,8,9,11,9,6,6,6,9,8,6,4,6,8,9,7,6,6,9,11,9,8,9,11,13,11,10,11,12,11,9,8,9,11,10,8,7,8,11,11,9,8,9,11,13,11,10,11,12,11,10,9,10,12,10,8,8,8,10,10,8,7,8,9,10,8,8,8,10,11,10,9,10,12,10,8,8,8,10,8,6,5,6,8,8,6,5,5,8,8,6,5,6,8,10,8,8,8,10,9,8,7,8,9,8,5,5,5,8,7,5,4,5,7,8,5,5,5,8,9,8,7,8,9,10,8,8,8,10,8,6,5,6,8,8,5,5,6,8,8,6,5,6,8,10,8,8,8,10,12,10,10,10,11,10,8,8,8,10,9,8,7,8,10,10,8,8,8,10,12,10,9,10,11,0,0,0,0,0,0,1,1,2,3,4,5,6,7,3,4,5,1,1,1,1,1,1,0,1,0,0,0,0,0,6,4,4,3,3,3,3,3,4,4,4,5,7,8,9,10,11,12,12,0,0,0,0,0,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,0,0,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,0,0,0,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,0,0,0,6,5,4,5,6,5,4,3,4,5,4,3,2,3,4,5,4,3,4,5,6,5,4,5,6,5,4,3,4,5,4,3,2,3,4,3,2,1,2,3,4,3,2,3,4,5,4,3,4,5,4,3,2,3,4,3,2,1,2,3,2,1,0,1,2,3,2,1,2,3,4,3,2,3,4,5,4,3,4,5,4,3,2,3,4,3,2,1,2,3,4,3,2,3,4,5,4,3,4,5,6,5,4,5,6,5,4,3,4,5,4,3,2,3,4,5,4,3,4,5,6,5,4,5,6,0,0,0,0,3,4,4,5,6,5,6,7,8,7,8,9,10,7,8,9,10,7,8,9,6,7,5,6,4,3,3,4,3,4,5,6,7,5,4,5,5,7,8,9,10,11,11,12,13,11,12,13,9,10,11,12,7,8,9,5,6,7,1,2,3,4,5,13,0,0,0,0,0,0,0,15,14,14,13,13,13,12,12,12,12,11,11,11,11,10,10,10,10,9,9,9,8,8,7,7,6,5,4,4,3,3,3,3,3,4,5,5,6,7,8,8,9,9,10,10,10,11,11,11,12,12,12,12,13,13,13,14,14,14,15,15,15,15,15,12,0,0,0,0,0,0,0,3,4,5,4,5,6,5,6,7,8,9,7,8,9,10,7,8,9,10,7,8,9,10,6,7,5,4,5,6,6,7,10,8,5,6,7,9,7,8,9,11,11,12,13,11,12,13,11,12,13,7,8,9,6,7,3,4,5,0,1,2,3,4,5,12,12,12,11,11,11,10,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,5,4,4,5,4,4,10,4,3,3,3,4,5,6,6,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,13,13,13,14,14,14,14,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,15,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,6,0,0,0,1,0,0,0,11,0,0,0,4,0,0,0,28,0,0,0,19,0,0,0,9,0,0,0,62,0,0,0,50,0,0,0,37,0,0,0,23,0,0,0,8,0,0,0,120,0,0,0,103,0,0,0,85,0,0,0,66,0,0,0,46,0,0,0,25,0,0,0,3,0,0,0,236,0,0,0,212,0,0,0,187,0,0,0,161,0,0,0,134,0,0,0,106,0,0,0,77,0,0,0,47,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,12,0,0,0,29,0,0,0,8,0,0,0,44,0,0,0,8,0,0,0,91,0,0,0,36,0,0,0,226,0,0,0,148,0,0,0,57,0,0,0,208,1,0,0,88,1,0,0,208,0,0,0,55,0,0,0,140,3,0,0,206,2,0,0,252,1,0,0,21,1,0,0,24,0,0,0,4,7,0,0,216,5,0,0,147,4,0,0,52,3,0,0,186,1,0,0,36,0,0,0,113,14,0,0,160,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,29,0,0,0,58,0,0,0,2,0,0,0,46,0,0,0,182,0,0,0,17,0,0,0,53,1,0,0,23,0,0,0,171,2,0,0,228,0,0,0,180,6,0,0,12,4,0,0,220,0,0,0,19,13,0,0,159,8,0,0,109,3,0,0,105,29,0,0,126,22,0,0,150,14,0,0,154,5,0,0,114,59,0,0,5,48,0,0,57,35,0,0,243,20,0,0,23,5,0,0,136,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,11,0,0,0,8,0,0,0,2,0,0,0,4,0,0,0,50,0,0,0,232,0,0,0,249,2,0,0,46,0,0,0,69,4,0,0,240,14,0,0,212,7,0,0,136,30,0,0,148,18,0,0,112,3,0,0,131,48,0,0,34,25,0,0,143,124,0,0,248,89,0,0,118,48,0,0,12,255,0,0,166,196,0,0,24,128,0,0,29,48,0,0,86,211,1,0,73,104,1,0,96,237,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,44,0,0,0,46,0,0,0,50,0,0,0,100,0,0,0,76,1,0,0,69,4,0,0,115,12,0,0,184,0,0,0,168,15,0,0,124,55,0,0,4,22,0,0,152,104,0,0,8,44,0,0,139,220,0,0,173,117,0,0,60,242,1,0,52,76,1,0,170,124,0,0,182,123,3,0,92,64,2,0,116,192,0,0,145,240,6,0,231,195,4,0,48,44,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,8,0,0,0,182,0,0,0,232,0,0,0,76,1,0,0,152,2,0,0,221,6,0,0,80,19,0,0,8,52,0,0,176,3,0,0,44,59,0,0,48,209,0,0,200,57,0,0,208,101,1,0,91,66,0,0,8,184,2,0,68,170,0,0,120,246,5,0,34,115,2,0,216,238,13,0,52,47,8,0,168,239,0,0,57,224,23,0,32,164,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,19,0,0,0,91,0,0,0,17,0,0,0,249,2,0,0,69,4,0,0,221,6,0,0,186,13,0,0,10,33,0,0,18,85,0,0,194,216,0,0,238,19,0,0,30,229,0,0,230,30,3,0,182,132,0,0,17,199,4,0,25,127,15,0,93,41,8,0,213,31,30,0,247,146,16,0,207,129,62,0,3,177,38,0,171,160,7,0,228,128,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,9,0,0,0,36,0,0,0,53,1,0,0,46,0,0,0,115,12,0,0,80,19,0,0,10,33,0,0,20,66,0,0,38,151,0,0,232,111,1,0,214,131,3,0,244,104,0,0,218,135,3,0,144,12,12,0,161,211,0,0,186,82,16,0,23,124,56,0,236,155,22,0,227,46,103,0,178,176,37,0,181,97,204,0,96,2,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,62,0,0,0,226,0,0,0,23,0,0,0,69,4,0,0,184,0,0,0,8,52,0,0,18,85,0,0,38,151,0,0,76,46,1,0,52,158,2,0,10,34,6,0,254,138,14,0,216,18,2,0,104,31,14,0,9,243,46,0,195,69,127,0,218,193,55,0,198,93,206,0,169,140,53,0,91,61,91,1,16,159,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,50,0,0,0,148,0,0,0,171,2,0,0,240,14,0,0,168,15,0,0,176,3,0,0,194,216,0,0,232,111,1,0,52,158,2,0,104,60,5,0,114,94,11,0,112,233,25,0,72,252,59,0,176,27,10,0,185,14,57,0,124,84,184,0,86,22,240,1,28,116,190,0,197,0,244,2,32,62,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,37,0,0,0,57,0,0,0,228,0,0,0,212,7,0,0,124,55,0,0,44,59,0,0,238,19,0,0,214,131,3,0,10,34,6,0,114,94,11,0,228,188,22,0,84,166,48,0,156,162,108,0,76,190,246,0,5,205,47,0,129,33,232,0,215,55,216,2,243,171,150,7,184,172,138,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,23,0,0,0,208,1,0,0,180,6,0,0,136,30,0,0,4,22,0,0,48,209,0,0,30,229,0,0,244,104,0,0,254,138,14,0,112,233,25,0,84,166,48,0,168,76,97,0,68,239,205,0,144,173,196,1,149,122,244,3,22,156,220,0,237,211,180,3,224,127,75,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,8,0,0,0,88,1,0,0,12,4,0,0,148,18,0,0,152,104,0,0,200,57,0,0,230,30,3,0,218,135,3,0,216,18,2,0,72,252,59,0,156,162,108,0,68,239,205,0,136,222,155,1,24,140,96,3,173,6,85,7,195,162,49,0,176,118,230,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,0,0,0,208,0,0,0,220,0,0,0,112,3,0,0,8,44,0,0,208,101,1,0,182,132,0,0,144,12,12,0,104,31,14,0,176,27,10,0,76,190,246,0,144,173,196,1,24,140,96,3,48,24,193,6,221,30,22,14,160,193,71,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,103,0,0,0,55,0,0,0,19,13,0,0,131,48,0,0,139,220,0,0,91,66,0,0,17,199,4,0,161,211,0,0,9,243,46,0,185,14,57,0,5,205,47,0,149,122,244,3,173,6,85,7,221,30,22,14,0,0,0,0,0,0,0,0,0,1,2,2,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,0,0,2,3,4,4,5,5,6,6,6,7,7,7,7,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,0,0,0,0,2,4,5,6,6,7,7,8,8,9,9,9,10,10,10,10,11,11,11,11,11,12,12,12,12,12,12,13,13,0,0,0,0,0,3,4,6,7,7,8,9,9,10,10,11,11,12,12,12,13,13,13,14,14,14,14,15,15,15,15,15,16,0,0,0,0,0,0,3,5,6,7,8,9,10,11,11,12,13,13,14,14,14,15,15,16,16,16,17,17,17,17,18,18,18,0,0,0,0,0,0,0,3,5,7,8,9,10,11,12,13,13,14,15,15,16,16,17,17,18,18,18,19,19,19,20,20,20,0,0,0,0,0,0,0,0,3,6,7,9,10,11,12,13,14,15,15,16,17,17,18,18,19,19,20,20,21,21,21,22,22,0,0,0,0,0,0,0,0,0,4,6,8,9,11,12,13,14,15,16,17,17,18,19,19,20,21,21,22,22,23,23,23,24,0,0,0,0,0,0,0,0,0,0,4,6,8,10,11,13,14,15,16,17,18,19,19,20,21,21,22,23,23,24,24,25,25,0,0,0,0,0,0,0,0,0,0,0,4,7,9,10,12,13,15,16,17,18,19,20,21,21,22,23,24,24,25,25,26,26,0,0,0,0,0,0,0,0,0,0,0,0,4,7,9,11,13,14,15,17,18,19,20,21,22,23,23,24,25,26,26,27,27,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,9,11,13,15,16,17,19,20,21,22,23,24,25,25,26,27,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,10,12,14,15,17,18,19,21,22,23,24,25,26,27,27,28,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,10,12,14,16,17,19,20,21,23,24,25,26,27,28,28,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,8,10,12,14,16,18,19,21,22,23,25,26,27,28,29,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,8,10,13,15,17,18,20,21,23,24,25,27,28,29,30,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,6,0,0,0,10,0,0,0,15,0,0,0,21,0,0,0,28,0,0,0,36,0,0,0,45,0,0,0,55,0,0,0,66,0,0,0,78,0,0,0,91,0,0,0,105,0,0,0,120,0,0,0,136,0,0,0,153,0,0,0,171,0,0,0,190,0,0,0,210,0,0,0,231,0,0,0,253,0,0,0,20,1,0,0,44,1,0,0,69,1,0,0,95,1,0,0,122,1,0,0,150,1,0,0,179,1,0,0,209,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,10,0,0,0,20,0,0,0,35,0,0,0,56,0,0,0,84,0,0,0,120,0,0,0,165,0,0,0,220,0,0,0,30,1,0,0,108,1,0,0,199,1,0,0,48,2,0,0,168,2,0,0,48,3,0,0,201,3,0,0,116,4,0,0,50,5,0,0,4,6,0,0,235,6,0,0,232,7,0,0,252,8,0,0,40,10,0,0,109,11,0,0,204,12,0,0,70,14,0,0,220,15,0,0,143,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,15,0,0,0,35,0,0,0,70,0,0,0,126,0,0,0,210,0,0,0,74,1,0,0,239,1,0,0,203,2,0,0,233,3,0,0,85,5,0,0,28,7,0,0,76,9,0,0,244,11,0,0,36,15,0,0,237,18,0,0,97,23,0,0,147,28,0,0,151,34,0,0,130,41,0,0,106,49,0,0,102,58,0,0,142,68,0,0,251,79,0,0,199,92,0,0,13,107,0,0,233,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,6,0,0,0,21,0,0,0,56,0,0,0,126,0,0,0,252,0,0,0,206,1,0,0,24,3,0,0,7,5,0,0,210,7,0,0,187,11,0,0,16,17,0,0,44,24,0,0,120,33,0,0,108,45,0,0,144,60,0,0,125,79,0,0,222,102,0,0,113,131,0,0,8,166,0,0,138,207,0,0,244,0,1,0,90,59,1,0,232,127,1,0,227,207,1,0,170,44,2,0,183,151,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,7,0,0,0,28,0,0,0,84,0,0,0,210,0,0,0,206,1,0,0,156,3,0,0,180,6,0,0,187,11,0,0,141,19,0,0,72,31,0,0,88,48,0,0,132,72,0,0,252,105,0,0,104,151,0,0,248,211,0,0,117,35,1,0,83,138,1,0,196,13,2,0,204,179,2,0,86,131,3,0,74,132,4,0,164,191,5,0,140,63,7,0,111,15,9,0,25,60,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,8,0,0,0,36,0,0,0,120,0,0,0,74,1,0,0,24,3,0,0,180,6,0,0,104,13,0,0,35,25,0,0,176,44,0,0,248,75,0,0,80,124,0,0,212,196,0,0,208,46,1,0,56,198,1,0,48,154,2,0,165,189,3,0,248,71,5,0,188,85,7,0,136,9,10,0,222,140,13], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+646496);
/* memory initializer */ allocate([40,17,18,0,204,208,23,0,88,16,31,0,199,31,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,9,0,0,0,45,0,0,0,165,0,0,0,239,1,0,0,7,5,0,0,187,11,0,0,35,25,0,0,70,50,0,0,246,94,0,0,238,170,0,0,62,39,1,0,18,236,1,0,226,26,3,0,26,225,4,0,74,123,7,0,239,56,11,0,231,128,16,0,163,214,23,0,43,224,33,0,9,109,47,0,49,126,65,0,253,78,89,0,85,95,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,10,0,0,0,55,0,0,0,220,0,0,0,203,2,0,0,210,7,0,0,141,19,0,0,176,44,0,0,246,94,0,0,236,189,0,0,218,104,1,0,24,144,2,0,42,124,4,0,12,151,7,0,38,120,12,0,112,243,19,0,95,44,31,0,70,173,47,0,233,131,71,0,20,100,105,0,29,209,152,0,78,79,218,0,75,158,51,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,11,0,0,0,66,0,0,0,30,1,0,0,233,3,0,0,187,11,0,0,72,31,0,0,248,75,0,0,238,170,0,0,218,104,1,0,180,209,2,0,204,97,5,0,246,221,9,0,2,117,17,0,40,237,29,0,152,224,49,0,247,12,81,0,61,186,128,0,38,62,200,0,58,162,49,1,87,115,202,1,165,194,164,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,12,0,0,0,78,0,0,0,108,1,0,0,85,5,0,0,16,17,0,0,88,48,0,0,80,124,0,0,62,39,1,0,24,144,2,0,204,97,5,0,152,195,10,0,142,161,20,0,144,22,38,0,184,3,68,0,80,228,117,0,71,241,198,0,132,171,71,1,170,233,15,2,228,139,65,3,59,255,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,13,0,0,0,91,0,0,0,199,1,0,0,28,7,0,0,44,24,0,0,132,72,0,0,212,196,0,0,18,236,1,0,42,124,4,0,246,221,9,0,142,161,20,0,28,67,41,0,172,89,79,0,100,93,147,0,180,65,9,1,251,50,208,1,127,222,23,3,41,200,39,5,13,84,105,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,14,0,0,0,105,0,0,0,48,2,0,0,76,9,0,0,120,33,0,0,252,105,0,0,208,46,1,0,226,26,3,0,12,151,7,0,2,117,17,0,144,22,38,0,172,89,79,0,88,179,158,0,188,16,50,1,112,82,59,2,107,133,11,4,234,99,35,7,19,44,75,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,15,0,0,0,120,0,0,0,168,2,0,0,244,11,0,0,108,45,0,0,104,151,0,0,56,198,1,0,26,225,4,0,38,120,12,0,40,237,29,0,184,3,68,0,100,93,147,0,188,16,50,1,120,33,100,2,232,115,159,4,83,249,170,8,61,93,206,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,16,0,0,0,136,0,0,0,48,3,0,0,36,15,0,0,144,60,0,0,248,211,0,0,48,154,2,0,74,123,7,0,112,243,19,0,152,224,49,0,80,228,117,0,180,65,9,1,112,82,59,2,232,115,159,4,208,231,62,9,35,225,233,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,17,0,0,0,153,0,0,0,201,3,0,0,237,18,0,0,125,79,0,0,117,35,1,0,165,189,3,0,239,56,11,0,95,44,31,0,247,12,81,0,71,241,198,0,251,50,208,1,107,133,11,4,83,249,170,8,35,225,233,17,1,1,2,2,3,3,4,4,5,6,1,2,3,0,4,5,6,7,8,1,9,10,11,7,8,9,6,7,5,5,3,3,1,0,0,0,0,0,0,0,1,3,5,6,7,8,8,9,10,11,12,12,12,13,12,12,12,12,12,13,12,12,12,11,11,11,10,10,9,8,6,5,2,0,0,0,0,0,0,0,2,3,1,1,3,3,0,2,27,25,7,9,15,31,63,0,0,0,0,0,0,0,0,0,0,0,3,4,7,15,31,0,54,0,6,0,9,0,5,0,32,0,6,0,5,0,5,0,10,0,4,0,7,0,5,0,52,0,6,0,0,0,5,0,35,0,6,0,10,0,5,0,6,0,4,0,4,0,5,0,11,0,4,0,7,0,3,0,12,0,4,0,3,0,5,0,7,0,4,0,11,0,5,0,34,0,6,0,1,0,5,0,53,0,6,0,6,0,5,0,9,0,4,0,2,0,5,0,33,0,6,0,8,0,5,0,55,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,0,8,0,62,0,7,0,225,0,9,0,55,0,7,0,3,0,4,0,52,0,7,0,101,0,8,0,60,0,7,0,227,0,9,0,24,0,6,0,0,0,4,0,61,0,7,0,4,0,4,0,1,0,1,0,5,0,4,0,63,0,7,0,1,0,4,0,59,0,7,0,226,0,9,0,57,0,7,0,100,0,8,0,53,0,7,0,2,0,4,0,54,0,7,0,224,0,9,0,58,0,7,0,102,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,0,7,0,47,0,6,0,15,0,5,0,0,0,5,0,91,0,7,0,4,0,5,0,6,0,4,0,13,0,4,0,4,0,4,0,5,0,5,0,20,0,5,0,12,0,4,0,4,0,3,0,15,0,4,0,14,0,5,0,3,0,5,0,3,0,4,0,14,0,4,0,5,0,4,0,1,0,5,0,90,0,7,0,2,0,5,0,21,0,5,0,46,0,6,0,88,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,153,3,10,0,113,0,7,0,51,0,6,0,231,0,8,0,154,3,10,0,104,0,7,0,30,0,5,0,0,0,3,0,29,0,5,0,105,0,7,0,50,0,6,0,1,0,3,0,2,0,2,0,3,0,3,0,49,0,6,0,107,0,7,0,27,0,5,0,2,0,3,0,31,0,5,0,112,0,7,0,152,3,10,0,106,0,7,0,48,0,6,0,114,0,7,0,155,3,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,4,0,4,0,3,0,0,0,2,0,1,0,2,0,7,0,3,0,5,0,3,0,13,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,0,3,0,4,0,2,0,2,0,3,0,2,0,1,0,2,0,0,0,3,0,5,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,4,0,0,0,3,0,4,0,3,0,6,0,3,0,7,0,3,0,5,0,3,0,3,0,3,0,1,0,3,0,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,5,0,12,0,4,0,3,0,3,0,0,0,2,0,2,0,2,0,7,0,3,0,13,0,4,0,5,0,4,0,8,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,0,6,0,23,0,5,0,8,0,4,0,10,0,4,0,13,0,4,0,0,0,3,0,2,0,3,0,3,0,3,0,1,0,3,0,15,0,4,0,12,0,4,0,9,0,4,0,29,0,5,0,22,0,5,0,56,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,229,0,8,0,56,0,6,0,7,0,5,0,2,0,4,0,0,0,3,0,3,0,3,0,5,0,3,0,6,0,3,0,4,0,3,0,2,0,3,0,15,0,4,0,29,0,5,0,6,0,5,0,115,0,7,0,228,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,0,7,0,6,0,6,0,44,0,6,0,45,0,6,0,59,0,6,0,13,0,5,0,17,0,5,0,19,0,5,0,23,0,5,0,21,0,5,0,26,0,5,0,30,0,5,0,0,0,4,0,2,0,4,0,5,0,4,0,7,0,4,0,3,0,4,0,4,0,4,0,31,0,5,0,28,0,5,0,25,0,5,0,27,0,5,0,24,0,5,0,20,0,5,0,18,0,5,0,12,0,5,0,2,0,5,0,58,0,6,0,33,0,6,0,7,0,6,0,64,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,25,13,0,74,25,13,0,40,3,10,0,149,1,9,0,203,0,8,0,102,0,7,0,49,0,6,0,9,0,5,0,15,0,5,0,31,0,5,0,2,0,4,0,6,0,4,0,8,0,4,0,11,0,4,0,13,0,4,0,0,0,3,0,14,0,4,0,10,0,4,0,9,0,4,0,5,0,4,0,3,0,4,0,30,0,5,0,14,0,5,0,8,0,5,0,48,0,6,0,103,0,7,0,201,0,8,0,200,0,8,0,83,6,11,0,73,25,13,0,75,25,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,0,8,0,153,0,8,0,181,0,8,0,233,0,8,0,64,0,7,0,65,0,7,0,77,0,7,0,81,0,7,0,91,0,7,0,113,0,7,0,112,0,7,0,24,0,6,0,29,0,6,0,35,0,6,0,37,0,6,0,41,0,6,0,44,0,6,0,46,0,6,0,51,0,6,0,49,0,6,0,54,0,6,0,55,0,6,0,57,0,6,0,60,0,6,0,0,0,5,0,2,0,5,0,10,0,5,0,5,0,5,0,9,0,5,0,6,0,5,0,13,0,5,0,7,0,5,0,11,0,5,0,15,0,5,0,8,0,5,0,4,0,5,0,3,0,5,0,1,0,5,0,63,0,6,0,62,0,6,0,61,0,6,0,53,0,6,0,59,0,6,0,52,0,6,0,48,0,6,0,47,0,6,0,43,0,6,0,42,0,6,0,39,0,6,0,36,0,6,0,33,0,6,0,28,0,6,0,117,0,7,0,101,0,7,0,100,0,7,0,80,0,7,0,69,0,7,0,68,0,7,0,50,0,7,0,232,0,8,0,180,0,8,0,152,0,8,0,102,0,8,0,0,0,0,0,164,55,14,0,173,55,14,0,166,55,14,0,174,55,14,0,234,13,12,0,240,2,10,0,241,2,10,0,160,0,9,0,162,0,9,0,188,1,9,0,122,0,8,0,223,0,8,0,60,0,7,0,73,0,7,0,110,0,7,0,14,0,6,0,24,0,6,0,25,0,6,0,34,0,6,0,37,0,6,0,54,0,6,0,3,0,5,0,9,0,5,0,11,0,5,0,16,0,5,0,19,0,5,0,21,0,5,0,24,0,5,0,26,0,5,0,29,0,5,0,31,0,5,0,2,0,4,0,0,0,4,0,30,0,5,0,28,0,5,0,25,0,5,0,22,0,5,0,20,0,5,0,14,0,5,0,13,0,5,0,8,0,5,0,6,0,5,0,2,0,5,0,46,0,6,0,35,0,6,0,31,0,6,0,21,0,6,0,15,0,6,0,95,0,7,0,72,0,7,0,41,0,7,0,189,0,8,0,123,0,8,0,121,1,9,0,161,0,9,0,123,3,10,0,71,1,10,0,70,1,10,0,232,13,12,0,175,55,14,0,167,55,14,0,172,55,14,0,165,55,14,0,0,0,0,0,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,0,0,0,0,0,0,0,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,0,0,0,0,0,255,255,255,0,0,0,1,1,1,255,255,255,0,0,0,1,1,1,255,255,255,0,0,0,1,1,1,0,0,0,0,0,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,0,0,0,0,0,92,8,47,7,10,5,4,4,0,2,1,1,3,3,22,6,187,9,186,9,0,0,0,0,32,6,4,5,17,5,30,5,13,4,0,3,3,3,9,4,5,3,2,3,14,4,3,4,31,5,5,5,33,6,12,4,0,0,0,0,0,0,0,0,1,5,4,5,6,5,4,4,7,3,6,0,7,2,3,1,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,1,5,4,5,6,5,4,4,7,3,6,0,7,2,3,1,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,1,4,4,5,4,6,5,6,4,5,5,6,5,6,6,6,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,1,4,4,5,4,6,5,6,4,5,5,6,5,6,6,6,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,3,3,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,3,3,3,2,0,0,0,0,0,7,0,5,0,9,0,14,0,15,0,7,0,6,0,4,0,5,0,5,0,6,0,7,0,7,0,6,0,8,0,8,0,8,0,5,0,15,0,6,0,9,0,10,0,5,0,1,0,11,0,7,0,9,0,6,0,4,0,1,0,14,0,4,0,6,0,2,0,6,0,0,0,7,0,5,0,9,0,14,0,15,0,7,0,6,0,4,0,5,0,5,0,6,0,7,0,7,0,6,0,8,0,8,0,8,0,5,0,15,0,6,0,9,0,10,0,5,0,1,0,11,0,7,0,9,0,6,0,4,0,1,0,14,0,4,0,6,0,2,0,6,0,0,0,3,0,4,0,6,0,18,0,12,0,5,0,5,0,1,0,2,0,16,0,9,0,3,0,7,0,3,0,5,0,14,0,7,0,3,0,19,0,17,0,15,0,13,0,10,0,4,0,13,0,5,0,8,0,11,0,5,0,1,0,12,0,4,0,4,0,1,0,1,0,0,0,3,0,4,0,6,0,18,0,12,0,5,0,5,0,1,0,2,0,16,0,9,0,3,0,7,0,3,0,5,0,14,0,7,0,3,0,19,0,17,0,15,0,13,0,10,0,4,0,13,0,5,0,8,0,11,0,5,0,1,0,12,0,4,0,4,0,1,0,1,0,0,0,1,0,2,0,10,0,19,0,16,0,10,0,3,0,3,0,7,0,10,0,5,0,3,0,11,0,4,0,13,0,17,0,8,0,4,0,12,0,11,0,18,0,15,0,11,0,2,0,7,0,6,0,9,0,14,0,3,0,1,0,6,0,4,0,5,0,3,0,2,0,0,0,1,0,2,0,10,0,19,0,16,0,10,0,3,0,3,0,7,0,10,0,5,0,3,0,11,0,4,0,13,0,17,0,8,0,4,0,12,0,11,0,18,0,15,0,11,0,2,0,7,0,6,0,9,0,14,0,3,0,1,0,6,0,4,0,5,0,3,0,2,0,0,0,7,0,3,0,5,0,1,0,6,0,2,0,3,0,2,0,5,0,4,0,4,0,1,0,3,0,3,0,2,0,0,0,7,0,3,0,5,0,1,0,6,0,2,0,3,0,2,0,5,0,4,0,4,0,1,0,3,0,3,0,2,0,0,0,1,0,2,0,6,0,5,0,3,0,1,0,4,0,4,0,7,0,5,0,7,0,1,0,6,0,1,0,1,0,0,0,1,0,2,0,6,0,5,0,3,0,1,0,4,0,4,0,7,0,5,0,7,0,1,0,6,0,1,0,1,0,0,0,3,0,2,0,1,0,1,0,1,0,1,0,3,0,2,0,0,0,0,0,0,0,0,0,3,0,2,0,1,0,1,0,1,0,1,0,3,0,2,0,0,0,0,0,0,0,0,0,15,0,13,0,46,0,80,0,146,0,6,1,248,0,178,1,170,1,157,2,141,2,137,2,109,2,5,2,8,4,88,0,14,0,12,0,21,0,38,0,71,0,130,0,122,0,216,0,209,0,198,0,71,1,89,1,63,1,41,1,23,1,42,0,47,0,22,0,41,0,74,0,68,0,128,0,120,0,221,0,207,0,194,0,182,0,84,1,59,1,39,1,29,2,18,0,81,0,39,0,75,0,70,0,134,0,125,0,116,0,220,0,204,0,190,0,178,0,69,1,55,1,37,1,15,1,16,0,147,0,72,0,69,0,135,0,127,0,118,0,112,0,210,0,200,0,188,0,96,1,67,1,50,1,29,1,28,2,14,0,7,1,66,0,129,0,126,0,119,0,114,0,214,0,202,0,192,0,180,0,85,1,61,1,45,1,25,1,6,1,12,0,249,0,123,0,121,0,117,0,113,0,215,0,206,0,195,0,185,0,91,1,74,1,52,1,35,1,16,1,8,2,10,0,179,1,115,0,111,0,109,0,211,0,203,0,196,0,187,0,97,1,76,1,57,1,42,1,27,1,19,2,125,1,17,0,171,1,212,0,208,0,205,0,201,0,193,0,186,0,177,0,169,0,64,1,47,1,30,1,12,1,2,2,121,1,16,0,79,1,199,0,197,0,191,0,189,0,181,0,174,0,77,1,65,1,49,1,33,1,19,1,9,2,123,1,115,1,11,0,156,2,184,0,183,0,179,0,175,0,88,1,75,1,58,1,48,1,34,1,21,1,18,2,127,1,117,1,110,1,10,0,140,2,90,1,171,0,168,0,164,0,62,1,53,1,43,1,31,1,20,1,7,1,1,2,119,1,112,1,106,1,6,0,136,2,66,1,60,1,56,1,51,1,46,1,36,1,28,1,13,1,5,1,0,2,120,1,114,1,108,1,103,1,4,0,108,2,44,1,40,1,38,1,32,1,26,1,17,1,10,1,3,2,124,1,118,1,113,1,109,1,105,1,101,1,2,0,9,4,24,1,22,1,18,1,11,1,8,1,3,1,126,1,122,1,116,1,111,1,107,1,104,1,102,1,100,1,0,0,43,0,20,0,19,0,17,0,15,0,13,0,11,0,9,0,7,0,6,0,4,0,7,0,5,0,3,0,1,0,3,0,15,0,13,0,46,0,80,0,146,0,6,1,248,0,178,1,170,1,157,2,141,2,137,2,109,2,5,2,8,4,88,0,14,0,12,0,21,0,38,0,71,0,130,0,122,0,216,0,209,0,198,0,71,1,89,1,63,1,41,1,23,1,42,0,47,0,22,0,41,0,74,0,68,0,128,0,120,0,221,0,207,0,194,0,182,0,84,1,59,1,39,1,29,2,18,0,81,0,39,0,75,0,70,0,134,0,125,0,116,0,220,0,204,0,190,0,178,0,69,1,55,1,37,1,15,1,16,0,147,0,72,0,69,0,135,0,127,0,118,0,112,0,210,0,200,0,188,0,96,1,67,1,50,1,29,1,28,2,14,0,7,1,66,0,129,0,126,0,119,0,114,0,214,0,202,0,192,0,180,0,85,1,61,1,45,1,25,1,6,1,12,0,249,0,123,0,121,0,117,0,113,0,215,0,206,0,195,0,185,0,91,1,74,1,52,1,35,1,16,1,8,2,10,0,179,1,115,0,111,0,109,0,211,0,203,0,196,0,187,0,97,1,76,1,57,1,42,1,27,1,19,2,125,1,17,0,171,1,212,0,208,0,205,0,201,0,193,0,186,0,177,0,169,0,64,1,47,1,30,1,12,1,2,2,121,1,16,0,79,1,199,0,197,0,191,0,189,0,181,0,174,0,77,1,65,1,49,1,33,1,19,1,9,2,123,1,115,1,11,0,156,2,184,0,183,0,179,0,175,0,88,1,75,1,58,1,48,1,34,1,21,1,18,2,127,1,117,1,110,1,10,0,140,2,90,1,171,0,168,0,164,0,62,1,53,1,43,1,31,1,20,1,7,1,1,2,119,1,112,1,106,1,6,0,136,2,66,1,60,1,56,1,51,1,46,1,36,1,28,1,13,1,5,1,0,2,120,1,114,1,108,1,103,1,4,0,108,2,44,1,40,1,38,1,32,1,26,1,17,1,10,1,3,2,124,1,118,1,113,1,109,1,105,1,101,1,2,0,9,4,24,1,22,1,18,1,11,1,8,1,3,1,126,1,122,1,116,1,111,1,107,1,104,1,102,1,100,1,0,0,43,0,20,0,19,0,17,0,15,0,13,0,11,0,9,0,7,0,6,0,4,0,7,0,5,0,3,0,1,0,3,0,1,0,2,0,1,0,3,0,1,0,1,0,3,0,2,0,0,0,0,0,0,0,0,0,1,0,2,0,1,0,3,0,1,0,1,0,3,0,2,0,0,0,0,0,0,0,0,0,1,0,5,0,14,0,44,0,74,0,63,0,110,0,93,0,172,0,149,0,138,0,242,0,225,0,195,0,120,1,17,0,3,0,4,0,12,0,20,0,35,0,62,0,53,0,47,0,83,0,75,0,68,0,119,0,201,0,107,0,207,0,9,0,15,0,13,0,23,0,38,0,67,0,58,0,103,0,90,0,161,0,72,0,127,0,117,0,110,0,209,0,206,0,16,0,45,0,21,0,39,0,69,0,64,0,114,0,99,0,87,0,158,0,140,0,252,0,212,0,199,0,131,1,109,1,26,0,75,0,36,0,68,0,65,0,115,0,101,0,179,0,164,0,155,0,8,1,246,0,226,0,139,1,126,1,106,1,9,0,66,0,30,0,59,0,56,0,102,0,185,0,173,0,9,1,142,0,253,0,232,0,144,1,132,1,122,1,189,1,16,0,111,0,54,0,52,0,100,0,184,0,178,0,160,0,133,0,1,1,244,0,228,0,217,0,129,1,110,1,203,2,10,0,98,0,48,0,91,0,88,0,165,0,157,0,148,0,5,1,248,0,151,1,141,1,116,1,124,1,121,3,116,3,8,0,85,0,84,0,81,0,159,0,156,0,143,0,4,1,249,0,171,1,145,1,136,1,127,1,215,2,201,2,196,2,7,0,154,0,76,0,73,0,141,0,131,0,0,1,245,0,170,1,150,1,138,1,128,1,223,2,103,1,198,2,96,1,11,0,139,0,129,0,67,0,125,0,247,0,233,0,229,0,219,0,137,1,231,2,225,2,208,2,117,3,114,3,183,1,4,0,243,0,120,0,118,0,115,0,227,0,223,0,140,1,234,2,230,2,224,2,209,2,200,2,194,2,223,0,180,1,6,0,202,0,224,0,222,0,218,0,216,0,133,1,130,1,125,1,108,1,120,3,187,1,195,2,184,1,181,1,192,6,4,0,235,2,211,0,210,0,208,0,114,1,123,1,222,2,211,2,202,2,199,6,115,3,109,3,108,3,131,13,97,3,2,0,121,1,113,1,102,0,187,0,214,2,210,2,102,1,199,2,197,2,98,3,198,6,103,3,130,13,102,3,178,1,0,0,12,0,10,0,7,0,11,0,10,0,17,0,11,0,9,0,13,0,12,0,10,0,7,0,5,0,3,0,1,0,3,0,1,0,5,0,14,0,44,0,74,0,63,0,110,0,93,0,172,0,149,0,138,0,242,0,225,0,195,0,120,1,17,0,3,0,4,0,12,0,20,0,35,0,62,0,53,0,47,0,83,0,75,0,68,0,119,0,201,0,107,0,207,0,9,0,15,0,13,0,23,0,38,0,67,0,58,0,103,0,90,0,161,0,72,0,127,0,117,0,110,0,209,0,206,0,16,0,45,0,21,0,39,0,69,0,64,0,114,0,99,0,87,0,158,0,140,0,252,0,212,0,199,0,131,1,109,1,26,0,75,0,36,0,68,0,65,0,115,0,101,0,179,0,164,0,155,0,8,1,246,0,226,0,139,1,126,1,106,1,9,0,66,0,30,0,59,0,56,0,102,0,185,0,173,0,9,1,142,0,253,0,232,0,144,1,132,1,122,1,189,1,16,0,111,0,54,0,52,0,100,0,184,0,178,0,160,0,133,0,1,1,244,0,228,0,217,0,129,1,110,1,203,2,10,0,98,0,48,0,91,0,88,0,165,0,157,0,148,0,5,1,248,0,151,1,141,1,116,1,124,1,121,3,116,3,8,0,85,0,84,0,81,0,159,0,156,0,143,0,4,1,249,0,171,1,145,1,136,1,127,1,215,2,201,2,196,2,7,0,154,0,76,0,73,0,141,0,131,0,0,1,245,0,170,1,150,1,138,1,128,1,223,2,103,1,198,2,96,1,11,0,139,0,129,0,67,0,125,0,247,0,233,0,229,0,219,0,137,1,231,2,225,2,208,2,117,3,114,3,183,1,4,0,243,0,120,0,118,0,115,0,227,0,223,0,140,1,234,2,230,2,224,2,209,2,200,2,194,2,223,0,180,1,6,0,202,0,224,0,222,0,218,0,216,0,133,1,130,1,125,1,108,1,120,3,187,1,195,2,184,1,181,1,192,6,4,0,235,2,211,0,210,0,208,0,114,1,123,1,222,2,211,2,202,2,199,6,115,3,109,3,108,3,131,13,97,3,2,0,121,1,113,1,102,0,187,0,214,2,210,2,102,1,199,2,197,2,98,3,198,6,103,3,130,13,102,3,178,1,0,0,12,0,10,0,7,0,11,0,10,0,17,0,11,0,9,0,13,0,12,0,10,0,7,0,5,0,3,0,1,0,3,0,7,0,12,0,18,0,53,0,47,0,76,0,124,0,108,0,89,0,123,0,108,0,119,0,107,0,81,0,122,0,63,0,13,0,5,0,16,0,27,0,46,0,36,0,61,0,51,0,42,0,70,0,52,0,83,0,65,0,41,0,59,0,36,0,19,0,17,0,15,0,24,0,41,0,34,0,59,0,48,0,40,0,64,0,50,0,78,0,62,0,80,0,56,0,33,0,29,0,28,0,25,0,43,0,39,0,63,0,55,0,93,0,76,0,59,0,93,0,72,0,54,0,75,0,50,0,29,0,52,0,22,0,42,0,40,0,67,0,57,0,95,0,79,0,72,0,57,0,89,0,69,0,49,0,66,0,46,0,27,0,77,0,37,0,35,0,66,0,58,0,52,0,91,0,74,0,62,0,48,0,79,0,63,0,90,0,62,0,40,0,38,0,125,0,32,0,60,0,56,0,50,0,92,0,78,0,65,0,55,0,87,0,71,0,51,0,73,0,51,0,70,0,30,0,109,0,53,0,49,0,94,0,88,0,75,0,66,0,122,0,91,0,73,0,56,0,42,0,64,0,44,0,21,0,25,0,90,0,43,0,41,0,77,0,73,0,63,0,56,0,92,0,77,0,66,0,47,0,67,0,48,0,53,0,36,0,20,0,71,0,34,0,67,0,60,0,58,0,49,0,88,0,76,0,67,0,106,0,71,0,54,0,38,0,39,0,23,0,15,0,109,0,53,0,51,0,47,0,90,0,82,0,58,0,57,0,48,0,72,0,57,0,41,0,23,0,27,0,62,0,9,0,86,0,42,0,40,0,37,0,70,0,64,0,52,0,43,0,70,0,55,0,42,0,25,0,29,0,18,0,11,0,11,0,118,0,68,0,30,0,55,0,50,0,46,0,74,0,65,0,49,0,39,0,24,0,16,0,22,0,13,0,14,0,7,0,91,0,44,0,39,0,38,0,34,0,63,0,52,0,45,0,31,0,52,0,28,0,19,0,14,0,8,0,9,0,3,0,123,0,60,0,58,0,53,0,47,0,43,0,32,0,22,0,37,0,24,0,17,0,12,0,15,0,10,0,2,0,1,0,71,0,37,0,34,0,30,0,28,0,20,0,17,0,26,0,21,0,16,0,10,0,6,0,8,0,6,0,2,0,0,0,7,0,12,0,18,0,53,0,47,0,76,0,124,0,108,0,89,0,123,0,108,0,119,0,107,0,81,0,122,0,63,0,13,0,5,0,16,0,27,0,46,0,36,0,61,0,51,0,42,0,70,0,52,0,83,0,65,0,41,0,59,0,36,0,19,0,17,0,15,0,24,0,41,0,34,0,59,0,48,0,40,0,64,0,50,0,78,0,62,0,80,0,56,0,33,0,29,0,28,0,25,0,43,0,39,0,63,0,55,0,93,0,76,0,59,0,93,0,72,0,54,0,75,0,50,0,29,0,52,0,22,0,42,0,40,0,67,0,57,0,95,0,79,0,72,0,57,0,89,0,69,0,49,0,66,0,46,0,27,0,77,0,37,0,35,0,66,0,58,0,52,0,91,0,74,0,62,0,48,0,79,0,63,0,90,0,62,0,40,0,38,0,125,0,32,0,60,0,56,0,50,0,92,0,78,0,65,0,55,0,87,0,71,0,51,0,73,0,51,0,70,0,30,0,109,0,53,0,49,0,94,0,88,0,75,0,66,0,122,0,91,0,73,0,56,0,42,0,64,0,44,0,21,0,25,0,90,0,43,0,41,0,77,0,73,0,63,0,56,0,92,0,77,0,66,0,47,0,67,0,48,0,53,0,36,0,20,0,71,0,34,0,67,0,60,0,58,0,49,0,88,0,76,0,67,0,106,0,71,0,54,0,38,0,39,0,23,0,15,0,109,0,53,0,51,0,47,0,90,0,82,0,58,0,57,0,48,0,72,0,57,0,41,0,23,0,27,0,62,0,9,0,86,0,42,0,40,0,37,0,70,0,64,0,52,0,43,0,70,0,55,0,42,0,25,0,29,0,18,0,11,0,11,0,118,0,68,0,30,0,55,0,50,0,46,0,74,0,65,0,49,0,39,0,24,0,16,0,22,0,13,0,14,0,7,0,91,0,44,0,39,0,38,0,34,0,63,0,52,0,45,0,31,0,52,0,28,0,19,0,14,0,8,0,9,0,3,0,123,0,60,0,58,0,53,0,47,0,43,0,32,0,22,0,37,0,24,0,17,0,12,0,15,0,10,0,2,0,1,0,71,0,37,0,34,0,30,0,28,0,20,0,17,0,26,0,21,0,16,0,10,0,6,0,8,0,6,0,2,0,0,0,1,0,5,0,14,0,21,0,34,0,51,0,46,0,71,0,42,0,52,0,68,0,52,0,67,0,44,0,43,0,19,0,3,0,4,0,12,0,19,0,31,0,26,0,44,0,33,0,31,0,24,0,32,0,24,0,31,0,35,0,22,0,14,0,15,0,13,0,23,0,36,0,59,0,49,0,77,0,65,0,29,0,40,0,30,0,40,0,27,0,33,0,42,0,16,0,22,0,20,0,37,0,61,0,56,0,79,0,73,0,64,0,43,0,76,0,56,0,37,0,26,0,31,0,25,0,14,0,35,0,16,0,60,0,57,0,97,0,75,0,114,0,91,0,54,0,73,0,55,0,41,0,48,0,53,0,23,0,24,0,58,0,27,0,50,0,96,0,76,0,70,0,93,0,84,0,77,0,58,0,79,0,29,0,74,0,49,0,41,0,17,0,47,0,45,0,78,0,74,0,115,0,94,0,90,0,79,0,69,0,83,0,71,0,50,0,59,0,38,0,36,0,15,0,72,0,34,0,56,0,95,0,92,0,85,0,91,0,90,0,86,0,73,0,77,0,65,0,51,0,44,0,43,0,42,0,43,0,20,0,30,0,44,0,55,0,78,0,72,0,87,0,78,0,61,0,46,0,54,0,37,0,30,0,20,0,16,0,53,0,25,0,41,0,37,0,44,0,59,0,54,0,81,0,66,0,76,0,57,0,54,0,37,0,18,0,39,0,11,0,35,0,33,0,31,0,57,0,42,0,82,0,72,0,80,0,47,0,58,0,55,0,21,0,22,0,26,0,38,0,22,0,53,0,25,0,23,0,38,0,70,0,60,0,51,0,36,0,55,0,26,0,34,0,23,0,27,0,14,0,9,0,7,0,34,0,32,0,28,0,39,0,49,0,75,0,30,0,52,0,48,0,40,0,52,0,28,0,18,0,17,0,9,0,5,0,45,0,21,0,34,0,64,0,56,0,50,0,49,0,45,0,31,0,19,0,12,0,15,0,10,0,7,0,6,0,3,0,48,0,23,0,20,0,39,0,36,0,35,0,53,0,21,0,16,0,23,0,13,0,10,0,6,0,1,0,4,0,2,0,16,0,15,0,17,0,27,0,25,0,20,0,29,0,11,0,17,0,12,0,16,0,8,0,1,0,1,0,0,0,1,0,1,0,5,0,14,0,21,0,34,0,51,0,46,0,71,0,42,0,52,0,68,0,52,0,67,0,44,0,43,0,19,0,3,0,4,0,12,0,19,0,31,0,26,0,44,0,33,0,31,0,24,0,32,0,24,0,31,0,35,0,22,0,14,0,15,0,13,0,23,0,36,0,59,0,49,0,77,0,65,0,29,0,40,0,30,0,40,0,27,0,33,0,42,0,16,0,22,0,20,0,37,0,61,0,56,0,79,0,73,0,64,0,43,0,76,0,56,0,37,0,26,0,31,0,25,0,14,0,35,0,16,0,60,0,57,0,97,0,75,0,114,0,91,0,54,0,73,0,55,0,41,0,48,0,53,0,23,0,24,0,58,0,27,0,50,0,96,0,76,0,70,0,93,0,84,0,77,0,58,0,79,0,29,0,74,0,49,0,41,0,17,0,47,0,45,0,78,0,74,0,115,0,94,0,90,0,79,0,69,0,83,0,71,0,50,0,59,0,38,0,36,0,15,0,72,0,34,0,56,0,95,0,92,0,85,0,91,0,90,0,86,0,73,0,77,0,65,0,51,0,44,0,43,0,42,0,43,0,20,0,30,0,44,0,55,0,78,0,72,0,87,0,78,0,61,0,46,0,54,0,37,0,30,0,20,0,16,0,53,0,25,0,41,0,37,0,44,0,59,0,54,0,81,0,66,0,76,0,57,0,54,0,37,0,18,0,39,0,11,0,35,0,33,0,31,0,57,0,42,0,82,0,72,0,80,0,47,0,58,0,55,0,21,0,22,0,26,0,38,0,22,0,53,0,25,0,23,0,38,0,70,0,60,0,51,0,36,0,55,0,26,0,34,0,23,0,27,0,14,0,9,0,7,0,34,0,32,0,28,0,39,0,49,0,75,0,30,0,52,0,48,0,40,0,52,0,28,0,18,0,17,0,9,0,5,0,45,0,21,0,34,0,64,0,56,0,50,0,49,0,45,0,31,0,19,0,12,0,15,0,10,0,7,0,6,0,3,0,48,0,23,0,20,0,39,0,36,0,35,0,53,0,21,0,16,0,23,0,13,0,10,0,6,0,1,0,4,0,2,0,16,0,15,0,17,0,27,0,25,0,20,0,29,0,11,0,17,0,12,0,16,0,8,0,1,0,1,0,0,0,1,0,9,0,6,0,16,0,33,0,41,0,39,0,38,0,26,0,7,0,5,0,6,0,9,0,23,0,16,0,26,0,11,0,17,0,7,0,11,0,14,0,21,0,30,0,10,0,7,0,17,0,10,0,15,0,12,0,18,0,28,0,14,0,5,0,32,0,13,0,22,0,19,0,18,0,16,0,9,0,5,0,40,0,17,0,31,0,29,0,17,0,13,0,4,0,2,0,27,0,12,0,11,0,15,0,10,0,7,0,4,0,1,0,27,0,12,0,8,0,12,0,6,0,3,0,1,0,0,0,9,0,6,0,16,0,33,0,41,0,39,0,38,0,26,0,7,0,5,0,6,0,9,0,23,0,16,0,26,0,11,0,17,0,7,0,11,0,14,0,21,0,30,0,10,0,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+656736);
/* memory initializer */ allocate([17,0,10,0,15,0,12,0,18,0,28,0,14,0,5,0,32,0,13,0,22,0,19,0,18,0,16,0,9,0,5,0,40,0,17,0,31,0,29,0,17,0,13,0,4,0,2,0,27,0,12,0,11,0,15,0,10,0,7,0,4,0,1,0,27,0,12,0,8,0,12,0,6,0,3,0,1,0,0,0,1,0,1,0,1,0,0,0,3,0,4,0,10,0,24,0,34,0,33,0,21,0,15,0,5,0,3,0,4,0,10,0,32,0,17,0,11,0,10,0,11,0,7,0,13,0,18,0,30,0,31,0,20,0,5,0,25,0,11,0,19,0,59,0,27,0,18,0,12,0,5,0,35,0,33,0,31,0,58,0,30,0,16,0,7,0,5,0,28,0,26,0,32,0,19,0,17,0,15,0,8,0,14,0,14,0,12,0,9,0,13,0,14,0,9,0,4,0,1,0,11,0,4,0,6,0,6,0,6,0,3,0,2,0,0,0,3,0,4,0,10,0,24,0,34,0,33,0,21,0,15,0,5,0,3,0,4,0,10,0,32,0,17,0,11,0,10,0,11,0,7,0,13,0,18,0,30,0,31,0,20,0,5,0,25,0,11,0,19,0,59,0,27,0,18,0,12,0,5,0,35,0,33,0,31,0,58,0,30,0,16,0,7,0,5,0,28,0,26,0,32,0,19,0,17,0,15,0,8,0,14,0,14,0,12,0,9,0,13,0,14,0,9,0,4,0,1,0,11,0,4,0,6,0,6,0,6,0,3,0,2,0,0,0,1,0,2,0,10,0,23,0,35,0,30,0,12,0,17,0,3,0,3,0,8,0,12,0,18,0,21,0,12,0,7,0,11,0,9,0,15,0,21,0,32,0,40,0,19,0,6,0,14,0,13,0,22,0,34,0,46,0,23,0,18,0,7,0,20,0,19,0,33,0,47,0,27,0,22,0,9,0,3,0,31,0,22,0,41,0,26,0,21,0,20,0,5,0,3,0,14,0,13,0,10,0,11,0,16,0,6,0,5,0,1,0,9,0,8,0,7,0,8,0,4,0,4,0,2,0,0,0,1,0,2,0,10,0,23,0,35,0,30,0,12,0,17,0,3,0,3,0,8,0,12,0,18,0,21,0,12,0,7,0,11,0,9,0,15,0,21,0,32,0,40,0,19,0,6,0,14,0,13,0,22,0,34,0,46,0,23,0,18,0,7,0,20,0,19,0,33,0,47,0,27,0,22,0,9,0,3,0,31,0,22,0,41,0,26,0,21,0,20,0,5,0,3,0,14,0,13,0,10,0,11,0,16,0,6,0,5,0,1,0,9,0,8,0,7,0,8,0,4,0,4,0,2,0,0,0,1,0,1,0,1,0,0,0,3,3,5,6,8,9,3,3,4,5,6,8,4,4,5,6,7,8,6,5,6,7,7,8,7,6,7,7,8,9,8,7,8,8,9,9,0,0,0,0,3,3,5,6,8,9,3,3,4,5,6,8,4,4,5,6,7,8,6,5,6,7,7,8,7,6,7,7,8,9,8,7,8,8,9,9,0,0,0,0,2,3,6,8,8,9,3,2,4,8,8,8,6,4,6,8,8,9,8,8,8,9,9,10,8,7,8,9,10,10,9,8,9,9,11,11,0,0,0,0,2,3,6,8,8,9,3,2,4,8,8,8,6,4,6,8,8,9,8,8,8,9,9,10,8,7,8,9,10,10,9,8,9,9,11,11,0,0,0,0,1,3,6,8,8,9,3,4,6,7,7,8,6,5,7,8,8,9,7,7,8,9,9,9,7,7,8,9,9,10,8,8,9,10,10,10,0,0,0,0,1,3,6,8,8,9,3,4,6,7,7,8,6,5,7,8,8,9,7,7,8,9,9,9,7,7,8,9,9,10,8,8,9,10,10,10,0,0,0,0,3,3,5,7,3,2,4,5,4,4,5,6,6,5,6,7,3,3,5,7,3,2,4,5,4,4,5,6,6,5,6,7,1,3,6,7,3,3,6,7,6,6,7,8,7,6,7,8,1,3,6,7,3,3,6,7,6,6,7,8,7,6,7,8,2,2,6,3,2,5,5,5,6,0,0,0,0,0,0,0,2,2,6,3,2,5,5,5,6,0,0,0,0,0,0,0,4,4,6,7,8,9,9,10,10,11,11,11,11,11,12,9,4,4,5,6,7,8,8,9,9,9,10,10,10,10,10,8,6,5,6,7,7,8,8,9,9,9,9,10,10,10,11,7,7,6,7,7,8,8,8,9,9,9,9,10,10,10,10,7,8,7,7,8,8,8,8,9,9,9,10,10,10,10,11,7,9,7,8,8,8,8,9,9,9,9,10,10,10,10,10,7,9,8,8,8,8,9,9,9,9,10,10,10,10,10,11,7,10,8,8,8,9,9,9,9,10,10,10,10,10,11,11,8,10,9,9,9,9,9,9,9,9,10,10,10,10,11,11,8,10,9,9,9,9,9,9,10,10,10,10,10,11,11,11,8,11,9,9,9,9,10,10,10,10,10,10,11,11,11,11,8,11,10,9,9,9,10,10,10,10,10,10,11,11,11,11,8,11,10,10,10,10,10,10,10,10,10,11,11,11,11,11,8,11,10,10,10,10,10,10,10,11,11,11,11,11,11,11,8,12,10,10,10,10,10,10,11,11,11,11,11,11,11,11,8,8,7,7,7,7,7,7,7,7,7,7,8,8,8,8,4,4,4,6,7,8,9,9,10,10,11,11,11,11,11,12,9,4,4,5,6,7,8,8,9,9,9,10,10,10,10,10,8,6,5,6,7,7,8,8,9,9,9,9,10,10,10,11,7,7,6,7,7,8,8,8,9,9,9,9,10,10,10,10,7,8,7,7,8,8,8,8,9,9,9,10,10,10,10,11,7,9,7,8,8,8,8,9,9,9,9,10,10,10,10,10,7,9,8,8,8,8,9,9,9,9,10,10,10,10,10,11,7,10,8,8,8,9,9,9,9,10,10,10,10,10,11,11,8,10,9,9,9,9,9,9,9,9,10,10,10,10,11,11,8,10,9,9,9,9,9,9,10,10,10,10,10,11,11,11,8,11,9,9,9,9,10,10,10,10,10,10,11,11,11,11,8,11,10,9,9,9,10,10,10,10,10,10,11,11,11,11,8,11,10,10,10,10,10,10,10,10,10,11,11,11,11,11,8,11,10,10,10,10,10,10,10,11,11,11,11,11,11,11,8,12,10,10,10,10,10,10,11,11,11,11,11,11,11,11,8,8,7,7,7,7,7,7,7,7,7,7,8,8,8,8,4,1,3,6,3,3,5,5,5,6,0,0,0,0,0,0,0,1,3,6,3,3,5,5,5,6,0,0,0,0,0,0,0,1,4,6,8,9,9,10,10,11,11,11,12,12,12,13,9,3,4,6,7,8,9,9,9,10,10,10,11,12,11,12,8,6,6,7,8,9,9,10,10,11,10,11,11,11,12,12,9,8,7,8,9,9,10,10,10,11,11,12,12,12,13,13,10,9,8,9,9,10,10,11,11,11,12,12,12,13,13,13,9,9,8,9,9,10,11,11,12,11,12,12,13,13,13,14,10,10,9,9,10,11,11,11,11,12,12,12,12,13,13,14,10,10,9,10,10,11,11,11,12,12,13,13,13,13,15,15,10,10,10,10,11,11,11,12,12,13,13,13,13,14,14,14,10,11,10,10,11,11,12,12,13,13,13,13,14,13,14,13,11,11,11,10,11,12,12,12,12,13,14,14,14,15,15,14,10,12,11,11,11,12,12,13,14,14,14,14,14,14,13,14,11,12,12,12,12,12,13,13,13,13,15,14,14,14,14,16,11,14,12,12,12,13,13,14,14,14,16,15,15,15,17,15,11,13,13,11,12,14,14,13,14,14,15,16,15,17,15,14,11,9,8,8,9,9,10,10,10,11,11,11,11,11,11,11,8,1,4,6,8,9,9,10,10,11,11,11,12,12,12,13,9,3,4,6,7,8,9,9,9,10,10,10,11,12,11,12,8,6,6,7,8,9,9,10,10,11,10,11,11,11,12,12,9,8,7,8,9,9,10,10,10,11,11,12,12,12,13,13,10,9,8,9,9,10,10,11,11,11,12,12,12,13,13,13,9,9,8,9,9,10,11,11,12,11,12,12,13,13,13,14,10,10,9,9,10,11,11,11,11,12,12,12,12,13,13,14,10,10,9,10,10,11,11,11,12,12,13,13,13,13,15,15,10,10,10,10,11,11,11,12,12,13,13,13,13,14,14,14,10,11,10,10,11,11,12,12,13,13,13,13,14,13,14,13,11,11,11,10,11,12,12,12,12,13,14,14,14,15,15,14,10,12,11,11,11,12,12,13,14,14,14,14,14,14,13,14,11,12,12,12,12,12,13,13,13,13,15,14,14,14,14,16,11,14,12,12,12,13,13,14,14,14,16,15,15,15,17,15,11,13,13,11,12,14,14,13,14,14,15,16,15,17,15,14,11,9,8,8,9,9,10,10,10,11,11,11,11,11,11,11,8,3,4,5,7,7,8,9,9,9,10,10,11,11,11,12,13,4,3,5,6,7,7,8,8,8,9,9,10,10,10,11,11,5,5,5,6,7,7,8,8,8,9,9,10,10,11,11,11,6,6,6,7,7,8,8,9,9,9,10,10,10,11,11,11,7,6,7,7,8,8,9,9,9,9,10,10,10,11,11,11,8,7,7,8,8,8,9,9,9,9,10,10,11,11,11,12,9,7,8,8,8,9,9,9,9,10,10,10,11,11,12,12,9,8,8,9,9,9,9,10,10,10,10,10,11,11,11,12,9,8,8,9,9,9,9,10,10,10,10,11,11,12,12,12,9,8,9,9,9,9,10,10,10,11,11,11,11,12,12,12,10,9,9,9,10,10,10,10,10,11,11,11,11,12,13,12,10,9,9,9,10,10,10,10,11,11,11,11,12,12,12,13,11,10,9,10,10,10,11,11,11,11,11,11,12,12,13,13,11,10,10,10,10,11,11,11,11,12,12,12,12,12,13,13,12,11,11,11,11,11,11,11,12,12,12,12,13,13,12,13,12,11,11,11,11,11,11,12,12,12,12,12,13,13,13,13,3,4,5,7,7,8,9,9,9,10,10,11,11,11,12,13,4,3,5,6,7,7,8,8,8,9,9,10,10,10,11,11,5,5,5,6,7,7,8,8,8,9,9,10,10,11,11,11,6,6,6,7,7,8,8,9,9,9,10,10,10,11,11,11,7,6,7,7,8,8,9,9,9,9,10,10,10,11,11,11,8,7,7,8,8,8,9,9,9,9,10,10,11,11,11,12,9,7,8,8,8,9,9,9,9,10,10,10,11,11,12,12,9,8,8,9,9,9,9,10,10,10,10,10,11,11,11,12,9,8,8,9,9,9,9,10,10,10,10,11,11,12,12,12,9,8,9,9,9,9,10,10,10,11,11,11,11,12,12,12,10,9,9,9,10,10,10,10,10,11,11,11,11,12,13,12,10,9,9,9,10,10,10,10,11,11,11,11,12,12,12,13,11,10,9,10,10,10,11,11,11,11,11,11,12,12,13,13,11,10,10,10,10,11,11,11,11,12,12,12,12,12,13,13,12,11,11,11,11,11,11,11,12,12,12,12,13,13,12,13,12,11,11,11,11,11,11,12,12,12,12,12,13,13,13,13,1,4,6,7,8,9,9,10,9,10,11,11,12,12,13,13,3,4,6,7,8,8,9,9,9,9,10,10,11,12,12,12,6,6,7,8,9,9,10,10,9,10,10,11,11,12,13,13,7,7,8,9,9,10,10,10,10,11,11,11,11,12,13,13,8,7,9,9,10,10,11,11,10,11,11,12,12,13,13,14,9,8,9,10,10,10,11,11,11,11,12,11,13,13,14,14,9,9,10,10,11,11,11,11,11,12,12,12,13,13,14,14,10,9,10,11,11,11,12,12,12,12,13,13,13,14,16,16,9,8,9,10,10,11,11,12,12,12,12,13,13,14,15,15,10,9,10,10,11,11,11,13,12,13,13,14,14,14,16,15,10,10,10,11,11,12,12,13,12,13,14,13,14,15,16,17,11,10,10,11,12,12,12,12,13,13,13,14,15,15,15,16,11,11,11,12,12,13,12,13,14,14,15,15,15,16,16,16,12,11,12,13,13,13,14,14,14,14,14,15,16,15,16,16,13,12,12,13,13,13,15,14,14,17,15,15,15,17,16,16,12,12,13,14,14,14,15,14,15,15,16,16,19,18,19,16,1,4,6,7,8,9,9,10,9,10,11,11,12,12,13,13,3,4,6,7,8,8,9,9,9,9,10,10,11,12,12,12,6,6,7,8,9,9,10,10,9,10,10,11,11,12,13,13,7,7,8,9,9,10,10,10,10,11,11,11,11,12,13,13,8,7,9,9,10,10,11,11,10,11,11,12,12,13,13,14,9,8,9,10,10,10,11,11,11,11,12,11,13,13,14,14,9,9,10,10,11,11,11,11,11,12,12,12,13,13,14,14,10,9,10,11,11,11,12,12,12,12,13,13,13,14,16,16,9,8,9,10,10,11,11,12,12,12,12,13,13,14,15,15,10,9,10,10,11,11,11,13,12,13,13,14,14,14,16,15,10,10,10,11,11,12,12,13,12,13,14,13,14,15,16,17,11,10,10,11,12,12,12,12,13,13,13,14,15,15,15,16,11,11,11,12,12,13,12,13,14,14,15,15,15,16,16,16,12,11,12,13,13,13,14,14,14,14,14,15,16,15,16,16,13,12,12,13,13,13,15,14,14,17,15,15,15,17,16,16,12,12,13,14,14,14,15,14,15,15,16,16,19,18,19,16,4,3,5,7,8,9,9,9,3,3,4,5,7,7,8,8,5,4,5,6,7,8,7,8,6,5,6,6,7,8,8,8,7,6,7,7,8,8,8,9,8,7,8,8,8,9,8,9,8,7,7,8,8,9,9,10,9,8,8,9,9,9,9,10,4,3,5,7,8,9,9,9,3,3,4,5,7,7,8,8,5,4,5,6,7,8,7,8,6,5,6,6,7,8,8,8,7,6,7,7,8,8,8,9,8,7,8,8,8,9,8,9,8,7,7,8,8,9,9,10,9,8,8,9,9,9,9,10,1,3,2,3,0,0,0,0,2,3,5,7,8,9,8,9,3,3,4,6,8,8,7,8,5,5,6,7,8,9,8,8,7,6,7,9,8,10,8,9,8,8,8,9,9,10,9,10,8,8,9,10,10,11,10,11,8,7,7,8,9,10,10,10,8,7,8,9,10,10,10,10,2,3,5,7,8,9,8,9,3,3,4,6,8,8,7,8,5,5,6,7,8,9,8,8,7,6,7,9,8,10,8,9,8,8,8,9,9,10,9,10,8,8,9,10,10,11,10,11,8,7,7,8,9,10,10,10,8,7,8,9,10,10,10,10,1,3,6,8,9,9,9,10,3,4,6,7,8,9,8,8,6,6,7,8,9,10,9,9,7,7,8,9,10,10,9,10,8,8,9,10,10,10,10,10,9,9,10,10,11,11,10,11,8,8,9,10,10,10,11,11,9,8,9,10,10,11,11,11,1,3,6,8,9,9,9,10,3,4,6,7,8,9,8,8,6,6,7,8,9,10,9,9,7,7,8,9,10,10,9,10,8,8,9,10,10,10,10,10,9,9,10,10,11,11,10,11,8,8,9,10,10,10,11,11,9,8,9,10,10,11,11,11,1,3,2,3,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,184,57,10,0,184,45,10,0,3,0,0,0,24,51,10,0,136,32,10,0,3,0,0,0,248,48,10,0,88,28,10,0,4,0,0,0,216,48,10,0,24,28,10,0,4,0,0,0,184,48,10,0,216,27,10,0,6,0,0,0,104,48,10,0,72,27,10,0,6,0,0,0,24,48,10,0,184,26,10,0,6,0,0,0,200,47,10,0,40,26,10,0,8,0,0,0,64,58,10,0,192,46,10,0,8,0,0,0,192,57,10,0,192,45,10,0,8,0,0,0,56,57,10,0,184,44,10,0,16,0,0,0,56,55,10,0,184,40,10,0,16,0,0,0,56,53,10,0,184,36,10,0,16,0,0,0,56,51,10,0,184,32,10,0,16,0,0,0,24,49,10,0,136,28,10,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,192,58,10,0,192,47,10,0,3,0,0,0,40,51,10,0,160,32,10,0,3,0,0,0,8,49,10,0,112,28,10,0,4,0,0,0,232,48,10,0,56,28,10,0,4,0,0,0,200,48,10,0,248,27,10,0,6,0,0,0,144,48,10,0,144,27,10,0,6,0,0,0,64,48,10,0,0,27,10,0,6,0,0,0,240,47,10,0,112,26,10,0,8,0,0,0,128,58,10,0,64,47,10,0,8,0,0,0,0,58,10,0,64,46,10,0,8,0,0,0,120,57,10,0,56,45,10,0,16,0,0,0,56,56,10,0,184,42,10,0,16,0,0,0,56,54,10,0,184,38,10,0,16,0,0,0,56,52,10,0,184,34,10,0,16,0,0,0,24,50,10,0,136,30,10,0,0,0,1,0,2,0,3,0,0,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,0,0,13,0,14,1,14,2,14,3,14,4,14,6,14,8,14,10,14,13,15,4,15,5,15,6,15,7,15,8,15,9,15,11,15,13,0,0,1,0,2,0,3,0,0,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,0,0,13,0,14,1,14,2,14,3,14,4,14,6,14,8,14,10,14,13,15,4,15,5,15,6,15,7,15,8,15,9,15,11,15,13,56,247,28,0,108,0,0,0,16,75,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,80,1,0,29,0,0,0,14,80,1,0,32,0,0,0,14,80,1,0,33,0,0,0,14,80,1,0,34,0,0,0,46,80,1,0,36,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,160,37,32,0,108,0,0,0,240,73,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,3,3,4,5,0,1,1,2,3,3,4,5,72,225,35,0,72,147,35,0,0,0,0,0,0,0,0,0,80,225,35,0,80,147,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,248,70,31,0,0,0,0,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,144,148,30,0,152,2,30,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,168,148,29,0,152,2,30,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,32,54,29,0,8,230,28,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,72,224,35,0,8,230,28,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,224,145,35,0,120,50,35,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,181,160,247,198,160,66,24,0,1,0,0,0,0,0,96,235,34,0,120,50,35,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,181,160,247,198,160,66,24,0,1,0,0,0,0,0,208,171,34,0,48,112,34,0,32,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,95,64,0,0,0,0,0,192,95,64,24,0,1,0,0,0,0,0,24,56,34,0,48,112,34,0,32,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,95,64,0,0,0,0,0,192,95,64,24,0,1,0,0,0,0,0,128,7,34,0,232,216,33,0,40,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,46,34,0,108,0,0,0,184,61,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,29,155,5,66,213,68,230,128,226,20,29,175,247,87,178,212,128,126,242,202,57,70,149,142,84,38,203,158,70,167,159,165,212,11,48,232,20,17,221,186,47,8,0,32,12,154,102,0,0,0,0,1,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,255,255,255,255,0,0,0,18,102,116,97,98,0,1,0,1,5,83,101,114,105,102,166,8,0,0,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,165,212,11,48,232,20,17,221,186,47,8,0,32,12,154,102,1,0,0,0,121,117,118,50,0,0,0,0,1,0,0,0,121,117,118,115,0,0,0,0,17,0,0,0,50,118,117,121,0,0,0,0,45,0,0,0,114,97,119,32,16,0,0,0,46,0,0,0,76,53,53,53,16,0,0,0,44,0,0,0,76,53,54,53,16,0,0,0,43,0,0,0,66,53,54,53,16,0,0,0,31,0,0,0,98,49,54,103,16,0,0,0,2,0,0,0,114,97,119,32,24,0,0,0,3,0,0,0,50,52,66,71,24,0,0,0,27,0,0,0,114,97,119,32,32,0,0,0,30,0,0,0,66,71,82,65,32,0,0,0,28,0,0,0,82,71,66,65,32,0,0,0,29,0,0,0,65,66,71,82,32,0,0,0,41,0,0,0,98,52,56,114,48,0,0,0,0,0,0,0,16,187,31,0,108,0,0,0,16,75,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,110,103,0,102,114,97,0,103,101,114,0,105,116,97,0,100,117,116,0,115,118,101,0,115,112,97,0,100,97,110,0,112,111,114,0,110,111,114,0,104,101,98,0,106,112,110,0,97,114,97,0,102,105,110,0,103,114,101,0,105,99,101,0,109,108,116,0,116,117,114,0,104,114,32,0,99,104,105,0,117,114,100,0,104,105,110,0,116,104,97,0,107,111,114,0,108,105,116,0,112,111,108,0,104,117,110,0,101,115,116,0,108,97,118,0,0,0,0,0,102,111,32,0,0,0,0,0,114,117,115,0,99,104,105,0,0,0,0,0,105,114,105,0,97,108,98,0,114,111,110,0,99,101,115,0,115,108,107,0,115,108,118,0,121,105,100,0,115,114,32,0,109,97,99,0,98,117,108,0,117,107,114,0,98,101,108,0,117,122,98,0,107,97,122,0,97,122,101,0,97,122,101,0,97,114,109,0,103,101,111,0,109,111,108,0,107,105,114,0,116,103,107,0,116,117,107,0,109,111,110,0,0,0,0,0,112,117,115,0,107,117,114,0,107,97,115,0,115,110,100,0,116,105,98,0,110,101,112,0,115,97,110,0,109,97,114,0,98,101,110,0,97,115,109,0,103,117,106,0,112,97,32,0,111,114,105,0,109,97,108,0,107,97,110,0,116,97,109,0,116,101,108,0,0,0,0,0,98,117,114,0,107,104,109,0,108,97,111,0,118,105,101,0,105,110,100,0,116,103,108,0,109,97,121,0,109,97,121,0,97,109,104,0,116,105,114,0,111,114,109,0,115,111,109,0,115,119,97,0,0,0,0,0,114,117,110,0,0,0,0,0,109,108,103,0,101,112,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,101,108,0,98,97,113,0,99,97,116,0,108,97,116,0,113,117,101,0,103,114,110,0,97,121,109,0,116,97,116,0,117,105,103,0,100,122,111,0,106,97,118,0,0,0,0,0,65,67,76,82,210,0,0,0,65,80,82,71,210,0,0,0,65,65,76,80,210,0,0,0,65,82,69,83,56,1,0,0,97,118,115,115,54,0,0,0,99,104,112,108,2,1,0,0,99,111,54,52,46,1,0,0,99,116,116,115,226,0,0,0,100,105,110,102,32,1,0,0,100,114,101,102,200,0,0,0,101,100,116,115,32,1,0,0,101,108,115,116,88,0,0,0,101,110,100,97,202,0,0,0,102,105,101,108,14,1,0,0,102,116,121,112,92,0,0,0,103,108,98,108,188,0,0,0,104,100,108,114,32,0,0,0,105,108,115,116,228,0,0,0,106,112,50,104,8,0,0,0,109,100,97,116,8,1,0,0,109,100,104,100,52,0,0,0,109,100,105,97,32,1,0,0,109,101,116,97,10,0,0,0,109,105,110,102,32,1,0,0,109,111,111,102,240,0,0,0,109,111,111,118,238,0,0,0,109,118,101,120,32,1,0,0,109,118,104,100,234,0,0,0,83,77,73,32,82,0,0,0,97,108,97,99,174,0,0,0,97,118,99,67,188,0,0,0,112,97,115,112,22,1,0,0,115,116,98,108,32,1,0,0,115,116,99,111,46,1,0,0,115,116,112,115,60,0,0,0,115,116,114,102,66,0,0,0,115,116,115,99,220,0,0,0,115,116,115,100,218,0,0,0,115,116,115,115,222,0,0,0,115,116,115,122,78,0,0,0,115,116,116,115,80,0,0,0,115,116,122,50,78,0,0,0,116,107,104,100,50,0,0,0,116,102,104,100,60,1,0,0,116,114,97,107,44,0,0,0,116,114,97,102,32,1,0,0,116,114,101,102,32,1,0,0,116,109,99,100,2,0,0,0,99,104,97,112,6,0,0,0,116,114,101,120,72,0,0,0,116,114,117,110,160,0,0,0,117,100,116,97,32,1,0,0,119,97,118,101,254,0,0,0,101,115,100,115,198,0,0,0,100,97,99,51,94,0,0,0,100,101,99,51,28,0,0,0,119,105,100,101,4,1,0,0,119,102,101,120,30,1,0,0,99,109,111,118,230,0,0,0,99,104,97,110,4,0,0,0,100,118,99,49,176,0,0,0,115,98,103,112,110,0,0,0,104,118,99,67,188,0,0,0,117,117,105,100,20,0,0,0,67,105,110,142,166,0,0,0,0,0,0,0,0,0,0,0,2,80,1,0,120,72,10,0,3,80,1,0,56,72,10,0,16,80,1,0,16,72,10,0,5,0,1,0,224,71,10,0,4,0,1,0,224,71,10,0,0,0,1,0,224,71,10,0,1,0,1,0,224,71,10,0,12,0,1,0,224,71,10,0,13,0,1,0,224,71,10,0,8,0,1,0,224,71,10,0,9,0,1,0,224,71,10,0,21,0,1,0,224,71,10,0,20,0,1,0,224,71,10,0,23,0,1,0,224,71,10,0,22,0,1,0,224,71,10,0,0,0,0,0,0,0,0,0,48,173,32,0,108,0,0,0,32,80,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,1,0,100,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,101,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,102,0,0,0,0,0,3,1,0,0,0,0,0,0,3,0,131,0,0,0,0,0,51,0,0,0,0,0,0,0,4,0,132,0,0,0,0,0,3,6,0,0,0,0,0,0,4,0,132,0,0,0,0,0,51,0,0,0,0,0,0,0,4,0,108,0,0,0,0,0,7,0,0,0,0,0,0,0,3,0,113,0,0,0,0,0,7,1,0,0,0,0,0,0,4,0,115,0,0,0,0,0,55,0,0,0,0,0,0,0,5,0,117,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,117,0,0,0,0,0,63,0,0,0,0,0,0,0,6,0,121,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,121,0,0,0,0,0,63,6,0,0,0,0,0,0,8,0,128,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,126,0,0,0,0,0,63,0,0,96,0,0,0,0,8,0,130,0,0,0,0,0,11,0,0,0,0,0,0,0,3,0,133,0,0,0,0,0,11,1,0,0,0,0,0,0,4,0,134,0,0,0,0,0,59,0,0,0,0,0,0,0,4,0,135,0,0,0,0,0,11,6,0,0,0,0,0,0,4,0,135,0,0,0,0,0,15,0,0,0,0,0,0,0,4,0,136,0,0,0,0,0,15,1,0,0,0,0,0,0,5,0,137,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,0,2,0,101,0,2,0,103,0,3,0,113,0,4,0,108,0,5,0,117,0,6,0,121,0,7,0,125,0,8,0,126,0,8,0,128,0,8,0,130,0,0,0,0,0,1,0,100,0,2,0,101,0,3,0,114,0,4,0,116,0,5,0,120,0,6,0,124,0,7,0,142,0,8,0,127,0,0,0,0,0,0,0,0,0,1,0,100,0,2,0,101,0,2,0,149,0,3,0,150,0,3,0,131,0,3,0,133,0,4,0,151,0,4,0,132,0,4,0,153,0,4,0,152,0,5,0,119,0,5,0,138,0,5,0,154,0,6,0,123,0,0,0,0,0,0,0,0,0,1,0,100,0,2,0,101,0,2,0,149,0,3,0,114,0,3,0,131,0,3,0,133,0,4,0,108,0,4,0,116,0,4,0,132,0,4,0,153,0,4,0,168,0,5,0,120,0,5,0,138,0,5,0,169,0,6,0,124,0,6,0,141,0,6,0,170,0,7,0,142,0,7,0,143,0,7,0,173,0,8,0,144,0,8,0,127,0,8,0,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,16,0,145,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,146,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,180,0,0,0,0,0,251,6,0,0,0,0,0,0,9,0,181,0,0,0,0,0,207,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,0,0,0,0,0,55,7,0,0,0,0,0,0,8,0,144,0,0,0,0,0,55,7,0,0,0,0,0,0,8,0,112,0,0,0,0,0,51,208,2,0,0,0,0,0,8,0,126,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,127,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,129,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,161,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,177,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,128,0,0,0,0,0,63,6,0,0,0,0,0,0,8,0,160,0,0,0,0,0,63,6,0,0,0,0,0,0,8,0,130,0,0,0,0,0,15,6,0,96,0,0,0,0,8,0,162,0,0,0,0,0,15,6,0,0,6,0,0,0,8,0,163,0,0,0,0,0,15,6,0,128,1,0,0,0,8,0,164,0,0,0,0,0,15,86,0,0,0,0,0,0,8,0,165,0,0,0,0,0,15,15,0,0,0,0,0,0,8,0,166,0,0,0,0,0,15,39,0,0,0,0,0,0,8,0,167,0,0,0,0,0,15,46,0,0,0,0,0,0,8,0,178,0,0,0,0,0,243,6,0,0,0,0,0,0,8,0,179,0,0,0,0,0,199,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,125,0,0,0,0,0,15,7,0,0,0,0,0,0,7,0,142,0,0,0,0,0,15,7,0,0,0,0,0,0,7,0,157,0,0,0,0,0,15,7,0,0,0,0,0,0,7,0,182,0,0,0,0,0,15,7,0,0,0,0,0,0,7,0,140,0,0,0,0,0,55,6,0,0,0,0,0,0,7,0,143,0,0,0,0,0,55,6,0,0,0,0,0,0,7,0,156,0,0,0,0,0,55,6,0,0,0,0,0,0,7,0,148,0,0,0,0,0,199,6,0,0,0,0,0,0,7,0,176,0,0,0,0,0,199,6,0,0,0,0,0,0,7,0,158,0,0,0,0,0,15,14,0,0,0,0,0,0,7,0,159,0,0,0,0,0,15,38,0,0,0,0,0,0,7,0,173,0,0,0,0,0,203,6,0,0,0,0,0,0,7,0,174,0,0,0,0,0,63,8,0,0,0,0,0,0,7,0,175,0,0,0,0,0,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,110,0,0,0,0,0,55,1,0,0,0,0,0,0,6,0,172,0,0,0,0,0,55,1,0,0,0,0,0,0,6,0,121,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,122,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,123,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,124,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,139,0,0,0,0,0,7,7,0,0,0,0,0,0,6,0,141,0,0,0,0,0,7,7,0,0,0,0,0,0,6,0,155,0,0,0,0,0,7,7,0,0,0,0,0,0,6,0,170,0,0,0,0,0,195,6,0,0,0,0,0,0,6,0,171,0,0,0,0,0,55,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,109,0,0,0,0,0,55,0,0,0,0,0,0,0,5,0,117,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,118,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,119,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,120,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,135,0,0,0,0,0,11,6,0,0,0,0,0,0,5,0,138,0,0,0,0,0,11,6,0,0,0,0,0,0,5,0,137,0,0,0,0,0,15,1,0,0,0,0,0,0,5,0,154,0,0,0,0,0,15,1,0,0,0,0,0,0,5,0,169,0,0,0,0,0,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,0,0,0,0,0,51,0,0,0,0,0,0,0,4,0,115,0,0,0,0,0,7,1,0,0,0,0,0,0,4,0,116,0,0,0,0,0,7,1,0,0,0,0,0,0,4,0,151,0,0,0,0,0,7,1,0,0,0,0,0,0,4,0,132,0,0,0,0,0,3,6,0,0,0,0,0,0,4,0,134,0,0,0,0,0,11,1,0,0,0,0,0,0,4,0,153,0,0,0,0,0,11,1,0,0,0,0,0,0,4,0,136,0,0,0,0,0,15,0,0,0,0,0,0,0,4,0,152,0,0,0,0,0,15,0,0,0,0,0,0,0,4,0,168,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,113,0,0,0,0,0,7,0,0,0,0,0,0,0,3,0,114,0,0,0,0,0,7,0,0,0,0,0,0,0,3,0,150,0,0,0,0,0,7,0,0,0,0,0,0,0,3,0,131,0,0,0,0,0,3,1,0,0,0,0,0,0,3,0,133,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,102,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,106,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,104,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,105,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,103,0,0,0,0,0,0,0,0,96,0,0,0,0,2,0,149,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,72,10,0,184,78,10,0,56,78,10,0,216,77,10,0,24,77,10,0,104,76,10,0,168,75,10,0,184,74,10,0,120,73,10,0,72,73,10,0,0,0,255,213,6,213,247,214,13,215,240,216,19,217,233,220,26,222,254,223,4,223,227,224,247,224,11,225,240,227,32,227,18,228,222,230,234,231,255,231,3,231,249,232,8,232,24,233,36,233,244,234,13,235,218,236,0,236,229,237,252,237,4,237,239,238,248,239,8,239,18,239,28,239,39,239,244,241,12,241,235,242,255,242,1,242,215,243,251,243,5,243,21,243,225,244,241,245,248,245,8,245,15,245,254,246,1,246,31,246,233,247,245,247,251,247,4,247,11,247,42,247,6,248,24,248,238,249,249,249,253,249,255,249,2,249,18,249,213,250,243,250,252,250,4,250,8,250,223,251,247,251,254,251,0,251,2,251,5,251,13,251,231,252,250,252,253,252,3,252,9,252,237,253,249,253,252,253,254,253,255,253,0,253,1,253,2,253,4,253,6,253,33,253,242,254,246,254,251,254,253,254,254,254,255,254,0,254,1,254,2,254,3,254,5,254,7,254,14,254,19,254,25,254,43,254,249,255,253,255,254,255,255,255,0,255,1,255,2,255,3,255,10,255,251,0,253,0,254,0,255,0,1,0,2,0,3,0,5,0,7,0,246,1,249,1,253,1,254,1,255,1,0,1,1,1,2,1,3,1,213,2,231,2,237,2,242,2,251,2,253,2,254,2,255,2,0,2,1,2,2,2,3,2,5,2,7,2,10,2,14,2,223,3,250,3,252,3,254,3,255,3,0,3,1,3,2,3,4,3,19,3,247,4,253,4,3,4,7,4,25,4,243,5,251,5,254,5,0,5,2,5,5,5,9,5,33,5,248,6,252,6,4,6,13,6,43,6,238,7,254,7,0,7,2,7,7,7,18,7,232,8,250,8,214,9,245,9,252,9,5,9,11,9,23,9,225,10,255,10,2,10,241,11,248,11,8,11,15,11,31,12,235,13,251,13,5,13,41,13,255,14,1,14,21,14,244,15,12,15,217,17,228,17,238,17,248,17,8,17,17,18,252,19,0,19,4,19,27,19,38,20,243,21,12,22,220,23,232,23,248,24,7,24,253,25,1,25,22,25,34,26,238,28,224,29,16,29,245,31,9,32,29,32,252,33,2,33,230,34,23,36,237,39,16,40,243,41,9,42,250,43,1,43,0,0,0,0,0,0,0,0,0,3,1,3,2,3,6,4,7,4,8,4,9,4,40,6,41,6,42,6,43,6,44,6,45,6,46,6,47,6,96,7,97,7,98,7,99,7,100,7,101,7,102,7,103,7,104,7,105,7,106,7,107,7,108,7,109,7,110,7,111,7,224,8,225,8,226,8,227,8,228,8,229,8,230,8,231,8,232,8,233,8,234,8,235,8,236,8,237,8,238,8,239,8,240,8,241,8,242,8,243,8,244,8,245,8,246,8,247,8,248,8,249,8,250,8,251,8,252,8,253,8,254,8,255,8,0,0,0,0,0,0,1,0,0,0,255,255,255,255,2,0,0,0,254,255,255,255,3,0,0,0,253,255,255,255,4,0,0,0,252,255,255,255,5,0,0,0,251,255,255,255,6,0,0,0,250,255,255,255,7,0,0,0,249,255,255,255,8,0,0,0,248,255,255,255,9,0,0,0,247,255,255,255,10,0,0,0,246,255,255,255,11,0,0,0,245,255,255,255,12,0,0,0,244,255,255,255,13,0,0,0,243,255,255,255,14,0,0,0,242,255,255,255,15,0,0,0,241,255,255,255,16,0,0,0,240,255,255,255,17,0,0,0,239,255,255,255,18,0,0,0,238,255,255,255,19,0,0,0,237,255,255,255,20,0,0,0,236,255,255,255,21,0,0,0,235,255,255,255,22,0,0,0,234,255,255,255,23,0,0,0,233,255,255,255,24,0,0,0,232,255,255,255,25,0,0,0,231,255,255,255,26,0,0,0,230,255,255,255,27,0,0,0,229,255,255,255,28,0,0,0,228,255,255,255,29,0,0,0,227,255,255,255,30,0,0,0,226,255,255,255,31,0,0,0,225,255,255,255,0,0,0,0,252,252,254,252,0,252,2,252,252,254,252,0,253,253,255,253,1,253,3,253,253,255,254,254,0,254,2,254,4,254,254,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,255,255,255,255,1,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,1,0,0,0,74,97,110,0,70,101,98,0,77,97,114,0,65,112,114,0,77,97,121,0,74,117,110,0,74,117,108,0,65,117,103,0,83,101,112,0,79,99,116,0,78,111,118,0,68,101,99,0,0,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,0,0,1,2,4,5,6,8,9,10,16,17,18,20,21,22,24,25,26,32,33,34,36,37,38,40,41,42,64,65,66,68,69,70,72,73,74,80,81,82,84,85,86,88,89,90,96,97,98,100,101,102,104,105,106,128,129,130,132,133,134,136,137,138,144,145,146,148,149,150,152,153,154,160,161,162,164,165,166,168,169,170,192,193,194,196,197,198,200,201,202,208,209,210,212,213,214,216,217,218,224,225,226,228,229,230,232,233,234,0,0,0,0,120,30,32,0,160,0,2,1,0,0,0,0,10,1,7,8,7,7,7,9,6,0,0,0,4,4,5,4,5,4,5,4,5,4,5,5,248,64,31,0,152,0,3,1,205,204,76,63,3,0,6,7,7,7,5,8,5,5,0,0,0,9,9,9,0,0,0,0,0,0,0,7,88,143,30,0,232,0,3,2,205,204,76,63,3,0,6,7,7,7,5,8,5,5,0,0,0,5,5,5,0,0,0,0,0,0,0,7,64,253,29,0,40,1,5,2,154,153,89,63,1,0,6,7,7,7,5,8,5,8,5,5,0,10,0,0,0,0,0,0,0,0,0,7,0,1,2,2,6,3,14,4,30,5,62,6,126,7,127,7,16,0,0,0,64,122,26,0,10,0,0,0,208,192,5,0,1,6,0,0,112,4,6,0,240,11,6,0,15,0,0,0,4,0,0,0,168,123,26,0,20,0,0,0,208,187,5,0,2,6,0,0,112,246,5,0,112,253,5,0,14,0,0,0,1,0,0,0,48,126,26,0,40,0,0,0,208,182,5,0,4,6,0,0,112,232,5,0,112,239,5,0,14,0,0,0,0,8,20,0,208,206,5,0,1,6,4,4,208,197,5,0,9,84,54,7,176,1,0,0,16,0,0,0,64,122,26,0,10,0,0,0,208,192,5,0,1,6,0,0,208,164,5,0,208,173,5,0,18,0,0,0,4,0,0,0,168,123,26,0,20,0,0,0,208,187,5,0,2,6,0,0,208,147,5,0,80,156,5,0,17,0,0,0,1,0,0,0,48,126,26,0,40,0,0,0,208,182,5,0,4,6,0,0,208,130,5,0,80,139,5,0,17,0,0,0,0,8,20,0,208,206,5,0,1,6,4,4,208,197,5,0,9,84,54,7,176,1,0,0,4,0,0,0,136,122,26,0,10,0,0,0,80,62,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+666976);
/* memory initializer */ allocate([1,6,0,0,208,119,5,0,80,125,5,0,11,0,0,0,2,0,0,0,112,124,26,0,20,0,0,0,80,57,5,0,2,6,0,0,208,108,5,0,80,114,5,0,11,0,0,0,1,0,0,0,16,127,26,0,32,0,0,0,80,53,5,0,4,6,0,0,208,96,5,0,208,102,5,0,12,0,0,0,0,2,16,0,80,76,5,0,1,6,4,4,80,67,5,0,9,56,36,7,72,0,0,0,8,0,0,0,136,122,26,0,10,0,0,0,208,230,4,0,1,6,0,0,80,38,5,0,208,45,5,0,15,0,0,0,2,0,0,0,32,124,26,0,20,0,0,0,208,225,4,0,2,6,0,0,80,24,5,0,80,31,5,0,14,0,0,0,1,0,0,0,80,127,26,0,32,0,0,0,208,221,4,0,4,6,0,0,80,9,5,0,208,16,5,0,15,0,0,0,0,4,16,0,208,244,4,0,1,6,4,3,208,235,4,0,9,56,36,7,144,0,0,0,8,0,0,0,136,122,26,0,10,0,0,0,208,230,4,0,1,6,0,0,208,203,4,0,208,212,4,0,18,0,0,0,2,0,0,0,32,124,26,0,20,0,0,0,208,225,4,0,2,6,0,0,208,186,4,0,80,195,4,0,17,0,0,0,1,0,0,0,80,127,26,0,32,0,0,0,208,221,4,0,4,6,0,0,208,168,4,0,208,177,4,0,18,0,0,0,0,4,16,0,208,244,4,0,1,6,4,3,208,235,4,0,9,56,36,7,144,0,0,0,8,0,0,0,208,122,26,0,10,0,0,0,112,82,4,0,1,5,0,0,208,152,4,0,208,160,4,0,16,0,0,0,2,0,0,0,192,124,26,0,20,0,0,0,240,79,4,0,2,5,0,0,208,137,4,0,80,145,4,0,15,0,0,0,1,0,0,0,16,128,26,0,30,0,0,0,240,74,4,0,3,6,0,0,208,121,4,0,208,129,4,0,16,0,0,0,0,4,16,0,240,99,4,0,1,6,4,3,240,84,4,0,9,56,60,7,180,0,0,0,8,0,0,0,24,123,26,0,10,0,0,0,240,238,3,0,1,5,0,0,240,53,4,0,112,64,4,0,21,0,0,0,2,0,0,0,64,125,26,0,20,0,0,0,112,236,3,0,2,5,0,0,240,35,4,0,240,44,4,0,18,0,0,0,1,0,0,0,208,128,26,0,30,0,0,0,112,231,3,0,3,6,0,0,240,15,4,0,240,25,4,0,20,0,0,0,0,2,16,0,112,251,3,0,1,6,4,3,112,241,3,0,9,36,30,7,90,0,0,0,8,0,0,0,24,123,26,0,10,0,0,0,240,238,3,0,1,5,0,0,112,202,3,0,240,216,3,0,29,0,0,0,2,0,0,0,64,125,26,0,20,0,0,0,112,236,3,0,2,5,0,0,112,178,3,0,112,190,3,0,24,0,0,0,1,0,0,0,208,128,26,0,30,0,0,0,112,231,3,0,3,6,0,0,112,151,3,0,240,164,3,0,27,0,0,0,0,2,16,0,112,251,3,0,1,6,4,3,112,241,3,0,9,36,30,7,90,0,0,0,8,0,0,0,64,123,26,0,10,0,0,0,240,87,3,0,1,5,0,0,112,117,3,0,112,126,3,0,18,0,0,0,2,0,0,0,136,125,26,0,20,0,0,0,112,85,3,0,2,5,0,0,112,135,3,0,112,143,3,0,16,0,0,0,1,0,0,0,64,129,26,0,30,0,0,0,112,80,3,0,3,6,0,0,112,100,3,0,240,108,3,0,17,0,0,0,0,2,12,0,144,72,3,0,1,5,3,3,112,90,3,0,8,28,20,6,40,0,0,0,35,33,105,76,66,67,51,48,10,0,0,0,0,0,0,0,0,0,102,2,198,4,2,7,106,9,198,11,2,14,106,16,184,18,6,21,78,23,142,25,226,27,36,30,100,32,160,34,228,36,46,39,146,41,204,43,38,46,0,0,0,0,0,0,35,33,105,76,66,67,50,48,10,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,0,0,0,0,160,15,0,0,64,31,0,0,17,43,0,0,34,86,0,0,68,172,0,0,0,0,0,0,16,20,24,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,3,4,5,3,4,5,4,5,6,4,5,4,5,6,5,5,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,202,154,59,96,97,35,0,108,0,0,0,176,80,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,213,29,0,108,0,0,0,48,124,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,129,33,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,59,223,79,141,151,250,63,104,145,237,124,63,53,244,191,106,222,113,138,142,228,222,63,134,201,84,193,168,164,210,191,151,255,144,126,251,58,192,63,188,5,18,20,63,198,188,191,17,141,238,32,118,166,160,63,99,238,90,66,62,232,137,191,9,167,5,47,250,10,162,191,64,32,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,6,0,0,240,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,35,29,0,216,211,28,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,153,153,153,201,65,16,0,1,0,0,0,0,0,176,206,35,0,64,124,35,0,16,0,0,0,84,77,70,80,43,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,126,32,0,108,0,0,0,8,91,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,138,139,184,73,176,128,76,173,207,88,152,152,94,34,193,108,23,95,69,6,75,206,71,154,239,140,174,247,61,247,181,32,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,227,118,42,247,10,235,208,17,172,228,0,0,192,204,22,186,121,133,159,74,248,107,146,67,138,109,210,221,9,250,120,97,129,235,54,228,79,82,206,17,159,83,0,32,175,11,167,112,195,203,255,52,179,213,113,65,144,2,212,198,3,1,105,127,170,221,42,245,240,54,245,67,149,234,109,134,100,132,38,42,23,182,6,62,164,136,124,62,195,45,223,62,165,248,36,63,91,235,83,63,195,73,130,63,226,117,153,63,72,136,176,63,195,244,199,63,0,83,222,63,123,105,248,63,21,114,8,64,231,55,22,64,154,96,33,64,149,241,45,64,93,54,54,64,45,36,152,62,234,148,231,62,19,244,67,63,58,65,145,63,109,231,181,63,153,12,227,63,167,37,3,64,250,14,24,64,59,114,37,64,246,37,155,61,7,7,8,0,0,0,0,0,152,236,33,0,108,0,0,0,168,250,14,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,0,192,0,179,0,166,0,153,0,140,0,128,0,115,0,102,0,89,0,76,0,64,0,51,0,38,0,25,0,12,0,0,0,244,255,231,255,218,255,205,255,192,255,180,255,167,255,154,255,141,255,128,255,116,255,103,255,90,255,77,255,64,255,1,3,4,6,0,0,0,0,0,0,0,0,11,0,0,0,12,0,0,0,15,0,0,0,1,0,0,0,0,0,0,0,8,7,6,5,4,3,2,1,7,7,0,0,0,0,0,1,6,0,6,0,0,0,2,0,5,0,0,5,0,3,0,0,4,0,0,0,4,0,0,0,3,0,0,5,0,3,0,0,2,0,6,0,0,0,2,0,1,7,0,0,0,0,0,1,0,1,0,0,2,4,2,0,0,1,0,0,15,0,0,0,0,1,1,1,1,1,1,1,17,18,18,18,18,18,18,18,4,5,204,204,204,204,204,65,21,22,204,204,204,204,204,82,4,204,5,204,204,204,65,204,21,204,22,204,204,204,82,204,4,204,204,5,204,65,204,204,21,204,204,22,204,82,204,204,4,204,204,204,65,204,204,204,21,204,204,204,22,204,204,204,4,204,204,65,204,5,204,204,21,204,204,82,204,22,204,204,4,204,65,204,204,204,5,204,21,204,82,204,204,204,22,204,4,65,204,204,204,204,204,5,21,82,204,204,204,204,204,22,68,69,69,69,69,69,69,69,85,86,86,86,86,86,86,86,72,73,204,204,204,204,204,133,89,90,204,204,204,204,204,150,72,204,73,204,204,204,133,204,89,204,90,204,204,204,150,204,72,204,204,73,204,133,204,204,89,204,204,90,204,150,204,204,72,204,204,204,73,204,204,204,89,204,204,204,150,204,204,204,72,204,204,133,204,73,204,204,89,204,204,150,204,90,204,204,72,204,133,204,204,204,73,204,89,204,150,204,204,204,90,204,72,133,204,204,204,204,204,73,89,150,204,204,204,204,204,90,0,241,0,0,8,240,0,0,8,192,0,0,8,48,0,0,1,0,0,0,6,0,0,0,21,0,0,0,43,0,0,0,64,0,0,0,0,0,0,0,111,15,9,0,170,44,2,0,111,15,9,0,170,44,2,0,171,170,42,63,0,0,0,0,255,255,255,127,0,0,0,0,174,0,0,0,6,0,0,0,40,1,0,0,56,1,0,0,120,99,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,227,131,35,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,84,0,0,1,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,255,255,255,255,186,84,0,0,1,0,0,0,0,0,0,0,16,0,0,0,255,255,255,255,255,255,255,255,176,0,0,0,1,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,186,0,0,0,1,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,36,181,46,0,5,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,184,83,0,0,1,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,192,83,0,0,1,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,170,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,221,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,179,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,229,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,227,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,208,98,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,98,0,0,6,0,0,0,64,0,0,0,0,1,0,0,64,98,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,225,71,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,71,0,0,5,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,231,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,229,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,227,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,66,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,66,0,0,5,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,80,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,51,80,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,52,80,0,0,6,0,0,0,0,0,0,0,16,0,0,0,248,97,10,0,0,0,0,0,53,80,0,0,6,0,0,0,0,0,0,0,40,0,0,0,56,97,10,0,0,0,0,0,49,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,0,0,0,6,0,0,0,16,0,0,0,0,0,0,0,144,96,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,181,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,191,64,181,120,0,0,2,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,100,98,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,159,0,0,0,1,0,0,0,0,0,0,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,215,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,83,0,0,4,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,197,115,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,131,0,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,134,0,0,0,3,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,162,99,0,0,5,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,156,181,34,0,4,0,0,0,0,0,0,0,48,0,0,0,96,149,32,0,0,0,0,0,131,227,35,0,1,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,79,49,35,0,2,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,240,63,136,0,0,0,1,0,0,0,0,0,0,0,72,0,0,0,1,0,0,0,0,0,0,0,170,85,0,0,1,0,0,0,0,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,6,0,0,0,0,0,0,0,104,0,0,0,16,95,10,0,0,0,0,0,225,0,0,0,6,0,0,0,0,0,0,0,176,0,0,0,0,99,10,0,0,0,0,0,226,0,0,0,6,0,0,0,0,0,0,0,248,0,0,0,216,96,10,0,0,0,0,0,128,109,0,0,6,0,0,0,0,0,0,0,0,0,0,0,8,97,10,0,0,0,0,0,238,85,0,0,1,0,0,0,0,0,0,0,32,1,0,0,0,0,0,0,0,0,0,0,170,86,0,0,1,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,187,86,0,0,1,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,185,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,134,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,178,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,99,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,104,0,0,1,0,0,0,0,0,0,0,8,0,0,0,50,0,0,0,0,0,0,0,197,99,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,196,99,0,0,1,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,198,99,0,0,1,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,115,0,0,6,0,0,0,48,0,0,0,88,1,0,0,192,102,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,103,0,0,6,0,0,0,32,0,0,0,40,0,0,0,8,103,10,0,0,0,0,0,192,99,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,102,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,69,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,68,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,122,68,0,0,3,0,0,0,0,0,0,0,8,0,0,0,112,172,32,0,0,0,0,0,132,68,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,180,68,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,200,103,0,0,6,0,0,0,32,0,0,0,24,0,0,0,8,103,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,128,83,24,6,0,0,0,0,0,0,0,0,0,0,0,224,103,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,169,73,21,6,0,0,0,0,0,0,0,0,0,0,0,64,105,10,0,0,0,0,0,107,174,84,22,6,0,0,0,0,0,0,0,0,0,0,0,224,94,10,0,0,0,0,0,105,164,65,25,6,0,0,0,0,0,0,0,0,0,0,0,184,113,10,0,0,0,0,0,112,167,67,16,6,0,0,0,0,0,0,0,0,0,0,0,136,110,10,0,0,0,0,0,107,187,83,28,6,0,0,0,0,0,0,0,0,0,0,0,216,106,10,0,0,0,0,0,103,195,84,18,6,0,0,0,0,0,0,0,0,0,0,0,144,102,10,0,0,0,0,0,116,155,77,17,6,0,0,0,0,0,0,0,0,0,0,0,0,105,10,0,0,0,0,0,117,182,67,31,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,83,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,83,0,0,1,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,77,0,0,6,0,0,0,16,0,0,0,96,1,0,0,184,104,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,25,0,0,48,33,0,0,136,19,0,0,128,62,0,0,177,215,42,0,1,0,0,0,0,0,0,0,16,1,0,0,64,66,15,0,0,0,0,0,137,68,0,0,2,0,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,169,123,0,0,4,0,0,0,0,0,0,0,32,1,0,0,0,0,0,0,0,0,0,0,65,87,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,77,0,0,4,0,0,0,0,0,0,0,36,1,0,0,0,0,0,0,0,0,0,0,97,68,0,0,5,0,0,0,0,0,0,0,40,1,0,0,0,0,0,0,0,0,0,0,164,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,241,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,179,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,183,0,0,0,6,0,0,0,16,0,0,0,8,0,0,0,0,106,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,0,0,0,6,0,0,0,16,0,0,0,80,1,0,0,144,106,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,208,29,0,48,200,29,0,117,182,67,31,6,0,0,0,0,0,0,0,0,0,0,0,56,109,10,0,0,0,0,0,102,169,73,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,187,83,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,195,84,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,155,77,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,182,67,31,6,0,0,0,0,0,0,0,0,0,0,0,200,109,10,0,0,0,0,0,102,169,73,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,187,83,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,195,84,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,155,77,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,0,0,0,6,0,0,0,72,0,0,0,8,0,0,0,176,112,10,0,0,0,0,0,163,0,0,0,7,0,0,0,72,0,0,0,8,0,0,0,176,112,10,0,0,0,0,0,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,169,73,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,187,83,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,195,84,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,155,77,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,182,67,31,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,0,0,0,6,0,0,0,72,0,0,0,8,0,0,0,176,112,10,0,0,0,0,0,163,0,0,0,7,0,0,0,72,0,0,0,8,0,0,0,176,112,10,0,0,0,0,0,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,97,29,0,108,0,0,0,176,80,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,185,69,0,0,6,0,0,0,0,0,0,0,0,0,0,0,216,111,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,146,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,128,196,115,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,144,111,10,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,195,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,4,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,124,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,6,0,0,0,32,0,0,0,72,1,0,0,184,110,10,0,0,0,0,0,188,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,189,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,219,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,221,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,0,0,0,1,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,165,0,0,0,5,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,0,0,0,5,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,161,117,0,0,6,0,0,0,0,0,0,0,0,0,0,0,136,113,10,0,0,0,0,0,163,0,0,0,5,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,155,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,117,0,0,9,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,251,0,0,0,9,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,166,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,104,112,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,167,97,0,0,6,0,0,0,40,0,0,0,64,1,0,0,232,113,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,70,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,70,0,0,4,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,96,70,0,0,3,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,92,70,0,0,5,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,126,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,26,30,0,144,2,30,0,16,234,29,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,1,0,2,0,16,0,32,0,4,0,8,0,64,0,128,0,0,1,0,2,0,16,0,32,0,4,0,8,0,64,0,128,255,0,0,0,85,0,0,0,17,0,0,0,1,0,0,0,0,0,1,0,3,0,7,0,15,0,31,0,63,0,127,0,255,0,255,1,255,3,255,7,255,15,255,31,255,63,255,127,255,255,0,0,0,0,0,0,4,0,0,0,1,0,0,0,2,0,0,0,0,2,0,0,0,4,0,0,8,0,0,0,0,1,0,0,16,0,0,0,32,0,0,0,0,2,0,0,0,4,0,0,64,0,0,0,128,0,0,0,0,16,0,0,0,32,0,0,0,64,0,0,8,0,0,0,64,0,0,0,128,0,0,0,0,8,0,0,0,16,0,0,0,64,0,0,0,0,1,0,0,128,0,0,0,0,2,0,0,1,0,0,16,0,0,0,32,0,0,0,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,62,255,255,255,63,52,53,54,55,56,57,58,59,60,61,255,255,255,254,255,255,255,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,255,255,255,255,255,255,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,1,0,255,1,0,255,0,1,1,1,255,255,1,255,255,0,0,0,0,0,0,0,1,254,255,0,0,0,0,224,181,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,9,0,0,102,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,250,32,0,192,229,31,0,4,0,0,0,69,90,73,83,208,23,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,106,30,0,192,229,31,0,4,0,0,0,69,90,73,83,208,23,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,48,226,29,0,64,117,29,0,12,0,0,0,84,65,82,86,224,30,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,32,205,28,0,64,117,29,0,12,0,0,0,84,65,82,86,224,30,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,56,202,35,0,176,117,35,0,32,0,0,0,1,0,0,0,21,28,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,168,27,35,0,56,215,34,0,40,0,0,0,3,0,0,0,190,60,214,67,238,203,231,191,0,0,0,0,0,0,89,192,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,184,155,34,0,240,94,34,0,48,0,0,0,3,0,0,0,174,233,169,213,171,223,192,191,0,0,0,0,0,0,89,192,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,184,39,34,0,192,247,33,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,216,206,33,0,88,167,33,0,64,0,0,0,3,0,0,0,51,51,51,51,51,51,211,63,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,232,137,33,0,120,96,33,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,121,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,160,34,33,0,184,255,32,0,80,0,0,0,3,0,0,0,0,0,0,0,0,0,36,64,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,136,229,32,0,64,202,32,0,120,0,0,0,3,0,0,0,123,20,174,71,225,122,132,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,96,176,32,0,96,154,32,0,128,0,0,0,3,0,0,0,141,40,237,13,190,48,137,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,224,129,32,0,104,103,32,0,136,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,248,82,32,0,192,50,32,0,88,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,248,82,32,0,216,255,31,0,216,233,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,248,82,32,0,88,214,31,0,160,195,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,248,82,32,0,0,173,31,0,160,155,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,248,82,32,0,32,138,31,0,32,121,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,248,82,32,0,192,106,31,0,72,79,31,0,92,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,192,106,31,0,160,40,31,0,88,26,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,106,31,0,16,14,31,0,144,254,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,106,31,0,8,238,30,0,240,224,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,106,31,0,24,212,30,0,184,196,30,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,106,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,170,31,0,108,0,0,0,8,117,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,0,0,0,197,0,0,0,199,0,0,0,201,0,0,0,209,0,0,0,214,0,0,0,220,0,0,0,225,0,0,0,224,0,0,0,226,0,0,0,228,0,0,0,227,0,0,0,229,0,0,0,231,0,0,0,233,0,0,0,232,0,0,0,234,0,0,0,235,0,0,0,237,0,0,0,236,0,0,0,238,0,0,0,239,0,0,0,241,0,0,0,243,0,0,0,242,0,0,0,244,0,0,0,246,0,0,0,245,0,0,0,250,0,0,0,249,0,0,0,251,0,0,0,252,0,0,0,32,32,0,0,176,0,0,0,162,0,0,0,163,0,0,0,167,0,0,0,34,32,0,0,182,0,0,0,223,0,0,0,174,0,0,0,169,0,0,0,34,33,0,0,180,0,0,0,168,0,0,0,96,34,0,0,198,0,0,0,216,0,0,0,30,34,0,0,177,0,0,0,100,34,0,0,101,34,0,0,165,0,0,0,181,0,0,0,2,34,0,0,17,34,0,0,15,34,0,0,192,3,0,0,43,34,0,0,170,0,0,0,186,0,0,0,169,3,0,0,230,0,0,0,248,0,0,0,191,0,0,0,161,0,0,0,172,0,0,0,26,34,0,0,146,1,0,0,72,34,0,0,6,34,0,0,171,0,0,0,187,0,0,0,38,32,0,0,160,0,0,0,192,0,0,0,195,0,0,0,213,0,0,0,82,1,0,0,83,1,0,0,19,32,0,0,20,32,0,0,28,32,0,0,29,32,0,0,24,32,0,0,25,32,0,0,247,0,0,0,202,37,0,0,255,0,0,0,120,1,0,0,68,32,0,0,172,32,0,0,57,32,0,0,58,32,0,0,1,251,0,0,2,251,0,0,33,32,0,0,183,0,0,0,26,32,0,0,30,32,0,0,48,32,0,0,194,0,0,0,202,0,0,0,193,0,0,0,203,0,0,0,200,0,0,0,205,0,0,0,206,0,0,0,207,0,0,0,204,0,0,0,211,0,0,0,212,0,0,0,255,248,0,0,210,0,0,0,218,0,0,0,219,0,0,0,217,0,0,0,49,1,0,0,198,2,0,0,220,2,0,0,175,0,0,0,216,2,0,0,217,2,0,0,218,2,0,0,184,0,0,0,221,2,0,0,219,2,0,0,199,2,0,0,195,21,143,18,225,10,20,6,240,176,32,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,255,1,0,2,2,0,1,2,255,2,2,1,254,1,2,2,254,2,0,3,3,0,1,3,255,3,3,1,253,1,2,3,254,3,3,2,253,2,0,4,4,0,1,4,255,4,4,1,252,1,3,3,253,3,2,4,254,4,4,2,252,2,0,5,3,4,253,4,4,3,252,3,5,0,1,5,255,5,5,1,251,1,2,5,254,5,5,2,251,2,4,4,252,4,3,5,253,5,5,3,251,3,0,6,6,0,1,6,255,6,6,1,250,1,2,6,254,6,6,2,250,2,4,5,252,5,5,4,251,4,3,6,253,6,6,3,250,3,0,7,7,0,1,7,255,7,5,5,251,5,7,1,249,1,4,6,252,6,6,4,250,4,2,7,254,7,7,2,249,2,3,7,253,7,7,3,249,3,5,6,251,6,6,5,250,5,8,0,4,7,252,7,7,4,249,4,8,1,8,2,6,6,250,6,8,3,5,7,251,7,7,5,249,5,8,4,6,7,250,7,7,6,249,6,8,5,7,7,249,7,8,6,8,7,8,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,25,0,0,0,4,0,0,0,25,0,0,0,5,0,0,0,25,0,0,0,6,0,0,0,14,0,0,0,7,0,0,0,14,0,0,0,8,0,0,0,2,0,0,0,9], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+677216);
/* memory initializer */ allocate([136,22,33,0,108,0,0,0,128,92,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,36,31,0,108,0,0,0,128,92,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,56,155,32,0,108,0,0,0,128,92,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,252,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,161,30,0,176,123,30,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,48,35,29,0,32,212,28,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,200,206,35,0,112,124,35,0,104,32,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,200,206,35,0,80,219,34,0,24,159,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,200,206,35,0,160,98,34,0,16,43,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,200,206,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,252,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,3,0,0,0,0,0,0,0,0,0,0,52,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,143,32,0,108,0,0,0,128,126,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,11,10,16,24,40,51,61,12,12,14,19,26,58,60,55,14,13,16,24,40,57,69,56,14,17,22,29,51,87,80,62,18,22,37,56,68,109,103,77,24,35,55,64,81,104,113,92,49,64,78,87,103,121,120,101,72,92,95,98,112,100,103,99,8,6,5,8,12,20,26,31,6,6,7,10,13,29,30,28,7,7,8,12,20,29,35,28,7,9,11,15,26,44,40,31,9,11,19,28,34,55,52,39,12,18,28,32,41,52,57,46,25,32,39,44,52,61,60,51,36,46,48,49,56,50,52,50,0,16,32,128,48,64,80,96,144,160,176,192,112,208,224,240,252,253,254,255,1,2,3,4,0,8,16,24,32,40,48,56,64,70,76,82,88,92,96,100,217,33,18,63,109,85,50,63,8,33,80,63,56,75,105,63,104,34,124,63,192,176,136,63,176,232,152,63,219,76,175,63,30,26,21,15,8,0,248,241,235,230,0,0,0,0,0,0,48,117,144,101,8,82,152,58,64,31,0,0,192,224,104,197,248,173,112,154,0,0,0,0,0,0,0,0,0,0,0,0,89,2,0,2,226,253,78,1,172,1,63,4,28,254,124,255,140,2,110,2,121,254,196,253,122,1,31,3,141,0,164,252,16,4,153,1,112,0,214,253,99,4,158,2,181,255,177,252,141,5,238,1,197,254,185,251,19,3,233,3,114,0,52,254,220,3,136,6,216,0,87,253,239,3,217,4,124,255,33,251,49,4,143,1,186,0,251,255,238,4,193,0,74,253,127,255,69,1,196,0,51,0,127,253,93,3,197,255,94,1,54,254,237,4,55,2,74,2,166,254,252,5,117,3,210,0,251,253,235,7,169,3,113,0,232,252,103,5,40,4,78,1,38,0,172,7,188,5,203,1,133,0,14,8,162,4,158,255,135,255,17,10,165,5,250,1,139,254,6,9,146,6,254,255,64,252,60,11,147,7,253,2,138,0,253,13,56,9,137,2,98,254,219,0,176,0,114,254,203,254,178,1,178,255,77,254,144,252,168,254,45,1,9,1,216,253,109,252,214,1,145,2,132,254,163,1,80,254,93,255,59,254,95,1,71,252,8,0,206,253,21,3,213,255,20,0,66,252,46,1,174,253,160,254,121,251,16,4,108,0,100,253,100,252,53,5,210,0,63,251,129,249,227,1,77,2,162,254,140,251,235,3,56,3,222,252,96,251,233,2,58,0,179,253,93,250,90,1,247,0,109,252,109,249,14,1,28,3,48,253,5,248,184,4,210,2,34,255,63,255,206,5,156,4,100,254,96,253,186,6,179,0,187,255,247,253,255,7,92,3,102,253,126,250,110,255,222,0,231,254,219,252,67,255,90,0,142,255,229,250,104,255,62,4,15,255,4,253,73,254,221,2,167,253,234,250,191,252,89,255,161,254,167,253,168,252,90,254,101,254,221,251,21,253,157,254,186,253,148,249,187,252,210,0,108,252,136,251,248,248,32,0,146,252,105,249,208,255,233,255,134,251,52,0,162,254,103,254,136,249,148,254,9,1,40,253,166,252,191,253,202,1,9,255,139,251,27,252,179,2,105,254,60,248,119,251,190,255,152,255,63,253,31,251,81,254,163,255,89,251,204,248,203,0,36,253,24,252,99,249,10,0,192,252,202,248,229,248,237,1,128,255,100,250,24,249,232,1,201,254,62,249,20,246,115,253,236,253,130,251,108,251,194,251,223,254,86,249,3,250,69,253,75,251,64,251,26,249,248,251,55,250,230,247,13,250,47,253,60,251,27,247,216,245,12,0,229,253,52,250,149,251,216,255,113,252,198,247,71,254,41,254,28,254,37,247,243,249,115,255,36,252,66,244,71,249,247,249,202,247,185,253,86,1,153,250,44,245,126,254,243,255,186,247,227,245,75,251,72,0,157,247,97,243,59,252,134,1,123,244,28,243,147,253,125,2,189,240,214,239,159,252,35,3,249,250,179,252,137,254,220,253,120,250,111,251,25,254,3,251,136,250,102,249,253,251,94,254,30,248,139,248,92,251,20,251,118,250,82,247,19,248,128,255,237,247,74,244,123,245,202,254,74,252,252,251,254,249,185,0,176,249,109,252,99,247,219,253,19,0,203,252,135,251,96,1,184,0,105,251,180,250,141,253,221,253,192,251,131,249,113,252,40,255,34,250,107,247,76,252,229,252,230,250,186,246,61,254,100,252,159,248,20,245,88,253,168,253,178,249,231,241,139,252,168,246,32,246,63,1,47,1,164,244,209,247,202,254,61,2,124,242,163,247,49,0,143,255,73,247,64,254,163,2,110,255,11,245,236,253,207,4,223,1,132,245,26,254,56,255,99,2,59,242,53,252,58,255,192,2,133,241,173,0,93,1,254,0,130,237,89,250,222,255,112,3,9,3,0,254,114,0,246,255,226,4,190,255,186,1,251,255,92,2,101,2,196,1,160,254,200,4,9,3,163,2,10,252,164,250,177,255,72,251,18,255,171,246,239,255,123,251,206,252,32,250,95,253,147,251,220,251,64,248,225,252,43,248,75,248,11,248,226,252,212,251,151,255,138,243,125,252,231,248,62,255,100,255,138,252,138,1,194,254,254,254,253,250,39,2,202,0,232,253,63,249,142,3,75,1,177,252,171,251,27,3,93,255,109,251,152,251,203,2,7,2,200,251,217,250,149,6,156,2,24,252,127,248,96,0,211,0,49,250,156,247,63,3,174,0,141,251,138,254,158,1,252,255,19,250,153,250,140,1,160,254,12,252,183,1,197,255,57,252,236,248,194,2,72,254,250,251,77,248,183,254,222,255,197,252,88,246,204,249,105,255,162,253,143,247,118,1,231,254,76,0,60,244,231,0,241,255,78,253,80,4,54,2,209,2,209,0,149,6,52,2,127,1,98,0,106,7,238,2,24,3,159,255,44,2,192,255,49,2,163,255,108,3,162,0,145,3,234,255,193,3,163,2,16,5,140,0,244,2,116,254,83,3,32,2,104,1,209,254,61,5,140,1,110,3,234,255,184,5,95,3,203,254,239,254,130,2,127,255,82,253,174,255,74,3,198,1,251,255,209,255,45,4,230,3,162,255,199,3,253,4,42,1,23,254,129,1,193,5,234,2,143,254,51,253,53,5,242,0,25,1,31,252,190,6,156,3,208,1,89,2,39,6,96,5,6,255,206,0,35,9,151,4,74,254,121,1,171,253,227,254,4,252,19,3,234,252,225,254,54,254,102,254,215,0,39,1,179,253,164,252,135,255,29,3,105,251,122,0,75,254,210,1,56,250,135,255,111,1,156,3,234,0,67,1,2,3,213,253,145,0,30,0,228,3,26,0,66,0,81,3,93,0,111,255,139,255,237,4,218,1,113,254,41,250,27,4,218,0,6,254,146,250,182,2,226,3,88,0,104,2,7,0,78,0,48,1,36,4,52,0,194,255,67,3,65,3,198,1,137,2,79,5,254,252,208,1,47,0,93,0,194,253,175,4,217,255,123,1,114,0,158,255,232,1,229,1,215,2,244,0,94,2,184,2,180,255,199,1,159,2,34,2,203,253,243,255,145,0,51,3,136,254,57,2,192,1,104,4,218,0,122,0,9,1,143,4,230,0,226,2,164,3,235,3,138,0,221,1,36,0,194,1,148,1,19,3,183,255,232,3,241,1,235,4,131,1,207,4,17,0,207,0,195,0,177,255,50,2,102,1,53,0,98,255,237,1,131,1,222,1,189,0,166,2,63,3,128,2,46,2,59,255,11,2,101,2,57,0,173,1,126,3,1,3,111,0,67,0,150,4,56,2,255,1,218,4,56,3,251,0,72,3,139,5,50,4,96,3,225,1,156,3,194,5,157,2,212,2,3,6,87,7,142,2,54,6,189,1,81,1,87,4,29,2,216,1,141,5,240,4,70,4,26,3,223,2,79,4,156,2,31,4,95,3,168,4,252,3,10,3,81,4,38,3,6,7,28,4,247,5,51,6,103,8,113,3,16,6,241,4,135,1,214,2,104,3,20,7,89,2,189,5,24,1,240,3,104,2,123,5,65,2,11,7,220,4,114,6,34,5,124,4,48,4,17,5,133,6,119,7,2,4,45,8,20,4,67,8,165,4,108,6,169,7,27,10,232,5,25,0,197,254,247,255,150,255,34,1,173,254,172,1,68,254,188,255,241,252,223,2,4,3,245,0,213,253,212,1,47,0,78,1,129,252,46,3,146,0,235,0,112,1,60,252,65,252,53,255,59,1,226,249,63,251,33,3,17,0,236,254,158,254,126,3,17,254,235,252,133,253,204,2,35,1,91,251,155,254,48,2,252,254,35,253,254,255,167,2,4,254,107,250,211,0,205,255,194,255,84,254,45,2,66,1,130,253,45,255,102,2,146,252,223,251,172,255,185,255,124,254,121,250,89,255,194,254,14,253,218,249,214,0,229,253,117,250,44,248,164,255,237,252,209,255,168,252,165,254,1,255,23,0,69,251,83,255,64,1,110,253,25,254,131,252,97,1,241,252,205,249,184,253,251,1,116,250,165,252,134,254,185,1,209,247,45,250,119,255,183,1,191,254,86,250,248,250,244,255,153,254,191,247,215,253,248,255,193,252,130,248,231,249,32,0,10,252,73,246,177,250,85,252,37,254,201,254,87,255,20,255,117,252,86,254,20,1,157,253,160,255,112,254,50,0,58,253,86,254,2,252,246,255,39,252,59,255,254,254,24,253,193,253,157,253,94,252,253,252,118,254,245,254,248,252,156,253,85,252,0,255,190,250,222,252,158,251,228,252,222,249,199,252,14,253,200,2,108,3,141,0,227,0,213,3,229,5,85,0,124,0,182,5,204,4,211,3,217,255,198,6,231,3,201,5,184,1,245,8,92,4,1,3,184,1,200,9,200,5,217,4,100,1,170,9,117,7,22,6,42,3,149,3,110,4,95,2,122,255,253,1,17,7,13,3,133,255,176,6,226,5,47,2,89,254,245,7,13,9,214,2,101,255,215,11,116,10,179,4,75,1,80,14,202,12,232,6,19,2,74,6,47,7,99,3,183,0,238,6,180,7,2,6,97,0,30,7,110,8,2,5,147,2,174,8,198,10,26,7,132,3,179,12,76,8,187,6,228,3,49,14,32,9,104,9,173,5,107,11,189,13,7,10,38,5,0,0,0,0,0,0,190,247,234,250,76,0,164,245,2,251,168,250,225,244,196,252,163,254,28,241,114,247,163,254,150,240,148,254,63,254,91,245,116,238,233,241,89,242,100,237,48,249,205,255,12,253,84,0,103,255,89,251,248,1,108,0,118,250,143,4,189,252,128,252,134,1,199,253,90,249,87,0,129,251,230,248,165,3,222,248,13,246,155,1,206,248,230,248,171,5,122,246,181,249,13,3,69,245,83,246,31,5,84,252,228,4,221,1,163,249,152,6,90,2,78,251,105,2,24,1,55,249,137,1,68,2,8,250,53,4,175,4,139,247,95,255,128,5,56,246,193,251,67,9,126,242,81,255,115,5,139,250,158,255,181,252,52,247,79,255,131,251,47,250,42,253,253,250,234,249,247,254,48,249,181,248,203,252,151,248,242,247,20,250,220,246,221,245,138,251,211,244,170,0,46,0,205,252,63,255,52,255,129,251,70,1,60,255,4,250,12,3,73,1,208,252,201,0,113,1,37,251,138,2,47,255,220,251,120,4,241,255,64,251,179,4,253,254,181,248,134,252,204,253,106,250,130,253,172,252,127,248,177,0,29,253,178,250,251,254,242,253,126,249,206,0,105,254,49,247,82,1,242,253,202,252,165,1,185,251,15,252,253,2,161,253,128,250,57,3,241,250,44,248,101,1,119,252,233,248,198,255,32,251,204,249,172,253,100,250,2,248,183,255,121,251,188,247,141,255,154,250,235,245,96,255,69,249,96,248,250,255,108,247,118,244,119,253,87,249,213,245,151,253,83,250,46,243,75,252,29,248,226,243,212,252,8,6,145,7,194,248,62,2,208,7,73,250,116,4,89,10,133,245,212,6,172,5,74,246,193,8,219,9,15,3,118,7,155,5,69,2,122,10,96,5,236,0,149,8,93,7,59,254,127,11,9,8,86,253,130,8,5,10,194,250,129,12,0,13,224,254,72,255,6,1,121,0,107,255,73,255,246,2,100,254,206,0,14,4,52,255,85,3,41,6,55,254,188,2,169,3,128,253,201,253,228,5,240,253,0,252,31,255,241,253,85,254,204,253,185,251,180,254,26,253,159,254,70,255,248,250,53,254,84,0,195,248,28,254,238,254,238,249,37,253,57,3,135,246,22,255,126,1,70,249,37,1,241,254,45,246,169,1,204,253,217,245,50,3,208,1,154,254,118,0,137,254,155,253,198,0,150,252,78,253,171,2,188,254,184,250,131,4,88,255,187,251,129,0,188,254,96,251,99,2,166,252,177,1,130,1,140,254,136,255,230,1,134,253,234,0,83,3,137,253,90,2,128,0,46,0,75,4,154,1,159,0,203,2,111,255,88,254,174,4,171,255,175,253,110,5,111,1,154,254,147,6,106,1,60,252,175,6,110,2,45,0,241,7,65,3,129,254,74,11,37,2,6,254,7,0,145,1,52,0,72,0,43,3,159,1,54,2,156,2,41,0,211,1,194,4,130,0,68,0,189,3,69,255,231,255,113,6,153,255,107,253,4,1,214,0,99,252,162,255,100,2,191,254,90,254,197,3,236,252,96,253,247,6,144,1,95,253,11,3,229,2,173,253,99,6,95,255,51,1,145,2,130,254,68,3,103,3,210,252,144,1,199,4,108,1,94,2,223,4,57,0,75,0,35,6,151,0,215,1,239,8,175,255,253,3,222,5,227,0,190,5,73,4,146,2,251,4,117,6,152,2,198,5,73,9,7,1,129,255,188,1,8,1,89,0,201,3,26,3,171,0,64,2,53,3,186,0,202,4,148,1,206,1,5,2,83,1,150,3,26,3,0,5,143,5,196,0,173,5,227,7,109,1,79,6,201,5,160,2,90,9,172,6,252,1,38,3,214,4,61,2,201,2,134,4,54,4,5,5,156,5,208,4,254,6,164,4,117,4,253,2,131,2,96,3,8,4,29,3,255,4,132,3,51,2,35,7,234,5,161,2,8,9,8,6,105,4,168,12,189,5,26,4,58,6,153,7,38,5,196,7,93,9,234,7,12,8,210,13,9,8,60,10,225,4,138,255,74,0,191,6,194,0,165,1,30,8,206,255,49,254,202,3,176,2,80,254,125,4,184,3,146,255,230,4,251,4,117,253,106,5,161,3,145,1,168,7,143,4,232,0,151,1,16,253,13,255,91,3,162,251,172,0,29,255,164,252,32,252,228,252,105,251,156,250,8,0,254,250,124,254,97,1,11,249,243,251,36,253,115,254,217,252,171,252,228,255,194,250,51,251,73,251,89,248,9,252,155,251,17,246,84,250,1,249,91,245,157,248,144,246,59,243,106,252,163,249,241,252,188,253,149,247,70,253,183,251,196,246,160,255,149,250,23,250,7,0,204,249,228,247,104,253,63,250,76,245,240,252,182,246,179,243,200,255,216,244,212,247,87,255,193,242,132,241,60,1,104,251,134,252,154,253,104,248,219,251,224,252,213,254,19,250,24,252,128,253,198,248,10,250,82,250,0,250,47,251,158,248,93,248,36,249,194,251,127,248,182,247,18,253,235,246,44,247,211,250,147,246,143,245,166,251,18,246,125,242,195,250,171,244,133,240,120,251,78,247,143,250,23,252,44,245,219,249,198,249,175,245,70,248,2,250,26,244,192,245,80,247,108,247,93,253,9,245,18,244,178,251,40,248,232,244,94,251,68,248,252,242,97,249,77,249,22,242,7,254,33,246,96,240,161,248,227,246,82,245,8,247,144,242,159,246,117,243,40,248,56,242,247,242,57,247,37,243,98,238,37,254,181,3,155,0,107,255,85,5,33,2,11,253,108,6,59,4,39,255,5,8,73,5,103,250,253,8,182,5,239,1,125,6,17,2,10,0,245,7,228,2,34,8,106,7,210,3,15,11,246,8,143,3,74,3,25,3,164,1,199,4,255,3,95,3,213,4,195,1,12,3,208,6,196,2,54,3,253,5,28,1,104,5,87,8,97,2,2,6,1,9,114,2,28,2,64,9,163,4,187,3,26,10,231,4,249,255,44,12,107,4,214,2,103,13,194,6,172,1,174,10,112,6,27,5,172,11,207,4,218,7,195,13,232,7,208,5,10,4,121,6,103,3,182,4,115,8,12,4,15,7,68,9,209,4,16,7,233,6,213,5,37,6,28,9,243,6,192,4,73,6,74,7,200,5,106,7,209,9,209,1,148,10,216,10,3,3,54,14,10,13,77,7,39,10,63,10,9,11,185,10,164,9,78,10,135,9,49,6,46,8,154,11,28,5,230,7,241,11,207,7,100,13,96,11,24,7,184,17,158,11,81,8,22,4,3,10,38,8,83,5,234,13,14,9,207,9,99,7,168,11,74,7,2,9,146,15,200,12,108,11,98,14,74,12,236,13,224,8,8,14,128,15,6,11,127,9,41,13,253,11,139,7,101,18,18,12,69,10,124,16,146,15,31,18,216,15,80,14,195,15,214,20,48,19,0,0,0,0,0,0,242,254,164,250,248,251,227,253,142,249,154,250,45,253,37,248,91,247,83,252,158,251,106,248,244,252,135,251,106,246,140,252,227,250,163,250,229,251,13,250,26,249,197,251,170,249,4,247,247,252,159,250,157,247,89,252,69,250,53,245,222,252,209,250,113,242,89,252,89,248,97,240,16,255,167,255,222,0,107,253,255,254,96,255,30,252,46,254,93,254,68,255,92,255,234,254,170,254,0,254,97,254,161,253,1,254,227,252,16,0,19,0,52,253,118,1,169,1,52,252,166,254,245,0,230,254,247,254,250,1,14,253,148,253,109,255,163,7,26,253,164,252,37,10,106,255,160,254,144,10,49,1,112,3,162,7,123,0,219,2,206,10,164,254,253,2,255,12,106,2,221,0,186,12,78,255,209,255,123,16,137,1,24,5,2,15,186,2,166,6,193,18,63,0,184,253,205,4,41,255,36,253,168,6,172,0,177,254,117,7,254,255,216,0,5,7,97,1,127,0,157,8,72,251,188,0,11,0,255,253,181,255,85,253,51,252,222,0,122,253,152,253,181,252,124,254,74,252,167,251,153,254,105,250,145,253,63,253,138,250,217,251,78,255,211,255,51,254,35,0,247,255,111,253,40,255,127,0,202,251,95,0,74,252,124,251,72,2,56,250,42,250,193,1,136,255,63,253,4,2,144,254,63,252,215,2,134,254,242,253,205,3,231,252,154,253,164,2,223,252,13,253,7,5,60,250,172,254,100,6,7,254,26,251,7,6,37,251,170,249,252,5,248,252,59,250,113,253,129,251,240,250,201,252,127,251,120,249,156,251,245,250,45,248,90,249,146,253,253,250,57,0,41,254,181,249,253,1,220,251,222,249,117,255,151,252,148,247,232,253,76,249,27,248,148,254,154,247,110,243,245,250,32,251,103,248,168,244,65,251,183,245,217,244,167,0,12,255,84,0,93,1,100,254,39,255,216,255,160,254,120,2,227,0,239,253,149,1,68,0,129,254,69,254,167,0,210,253,62,253,237,254,170,252,242,255,161,254,191,251,63,254,85,1,184,255,223,254,91,2,150,255,38,254,66,1,37,255,119,253,179,0,195,254,26,252,194,1,221,254,28,252,43,2,195,0,243,253,16,3,16,1,193,252,108,255,128,254,175,252,82,0,232,253,179,250,238,0,84,255,182,250,166,1,244,254,207,248,41,1,31,253,225,247,145,255,223,252,170,253,1,0,100,253,40,252,125,255,206,252,237,250,183,254,247,253,226,250,105,255,246,252,214,248,163,255,160,254,46,249,200,253,128,253,227,248,3,254,83,252,121,247,208,1,209,252,30,251,79,0,147,251,195,249,72,255,183,250,181,247,60,255,102,254,133,246,64,255,191,252,6,245,253,254,154,250,27,244,39,255,4,0,114,251,224,252,187,254,61,251,149,254,194,252,126,252,107,253,146,251,64,252,126,254,44,252,35,250,141,253,121,251,70,249,121,252,195,252,169,252,83,253,195,252,223,250,215,251,65,252,131,250,185,1,25,0,177,252,143,2,229,255,99,251,135,4,146,255,63,253,88,3,253,0,121,249,159,1,148,1,255,255,66,1,135,3,114,254,158,2,243,1,220,254,35,3,79,2,158,253,120,4,79,2,210,252,205,2,183,0,137,1,89,3,125,1,106,0,97,2,62,0,229,255,24,3,198,0,187,254,223,2,37,3,88,0,118,4,44,3,78,0,4,4,110,1,220,254,29,5,231,2,19,255,79,6,77,2,177,255,242,3,127,2,13,255,231,3,196,3,201,254,220,5,113,4,153,253,220,3,101,1,134,2,203,4,155,2,171,2,140,4,29,6,126,3,112,5,223,7,221,1,114,4,21,2,250,0,157,5,128,3,135,1,229,6,94,4,99,0,88,4,66,4,34,3,60,6,78,3,110,4,169,3,137,4,23,1,183,6,230,4,171,2,58,5,62,4,35,0,139,5,44,5,172,1,148,5,244,5,40,0,60,8,58,6,89,0,247,3,32,2,198,4,97,4,157,3,239,4,6,4,38,5,205,5,15,5,21,3,25,7,43,5,248,4,117,7,188,6,213,4,11,7,5,7,153,6,90,3,101,8,87,5,21,5,254,8,75,7,249,2,47,11,47,9,29,4,52,0,163,0,180,255,230,0,53,1,20,254,185,255,107,2,39,0,38,255,88,3,243,1,114,253,224,2,49,255,233,253,235,4,155,0,32,254,196,5,131,2,6,1,57,4,102,0,53,1,56,6,74,255,115,2,93,6,22,2,81,1,131,2,200,1,246,2,158,2,201,2,202,0,102,4,146,2,100,2,107,4,154,2,174,2,199,4,112,4,125,255,121,1,13,2,42,0,196,2,139,3,87,0,208,5,11,4,176,1,69,8,136,3,137,0,213,3,52,5,65,254,246,3,112,4,185,252,1,7,222,4,209,253,41,1,198,0,174,252,173,2,190,1,7,251,120,2,58,3,111,254,224,253,173,0,15,253,231,252,144,0,76,254,247,255,4,3,141,255,13,255,30,5,98,253,243,254,118,1,253,251,243,255,127,2,137,252,175,255,113,4,3,251,57,254,158,0,125,250,48,253,224,2,172,0,88,0,147,1,130,1,255,0,244,2,12,254,10,2,142,3,66,252,147,2,108,5,117,254,45,1,64,5,156,254,0,3,21,7,155,253,73,3,115,9,189,1,134,255,252,0,117,2,169,255,211,2,27,1,3,255,102,3,200,1,140,255,101,5,245,2,180,0,35,4,20,2,152,1,229,5,179,3,32,1,14,7,45,5,226,3,220,9,124,3,195,4,207,11,117,5,60,6,78,13,119,4,16,6,242,9,58,7,153,5,150,10,246,255,134,0,234,3,154,0,243,1,43,5,252,1,24,3,93,4,253,1,60,5,80,6,250,2,94,3,72,6,19,3,228,2,16,9,26,3,191,6,3,5,209,1,60,8,124,6,136,255,171,5,77,6,126,254,224,7,121,8,123,3,201,4,2,8,200,1,200,5,137,8,213,5,3,5,185,4,117,5,100,6,238,5,240,6,202,6,16,6,36,6,162,6,93,8,109,5,78,8,247,4,167,7,109,9,95,4,85,5,76,11,225,5,158,8,179,7,87,6,28,8,158,7,232,8,181,6,243,8,75,7,62,9,211,9,161,7,49,11,22,11,218,9,231,9,137,13,219,7,53,13,31,16,78,10,68,3,107,10,241,8,225,6,213,10,33,9,135,5,253,12,95,11,50,9,66,12,54,12,99,10,96,16,170,15,24,4,250,6,26,7,218,4,63,8,192,8,232,5,31,8,220,10,37,6,187,9,66,12,182,8,73,9,222,10,160,1,237,6,144,10,213,2,32,9,225,12,228,4,69,9,138,15,46,8,220,8,240,13,219,7,152,10,176,17,61,5,179,13,36,15,192,4,79,15,58,19,157,6,185,18,124,23,104,5,29,8,92,13,244,19,86,26,186,31,135,38,84,43,170,49,133,53,0,0,0,0,168,87,138,62,37,117,2,63,134,201,36,63,56,103,68,63,39,194,118,63,167,232,136,63,154,153,161,63,101,25,202,63,23,217,246,63,79,64,15,64,91,211,32,64,63,53,54,64,14,45,50,62,45,67,188,62,255,178,27,63,11,181,86,63,13,224,141,63,249,160,175,63,0,111,209,63,75,200,239,63,147,24,4,64,95,7,22,64,241,244,38,64,11,181,54,64,82,73,29,62,130,226,167,62,42,169,3,63,36,151,47,63,204,238,121,63,138,31,163,63,119,190,199,63,18,165,237,63,222,113,6,64,123,20,22,64,72,225,38,64,215,163,56,64,225,122,84,62,240,22,232,62,180,89,69,63,91,211,132,63,100,204,165,63,138,176,193,63,61,44,228,63,20,63,2,64,117,147,16,64,114,249,31,64,238,124,43,64,185,252,55,64,169,164,14,62,236,47,123,62,110,52,192,62,200,152,11,63,188,150,80,63,204,127,144,63,224,45,184,63,119,45,225,63,91,66,2,64,117,147,20,64,68,250,37,64,148,246,54,64,0,0,0,62,208,179,185,62,143,228,66,63,252,169,145,63,82,73,181,63,100,59,199,63,117,147,216,63,98,16,232,63,18,20,239,63,153,187,2,64,156,162,27,64,125,174,54,64,176,3,103,62,181,55,216,62,212,43,37,63,104,34,92,63,73,157,136,63,16,233,167,63,134,56,198,63,181,21,235,63,140,219,4,64,204,93,19,64,78,209,33,64,90,100,51,64,250,237,107,62,28,124,225,62,220,104,48,63,120,122,101,63,248,83,147,63,29,201,181,63,127,251,210,63,242,210,237,63,243,142,7,64,36,151,23,64,50,230,38,64,81,107,58,64,29,90,100,62,19,97,195,62,223,79,13,63,236,47,27,63,108,120,74,63,122,165,140,63,139,108,183,63,198,109,228,63,46,144,4,64,243,31,22,64,11,181,38,64,48,187,55,64,163,146,122,62,225,122,20,63,165,44,83,63,104,145,125,63,95,7,150,63,111,18,179,63,230,174,213,63,234,4,244,63,100,93,8,64,100,59,27,64,178,157,43,64,75,89,58,64,58,35,74,62,165,44,195,62,253,135,20,63,98,161,70,63,104,145,109,63,54,205,147,63,66,96,181,63,240,133,209,63,193,202,241,63,138,142,16,64,163,1,36,64,199,186,52,64,107,154,247,61,18,131,128,62,245,219,247,62,95,7,78,63,84,82,143,63,61,155,173,63,2,188,205,63,184,64,242,63,215,163,8,64,74,123,23,64,45,67,40,64,6,129,57,64,69,216,112,62,0,145,222,62,204,127,40,63,87,91,81,63,198,109,116,63,212,43,149,63,242,65,191,63,41,203,240,63,50,230,10,64,131,47,24,64,108,9,41,64,63,198,56,64,79,30,86,62,206,25,209,62,186,73,44,63,254,67,106,63,126,29,144,63,236,192,169,63,93,254,203,63,27,13,232,63,77,132,1,64,147,58,21,64,173,250,36,64,2,43,55,64,105,0,239,61,217,95,118,62,139,108,231,62,44,212,58,63,218,27,124,63,155,85,159,63,236,192,193,63,134,201,228,63,193,202,1,64,248,83,19,64,127,217,37,64,23,72,56,64,236,192,153,62,91,66,254,62,121,233,38,63,94,186,89,63,225,122,148,63,241,244,178,63,211,77,202,63,44,212,234,63,69,216,4,64,81,218,19,64,47,221,36,64,195,100,54,64,127,251,122,62,70,37,213,62,117,147,24,63,217,206,71,63,19,97,115,63,215,52,159,63,123,131,199,63,57,214,237,63,57,180,4,64,154,119,20,64,111,129,36,64,166,155,52,64,155,85,159,62,54,60,13,63,234,4,52,63,26,81,90,63,40,15,147,63,86,125,182,63,135,167,215,63,153,42,248,63,194,23,10,64,199,75,27,64,60,189,42,64,41,237,57,64,48,76,102,62,194,134,199,62,118,79,14,63,14,79,63,63,188,5,130,63,57,214,173,63,204,127,216,63,160,26,255,63,146,203,11,64,27,158,22,64,220,70,35,64,178,157,51,64,184,30,133,62,85,48,234,62,104,34,60,63,240,22,120,63,116,181,149,63,32,65,177,63,135,22,209,63,3,120,243,63,123,131,7,64,69,71,22,64,214,197,37,64,45,178,53,64,139,253,101,62,122,165,172,62,213,120,233,62,217,95,6,63,52,162,52,63,145,126,131,63,156,196,176,63,35,74,219,63,230,174,253,63,62,121,16,64,190,159,34,64,168,87,54,64,60,78,17,62,52,128,247,62,14,45,98,63,49,153,146,63,214,86,164,63,52,17,182,63,36,151,199,63,91,211,228,63,88,57,8,64,74,12,26,64,218,172,38,64,108,120,54,64,92,32,65,62,45,67,188,62,146,203,15,63,155,85,79,63,121,88,144,63,48,42,177,63,140,74,202,63,11,36,232,63,253,246,1,64,182,243,17,64,185,141,34,64,196,66,53,64,14,190,112,62,253,135,212,62,72,225,42,63,132,13,95,63,111,240,133,63,58,35,170,63,1,77,212,63,251,203,246,63,8,172,8,64,53,94,22,64,32,210,39,64,110,52,56,64,113,61,138,62,57,214,229,62,164,223,30,63,48,76,54,63,52,17,70,63,218,27,124,63,137,210,174,63,116,36,223,63,189,227,0,64,238,90,14,64,39,194,30,64,236,81,52,64,127,217,125,62,92,143,226,62,221,36,38,63,59,223,95,63,93,220,142,63,103,68,177,63,196,177,214,63,222,113,250,63,219,138,9,64,144,49,23,64,78,98,36,64,250,237,51,64,78,98,80,62,191,125,189,62,228,131,14,63,200,152,75,63,179,12,129,63,106,77,163,63,63,198,196,63,33,31,228,63,184,30,1,64,122,165,16,64,37,117,30,64,2,188,49,64,237,13,62,62,5,52,177,62,126,140,25,63,25,115,103,63,157,128,158,63,154,8,187,63,109,86,213,63,160,26,247,63,75,89,10,64,233,72,26,64,235,115,41,64,254,101,55,64,190,193,87,62,63,53,190,62,254,101,7,63,254,67,42,63,80,141,87,63,77,243,142,63,50,85,184,63,68,139,220,63,153,187,254,63,97,50,17,64,143,228,34,64,90,100,55,64,71,114,249,61,126,140,153,62,65,130,34,63,60,189,114,63,209,34,163,63,122,54,203,63,232,217,244,63,247,6,15,64,94,186,25,64,52,128,31,64,122,165,40,64,28,124,53,64,175,148,37,62,97,84,178,62,20,63,22,63,9,249,80,63,79,175,132,63,210,0,158,63,197,254,186,63,161,248,217,63,245,74,249,63,241,244,14,64,181,166,33,64,95,7,54,64,137,65,128,62,163,146,250,62,137,65,64,63,140,74,106,63,229,208,138,63,66,207,174,63,243,142,211,63,44,212,234,63,37,6,1,64,139,253,17,64,199,41,34,64,6,18,52,64,19,242,193,61,141,40,237,61,177,191,108,61,3,9,10,189,208,68,216,187,195,100,42,60,89,23,55,189,23,217,78,189,155,85,159,189,142,6,240,188,132,158,205,60,140,74,106,188,77,243,14,61,90,245,185,188,199,41,186,189,134,56,86,61,184,30,5,61,158,239,39,189,25,4,214,189,126,29,184,189,250,237,107,186,143,194,245,59,31,133,107,189,160,26,175,189,134,90,83,188,31,133,107,61,253,135,116,61,82,39,32,61,43,246,23,61,153,187,150,188,185,252,7,188,67,28,235,60,140,74,106,60,112,206,136,60,166,155,68,60,39,160,137,188,163,35,57,61,125,174,182,60,224,45,16,189,56,248,66,60,95,41,75,189,203,161,197,189,112,95,135,189,250,237,235,187,64,19,225,61,122,165,172,61,114,138,14,188,239,201,67,189,23,183,81,188,166,155,68,188,23,183,209,185,116,181,149,61,244,108,214,61,37,6,129,61,46,144,160,60,85,193,40,188,47,110,35,189,204,238,201,189,17,199,186,189,119,190,31,189,168,87,202,188,150,33,142,189,44,101,153,189,208,68,216,187,125,174,182,60,220,215,129,61,40,126,12,61,172,139,91,188,189,227,148,61,93,109,197,60,208,68,216,59,197,254,50,61,35,219,121,61,43,24,21,61,95,41,203,60,5,163,18,189,40,126,140,189,195,100,42,188,86,125,46,61,224,45,16,60,247,117,96,188,2,43,135,188,186,107,137,61,121,233,166,61,14,190,176,189,38,228,131,189,224,45,16,188,153,187,22,59,93,109,69,61,105,111,240,61,74,12,2,62,106,77,115,61,2,43,135,60,238,90,194,61,211,222,224,61,247,117,96,60,191,125,253,62,229,242,255,62,127,217,253,62,8,61,251,62,73,46,255,62,63,53,254,62,127,217,253,62,146,203,255,62,155,85,255,62,127,217,253,62,128,72,255,62,137,210,254,62,142,117,145,62,174,216,95,62,7,240,22,62,177,191,44,62,83,5,99,62,39,194,134,62,21,140,138,62,75,89,134,62,136,99,93,62,236,47,123,62,109,231,123,62,83,150,129,62,168,87,138,62,37,117,2,63,134,201,36,63,56,103,68,63,39,194,118,63,167,232,136,63,154,153,161,63,101,25,202,63,23,217,246,63,79,64,15,64,91,211,32,64,63,53,54,64,14,45,50,62,45,67,188,62,255,178,27,63,11,181,86,63,13,224,141,63,249,160,175,63,0,111,209,63,75,200,239,63,147,24,4,64,95,7,22,64,241,244,38,64,11,181,54,64,82,73,29,62,130,226,167,62,42,169,3,63,36,151,47,63,204,238,121,63,138,31,163,63,119,190,199,63,18,165,237,63,222,113,6,64,123,20,22,64,72,225,38,64,215,163,56,64,225,122,84,62,240,22,232,62,180,89,69,63,91,211,132,63,100,204,165,63,138,176,193,63,61,44,228,63,20,63,2,64,117,147,16,64,114,249,31,64,238,124,43,64,185,252,55,64,169,164,14,62,236,47,123,62,110,52,192,62,200,152,11,63,188,150,80,63,204,127,144,63,224,45,184,63,119,45,225,63,91,66,2,64,117,147,20,64,68,250,37,64,148,246,54,64,0,0,0,62,208,179,185,62,143,228,66,63,252,169,145,63,82,73,181,63,100,59,199,63,117,147,216,63,98,16,232,63,18,20,239,63,153,187,2,64,156,162,27,64,125,174,54,64,176,3,103,62,181,55,216,62,212,43,37,63,104,34,92,63,73,157,136,63,16,233,167,63,134,56,198,63,181,21,235,63,140,219,4,64,204,93,19,64,78,209,33,64,90,100,51,64,250,237,107,62,28,124,225,62,220,104,48,63,120,122,101,63,248,83,147,63,29,201,181,63,127,251,210,63,242,210,237,63,243,142,7,64,36,151,23,64,50,230,38,64,81,107,58,64,29,90,100,62,19,97,195,62,223,79,13,63,236,47,27,63,108,120,74,63,122,165,140,63,139,108,183,63,198,109,228,63,46,144,4,64,243,31,22,64,11,181,38,64,48,187,55,64,163,146,122,62,225,122,20,63,165,44,83,63,104,145,125,63,95,7,150,63,111,18,179,63,230,174,213,63,234,4,244,63,100,93,8,64,100,59,27,64,178,157,43,64,75,89,58,64,58,35,74,62,165,44,195,62,253,135,20,63,98,161,70,63,104,145,109,63,54,205,147,63,66,96,181,63,240,133,209,63,193,202,241,63,138,142,16,64,163,1,36,64,199,186,52,64,107,154,247,61,18,131,128,62,245,219,247,62,95,7,78,63,84,82,143,63,61,155,173,63,2,188,205,63,184,64,242,63,215,163,8,64,74,123,23,64,45,67,40,64,6,129,57,64,69,216,112,62,0,145,222,62,204,127,40,63,87,91,81,63,198,109,116,63,212,43,149,63,242,65,191,63,41,203,240,63,50,230,10,64,131,47,24,64,108,9,41,64,63,198,56,64,79,30,86,62,206,25,209,62,186,73,44,63,254,67,106,63,126,29,144,63,236,192,169,63,93,254,203,63,27,13,232,63,77,132,1,64,147,58,21,64,173,250,36,64,2,43,55,64,105,0,239,61,217,95,118,62,139,108,231,62,44,212,58,63,218,27,124,63,155,85,159,63,236,192,193,63,134,201,228,63,193,202,1,64,248,83,19,64,127,217,37,64,23,72,56,64,236,192,153,62,91,66,254,62,121,233,38,63,94,186,89,63,225,122,148,63,241,244,178,63,211,77,202,63,44,212,234,63,69,216,4,64,81,218,19,64,47,221,36,64,195,100,54,64,127,251,122,62,70,37,213,62,117,147,24,63,217,206,71,63,19,97,115,63,215,52,159,63,123,131,199,63,57,214,237,63,57,180,4,64,154,119,20,64,111,129,36,64,166,155,52,64,155,85,159,62,54,60,13,63,234,4,52,63,26,81,90,63,40,15,147,63,86,125,182,63,135,167,215,63,153,42,248,63,194,23,10,64,199,75,27,64,60,189,42,64,41,237,57,64,48,76,102,62,194,134,199,62,118,79,14,63,14,79,63,63,188,5,130,63,57,214,173,63,204,127,216,63,160,26,255,63,146,203,11,64,27,158,22,64,220,70,35,64,178,157,51,64,184,30,133,62,85,48,234,62,104,34,60,63,240,22,120,63,116,181,149,63,32,65,177,63,135,22,209,63,3,120,243,63,123,131,7,64,69,71,22,64,214,197,37,64,45,178,53,64,139,253,101,62,122,165,172,62,213,120,233,62,217,95,6,63,52,162,52,63,145,126,131,63,156,196,176,63,35,74,219,63,230,174,253,63,62,121,16,64,190,159,34,64,168,87,54,64,60,78,17,62,52,128,247,62,14,45,98,63,49,153,146,63,214,86,164,63,52,17,182,63,36,151,199,63,91,211,228,63,88,57,8,64,74,12,26,64,218,172,38,64,108,120,54,64,92,32,65,62,45,67,188,62,146,203,15,63,155,85,79,63,121,88,144,63,48,42,177,63,140,74,202,63,11,36,232,63,253,246,1,64,182,243,17,64,185,141,34,64,196,66,53,64,14,190,112,62,253,135,212,62,72,225,42,63,132,13,95,63,111,240,133,63,58,35,170,63,1,77,212,63,251,203,246,63,8,172,8,64,53,94,22,64,32,210,39,64,110,52,56,64,113,61,138,62,57,214,229,62,164,223,30,63,48,76,54,63,52,17,70,63,218,27,124,63,137,210,174,63,116,36,223,63,189,227,0,64,238,90,14,64,39,194,30,64,236,81,52,64,127,217,125,62,92,143,226,62,221,36,38,63,59,223,95,63,93,220,142,63,103,68,177,63,196,177,214,63,222,113,250,63,219,138,9,64,144,49,23,64,78,98,36,64,250,237,51,64,78,98,80,62,191,125,189,62,228,131,14,63,200,152,75,63,179,12,129,63,106,77,163,63,63,198,196,63,33,31,228,63,184,30,1,64,122,165,16,64,37,117,30,64,2,188,49,64,237,13,62,62,5,52,177,62,126,140,25,63,25,115,103,63,157,128,158,63,154,8,187,63,109,86,213,63,160,26,247,63,75,89,10,64,233,72,26,64,235,115,41,64,254,101,55,64,190,193,87,62,63,53,190,62,254,101,7,63,254,67,42,63,80,141,87,63,77,243,142,63,50,85,184,63,68,139,220,63,153,187,254,63,97,50,17,64,143,228,34,64,90,100,55,64,71,114,249,61,126,140,153,62,65,130,34,63,60,189,114,63,209,34,163,63,122,54,203,63,232,217,244,63,247,6,15,64,94,186,25,64,52,128,31,64,122,165,40,64,28,124,53,64,175,148,37,62,97,84,178,62,20,63,22,63,9,249,80,63,79,175,132,63,210,0,158,63,197,254,186,63,161,248,217,63,245,74,249,63,241,244,14,64,181,166,33,64,95,7,54,64,137,65,128,62,163,146,250,62,137,65,64,63,140,74,106,63,229,208,138,63,66,207,174,63,243,142,211,63,44,212,234,63,37,6,1,64,139,253,17,64,199,41,34,64,6,18,52,64,19,242,193,61,141,40,237,61,177,191,108,61,3,9,10,189,208,68,216,187,195,100,42,60,89,23,55,189,23,217,78,189,155,85,159,189,142,6,240,188,132,158,205,60,140,74,106,188,77,243,14,61,90,245,185,188,199,41,186,189,134,56,86,61,184,30,5,61,158,239,39,189,25,4,214,189,126,29,184,189,250,237,107,186,143,194,245,59,31,133,107,189,160,26,175,189,134,90,83,188,31,133,107,61,253,135,116,61,82,39,32,61,43,246,23,61,153,187,150,188,185,252,7,188,67,28,235,60,140,74,106,60,112,206,136,60,166,155,68,60,39,160,137,188,163,35,57,61,125,174,182,60,224,45,16,189,56,248,66,60,95,41,75,189,203,161,197,189,112,95,135,189,250,237,235,187,64,19,225,61,122,165,172,61,114,138,14,188,239,201,67,189,23,183,81,188,166,155,68,188,23,183,209,185,116,181,149,61,244,108,214,61,37,6,129,61,46,144,160,60,85,193,40,188,47,110,35,189,204,238,201,189,17,199,186,189,119,190,31,189,168,87,202,188,150,33,142,189,44,101,153,189,208,68,216,187,125,174,182,60,220,215,129,61,40,126,12,61,172,139,91,188,189,227,148,61,93,109,197,60,208,68,216,59,197,254,50,61,35,219,121,61,43,24,21,61,95,41,203,60,5,163,18,189,40,126,140,189,195,100,42,188,86,125,46,61,224,45,16,60,247,117,96,188,2,43,135,188,186,107,137,61,121,233,166,61,14,190,176,189,38,228,131,189,224,45,16,188,153,187,22,59,93,109,69,61,105,111,240,61,74,12,2,62,106,77,115,61,2,43,135,60,238,90,194,61,211,222,224,61,247,117,96,60,191,125,253,62,229,242,255,62,127,217,253,62,8,61,251,62,73,46,255,62,63,53,254,62,127,217,253,62,146,203,255,62,155,85,255,62,127,217,253,62,128,72,255,62,137,210,254,62,142,117,145,62,174,216,95,62,7,240,22,62,177,191,44,62,83,5,99,62,39,194,134,62,21,140,138,62,75,89,134,62,136,99,93,62,236,47,123,62,109,231,123,62,83,150,129,62,127,217,189,61,49,153,106,62,32,210,207,62,65,241,19,63,163,146,58,63,78,209,97,63,91,211,132,63,18,131,152,63,65,241,171,63,231,29,191,63,72,225,210,63,91,66,230,63,169,19,248,63,191,125,5,64,186,218,14,64,147,24,24,64,97,50,33,64,193,202,41,64,43,135,50,64,152,221,59,64,202,84,193,61,58,35,74,62,136,244,155,62,87,91,241,62], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+687464);
/* memory initializer */ allocate([209,145,28,63,34,108,72,63,89,23,103,63,205,204,132,63,87,236,151,63,122,165,172,63,247,117,192,63,251,203,214,63,204,238,233,63,75,200,255,63,11,70,9,64,5,197,19,64,129,4,29,64,138,31,39,64,214,86,48,64,46,255,57,64,215,52,239,61,197,143,145,62,8,61,251,62,113,172,43,63,41,92,79,63,64,19,113,63,110,163,137,63,122,199,153,63,50,85,168,63,126,140,185,63,76,166,202,63,130,115,222,63,27,158,238,63,213,120,1,64,39,194,10,64,205,204,20,64,41,237,29,64,229,242,39,64,30,167,48,64,188,5,58,64,21,140,10,62,160,26,111,62,68,139,172,62,137,65,224,62,102,247,20,63,159,60,60,63,68,250,93,63,74,12,130,63,53,94,146,63,9,27,166,63,63,53,190,63,91,66,214,63,113,172,235,63,224,45,0,64,57,214,9,64,93,254,19,64,168,87,30,64,11,36,40,64,26,81,50,64,200,7,61,64,22,106,205,61,65,241,99,62,52,128,183,62,228,131,254,62,179,12,33,63,66,96,69,63,81,107,106,63,46,144,136,63,47,110,155,63,32,99,174,63,202,84,193,63,77,132,213,63,204,127,232,63,2,188,253,63,238,235,8,64,140,185,19,64,204,238,29,64,192,91,40,64,27,158,50,64,120,11,60,64,208,68,216,61,151,144,79,62,226,88,151,62,86,14,205,62,6,129,5,63,140,185,43,63,131,192,90,63,45,33,135,63,210,0,158,63,145,126,179,63,30,167,200,63,141,40,221,63,14,190,240,63,59,112,2,64,125,208,11,64,61,155,21,64,220,70,31,64,20,208,40,64,81,107,50,64,91,211,60,64,59,223,207,61,218,27,124,62,225,11,211,62,120,11,20,63,48,42,57,63,243,31,98,63,91,211,132,63,192,91,152,63,202,195,170,63,111,129,188,63,0,145,206,63,179,12,225,63,215,18,242,63,53,94,2,64,235,226,10,64,0,0,20,64,205,204,28,64,59,112,38,64,120,11,48,64,147,169,58,64,34,253,54,62,107,154,119,62,2,43,167,62,208,179,9,63,231,140,40,63,52,162,68,63,29,90,116,63,164,112,141,63,51,51,155,63,141,40,173,63,102,247,188,63,242,210,213,63,11,36,232,63,159,205,250,63,139,253,5,64,0,111,17,64,33,31,28,64,177,225,37,64,108,9,45,64,22,251,55,64,87,236,175,61,10,215,35,62,117,147,152,62,209,145,252,62,232,106,43,63,147,24,84,63,192,236,126,63,168,198,147,63,5,197,167,63,202,195,186,63,244,108,206,63,19,242,225,63,200,7,245,63,29,90,4,64,247,228,13,64,177,80,23,64,4,231,32,64,118,79,42,64,126,29,52,64,188,5,62,64,53,94,186,61,98,16,88,62,159,60,172,62,197,143,241,62,226,233,21,63,44,212,58,63,147,24,100,63,70,148,134,63,71,114,153,63,187,184,173,63,69,71,194,63,32,210,215,63,216,129,235,63,52,162,0,64,86,125,10,64,215,163,20,64,185,141,30,64,84,116,40,64,189,82,50,64,159,60,60,64,56,248,66,62,24,38,147,62,154,119,188,62,247,6,255,62,229,242,31,63,94,186,73,63,99,127,105,63,154,153,137,63,207,247,155,63,85,193,176,63,239,201,195,63,138,176,217,63,68,250,237,63,12,2,3,64,66,62,12,64,205,204,20,64,238,235,28,64,48,76,38,64,68,105,47,64,72,191,57,64,54,205,187,61,42,169,83,62,249,49,166,62,210,0,254,62,55,137,33,63,22,106,77,63,224,156,113,63,4,231,140,63,205,59,158,63,78,209,177,63,168,53,197,63,188,5,218,63,152,221,235,63,241,99,0,64,83,150,9,64,229,242,19,64,184,30,29,64,60,189,38,64,190,193,47,64,29,201,57,64,21,140,202,61,46,144,96,62,165,78,192,62,250,126,10,63,229,97,49,63,134,56,86,63,213,231,122,63,0,0,144,63,254,67,162,63,34,142,181,63,101,170,200,63,109,86,221,63,137,65,240,63,139,253,1,64,9,138,11,64,141,40,21,64,77,243,30,64,209,145,40,64,208,213,50,64,21,29,61,64,50,85,176,61,148,246,70,62,182,132,156,62,190,48,249,62,0,145,30,63,238,90,66,63,67,28,107,63,50,119,141,63,32,210,159,63,234,4,180,63,146,203,199,63,43,24,221,63,254,101,239,63,198,220,1,64,88,202,10,64,215,163,20,64,132,158,29,64,209,34,39,64,125,208,47,64,203,161,57,64,164,223,190,61,98,16,88,62,155,85,191,62,45,67,12,63,162,69,54,63,90,100,91,63,41,92,127,63,142,117,145,63,74,123,163,63,25,4,182,63,103,213,199,63,60,189,218,63,227,165,235,63,29,201,253,63,77,21,8,64,48,76,18,64,160,137,28,64,52,128,39,64,220,215,49,64,197,32,60,64,143,83,244,61,233,183,111,62,170,96,180,62,14,190,0,63,134,201,36,63,190,193,71,63,146,203,111,63,189,227,140,63,27,158,158,63,240,133,177,63,164,112,197,63,26,192,219,63,167,121,239,63,83,150,1,64,58,35,10,64,164,223,18,64,58,146,27,64,103,68,37,64,211,77,46,64,78,209,57,64,159,205,170,61,58,146,75,62,79,30,182,62,125,174,6,63,54,60,45,63,48,187,87,63,7,95,128,63,219,138,149,63,153,42,168,63,19,242,185,63,136,99,205,63,249,15,225,63,63,87,243,63,14,79,3,64,214,86,12,64,165,189,21,64,56,248,30,64,45,67,40,64,2,188,49,64,162,180,59,64,55,26,192,61,186,107,73,62,111,129,164,62,41,92,239,62,63,87,27,63,202,50,68,63,206,25,113,63,4,86,142,63,176,114,160,63,97,84,178,63,67,28,195,63,132,13,215,63,44,212,234,63,231,29,255,63,112,206,8,64,139,108,19,64,159,171,29,64,43,246,39,64,9,27,50,64,114,249,59,64,23,72,208,61,147,169,130,62,219,138,221,62,3,9,26,63,187,39,63,63,5,52,97,63,217,61,129,63,37,117,146,63,110,163,161,63,195,211,179,63,192,236,198,63,131,192,218,63,1,77,236,63,5,197,255,63,170,130,9,64,183,98,19,64,25,226,28,64,72,225,38,64,2,154,48,64,7,240,58,64,24,38,211,61,12,2,107,62,174,216,191,62,138,31,3,63,140,219,40,63,209,34,75,63,100,59,111,63,164,112,141,63,228,131,158,63,180,89,173,63,193,168,188,63,114,138,206,63,84,82,223,63,101,25,242,63,17,199,2,64,45,67,12,64,202,195,22,64,206,136,34,64,74,123,47,64,153,42,60,64,205,59,206,61,252,24,115,62,63,53,190,62,198,109,4,63,6,129,37,63,0,145,78,63,138,142,116,63,240,167,142,63,5,52,161,63,200,7,181,63,201,229,199,63,140,185,219,63,230,63,236,63,169,19,0,64,87,91,9,64,97,84,18,64,79,64,27,64,242,210,37,64,73,46,47,64,23,183,57,64,120,122,165,61,14,190,48,62,106,222,145,62,67,28,235,62,237,158,28,63,108,9,73,63,235,115,117,63,169,19,144,63,122,54,163,63,181,55,184,63,145,126,203,63,224,45,224,63,213,231,242,63,172,139,3,64,149,101,12,64,182,243,21,64,28,235,30,64,93,254,39,64,122,165,48,64,141,151,58,64,213,231,42,62,239,201,131,62,255,33,189,62,0,145,14,63,136,99,45,63,146,92,78,63,74,12,130,63,109,86,149,63,140,185,163,63,140,185,179,63,29,201,197,63,230,63,220,63,113,27,237,63,66,62,0,64,179,12,9,64,251,92,21,64,124,97,30,64,161,103,39,64,60,189,46,64,144,160,56,64,156,162,35,62,64,19,129,62,50,230,174,62,125,208,3,63,200,152,43,63,35,74,75,63,69,216,112,63,50,230,142,63,78,209,153,63,129,38,170,63,137,210,190,63,137,210,214,63,163,1,236,63,203,16,255,63,134,90,7,64,103,68,17,64,186,73,28,64,156,162,39,64,253,135,48,64,91,66,58,64,199,186,184,61,21,140,74,62,2,43,167,62,195,100,234,62,16,122,22,63,59,112,62,63,76,55,105,63,200,152,139,63,128,183,160,63,205,204,180,63,112,206,200,63,66,96,221,63,222,2,241,63,83,5,3,64,212,43,13,64,5,163,22,64,225,122,32,64,62,232,41,64,58,146,51,64,15,11,61,64,194,134,167,61,104,145,45,62,132,13,143,62,47,221,228,62,204,93,27,63,15,156,67,63,173,105,110,63,218,27,140,63,93,220,158,63,33,31,180,63,39,49,200,63,22,251,219,63,153,187,238,63,39,160,1,64,225,11,11,64,200,7,21,64,27,158,30,64,159,60,40,64,154,153,49,64,5,197,59,64,131,192,74,62,247,117,160,62,106,222,209,62,82,184,254,62,107,43,38,63,244,108,86,63,138,176,113,63,125,208,131,63,219,249,150,63,28,124,177,63,3,9,202,63,116,70,220,63,82,39,232,63,54,171,246,63,240,133,5,64,131,192,18,64,237,13,30,64,222,147,39,64,138,142,48,64,215,52,59,64,222,2,9,62,233,183,111,62,70,148,182,62,61,155,245,62,4,231,28,63,74,12,66,63,227,199,104,63,233,72,134,63,247,117,152,63,10,104,170,63,253,246,189,63,8,61,211,63,23,217,230,63,207,247,251,63,29,56,7,64,217,61,17,64,249,49,26,64,193,168,36,64,79,30,46,64,197,143,57,64,201,229,191,61,23,72,80,62,133,124,176,62,183,209,0,63,111,18,35,63,237,158,76,63,135,167,119,63,53,239,144,63,88,57,164,63,72,191,181,63,48,76,198,63,94,186,217,63,102,247,236,63,138,142,0,64,133,235,9,64,158,239,19,64,23,183,29,64,179,234,39,64,46,255,49,64,218,27,60,64,63,53,222,61,100,93,92,62,27,13,160,62,204,238,233,62,124,97,18,63,30,167,56,63,42,58,98,63,48,187,135,63,69,71,154,63,98,16,176,63,228,20,197,63,224,156,217,63,156,162,235,63,230,63,0,64,83,150,9,64,70,182,19,64,37,6,29,64,159,205,38,64,49,8,48,64,211,77,58,64,249,49,102,61,243,142,83,62,114,138,206,62,68,139,12,63,40,15,43,63,186,218,74,63,111,18,115,63,113,61,138,63,87,236,151,63,149,101,168,63,13,224,189,63,36,185,212,63,58,146,235,63,11,70,1,64,88,168,9,64,203,161,17,64,145,15,26,64,70,182,35,64,85,193,44,64,15,11,57,64,165,78,192,61,195,211,107,62,36,151,191,62,240,167,6,63,21,140,42,63,143,83,84,63,30,22,122,63,254,212,144,63,211,188,163,63,141,40,181,63,175,148,197,63,214,197,213,63,233,38,233,63,219,249,254,63,78,98,8,64,100,59,19,64,129,4,29,64,200,7,37,64,9,27,46,64,3,9,58,64,242,210,205,61,145,15,122,62,222,147,199,62,85,48,10,63,243,31,50,63,53,239,88,63,55,26,128,63,179,234,147,63,240,167,166,63,108,9,185,63,17,54,204,63,178,157,223,63,156,51,242,63,51,51,3,64,238,235,12,64,75,89,22,64,97,195,31,64,108,9,41,64,250,126,50,64,165,78,60,64,60,78,209,61,114,249,79,62,111,129,164,62,229,97,225,62,165,78,16,63,249,49,54,63,95,7,94,63,252,24,131,63,9,27,150,63,108,9,169,63,95,7,190,63,131,192,210,63,141,151,230,63,129,149,251,63,38,228,7,64,32,99,18,64,209,145,28,64,164,223,38,64,27,47,49,64,181,55,60,64,150,67,75,62,225,11,179,62,122,165,236,62,163,35,25,63,233,183,63,63,27,13,96,63,123,20,126,63,191,125,149,63,30,22,170,63,241,244,186,63,250,126,202,63,201,229,223,63,156,51,242,63,57,69,3,64,90,100,11,64,83,150,21,64,201,118,30,64,38,228,39,64,75,200,47,64,142,117,57,64,74,123,3,62,163,35,121,62,35,219,185,62,34,108,248,62,95,152,28,63,219,249,62,63,65,241,99,63,166,155,132,63,20,63,150,63,181,55,168,63,218,27,188,63,2,43,207,63,159,205,226,63,57,69,247,63,129,38,6,64,196,66,17,64,17,54,28,64,196,177,38,64,141,40,49,64,133,124,60,64,207,102,213,61,30,22,106,62,181,55,184,62,110,163,1,63,20,208,36,63,227,54,74,63,41,92,111,63,161,103,139,63,2,188,157,63,199,186,176,63,72,225,194,63,146,92,214,63,192,91,232,63,97,195,251,63,248,83,7,64,243,31,18,64,29,90,28,64,170,241,38,64,83,150,49,64,125,208,59,64,119,190,159,61,160,137,48,62,35,219,121,62,5,163,178,62,2,43,7,63,9,27,62,63,251,92,109,63,255,178,139,63,41,203,160,63,61,155,181,63,140,74,202,63,173,105,222,63,3,9,242,63,247,6,3,64,84,116,12,64,243,31,22,64,20,174,31,64,21,29,41,64,245,185,50,64,21,29,61,64,247,228,225,61,148,135,133,62,32,65,209,62,214,197,13,63,147,58,49,63,52,128,87,63,201,118,126,63,35,74,147,63,251,92,165,63,149,101,184,63,254,67,202,63,31,244,220,63,0,145,238,63,68,139,0,64,145,15,10,64,61,10,19,64,162,180,27,64,219,138,37,64,100,59,47,64,233,72,58,64,20,208,4,62,110,163,129,62,31,244,204,62,34,108,8,63,100,93,44,63,31,133,75,63,193,168,116,63,197,254,138,63,166,155,156,63,82,73,173,63,62,121,192,63,122,199,209,63,111,240,229,63,23,217,246,63,72,191,5,64,45,67,16,64,18,20,27,64,231,140,36,64,0,0,44,64,196,66,57,64,124,97,178,61,240,133,73,62,41,92,175,62,136,99,253,62,84,116,36,63,26,192,75,63,6,18,116,63,86,125,142,63,46,255,161,63,150,33,182,63,74,12,202,63,157,17,221,63,48,187,239,63,162,69,2,64,134,201,12,64,251,203,22,64,102,247,32,64,169,164,42,64,197,32,52,64,129,4,61,64,24,149,212,61,138,176,97,62,48,76,166,62,122,199,233,62,66,62,24,63,114,138,62,63,197,143,97,63,232,217,132,63,46,255,153,63,23,72,176,63,6,129,197,63,17,199,218,63,102,102,238,63,145,15,2,64,131,47,12,64,106,222,21,64,119,190,31,64,202,84,41,64,203,16,51,64,57,180,60,64,240,22,8,62,50,119,141,62,177,225,201,62,97,195,3,63,11,181,38,63,27,158,78,63,96,229,112,63,79,64,139,63,22,106,157,63,174,71,177,63,15,156,195,63,93,109,213,63,82,39,232,63,16,233,255,63,2,154,8,64,246,151,17,64,171,62,27,64,240,133,37,64,139,108,47,64,17,199,58,64,25,115,215,61,63,87,91,62,52,128,183,62,69,216,0,63,216,129,35,63,75,200,71,63,141,151,110,63,231,251,137,63,54,205,155,63,224,45,176,63,136,99,197,63,82,39,216,63,126,140,233,63,198,220,253,63,207,247,7,64,155,230,17,64,231,29,27,64,80,252,36,64,222,113,46,64,134,56,58,64,64,164,223,61,222,2,137,62,105,111,208,62,135,22,9,63,136,133,42,63,105,111,80,63,48,76,118,63,176,3,143,63,110,163,161,63,104,145,181,63,167,232,200,63,127,106,220,63,25,4,238,63,163,35,1,64,12,2,11,64,73,157,20,64,249,49,30,64,191,14,40,64,143,194,49,64,211,188,59,64,91,66,190,61,114,138,78,62,109,86,157,62,231,251,233,62,10,215,19,63,188,116,67,63,237,13,110,63,76,166,138,63,13,224,157,63,53,94,178,63,66,96,197,63,154,8,219,63,194,23,238,63,68,250,1,64,160,26,11,64,8,172,20,64,64,19,29,64,27,158,38,64,167,121,47,64,240,133,57,64,82,184,158,61,223,79,77,62,33,176,178,62,184,30,5,63,36,185,44,63,212,154,86,63,86,14,125,63,20,63,150,63,110,52,168,63,134,56,182,63,232,106,203,63,224,190,222,63,154,119,236,63,16,88,1,64,249,49,10,64,213,120,17,64,160,26,27,64,152,221,35,64,132,158,45,64,203,161,57,64,101,25,226,61,104,179,106,62,113,172,171,62,69,71,242,62,191,125,29,63,225,122,68,63,49,153,106,63,15,156,139,63,5,52,161,63,234,4,180,63,88,202,194,63,184,64,210,63,98,161,230,63,144,49,255,63,128,183,8,64,77,243,18,64,124,242,28,64,99,238,38,64,36,185,48,64,143,228,58,64,48,42,169,61,205,204,76,62,196,66,173,62,184,175,3,63,204,93,43,63,130,115,86,63,8,172,124,63,104,179,146,63,143,194,165,63,55,137,185,63,95,41,203,63,185,141,222,63,231,140,240,63,9,27,2,64,247,6,11,64,250,237,19,64,137,65,28,64,171,207,37,64,203,16,47,64,122,199,57,64,208,179,217,61,66,62,104,62,251,58,176,62,152,110,242,62,209,145,28,63,224,45,64,63,231,29,103,63,149,212,137,63,132,13,159,63,152,221,179,63,171,62,199,63,193,202,217,63,170,130,233,63,150,178,252,63,153,42,8,64,215,18,18,64,220,70,27,64,101,25,38,64,20,208,48,64,188,116,59,64,31,133,235,61,169,19,144,62,2,154,232,62,49,8,28,63,177,191,60,63,136,244,91,63,18,165,125,63,178,46,142,63,111,240,157,63,182,243,173,63,91,66,190,63,77,243,206,63,27,158,222,63,142,6,240,63,87,91,1,64,159,205,10,64,234,4,20,64,95,41,31,64,238,235,44,64,45,33,59,64,129,38,194,61,170,96,84,62,5,197,175,62,228,20,253,62,37,117,34,63,70,182,67,63,170,130,97,63,217,206,135,63,148,135,157,63,52,162,172,63,129,149,187,63,73,46,207,63,105,111,224,63,44,101,241,63,67,28,3,64,123,20,14,64,68,139,24,64,233,183,35,64,127,106,48,64,20,208,60,64,99,127,217,61,11,70,101,62,209,145,188,62,15,11,5,63,86,159,43,63,170,130,81,63,208,213,118,63,244,108,142,63,128,183,160,63,143,228,178,63,27,47,197,63,254,212,216,63,51,51,235,63,0,145,254,63,20,208,8,64,111,18,19,64,233,38,29,64,222,147,39,64,205,59,50,64,40,126,60,64,198,220,181,61,223,79,77,62,51,196,145,62,82,73,221,62,102,136,19,63,161,248,65,63,113,27,109,63,25,4,142,63,159,205,162,63,210,111,183,63,88,202,202,63,183,98,223,63,76,55,241,63,201,118,2,64,80,141,11,64,115,104,21,64,102,102,30,64,239,201,39,64,29,90,48,64,230,174,57,64,68,105,47,62,139,253,133,62,166,10,198,62,139,253,21,63,157,17,53,63,250,126,90,63,36,151,135,63,39,194,150,63,146,203,167,63,208,179,185,63,227,165,203,63,194,134,223,63,145,15,242,63,153,42,4,64,37,6,13,64,213,120,21,64,42,169,31,64,76,55,41,64,123,131,47,64,54,60,57,64,149,212,9,62,65,130,130,62,87,91,209,62,40,126,12,63,247,228,49,63,235,226,86,63,209,34,123,63,240,167,142,63,192,91,160,63,97,195,179,63,22,106,197,63,43,246,215,63,62,232,233,63,40,126,252,63,173,250,8,64,68,250,17,64,81,107,26,64,15,156,35,64,169,19,44,64,145,237,56,64,192,236,158,61,139,253,37,62,174,182,130,62,70,148,214,62,245,74,25,63,17,199,74,63,203,16,119,63,174,71,145,63,6,129,165,63,174,71,185,63,216,240,204,63,135,22,225,63,6,18,244,63,77,21,4,64,235,115,13,64,105,0,23,64,73,157,32,64,79,30,42,64,103,213,51,64,29,201,61,64,124,242,176,61,52,17,54,62,243,31,146,62,254,212,216,62,114,138,14,63,254,212,56,63,235,115,101,63,146,203,135,63,170,96,156,63,37,6,177,63,207,102,197,63,149,212,217,63,235,115,237,63,131,81,1,64,68,105,11,64,152,76,21,64,95,41,31,64,14,190,40,64,11,181,50,64,179,12,61,64,140,74,234,61,38,228,131,62,189,82,214,62,215,52,15,63,0,0,48,63,37,117,82,63,116,181,117,63,77,21,140,63,43,24,157,63,194,134,175,63,19,242,193,63,161,214,212,63,199,75,231,63,133,235,249,63,14,45,6,64,88,57,16,64,222,113,26,64,215,163,36,64,102,102,46,64,92,143,58,64,173,250,220,61,47,110,99,62,104,179,170,62,98,16,248,62,140,185,27,63,220,104,64,63,93,220,102,63,107,154,135,63,53,94,154,63,176,3,175,63,174,182,194,63,98,16,216,63,249,15,233,63,57,214,253,63,33,31,8,64,27,158,18,64,65,241,27,64,163,146,38,64,56,248,46,64,21,29,57,64,58,146,203,61,193,168,100,62,145,15,186,62,70,182,3,63,11,36,40,63,82,39,80,63,99,127,121,63,188,150,144,63,243,31,162,63,79,175,180,63,12,147,201,63,173,250,220,63,11,181,238,63,136,99,1,64,127,251,10,64,64,19,21,64,41,92,31,64,223,79,41,64,3,9,50,64,179,234,59,64,66,96,229,61,189,227,84,62,82,39,160,62,24,38,211,62,25,115,7,63,86,125,46,63,108,9,89,63,133,235,129,63,125,174,150,63,159,60,172,63,147,169,194,63,240,22,216,63,45,67,236,63,204,127,0,64,173,105,10,64,154,119,20,64,140,74,30,64,163,1,40,64,247,228,49,64,199,186,60,64,196,177,174,61,59,223,79,62,81,218,187,62,121,88,8,63,241,244,42,63,105,0,79,63,152,221,115,63,27,158,142,63,30,167,160,63,239,56,181,63,25,226,200,63,206,136,218,63,179,234,235,63,22,251,251,63,19,97,7,64,215,52,15,64,36,151,23,64,75,200,35,64,23,217,46,64,254,67,58,64,16,88,185,61,100,204,93,62,97,50,181,62,70,37,5,63,31,133,43,63,88,168,85,63,59,1,125,63,76,166,146,63,60,189,162,63,76,55,177,63,156,51,194,63,61,155,213,63,157,128,230,63,74,12,250,63,136,133,6,64,202,84,17,64,201,118,26,64,205,59,38,64,16,233,47,64,171,207,57,64,39,160,9,60,190,48,25,61,75,89,134,60,218,172,122,188,250,237,235,60,14,79,47,60,96,229,208,188,20,63,198,188,0,0,0,0,88,57,180,187,221,181,4,188,143,194,245,187,224,45,16,187,195,100,170,187,101,25,226,187,137,210,222,186,82,73,157,57,43,24,21,60,52,128,55,59,124,242,48,187,150,67,11,60,4,231,140,59,18,131,192,188,121,88,40,189,120,122,165,60,225,11,19,61,117,2,26,61,74,123,3,61,218,172,250,60,5,163,18,189,101,25,226,188,188,116,19,188,23,183,81,59,82,73,157,59,255,33,253,60,185,252,7,61,30,167,232,60,129,38,194,60,231,29,167,59,120,122,37,188,164,223,190,188,14,79,47,189,178,157,111,189,228,131,30,189,36,151,127,59,221,181,4,60,237,13,62,59,137,210,222,186,82,73,29,186,137,210,222,187,224,45,144,59,43,24,149,60,117,2,26,61,228,131,30,61,112,206,8,189,100,93,220,188,43,24,149,188,101,25,226,187,195,100,42,187,66,96,101,59,46,144,160,187,159,171,173,188,231,29,39,189,57,180,200,188,7,95,152,60,44,212,154,60,218,172,122,60,166,155,68,60,73,157,128,60,88,57,180,59,153,187,150,187,5,163,146,60,30,167,232,60,23,183,81,187,171,207,213,188,158,239,167,188,36,151,127,187,114,138,142,60,216,240,244,60,12,147,169,60,82,73,157,58,52,128,183,187,111,18,131,58,176,3,103,60,56,248,66,188,227,165,155,60,37,6,1,61,208,68,88,59,23,183,81,188,143,194,245,60,75,89,6,61,72,80,252,60,188,150,16,61,62,232,217,60,208,68,216,59,75,89,6,189,64,164,223,188,124,242,176,59,104,145,109,60,41,92,143,60,166,155,196,58,77,21,140,188,95,41,203,59,75,89,134,188,188,116,147,59,30,167,232,187,10,215,35,59,211,188,227,60,103,213,231,60,91,177,63,60,195,100,42,187,213,120,233,188,231,29,39,189,226,233,21,189,202,84,193,187,195,100,170,188,151,255,16,189,112,206,8,189,25,115,215,188,23,183,209,187,250,237,235,59,82,73,29,186,18,131,192,188,179,123,114,187,145,126,251,188,69,216,240,188,148,135,133,188,229,97,161,188,18,131,192,188,82,73,157,60,195,100,170,58,161,103,179,188,240,133,73,188,23,183,209,185,221,181,4,188,82,73,29,188,240,133,73,188,120,122,37,188,39,160,9,59,254,101,119,60,159,171,45,60,254,101,119,60,215,52,239,60,208,68,88,59,103,213,231,60,95,41,75,60,237,13,190,59,137,210,222,186,108,9,121,187,108,9,121,60,176,3,103,60,208,68,88,60,78,209,145,60,73,157,128,60,215,52,239,59,224,45,144,60,176,3,103,60,192,236,30,60,153,187,22,188,148,135,133,188,127,106,188,188,172,139,91,188,156,51,34,188,69,216,112,188,111,18,131,59,226,233,149,188,41,92,143,188,111,18,3,188,185,252,7,188,104,145,237,188,159,205,42,189,83,5,35,189,100,93,220,188,83,5,163,188,140,74,106,188,159,171,173,187,156,51,34,188,124,242,176,187,83,5,163,188,161,103,179,188,150,67,139,188,14,79,47,60,192,236,158,60,66,96,101,59,197,254,50,61,48,76,38,61,197,32,176,60,166,155,68,60,159,171,173,59,52,128,55,187,56,248,194,60,3,9,10,61,51,196,177,60,224,45,144,58,90,245,185,60,130,226,199,60,111,240,5,61,44,212,26,61,197,254,50,61,78,209,17,61,208,68,88,187,163,35,57,60,11,181,38,61,112,206,8,61,205,204,76,188,82,73,157,185,176,3,103,188,64,164,223,188,247,117,96,188,0,111,1,188,104,145,109,188,30,167,232,187,17,199,58,60,116,70,148,60,143,194,117,60,150,67,11,60,72,80,252,187,108,9,121,187,161,103,179,188,25,115,215,188,190,48,153,188,164,223,190,188,62,232,89,60,135,22,217,60,36,151,127,188,43,24,21,188,88,57,52,188,23,183,209,186,140,74,106,60,151,255,144,60,166,155,196,60,75,89,6,60,140,74,106,188,206,136,210,188,52,128,183,186,23,183,81,57,75,89,6,60,188,116,147,60,184,30,5,61,150,67,11,61,218,172,122,188,155,85,31,189,166,155,196,188,75,89,6,60,66,96,101,60,153,187,150,59,101,25,98,188,44,212,26,189,226,233,21,189,106,77,243,60,59,112,206,60,36,151,255,59,59,112,206,59,82,73,29,58,224,45,144,59,179,123,242,59,117,2,26,60,163,35,57,60,49,8,44,60,247,117,96,60,161,103,51,61,98,161,214,60,36,151,255,187,80,141,151,188,197,32,176,188,11,181,38,189,14,45,50,189,195,100,170,188,23,183,209,185,250,237,107,188,158,239,167,188,95,41,203,188,184,64,130,188,101,25,226,187,218,172,122,188,208,68,88,60,115,104,17,61,33,31,244,60,166,155,68,60,250,237,235,59,202,84,193,60,25,115,87,61,202,50,68,61,164,223,190,60,62,232,89,188,103,213,231,188,91,177,63,189,211,222,96,189,80,141,23,189,23,183,81,59,52,128,183,59,153,187,22,59,10,215,163,59,82,73,29,59,138,142,228,60,237,13,62,60,188,116,147,187,82,73,157,186,14,79,47,60,227,165,155,60,242,65,207,60,154,119,156,60,4,231,140,59,9,27,158,60,114,138,14,189,240,133,201,188,240,133,73,60,49,8,172,60,27,47,93,60,82,73,29,188,234,149,50,188,108,9,249,187,36,151,127,188,104,145,237,188,111,18,131,60,192,236,158,60,161,103,179,60,61,44,212,60,205,204,204,60,119,190,159,60,109,86,253,62,210,0,254,62,145,237,252,62,236,192,249,62,208,68,248,62,188,5,242,62,3,9,234,62,222,2,233,62,11,36,232,62,248,194,228,62,247,228,225,62,192,236,222,62,191,14,220,62,245,185,218,62,48,76,230,62,11,181,230,62,213,120,233,62,67,28,235,62,15,156,243,62,173,250,252,62,219,138,125,62,180,89,53,62,58,35,74,62,73,157,64,62,104,179,42,62,127,251,58,62,42,169,83,62,114,249,79,62,197,143,49,62,228,20,29,62,96,229,16,62,143,83,52,62,184,64,66,62,235,115,53,62,249,15,41,62,183,98,255,61,97,50,213,61,218,27,252,61,217,61,57,62,248,194,100,62,185,252,135,61,0,0,64,62,246,40,220,62,186,73,44,63,206,25,97,63,39,49,136,63,112,206,160,63,14,190,184,63,220,215,209,63,30,167,232,63,131,47,0,64,94,75,12,64,94,75,24,64,94,75,36,64,166,155,48,64,200,7,61,64,62,232,89,62,96,118,207,62,43,246,7,63,65,241,35,63,154,153,73,63,215,163,96,63,154,119,140,63,165,189,169,63,215,52,199,63,121,233,214,63,60,189,234,63,227,165,7,64,122,165,20,64,99,127,29,64,76,55,41,64,196,66,57,64,242,65,79,62,104,34,172,62,52,128,247,62,159,171,45,63,30,167,104,63,72,225,138,63,163,1,156,63,38,228,179,63,9,27,206,63,232,106,227,63,38,228,251,63,190,48,9,64,74,12,22,64,34,253,34,64,172,139,47,64,227,165,59,64,106,222,241,61,158,94,105,62,19,242,225,62,182,132,28,63,66,96,69,63,202,84,113,63,27,158,142,63,76,166,162,63,27,158,190,63,192,236,222,63,204,238,249,63,229,97,9,64,193,57,23,64,23,217,34,64,218,172,46,64,121,233,58,64,68,139,236,61,150,67,139,62,199,41,250,62,32,99,46,63,163,1,92,63,207,102,133,63,203,161,157,63,79,175,180,63,185,141,206,63,240,167,230,63,4,231,252,63,187,39,11,64,132,13,23,64,156,162,35,64,32,210,47,64,93,254,59,64,248,83,227,61,12,147,169,62,152,110,242,62,206,170,15,63,157,128,54,63,160,137,80,63,127,251,130,63,78,98,168,63,193,202,201,63,24,38,227,63,21,140,250,63,249,15,9,64,166,155,20,64,37,117,34,64,7,240,46,64,156,162,59,64,12,147,41,62,31,133,171,62,217,206,215,62,36,151,15,63,200,7,45,63,67,173,89,63,231,251,145,63,56,103,180,63,148,135,205,63,217,206,215,63,122,199,225,63,202,50,0,64,233,38,17,64,133,124,32,64,179,123,46,64,136,244,59,64,79,30,22,62,254,67,186,62,186,218,234,62,32,65,17,63,31,244,60,63,41,237,93,63,20,63,118,63,239,56,149,63,211,188,187,63,100,59,223,63,238,124,247,63,228,131,6,64,63,87,19,64,100,204,33,64,252,24,47,64,57,69,59,64,245,74,217,61,19,97,131,62,5,163,242,62,91,211,44,63,105,0,95,63,222,2,137,63,229,208,162,63,129,149,187,63,68,139,212,63,36,185,236,63,35,219,1,64,145,15,14,64,181,166,25,64,57,214,37,64,165,189,49,64,25,226,60,64,138,142,228,61,215,18,114,62,177,80,203,62,138,176,33,63,140,185,91,63,186,73,132,63,175,148,149,63,254,67,170,63,103,213,199,63,91,211,228,63,171,207,253,63,255,33,13,64,176,3,23,64,170,241,34,64,127,251,46,64,188,116,59,64,66,62,136,62,189,82,214,62,193,57,3,63,171,207,37,63,165,189,97,63,66,96,141,63,111,129,164,63,161,214,180,63,143,228,202,63,190,48,225,63,165,78,248,63,171,62,11,64,222,147,23,64,211,222,32,64,50,85,44,64,117,2,58,64,135,22,25,62,177,191,140,62,183,209,224,62,229,97,33,63,28,235,82,63,26,81,130,63,55,137,153,63,126,29,176,63,46,144,200,63,115,215,226,63,239,201,251,63,201,118,10,64,77,243,22,64,19,97,35,64,227,165,47,64,36,151,59,64,17,199,186,61,33,31,52,62,173,250,156,62,96,229,16,63,145,237,76,63,216,240,116,63,25,115,151,63,181,166,185,63,126,29,208,63,2,188,229,63,36,185,0,64,20,208,12,64,183,98,23,64,48,187,35,64,224,190,50,64,211,77,62,64,21,140,10,62,122,165,140,62,41,203,208,62,222,2,25,63,120,11,68,63,12,147,105,63,57,214,141,63,201,118,174,63,51,51,203,63,13,113,228,63,155,85,247,63,243,142,7,64,32,65,21,64,94,75,32,64,161,248,45,64,61,10,59,64,130,115,70,62,142,6,208,62,18,20,255,62,181,166,25,63,212,43,69,63,181,55,104,63,118,224,148,63,94,186,177,63,180,89,205,63,16,233,231,63,231,29,247,63,23,183,5,64,0,111,17,64,99,127,29,64,17,54,40,64,50,85,56,64,36,40,62,62,58,146,171,62,165,78,224,62,131,47,28,63,197,143,65,63,12,2,91,63,75,234,132,63,188,150,168,63,160,137,200,63,7,95,216,63,101,170,224,63,234,4,252,63,237,158,16,64,252,169,33,64,114,138,46,64,190,193,59,64,170,96,212,61,228,20,93,62,244,108,214,62,237,13,30,63,45,178,77,63,227,165,131,63,118,224,156,63,221,36,182,63,133,235,209,63,136,133,234,63,238,235,0,64,36,185,12,64,78,98,24,64,100,93,36,64,36,185,48,64,56,103,60,64,102,102,38,62,150,33,142,62,236,81,216,62,39,160,25,63,208,179,73,63,144,160,104,63,184,64,138,63,177,80,163,63,11,181,190,63,155,85,223,63,93,220,254,63,248,83,11,64,195,211,23,64,9,249,36,64,176,3,51,64,13,113,60,64,153,42,88,62,53,94,186,62,120,122,21,63,190,159,58,63,9,27,78,63,94,75,128,63,203,161,157,63,200,7,181,63,8,61,203,63,150,67,227,63,191,125,253,63,83,150,9,64,97,50,21,64,113,61,34,64,36,185,48,64,237,158,60,64,23,183,17,62,167,121,135,62,97,195,211,62,92,143,34,63,141,151,78,63,243,142,115,63,77,243,142,63,92,32,169,63,204,238,201,63,44,212,226,63,7,95,248,63,84,227,9,64,252,169,21,64,118,224,32,64,155,85,47,64,163,35,61,64,103,213,231,61,143,83,116,62,215,18,210,62,103,213,23,63,130,226,71,63,31,244,124,63,80,141,151,63,115,104,177,63,157,17,205,63,162,69,230,63,105,0,255,63,98,16,12,64,30,167,24,64,188,150,36,64,96,229,48,64,47,221,60,64,165,189,1,62,239,56,133,62,121,88,200,62,153,42,24,63,65,130,66,63,3,120,107,63,46,255,137,63,131,192,162,63,195,211,195,63,53,239,224,63,116,36,247,63,73,157,8,64,167,232,20,64,125,174,34,64,75,200,47,64,227,165,59,64,187,39,79,62,77,243,174,62,211,222,224,62,168,53,29,63,59,112,62,63,22,251,91,63,95,7,142,63,180,89,173,63,53,94,194,63,223,224,211,63,52,162,228,63,178,46,2,64,44,101,17,64,7,240,30,64,142,117,45,64,24,149,60,64,65,241,227,61,145,237,124,62,45,67,188,62,197,143,17,63,184,30,69,63,123,131,111,63,26,81,138,63,183,98,159,63,242,210,189,63,210,0,222,63,98,161,246,63,80,252,8,64,12,147,21,64,228,20,33,64,213,231,46,64,67,173,57,64,195,100,42,62,253,246,181,62,54,171,14,63,242,65,63,63,8,172,108,63,63,198,140,63,113,172,163,63,129,149,187,63,212,43,213,63,44,212,234,63,70,37,1,64,78,209,13,64,227,54,26,64,237,13,38,64,35,219,49,64,244,253,60,64,130,115,6,62,102,102,134,62,42,58,242,62,102,247,36,63,178,157,79,63,118,224,124,63,67,28,147,63,21,29,169,63,5,52,201,63,153,42,232,63,134,56,254,63,105,111,12,64,5,197,23,64,255,178,35,64,176,3,47,64,145,126,59,64,143,228,242,61,90,100,155,62,32,65,1,63,178,157,47,63,182,243,93,63,41,92,127,63,142,117,145,63,198,109,172,63,96,229,200,63,164,223,222,63,249,160,247,63,110,163,9,64,220,215,21,64,254,101,35,64,177,225,49,64,224,156,61,64,28,235,226,61,30,22,138,62,43,24,245,62,10,104,34,63,108,120,74,63,207,102,117,63,152,110,146,63,216,240,172,63,227,199,200,63,245,74,225,63,75,89,246,63,65,241,7,64,64,19,21,64,250,126,34,64,229,208,46,64,48,187,59,64,94,186,201,61,140,185,107,62,235,115,181,62,47,110,19,63,111,18,67,63,203,16,119,63,95,41,147,63,139,108,167,63,102,102,198,63,127,106,228,63,149,212,249,63,252,24,11,64,229,208,22,64,137,65,36,64,8,172,48,64,184,64,58,64,254,101,247,61,86,159,139,62,165,78,224,62,115,215,18,63,173,250,60,63,180,200,86,63,60,78,129,63,247,228,161,63,174,71,193,63,100,59,223,63,138,31,251,63,233,38,9,64,48,42,21,64,129,4,33,64,86,125,46,64,77,243,58,64,46,255,33,62,178,46,142,62,184,30,229,62,162,180,39,63,250,237,91,63,64,19,129,63,101,25,146,63,243,31,170,63,172,139,203,63,61,44,228,63,129,38,250,63,27,158,10,64,242,176,20,64,23,72,32,64,78,98,44,64,164,223,58,64,150,67,11,62,252,24,147,62,131,192,234,62,233,38,33,63,238,90,66,63,172,173,104,63,48,76,134,63,127,251,162,63,59,1,197,63,47,110,227,63,43,246,247,63,111,129,8,64,116,70,20,64,147,24,32,64,130,226,43,64,138,142,56,64,235,115,181,61,35,74,59,62,54,60,189,62,91,211,28,63,180,89,85,63,94,186,129,63,120,122,157,63,195,211,187,63,118,79,214,63,132,158,237,63,90,100,3,64,2,43,15,64,16,88,25,64,108,9,37,64,110,163,49,64,71,3,60,64,223,79,77,62,43,24,181,62,215,163,240,62,114,249,31,63,86,14,61,63,25,226,104,63,228,131,150,63,227,199,176,63,234,4,196,63,242,210,213,63,136,99,237,63,152,221,7,64,157,17,21,64,61,155,33,64,235,226,50,64,2,188,61,64,150,178,76,62,155,85,159,62,51,196,241,62,7,240,54,63,120,11,100,63,192,91,128,63,210,111,151,63,90,245,177,63,102,102,206,63,224,45,224,63,45,67,244,63,185,252,7,64,53,239,20,64,107,43,34,64,176,114,44,64,64,19,57,64,0,145,254,61,93,109,133,62,192,91,224,62,143,194,21,63,125,63,69,63,222,2,121,63,9,138,143,63,187,39,167,63,88,202,194,63,251,203,222,63,31,244,244,63,193,168,8,64,50,119,21,64,226,233,33,64,5,163,46,64,3,9,58,64,134,201,212,61,34,108,120,62,53,94,218,62,211,222,32,63,242,176,80,63,86,125,126,63,181,166,153,63,184,175,179,63,113,172,203,63,204,93,227,63,31,133,251,63,42,58,10,64,205,59,22,64,138,31,35,64,74,123,47,64,42,169,59,64,113,172,11,62,217,206,119,62,148,246,198,62,79,30,22,63,61,44,68,63,10,104,98,63,12,2,139,63,99,127,169,63,98,161,198,63,200,7,229,63,142,6,0,64,46,255,9,64,95,41,23,64,106,77,35,64,97,50,49,64,39,194,58,64,245,219,23,62,161,248,145,62,38,83,229,62,83,150,33,63,186,218,74,63,232,106,123,63,242,210,149,63,63,87,171,63,205,204,196,63,40,126,220,63,223,224,243,63,168,87,6,64,21,140,18,64,255,178,31,64,205,204,44,64,206,136,58,64,251,203,110,62,240,133,233,62,81,107,10,63,247,6,31,63,73,157,64,63,211,77,82,63,97,195,115,63,104,145,149,63,202,195,194,63,35,74,219,63,243,31,234,63,11,36,4,64,139,253,17,64,181,21,31,64,32,65,45,64,254,101,59,64,3,9,10,62,27,13,160,62,24,149,4,63,126,29,56,63,17,54,108,63,71,114,145,63,32,65,169,63,118,224,188,63,177,80,211,63,69,216,232,63,130,226,255,63,122,165,12,64,20,208,24,64,75,234,36,64,117,147,48,64,6,18,60,64,174,216,223,61,10,104,98,62,152,221,243,62,200,152,43,63,234,4,84,63,33,31,116,63,183,98,143,63,188,150,176,63,180,89,205,63,251,203,230,63,127,217,253,63,254,67,10,64,50,230,22,64,120,122,37,64,195,245,48,64,96,118,59,64,219,249,62,62,127,251,154,62,250,126,234,62,163,1,44,63,61,10,87,63,179,12,129,63,50,85,152,63,220,104,176,63,2,188,197,63,197,32,216,63,60,78,249,63,161,214,8,64,155,230,17,64,36,185,32,64,168,198,47,64,230,63,60,64,174,71,33,62,229,242,159,62,95,7,238,62,165,78,32,63,100,59,79,63,100,93,124,63,235,115,149,63,9,27,174,63,208,68,200,63,179,12,225,63,113,61,250,63,196,177,10,64,29,56,23,64,150,178,36,64,135,22,49,64,238,235,60,64,105,111,240,61,178,46,142,62,224,190,238,62,243,31,34,63,92,32,81,63,147,58,129,63,197,32,152,63,217,61,177,63,69,71,202,63,167,232,224,63,98,16,248,63,124,242,8,64,127,217,21,64,212,154,34,64,160,26,47,64,0,0,60,64,26,192,219,61,103,213,103,62,179,12,209,62,167,232,24,63,155,85,63,63,243,142,115,63,103,68,145,63,174,182,170,63,219,138,197,63,237,13,222,63,98,16,248,63,190,48,9,64,188,5,22,64,159,205,34,64,140,185,47,64,27,13,60,64,153,187,22,62,188,116,147,62,207,102,245,62,247,117,32,63,27,47,77,63,112,206,128,63,182,243,149,63,169,164,174,63,82,184,198,63,23,217,222,63,157,128,246,63,81,218,7,64,209,145,20,64,31,244,32,64,72,191,45,64,186,218,58,64,41,203,16,62,248,83,131,62,54,171,222,62,13,113,28,63,244,253,68,63,252,24,115,63,123,131,143,63,193,202,169,63,88,202,194,63,116,70,220,63,90,100,243,63,67,173,5,64,17,54,20,64,40,126,32,64,140,74,46,64,94,75,60,64,110,52,0,62,231,140,136,62,120,11,228,62,52,162,36,63,48,76,86,63,83,150,129,63,12,2,155,63,125,63,181,63,59,223,207,63,99,127,233,63,1,77,0,64,52,162,12,64,9,249,24,64,173,250,36,64,118,224,48,64,172,173,60,64,57,69,7,62,248,83,131,62,75,234,196,62,230,174,21,63,46,255,65,63,200,7,109,63,82,39,136,63,193,168,156,63,49,8,188,63,95,7,222,63,205,204,252,63,120,11,12,64,190,193,23,64,242,65,35,64,141,151,46,64,47,221,56,64,24,38,19,62,25,4,150,62,174,182,226,62,246,151,29,63,182,243,77,63,153,187,118,63,92,143,146,63,153,42,168,63,220,215,193,63,221,36,222,63,5,52,249,63,78,209,9,64,127,217,21,64,143,228,34,64,40,15,47,64,211,188,59,64,196,66,45,62,242,210,141,62,175,37,196,62,246,40,28,63,236,81,72,63,150,33,110,63,254,212,136,63,190,193,159,63,111,18,187,63,247,6,215,63,223,79,245,63,45,33,11,64,231,251,21,64,205,59,34,64,197,32,48,64,169,164,58,64,145,237,252,61,164,223,126,62,192,236,222,62,124,97,34,63,115,215,82,63,69,216,128,63,34,108,152,63,154,119,172,63,149,101,200,63,133,235,233,63,207,247,3,64,165,78,16,64,201,118,26,64,220,215,37,64,189,227,48,64,211,188,59,64,100,59,223,61,112,206,72,62,38,83,197,62,19,242,17,63,125,208,51,63,124,97,98,63,149,212,145,63,176,114,176,63,49,8,204,63,54,205,227,63,140,219,248,63,209,34,11,64,193,168,24,64,124,242,36,64,235,115,49,64,202,50,60,64,119,190,31,62,188,5,178,62,23,72,0,63,124,242,32,63,1,222,66,63,109,86,125,63,248,83,147,63,168,198,171,63,104,145,197,63,171,62,215,63,190,193,239,63,153,42,4,64,36,185,16,64,93,254,31,64,9,249,44,64,22,106,57,64,207,102,21,62,254,101,119,62,230,63,196,62,31,133,11,63,76,166,74,63,218,27,108,63,62,121,136,63,151,255,152,63,58,146,179,63,79,175,212,63,199,75,247,63,109,86,9,64,159,171,21,64,182,132,32,64,123,131,43,64,23,217,58,64,118,79,30,62,38,83,197,62,118,79,30,63,117,147,88,63,206,170,135,63,18,20,159,63,46,255,177,63,61,10,199,63,0,145,222,63,250,126,242,63,69,216,4,64,57,69,15,64,138,176,25,64,18,131,36,64,62,121,48,64,246,40,60,64,27,47,221,61,159,60,108,62,206,136,210,62,177,80,27,63,143,194,69,63,238,90,114,63,176,114,144,63,37,6,169,63,84,116,196,63,44,101,225,63,144,49,255,63,234,4,12,64,99,238,22,64,199,75,35,64,215,18,46,64,226,233,57,64,190,193,23,62,174,182,162,62,45,33,255,62,238,90,34,63,171,62,71,63,145,237,124,63,220,215,153,63,58,146,171,63,186,218,194,63,136,99,221,63,155,230,245,63,3,9,6,64,60,189,18,64,27,13,32,64,159,171,45,64,154,8,59,64], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+697704);
/* memory initializer */ allocate([250,126,234,61,244,253,148,62,81,107,250,62,249,49,38,63,142,6,80,63,207,247,115,63,160,26,143,63,78,98,168,63,242,176,192,63,251,58,216,63,62,232,241,63,107,154,7,64,138,176,21,64,220,70,35,64,159,205,46,64,154,8,59,64,165,78,192,61,31,244,44,62,102,102,166,62,116,70,20,63,157,17,69,63,8,172,108,63,175,37,148,63,213,120,177,63,116,70,204,63,9,27,230,63,116,181,253,63,122,199,9,64,82,73,21,64,188,116,35,64,214,86,48,64,224,190,58,64,0,145,254,61,109,86,125,62,140,219,200,62,196,177,30,63,222,113,74,63,55,26,112,63,95,41,147,63,146,203,175,63,25,115,199,63,219,249,222,63,101,25,250,63,47,221,8,64,106,188,20,64,214,197,33,64,88,202,46,64,60,189,58,64,112,206,72,62,201,229,191,62,111,129,4,63,216,129,35,63,92,32,81,63,9,27,134,63,236,47,155,63,240,133,177,63,48,187,199,63,225,122,220,63,137,65,240,63,87,91,5,64,170,241,18,64,193,168,32,64,176,114,44,64,128,183,56,64,166,155,4,62,52,17,118,62,198,109,212,62,59,112,30,63,163,146,74,63,94,186,105,63,76,166,138,63,113,172,163,63,63,53,190,63,154,8,219,63,39,160,249,63,144,160,8,64,51,196,17,64,130,226,31,64,243,142,47,64,216,240,60,64,111,18,131,60,116,70,20,61,192,236,30,60,17,199,186,59,52,128,183,186,215,52,239,187,153,187,150,187,23,183,209,187,20,63,70,188,108,9,249,58,33,31,116,60,88,57,52,189,202,50,68,189,154,119,28,189,166,155,68,189,43,24,149,188,150,67,139,60,17,199,58,60,33,31,244,188,41,92,143,188,208,68,88,187,151,255,16,189,96,229,80,189,10,215,35,187,145,126,251,60,5,197,15,61,222,113,10,61,49,8,44,61,101,25,98,60,41,92,143,188,231,29,39,188,159,171,173,59,39,160,9,60,82,73,157,185,85,193,40,61,124,242,48,187,104,145,109,60,36,151,127,187,185,252,7,60,10,215,35,61,23,183,209,56,98,161,214,188,88,57,180,59,75,89,6,188,114,138,14,61,87,91,49,61,247,117,96,60,82,73,29,187,88,57,180,187,98,161,214,60,207,102,85,61,77,243,14,61,80,141,151,60,108,9,249,59,147,169,2,189,29,201,101,189,127,106,60,189,242,65,207,188,192,236,30,188,148,135,133,60,153,187,150,60,179,123,114,187,166,155,68,189,43,246,23,189,73,157,128,61,39,49,136,61,179,123,242,60,17,199,186,187,242,65,207,60,90,245,185,60,41,92,15,61,187,184,141,61,100,59,95,61,234,149,178,60,117,2,26,60,16,233,55,189,7,95,24,189,111,18,3,58,134,90,211,60,202,84,65,60,213,120,233,60,227,165,155,61,121,88,168,61,245,219,87,61,216,240,244,188,46,144,160,187,150,67,139,60,119,190,159,60,137,210,94,60,140,74,234,60,177,191,236,60,211,188,99,60,124,242,176,59,108,9,121,60,130,226,199,60,52,128,55,59,52,128,183,187,244,253,212,188,145,126,251,60,140,74,106,61,114,138,14,188,224,45,16,60,95,41,203,59,0,0,0,0,205,204,76,60,0,0,0,0,215,52,239,188,158,239,167,61,234,149,178,61,1,77,132,61,187,184,13,61,108,9,249,59,224,45,16,187,242,65,207,188,66,62,104,189,117,2,154,188,39,160,9,189,149,212,137,189,211,222,96,189,185,252,135,188,61,44,212,188,66,96,101,188,111,18,131,59,237,13,62,187,197,32,48,189,99,127,89,189,242,65,207,188,108,9,249,186,30,167,232,187,9,249,32,61,250,237,235,59,111,240,5,189,202,84,193,188,18,131,192,188,151,255,144,188,7,95,152,188,66,96,229,188,193,168,164,188,72,80,252,187,118,224,28,61,122,54,43,61,74,123,3,61,69,216,240,60,222,113,138,60,91,177,63,61,70,148,246,60,62,232,89,60,79,175,20,61,134,90,83,61,201,229,191,61,182,243,253,61,5,197,15,62,20,174,7,62,32,65,241,61,95,152,204,61,132,158,205,60,179,123,114,187,131,192,74,189,114,249,143,189,161,103,179,188,171,207,213,188,108,9,249,188,231,29,167,188,7,95,24,189,115,104,17,61,98,161,86,60,7,95,24,188,156,51,34,188,101,25,226,187,137,210,94,187,244,253,212,187,195,100,170,188,54,60,189,188,91,177,63,188,232,217,172,188,203,16,199,188,153,187,150,59,14,79,47,188,66,96,229,187,240,133,73,60,127,106,188,60,108,9,121,60,75,89,134,60,85,193,40,61,219,138,125,61,233,183,175,61,160,137,176,61,52,128,183,187,205,204,76,60,43,24,149,60,150,33,14,61,192,236,30,61,17,199,58,61,11,181,38,61,22,251,203,188,127,106,60,189,85,193,168,60,216,240,244,60,242,65,207,60,12,147,169,60,151,255,144,60,56,248,194,60,242,65,207,60,166,155,68,59,39,160,137,59,111,18,3,59,221,181,4,188,137,210,94,188,104,145,237,188,39,160,137,187,130,226,71,60,231,29,167,59,14,79,47,60,17,199,186,60,232,217,172,60,137,210,222,187,234,149,50,189,216,240,244,188,36,151,255,187,9,138,159,189,31,244,236,189,40,15,139,189,4,231,140,60,143,194,117,60,231,29,167,187,221,181,4,60,23,183,81,189,72,80,124,189,250,237,107,61,156,162,163,61,84,116,164,61,39,160,9,61,23,183,209,56,33,31,244,188,80,252,152,189,127,106,60,188,120,122,37,188,150,67,139,188,10,215,163,187,114,138,142,60,104,145,237,188,107,43,118,189,143,194,117,188,20,63,70,60,2,43,135,60,127,106,188,60,52,128,55,59,220,215,1,189,2,43,135,188,78,209,17,61,199,186,56,61,166,155,68,60,74,123,3,61,39,160,9,60,237,13,190,187,130,226,71,60,221,36,70,62,89,134,56,62,156,196,96,62,180,200,118,62,229,97,97,62,147,24,68,62,127,106,60,62,221,36,70,62,120,156,98,62,189,227,84,62,91,66,62,62,58,35,74,62,11,70,101,62,228,131,94,62,127,106,60,62,135,22,89,62,145,126,251,62,24,149,244,62,223,224,235,62,37,6,225,62,120,156,226,62,101,170,224,62,101,25,226,62,201,118,222,62,108,9,217,62,72,191,221,62,194,134,231,62,37,117,226,62,184,30,229,62,73,157,224,62,20,174,231,62,156,162,227,62,185,252,135,61,0,0,64,62,246,40,220,62,186,73,44,63,206,25,97,63,39,49,136,63,112,206,160,63,14,190,184,63,220,215,209,63,30,167,232,63,131,47,0,64,94,75,12,64,94,75,24,64,94,75,36,64,166,155,48,64,200,7,61,64,62,232,89,62,96,118,207,62,43,246,7,63,65,241,35,63,154,153,73,63,215,163,96,63,154,119,140,63,165,189,169,63,215,52,199,63,121,233,214,63,60,189,234,63,227,165,7,64,122,165,20,64,99,127,29,64,76,55,41,64,196,66,57,64,242,65,79,62,104,34,172,62,52,128,247,62,159,171,45,63,30,167,104,63,72,225,138,63,163,1,156,63,38,228,179,63,9,27,206,63,232,106,227,63,38,228,251,63,190,48,9,64,74,12,22,64,34,253,34,64,172,139,47,64,227,165,59,64,106,222,241,61,158,94,105,62,19,242,225,62,182,132,28,63,66,96,69,63,202,84,113,63,27,158,142,63,76,166,162,63,27,158,190,63,192,236,222,63,204,238,249,63,229,97,9,64,193,57,23,64,23,217,34,64,218,172,46,64,121,233,58,64,68,139,236,61,150,67,139,62,199,41,250,62,32,99,46,63,163,1,92,63,207,102,133,63,203,161,157,63,79,175,180,63,185,141,206,63,240,167,230,63,4,231,252,63,187,39,11,64,132,13,23,64,156,162,35,64,32,210,47,64,93,254,59,64,248,83,227,61,12,147,169,62,152,110,242,62,206,170,15,63,157,128,54,63,160,137,80,63,127,251,130,63,78,98,168,63,193,202,201,63,24,38,227,63,21,140,250,63,249,15,9,64,166,155,20,64,37,117,34,64,7,240,46,64,156,162,59,64,12,147,41,62,31,133,171,62,217,206,215,62,36,151,15,63,200,7,45,63,67,173,89,63,231,251,145,63,56,103,180,63,148,135,205,63,217,206,215,63,122,199,225,63,202,50,0,64,233,38,17,64,133,124,32,64,179,123,46,64,136,244,59,64,79,30,22,62,254,67,186,62,186,218,234,62,32,65,17,63,31,244,60,63,41,237,93,63,20,63,118,63,239,56,149,63,211,188,187,63,100,59,223,63,238,124,247,63,228,131,6,64,63,87,19,64,100,204,33,64,252,24,47,64,57,69,59,64,245,74,217,61,19,97,131,62,5,163,242,62,91,211,44,63,105,0,95,63,222,2,137,63,229,208,162,63,129,149,187,63,68,139,212,63,36,185,236,63,35,219,1,64,145,15,14,64,181,166,25,64,57,214,37,64,165,189,49,64,25,226,60,64,138,142,228,61,215,18,114,62,177,80,203,62,138,176,33,63,140,185,91,63,186,73,132,63,175,148,149,63,254,67,170,63,103,213,199,63,91,211,228,63,171,207,253,63,255,33,13,64,176,3,23,64,170,241,34,64,127,251,46,64,188,116,59,64,66,62,136,62,189,82,214,62,193,57,3,63,171,207,37,63,165,189,97,63,66,96,141,63,111,129,164,63,161,214,180,63,143,228,202,63,190,48,225,63,165,78,248,63,171,62,11,64,222,147,23,64,211,222,32,64,50,85,44,64,117,2,58,64,135,22,25,62,177,191,140,62,183,209,224,62,229,97,33,63,28,235,82,63,26,81,130,63,55,137,153,63,126,29,176,63,46,144,200,63,115,215,226,63,239,201,251,63,201,118,10,64,77,243,22,64,19,97,35,64,227,165,47,64,36,151,59,64,17,199,186,61,33,31,52,62,173,250,156,62,96,229,16,63,145,237,76,63,216,240,116,63,25,115,151,63,181,166,185,63,126,29,208,63,2,188,229,63,36,185,0,64,20,208,12,64,183,98,23,64,48,187,35,64,224,190,50,64,211,77,62,64,21,140,10,62,122,165,140,62,41,203,208,62,222,2,25,63,120,11,68,63,12,147,105,63,57,214,141,63,201,118,174,63,51,51,203,63,13,113,228,63,155,85,247,63,243,142,7,64,32,65,21,64,94,75,32,64,161,248,45,64,61,10,59,64,130,115,70,62,142,6,208,62,18,20,255,62,181,166,25,63,212,43,69,63,181,55,104,63,118,224,148,63,94,186,177,63,180,89,205,63,16,233,231,63,231,29,247,63,23,183,5,64,0,111,17,64,99,127,29,64,17,54,40,64,50,85,56,64,36,40,62,62,58,146,171,62,165,78,224,62,131,47,28,63,197,143,65,63,12,2,91,63,75,234,132,63,188,150,168,63,160,137,200,63,7,95,216,63,101,170,224,63,234,4,252,63,237,158,16,64,252,169,33,64,114,138,46,64,190,193,59,64,170,96,212,61,228,20,93,62,244,108,214,62,237,13,30,63,45,178,77,63,227,165,131,63,118,224,156,63,221,36,182,63,133,235,209,63,136,133,234,63,238,235,0,64,36,185,12,64,78,98,24,64,100,93,36,64,36,185,48,64,56,103,60,64,102,102,38,62,150,33,142,62,236,81,216,62,39,160,25,63,208,179,73,63,144,160,104,63,184,64,138,63,177,80,163,63,11,181,190,63,155,85,223,63,93,220,254,63,248,83,11,64,195,211,23,64,9,249,36,64,176,3,51,64,13,113,60,64,153,42,88,62,53,94,186,62,120,122,21,63,190,159,58,63,9,27,78,63,94,75,128,63,203,161,157,63,200,7,181,63,8,61,203,63,150,67,227,63,191,125,253,63,83,150,9,64,97,50,21,64,113,61,34,64,36,185,48,64,237,158,60,64,23,183,17,62,167,121,135,62,97,195,211,62,92,143,34,63,141,151,78,63,243,142,115,63,77,243,142,63,92,32,169,63,204,238,201,63,44,212,226,63,7,95,248,63,84,227,9,64,252,169,21,64,118,224,32,64,155,85,47,64,163,35,61,64,103,213,231,61,143,83,116,62,215,18,210,62,103,213,23,63,130,226,71,63,31,244,124,63,80,141,151,63,115,104,177,63,157,17,205,63,162,69,230,63,105,0,255,63,98,16,12,64,30,167,24,64,188,150,36,64,96,229,48,64,47,221,60,64,165,189,1,62,239,56,133,62,121,88,200,62,153,42,24,63,65,130,66,63,3,120,107,63,46,255,137,63,131,192,162,63,195,211,195,63,53,239,224,63,116,36,247,63,73,157,8,64,167,232,20,64,125,174,34,64,75,200,47,64,227,165,59,64,187,39,79,62,77,243,174,62,211,222,224,62,168,53,29,63,59,112,62,63,22,251,91,63,95,7,142,63,180,89,173,63,53,94,194,63,223,224,211,63,52,162,228,63,178,46,2,64,44,101,17,64,7,240,30,64,142,117,45,64,24,149,60,64,65,241,227,61,145,237,124,62,45,67,188,62,197,143,17,63,184,30,69,63,123,131,111,63,26,81,138,63,183,98,159,63,242,210,189,63,210,0,222,63,98,161,246,63,80,252,8,64,12,147,21,64,228,20,33,64,213,231,46,64,67,173,57,64,195,100,42,62,253,246,181,62,54,171,14,63,242,65,63,63,8,172,108,63,63,198,140,63,113,172,163,63,129,149,187,63,212,43,213,63,44,212,234,63,70,37,1,64,78,209,13,64,227,54,26,64,237,13,38,64,35,219,49,64,244,253,60,64,130,115,6,62,102,102,134,62,42,58,242,62,102,247,36,63,178,157,79,63,118,224,124,63,67,28,147,63,21,29,169,63,5,52,201,63,153,42,232,63,134,56,254,63,105,111,12,64,5,197,23,64,255,178,35,64,176,3,47,64,145,126,59,64,143,228,242,61,90,100,155,62,32,65,1,63,178,157,47,63,182,243,93,63,41,92,127,63,142,117,145,63,198,109,172,63,96,229,200,63,164,223,222,63,249,160,247,63,110,163,9,64,220,215,21,64,254,101,35,64,177,225,49,64,224,156,61,64,28,235,226,61,30,22,138,62,43,24,245,62,10,104,34,63,108,120,74,63,207,102,117,63,152,110,146,63,216,240,172,63,227,199,200,63,245,74,225,63,75,89,246,63,65,241,7,64,64,19,21,64,250,126,34,64,229,208,46,64,48,187,59,64,94,186,201,61,140,185,107,62,235,115,181,62,47,110,19,63,111,18,67,63,203,16,119,63,95,41,147,63,139,108,167,63,102,102,198,63,127,106,228,63,149,212,249,63,252,24,11,64,229,208,22,64,137,65,36,64,8,172,48,64,184,64,58,64,254,101,247,61,86,159,139,62,165,78,224,62,115,215,18,63,173,250,60,63,180,200,86,63,60,78,129,63,247,228,161,63,174,71,193,63,100,59,223,63,138,31,251,63,233,38,9,64,48,42,21,64,129,4,33,64,86,125,46,64,77,243,58,64,46,255,33,62,178,46,142,62,184,30,229,62,162,180,39,63,250,237,91,63,64,19,129,63,101,25,146,63,243,31,170,63,172,139,203,63,61,44,228,63,129,38,250,63,27,158,10,64,242,176,20,64,23,72,32,64,78,98,44,64,164,223,58,64,150,67,11,62,252,24,147,62,131,192,234,62,233,38,33,63,238,90,66,63,172,173,104,63,48,76,134,63,127,251,162,63,59,1,197,63,47,110,227,63,43,246,247,63,111,129,8,64,116,70,20,64,147,24,32,64,130,226,43,64,138,142,56,64,235,115,181,61,35,74,59,62,54,60,189,62,91,211,28,63,180,89,85,63,94,186,129,63,120,122,157,63,195,211,187,63,118,79,214,63,132,158,237,63,90,100,3,64,2,43,15,64,16,88,25,64,108,9,37,64,110,163,49,64,71,3,60,64,223,79,77,62,43,24,181,62,215,163,240,62,114,249,31,63,86,14,61,63,25,226,104,63,228,131,150,63,227,199,176,63,234,4,196,63,242,210,213,63,136,99,237,63,152,221,7,64,157,17,21,64,61,155,33,64,235,226,50,64,2,188,61,64,150,178,76,62,155,85,159,62,51,196,241,62,7,240,54,63,120,11,100,63,192,91,128,63,210,111,151,63,90,245,177,63,102,102,206,63,224,45,224,63,45,67,244,63,185,252,7,64,53,239,20,64,107,43,34,64,176,114,44,64,64,19,57,64,0,145,254,61,93,109,133,62,192,91,224,62,143,194,21,63,125,63,69,63,222,2,121,63,9,138,143,63,187,39,167,63,88,202,194,63,251,203,222,63,31,244,244,63,193,168,8,64,50,119,21,64,226,233,33,64,5,163,46,64,3,9,58,64,134,201,212,61,34,108,120,62,53,94,218,62,211,222,32,63,242,176,80,63,86,125,126,63,181,166,153,63,184,175,179,63,113,172,203,63,204,93,227,63,31,133,251,63,42,58,10,64,205,59,22,64,138,31,35,64,74,123,47,64,42,169,59,64,113,172,11,62,217,206,119,62,148,246,198,62,79,30,22,63,61,44,68,63,10,104,98,63,12,2,139,63,99,127,169,63,98,161,198,63,200,7,229,63,142,6,0,64,46,255,9,64,95,41,23,64,106,77,35,64,97,50,49,64,39,194,58,64,245,219,23,62,161,248,145,62,38,83,229,62,83,150,33,63,186,218,74,63,232,106,123,63,242,210,149,63,63,87,171,63,205,204,196,63,40,126,220,63,223,224,243,63,168,87,6,64,21,140,18,64,255,178,31,64,205,204,44,64,206,136,58,64,251,203,110,62,240,133,233,62,81,107,10,63,247,6,31,63,73,157,64,63,211,77,82,63,97,195,115,63,104,145,149,63,202,195,194,63,35,74,219,63,243,31,234,63,11,36,4,64,139,253,17,64,181,21,31,64,32,65,45,64,254,101,59,64,3,9,10,62,27,13,160,62,24,149,4,63,126,29,56,63,17,54,108,63,71,114,145,63,32,65,169,63,118,224,188,63,177,80,211,63,69,216,232,63,130,226,255,63,122,165,12,64,20,208,24,64,75,234,36,64,117,147,48,64,6,18,60,64,174,216,223,61,10,104,98,62,152,221,243,62,200,152,43,63,234,4,84,63,33,31,116,63,183,98,143,63,188,150,176,63,180,89,205,63,251,203,230,63,127,217,253,63,254,67,10,64,50,230,22,64,120,122,37,64,195,245,48,64,96,118,59,64,219,249,62,62,127,251,154,62,250,126,234,62,163,1,44,63,61,10,87,63,179,12,129,63,50,85,152,63,220,104,176,63,2,188,197,63,197,32,216,63,60,78,249,63,161,214,8,64,155,230,17,64,36,185,32,64,168,198,47,64,230,63,60,64,174,71,33,62,229,242,159,62,95,7,238,62,165,78,32,63,100,59,79,63,100,93,124,63,235,115,149,63,9,27,174,63,208,68,200,63,179,12,225,63,113,61,250,63,196,177,10,64,29,56,23,64,150,178,36,64,135,22,49,64,238,235,60,64,105,111,240,61,178,46,142,62,224,190,238,62,243,31,34,63,92,32,81,63,147,58,129,63,197,32,152,63,217,61,177,63,69,71,202,63,167,232,224,63,98,16,248,63,124,242,8,64,127,217,21,64,212,154,34,64,160,26,47,64,0,0,60,64,26,192,219,61,103,213,103,62,179,12,209,62,167,232,24,63,155,85,63,63,243,142,115,63,103,68,145,63,174,182,170,63,219,138,197,63,237,13,222,63,98,16,248,63,190,48,9,64,188,5,22,64,159,205,34,64,140,185,47,64,27,13,60,64,153,187,22,62,188,116,147,62,207,102,245,62,247,117,32,63,27,47,77,63,112,206,128,63,182,243,149,63,169,164,174,63,82,184,198,63,23,217,222,63,157,128,246,63,81,218,7,64,209,145,20,64,31,244,32,64,72,191,45,64,186,218,58,64,41,203,16,62,248,83,131,62,54,171,222,62,13,113,28,63,244,253,68,63,252,24,115,63,123,131,143,63,193,202,169,63,88,202,194,63,116,70,220,63,90,100,243,63,67,173,5,64,17,54,20,64,40,126,32,64,140,74,46,64,94,75,60,64,110,52,0,62,231,140,136,62,120,11,228,62,52,162,36,63,48,76,86,63,83,150,129,63,12,2,155,63,125,63,181,63,59,223,207,63,99,127,233,63,1,77,0,64,52,162,12,64,9,249,24,64,173,250,36,64,118,224,48,64,172,173,60,64,57,69,7,62,248,83,131,62,75,234,196,62,230,174,21,63,46,255,65,63,200,7,109,63,82,39,136,63,193,168,156,63,49,8,188,63,95,7,222,63,205,204,252,63,120,11,12,64,190,193,23,64,242,65,35,64,141,151,46,64,47,221,56,64,24,38,19,62,25,4,150,62,174,182,226,62,246,151,29,63,182,243,77,63,153,187,118,63,92,143,146,63,153,42,168,63,220,215,193,63,221,36,222,63,5,52,249,63,78,209,9,64,127,217,21,64,143,228,34,64,40,15,47,64,211,188,59,64,196,66,45,62,242,210,141,62,175,37,196,62,246,40,28,63,236,81,72,63,150,33,110,63,254,212,136,63,190,193,159,63,111,18,187,63,247,6,215,63,223,79,245,63,45,33,11,64,231,251,21,64,205,59,34,64,197,32,48,64,169,164,58,64,145,237,252,61,164,223,126,62,192,236,222,62,124,97,34,63,115,215,82,63,69,216,128,63,34,108,152,63,154,119,172,63,149,101,200,63,133,235,233,63,207,247,3,64,165,78,16,64,201,118,26,64,220,215,37,64,189,227,48,64,211,188,59,64,100,59,223,61,112,206,72,62,38,83,197,62,19,242,17,63,125,208,51,63,124,97,98,63,149,212,145,63,176,114,176,63,49,8,204,63,54,205,227,63,140,219,248,63,209,34,11,64,193,168,24,64,124,242,36,64,235,115,49,64,202,50,60,64,119,190,31,62,188,5,178,62,23,72,0,63,124,242,32,63,1,222,66,63,109,86,125,63,248,83,147,63,168,198,171,63,104,145,197,63,171,62,215,63,190,193,239,63,153,42,4,64,36,185,16,64,93,254,31,64,9,249,44,64,22,106,57,64,207,102,21,62,254,101,119,62,230,63,196,62,31,133,11,63,76,166,74,63,218,27,108,63,62,121,136,63,151,255,152,63,58,146,179,63,79,175,212,63,199,75,247,63,109,86,9,64,159,171,21,64,182,132,32,64,123,131,43,64,23,217,58,64,118,79,30,62,38,83,197,62,118,79,30,63,117,147,88,63,206,170,135,63,18,20,159,63,46,255,177,63,61,10,199,63,0,145,222,63,250,126,242,63,69,216,4,64,57,69,15,64,138,176,25,64,18,131,36,64,62,121,48,64,246,40,60,64,27,47,221,61,159,60,108,62,206,136,210,62,177,80,27,63,143,194,69,63,238,90,114,63,176,114,144,63,37,6,169,63,84,116,196,63,44,101,225,63,144,49,255,63,234,4,12,64,99,238,22,64,199,75,35,64,215,18,46,64,226,233,57,64,190,193,23,62,174,182,162,62,45,33,255,62,238,90,34,63,171,62,71,63,145,237,124,63,220,215,153,63,58,146,171,63,186,218,194,63,136,99,221,63,155,230,245,63,3,9,6,64,60,189,18,64,27,13,32,64,159,171,45,64,154,8,59,64,250,126,234,61,244,253,148,62,81,107,250,62,249,49,38,63,142,6,80,63,207,247,115,63,160,26,143,63,78,98,168,63,242,176,192,63,251,58,216,63,62,232,241,63,107,154,7,64,138,176,21,64,220,70,35,64,159,205,46,64,154,8,59,64,165,78,192,61,31,244,44,62,102,102,166,62,116,70,20,63,157,17,69,63,8,172,108,63,175,37,148,63,213,120,177,63,116,70,204,63,9,27,230,63,116,181,253,63,122,199,9,64,82,73,21,64,188,116,35,64,214,86,48,64,224,190,58,64,0,145,254,61,109,86,125,62,140,219,200,62,196,177,30,63,222,113,74,63,55,26,112,63,95,41,147,63,146,203,175,63,25,115,199,63,219,249,222,63,101,25,250,63,47,221,8,64,106,188,20,64,214,197,33,64,88,202,46,64,60,189,58,64,112,206,72,62,201,229,191,62,111,129,4,63,216,129,35,63,92,32,81,63,9,27,134,63,236,47,155,63,240,133,177,63,48,187,199,63,225,122,220,63,137,65,240,63,87,91,5,64,170,241,18,64,193,168,32,64,176,114,44,64,128,183,56,64,166,155,4,62,52,17,118,62,198,109,212,62,59,112,30,63,163,146,74,63,94,186,105,63,76,166,138,63,113,172,163,63,63,53,190,63,154,8,219,63,39,160,249,63,144,160,8,64,51,196,17,64,130,226,31,64,243,142,47,64,216,240,60,64,111,18,131,60,116,70,20,61,192,236,30,60,17,199,186,59,52,128,183,186,215,52,239,187,153,187,150,187,23,183,209,187,20,63,70,188,108,9,249,58,33,31,116,60,88,57,52,189,202,50,68,189,154,119,28,189,166,155,68,189,43,24,149,188,150,67,139,60,17,199,58,60,33,31,244,188,41,92,143,188,208,68,88,187,151,255,16,189,96,229,80,189,10,215,35,187,145,126,251,60,5,197,15,61,222,113,10,61,49,8,44,61,101,25,98,60,41,92,143,188,231,29,39,188,159,171,173,59,39,160,9,60,82,73,157,185,85,193,40,61,124,242,48,187,104,145,109,60,36,151,127,187,185,252,7,60,10,215,35,61,23,183,209,56,98,161,214,188,88,57,180,59,75,89,6,188,114,138,14,61,87,91,49,61,247,117,96,60,82,73,29,187,88,57,180,187,98,161,214,60,207,102,85,61,77,243,14,61,80,141,151,60,108,9,249,59,147,169,2,189,29,201,101,189,127,106,60,189,242,65,207,188,192,236,30,188,148,135,133,60,153,187,150,60,179,123,114,187,166,155,68,189,43,246,23,189,73,157,128,61,39,49,136,61,179,123,242,60,17,199,186,187,242,65,207,60,90,245,185,60,41,92,15,61,187,184,141,61,100,59,95,61,234,149,178,60,117,2,26,60,16,233,55,189,7,95,24,189,111,18,3,58,134,90,211,60,202,84,65,60,213,120,233,60,227,165,155,61,121,88,168,61,245,219,87,61,216,240,244,188,46,144,160,187,150,67,139,60,119,190,159,60,137,210,94,60,140,74,234,60,177,191,236,60,211,188,99,60,124,242,176,59,108,9,121,60,130,226,199,60,52,128,55,59,52,128,183,187,244,253,212,188,145,126,251,60,140,74,106,61,114,138,14,188,224,45,16,60,95,41,203,59,0,0,0,0,205,204,76,60,0,0,0,0,215,52,239,188,158,239,167,61,234,149,178,61,1,77,132,61,187,184,13,61,108,9,249,59,224,45,16,187,242,65,207,188,66,62,104,189,117,2,154,188,39,160,9,189,149,212,137,189,211,222,96,189,185,252,135,188,61,44,212,188,66,96,101,188,111,18,131,59,237,13,62,187,197,32,48,189,99,127,89,189,242,65,207,188,108,9,249,186,30,167,232,187,9,249,32,61,250,237,235,59,111,240,5,189,202,84,193,188,18,131,192,188,151,255,144,188,7,95,152,188,66,96,229,188,193,168,164,188,72,80,252,187,118,224,28,61,122,54,43,61,74,123,3,61,69,216,240,60,222,113,138,60,91,177,63,61,70,148,246,60,62,232,89,60,79,175,20,61,134,90,83,61,201,229,191,61,182,243,253,61,5,197,15,62,20,174,7,62,32,65,241,61,95,152,204,61,132,158,205,60,179,123,114,187,131,192,74,189,114,249,143,189,161,103,179,188,171,207,213,188,108,9,249,188,231,29,167,188,7,95,24,189,115,104,17,61,98,161,86,60,7,95,24,188,156,51,34,188,101,25,226,187,137,210,94,187,244,253,212,187,195,100,170,188,54,60,189,188,91,177,63,188,232,217,172,188,203,16,199,188,153,187,150,59,14,79,47,188,66,96,229,187,240,133,73,60,127,106,188,60,108,9,121,60,75,89,134,60,85,193,40,61,219,138,125,61,233,183,175,61,160,137,176,61,52,128,183,187,205,204,76,60,43,24,149,60,150,33,14,61,192,236,30,61,17,199,58,61,11,181,38,61,22,251,203,188,127,106,60,189,85,193,168,60,216,240,244,60,242,65,207,60,12,147,169,60,151,255,144,60,56,248,194,60,242,65,207,60,166,155,68,59,39,160,137,59,111,18,3,59,221,181,4,188,137,210,94,188,104,145,237,188,39,160,137,187,130,226,71,60,231,29,167,59,14,79,47,60,17,199,186,60,232,217,172,60,137,210,222,187,234,149,50,189,216,240,244,188,36,151,255,187,9,138,159,189,31,244,236,189,40,15,139,189,4,231,140,60,143,194,117,60,231,29,167,187,221,181,4,60,23,183,81,189,72,80,124,189,250,237,107,61,156,162,163,61,84,116,164,61,39,160,9,61,23,183,209,56,33,31,244,188,80,252,152,189,127,106,60,188,120,122,37,188,150,67,139,188,10,215,163,187,114,138,142,60,104,145,237,188,107,43,118,189,143,194,117,188,20,63,70,60,2,43,135,60,127,106,188,60,52,128,55,59,220,215,1,189,2,43,135,188,78,209,17,61,199,186,56,61,166,155,68,60,74,123,3,61,39,160,9,60,237,13,190,187,130,226,71,60,221,36,70,62,89,134,56,62,156,196,96,62,180,200,118,62,229,97,97,62,147,24,68,62,127,106,60,62,221,36,70,62,120,156,98,62,189,227,84,62,91,66,62,62,58,35,74,62,11,70,101,62,228,131,94,62,127,106,60,62,135,22,89,62,145,126,251,62,24,149,244,62,223,224,235,62,37,6,225,62,120,156,226,62,101,170,224,62,101,25,226,62,201,118,222,62,108,9,217,62,72,191,221,62,194,134,231,62,37,117,226,62,184,30,229,62,73,157,224,62,20,174,231,62,156,162,227,62,181,166,57,62,66,62,200,62,60,78,33,63,113,27,77,63,199,186,128,63,243,31,154,63,54,171,182,63,211,222,216,63,121,88,248,63,89,23,11,64,206,136,22,64,250,237,31,64,158,94,37,64,125,208,43,64,140,219,48,64,174,71,57,64,20,63,6,62,56,248,162,62,114,138,238,62,183,98,15,63,222,113,42,63,149,101,72,63,254,212,128,63,17,199,162,63,53,94,194,63,111,240,221,63,231,251,249,63,117,2,14,64,250,237,23,64,65,241,31,64,150,178,44,64,8,61,59,64,212,154,38,62,112,95,231,62,106,222,33,63,216,129,51,63,167,232,72,63,213,231,122,63,2,43,151,63,217,61,169,63,82,73,197,63,27,13,232,63,194,134,247,63,119,45,5,64,29,90,20,64,168,53,33,64,239,56,45,64,189,227,60,64,61,10,23,62,163,146,122,62,135,22,217,62,92,32,17,63,240,133,73,63,81,218,123,63,155,85,151,63,183,209,176,63,24,149,196,63,199,75,215,63,46,144,240,63,228,20,9,64,222,113,26,64,231,29,39,64,98,161,50,64,211,222,60,64,218,172,250,61,79,64,147,62,50,85,0,63,229,208,50,63,38,228,99,63,102,136,139,63,186,73,164,63,200,7,189,63,198,109,212,63,82,73,237,63,34,253,2,64,224,190,14,64,195,100,26,64,95,7,38,64,50,119,49,64,151,255,60,64,69,71,50,62,63,87,155,62,96,118,239,62,157,128,22,63,7,206,57,63,34,253,118,63,58,35,146,63,76,55,169,63,108,9,193,63,102,136,219,63,226,233,245,63,251,58,8,64,253,135,20,64,107,154,31,64,199,75,43,64,4,231,56,64,67,173,41,62,65,130,162,62,8,61,251,62,16,233,39,63,29,90,84,63,79,64,131,63,65,130,154,63,252,169,177,63,0,111,201,63,127,106,228,63,172,139,243,63,35,74,7,64,103,68,21,64,59,1,33,64,1,222,46,64,45,178,57,64,83,5,35,62,168,53,141,62,129,38,226,62,252,169,33,63,19,97,83,63,177,191,124,63,121,88,144,63,88,57,164,63,123,131,183,63,254,212,208,63,62,232,241,63,172,173,8,64,93,220,22,64,120,11,36,64,146,203,47,64,186,73,60,64,191,14,28,62,164,112,221,62,103,213,23,63,33,31,52,63,129,4,69,63,198,109,100,63,91,66,150,63,43,24,189,63,95,152,212,63,196,66,229,63,140,185,251,63,237,158,12,64,142,6,24,64,186,73,32,64,189,82,42,64,69,216,56,64,172,28,90,62,254,67,154,62,228,131,190,62,90,245,217,62,188,5,2,63,129,149,51,63,150,67,123,63,242,176,160,63,145,126,187,63,48,42,217,63,102,247,244,63,72,225,6,64,54,60,21,64,106,222,33,64,255,178,47,64,32,210,59,64,177,225,233,61,201,229,191,62,23,217,30,63,156,162,67,63,201,229,79,63,148,246,102,63,22,251,123,63,65,241,147,63,119,45,185,63,105,0,223,63,21,140,250,63,50,85,8,64,149,101,24,64,72,191,37,64,115,104,49,64,202,84,61,64,18,131,0,62,123,131,111,62,180,200,182,62,208,68,8,63,192,236,62,63,213,9,128,63,150,33,150,63,88,168,173,63,17,199,194,63,60,78,217,63,42,58,242,63,95,7,6,64,197,32,20,64,120,156,34,64,214,86,48,64,190,193,59,64,39,194,6,62,195,100,106,62,219,138,221,62,163,146,42,63,149,212,89,63,174,216,127,63,187,184,149,63,242,176,176,63,146,203,199,63,192,91,216,63,187,184,237,63,136,133,6,64,200,152,23,64,179,12,37,64,66,96,49,64,237,158,60,64,7,206,25,62,238,90,130,62,66,207,198,62,89,134,8,63,234,149,50,63,163,146,106,63,116,181,141,63,40,15,171,63,66,96,197,63,236,81,224,63,206,136,242,63,158,94,5,64,166,10,18,64,51,196,29,64,0,0,44,64,77,132,57,64,138,31,35,62,26,81,154,62,58,35,234,62,147,169,34,63,183,209,80,63,12,2,123,63,137,210,150,63,43,246,175,63,172,173,200,63,214,197,221,63,93,220,246,63,117,147,8,64,183,209,20,64,193,202,33,64,182,243,45,64,216,129,59,64,71,114,57,62,129,38,162,62,4,86,238,62,70,148,38,63,106,222,81,63,195,245,128,63,181,55,152,63,16,233,175,63,213,231,194,63,131,192,218,63,103,68,241,63,85,193,4,64,154,153,17,64,121,233,30,64,104,34,44,64,152,76,57,64,200,7,61,62,116,36,183,62,98,16,8,63,190,159,58,63,213,231,106,63,59,1,141,63,161,248,161,63,133,235,185,63,254,212,208,63,149,212,233,63,240,133,1,64,170,96,12,64,85,193,24,64,183,209,36,64,48,42,49,64,2,154,60,64,161,103,179,61,134,90,19,62,23,183,81,62,181,21,187,62,41,203,32,63,5,163,98,63,15,156,139,63,48,76,166,63,213,231,194,63,217,95,222,63,137,65,248,63,228,20,9,64,189,82,22,64,67,28,35,64,75,200,47,64,195,211,59,64,59,112,14,62,6,129,213,62,43,246,39,63,200,152,75,63,36,151,95,63,64,164,127,63,158,239,151,63,35,219,185,63,109,86,205,63,125,63,229,63,47,221,0,64,207,247,11,64,191,125,21,64,34,108,32,64,232,106,47,64,70,182,63,64,193,168,164,61,131,192,10,62,157,17,133,62,201,229,255,62,18,165,61,63,206,136,114,63,50,85,144,63,223,224,171,63,231,29,199,63,174,182,226,63,175,37,252,63,242,210,9,64,111,18,23,64,216,129,35,64,250,237,47,64,20,174,59,64,148,135,5,62,237,13,158,62,192,236,254,62,231,140,40,63,254,101,87,63,17,54,132,63,36,185,156,63,132,158,181,63,118,79,206,63,195,245,232,63,217,206,255,63,126,29,12,64,86,14,25,64,228,20,37,64,216,240,48,64,54,205,59,64,74,12,66,62,106,222,145,62,45,178,189,62,79,64,211,62,78,98,32,63,255,178,107,63,11,181,150,63,82,39,176,63,138,176,201,63,28,235,226,63,108,120,250,63,5,163,10,64,209,34,23,64,20,174,35,64,241,99,48,64,45,67,60,64,236,81,56,62,246,151,157,62,25,4,246,62,68,250,45,63,67,173,89,63,188,150,128,63,100,204,149,63,220,215,169,63,205,59,190,63,193,57,211,63,17,54,236,63,83,150,5,64,236,81,20,64,69,71,34,64,55,26,48,64,2,154,60,64,20,174,71,62,148,135,165,62,177,225,233,62,98,16,24,63,69,71,66,63,210,111,127,63,214,197,149,63,106,77,171,63,181,55,192,63,49,8,212,63,170,130,233,63,59,223,3,64,159,205,18,64,216,240,32,64,74,123,47,64,104,34,60,64,83,150,129,62,183,209,224,62,88,57,20,63,80,141,55,63,75,89,102,63,211,77,146,63,29,201,173,63,61,44,196,63,151,255,208,63,39,160,225,63,40,126,252,63,220,70,11,64,159,205,22,64,40,15,35,64,150,67,47,64,95,7,58,64,254,212,56,62,224,190,142,62,245,219,183,62,11,181,198,62,35,74,11,63,63,53,78,63,7,206,137,63,18,131,168,63,120,11,196,63,55,26,224,63,60,78,249,63,41,203,8,64,210,0,22,64,252,24,35,64,163,1,48,64,88,57,60,64,60,78,81,62,136,244,187,62,58,35,10,63,116,70,52,63,255,178,91,63,113,172,123,63,11,36,144,63,25,226,168,63,15,11,189,63,202,84,217,63,222,147,239,63,148,246,2,64,156,196,16,64,97,84,30,64,70,37,45,64,99,238,58,64,98,161,214,61,82,184,94,62,226,88,215,62,249,160,23,63,151,144,63,63,215,163,112,63,87,91,145,63,144,160,176,63,45,67,204,63,45,178,221,63,197,254,242,63,94,75,8,64,105,0,23,64,24,38,35,64,220,70,47,64,80,141,59,64,13,113,172,61,179,12,49,62,140,74,202,62,15,11,37,63,173,105,94,63,119,190,135,63,64,164,159,63,139,108,183,63,5,197,207,63,66,62,232,63,229,97,1,64,137,65,12,64,183,209,24,64,25,226,36,64,27,47,49,64,209,145,60,64,61,155,21,62,248,194,132,62,14,45,210,62,202,84,17,63,200,152,59,63,143,83,100,63,249,49,134,63,50,119,157,63,11,36,184,63,145,237,212,63,12,147,241,63,185,141,6,64,65,241,19,64,23,183,33,64,21,140,46,64,84,82,59,64,62,232,25,62,45,33,159,62,216,129,243,62,72,80,44,63,246,40,92,63,127,251,130,63,111,18,155,63,44,212,178,63,70,182,203,63,129,4,229,63,78,209,249,63,91,66,10,64,26,81,22,64,170,241,34,64,109,197,46,64,83,150,57,64,191,125,93,62,81,218,187,62,51,51,3,63,26,192,43,63,247,117,80,63,63,53,126,63,229,208,154,63,242,210,181,63,132,13,207,63,154,8,219,63,145,126,235,63,2,188,5,64,179,123,22,64,35,219,33,64,54,171,42,64,16,88,57,64,81,107,90,62,192,91,224,62,124,242,32,63,109,197,94,63,41,237,141,63,185,252,175,63,246,151,205,63,14,79,223,63,147,169,234,63,248,194,244,63,40,15,251,63,23,72,4,64,25,115,11,64,215,18,22,64,169,164,38,64,52,162,56,64,156,162,35,62,122,54,139,62,157,128,198,62,43,135,246,62,162,180,23,63,80,141,71,63,72,191,133,63,219,249,166,63,33,176,194,63,212,154,222,63,21,29,249,63,216,240,8,64,60,189,22,64,99,238,34,64,137,65,48,64,218,27,60,64,207,102,149,62,9,138,15,63,9,27,46,63,219,138,61,63,147,24,84,63,0,111,113,63,17,54,148,63,88,57,180,63,179,12,209,63,13,113,236,63,122,165,252,63,53,239,4,64,250,126,18,64,163,35,33,64,227,165,47,64,121,233,62,64,195,100,42,62,170,130,145,62,12,2,203,62,81,218,11,63,124,242,80,63,198,109,132,63,206,170,151,63,218,27,172,63,197,143,193,63,112,206,224,63,238,124,255,63,20,208,12,64,94,75,24,64,220,104,36,64,87,91,49,64,184,30,61,64,163,146,186,61,235,115,117,62,202,84,1,63,186,107,73,63,195,211,131,63,227,199,144,63,36,185,156,63,147,169,170,63,137,65,184,63,121,233,214,63,87,236,247,63,34,253,10,64,15,156,23,64,118,113,35,64,219,249,46,64,184,175,59,64,30,167,40,62,52,17,150,62,56,103,196,62,164,223,254,62,197,32,32,63,237,158,108,63,163,35,145,63,173,105,166,63,118,113,195,63,43,135,230,63,29,90,252,63,228,20,9,64,181,55,24,64,29,56,35,64,105,0,43,64,207,247,55,64,35,219,121,62,147,169,194,62,216,129,243,62,245,74,41,63,232,217,92,63,211,188,131,63,38,83,157,63,207,247,179,63,206,136,194,63,150,33,222,63,97,195,243,63,201,118,6,64,11,36,20,64,114,249,31,64,247,228,45,64,198,220,57,64,229,208,34,62,79,64,147,62,30,22,234,62,99,127,25,63,235,115,69,63,170,241,114,63,139,108,143,63,49,8,164,63,7,206,185,63,94,186,209,63,242,176,232,63,192,236,2,64,88,168,17,64,190,159,30,64,16,233,43,64,172,28,58,64,122,54,107,62,237,158,220,62,42,58,18,63,136,244,43,63,50,85,80,63,41,237,133,63,201,229,159,63,53,94,186,63,34,253,214,63,45,67,236,63,232,106,251,63,245,74,9,64,57,69,23,64,43,135,34,64,233,183,47,64,156,196,60,64,236,81,152,62,123,131,239,62,146,203,255,62,221,181,20,63,14,190,32,63,251,58,48,63,72,80,92,63,165,189,145,63,62,121,184,63,71,3,216,63,197,32,240,63,253,246,5,64,214,86,20,64,249,15,33,64,12,2,47,64,90,100,59,64,1,222,2,62,155,85,191,62,208,179,25,63,102,247,52,63,46,144,80,63,211,77,130,63,108,9,161,63,41,203,176,63,221,36,190,63,200,7,221,63,178,157,255,63,27,13,8,64,88,202,18,64,40,126,36,64,56,103,48,64,191,125,57,64,185,141,6,62,220,104,128,62,177,191,204,62,115,104,17,63,237,13,62,63,146,203,111,63,247,117,144,63,215,163,168,63,1,77,196,63,109,197,222,63,242,65,247,63,80,252,8,64,86,125,22,64,200,152,35,64,98,16,48,64,61,44,60,64,61,155,213,61,124,97,114,62,54,205,219,62,193,57,35,63,96,229,80,63,54,205,123,63,109,197,150,63,174,71,177,63,33,176,202,63,205,204,228,63,244,253,252,63,249,49,10,64,183,98,23,64,91,177,35,64,168,198,47,64,175,37,60,64,209,145,28,62,156,196,128,62,69,216,176,62,229,242,223,62,74,123,51,63,180,200,102,63,240,133,137,63,168,53,173,63,124,242,200,63,117,147,224,63,104,34,0,64,191,14,8,64,70,148,14,64,43,24,29,64,86,125,46,64,236,81,60,64,97,84,18,62,5,197,143,62,37,6,225,62,129,38,34,63,0,145,78,63,176,114,120,63,188,116,147,63,154,153,169,63,44,101,193,63,125,63,221,63,190,193,247,63,207,102,9,64,254,67,22,64,172,139,35,64,169,19,48,64,195,211,59,64,102,102,38,62,245,185,154,62,216,129,243,62,252,169,33,63,132,158,77,63,237,13,126,63,198,109,148,63,222,2,169,63,87,236,191,63,242,176,216,63,190,159,242,63,219,249,6,64,41,92,19,64,126,29,32,64,17,54,44,64,213,120,57,64,196,66,45,62,96,118,175,62,57,214,5,63,185,141,70,63,71,3,120,63,246,40,140,63,231,29,167,63,217,206,183,63,215,163,200,63,247,6,231,63,71,3,248,63,204,93,7,64,7,206,21,64,169,19,32,64,95,7,46,64,79,64,59,64,129,38,66,61,55,26,0,62,185,141,70,62,193,168,196,62,244,108,38,63,72,80,108,63,39,194,142,63,213,120,169,63,79,30,198,63,103,68,225,63,102,136,251,63,252,169,9,64,248,83,23,64,102,136,35,64,208,68,48,64,126,29,60,64,211,222,96,62,32,99,238,62,146,203,63,63,210,0,126,63,120,122,149,63,245,219,159,63,103,213,167,63,66,207,174,63,237,13,182,63,152,221,195,63,72,80,220,63,229,242,255,63,175,37,16,64,105,0,31,64,200,7,45,64,43,135,58,64,176,3,231,61,179,123,114,62,18,165,189,62,131,47,12,63,116,181,69,63,73,46,127,63,57,180,152,63,252,24,179,63,102,247,204,63,127,217,229,63,0,145,254,63,130,226,11,64,225,122,24,64,18,131,36,64,14,190,48,64,170,96,60,64,131,81,9,62,187,184,141,62,121,233,230,62,88,202,34,63,152,76,85,63,186,73,132,63,181,166,153,63,234,149,178,63,236,192,201,63,26,81,226,63,203,161,253,63,160,26,11,64,161,103,23,64,102,136,35,64,240,22,48,64,134,201,60,64,183,98,255,61,83,5,131,62,234,4,180,62,161,248,241,62,64,164,47,63,202,195,114,63,162,180,151,63,229,97,177,63,143,228,202,63,49,8,228,63,141,40,253,63,231,29,11,64,152,221,23,64,230,63,36,64,156,196,48,64,121,88,60,64,58,146,75,62,231,251,169,62,24,149,244,62,154,119,44,63,20,174,87,63,90,100,131,63,230,174,149,63,180,200,174,63,41,237,197,63,248,83,219,63,197,32,248,63,92,143,10,64,234,149,22,64,75,89,34,64,186,73,48,64,16,88,61,64], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+707944);
/* memory initializer */ allocate([4,231,12,62,221,36,134,62,17,199,218,62,41,237,29,63,43,135,70,63,138,176,113,63,148,246,142,63,220,104,168,63,140,74,194,63,35,219,217,63,26,81,242,63,17,199,6,64,179,234,19,64,211,222,32,64,177,225,45,64,1,222,58,64,208,68,88,62,18,131,224,62,250,237,27,63,83,5,67,63,138,142,116,63,26,192,147,63,147,24,172,63,157,17,197,63,243,142,219,63,88,168,245,63,77,21,8,64,197,254,22,64,150,33,38,64,94,75,52,64,33,31,60,64,27,158,66,64,204,238,9,62,7,240,86,62,167,121,135,62,41,203,176,62,66,207,6,63,71,114,73,63,0,145,134,63,168,198,163,63,201,118,190,63,179,234,219,63,148,246,246,63,89,134,8,64,77,132,21,64,44,212,34,64,58,146,47,64,179,234,59,64,183,209,160,62,158,239,23,63,105,111,64,63,20,208,84,63,63,87,91,63,244,253,116,63,51,51,131,63,236,81,144,63,54,205,171,63,172,173,208,63,29,201,237,63,18,131,4,64,192,236,18,64,166,155,32,64,146,92,46,64,220,70,59,64,129,4,197,61,172,173,88,62,159,205,202,62,220,104,16,63,189,82,54,63,161,103,99,63,43,24,141,63,138,142,172,63,114,249,199,63,242,176,224,63,67,28,251,63,82,184,10,64,233,183,23,64,243,142,35,64,80,141,47,64,190,193,59,64,16,233,183,61,190,159,26,62,8,172,156,62,244,253,20,63,37,117,82,63,102,247,132,63,216,240,156,63,50,230,182,63,191,125,205,63,233,183,231,63,171,62,255,63,54,205,11,64,229,242,23,64,231,140,36,64,69,216,48,64,52,162,60,64,75,200,7,62,141,40,109,62,46,144,192,62,253,135,4,63,132,158,45,63,23,72,96,63,131,47,140,63,215,163,168,63,151,255,192,63,3,9,218,63,81,218,243,63,207,247,7,64,226,233,21,64,252,24,35,64,64,164,47,64,240,22,60,64,14,45,50,62,2,154,168,62,84,116,4,63,196,177,46,63,235,226,86,63,248,194,132,63,85,48,154,63,135,167,175,63,149,101,200,63,128,72,223,63,140,219,248,63,211,222,8,64,240,22,20,64,119,190,31,64,32,65,45,64,52,128,59,64,250,237,107,62,174,71,193,62,135,22,249,62,91,66,30,63,85,193,72,63,140,185,107,63,153,187,142,63,241,99,164,63,161,103,187,63,71,114,217,63,13,224,245,63,98,16,8,64,103,213,19,64,50,119,33,64,25,115,47,64,204,93,59,64,117,2,26,60,171,207,213,60,179,123,114,187,75,89,134,59,153,187,22,188,224,45,144,187,237,13,190,188,215,52,239,187,117,2,154,187,39,160,9,187,205,204,204,60,104,145,109,189,66,96,101,188,77,21,12,189,142,6,112,189,111,18,3,59,16,233,55,61,182,243,125,60,134,56,86,189,138,142,228,188,216,240,244,60,226,233,149,188,153,187,150,189,1,222,130,189,137,210,222,186,39,160,9,61,122,54,171,60,153,187,150,59,72,80,252,59,179,123,114,188,17,199,58,188,166,155,68,188,127,106,60,60,10,215,163,187,162,69,54,61,82,73,157,59,117,2,154,60,247,117,96,188,111,18,3,188,239,201,195,60,153,187,150,188,98,161,86,189,119,190,159,188,59,112,78,188,30,167,232,60,0,111,129,61,176,3,103,60,7,95,24,188,82,73,29,188,46,144,160,60,127,106,188,60,8,61,27,61,72,80,252,60,129,38,194,60,52,128,183,188,143,194,117,189,190,159,154,189,136,244,219,189,168,87,202,189,181,55,120,189,24,149,212,189,192,236,30,190,80,141,23,190,39,160,137,189,59,112,78,61,222,113,138,61,39,160,9,61,39,160,137,187,152,76,149,61,96,118,207,61,51,196,177,61,196,66,173,61,19,97,195,61,170,241,82,61,208,68,216,187,233,72,174,189,240,167,70,189,69,216,240,60,193,202,33,61,114,138,14,60,36,151,255,59,125,174,54,61,198,109,180,61,39,160,137,61,82,73,29,189,10,215,35,187,231,251,41,61,188,150,16,61,111,18,3,60,195,100,170,59,227,165,155,60,43,24,149,60,101,25,226,59,39,160,137,60,190,48,25,61,179,123,114,59,215,52,239,188,233,183,47,189,254,101,247,60,3,120,139,61,164,223,190,188,56,248,194,188,82,73,157,185,4,231,140,187,124,242,176,59,237,13,62,187,33,31,116,188,74,123,131,61,109,197,126,61,113,172,11,61,237,13,190,188,91,211,60,189,75,89,6,188,55,26,64,189,255,33,125,189,148,135,5,189,163,35,57,189,75,234,132,189,253,135,116,189,83,5,35,189,184,64,2,189,237,13,62,188,224,45,144,58,250,237,107,58,82,73,29,189,82,73,29,189,36,151,127,188,244,253,212,188,52,128,55,186,165,189,65,61,198,220,53,60,5,163,18,189,20,63,70,189,231,29,167,188,237,13,62,187,188,116,19,188,213,120,233,188,131,192,74,189,117,2,26,189,54,205,187,61,33,31,244,61,243,31,210,61,117,147,152,61,120,156,34,61,18,165,61,61,242,65,207,60,10,215,35,59,201,118,62,61,10,215,35,60,130,226,71,61,195,100,42,61,125,174,182,60,25,115,215,60,250,237,235,59,159,171,173,187,70,182,115,61,166,155,196,59,61,44,84,189,0,111,1,189,4,231,140,187,62,232,89,188,164,223,190,188,143,194,245,187,132,158,205,188,28,235,226,60,172,139,219,187,137,210,94,188,23,183,209,185,18,131,192,60,52,128,55,60,43,24,149,188,221,181,4,189,49,8,172,188,66,96,101,187,193,202,33,189,82,73,29,189,111,18,3,58,143,194,117,188,78,209,17,189,169,19,80,60,208,68,88,187,137,210,94,187,158,239,167,60,80,252,152,61,249,15,233,61,59,223,207,61,168,198,203,61,38,228,131,188,188,116,147,187,134,90,83,60,202,84,65,61,31,133,107,61,198,220,181,60,43,24,21,60,179,123,114,59,238,235,64,189,43,246,23,61,208,68,88,60,195,100,170,60,168,87,202,60,91,177,63,60,75,89,134,60,236,81,184,60,95,41,75,60,153,187,22,187,224,45,16,60,153,187,150,187,117,2,154,59,9,249,32,189,250,237,235,58,179,123,114,60,111,18,3,59,224,45,144,59,2,43,135,60,200,152,187,60,195,100,170,188,19,97,67,189,182,243,253,188,75,89,134,188,119,190,31,189,154,119,156,189,61,10,87,189,117,2,26,188,143,194,245,59,231,29,39,188,188,116,147,187,59,112,78,189,5,52,145,189,121,88,168,61,115,104,145,61,86,125,46,61,52,128,183,58,43,246,23,189,10,215,35,189,73,157,128,188,182,243,125,188,187,184,141,188,101,25,98,188,166,155,196,186,172,139,91,60,122,54,43,189,113,172,139,189,23,183,209,188,10,215,163,59,188,116,19,61,151,255,16,61,179,123,242,59,156,51,34,189,18,131,192,188,30,167,232,60,168,87,74,61,218,172,122,60,52,128,55,61,10,215,35,59,130,226,199,187,59,112,206,60,205,204,204,61,139,108,103,62,173,250,92,62,172,173,88,62,64,19,97,62,152,110,82,62,98,16,88,62,146,203,63,62,220,70,67,62,6,18,84,62,246,151,93,62,187,184,77,62,115,215,82,62,99,127,89,62,8,61,91,62,189,82,86,62,51,51,179,61,167,232,200,61,179,12,241,61,63,87,219,61,243,142,211,61,36,151,255,61,98,161,214,61,219,138,253,61,251,203,238,61,59,112,206,61,99,127,217,61,95,41,203,61,58,146,203,61,136,133,218,61,95,152,204,61,252,24,243,61,154,153,153,61,120,156,162,61,12,147,169,61,50,230,174,61,87,236,175,61,120,11,164,61,16,122,182,61,18,20,191,61,130,115,198,61,127,106,188,61,90,100,187,61,160,137,176,61,51,196,177,61,16,122,182,61,13,113,172,61,85,193,168,61,0,0,128,61,201,118,190,61,121,233,166,61,196,177,174,61,16,233,183,61,12,147,169,61,121,88,168,61,53,94,186,61,88,202,178,61,126,140,185,61,14,79,175,61,49,8,172,61,228,131,158,61,156,196,160,61,77,21,140,61,224,156,145,61,204,238,169,62,71,3,216,62,213,231,234,62,115,104,209,62,170,130,209,62,77,132,205,62,88,168,181,62,113,172,171,62,127,217,189,62,86,159,171,62,201,118,190,62,70,37,181,62,206,25,209,62,200,152,219,62,59,223,207,62,80,141,215,62,69,216,112,61,122,54,171,60,75,89,6,188,127,106,60,188,40,126,12,189,146,92,126,189,246,151,93,189,187,184,13,189,187,184,13,189,226,233,21,189,88,57,180,188,135,22,217,188,231,29,39,188,190,48,25,61,218,172,250,60,120,122,37,61,218,172,250,60,188,116,19,60,124,242,176,187,149,101,8,61,117,2,154,59,56,248,194,60,176,3,103,60,2,43,135,60,218,172,250,60,49,8,44,61,184,64,130,60,95,41,75,60,12,147,41,61,0,111,129,60,129,38,194,188,176,3,103,60,8,172,156,61,17,199,186,59,244,253,212,188,86,125,46,189,193,202,33,189,59,112,78,188,141,40,109,189,159,205,42,189,233,183,47,189,109,231,123,189,235,226,182,189,255,33,125,189,82,73,29,189,172,139,91,188,237,13,190,188,56,248,194,188,247,228,225,61,2,188,197,62,91,177,47,63,66,62,88,63,72,80,108,63,63,87,131,63,114,249,143,63,250,237,179,63,177,191,212,63,43,135,230,63,242,65,239,63,111,129,4,64,4,86,22,64,180,200,38,64,230,63,48,64,235,115,57,64,238,90,2,62,16,122,118,62,165,44,195,62,208,179,25,63,208,213,70,63,110,52,112,63,5,52,145,63,143,228,170,63,127,251,194,63,31,244,220,63,48,42,249,63,45,33,11,64,53,94,22,64,108,9,33,64,127,217,45,64,143,228,58,64,242,210,77,62,250,126,170,62,29,201,229,62,6,129,37,63,68,250,77,63,141,40,125,63,99,238,146,63,111,240,165,63,86,14,189,63,138,142,212,63,204,127,240,63,90,100,7,64,108,9,21,64,11,70,33,64,71,114,45,64,146,92,58,64,215,52,239,61,9,249,96,62,130,226,167,62,224,45,240,62,247,117,32,63,193,57,83,63,137,210,134,63,60,189,162,63,72,80,188,63,185,141,214,63,108,9,241,63,45,33,7,64,8,172,20,64,155,230,33,64,209,34,47,64,248,83,59,64,59,223,15,62,73,46,159,62,128,72,255,62,220,104,48,63,200,7,93,63,96,118,135,63,5,52,161,63,206,170,183,63,5,197,207,63,130,226,231,63,180,200,254,63,78,98,12,64,72,80,24,64,202,50,36,64,200,7,49,64,221,181,60,64,32,99,46,62,182,132,156,62,0,111,225,62,143,194,5,63,112,206,24,63,178,157,79,63,202,84,137,63,233,38,169,63,168,53,197,63,16,122,222,63,60,78,249,63,131,192,10,64,77,243,22,64,179,234,35,64,254,212,48,64,88,57,60,64,176,3,231,61,185,141,134,62,222,147,231,62,162,69,38,63,60,78,81,63,35,74,123,63,75,89,150,63,238,124,175,63,57,69,199,63,251,58,224,63,197,143,249,63,245,74,9,64,22,106,21,64,86,125,34,64,231,29,47,64,35,74,59,64,217,61,57,62,94,75,168,62,125,63,5,63,90,245,57,63,95,7,110,63,222,147,143,63,25,4,166,63,169,164,190,63,185,252,215,63,221,181,236,63,184,175,3,64,171,62,15,64,134,56,26,64,147,169,38,64,247,228,49,64,240,22,60,64,55,26,128,62,206,25,241,62,105,111,48,63,88,168,85,63,26,192,107,63,242,210,133,63,11,181,158,63,181,21,187,63,245,185,210,63,150,67,235,63,61,10,3,64,63,87,15,64,35,219,29,64,133,235,41,64,82,73,49,64,145,237,56,64,244,253,212,61,178,157,111,62,241,244,202,62,170,241,18,63,39,194,70,63,86,125,126,63,154,153,153,63,19,97,179,63,113,27,205,63,52,17,230,63,29,56,255,63,160,137,12,64,17,54,24,64,66,62,36,64,36,185,48,64,150,178,60,64,239,201,67,62,187,184,173,62,115,215,242,62,224,156,33,63,141,40,77,63,4,231,124,63,119,190,151,63,156,51,178,63,172,173,200,63,152,76,221,63,54,171,246,63,188,116,7,64,5,197,19,64,76,166,34,64,206,170,47,64,84,82,59,64,203,161,197,61,41,92,79,62,68,250,173,62,238,124,255,62,170,130,49,63,23,72,112,63,221,36,150,63,110,52,176,63,188,5,202,63,86,159,227,63,223,79,253,63,233,183,11,64,238,124,23,64,255,178,35,64,4,231,48,64,4,231,60,64,208,179,89,62,127,251,186,62,182,243,13,63,80,141,55,63,237,13,94,63,39,49,136,63,14,190,160,63,22,251,179,63,58,146,203,63,178,157,231,63,145,237,252,63,203,161,9,64,174,182,22,64,20,174,35,64,124,242,44,64,20,208,56,64,181,21,59,62,68,105,175,62,163,146,250,62,194,23,38,63,168,198,75,63,147,24,116,63,222,147,143,63,125,208,163,63,222,113,186,63,49,153,210,63,148,246,230,63,208,68,0,64,193,57,15,64,170,130,29,64,93,220,42,64,229,97,57,64,23,72,80,62,184,175,195,62,226,233,5,63,14,45,50,63,31,133,107,63,15,11,133,63,79,175,148,63,23,72,176,63,118,79,198,63,242,210,221,63,3,120,251,63,38,228,7,64,109,86,21,64,118,79,34,64,87,91,45,64,166,155,60,64,61,10,215,61,170,241,82,62,45,178,189,62,126,140,25,63,93,109,85,63,183,98,135,63,85,193,160,63,183,98,183,63,64,19,209,63,18,131,232,63,79,30,254,63,212,43,13,64,210,0,26,64,54,60,37,64,205,204,48,64,253,135,60,64,60,78,17,62,123,131,207,62,250,126,42,63,33,31,100,63,27,47,133,63,54,205,147,63,169,19,160,63,184,64,178,63,46,144,200,63,121,88,224,63,77,21,252,63,70,37,13,64,189,227,24,64,85,193,36,64,231,140,48,64,174,182,58,64,154,8,27,62,215,163,144,62,237,158,220,62,97,195,19,63,100,59,63,63,149,101,120,63,174,182,146,63,222,113,170,63,218,27,196,63,75,234,220,63,66,207,246,63,55,26,8,64,223,224,19,64,220,104,32,64,147,58,45,64,156,51,58,64,251,92,45,62,83,150,161,62,236,192,249,62,35,219,41,63,215,18,82,63,102,247,116,63,109,197,142,63,29,56,167,63,44,101,193,63,136,244,219,63,191,125,245,63,98,161,6,64,230,174,17,64,23,217,30,64,62,121,44,64,162,69,58,64,5,163,18,62,95,41,139,62,163,35,217,62,59,112,14,63,110,163,49,63,125,174,102,63,230,63,148,63,206,136,178,63,231,29,207,63,11,181,230,63,132,158,253,63,209,34,11,64,58,35,22,64,28,235,34,64,65,241,47,64,151,144,59,64,213,231,106,62,120,122,197,62,160,26,15,63,118,79,62,63,8,61,107,63,120,11,140,63,111,18,163,63,108,9,185,63,18,20,207,63,189,82,230,63,234,4,252,63,136,133,10,64,92,143,22,64,201,118,34,64,146,203,47,64,39,49,60,64,104,179,42,62,73,46,159,62,104,34,236,62,81,107,26,63,205,204,60,63,56,248,98,63,131,192,138,63,18,20,167,63,5,197,191,63,199,41,218,63,157,17,245,63,24,38,7,64,44,212,18,64,38,228,31,64,109,86,45,64,222,113,58,64,16,88,57,62,147,24,164,62,105,111,240,62,123,131,31,63,15,156,67,63,77,243,126,63,203,16,159,63,32,210,183,63,19,97,203,63,46,144,224,63,45,67,244,63,242,176,4,64,140,185,15,64,231,140,28,64,167,121,43,64,42,58,58,64,32,99,238,61,82,39,192,62,63,87,27,63,169,19,64,63,174,71,129,63,220,70,155,63,231,140,176,63,152,221,195,63,215,163,208,63,143,194,229,63,250,237,243,63,49,153,6,64,18,131,24,64,156,196,36,64,62,121,44,64,131,47,56,64,211,222,32,62,82,39,224,62,127,106,44,63,134,201,84,63,102,247,100,63,63,87,123,63,248,194,148,63,56,103,180,63,227,54,210,63,171,62,231,63,157,128,246,63,97,195,11,64,87,236,27,64,131,47,40,64,89,23,47,64,137,65,56,64,187,39,15,62,240,133,137,62,99,127,217,62,246,151,29,63,213,120,73,63,176,114,128,63,236,192,153,63,29,56,175,63,122,165,196,63,196,177,222,63,99,238,250,63,146,92,10,64,115,104,21,64,237,158,32,64,206,136,46,64,136,244,59,64,38,228,67,62,213,231,170,62,155,85,255,62,129,4,37,63,222,2,73,63,30,22,130,63,11,36,152,63,63,53,174,63,232,217,196,63,68,139,220,63,252,169,241,63,77,132,5,64,170,241,18,64,9,138,31,64,175,148,45,64,0,145,58,64,90,245,185,61,161,103,51,62,198,109,148,62,16,88,9,63,125,174,70,63,174,71,129,63,236,47,155,63,207,247,179,63,15,11,205,63,43,135,230,63,113,27,253,63,39,49,12,64,38,228,23,64,185,252,35,64,37,6,49,64,76,55,61,64,34,142,53,62,202,195,162,62,246,40,252,62,233,183,47,63,7,95,88,63,251,92,125,63,217,206,151,63,64,164,175,63,141,151,198,63,188,5,226,63,50,119,253,63,64,164,11,64,2,43,23,64,44,212,34,64,102,102,46,64,12,2,59,64,184,175,3,62,233,183,111,62,118,224,188,62,131,81,9,63,162,180,55,63,41,92,111,63,198,220,141,63,159,171,165,63,206,170,191,63,238,90,218,63,54,205,243,63,248,83,7,64,177,191,20,64,118,79,34,64,255,178,47,64,162,180,59,64,85,193,104,62,1,77,196,62,201,118,14,63,126,29,56,63,103,213,87,63,247,6,127,63,0,145,150,63,116,181,173,63,62,232,201,63,148,246,222,63,29,201,245,63,8,61,7,64,125,174,18,64,226,88,31,64,197,32,44,64,131,192,58,64,143,194,53,62,209,145,156,62,44,212,218,62,85,48,26,63,101,170,80,63,44,101,137,63,206,25,169,63,69,71,194,63,57,214,213,63,7,95,232,63,22,251,251,63,57,214,9,64,129,38,22,64,51,196,33,64,90,245,45,64,217,95,58,64,103,68,41,62,100,93,220,62,115,215,34,63,94,75,72,63,181,21,107,63,29,201,133,63,65,130,154,63,131,47,180,63,210,111,207,63,42,58,234,63,209,145,0,64,154,119,12,64,195,245,24,64,233,72,38,64,156,51,50,64,128,183,60,64,227,199,24,62,175,148,133,62,129,149,195,62,127,106,12,63,186,107,57,63,0,145,110,63,184,175,147,63,171,207,173,63,161,103,195,63,39,160,217,63,12,147,241,63,157,128,6,64,236,81,20,64,22,106,33,64,168,87,46,64,187,39,59,64,170,96,84,62,83,150,193,62,180,89,5,63,174,216,47,63,58,146,91,63,205,204,124,63,206,170,151,63,159,171,173,63,66,207,190,63,84,227,221,63,19,242,241,63,103,213,7,64,103,213,19,64,167,121,31,64,124,242,44,64,147,24,56,64,95,41,11,62,66,207,102,62,66,62,168,62,28,235,226,62,2,154,40,63,120,122,101,63,102,102,142,63,43,24,173,63,71,3,200,63,222,2,225,63,95,7,254,63,39,49,12,64,11,181,22,64,3,120,35,64,15,11,49,64,125,208,59,64,152,110,18,62,245,219,151,62,59,223,239,62,134,56,38,63,47,221,84,63,38,228,131,63,127,106,156,63,230,63,180,63,106,188,204,63,102,247,228,63,113,27,253,63,231,29,11,64,181,21,23,64,91,177,35,64,7,95,48,64,39,49,60,64,171,62,23,62,204,238,137,62,206,170,207,62,142,6,16,63,111,129,52,63,251,92,93,63,233,72,134,63,174,216,159,63,132,158,189,63,136,133,218,63,184,30,245,63,63,87,7,64,118,113,19,64,238,235,32,64,68,250,45,64,143,228,58,64,86,14,45,62,35,74,155,62,250,126,234,62,95,41,43,63,136,133,90,63,26,192,131,63,236,47,155,63,165,44,179,63,190,48,201,63,158,94,225,63,190,159,250,63,207,247,7,64,176,3,19,64,16,122,30,64,104,34,44,64,153,187,58,64,64,164,223,61,233,72,142,62,62,121,248,62,197,32,48,63,125,174,102,63,202,50,140,63,193,57,163,63,67,28,187,63,63,198,212,63,95,152,236,63,138,176,1,64,214,197,13,64,116,181,25,64,16,88,37,64,43,24,49,64,241,99,60,64,245,74,25,62,227,54,186,62,90,245,25,63,132,158,77,63,132,13,127,63,238,124,151,63,130,226,175,63,53,239,200,63,86,125,222,63,56,103,244,63,68,139,4,64,14,79,15,64,243,31,26,64,41,237,37,64,67,173,49,64,200,7,61,64,115,215,18,62,73,46,127,62,40,15,203,62,16,233,23,63,18,165,77,63,220,104,136,63,239,201,163,63,153,187,182,63,55,137,201,63,45,67,228,63,235,226,246,63,22,251,7,64,218,172,22,64,5,163,34,64,21,29,45,64,227,199,56,64,157,17,37,62,171,207,149,62,85,48,234,62,216,129,35,63,129,149,83,63,211,77,130,63,116,36,151,63,255,33,173,63,29,56,199,63,247,117,224,63,246,151,245,63,249,160,7,64,82,39,20,64,213,9,32,64,71,114,45,64,34,253,58,64,12,147,169,61,109,197,62,62,203,161,165,62,174,71,1,63,154,153,57,63,95,152,124,63,88,202,154,63,222,113,178,63,68,139,204,63,148,135,229,63,34,142,253,63,33,31,12,64,64,19,25,64,124,242,36,64,137,65,48,64,162,180,59,64,4,231,76,62,209,34,187,62,139,108,7,63,228,20,45,63,191,125,77,63,128,72,127,63,131,192,154,63,201,118,182,63,84,227,205,63,246,40,228,63,191,125,253,63,39,194,10,64,243,31,22,64,123,20,34,64,115,215,46,64,186,218,58,64,172,28,26,62,159,171,141,62,7,206,217,62,127,251,26,63,181,55,72,63,75,234,116,63,46,144,144,63,139,108,167,63,146,203,191,63,222,2,217,63,192,236,238,63,221,181,4,64,102,102,18,64,54,205,31,64,196,66,45,64,169,164,58,64,174,182,34,62,253,135,212,62,165,44,19,63,254,67,42,63,146,92,78,63,25,4,134,63,28,124,161,63,100,59,175,63,217,206,191,63,65,241,227,63,143,194,253,63,208,213,6,64,61,155,17,64,1,222,34,64,181,166,45,64,15,156,55,64,200,152,187,61,200,7,61,62,19,242,193,62,188,5,34,63,73,157,96,63,41,203,136,63,90,245,161,63,124,97,186,63,104,34,212,63,175,37,236,63,163,146,2,64,244,108,14,64,44,101,25,64,170,130,37,64,106,222,49,64,232,217,60,64,67,173,105,62,216,240,212,62,180,89,21,63,73,157,48,63,151,144,79,63,218,27,132,63,168,198,163,63,134,90,195,63,227,199,216,63,56,103,236,63,155,230,5,64,79,175,16,64,186,73,24,64,41,237,33,64,57,69,47,64,244,253,60,64,249,15,41,62,7,206,153,62,76,55,233,62,178,46,30,63,117,2,74,63,180,89,117,63,197,143,145,63,25,115,175,63,61,44,204,63,47,221,228,63,85,193,248,63,66,96,9,64,190,48,21,64,182,132,32,64,30,167,44,64,115,104,57,64,56,248,2,62,93,254,195,62,74,12,34,63,157,17,85,63,89,23,119,63,61,10,143,63,230,174,157,63,216,240,172,63,213,120,193,63,78,209,209,63,186,73,228,63,168,87,250,63,232,217,12,64,252,169,29,64,88,57,44,64,161,248,57,64,143,83,244,61,119,190,95,62,116,70,180,62,43,246,7,63,118,224,60,63,182,132,108,63,221,36,142,63,119,45,169,63,52,162,196,63,27,13,224,63,145,15,250,63,173,105,10,64,180,200,22,64,8,61,35,64,165,78,48,64,204,127,60,64,53,239,56,62,233,183,175,62,247,6,255,62,106,222,49,63,138,142,100,63,224,190,134,63,222,147,159,63,244,253,180,63,9,249,208,63,143,194,229,63,2,43,255,63,2,154,12,64,16,122,22,64,100,93,36,64,227,165,47,64,112,95,59,64,200,7,61,62,155,85,159,62,177,225,233,62,66,207,22,63,177,80,59,63,186,107,89,63,120,156,130,63,177,225,153,63,215,52,175,63,86,14,205,63,223,224,235,63,68,139,4,64,164,112,17,64,193,57,31,64,48,42,45,64,190,159,58,64,88,57,180,61,128,183,128,62,204,127,8,63,199,41,58,63,93,254,99,63,202,84,145,63,124,242,168,63,171,62,191,63,145,237,204,63,102,136,219,63,123,131,239,63,126,29,4,64,203,161,17,64,102,102,34,64,70,37,45,64,4,231,56,64,77,132,13,62,179,12,145,62,86,125,238,62,46,144,48,63,181,55,104,63,48,42,137,63,107,154,159,63,200,7,181,63,227,165,203,63,187,184,229,63,6,129,253,63,79,30,10,64,251,92,21,64,66,96,33,64,54,171,46,64,77,243,58,64,245,74,217,61,143,228,178,62,161,248,33,63,90,100,91,63,126,140,121,63,2,43,135,63,58,146,147,63,154,153,169,63,168,53,205,63,131,192,234,63,1,77,252,63,161,103,7,64,57,69,19,64,56,248,34,64,255,178,51,64,60,189,62,64,175,37,36,62,87,91,145,62,182,132,220,62,135,22,25,63,186,73,76,63,113,27,133,63,147,58,153,63,113,27,173,63,233,38,201,63,143,83,228,63,190,48,249,63,83,150,9,64,122,54,23,64,35,74,35,64,143,228,46,64,21,140,58,64,141,40,45,62,36,151,159,62,34,142,245,62,18,131,48,63,9,138,95,63,101,25,130,63,89,134,152,63,25,115,175,63,75,234,196,63,131,47,220,63,158,94,241,63,1,77,4,64,179,234,15,64,44,101,29,64,25,115,43,64,76,55,57,64,203,161,197,61,233,72,46,62,19,97,163,62,37,117,18,63,41,92,79,63,181,21,131,63,228,20,157,63,116,181,181,63,139,253,205,63,45,33,231,63,228,131,254,63,108,9,13,64,184,30,25,64,233,38,37,64,204,127,48,64,65,241,59,64,20,174,71,62,61,44,180,62,148,246,6,63,65,130,50,63,9,138,95,63,149,101,136,63,154,8,155,63,218,172,178,63,233,72,206,63,218,27,228,63,96,229,248,63,85,48,10,64,93,109,21,64,167,232,32,64,178,157,47,64,52,128,59,64,150,33,14,62,28,235,130,62,170,241,210,62,120,156,18,63,45,67,60,63,232,106,107,63,166,155,140,63,109,231,163,63,47,110,187,63,227,165,211,63,131,192,234,63,145,126,3,64,181,166,17,64,70,148,30,64,94,75,44,64,124,97,58,64,218,172,58,62,159,205,170,62,100,204,253,62,109,86,45,63,122,54,91,63,236,192,129,63,93,109,157,63,103,68,177,63,190,48,201,63,58,35,226,63,159,171,245,63,133,124,8,64,98,16,20,64,23,183,33,64,181,166,45,64,83,150,57,64,193,202,161,61,147,169,66,62,179,12,209,62,11,70,37,63,30,167,88,63,227,165,131,63,207,102,157,63,77,132,181,63,208,213,206,63,231,29,231,63,249,160,255,63,159,60,12,64,34,108,24,64,63,198,36,64,147,58,49,64,227,199,60,64,46,144,160,59,237,13,62,60,188,116,147,59,36,151,127,59,111,18,131,186,130,226,71,188,158,239,167,188,137,210,94,187,66,96,101,188,75,89,134,187,154,119,156,60,38,228,3,189,23,183,81,57,95,41,75,188,100,93,220,188,202,84,193,59,142,6,112,61,186,218,10,61,155,85,31,189,147,169,2,189,0,111,1,188,158,239,167,188,79,175,20,189,232,217,172,188,93,109,197,60,70,182,115,61,55,26,64,61,103,213,231,60,224,45,144,60,226,233,149,188,187,184,141,188,23,183,209,185,82,73,29,59,104,145,109,60,245,185,90,61,229,97,161,60,244,253,212,187,172,139,219,187,62,232,89,60,5,163,18,61,195,100,42,188,9,27,30,189,234,149,50,188,36,151,255,187,174,71,225,60,139,108,103,61,132,158,205,60,124,242,48,187,159,171,173,187,77,21,140,60,224,45,16,60,131,192,74,61,176,3,103,60,36,151,127,59,162,69,54,189,86,125,46,189,153,187,150,188,66,96,229,188,125,174,182,188,36,151,127,59,77,21,140,188,181,55,120,189,9,249,160,189,197,32,48,189,137,210,94,61,70,182,115,61,111,18,3,61,82,73,157,186,124,242,48,60,80,141,151,60,208,68,216,59,231,29,39,61,101,25,98,61,215,52,239,187,168,87,202,188,166,155,68,189,250,237,235,188,7,95,152,60,159,171,173,60,195,100,170,186,157,17,37,61,216,240,116,61,223,79,141,61,134,90,83,61,33,31,244,188,151,255,144,188,211,188,227,60,39,160,137,60,159,171,45,188,132,158,205,60,9,27,30,61,222,147,7,61,195,100,170,187,62,232,89,60,32,99,238,60,0,111,129,188,39,194,6,189,189,82,22,189,67,28,235,60,54,60,61,61,224,45,144,188,46,144,160,59,20,63,198,60,137,210,94,187,27,47,93,60,4,231,12,60,33,31,116,188,93,109,197,60,59,112,78,61,240,133,201,60,64,164,223,188,116,36,23,189,124,242,48,188,16,233,55,189,0,0,128,189,12,147,41,189,215,52,239,188,177,225,105,189,88,57,52,189,224,45,16,188,46,144,32,60,250,237,107,58,23,183,209,185,52,128,55,58,73,157,0,189,195,100,170,188,101,25,98,188,28,235,226,188,224,45,144,187,171,207,85,61,37,6,1,61,27,47,221,188,28,235,226,188,23,183,209,188,85,193,40,188,193,168,164,188,67,28,235,188,138,142,228,188,43,24,149,188,202,84,65,61,181,21,123,61,236,81,56,61,48,42,41,61,149,101,8,61,198,220,53,61,125,174,182,60,130,226,199,59,0,111,1,61,74,123,3,61,168,53,77,61,127,106,60,61,205,204,204,60,90,245,185,60,18,131,192,60,156,51,34,60,80,141,151,60,150,33,14,189,77,21,140,189,44,212,154,188,20,63,198,60,227,165,155,188,64,164,223,188,82,73,157,186,242,65,207,188,142,6,240,60,54,60,189,188,161,103,179,188,111,18,131,186,218,172,122,60,23,183,81,60,185,252,135,188,14,45,50,189,159,205,42,189,20,63,70,188,5,197,15,189,119,190,31,189,72,80,252,59,211,188,227,188,115,104,17,189,153,187,22,60,59,112,206,187,111,18,3,58,124,242,176,60,91,211,60,61,100,93,92,61,199,186,56,61,33,31,244,60,244,253,84,188,237,13,190,59,85,193,168,60,238,235,64,61,241,99,76,61,66,96,229,60,4,231,12,60,52,128,55,186,220,215,1,189,61,44,212,60,224,45,144,60,4,231,140,59,159,171,173,60,101,25,98,60,159,171,45,60,88,57,180,60,10,215,35,187,10,215,163,59,130,226,71,60,231,29,167,187,4,231,12,188,202,84,65,189,111,18,3,186,9,27,158,60,23,183,81,59,240,133,201,60,198,220,181,60,188,116,19,60,111,18,3,189,188,5,146,189,25,115,87,189,254,101,119,188,88,57,52,189,221,181,132,189,164,223,62,189,153,187,22,188,127,106,60,60,134,90,83,188,159,171,173,59,4,231,12,189,45,178,29,189,46,144,32,61,180,89,117,61,12,147,41,61,2,43,135,60,46,144,32,188,111,18,3,189,171,207,213,188,88,57,180,187,211,188,99,188,88,57,52,188,39,160,9,60,4,231,140,60,240,133,73,189,136,244,91,189,111,18,3,189,250,237,107,187,135,22,217,60,45,178,29,61,23,183,209,59,66,96,229,188,127,106,188,188,172,139,91,60,93,109,197,60,159,171,45,60,228,131,30,61,49,8,44,60,137,210,222,59,244,253,212,60,145,237,252,62,118,113,251,62,208,68,248,62,180,200,246,62,135,167,247,62,190,193,247,62,34,253,246,62,116,181,245,62,217,95,246,62,161,214,244,62,70,37,245,62,5,52,241,62,124,242,240,62,187,39,239,62,58,146,235,62,195,100,234,62,171,62,151,62,190,48,89,62,146,92,62,62,204,127,72,62,7,240,22,62,173,105,222,61,168,87,10,62,3,120,11,62,153,42,24,62,186,107,9,62,254,212,248,61,23,183,17,62,84,82,39,62,120,156,34,62,246,151,29,62,36,40,62,62,247,228,225,61,2,188,197,62,91,177,47,63,66,62,88,63,72,80,108,63,63,87,131,63,114,249,143,63,250,237,179,63,177,191,212,63,43,135,230,63,242,65,239,63,111,129,4,64,4,86,22,64,180,200,38,64,230,63,48,64,235,115,57,64,238,90,2,62,16,122,118,62,165,44,195,62,208,179,25,63,208,213,70,63,110,52,112,63,5,52,145,63,143,228,170,63,127,251,194,63,31,244,220,63,48,42,249,63,45,33,11,64,53,94,22,64,108,9,33,64,127,217,45,64,143,228,58,64,242,210,77,62,250,126,170,62,29,201,229,62,6,129,37,63,68,250,77,63,141,40,125,63,99,238,146,63,111,240,165,63,86,14,189,63,138,142,212,63,204,127,240,63,90,100,7,64,108,9,21,64,11,70,33,64,71,114,45,64,146,92,58,64,215,52,239,61,9,249,96,62,130,226,167,62,224,45,240,62,247,117,32,63,193,57,83,63,137,210,134,63,60,189,162,63,72,80,188,63,185,141,214,63,108,9,241,63,45,33,7,64,8,172,20,64,155,230,33,64,209,34,47,64,248,83,59,64,59,223,15,62,73,46,159,62,128,72,255,62,220,104,48,63,200,7,93,63,96,118,135,63,5,52,161,63,206,170,183,63,5,197,207,63,130,226,231,63,180,200,254,63,78,98,12,64,72,80,24,64,202,50,36,64,200,7,49,64,221,181,60,64,32,99,46,62,182,132,156,62,0,111,225,62,143,194,5,63,112,206,24,63,178,157,79,63,202,84,137,63,233,38,169,63,168,53,197,63,16,122,222,63,60,78,249,63,131,192,10,64,77,243,22,64,179,234,35,64,254,212,48,64,88,57,60,64,176,3,231,61,185,141,134,62,222,147,231,62,162,69,38,63,60,78,81,63,35,74,123,63,75,89,150,63,238,124,175,63,57,69,199,63,251,58,224,63,197,143,249,63,245,74,9,64,22,106,21,64,86,125,34,64,231,29,47,64,35,74,59,64,217,61,57,62,94,75,168,62,125,63,5,63,90,245,57,63,95,7,110,63,222,147,143,63,25,4,166,63,169,164,190,63,185,252,215,63,221,181,236,63,184,175,3,64,171,62,15,64,134,56,26,64,147,169,38,64,247,228,49,64,240,22,60,64,55,26,128,62,206,25,241,62,105,111,48,63,88,168,85,63,26,192,107,63,242,210,133,63,11,181,158,63,181,21,187,63,245,185,210,63,150,67,235,63,61,10,3,64,63,87,15,64,35,219,29,64,133,235,41,64,82,73,49,64,145,237,56,64,244,253,212,61,178,157,111,62,241,244,202,62,170,241,18,63,39,194,70,63,86,125,126,63,154,153,153,63,19,97,179,63,113,27,205,63,52,17,230,63,29,56,255,63,160,137,12,64,17,54,24,64,66,62,36,64,36,185,48,64,150,178,60,64,239,201,67,62,187,184,173,62,115,215,242,62,224,156,33,63,141,40,77,63,4,231,124,63,119,190,151,63,156,51,178,63,172,173,200,63,152,76,221,63,54,171,246,63,188,116,7,64,5,197,19,64,76,166,34,64,206,170,47,64,84,82,59,64,203,161,197,61,41,92,79,62,68,250,173,62,238,124,255,62,170,130,49,63,23,72,112,63,221,36,150,63,110,52,176,63,188,5,202,63,86,159,227,63,223,79,253,63,233,183,11,64,238,124,23,64,255,178,35,64,4,231,48,64,4,231,60,64,208,179,89,62,127,251,186,62,182,243,13,63,80,141,55,63,237,13,94,63,39,49,136,63,14,190,160,63,22,251,179,63,58,146,203,63,178,157,231,63,145,237,252,63,203,161,9,64,174,182,22,64,20,174,35,64,124,242,44,64,20,208,56,64,181,21,59,62,68,105,175,62,163,146,250,62,194,23,38,63,168,198,75,63,147,24,116,63,222,147,143,63,125,208,163,63,222,113,186,63,49,153,210,63,148,246,230,63,208,68,0,64,193,57,15,64,170,130,29,64,93,220,42,64,229,97,57,64,23,72,80,62,184,175,195,62,226,233,5,63,14,45,50,63,31,133,107,63,15,11,133,63,79,175,148,63,23,72,176,63,118,79,198,63,242,210,221,63,3,120,251,63,38,228,7,64,109,86,21,64,118,79,34,64,87,91,45,64,166,155,60,64,61,10,215,61,170,241,82,62,45,178,189,62,126,140,25,63,93,109,85,63,183,98,135,63,85,193,160,63,183,98,183,63,64,19,209,63,18,131,232,63,79,30,254,63,212,43,13,64,210,0,26,64,54,60,37,64,205,204,48,64,253,135,60,64,60,78,17,62,123,131,207,62,250,126,42,63,33,31,100,63,27,47,133,63,54,205,147,63,169,19,160,63,184,64,178,63,46,144,200,63,121,88,224,63,77,21,252,63,70,37,13,64,189,227,24,64,85,193,36,64,231,140,48,64,174,182,58,64,154,8,27,62,215,163,144,62,237,158,220,62,97,195,19,63,100,59,63,63,149,101,120,63,174,182,146,63,222,113,170,63,218,27,196,63,75,234,220,63,66,207,246,63,55,26,8,64,223,224,19,64,220,104,32,64,147,58,45,64,156,51,58,64,251,92,45,62,83,150,161,62,236,192,249,62,35,219,41,63,215,18,82,63,102,247,116,63,109,197,142,63,29,56,167,63,44,101,193,63,136,244,219,63,191,125,245,63,98,161,6,64,230,174,17,64,23,217,30,64,62,121,44,64,162,69,58,64,5,163,18,62,95,41,139,62,163,35,217,62,59,112,14,63,110,163,49,63,125,174,102,63,230,63,148,63,206,136,178,63,231,29,207,63,11,181,230,63,132,158,253,63,209,34,11,64,58,35,22,64,28,235,34,64,65,241,47,64,151,144,59,64,213,231,106,62,120,122,197,62,160,26,15,63,118,79,62,63,8,61,107,63,120,11,140,63,111,18,163,63,108,9,185,63,18,20,207,63,189,82,230,63,234,4,252,63,136,133,10,64,92,143,22,64,201,118,34,64,146,203,47,64,39,49,60,64,104,179,42,62,73,46,159,62,104,34,236,62,81,107,26,63,205,204,60,63,56,248,98,63,131,192,138,63,18,20,167,63,5,197,191,63,199,41,218,63,157,17,245,63,24,38,7,64,44,212,18,64,38,228,31,64,109,86,45,64,222,113,58,64,16,88,57,62,147,24,164,62,105,111,240,62,123,131,31,63,15,156,67,63,77,243,126,63,203,16,159,63,32,210,183,63,19,97,203,63,46,144,224,63,45,67,244,63,242,176,4,64,140,185,15,64,231,140,28,64,167,121,43,64,42,58,58,64,32,99,238,61,82,39,192,62,63,87,27,63,169,19,64,63,174,71,129,63,220,70,155,63,231,140,176,63,152,221,195,63,215,163,208,63,143,194,229,63,250,237,243,63,49,153,6,64,18,131,24,64,156,196,36,64,62,121,44,64,131,47,56,64,211,222,32,62,82,39,224,62,127,106,44,63,134,201,84,63,102,247,100,63,63,87,123,63,248,194,148,63,56,103,180,63,227,54,210,63,171,62,231,63,157,128,246,63,97,195,11,64,87,236,27,64,131,47,40,64,89,23,47,64,137,65,56,64,187,39,15,62,240,133,137,62,99,127,217,62,246,151,29,63,213,120,73,63,176,114,128,63,236,192,153,63,29,56,175,63,122,165,196,63,196,177,222,63,99,238,250,63,146,92,10,64,115,104,21,64,237,158,32,64,206,136,46,64,136,244,59,64,38,228,67,62,213,231,170,62,155,85,255,62,129,4,37,63,222,2,73,63,30,22,130,63,11,36,152,63,63,53,174,63,232,217,196,63,68,139,220,63,252,169,241,63,77,132,5,64,170,241,18,64,9,138,31,64,175,148,45,64,0,145,58,64,90,245,185,61,161,103,51,62,198,109,148,62,16,88,9,63,125,174,70,63,174,71,129,63,236,47,155,63,207,247,179,63,15,11,205,63,43,135,230,63,113,27,253,63,39,49,12,64,38,228,23,64,185,252,35,64,37,6,49,64,76,55,61,64,34,142,53,62,202,195,162,62,246,40,252,62,233,183,47,63,7,95,88,63,251,92,125,63,217,206,151,63,64,164,175,63,141,151,198,63,188,5,226,63,50,119,253,63,64,164,11,64,2,43,23,64,44,212,34,64,102,102,46,64,12,2,59,64,184,175,3,62,233,183,111,62,118,224,188,62,131,81,9,63,162,180,55,63,41,92,111,63,198,220,141,63,159,171,165,63,206,170,191,63,238,90,218,63,54,205,243,63,248,83,7,64,177,191,20,64,118,79,34,64,255,178,47,64,162,180,59,64,85,193,104,62,1,77,196,62,201,118,14,63,126,29,56,63,103,213,87,63,247,6,127,63,0,145,150,63,116,181,173,63,62,232,201,63,148,246,222,63,29,201,245,63,8,61,7,64,125,174,18,64,226,88,31,64,197,32,44,64,131,192,58,64,143,194,53,62,209,145,156,62,44,212,218,62,85,48,26,63,101,170,80,63,44,101,137,63,206,25,169,63,69,71,194,63,57,214,213,63,7,95,232,63,22,251,251,63,57,214,9,64,129,38,22,64,51,196,33,64,90,245,45,64,217,95,58,64,103,68,41,62,100,93,220,62,115,215,34,63,94,75,72,63,181,21,107,63,29,201,133,63,65,130,154,63,131,47,180,63,210,111,207,63,42,58,234,63,209,145,0,64,154,119,12,64,195,245,24,64,233,72,38,64,156,51,50,64,128,183,60,64,227,199,24,62,175,148,133,62,129,149,195,62,127,106,12,63,186,107,57,63,0,145,110,63,184,175,147,63,171,207,173,63,161,103,195,63,39,160,217,63,12,147,241,63,157,128,6,64,236,81,20,64,22,106,33,64,168,87,46,64,187,39,59,64,170,96,84,62,83,150,193,62,180,89,5,63,174,216,47,63,58,146,91,63,205,204,124,63,206,170,151,63,159,171,173,63,66,207,190,63,84,227,221,63,19,242,241,63,103,213,7,64,103,213,19,64,167,121,31,64,124,242,44,64,147,24,56,64,95,41,11,62,66,207,102,62,66,62,168,62,28,235,226,62,2,154,40,63,120,122,101,63,102,102,142,63,43,24,173,63,71,3,200,63,222,2,225,63,95,7,254,63,39,49,12,64,11,181,22,64,3,120,35,64,15,11,49,64,125,208,59,64,152,110,18,62,245,219,151,62,59,223,239,62,134,56,38,63,47,221,84,63,38,228,131,63,127,106,156,63,230,63,180,63,106,188,204,63,102,247,228,63,113,27,253,63,231,29,11,64,181,21,23,64,91,177,35,64,7,95,48,64,39,49,60,64,171,62,23,62,204,238,137,62,206,170,207,62,142,6,16,63,111,129,52,63,251,92,93,63,233,72,134,63,174,216,159,63,132,158,189,63,136,133,218,63,184,30,245,63,63,87,7,64,118,113,19,64,238,235,32,64,68,250,45,64,143,228,58,64,86,14,45,62,35,74,155,62,250,126,234,62,95,41,43,63,136,133,90,63,26,192,131,63,236,47,155,63,165,44,179,63,190,48,201,63,158,94,225,63,190,159,250,63,207,247,7,64,176,3,19,64,16,122,30,64,104,34,44,64,153,187,58,64,64,164,223,61,233,72,142,62,62,121,248,62,197,32,48,63,125,174,102,63,202,50,140,63,193,57,163,63,67,28,187,63,63,198,212,63,95,152,236,63,138,176,1,64,214,197,13,64,116,181,25,64,16,88,37,64,43,24,49,64,241,99,60,64,245,74,25,62,227,54,186,62,90,245,25,63,132,158,77,63,132,13,127,63,238,124,151,63,130,226,175,63,53,239,200,63,86,125,222,63,56,103,244,63,68,139,4,64,14,79,15,64,243,31,26,64,41,237,37,64,67,173,49,64,200,7,61,64,115,215,18,62,73,46,127,62,40,15,203,62,16,233,23,63,18,165,77,63,220,104,136,63,239,201,163,63,153,187,182,63,55,137,201,63,45,67,228,63,235,226,246,63,22,251,7,64,218,172,22,64,5,163,34,64,21,29,45,64,227,199,56,64,157,17,37,62,171,207,149,62,85,48,234,62,216,129,35,63,129,149,83,63,211,77,130,63,116,36,151,63,255,33,173,63,29,56,199,63,247,117,224,63,246,151,245,63,249,160,7,64,82,39,20,64,213,9,32,64,71,114,45,64,34,253,58,64,12,147,169,61,109,197,62,62,203,161,165,62,174,71,1,63,154,153,57,63,95,152,124,63,88,202,154,63,222,113,178,63,68,139,204,63,148,135,229,63,34,142,253,63,33,31,12,64,64,19,25,64,124,242,36,64,137,65,48,64,162,180,59,64,4,231,76,62,209,34,187,62,139,108,7,63,228,20,45,63,191,125,77,63,128,72,127,63,131,192,154,63,201,118,182,63,84,227,205,63,246,40,228,63,191,125,253,63,39,194,10,64,243,31,22,64,123,20,34,64,115,215,46,64,186,218,58,64], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+718184);
/* memory initializer */ allocate([172,28,26,62,159,171,141,62,7,206,217,62,127,251,26,63,181,55,72,63,75,234,116,63,46,144,144,63,139,108,167,63,146,203,191,63,222,2,217,63,192,236,238,63,221,181,4,64,102,102,18,64,54,205,31,64,196,66,45,64,169,164,58,64,174,182,34,62,253,135,212,62,165,44,19,63,254,67,42,63,146,92,78,63,25,4,134,63,28,124,161,63,100,59,175,63,217,206,191,63,65,241,227,63,143,194,253,63,208,213,6,64,61,155,17,64,1,222,34,64,181,166,45,64,15,156,55,64,200,152,187,61,200,7,61,62,19,242,193,62,188,5,34,63,73,157,96,63,41,203,136,63,90,245,161,63,124,97,186,63,104,34,212,63,175,37,236,63,163,146,2,64,244,108,14,64,44,101,25,64,170,130,37,64,106,222,49,64,232,217,60,64,67,173,105,62,216,240,212,62,180,89,21,63,73,157,48,63,151,144,79,63,218,27,132,63,168,198,163,63,134,90,195,63,227,199,216,63,56,103,236,63,155,230,5,64,79,175,16,64,186,73,24,64,41,237,33,64,57,69,47,64,244,253,60,64,249,15,41,62,7,206,153,62,76,55,233,62,178,46,30,63,117,2,74,63,180,89,117,63,197,143,145,63,25,115,175,63,61,44,204,63,47,221,228,63,85,193,248,63,66,96,9,64,190,48,21,64,182,132,32,64,30,167,44,64,115,104,57,64,56,248,2,62,93,254,195,62,74,12,34,63,157,17,85,63,89,23,119,63,61,10,143,63,230,174,157,63,216,240,172,63,213,120,193,63,78,209,209,63,186,73,228,63,168,87,250,63,232,217,12,64,252,169,29,64,88,57,44,64,161,248,57,64,143,83,244,61,119,190,95,62,116,70,180,62,43,246,7,63,118,224,60,63,182,132,108,63,221,36,142,63,119,45,169,63,52,162,196,63,27,13,224,63,145,15,250,63,173,105,10,64,180,200,22,64,8,61,35,64,165,78,48,64,204,127,60,64,53,239,56,62,233,183,175,62,247,6,255,62,106,222,49,63,138,142,100,63,224,190,134,63,222,147,159,63,244,253,180,63,9,249,208,63,143,194,229,63,2,43,255,63,2,154,12,64,16,122,22,64,100,93,36,64,227,165,47,64,112,95,59,64,200,7,61,62,155,85,159,62,177,225,233,62,66,207,22,63,177,80,59,63,186,107,89,63,120,156,130,63,177,225,153,63,215,52,175,63,86,14,205,63,223,224,235,63,68,139,4,64,164,112,17,64,193,57,31,64,48,42,45,64,190,159,58,64,88,57,180,61,128,183,128,62,204,127,8,63,199,41,58,63,93,254,99,63,202,84,145,63,124,242,168,63,171,62,191,63,145,237,204,63,102,136,219,63,123,131,239,63,126,29,4,64,203,161,17,64,102,102,34,64,70,37,45,64,4,231,56,64,77,132,13,62,179,12,145,62,86,125,238,62,46,144,48,63,181,55,104,63,48,42,137,63,107,154,159,63,200,7,181,63,227,165,203,63,187,184,229,63,6,129,253,63,79,30,10,64,251,92,21,64,66,96,33,64,54,171,46,64,77,243,58,64,245,74,217,61,143,228,178,62,161,248,33,63,90,100,91,63,126,140,121,63,2,43,135,63,58,146,147,63,154,153,169,63,168,53,205,63,131,192,234,63,1,77,252,63,161,103,7,64,57,69,19,64,56,248,34,64,255,178,51,64,60,189,62,64,175,37,36,62,87,91,145,62,182,132,220,62,135,22,25,63,186,73,76,63,113,27,133,63,147,58,153,63,113,27,173,63,233,38,201,63,143,83,228,63,190,48,249,63,83,150,9,64,122,54,23,64,35,74,35,64,143,228,46,64,21,140,58,64,141,40,45,62,36,151,159,62,34,142,245,62,18,131,48,63,9,138,95,63,101,25,130,63,89,134,152,63,25,115,175,63,75,234,196,63,131,47,220,63,158,94,241,63,1,77,4,64,179,234,15,64,44,101,29,64,25,115,43,64,76,55,57,64,203,161,197,61,233,72,46,62,19,97,163,62,37,117,18,63,41,92,79,63,181,21,131,63,228,20,157,63,116,181,181,63,139,253,205,63,45,33,231,63,228,131,254,63,108,9,13,64,184,30,25,64,233,38,37,64,204,127,48,64,65,241,59,64,20,174,71,62,61,44,180,62,148,246,6,63,65,130,50,63,9,138,95,63,149,101,136,63,154,8,155,63,218,172,178,63,233,72,206,63,218,27,228,63,96,229,248,63,85,48,10,64,93,109,21,64,167,232,32,64,178,157,47,64,52,128,59,64,150,33,14,62,28,235,130,62,170,241,210,62,120,156,18,63,45,67,60,63,232,106,107,63,166,155,140,63,109,231,163,63,47,110,187,63,227,165,211,63,131,192,234,63,145,126,3,64,181,166,17,64,70,148,30,64,94,75,44,64,124,97,58,64,218,172,58,62,159,205,170,62,100,204,253,62,109,86,45,63,122,54,91,63,236,192,129,63,93,109,157,63,103,68,177,63,190,48,201,63,58,35,226,63,159,171,245,63,133,124,8,64,98,16,20,64,23,183,33,64,181,166,45,64,83,150,57,64,193,202,161,61,147,169,66,62,179,12,209,62,11,70,37,63,30,167,88,63,227,165,131,63,207,102,157,63,77,132,181,63,208,213,206,63,231,29,231,63,249,160,255,63,159,60,12,64,34,108,24,64,63,198,36,64,147,58,49,64,227,199,60,64,46,144,160,59,237,13,62,60,188,116,147,59,36,151,127,59,111,18,131,186,130,226,71,188,158,239,167,188,137,210,94,187,66,96,101,188,75,89,134,187,154,119,156,60,38,228,3,189,23,183,81,57,95,41,75,188,100,93,220,188,202,84,193,59,142,6,112,61,186,218,10,61,155,85,31,189,147,169,2,189,0,111,1,188,158,239,167,188,79,175,20,189,232,217,172,188,93,109,197,60,70,182,115,61,55,26,64,61,103,213,231,60,224,45,144,60,226,233,149,188,187,184,141,188,23,183,209,185,82,73,29,59,104,145,109,60,245,185,90,61,229,97,161,60,244,253,212,187,172,139,219,187,62,232,89,60,5,163,18,61,195,100,42,188,9,27,30,189,234,149,50,188,36,151,255,187,174,71,225,60,139,108,103,61,132,158,205,60,124,242,48,187,159,171,173,187,77,21,140,60,224,45,16,60,131,192,74,61,176,3,103,60,36,151,127,59,162,69,54,189,86,125,46,189,153,187,150,188,66,96,229,188,125,174,182,188,36,151,127,59,77,21,140,188,181,55,120,189,9,249,160,189,197,32,48,189,137,210,94,61,70,182,115,61,111,18,3,61,82,73,157,186,124,242,48,60,80,141,151,60,208,68,216,59,231,29,39,61,101,25,98,61,215,52,239,187,168,87,202,188,166,155,68,189,250,237,235,188,7,95,152,60,159,171,173,60,195,100,170,186,157,17,37,61,216,240,116,61,223,79,141,61,134,90,83,61,33,31,244,188,151,255,144,188,211,188,227,60,39,160,137,60,159,171,45,188,132,158,205,60,9,27,30,61,222,147,7,61,195,100,170,187,62,232,89,60,32,99,238,60,0,111,129,188,39,194,6,189,189,82,22,189,67,28,235,60,54,60,61,61,224,45,144,188,46,144,160,59,20,63,198,60,137,210,94,187,27,47,93,60,4,231,12,60,33,31,116,188,93,109,197,60,59,112,78,61,240,133,201,60,64,164,223,188,116,36,23,189,124,242,48,188,16,233,55,189,0,0,128,189,12,147,41,189,215,52,239,188,177,225,105,189,88,57,52,189,224,45,16,188,46,144,32,60,250,237,107,58,23,183,209,185,52,128,55,58,73,157,0,189,195,100,170,188,101,25,98,188,28,235,226,188,224,45,144,187,171,207,85,61,37,6,1,61,27,47,221,188,28,235,226,188,23,183,209,188,85,193,40,188,193,168,164,188,67,28,235,188,138,142,228,188,43,24,149,188,202,84,65,61,181,21,123,61,236,81,56,61,48,42,41,61,149,101,8,61,198,220,53,61,125,174,182,60,130,226,199,59,0,111,1,61,74,123,3,61,168,53,77,61,127,106,60,61,205,204,204,60,90,245,185,60,18,131,192,60,156,51,34,60,80,141,151,60,150,33,14,189,77,21,140,189,44,212,154,188,20,63,198,60,227,165,155,188,64,164,223,188,82,73,157,186,242,65,207,188,142,6,240,60,54,60,189,188,161,103,179,188,111,18,131,186,218,172,122,60,23,183,81,60,185,252,135,188,14,45,50,189,159,205,42,189,20,63,70,188,5,197,15,189,119,190,31,189,72,80,252,59,211,188,227,188,115,104,17,189,153,187,22,60,59,112,206,187,111,18,3,58,124,242,176,60,91,211,60,61,100,93,92,61,199,186,56,61,33,31,244,60,244,253,84,188,237,13,190,59,85,193,168,60,238,235,64,61,241,99,76,61,66,96,229,60,4,231,12,60,52,128,55,186,220,215,1,189,61,44,212,60,224,45,144,60,4,231,140,59,159,171,173,60,101,25,98,60,159,171,45,60,88,57,180,60,10,215,35,187,10,215,163,59,130,226,71,60,231,29,167,187,4,231,12,188,202,84,65,189,111,18,3,186,9,27,158,60,23,183,81,59,240,133,201,60,198,220,181,60,188,116,19,60,111,18,3,189,188,5,146,189,25,115,87,189,254,101,119,188,88,57,52,189,221,181,132,189,164,223,62,189,153,187,22,188,127,106,60,60,134,90,83,188,159,171,173,59,4,231,12,189,45,178,29,189,46,144,32,61,180,89,117,61,12,147,41,61,2,43,135,60,46,144,32,188,111,18,3,189,171,207,213,188,88,57,180,187,211,188,99,188,88,57,52,188,39,160,9,60,4,231,140,60,240,133,73,189,136,244,91,189,111,18,3,189,250,237,107,187,135,22,217,60,45,178,29,61,23,183,209,59,66,96,229,188,127,106,188,188,172,139,91,60,93,109,197,60,159,171,45,60,228,131,30,61,49,8,44,60,137,210,222,59,244,253,212,60,145,237,252,62,118,113,251,62,208,68,248,62,180,200,246,62,135,167,247,62,190,193,247,62,34,253,246,62,116,181,245,62,217,95,246,62,161,214,244,62,70,37,245,62,5,52,241,62,124,242,240,62,187,39,239,62,58,146,235,62,195,100,234,62,171,62,151,62,190,48,89,62,146,92,62,62,204,127,72,62,7,240,22,62,173,105,222,61,168,87,10,62,3,120,11,62,153,42,24,62,186,107,9,62,254,212,248,61,23,183,17,62,84,82,39,62,120,156,34,62,246,151,29,62,36,40,62,62,6,5,5,5,9,9,9,9,6,9,9,9,6,5,7,3,9,9,12,6,6,9,12,6,11,10,0,0,18,18,0,0,15,18,0,0,7,7,7,0,12,12,12,0,6,15,12,0,6,6,6,3,12,9,9,6,6,12,9,6,8,8,5,0,15,12,9,0,6,18,9,0,6,5,5,5,9,9,9,9,6,9,9,9,6,5,7,3,9,9,12,6,6,9,12,6,11,10,0,0,18,18,0,0,15,18,0,0,7,7,7,0,12,12,12,0,6,15,12,0,6,6,6,3,12,9,9,6,6,12,9,6,8,8,5,0,15,12,9,0,6,18,9,0,112,84,11,0,112,68,11,0,112,58,11,0,112,48,11,0,112,39,11,0,0,0,0,0,112,90,11,0,112,80,11,0,112,64,11,0,112,54,11,0,112,47,11,0,0,0,0,0,143,27,78,190,4,175,142,190,152,107,49,190,142,88,75,190,171,209,91,190,113,145,27,190,148,190,240,189,143,86,69,190,57,211,36,190,166,182,84,190,238,124,255,189,236,220,4,190,35,48,6,190,41,32,13,190,252,1,31,190,165,76,42,190,231,110,55,190,38,172,45,190,56,48,41,190,160,196,135,189,215,191,11,190,170,72,53,190,165,16,128,190,74,152,9,190,145,39,137,189,218,200,21,190,186,187,46,190,151,169,9,190,230,146,170,189,52,215,41,190,199,214,211,189,203,186,15,190,250,154,5,190,121,92,244,189,194,193,254,189,173,246,176,189,239,171,2,190,22,164,9,190,103,183,150,189,105,199,237,189,179,122,231,189,146,234,187,189,232,190,220,189,248,25,7,190,240,138,0,190,14,134,58,190,30,24,192,189,50,174,56,189,36,242,157,189,129,93,13,190,242,66,42,190,237,70,31,189,46,143,149,189,141,209,218,189,146,93,137,189,165,73,233,189,81,77,73,189,199,44,219,189,167,118,230,189,145,209,129,189,174,243,207,189,129,233,244,189,58,4,78,189,150,149,38,189,220,189,220,189,175,9,137,189,168,223,165,189,13,111,86,189,133,206,27,190,232,246,210,189,158,67,185,189,196,96,126,188,215,194,28,190,253,132,179,189,199,217,244,188,36,14,25,189,159,114,92,190,32,96,13,190,145,154,182,189,142,60,80,189,136,133,90,189,197,115,118,189,203,246,129,189,32,178,200,188,30,168,83,189,3,96,156,189,157,43,10,189,205,32,158,189,52,131,56,189,246,37,219,189,137,12,171,188,167,232,200,188,122,253,169,189,119,102,130,189,43,249,88,188,188,7,232,188,122,52,213,189,136,133,154,189,171,32,6,189,72,138,200,60,220,128,175,189,169,194,159,188,204,208,56,189,91,238,204,188,87,38,252,189,142,172,252,188,231,137,103,187,50,232,132,188,251,115,209,188,148,104,73,189,217,39,128,187,209,117,225,188,223,220,31,189,38,171,162,188,4,254,48,189,162,236,109,189,247,86,36,189,1,247,188,188,207,187,177,186,96,4,13,60,43,190,129,189,172,200,232,186,228,49,131,60,167,231,221,188,65,125,139,189,152,20,31,189,178,46,46,61,146,8,141,58,8,174,50,189,139,222,169,188,242,10,68,189,205,117,26,61,36,38,40,189,224,216,179,60,236,52,210,188,133,180,70,58,193,144,85,188,141,71,41,59,180,227,6,188,227,199,24,189,72,250,180,187,113,90,112,188,34,251,160,60,64,137,79,188,95,121,144,187,43,137,108,188,255,89,115,189,254,99,161,188,142,91,204,60,43,22,63,188,117,32,107,188,73,158,235,188,227,107,79,60,62,118,151,60,223,50,39,188,176,254,79,60,208,238,144,187,238,9,146,60,119,17,38,61,132,212,109,59,126,113,169,60,35,20,219,60,125,4,254,59,155,172,209,188,226,92,3,61,230,90,52,56,55,136,214,60,49,40,211,187,238,208,112,61,242,152,129,60,105,171,146,186,231,169,142,188,50,30,165,60,187,237,66,189,165,130,138,59,158,12,14,60,130,86,96,61,253,159,3,61,55,224,243,60,196,5,32,188,113,0,253,60,216,156,67,61,80,114,7,61,47,252,224,59,155,28,126,61,221,206,62,60,14,135,101,61,227,27,138,60,2,17,98,60,76,251,230,188,13,171,120,61,90,70,106,60,88,227,204,61,59,194,41,61,81,133,191,60,254,240,115,188,138,119,128,61,19,101,47,189,85,222,14,59,36,214,98,189,88,146,124,61,64,189,153,60,130,29,127,188,31,191,151,189,169,251,128,61,156,219,164,61,87,118,65,60,22,51,2,189,155,1,174,61,160,137,48,61,1,252,211,188,15,95,166,60,161,245,112,60,156,21,17,61,253,188,41,189,166,157,90,189,214,111,166,61,110,194,189,59,13,195,135,189,138,31,35,189,183,236,144,60,255,31,167,188,246,240,37,189,56,243,171,189,202,140,247,61,66,93,100,61,201,228,212,188,204,236,115,189,231,168,163,61,214,85,1,60,182,219,174,189,151,172,234,189,81,246,22,61,139,25,33,189,53,122,213,189,176,140,141,189,163,176,11,60,144,161,131,189,206,226,69,189,202,21,30,189,103,14,9,61,34,53,237,188,198,51,136,189,246,154,30,61,77,75,44,189,207,45,52,189,41,35,206,189,206,136,146,189,3,93,123,188,20,208,132,189,157,128,134,189,80,110,251,189,110,165,215,187,144,47,161,187,62,148,232,189,70,64,21,190,122,139,7,60,54,204,144,189,60,245,40,190,0,171,195,189,109,143,222,186,55,140,130,189,30,23,5,190,210,224,54,188,135,137,70,189,51,51,179,189,29,87,227,189,238,180,37,190,207,220,3,189,231,82,188,189,162,39,165,189,156,83,73,60,16,89,196,189,18,245,130,188,70,239,148,189,175,95,208,189,214,196,162,189,19,15,168,189,84,225,79,190,131,104,205,189,72,166,195,188,247,29,131,189,149,97,44,190,28,210,88,190,8,114,144,189,115,16,212,189,67,169,253,189,15,123,97,61,113,58,9,189,156,79,157,189,81,108,133,188,17,224,52,61,55,25,181,189,247,143,37,190,137,240,111,189,148,75,99,60,142,31,170,189,99,66,44,190,136,103,137,188,158,68,164,189,90,246,164,189,156,109,14,190,105,55,250,60,181,250,234,59,103,154,240,189,88,116,171,189,75,202,221,60,126,199,112,187,193,255,38,190,220,158,32,190,186,187,78,188,79,235,182,188,231,198,52,190,144,130,231,189,107,13,165,188,200,12,84,61,154,149,29,190,119,19,76,190,159,32,49,189,106,22,232,60,200,209,220,189,210,58,26,190,53,152,134,60,81,76,190,61,240,250,12,190,18,159,59,190,164,56,135,61,187,96,240,60,75,177,67,190,150,67,203,189,229,213,57,61,19,211,133,59,35,187,114,190,94,244,5,190,25,172,184,188,253,18,241,188,157,214,77,190,61,130,91,189,200,94,239,187,148,104,9,189,212,68,127,190,201,227,105,190,209,231,163,59,254,40,234,59,24,119,83,190,1,22,89,190,60,76,123,189,100,119,65,189,95,235,130,190,83,91,10,190,127,106,156,61,87,9,22,61,213,176,151,190,0,113,151,189,89,82,238,187,71,146,160,188,240,23,155,190,76,80,51,190,190,104,143,189,187,213,51,189,129,4,117,190,128,17,52,189,11,11,174,189,33,33,138,189,180,88,130,190,138,229,150,190,218,200,181,189,157,72,144,189,90,132,82,190,94,187,116,190,128,126,255,189,179,122,7,61,90,132,82,190,44,16,93,190,29,62,233,188,250,13,243,61,206,83,29,190,3,95,81,190,60,108,34,189,231,170,9,190,105,110,21,190,201,147,68,190,241,131,51,190,192,7,175,60,175,238,24,190,176,171,89,190,218,83,242,189,99,155,212,61,250,99,42,190,252,223,97,190,41,208,135,190,99,126,238,188,113,28,40,190,242,207,108,190,27,133,132,190,225,154,123,61,180,0,77,190,80,227,134,190,185,26,89,190,87,65,236,61,202,53,5,190,145,66,89,190,143,57,79,190,40,209,242,61,29,87,83,190,201,229,159,189,21,83,105,190,122,170,227,189,44,183,4,190,164,23,53,190,204,97,119,190,157,17,133,190,224,17,53,190,176,2,60,189,243,28,17,190,137,94,86,190,243,204,179,190,35,191,254,188,66,38,9,190,54,202,58,190,111,44,40,190,176,59,221,60,213,3,102,188,18,105,91,189,83,36,47,190,146,94,212,188,254,184,253,60,140,245,141,60,250,154,165,189,64,194,176,188,161,189,250,59,168,1,131,61,106,21,125,189,92,33,44,61,206,222,153,188,99,123,109,189,188,234,225,189,6,76,96,61,133,205,0,61,143,223,219,187,146,234,11,190,245,159,181,60,195,15,174,61,12,178,229,60,6,74,130,190,140,100,143,187,74,208,159,61,137,211,9,61,85,23,112,190,168,139,180,61,145,238,39,61,19,243,44,59,237,240,23,189,129,122,115,61,28,211,147,61,206,51,118,60,89,220,63,189,95,182,157,187,206,196,180,61,18,222,30,61,195,186,177,189,253,246,245,61,6,71,169,61,94,15,166,60,65,103,242,189,192,206,141,189,161,73,194,61,46,144,32,61,185,55,191,188,13,167,172,189,46,203,87,61,158,6,140,60,243,141,104,188,22,165,132,58,40,185,67,60,217,206,151,61,3,93,123,188,130,117,156,61,206,54,183,60,90,98,229,188,177,247,226,60,152,190,23,61,60,79,220,61,38,25,121,61,79,204,250,60,75,143,38,61,200,125,43,60,213,36,152,61,69,75,30,61,78,183,236,61,154,152,142,61,190,105,250,59,101,142,197,61,189,252,142,61,181,249,127,61,207,134,124,60,158,153,96,61,91,152,133,61,255,90,94,61,209,117,225,61,173,247,27,62,2,45,189,61,193,110,216,60,180,1,88,188,241,185,19,62,16,205,252,61,185,27,164,61,34,83,190,60,12,200,254,61,247,231,34,60,91,10,24,190,193,27,82,190,81,102,67,189,210,26,3,60,218,169,57,60,102,45,133,61,134,141,178,188,84,114,14,189,116,238,22,190,13,169,162,186,87,179,206,186,60,191,168,60,125,173,171,189,251,92,237,188,211,248,53,190,32,67,135,61,122,29,49,189,130,27,41,190,43,104,90,61,193,171,197,61,165,16,200,189,73,20,218,61,148,160,191,188,167,206,227,61,216,68,22,190,69,47,35,190,133,40,223,60,244,109,65,188,89,196,48,189,59,52,108,61,5,224,159,60,89,109,126,189,251,232,212,60,13,111,38,62,199,47,188,61,163,64,31,60,35,192,201,189,217,38,21,61,61,210,96,60,216,157,238,189,145,152,96,61,131,81,57,190,216,186,244,61,85,221,3,62,42,112,242,61,92,5,1,190,36,237,134,61,27,101,253,188,44,243,246,61,75,177,35,189,13,25,79,189,220,103,181,189,79,89,77,61,111,246,7,61,5,196,4,190,82,212,153,189,245,189,102,190,104,204,36,189,240,165,144,61,190,246,172,189,179,153,195,61,116,37,130,61,88,32,26,62,93,195,12,61,231,142,62,62,122,222,141,189,134,2,70,190,43,250,155,190,15,239,129,190,98,16,40,190,247,57,142,190,113,202,28,190,246,239,10,190,142,35,86,190,45,206,88,190,208,125,249,189,96,233,92,190,40,156,149,190,63,141,75,190,222,141,37,190,226,91,120,190,39,22,40,190,88,231,56,190,57,98,13,190,21,111,196,189,180,118,75,190,46,3,30,190,230,88,126,190,206,22,112,190,137,69,12,190,95,237,40,190,212,213,221,189,169,217,51,190,94,77,254,189,30,252,228,189,163,201,101,190,246,7,138,189,16,201,32,190,12,117,72,190,32,151,184,189,128,17,244,189,21,56,41,190,175,177,203,189,165,107,22,190,111,185,218,189,138,227,16,190,27,101,221,189,122,252,222,189,158,66,174,189,123,102,201,189,10,47,225,189,4,30,216,189,152,20,95,189,192,4,30,190,91,206,37,189,114,191,19,190,187,9,254,189,28,207,39,189,164,28,172,189,34,79,18,190,53,10,73,189,234,203,242,189,171,146,136,189,207,75,197,189,16,59,179,189,173,80,100,189,204,11,112,189,222,0,115,189,208,213,182,189,76,136,249,189,125,91,112,189,81,18,178,189,0,85,92,189,198,109,180,188,42,224,254,189,224,128,22,189,185,22,141,189,240,220,59,189,36,151,127,59,123,48,201,189,12,177,186,189,147,26,218,186,62,175,56,189,103,156,166,189,95,39,149,189,207,158,11,189,24,90,29,189,196,123,206,189,127,48,240,187,54,176,181,189,106,23,19,189,204,38,192,187,95,40,128,189,245,132,165,188,24,121,217,188,123,215,160,188,132,155,140,59,180,31,41,189,82,127,13,190,191,185,191,60,34,28,51,188,66,237,55,189,46,30,94,60,43,220,114,60,230,88,190,189,173,107,116,61,11,38,254,188,207,18,196,189,210,24,173,60,72,21,165,189,112,178,13,189,72,249,201,60,143,171,17,189,131,136,84,59,226,33,140,60,154,205,227,59,15,123,161,185,167,6,154,61,248,54,253,188,76,111,255,188,102,131,204,60,89,50,71,61,58,148,33,189,49,150,105,61,86,131,176,60,244,77,26,188,203,46,152,188,54,32,194,60,54,228,31,188,33,61,197,60,149,98,7,61,32,67,199,60,215,195,23,61,132,46,97,187,23,101,54,61,227,224,82,188,209,61,235,187,121,59,2,61,250,125,159,61,86,131,176,60,57,125,189,60,66,149,90,61,190,79,85,61,122,29,241,60,179,64,59,60,130,59,144,61,145,99,235,60,242,119,239,186,152,163,7,61,171,236,123,61,155,201,55,189,123,249,29,61,44,243,214,60,226,114,124,61,101,137,14,61,17,224,116,61,67,85,12,61,44,41,119,61,183,127,133,61,16,150,113,61,204,235,168,61,80,139,65,61,29,86,184,61,153,12,135,61,45,38,54,61,217,34,137,61,181,254,150,61,48,101,224,185,88,29,153,61,203,245,118,61,212,95,175,61,230,234,135,61,70,182,211,61,88,27,163,61,217,118,250,61,215,189,21,61,153,158,112,61,253,105,227,61,65,155,188,61,125,236,174,61,234,63,203,61,174,126,236,61,205,200,32,61,107,158,163,60,163,149,251,61,48,216,77,61,149,102,35,62,41,174,202,61,82,237,83,61,78,237,12,62,19,73,148,61,242,209,226,187,162,93,5,62,225,152,21,62,150,179,183,61,177,167,13,62,2,102,190,61,46,118,11,62,67,59,135,61,38,227,24,62,200,124,0,62,111,157,79,62,192,63,21,62,36,242,157,61,135,192,17,59,208,152,169,61,75,89,6,62,70,237,254,61,197,88,54,62,105,59,38,62,83,234,50,62,123,221,66,62,19,40,2,62,175,11,79,62,49,65,29,62,172,197,39,62,47,109,120,62,9,139,74,62,30,55,12,62,183,68,62,62,52,218,106,62,84,254,69,62,243,230,112,189,190,220,71,62,134,57,17,62,227,221,129,62,113,27,125,62,83,180,82,62,43,161,123,61,117,61,209,188,83,89,244,61,120,208,108,189,237,216,168,61,109,0,150,61,45,205,141,189,12,63,24,62,229,37,255,60,164,137,247,188,43,80,11,188,61,124,217,61,188,202,218,188,242,34,179,61,46,27,29,188,19,45,185,189,179,239,138,57,117,174,104,61,73,73,79,189,25,201,158,188,7,239,43,60,229,154,162,189,180,227,6,60,121,232,59,188,34,193,148,189,39,136,122,189,10,44,64,61,25,30,155,189,145,40,148,189,182,160,247,187,138,32,206,188,87,63,150,189,69,130,169,59,239,169,252,189,26,253,40,189,76,55,9,188,255,66,15,190,109,202,149,60,127,135,34,60,244,220,18,190,188,122,213,189,53,10,9,61,184,176,206,189,39,160,9,190,119,133,190,188,247,147,33,190,97,165,194,189,82,98,23,189,216,42,97,190,111,12,161,189,75,229,237,58,121,3,60,190,165,217,188,188,180,231,50,189,79,202,20,190,182,188,34,190,43,217,113,189,150,91,74,190,237,41,41,190,224,47,230,60,190,136,102,190,59,200,43,190,188,4,103,189,13,197,93,190,177,135,214,189,202,222,210,189,180,114,47,190,50,198,119,190,245,217,129,189,121,64,9,190,122,140,82,190,208,214,65,60,151,31,152,190,188,61,88,190,244,134,123,188,10,20,177,189,253,103,77,190,48,74,144,189,239,0,95,190,215,138,142,190,58,5,249,60,255,234,113,190,56,187,165,190,86,97,179,189,94,103,99,190,6,216,87,190,161,132,217,61,206,25,145,190,78,208,198,189,86,45,41,61,24,153,160,189,208,43,30,190,19,239,128,61,33,144,91,190,46,57,206,189,109,171,249,61,160,220,54,190,139,80,236,188,45,7,122,61,215,164,27,189,209,177,19,190,33,201,44,188,38,141,177,189,90,102,145,189,237,73,0,62,39,192,48,60,160,23,174,189,2,186,111,61,28,182,29,190,156,80,136,61,95,124,145,61,115,242,18,190,163,59,8,61,51,25,30,62,98,73,9,190,213,202,4,61,125,147,102,189,217,5,227,189,210,252,177,61,88,115,128,59,44,131,106,189,208,69,67,61,107,158,99,189,209,88,91,190,160,222,140,61,15,40,155,187,27,184,131,190,137,183,78,61,97,83,167,61,68,107,149,190,17,1,135,59,231,56,183,188,234,119,49,190,71,59,238,188,129,93,237,189,221,154,84,190,65,182,44,62,115,75,11,62,143,109,185,61,15,41,6,61,221,210,106,189,146,149,15,62,4,173,64,186,199,16,128,188,76,250,11,62,107,153,140,188,97,169,206,189,210,110,244,60,164,83,183,189,63,169,22,190,130,200,98,189,211,218,148,189,192,38,91,190,174,100,71,61,149,16,108,189,253,134,89,190,253,47,87,188,91,67,233,189,222,29,73,190,128,216,146,189,218,59,35,190,153,129,130,190,80,137,107,187,197,226,183,188,121,177,144,61,180,28,232,60,231,171,148,190,115,76,150,188,4,226,101,190,137,153,189,190,29,3,138,190,95,96,6,190,122,81,251,189,77,20,137,190,28,124,49,62,217,6,14,62,44,213,37,62,201,119,169,60,30,198,228,61,228,102,184,60,111,246,199,61,163,147,101,61,172,27,15,62,173,110,117,61,237,159,103,61,68,51,79,189,91,176,20,61,221,34,176,60,240,224,135,189,154,234,73,60,158,40,137,189,243,226,196,61,17,227,245,189,147,113,172,189,16,233,55,60,184,64,66,61,7,120,82,188,197,3,138,189,202,250,237,189,93,165,251,61,172,228,227,188,42,55,17,61,213,177,202,188,132,42,149,61,140,131,11,189,78,180,171,186,17,168,158,61,159,34,167,61,101,109,3,62,28,239,14,62,103,209,59,62,241,71,177,61,66,148,31,190,45,67,92,189,1,249,66,190,209,176,152,188,190,104,79,190,200,178,128,189,239,89,191,190,31,217,140,190,114,220,201,190,68,253,62,190,59,112,238,190,206,79,97,190,38,228,131,61,230,63,196,189,208,43,134,190,18,162,76,190,33,63,43,190,214,85,193,189,203,16,71,61,96,203,107,61,171,95,233,187,214,140,44,62,93,164,80,61,177,52,32,62,200,38,121,189,237,156,22,62,172,3,48,190,144,133,72,62,60,48,96,190,219,192,13,62,44,131,138,190,62,121,72,62,96,199,207,190,184,234,154,61,49,96,225,190,62,7,70,62,186,77,248,190,187,99,33,62,246,11,246,190,226,175,137,61,157,158,223,190,10,16,229,189,141,213,38,189,172,83,37,189,182,44,79,190,72,140,46,190,194,81,34,190,189,199,9,190,144,162,182,190,45,209,193,190,198,162,137,190,187,100,148,190,121,2,65,190,235,31,148,190,192,177,23,190,248,224,53,190,77,158,146,189,15,183,67,190,17,25,86,189,1,52,26,190,203,73,168,188,192,4,238,189,213,34,34,61,173,78,78,188,235,84,137,190,100,234,46,61,4,202,86,190,165,45,142,61,230,4,45,190,244,251,254,61,152,250,185,190,205,200,64,62,36,98,6,191,198,225,204,188,244,222,216,189,181,225,48,187,221,239,128,190,150,6,126,189,60,247,158,190,2,154,168,189,241,14,112,60,125,62,170,61,205,201,11,190,165,164,7,61,221,12,151,189,186,187,206,188,73,217,226,61,136,131,196,61,212,156,60,59,44,244,65,60,139,141,153,189,193,116,122,190,48,155,64,189,16,149,166,189,160,165,59,190,106,222,241,60,244,224,134,62,130,230,83,62,120,123,32,190,73,131,107,190,178,213,229,189,161,244,85,190,97,169,238,189,144,75,252,189,5,135,151,189,49,178,228,189,110,136,241,60,240,223,12,190,145,152,32,188,193,144,37,190,5,167,190,188,96,143,233,61,59,81,170,190,185,255,72,61,140,187,201,190,206,111,152,60,89,249,221,190,155,169,16,189,168,166,188,190,176,59,221,189,97,79,179,190,73,20,26,189,118,108,164,190,103,210,54,190,222,90,166,60,78,154,70,189,117,144,87,190,60,217,109,190,4,57,168,189,251,6,134,189,43,219,167,61,205,6,25,188,43,81,22,62,56,215,208,61,142,34,91,62,230,91,255,61,146,62,205,61,184,146,93,189,80,80,234,189,49,150,41,189,195,242,199,189,70,205,23,61,211,21,204,189,252,196,33,190,14,248,92,190,196,177,238,189,63,87,219,189,45,67,156,61,141,94,173,61,54,29,1,62,129,90,124,62,241,69,187,61,58,235,35,62,149,15,65,62,159,60,140,62,254,241,142,62,178,13,164,62,150,33,110,62,33,229,7,62,185,140,155,188,8,61,155,60,64,195,187,189,250,94,3,189,151,198,79,190,92,229,89,62,234,118,54,62,255,149,85,62,188,122,117,62,160,108,74,61,234,120,204,61,18,49,21,190,80,251,45,188,162,180,7,190,177,51,165,190,151,26,161,60,56,164,1,62,194,136,133,62,191,69,23,62,208,97,110,190,85,222,142,186,89,22,76,189,35,105,103,62,19,125,30,190,205,231,156,61,121,115,56,61,229,181,98,62,242,91,164,62,220,130,37,62,31,129,127,189,254,124,91,61,17,109,7,62,95,152,124,62,104,6,201,62,34,55,139,62,175,119,135,190,187,153,209,61,194,134,167,190,1,22,249,61,224,157,204,190,5,221,254,61,190,222,221,189,154,120,55,62,226,144,205,61,214,29,59,62,148,190,80,62,193,197,74,61,30,198,100,190,161,248,113,190,163,148,64,190,16,36,79,190,199,245,95,190,224,213,210,189,136,216,128,190,109,226,36,190,102,73,0,190,203,72,45,190,129,120,13,190,226,204,15,190,72,169,52,190,167,37,22,190,165,249,99,190,191,244,246,189,72,197,63,190,233,124,56,190,158,64,72,190,71,3,152,189,233,42,45,190,45,5,20,190,89,51,18,190,72,51,150,189,126,84,227,189,127,246,227,189,44,213,5,190,58,3,195,189,93,224,50,190,229,12,229,189,24,179,229,189,91,11,211,189,41,208,71,190,7,183,117,189,3,149,17,190,110,163,33,190,13,169,2,190,63,1,84,189,155,200,28,190,239,144,130,189,27,14,139,189,73,14,40,190,179,39,17,190,61,211,139,189,249,105,188,189,249,187,119,189,102,245,206,189,140,185,203,189,110,108,214,189,7,237,213,189,14,47,136,189,73,213,150,189,199,129,87,189,18,159,187,189,218,197,180,189,226,60,156,188,48,19,5,190,13,80,154,188,63,58,213,189,180,231,2,190,102,49,177,188,174,100,7,189,30,252,4,190,143,142,171,189,189,194,66,189,99,154,41,189,3,239,100,189,225,66,222,189,124,242,48,189,97,222,227,188,244,254,127,189,225,98,69,189,46,83,19,187,19,40,226,189,240,192,128,189,33,118,166,58,233,43,8,189,140,72,148,189,122,23,47,189,50,172,98,188,71,144,10,189,48,18,26,189,137,97,23,190,14,218,171,189,10,106,56,189,236,247,196,59,235,201,188,189,196,123,78,189,137,151,167,189,224,160,189,59,187,43,187,57,205,145,213,189,230,119,26,188,180,33,127,187,103,42,68,189,249,100,197,186,200,39,36,189,1,164,22,190,94,133,20,188,61,70,121,189,254,184,253,188,194,249,84,60,56,107,112,188,146,145,179,58,84,254,181,59,225,150,207,189,35,22,1,190,80,198,248,186,123,245,209,189,234,120,204,185,84,201,128,188,26,223,7,190,164,142,142,189,12,64,163,188,100,92,209,189,146,234,155,189,162,97,49,61,14,18,98,189,51,49,221,60,221,67,66,60,102,46,32,190,138,57,136,188,56,50,143,60,87,64,161,189,51,23,56,59,99,123,109,61,113,147,33,190,194,191,136,188,58,148,97,189,217,179,55,190,253,159,195,189,169,193,180,60,128,186,225,189,81,134,42,60,88,201,167,189,195,102,0,190,158,40,73,61,63,169,54,61,20,117,230,189,217,96,129,61,85,108,204,188,68,250,61,190,12,120,89,61,99,125,3,189,222,33,53,190,181,192,158,188,168,198,235,189,238,178,127,190,24,180,144,188,30,111,114,189,128,12,77,190,184,148,211,189,142,230,136,189,78,239,98,189,18,193,56,61,163,121,64,189,57,155,14,186,97,224,185,60,182,160,55,189,76,170,182,60,22,20,134,188,203,100,184,188,68,167,231,60,107,14,144,60,170,13,206,189,19,14,125,61,74,155,170,188,51,167,139,189,169,218,238,60,102,135,152,189,9,139,202,189,80,109,48,61,251,177,137,189,170,69,4,189,48,103,118,61,122,222,13,61,147,227,14,189,170,184,145,61,34,109,99,188,187,11,20,188,160,252,93,61,126,171,245,188,77,73,6,190,79,87,247,60,120,154,204,60,8,144,33,60,125,36,101,61,176,144,57,189,227,197,2,61,141,14,8,61,79,119,30,187,231,82,28,61,234,176,130,61,72,225,58,61,210,84,207,60,122,253,9,61,172,0,31,61,58,146,75,61,41,178,150,61,117,177,233,60,70,148,118,61,20,94,2,188,239,146,184,60,36,241,50,61,144,249,128,186,68,78,95,61,211,136,153,60,7,125,105,61,14,131,121,61,101,27,120,61,78,236,33,60,206,168,121,60,170,69,164,61,110,77,186,60,94,16,145,61,218,3,141,61,148,23,89,61,40,10,244,60,10,72,187,61,232,220,45,189,248,79,119,61,148,191,123,61,243,86,157,61,114,222,127,61,254,155,183,61,159,2,32,61,134,226,142,61,98,249,243,61,116,94,131,61,111,72,195,61,8,174,146,61,142,90,193,61,44,100,142,61,172,253,93,61,163,91,47,61,62,150,190,61,80,54,229,60,201,33,194,61,154,35,203,61,207,19,207,61,9,222,240,61,216,17,71,61,251,176,190,61,223,168,245,61,140,104,251,61,230,33,83,61,55,22,212,61,238,148,174,61,14,79,47,188,161,186,25,62,49,205,116,61,62,34,166,60,181,81,221,61,26,168,140,60,46,0,13,60,91,12,222,61,19,125,190,60,6,244,130,189,59,253,160,60,162,9,148,61,184,120,248,188,33,88,69,62,193,224,154,61,61,186,145,61,134,114,98,62,3,180,141,61,74,181,15,189,71,227,64,62,147,58,1,62,23,72,16,61,223,55,62,62,218,83,50,61,110,79,208,189,91,39,46,189,52,19,204,61,74,153,84,59,104,206,122,188,184,115,225,188,202,112,60,61,195,157,11,61,170,128,59,189,225,149,196,61,224,19,235,59,123,50,191,189,203,75,62,61,108,233,81,189,84,87,126,189,80,80,170,61,84,226,58,189,15,128,8,190,98,19,89,61,30,254,26,189,186,243,196,60,75,62,6,62,31,158,165,188,0,115,237,189,181,50,1,62,122,199,9,190,223,165,20,189,202,252,227,61,171,117,226,189,85,221,35,190,34,23,188,61,68,24,191,189,161,101,61,190,103,96,100,60,248,112,169,189,93,111,43,190,152,221,83,189,46,3,46,190,179,39,49,190,126,116,234,187,101,82,3,190,234,60,90,190,230,119,90,189,114,137,163,189,150,208,29,190,142,118,124,190,48,16,4,189,119,187,222,189,62,8,81,190,213,122,15,190,107,72,76,190,164,170,145,190,165,162,49,60,151,142,153,189,51,83,42,190,227,26,191,189,116,124,20,62,237,182,11,61,238,181,32,189,56,220,231,61,193,111,227,61,209,89,38,61,228,46,2,189,67,60,50,62,111,44,40,190,58,147,6,62,46,112,25,62,181,78,220,60,36,182,219,61,162,153,55,62,64,221,64,61,156,105,34,62,166,125,211,61,110,133,144,189,144,130,87,62,182,247,9,62,152,80,193,61,214,86,12,62,189,229,42,62,55,53,176,61,154,94,130,61,118,224,44,62,39,50,35,62,217,152,247,61,195,15,30,62,165,161,22,62,89,138,36,62,65,71,235,61,102,21,246,61,13,113,76,62,111,74,57,62,209,2,68,62,33,176,50,62,229,212,46,62,1,249,34,62,180,147,17,62,132,242,110,62,239,145,109,62,12,201,25,62,65,103,210,61,116,209,64,62,73,15,99,62,234,60,106,62,116,121,131,62,170,183,86,62,43,105,37,62,91,6,132,62,115,189,125,62,162,67,128,62,119,104,40,190,69,242,21,185,66,10,110,62,183,150,201,60,152,24,203,59,150,208,93,190,207,220,203,190,187,128,183,189,240,51,78,190,44,155,249,189,203,77,156,190,169,74,27,61,135,249,114,61,79,2,123,62,120,242,121,62,245,160,136,62,253,218,58,62,107,131,163,62,83,93,80,62,254,43,179,62,142,90,129,62,147,166,201,62,189,252,142,62,181,51,228,62,213,32,132,62,240,78,198,62,239,172,77,62,160,255,30,189,166,182,4,62,213,207,27,188,25,141,156,61,40,185,195,188,151,1,231,188,243,227,239,189,103,126,21,190,35,16,63,190,254,158,88,189,186,73,12,189,250,38,173,189,81,21,179,189,181,110,195,189,210,25,232,190,75,174,50,190,238,90,186,190,18,190,23,190,46,56,171,190,168,86,79,190,224,159,98,190,243,171,57,190,35,75,6,190,123,77,79,189,25,112,214,189,255,205,235,61,48,100,69,62,117,3,141,62,2,100,104,60,188,233,70,62,137,234,29,62,82,101,104,62,114,24,172,61,203,20,99,62,9,252,65,62,253,131,40,62,236,223,5,62,170,16,47,62,77,214,136,189,7,238,128,61,160,109,53,190,168,166,20,190,244,140,125,190,164,225,4,190,48,101,64,190,120,98,150,190,147,228,121,190,159,118,176,190,191,239,79,190,242,149,112,190,190,222,149,190,29,57,34,190,122,25,133,61,48,184,230,188,59,53,23,62,38,30,176,61,12,35,221,61,17,167,19,59,101,254,145,61,227,140,225,60,216,43,172,60,109,2,76,189,237,74,139,190,232,21,95,190,50,87,134,189,76,55,9,60,9,112,26,190,210,52,72,190,174,44,81,188,232,103,26,190,24,68,116,62,113,226,11,62,20,95,149,62,106,133,233,61,143,138,79,62,49,97,212,61,95,94,16,62,46,169,26,61,252,194,131,190,6,128,226,190,85,46,164,190,57,181,163,190,42,58,250,190,118,137,26,191,64,106,163,190,105,138,240,190,187,68,117,60,227,255,206,189,244,82,209,61,50,201,136,61,203,15,156,189,73,216,55,189,27,72,151,61,0,58,28,62,255,231,144,61,231,25,187,189,101,57,137,188,23,244,222,60,212,209,145,61,249,157,198,61,236,192,121,189,33,34,21,190,159,202,233,61,116,209,240,61,171,203,145,190,56,101,238,188,223,137,129,190,49,211,150,189,183,236,80,190,44,182,201,189,44,131,234,189,218,198,159,58,217,176,102,190,66,147,68,188,122,83,113,190,53,181,172,61,158,206,37,62,253,105,3,62,117,172,210,60,89,165,244,61,162,181,130,190,248,28,144,190,122,29,201,190,130,55,196,189,151,174,32,61,185,194,27,190,241,46,159,190,172,58,203,189,157,156,137,190,101,85,4,61,36,40,174,190,4,27,87,60,108,149,176,190,140,246,56,189,245,241,64,190,30,253,135,62,204,69,44,190,230,93,117,186,151,56,242,57,98,16,152,62,71,0,135,62,195,15,190,62,244,81,22,190,48,42,201,189,205,234,197,190,36,154,144,190,254,72,145,189,115,215,130,190,234,37,150,62,9,109,129,62,228,16,209,62,77,135,198,62,59,138,195,190,26,196,183,190,187,95,237,190,21,145,161,190,132,185,165,190,134,85,132,190,53,7,128,62,175,206,145,61,183,125,207,190,183,8,220,190,134,1,11,190,252,166,128,190,148,79,63,62,40,124,118,61,110,22,239,61,20,62,91,189,23,128,206,190,140,160,97,190,175,10,212,190,175,234,172,188,231,112,213,190,189,141,77,61,184,174,240,190,115,242,162,189,75,144,161,190,108,122,96,62,164,222,139,190,110,194,13,62,126,167,129,62,14,221,156,62,186,17,54,62,249,77,177,62,22,104,87,62,134,174,84,62,44,159,165,190,72,194,158,61,114,197,69,190,232,77,69,61,200,122,234,61,255,230,149,62,134,231,5,190,36,38,104,61,146,176,47,190,32,211,178,190,154,122,189,190,252,80,9,191,174,73,159,190,235,167,199,190,175,123,171,62,117,62,188,62,132,214,179,62,145,152,224,62,70,208,4,63,254,153,169,62,118,198,223,62,59,142,167,62,166,71,163,62,23,98,157,62,59,195,212,188,95,184,83,190,75,30,191,62,207,159,166,62,5,109,242,62,208,100,199,62,230,4,245,62,27,187,244,62,137,98,170,62,77,132,29,62,56,48,89,62,150,152,231,62,6,102,37,62,137,178,55,188,145,100,86,62,201,119,169,60,34,170,176,189,157,102,81,62,55,252,198,190,237,216,8,62,175,67,53,190,52,161,9,62,142,31,90,190,143,54,150,190,3,68,169,190,25,175,89,190,155,198,118,190,170,45,173,190,228,187,100,190,21,200,156,190,28,236,141,190,113,175,108,190,55,81,147,190,251,234,106,190,110,48,116,190,132,14,106,190,195,155,133,190,55,80,16,190,73,242,124,190,195,98,132,190,61,130,11,190,59,169,127,190,241,69,179,190,235,84,25,190,237,153,69,190,126,29,144,190,65,17,43,190,156,168,133,190,33,3,73,190,85,76,53,190,225,39,78,190,243,226,84,190,34,113,239,189,176,113,77,190,106,160,89,190,20,36,38,190,158,65,19,190,169,249,122,190,163,5,168,189,59,114,68,190,116,93,136,190,198,111,202,189,232,131,85,190,22,22,164,190,238,119,232,189,24,33,28,190,57,208,99,190,75,146,135,189,35,105,55,190,238,204,84,190,7,153,4,190,57,98,45,190,182,246,30,190,112,120,161,189,232,219,66,190,105,229,30,190,62,203,179,189,69,70,23,190,89,106,45,190,1,108,16,190,141,66,2,190,10,46,54,190,197,143,1,190,8,86,101,190,139,83,29,190,92,204,207,189], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+728424);
/* memory initializer */ allocate([10,131,66,190,233,157,234,189,78,209,209,189,99,181,217,189,146,204,26,190,183,94,211,189,137,236,19,190,108,208,215,189,159,228,46,190,201,229,15,190,200,179,11,190,58,176,44,190,2,240,79,190,233,157,10,190,119,130,13,190,110,167,237,189,115,46,229,189,42,145,20,190,127,160,44,190,226,171,189,189,127,105,1,190,170,184,97,190,166,9,187,189,95,11,90,190,109,59,61,190,112,36,208,189,45,92,70,190,233,237,15,190,217,93,160,189,153,215,49,190,184,2,74,190,92,85,118,189,131,165,74,190,120,182,119,190,236,104,188,189,42,200,31,190,154,92,132,190,57,157,228,189,105,197,119,190,3,182,67,190,139,79,129,189,91,206,133,190,153,160,118,190,223,54,211,189,158,240,98,190,167,205,120,190,1,251,40,189,198,139,101,190,235,83,110,190,21,114,37,190,41,122,80,190,198,196,150,190,82,15,1,190,167,145,86,190,89,54,155,190,201,200,89,189,207,249,129,190,228,18,151,190,146,203,31,190,194,104,142,190,152,134,169,190,188,144,174,189,98,189,153,190,31,133,75,190,84,56,194,189,62,93,133,190,63,201,45,190,202,167,7,190,110,249,88,190,200,151,48,190,71,57,40,190,211,217,105,190,65,41,250,189,9,81,254,189,187,94,130,190,141,236,10,190,35,78,167,189,127,18,135,190,114,165,30,190,233,184,90,190,137,207,157,190,84,226,218,189,1,220,172,189,171,119,120,190,141,179,169,189,67,202,175,189,39,17,129,190,0,228,132,189,146,3,22,190,251,234,74,190,64,132,216,189,152,107,65,190,155,199,65,190,6,72,180,189,69,189,224,189,33,87,74,190,50,116,204,189,205,88,52,189,153,188,137,190,207,17,217,189,8,60,176,188,193,230,108,190,124,242,112,189,99,154,41,189,206,0,103,190,199,73,225,188,241,128,178,189,1,50,36,190,249,246,110,189,106,104,163,189,219,137,34,190,180,33,223,189,169,192,137,189,24,147,46,190,165,46,89,189,22,220,143,188,119,105,51,190,14,160,95,188,37,206,74,189,131,191,31,190,73,245,221,189,164,198,132,187,172,60,97,190,105,173,168,189,216,240,116,60,8,3,95,190,67,174,84,188,103,44,26,188,120,127,252,189,72,81,39,189,63,145,39,189,175,121,245,189,65,184,194,189,130,196,118,189,61,183,240,189,219,25,134,189,199,130,66,59,198,106,211,189,200,8,232,189,229,185,190,188,68,163,11,190,210,28,25,190,45,123,82,189,86,100,244,189,121,88,40,190,192,36,21,188,161,15,214,189,156,164,121,189,68,25,170,189,37,90,146,189,198,248,144,189,43,249,24,189,37,32,166,189,99,151,24,190,52,104,104,189,255,117,142,189,2,99,221,189,110,167,141,189,254,213,99,189,41,95,240,189,164,139,205,188,144,75,188,189,55,167,66,190,136,215,117,189,79,118,147,189,179,121,44,190,127,77,214,187,211,106,8,189,29,34,30,190,163,172,95,189,218,255,128,189,171,36,2,190,15,208,221,189,198,51,104,189,154,233,46,190,162,154,210,189,66,177,149,188,133,238,2,190,80,142,194,189,222,90,102,189,228,74,253,189,181,197,21,190,112,9,192,188,235,83,30,190,11,183,12,190,61,152,84,189,43,133,160,189,225,69,191,189,165,48,111,188,245,213,213,189,214,56,11,190,166,71,83,189,33,118,166,189,184,4,16,190,167,231,189,189,204,69,188,189,163,206,220,189,187,70,203,188,120,96,16,190,14,164,59,190,99,179,131,189,32,121,231,189,129,118,71,190,197,118,247,184,16,118,202,189,41,6,72,190,0,29,230,188,46,170,69,189,24,10,40,190,215,79,191,189,192,63,101,189,138,227,48,190,36,98,234,189,29,174,213,189,112,94,92,190,207,186,70,189,134,59,7,190,162,210,120,190,109,115,35,190,56,190,118,189,210,224,54,190,72,252,10,190,73,47,138,189,129,10,7,190,188,177,160,189,213,207,27,189,134,27,0,190,50,57,53,188,51,24,131,189,108,233,209,189,24,205,10,189,18,247,216,188,222,61,224,189,33,58,4,190,58,234,104,188,117,0,228,189,116,67,67,190,174,42,251,188,181,21,11,190,4,3,168,189,195,44,52,60,91,36,205,189,255,205,59,190,94,102,216,58,151,172,202,189,163,35,153,189,27,129,248,188,65,215,126,189,186,21,2,189,145,14,79,189,99,98,115,189,179,177,82,189,187,99,49,60,36,153,85,189,46,201,1,190,79,92,14,60,52,186,67,189,1,107,21,190,29,28,44,61,37,148,158,189,49,152,191,189,13,197,93,61,137,178,119,189,243,171,185,189,78,212,82,60,174,13,149,188,69,101,163,189,117,117,7,189,171,63,194,58,126,53,7,189,128,239,182,188,147,170,109,188,139,56,157,187,133,10,142,188,100,64,118,189,215,248,204,188,215,47,216,60,14,216,85,187,184,89,188,186,94,241,212,60,95,126,39,189,193,59,153,189,96,176,155,60,113,174,225,60,90,103,252,188,204,121,70,188,97,109,12,61,181,84,222,59,151,82,151,59,101,84,153,60,31,106,91,60,111,132,5,189,132,103,194,188,114,110,19,61,69,101,195,59,111,160,64,188,58,60,4,60,90,100,59,189,4,228,203,60,164,228,85,60,120,151,139,60,251,173,93,61,209,207,84,188,80,195,55,61,159,203,20,61,12,62,205,60,186,18,65,61,253,105,35,60,112,94,92,61,241,16,198,60,116,37,2,61,186,47,103,61,107,15,251,188,119,106,174,60,110,21,4,61,252,198,87,61,67,85,76,61,22,223,16,61,115,190,184,61,255,150,0,61,235,139,132,61,162,40,144,61,155,174,39,61,58,36,181,60,158,153,96,61,36,125,186,61,199,17,43,61,203,162,176,61,236,194,143,61,83,174,144,61,242,63,121,61,0,111,161,61,253,163,111,61,208,155,138,60,49,36,167,61,181,254,22,55,233,38,177,61,58,36,117,61,24,237,145,61,86,240,219,61,56,218,113,61,31,243,193,61,137,239,196,61,197,84,186,61,29,33,67,61,123,19,227,61,251,202,227,61,235,195,250,61,127,46,186,61,17,24,107,61,86,185,208,61,122,55,86,61,184,3,245,60,125,203,156,61,13,82,176,61,47,162,237,187,232,190,252,61,69,15,252,60,79,120,169,61,57,213,10,62,51,253,210,61,169,77,28,60,141,240,246,61,158,179,133,61,225,98,197,188,104,175,158,61,92,175,233,60,89,167,74,188,65,214,3,62,30,165,146,60,239,226,125,187,86,13,34,62,58,91,64,61,119,75,242,60,217,123,209,61,109,230,16,187,75,230,24,61,132,156,183,61,85,20,175,188,175,176,224,187,29,58,13,62,65,13,223,60,92,0,90,189,232,49,202,61,244,192,71,188,207,186,70,189,143,250,171,61,43,21,20,61,162,10,127,189,210,140,69,61,222,201,39,188,47,49,86,189,117,142,225,61,28,206,252,59,133,9,195,189,186,221,139,61,218,145,106,188,40,13,213,189,185,226,130,61,119,20,103,189,52,18,129,189,114,53,114,61,34,253,54,189,70,206,194,188,59,227,251,60,73,244,178,60,213,206,176,189,17,143,196,60,205,171,58,189,134,31,156,189,24,152,85,61,15,11,117,189,24,153,224,189,219,106,86,60,216,71,167,188,77,190,249,189,146,202,148,60,186,44,198,189,193,198,181,189,21,114,165,60,78,156,156,189,23,17,69,189,112,38,166,60,38,115,172,189,176,201,10,190,187,38,36,61,17,253,90,189,245,213,37,190,235,200,145,188,93,22,211,189,35,244,115,189,116,9,135,188,131,164,143,189,145,42,138,188,92,228,158,59,112,92,230,189,154,64,145,188,208,126,36,61,186,74,151,189,29,142,174,187,110,79,16,59,34,254,193,189,179,209,57,61,217,34,105,189,94,18,167,189,152,110,146,60,84,195,254,188,231,27,17,190,224,128,22,60,219,137,210,189,8,61,251,189,100,64,246,60,247,202,124,189,74,153,20,190,103,10,157,61,68,191,150,189,87,179,78,189,244,51,149,61,252,112,240,189,95,153,71,190,242,64,36,61,130,174,61,190,174,211,8,190,136,42,60,61,167,4,36,190,207,101,106,189,101,0,104,61,210,197,54,190,242,152,49,190,121,201,255,187,200,182,76,190,101,200,81,190,175,233,65,61,59,254,27,190,131,164,127,190,115,243,13,61,160,23,62,190,15,124,108,190,100,202,7,187,114,250,250,189,192,95,92,190,71,33,201,188,96,145,127,190,68,191,86,190,15,40,27,60,90,243,35,190,132,241,131,190,58,231,39,189,8,229,93,190,20,38,148,190,201,172,222,60,200,210,103,190,107,100,23,190,110,77,186,188,86,213,147,190,63,87,139,190,39,134,100,188,122,109,134,190,78,185,114,190,185,108,148,61,7,207,156,190,228,218,64,190,220,187,6,189,241,242,132,190,203,14,177,190,14,189,197,60,180,204,138,190,55,111,12,190,170,126,37,61,11,38,78,190,23,213,146,190,65,101,220,61,229,97,113,190,72,81,39,190,11,39,233,61,229,211,35,190,170,210,86,190,168,169,229,61,248,165,134,190,64,105,104,189,19,128,191,61,145,240,141,190,45,206,24,189,54,35,131,60,204,67,150,190,138,145,37,189,150,6,126,189,64,20,92,190,200,152,187,60,3,125,98,61,189,253,129,190,87,236,111,61,193,85,30,185,11,156,124,190,41,151,198,60,29,145,111,189,176,61,19,190,182,189,221,59,28,96,102,60,29,145,63,190,126,56,72,61,133,235,17,189,245,20,73,190,210,140,229,61,97,54,1,61,32,126,254,189,14,136,176,61,195,100,170,188,107,71,1,190,179,239,138,60,219,19,196,61,146,118,163,189,181,167,164,61,57,13,81,61,83,122,102,189,212,96,154,61,182,133,231,188,9,197,246,189,19,15,24,62,8,230,232,60,203,161,37,190,34,113,207,61,70,68,241,61,159,203,84,187,243,201,170,61,131,195,139,188,237,74,11,189,136,246,17,62,122,140,242,59,85,21,26,189,107,239,211,60,174,73,183,61,2,157,169,189,135,220,60,62,119,246,149,61,191,73,211,59,251,5,43,62,90,246,164,61,118,166,16,61,129,122,19,62,21,229,82,59,23,45,192,188,106,134,180,61,57,68,28,62,162,179,204,59,68,107,197,188,105,81,159,61,228,103,35,61,76,223,107,61,75,229,45,189,141,65,167,188,151,255,16,61,222,115,192,189,101,141,154,61,3,64,85,61,115,19,21,62,159,204,159,61,61,39,61,62,212,156,188,61,123,189,219,61,237,240,23,62,254,98,182,60,140,17,137,61,82,101,88,189,88,87,133,61,115,17,191,61,76,252,241,61,26,105,25,62,213,121,244,61,157,103,12,62,136,217,203,61,13,251,13,62,118,164,154,61,150,236,248,61,156,51,50,62,147,200,158,61,200,10,158,61,179,209,41,62,146,174,25,62,10,160,8,62,68,111,49,62,215,160,31,62,239,56,69,61,225,209,38,62,44,102,196,61,129,5,48,62,19,186,91,62,211,49,231,61,175,180,236,61,75,171,81,62,13,228,217,61,205,115,4,61,62,37,55,62,111,244,81,62,74,7,235,61,156,168,53,62,103,100,144,61,31,189,97,188,72,108,119,62,87,237,42,62,159,88,135,61,131,221,96,62,81,245,59,62,205,119,48,62,57,71,253,61,53,241,46,62,172,58,43,62,192,90,53,62,52,246,117,62,229,212,62,62,250,67,139,62,199,127,97,62,72,25,1,62,244,254,191,61,212,128,113,62,169,220,36,62,255,231,16,62,129,146,66,62,157,47,118,62,37,3,64,61,36,10,45,62,93,251,66,62,226,89,194,61,189,54,219,61,160,164,112,62,124,101,222,61,159,0,138,62,18,106,134,62,91,92,227,188,194,250,111,62,231,197,9,62,186,190,135,62,1,251,136,62,103,209,75,62,194,79,76,62,104,64,149,62,126,196,135,62,90,72,136,62,246,92,86,62,145,99,179,62,6,242,164,62,215,136,176,62,80,169,138,62,42,199,204,62,135,51,135,62,148,18,226,61,8,62,142,62,251,118,2,62,133,235,17,189,115,73,53,190,150,38,85,62,164,222,243,61,222,2,73,61,7,64,156,189,68,53,21,62,106,189,63,62,54,147,47,61,183,37,2,190,177,109,241,61,1,108,192,188,93,252,13,190,1,138,145,190,205,147,139,61,129,123,254,61,212,44,208,60,145,184,199,59,224,244,142,189,86,125,46,60,18,46,52,190,91,66,62,190,35,164,14,190,72,169,68,189,201,229,31,190,238,204,4,190,36,96,36,190,30,79,139,61,179,121,76,62,92,28,133,62,143,29,132,62,133,208,113,62,23,243,187,62,188,3,156,62,54,231,128,62,196,152,156,62,134,227,201,62,143,169,195,62,38,172,229,62,172,196,172,62,190,133,165,62,101,227,217,62,66,206,123,60,87,149,253,61,194,76,219,188,205,201,171,61,171,180,229,189,142,176,200,189,220,43,99,190,182,46,37,190,123,219,76,189,111,46,190,189,121,30,92,190,238,7,204,190,86,153,233,189,149,44,119,190,196,66,13,62,56,47,14,62,141,36,1,61,175,151,134,61,94,190,85,62,167,150,173,61,147,166,33,62,210,169,107,61,238,124,255,61,126,84,67,60,48,74,16,189,63,26,30,190,113,28,216,189,235,53,149,190,224,128,150,189,117,203,78,190,126,144,101,190,171,236,139,190,44,13,44,190,107,16,118,190,250,13,139,190,10,245,196,190,193,142,255,189,106,133,105,60,10,244,137,59,213,34,226,189,223,26,152,61,27,213,105,188,88,83,89,61,232,163,140,189,77,133,184,189,220,127,20,190,222,62,155,62,234,94,87,62,205,174,211,62,217,67,139,62,31,188,182,62,119,46,108,62,50,31,16,189,130,30,234,188,64,194,240,189,44,188,235,61,225,11,35,190,81,160,95,62,200,179,107,190,246,12,49,62,231,85,93,190,235,173,225,189,114,111,158,62,109,227,207,61,24,64,128,62,49,91,242,61,144,46,150,62,124,213,26,62,23,156,193,188,23,131,7,61,21,25,157,61,106,133,233,61,208,37,252,61,40,158,179,61,111,216,118,189,125,148,1,62,234,34,101,190,236,109,179,188,113,203,119,190,72,251,167,190,72,136,82,62,167,121,23,62,77,50,178,189,135,77,132,61,149,102,147,190,145,123,146,190,1,194,55,190,145,153,179,190,123,215,96,190,104,120,51,61,49,122,94,190,118,113,123,62,250,207,146,190,21,83,57,190,133,205,48,62,81,165,230,61,125,231,215,189,189,25,53,62,11,96,202,59,58,232,82,189,254,100,204,61,193,141,52,62,80,25,63,190,99,69,141,189,60,164,40,62,92,117,61,62,169,22,5,63,159,145,192,62,237,157,5,63,152,162,8,63,53,94,242,62,154,10,225,62,107,96,91,62,222,85,79,62,111,71,20,63,144,22,239,62,149,238,158,62,252,199,138,62,125,208,131,62,5,106,113,61,110,21,196,60,249,135,45,190,98,162,137,190,212,40,132,189,196,92,50,190,56,158,79,185,97,108,137,190,95,40,112,190,187,209,151,190,69,18,125,62,50,119,237,61,115,218,147,189,28,122,155,190,122,169,24,62,220,13,178,190,188,65,52,188,110,51,101,190,187,70,91,190,149,211,142,190,179,123,234,190,131,192,10,62,110,48,116,62,38,30,160,62,61,126,175,62,195,243,146,61,19,239,0,190,222,204,248,62,243,86,133,62,89,191,25,61,228,21,56,62,197,113,200,62,91,180,32,62,135,109,203,62,78,9,248,62,192,4,158,190,105,81,175,190,225,8,138,190,47,137,3,190,219,134,177,189,176,169,51,189,99,156,215,62,64,165,90,62,62,202,168,61,132,186,72,61,194,246,179,189,77,215,115,62,43,132,173,62,63,30,42,62,231,254,42,190,177,162,22,62,38,58,43,190,0,145,150,190,112,181,22,63,85,23,168,62,150,62,84,62,198,194,144,60,203,14,17,190,56,17,149,62,251,58,16,190,1,167,191,62,190,217,230,60,8,32,165,62,229,95,107,190,86,244,167,62,167,205,120,189,200,150,133,190,204,94,54,188,75,91,124,62,190,47,110,189,239,27,159,62,204,152,2,190,8,232,62,190,137,155,3,190,234,117,171,190,54,91,145,190,98,48,159,61,194,105,1,189,255,91,57,62,241,157,168,190,104,121,222,189,175,234,92,190,241,18,220,61,157,243,51,62,28,126,167,62,89,248,130,62,135,77,52,62,77,190,105,62,26,49,203,62,201,231,189,190,224,133,61,190,166,212,181,190,175,206,153,190,162,152,124,61,84,112,120,62,84,254,213,61,133,177,157,62,203,217,163,190,56,158,111,190,39,105,158,61,112,35,213,62,37,207,173,190,32,178,208,190,50,203,158,188,15,70,92,190,57,68,44,62,112,237,4,189,215,105,36,189,249,159,204,62,72,223,140,190,202,164,6,60,173,76,184,189,232,159,48,190,187,69,80,190,81,247,193,189,186,249,54,190,233,181,9,190,151,1,103,189,109,30,7,190,63,53,30,190,246,96,82,189,156,54,3,190,110,80,75,190,36,185,124,189,7,66,18,190,187,212,128,190,125,8,42,189,23,211,236,189,20,237,106,190,41,175,21,189,64,47,220,189,174,71,49,190,255,230,197,188,70,37,181,189,32,11,81,190,104,121,30,189,154,178,211,189,177,219,7,190,153,72,105,189,42,142,3,190,179,92,214,189,153,186,171,188,116,65,157,189,163,29,39,190,160,52,84,188,185,52,158,189,92,119,3,190,169,75,6,189,1,191,198,189,197,113,192,189,142,60,16,189,60,133,92,189,204,64,229,189,28,235,98,188,184,63,23,189,0,172,14,190,241,101,162,187,244,78,133,189,199,160,179,189,81,216,133,189,172,86,134,189,78,236,161,189,105,141,193,188,237,210,166,189,148,251,93,189,166,237,223,188,3,92,16,189,105,85,139,189,90,158,135,60,183,209,64,189,104,93,3,190,155,146,172,60,142,149,24,189,254,127,188,189,148,136,112,60,232,78,48,189,187,127,108,189,57,38,11,188,56,106,5,188,46,228,209,189,238,237,22,187,94,17,124,189,213,5,188,188,90,155,198,187,70,238,105,188,174,214,9,189,76,226,172,187,37,65,56,60,93,137,128,189,188,207,49,61,101,137,206,187,224,132,130,189,38,252,18,61,37,177,36,188,42,29,236,189,146,231,250,60,253,45,1,189,252,223,145,188,221,12,183,60,168,24,231,60,180,113,4,189,238,95,217,60,45,147,225,60,218,172,186,189,85,135,92,187,101,85,4,188,6,130,128,60,55,25,213,188,123,77,143,60,5,168,41,188,86,242,113,61,59,58,46,60,56,190,246,187,49,97,52,61,21,31,159,188,146,120,249,60,229,184,19,189,7,37,12,189,210,54,254,187,143,52,184,60,146,65,46,61,160,79,228,60,18,189,76,189,177,196,131,188,206,82,178,60,168,227,177,188,131,104,173,60,165,77,85,61,221,8,139,187,54,202,122,189,72,109,226,60,40,15,11,189,119,157,141,188,93,106,132,61,26,79,132,60,37,148,62,58,190,134,128,61,56,245,129,189,39,192,48,189,153,69,104,61,41,174,138,189,157,188,200,59,14,76,110,61,29,118,31,189,17,167,83,61,89,248,250,60,240,137,149,189,180,4,153,189,141,41,216,60,216,102,35,189,187,71,214,189,99,68,34,61,223,222,149,189,105,200,152,189,203,19,168,61,192,123,135,189,151,168,222,188,173,166,203,61,40,241,153,189,248,28,248,189,59,84,147,61,172,227,248,188,162,155,189,189,86,129,186,61,76,24,173,189,207,215,12,190,80,139,193,60,0,173,121,189,163,86,248,189,219,21,122,188,67,83,246,188,70,38,192,189,228,104,14,188,216,45,130,189,175,148,133,189,119,132,211,188,140,75,85,189,166,213,240,189,116,124,116,189,11,180,187,189,28,35,41,190,193,170,58,189,183,179,143,189,40,130,248,189,51,222,6,62,77,244,121,189,192,34,191,187,19,10,81,189,195,102,0,60,4,61,84,189,199,186,152,61,71,173,144,189,143,226,92,189,1,22,25,62,209,61,107,188,12,144,136,189,157,15,15,62,113,84,110,189,94,73,242,60,106,78,190,61,138,116,191,188,204,70,231,59,3,94,230,61,231,112,109,189,181,169,186,60,106,251,23,62,15,42,241,60,248,198,144,188,159,172,248,61,18,134,129,188,99,151,104,61,163,149,187,61,71,113,142,59,74,41,104,61,7,40,13,62,191,70,146,187,61,124,25,59,231,109,60,62,135,249,242,60,194,250,63,61,128,70,169,61,206,85,115,61,78,43,133,58,204,65,176,61,117,91,98,61,223,226,225,60,5,194,30,62,199,161,126,61,199,187,131,61,53,96,240,61,74,37,188,60,4,231,204,61,48,41,158,61,60,49,43,61,123,79,197,61,216,130,46,62,181,220,89,61,64,195,251,61,209,201,242,61,146,4,193,61,244,109,193,61,143,141,160,61,0,197,168,61,212,214,8,61,191,72,40,61,144,73,198,61,112,124,237,61,247,4,25,62,211,220,138,61,248,139,249,61,113,141,207,60,60,248,9,188,161,163,213,61,175,91,4,61,250,14,254,60,82,243,149,61,202,135,160,187,230,61,174,61,64,21,119,61,57,182,30,188,41,205,230,60,26,252,189,61,87,178,99,189,228,161,143,61,60,102,32,61,214,255,121,189,183,155,32,189,203,131,148,61,180,145,235,188,104,204,4,62,246,70,205,61,250,128,64,189,185,227,29,62,199,101,220,61,49,180,186,60,77,15,74,189,138,227,192,61,245,48,180,61,187,236,87,188,217,150,1,62,244,25,0,62,48,128,112,189,243,198,201,61,220,129,26,62,128,100,186,188,207,220,163,61,204,182,67,62,149,97,92,60,17,139,40,62,92,117,29,62,46,58,153,61,42,144,57,62,187,157,221,61,142,7,187,61,156,79,45,62,199,128,44,62,255,202,10,61,150,63,31,62,248,223,90,62,166,152,3,189,20,177,104,62,22,19,11,62,137,98,114,189,24,9,45,62,208,155,106,62,141,236,10,61,95,68,107,62,45,153,99,62,171,95,169,61,101,83,238,61,248,22,102,62,125,205,2,62,70,35,63,62,201,227,89,62,184,172,66,61,125,232,130,61,128,15,94,62,18,77,32,187,15,212,233,61,209,205,134,62,178,76,159,189,210,1,169,61,146,176,127,62,130,55,36,60,150,203,198,60,253,132,131,62,194,221,89,61,56,49,228,61,171,237,158,62,254,99,161,189,249,158,145,59,180,116,101,62,248,80,98,189,186,102,114,189,21,31,95,62,59,225,133,189,135,26,5,60,15,180,170,62,116,8,156,189,90,70,202,189,112,239,146,62,19,70,147,189,166,42,237,189,163,200,74,62,176,227,127,189,221,11,60,62,224,133,189,62,139,194,46,189,227,170,130,62,60,131,134,62,116,151,68,60,47,192,94,62,10,247,162,62,48,159,44,189,150,232,164,62,50,28,167,62,134,173,185,61,105,198,82,62,238,237,150,62,255,117,110,61,41,89,150,62,115,76,142,62,65,73,33,62,86,212,144,62,31,215,150,62,2,44,242,61,182,162,133,62,69,46,24,62,143,167,133,61,90,43,170,62,33,230,210,62,210,168,16,62,226,88,231,62,215,166,161,62,220,155,223,58,73,160,233,62,9,22,183,62,244,222,88,189,231,142,182,62,144,244,233,62,231,166,125,62,165,21,135,62,209,64,28,62,13,27,157,62,234,177,213,62,15,97,132,62,222,86,42,62,167,205,24,62,30,168,243,61,56,105,194,62,146,151,149,62,100,59,15,62,68,164,38,60,240,249,97,189,40,182,50,190,94,156,248,59,163,118,191,187,28,179,44,61,235,196,229,188,222,119,140,188,206,165,120,189,38,168,97,60,34,23,28,189,247,61,42,189,213,233,160,189,109,140,157,189,26,106,244,189,185,82,79,60,168,58,52,62,201,174,116,61,68,162,32,62,176,227,47,62,174,102,109,62,144,136,233,61,43,219,119,62,79,8,45,62,157,242,144,62,19,184,21,62,139,193,203,62,198,110,127,62,122,110,137,62,32,93,12,62,148,52,63,62,149,124,108,189,176,228,10,190,133,151,224,189,13,52,255,189,237,242,173,188,158,96,255,188,80,54,101,188,154,11,188,189,70,7,36,189,81,51,228,189,17,223,137,188,55,194,98,61,108,207,108,61,43,166,146,61,27,129,120,61,108,93,234,61,232,130,218,61,214,55,16,62,226,177,191,61,66,10,190,61,69,44,34,61,213,66,201,59,208,95,136,189,62,93,189,189,46,26,210,189,61,126,47,190,38,53,116,189,101,140,79,189,63,30,42,62,167,32,15,62,195,46,90,62,218,86,67,62,248,54,125,61,108,66,26,61,14,191,11,62,105,1,186,61,138,28,162,188,5,110,93,60,140,132,182,60,189,194,162,61,159,114,92,62,228,133,236,62,243,115,83,62,147,30,174,62,8,176,72,60,50,87,134,189,22,19,187,61,176,115,67,62,12,203,159,60,60,164,24,61,230,172,79,189,72,165,88,188,14,215,106,189,223,25,237,60,16,65,149,62,27,42,190,62,55,0,91,189,20,92,172,61,241,216,207,60,162,40,192,62,201,60,138,62,116,7,17,63,39,23,195,189,61,100,74,188,17,195,78,61,159,0,90,62,232,75,207,61,197,3,74,61,21,84,148,61,211,20,145,62,2,69,172,189,175,39,26,190,106,246,0,189,111,102,20,62,98,78,80,60,181,137,131,62,84,27,28,188,7,120,210,61,64,22,34,189,223,226,81,62,168,87,202,189,135,111,97,61,228,186,169,60,226,119,3,62,19,156,58,189,105,167,54,190,211,160,168,189,42,56,12,62,134,172,110,189,171,234,149,62,18,135,172,61,5,79,1,63,99,127,249,61,17,28,167,62,92,62,210,189,167,2,142,189,88,202,146,61,142,115,155,59,186,45,241,189,121,120,79,190,22,252,95,252,184,251,77,251,127,253,93,252,164,253,63,252,245,252,95,253,189,252,236,252,96,254,104,253,54,254,2,253,116,253,247,253,106,253,17,254,1,252,3,254,1,252,84,254,68,254,216,253,144,254,63,254,33,254,45,255,226,251,121,252,196,254,7,255,199,253,177,253,199,253,237,254,227,253,65,255,52,253,68,255,182,252,248,254,179,254,8,255,194,254,28,255,237,254,1,0,201,253,28,255,141,255,35,255,18,255,138,254,59,255,5,254,34,255,189,253,254,254,80,254,195,255,12,255,167,254,2,0,174,254,39,0,41,255,87,255,198,255,0,0,200,255,250,255,53,255,125,255,1,0,70,255,251,255,45,255,6,0,132,254,11,0,94,254,140,255,131,0,122,255,113,0,89,0,252,255,71,0,254,255,237,255,64,255,6,1,24,0,189,0,151,0,123,255,147,255,186,0,103,255,166,0,37,255,37,0,139,0,193,0,171,0,81,1,124,0,158,0,195,255,141,0,226,0,243,255,190,0,231,0,34,0,98,1,109,0,60,1,201,0,244,0,164,0,74,1,171,255,134,1,172,255,254,0,71,1,1,1,79,1,235,1,147,0,220,1,105,0,54,0,77,0,181,1,114,1,165,1,58,1,193,1,86,1,73,1,126,0,161,2,36,1,59,2,132,1,243,0,193,0,141,2,64,1,109,2,24,1,194,0,124,1,5,2,69,2,45,0,67,1,111,0,166,1,233,1,139,1,222,2,22,2,110,2,34,2,230,1,246,1,62,1,60,2,189,0,38,2,129,1,166,1,99,255,153,0,131,255,126,1,59,255,130,1,249,254,78,1,228,0,185,2,68,255,1,0,51,0,41,1,5,254,213,0,136,254,141,1,232,255,255,0,221,253,89,0,10,254,162,255,131,1,179,0,148,253,68,0,84,253,112,0,126,253,162,254,252,254,172,0,74,254,188,254,8,1,136,2,60,252,252,255,159,251,7,0,122,255,134,0,147,251,206,254,143,0,96,0,92,254,15,254,59,251,162,254,9,250,83,253,95,255,72,0,105,3,179,2,220,2,27,1,153,3,97,1,78,1,219,1,71,4,53,3,96,3,12,2,75,3,241,1,202,2,199,2,20,3,238,2,52,4,202,2,180,4,241,2,191,248,111,249,191,248,37,249,248,247,130,251,170,247,138,249,173,249,181,251,88,249,149,251,191,250,184,249,177,250,154,249,198,250,243,250,211,250,15,251,128,249,143,249,49,250,173,252,190,250,216,248,123,250,116,247,254,250,87,253,7,249,143,249,58,252,198,251,97,251,116,249,226,251,207,251,138,251,122,251,73,251,24,253,6,251,27,252,90,252,153,250,97,252,120,250,14,252,231,250,241,252,69,252,231,251,124,252,31,252,207,252,31,253,201,252,52,252,91,251,30,253,186,251,30,253,126,251,240,252,223,252,214,252,238,252,132,252,248,253,24,252,206,252,124,253,59,252,191,253,142,252,227,253,74,253,97,253,107,252,173,253,126,253,122,253,153,253,68,252,147,253,99,252,253,253,41,253,29,254,209,252,27,254,184,252,190,253,72,254,55,253,190,253,187,254,111,253,98,253,126,254,198,253,71,254,102,253,254,253,237,252,120,254,239,253,246,253,59,254,25,254,89,254,152,253,183,253,151,253,99,255,106,253,244,254,88,253,164,254,190,254,189,254,136,253,68,254,208,254,82,254,180,254,54,254,235,254,44,254,109,253,231,252,193,254,132,253,29,255,214,253,139,254,165,254,178,254,46,255,56,254,64,255,238,253,14,255,40,255,58,255,146,254,142,254,174,254,95,255,103,254,20,253,149,255,132,254,218,254,125,253,33,255,103,253,22,255,27,253,115,255,16,254,126,255,2,254,117,255,185,254,84,255,207,254,206,254,188,253,92,255,249,254,250,254,84,255,189,255,110,254,31,0,146,254,246,255,76,254,170,255,241,253,71,0,135,254,234,255,159,253,244,255,90,253,189,255,193,254,63,0,65,255,35,0,75,255,217,255,14,255,126,0,89,255,116,255,224,253,155,0,215,254,174,0,215,254,38,0,248,255,117,0,132,254,197,0,60,254,240,0,246,253,223,0,153,255,110,0,69,255,87,0,101,255,169,0,209,255,157,0,26,0,173,255,156,255,128,0,80,0,209,0,194,255,6,0,7,0,22,0,5,0,62,1,236,255,248,0,211,255,56,255,193,255,156,0,187,255,250,0,73,255,113,1,130,255,143,255,180,255,114,255,134,255,192,255,2,255,225,255,35,0,79,255,185,255,249,255,171,0,93,0,27,0,108,0,212,0,182,254,47,255,133,255,186,255,233,254,95,0,160,255,20,0,68,255,195,255,198,254,87,0,212,254,178,255,158,254,122,255,11,0,122,0,116,255,122,0,237,254,152,0,219,254,140,0,174,255,138,0,191,254,145,255,32,254,100,255,153,254,76,0,2,255,216,255,133,253,160,255,246,253,79,0,5,254,8,0,244,254,47,1,229,253,68,0,66,254,61,0,246,253,50,1,111,0,189,0,77,254,122,0,133,254,166,0,197,253,114,254,136,253,182,255,21,253,161,255,57,254,194,0,72,252,83,0,226,252,192,0,13,253,192,0,243,252,94,255,149,253,234,0,105,253,215,254,24,254,147,255,60,252,124,255,186,252,188,255,181,252,58,0,168,251,170,255,219,252,213,254,80,252,3,255,246,252,206,255,59,252,219,253,160,254,158,255,32,252,169,254,163,251,197,254,163,251,205,254,125,251,138,254,131,253,26,255,114,251,213,255,237,250,156,255,99,252,119,254,6,251,168,253,79,253,126,255,57,250,200,254,215,250,2,255,72,250,70,254,244,250,155,253,19,251,9,254,35,250,144,254,214,250,26,0,104,250,190,255,49,249,95,255,148,249,45,254,32,249,220,253,143,250,200,253,236,249,153,252,41,250,246,251,149,250,197,253,131,248,240,253,9,249,133,255,151,248,25,255,250,247,189,254,252,247,118,252,72,248,201,253,131,248,148,253,1,248,35,252,203,251,142,254,17,248,64,253,205,246,19,253,76,245,191,251,139,248,159,0,36,248,248,0,142,253,133,255,221,246,62,252,99,253,104,254,157,250,106,251,60,254,148,254,236,251,33,253,124,255,183,0,172,249,16,253,221,253,205,254,247,252,19,251,158,255,41,0,144,252,189,251,255,254,97,0,190,249,215,248,31,0,230,255,124,253,207,253,76,255,222,253,127,254,185,251,102,254,222,252,98,254,197,252,55,254,54,252,22,254,171,251,41,255,108,252,112,255,87,252,19,254,11,251,251,253,29,250,181,0,101,0,180,254,135,252,188,252,87,252,209,253,83,254,139,253,221,253,73,255,175,254,223,253,174,255,6,255,226,254,5,0,124,255,164,254,4,255,219,254,40,254,98,255,100,0,227,255,197,0,20,255,88,254,163,252,43,255,116,255,249,255,85,254,69,254,187,0,159,255,84,253,32,253,219,254,2,1,144,254,104,255,106,255,136,1,159,253,175,0,114,255,43,1,118,255,152,0,137,255,73,1,26,254,204,255,37,1,198,0,73,255,117,0,175,0,75,1,198,255,238,254,231,0,44,1,224,254,74,1,207,254,116,1,145,255,153,1,247,255,167,1,83,0,0,1,67,0,111,1,237,255,248,0,91,0,113,0,221,255,150,1,65,255,154,0,238,0,40,1,5,0,197,0,141,0,221,0,57,1,198,0,211,0,165,1,244,0,78,1,88,0,170,1,13,255,198,1,202,0,40,2,251,255,147,1,35,1,185,0,219,0,45,1,251,0,138,0,128,0,69,0,197,0,32,1,116,255,195,255,188,0,105,1,197,0,86,2,186,1,17,1,34,1,143,0,216,1,226,1,157,0,114,1,159,1,65,1,116,1,129,1,146,1,40,2,155,0,24,0,38,2,7,1,245,255,21,0,104,1,227,0,147,0,2,255,168,1,97,0,110,1,243,255,119,1,141,0,193,1,232,0,140,1,251,1,218,1,16,1,189,2,68,1,106,1,209,255,75,2,148,0,31,2,69,0,144,1,205,255,49,2,59,0,220,0,246,255,96,1,147,0,206,0,211,0,141,2,185,0,51,2,41,1,53,2,28,1,82,2,121,0,254,2,192,0,142,1,118,0,130,2,178,1,233,0,8,1,225,1,211,1,129,0,91,255,187,2,239,0,90,0,26,0,86,1,218,1,201,255,27,0,132,1,94,0,84,255,0,0,213,2,123,1,196,255,81,1,114,1,209,1,95,0,63,1,38,3,83,2,78,0,4,1,241,1,83,3,210,0,48,2,202,1,62,2,48,254,202,0,241,1,113,2,54,255,152,0,48,0,200,2,236,255,54,2,100,0,203,2,199,1,212,1,155,1,93,2,63,1,134,2,195,0,103,2,145,1,26,2,168,2,227,2,201,0,155,2,178,1,186,3,198,1,169,1,134,2,235,1,94,2,169,2,160,1,252,1,241,1,54,3,170,1,47,3,148,2,135,2,116,2,204,2,185,2,210,1,106,2,201,1,173,2,204,1,109,1,53,1,209,2,55,2,68,3,89,2,97,2,44,1,57,3,203,1,175,3,175,2,169,2,21,2,147,3,86,2,79,2,243,0,108,3,195,1,106,3,164,1,18,3,61,1,220,2,220,0,154,3,61,1,84,4,111,1,19,2,210,1,4,4,137,2,29,4,103,2,10,4,41,2,61,3,90,2,253,3,31,3,159,3,35,3,110,3,251,2,31,3,240,1,93,5,5,3,73,2,2,3,35,3,162,3,75,4,25,3,198,4,94,3,185,4,127,3,1,4,215,2,4,3,77,3,148,4,91,4,99,3,253,3,62,3,245,3,73,3,142,3,250,1,191,2,215,4,53,4,108,2,51,3,172,4,59,4,131,4,57,4,118,4,139,3,11,6,97,4,29,5,136,2,63,5,100,2,204,5,220,3,199,5,169,3,217,3,48,5,187,3,61,5,173,1,142,3,73,3,58,5,52,2,155,4,156,1,132,4,147,5,40,5,154,5,50,5,128,2,248,2,190,6,130,5,190,0,43,2,49,4,237,3,170,1,1,1,71,3,212,3,235,0,231,0,240,5,143,4,109,0,37,1,246,3,33,6,49,1,142,0,124,4,27,2,221,254,148,255,189,4,204,3,22,0,40,255,155,2,60,3,30,254,182,1,197,1,151,5,187,253,90,254,21,3,131,1,154,254,58,254,174,0,12,3,220,255,140,254,134,1,122,255,139,253,160,0,206,254,239,2,22,251,181,254,177,0,10,2,8,255,62,2,5,255,127,2,237,253,151,1,172,253,138,1,93,254,21,3,151,253,33,3,38,252,143,1,167,252,215,2,249,255,6,2,65,253,54,1,137,251,232,255,22,252,31,1,64,252,107,1,237,250,56,1,2,250,245,0,235,249,49,1,28,0,153,0,165,252,81,255,223,255,76,1,138,250,102,255,212,0,154,1,175,253,59,255,188,251,64,253,120,252,191,255,26,1,111,1,106,252,82,253,89,1,93,0,254,254,155,254,184,2,132,2,75,253,228,255,192,1,237,1,239,254,193,0,15,2,34,2,13,255,255,253,128,1,120,255,17,1,159,254,0,2,114,255,25,2,58,255,173,3,238,2,83,0,248,0,66,2,93,3,200,255,80,2,74,3,44,0,124,3,24,0,33,0,122,3,240,255,214,3,63,3,118,5,255,5,106,7,180,6,96,5,156,7,185,5,236,248,29,247,169,248,23,246,152,249,200,248,97,249,44,248,60,251,136,248,59,251,198,247,233,249,204,249,219,249,236,249,85,251,177,249,56,251,65,249,177,250,129,251,176,249,100,248,6,251,145,250,231,250,133,250,185,249,101,251,116,249,225,250,93,250,58,250,169,250,126,252,24,251,221,251,205,250,146,251,42,252,147,251,131,251,32,250,200,251,228,250,4,252,97,251,44,252,50,250,57,252,41,250,36,252,102,252,233,251,203,251,186,252,101,251,166,252,58,251,149,251,239,251,216,251,1,253,152,252,123,251,67,253,144,252,62,253,118,252,250,252,8,252,190,253,200,251,223,252,58,250,177,253,169,251,176,253,134,251,55,253,148,250,128,253,160,250,171,253,221,251,96,254,121,252,82,253,192,252,107,253,60,253,68,254,156,252,22,254,103,252,138,254,248,252,149,253,110,251,183,253,219,253,255,252,229,252,77,254,109,253,238,253,27,253,14,254,187,252,155,254,171,253,233,254,153,252,13,255,137,252,230,254,103,253,232,254,101,253,91,255,208,253,118,254,121,252,150,254,102,254,64,254,185,253,103,254,194,253,199,254,155,254,131,253,220,253,198,253,76,254,128,252,8,254,130,254,11,253,198,255,31,254,91,255,150,253,65,255,138,254,22,255,130,254,34,255,85,253,231,255,32,254,94,254,153,254,38,253,159,254,188,254,99,255,80,254,190,254,118,254,209,254,228,254,152,255,167,253,223,254,212,253,60,255,180,253,106,255,109,253,160,253,39,254,232,255,188,255,64,254,38,254,248,255,6,254,211,255,20,253,72,255,180,252,4,255,123,252,165,255,184,253,159,255,116,253,138,0,4,253,125,255,90,253,244,255,98,253,165,0,253,254,253,255,184,252,149,255,115,252,37,0,32,252,44,0,170,252,97,254,185,252,13,0,23,252,241,254,254,251,203,254,226,252,34,254,192,252,24,254,81,252,168,0,168,251,125,254,95,251,155,255,97,251,216,255,83,252,196,254,250,251,254,252,236,251,143,253,199,251,230,253,56,251,213,254,224,250,76,254,83,251,105,253,113,251,95,255,64,251,78,253,43,251,193,252,104,250,48,253,133,250,19,254,126,252,28,253,102,252,223,252,178,251,110,254,213,249,60,252,219,251,130,253,11,251,98,250,37,250,90,252,34,250,129,252,194,249,204,253,69,249,51,253,162,253,171,253,114,251,195,251,167,250,44,254,102,248,43,250,210,248,71,252,116,248,93,252,37,250,68,255,157,249,91,254,79,250,174,254,88,250,234,255,106,248,90,254,42,248,7,255,16,254,142,255,138,248,13,253,247,250,174,0,85,250,147,255,30,254,255,254,59,251,4,254,175,249,151,0,98,249,208,0,114,253,107,0,141,249,29,0,139,251,23,1,65,251,50,1,52,251,6,254,38,253,81,255,44,251,155,255,55,252,39,2,154,252,22,1,201,252,59,1,205,253,120,1,229,251,228,0,5,254,24,1,169,253,25,1,10,253,253,0,207,254,123,1,13,253,122,255,157,253,148,2,200,252,24,2,207,252,134,2,99,254,49,0,171,254,177,0,59,254,14,2,30,254,77,2,185,255,83,1,111,253,8,1,12,255,39,1,19,255,59,1,125,254,57,2,6,254,247,255,135,254,14,0,96,255,149,2,40,255,40,0,204,254,210,255,95,0,214,0,14,255,167,0,170,255,192,0,200,255,27,0,180,255,31,0,36,0,53,1,150,255,74,255,143,255,74,0,71,254,234,255,23,0,139,0,81,0,245,255,44,0,15,0,169,255,119,255,138,255,49,255,98,255,198,255,16,1,164,255,100,255,71,254,8,0,120,255,128,0,35,255,101,0,38,255,40,0,59,255,180,255,56,254,9,0,67,254,33,0,89,254,226,0,60,0,73,0,34,255,156,0,113,254,24,1,194,254,245,0,171,254,166,0,13,254,83,1,66,255,71,1,37,255,69,1,119,255,167,255,172,253,100,0,141,253,144,0,91,253,231,1,28,0,252,0,121,254,214,0,215,255,26,1,228,255,99,0,226,254,75,1,49,0,203,1,124,254,53,2,143,254,180,1,28,0,80,1,247,255,141,1,89,255,106,2,34,0,84,2,239,255,49,2,116,255,43,1,79,0,10,2,125,0,203,0,2,0,244,0,32,1,255,0,211,0,175,0,82,0,84,2,187,0,5,2,108,0,125,1,255,0,109,1,41,1,241,1,96,1,71,1,174,255,25,0,210,0,115,1,245,0,5,1,3,0,33,2,193,1,140,0,38,1,44,0,39,1,212,0,91,1,244,0,238,1,75,1,16,2,201,0,51,1,93,1,155,1,101,2,28,1,102,2,157,1,208,1,66,1,112,2,141,1,97,0,200,0,96,255,128,1,149,0,106,1,239,1,13,2,13,1,73,2,33,0,235,1,135,255,177,1,171,1,99,2,242,1,4,2,171,0,187,1,241,1,154,2,184,1,19,1,54,2,63,2,146,0,127,2,155,0,158,2,223,255,173,0,212,0,184,2,90,255,89,2,65,255,183,2,23,254,247,1,175,0,230,2,214,0,220,1,116,1,59,4,66,2,18,2,74,2,9,3,169,1,106,3,59,1,73,3,118,1,80,3,91,255,53,2,35,0,223,3,217,255,38,4,73,1,200,2,18,3,72,3,133,2,27,3,149,2,164,2,59,2,150,3,120,2,55,4,161,2,49,3,62,1,132,1,106,3,244,3,52,2,80,3,112,3,108,2,45,2,223,1,159,2,197,1,180,2,212,1,72,3,130,2,76,3,133,2,250,1,172,1,129,3,55,2,69,3,131,1,194,3,243,1,179,2,49,2,171,3,158,3,15,3,40,1,22,3,12,1,4,4,18,2,106,3,73,1,36,2,143,0,163,2,35,1,247,1,66,0,17,4,103,1,18,3,97,0,37,3,33,0,69,3,214,1,255,1,49,0,68,4,71,1,150,4,67,1,3,0,242,0,104,3,218,1,177,2,173,1,49,5,166,2,18,4,108,2,85,4,152,2,65,1,193,0,121,3,182,3,129,4,106,3,125,3,123,2,109,3,94,3,180,3,145,3,13,5,153,2,40,5,127,2,229,3,25,3,122,5,6,4,152,4,244,3,86,4,191,3,130,5,157,3,123,5,147,3,31,2,94,3,92,4,198,4,67,3,166,4,67,3,166,4,191,3,124,4,123,4,96,5,20,5,169,4,135,5,207,4,55,5,61,5,234,2,68,4,175,6,3,5,109,5,49,4,54,5,30,6,129,4,195,5,109,6,113,4,33,7,196,4,32,4,102,5,241,5,194,6,96,6,9,6,84,6,6,6,87,3,60,6,97,3,131,6,181,2,117,3,180,6,239,5,143,4,16,5,161,8,224,6,160,7,213,5,228,7,202,5,254,5,74,7,158,6,216,7,30,6,236,2,225,6,57,3,38,1,112,5,60,4,10,8,109,2,35,5,109,1,7,5,198,0,4,4,232,1,128,5,249,0,147,1,246,3,25,6,68,1,107,1,109,6,20,4,193,0,111,1,242,7,67,7,5,255,67,2,238,2,226,3,13,255,30,0,45,5,111,3,228,255,87,255,112,2,149,3,59,254,159,0,186,0,90,5,154,253,6,0,25,2,136,1,162,255,221,254,13,3,229,0,128,255,214,254,245,0,235,1,67,253,120,253,204,3,21,3,11,254,128,253,178,0,255,0,147,254,122,254,1,255,61,1,66,252,218,254,65,255,228,0,249,252,65,254,157,0,19,255,111,253,48,253,105,254,92,0,139,255,157,253,78,1,26,255,89,253,196,251,112,255,195,254,123,252,163,252,30,253,152,254,171,255,41,253,166,255,237,252,100,0,234,255,121,254,249,254,200,255,183,255,175,254,14,253,5,0,67,255,62,253,144,253,89,0,168,254,121,255,167,251,159,254,19,255,84,253,145,251,237,254,178,251,243,254,77,251,152,0,145,0,46,253,48,251,49,0,80,0,32,251,248,252,8,255,135,1,36,253,221,253], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+738664);
/* memory initializer */ allocate([213,1,218,0,1,255,160,252,69,0,110,1,90,255,27,254,80,253,191,0,68,251,84,251,86,255,87,255,228,250,161,249,65,1,214,1,117,250,37,251,192,255,16,1,175,250,8,255,236,1,53,2,47,253,159,253,195,0,229,1,195,253,123,255,171,1,202,0,85,255,138,255,199,0,63,2,2,0,225,255,182,2,243,2,170,250,217,255,40,2,45,2,23,254,15,1,168,2,25,2,13,0,59,254,87,3,186,3,123,255,204,255,175,255,226,2,111,251,125,2,31,4,35,4,161,255,164,2,235,4,57,4,233,1,49,1,63,254,186,3,234,253,228,3,55,252,98,3,222,251,35,4,242,250,106,2,120,250,105,2,54,254,86,5,97,255,29,7,250,252,240,253,242,255,86,4,78,251,123,252,252,252,177,1,24,251,25,251,13,252,210,254,166,253,183,253,9,253,174,249,8,253,243,249,184,252,127,248,208,252,229,253,23,249,69,247,29,255,220,255,14,248,217,248,197,247,154,251,89,246,232,248,66,250,252,0,115,245,97,254,197,253,45,254,229,5,18,6,132,8,183,7,22,9,228,7,161,249,192,249,252,248,14,247,253,251,22,249,180,251,23,248,3,251,148,250,169,250,2,250,77,252,75,250,52,252,12,250,25,252,58,251,4,252,108,251,209,252,37,252,32,252,165,250,64,251,18,252,247,250,186,251,24,253,12,251,13,253,243,250,162,252,101,252,119,252,40,252,90,253,229,251,83,253,230,251,193,251,39,252,218,251,89,253,35,252,127,253,153,251,48,252,6,253,114,253,134,252,218,252,191,252,189,251,62,253,139,253,147,253,218,252,128,253,212,252,249,252,134,253,245,252,225,253,28,252,203,253,205,251,188,253,222,253,157,253,196,253,149,253,8,253,222,254,145,252,242,253,201,252,50,254,229,252,3,255,215,253,97,254,179,253,73,254,235,253,172,254,76,253,89,252,7,254,252,252,66,253,149,251,249,254,206,254,53,252,29,254,67,254,182,255,213,253,220,253,154,253,127,255,75,253,22,255,116,254,10,255,37,254,6,255,247,254,108,254,136,254,254,253,95,254,2,254,212,254,199,254,178,254,104,253,49,254,210,252,126,254,64,253,175,254,153,253,22,255,55,255,23,255,17,255,89,255,201,253,53,255,149,253,109,255,97,254,141,255,160,254,90,255,18,253,85,255,7,253,242,254,145,252,248,254,121,252,145,254,24,253,43,0,37,254,14,0,115,253,43,0,98,253,11,0,64,254,197,255,247,253,130,255,137,255,101,255,155,253,214,255,161,252,229,255,93,252,136,0,29,254,183,0,44,254,55,0,214,254,55,0,208,254,57,1,159,253,57,1,48,253,66,1,89,255,100,0,227,253,253,255,137,255,145,255,69,255,233,0,20,255,4,1,22,255,26,0,91,255,134,0,211,255,216,255,219,253,104,1,53,255,122,1,124,254,194,1,129,254,19,1,20,0,182,0,153,255,246,0,145,255,175,1,37,0,206,1,110,255,231,1,99,255,228,254,197,255,247,1,72,255,24,0,53,0,253,255,54,0,122,0,3,1,77,1,66,0,228,1,104,0,180,1,68,0,195,0,116,0,190,0,206,0,13,1,247,255,226,1,96,1,126,1,29,1,143,1,21,1,196,1,0,1,69,0,186,0,13,0,41,1,243,255,3,1,161,255,30,0,56,0,138,1,196,0,169,1,205,0,200,1,25,1,65,2,15,0,191,0,119,1,34,1,151,1,64,2,200,255,227,0,32,2,149,1,0,0,37,2,164,255,16,2,27,255,95,1,11,255,82,1,150,254,179,1,167,0,15,2,181,255,46,1,91,0,56,3,129,0,87,2,240,1,167,2,186,0,237,2,153,0,225,2,231,254,88,2,164,254,103,2,20,255,1,3,41,0,113,3,38,0,122,3,36,255,73,3,155,254,115,3,119,254,135,3,134,253,218,1,68,254,82,3,81,255,166,2,19,254,242,0,249,253,17,3,54,253,70,2,227,253,110,1,225,253,178,1,171,253,244,1,3,253,222,0,66,253,149,3,25,253,194,3,155,252,245,1,125,252,36,2,133,254,200,0,77,254,157,0,205,252,214,0,163,252,157,0,154,253,40,0,136,253,94,0,141,252,202,255,27,253,4,2,11,254,42,1,154,253,85,255,154,252,95,255,159,252,233,255,206,252,93,0,9,252,245,254,106,253,153,254,219,253,2,0,70,254,135,255,135,254,0,0,29,255,33,0,98,254,130,255,127,255,212,0,90,252,34,0,198,251,230,254,161,251,244,254,58,253,199,252,92,254,65,255,204,251,96,252,107,252,163,255,140,253,154,254,97,0,7,0,50,255,119,254,155,255,24,0,53,255,38,0,88,255,83,0,169,253,89,254,233,254,170,1,68,253,118,0,181,255,206,0,43,252,95,253,88,253,161,1,145,254,37,0,233,254,218,1,127,255,194,254,63,1,40,1,142,253,217,255,87,1,90,2,72,253,217,255,209,254,172,3,104,0,233,0,132,254,137,0,220,255,13,1,181,255,42,255,120,0,43,0,239,253,35,254,203,1,164,0,54,255,27,255,207,255,89,255,97,2,24,3,98,0,36,255,147,3,148,0,37,1,27,1,101,3,91,0,63,2,138,1,70,1,178,255,205,2,67,0,109,1,189,254,104,2,220,255,219,2,27,0,107,2,238,0,120,2,17,1,192,1,99,0,33,3,220,1,101,3,17,1,173,2,64,0,21,3,72,0,253,3,217,0,25,3,203,1,222,2,104,1,134,2,224,1,104,1,66,1,173,1,208,1,126,2,174,1,244,2,107,1,232,3,148,1,171,2,16,2,90,2,103,2,143,2,157,1,178,3,175,2,169,3,90,2,136,3,92,2,43,2,225,2,18,3,150,2,211,1,142,2,106,1,77,2,161,3,198,2,242,1,222,1,159,1,164,1,181,2,115,3,45,3,171,2,13,3,157,3,145,3,171,3,214,2,220,2,235,1,85,3,19,2,180,3,222,2,195,3,59,1,40,3,249,2,243,2,120,4,248,2,143,2,52,4,58,3,33,4,67,4,70,3,235,3,40,3,23,4,109,4,147,2,77,4,224,3,26,4,50,4,51,4,203,3,182,2,202,4,30,4,59,2,73,3,116,3,124,5,99,5,72,4,56,4,93,3,207,4,223,2,4,5,248,2,248,4,223,3,87,5,29,4,233,4,188,2,26,4,22,2,220,3,197,1,240,4,87,2,116,4,167,2,85,6,47,3,104,5,9,2,37,5,137,1,28,6,37,3,168,5,174,2,44,4,136,2,107,3,51,1,59,4,105,1,23,4,61,1,137,5,196,3,163,2,59,2,128,4,79,0,90,4,209,255,250,5,55,1,185,6,58,1,142,4,177,2,2,2,162,255,93,1,26,1,132,5,72,1,1,4,231,1,191,255,57,0,37,3,202,3,36,0,62,0,1,3,249,254,23,3,166,254,125,2,187,2,119,255,108,2,22,2,29,2,33,253,194,0,199,2,44,1,244,254,161,252,158,3,1,3,60,253,84,254,250,1,174,0,132,252,138,253,179,1,35,2,101,250,254,254,109,2,215,1,6,252,168,250,119,254,9,2,104,252,82,253,231,255,20,0,42,252,124,251,84,1,9,0,234,249,145,251,160,254,48,0,213,249,110,254,137,252,6,0,124,251,136,252,220,253,160,254,149,249,112,251,97,255,98,2,24,248,61,252,31,255,193,0,136,249,88,248,11,255,19,254,60,252,112,249,88,252,133,253,237,250,48,249,148,250,164,253,252,249,189,252,139,250,121,255,204,249,222,254,122,249,56,253,37,248,160,249,129,249,229,255,46,247,213,252,123,251,184,0,15,251,189,0,169,250,74,2,37,248,201,0,234,252,200,2,70,251,3,0,247,251,40,3,29,251,62,3,145,255,123,2,156,249,191,1,49,254,75,252,67,254,96,252,8,254,118,251,11,254,69,251,144,0,161,254,140,254,228,251,229,254,221,251,233,254,157,251,193,253,98,250,181,253,178,249,89,252,40,252,229,0,178,2,103,252,49,253,109,254,82,5,83,253,47,254,106,3,141,1,3,254,210,255,61,1,54,5,27,254,200,1,45,3,183,1,101,254,83,1,130,3,43,4,87,254,46,0,161,5,241,1,115,252,224,252,185,5,22,4,2,255,191,254,150,5,141,4,68,0,94,1,10,4,154,2,114,1,11,0,31,5,22,3,143,0,232,0,17,4,26,6,142,255,151,2,80,6,54,4,198,1,67,2,251,4,16,4,180,255,141,3,240,2,43,4,153,0,0,2,92,1,190,4,102,2,129,1,51,7,40,3,13,1,10,4,203,0,62,4,140,2,249,3,247,6,106,4,173,1,47,5,131,1,104,5,207,255,159,4,184,255,191,4,96,254,233,3,32,2,213,6,160,254,199,4,10,254,175,4,179,253,57,2,29,255,94,6,114,255,42,6,26,255,179,6,54,253,8,5,186,252,118,5,107,4,77,5,48,255,208,4,181,1,197,3,95,252,50,3,43,3,130,5,91,3,227,5,164,0,188,4,107,5,1,7,228,1,82,7,200,1,15,8,228,3,146,4,46,5,122,5,36,5,80,5,111,4,238,4,210,4,82,6,81,5,232,6,141,5,203,4,48,6,67,5,86,3,160,2,149,6,30,6,115,4,246,4,224,7,33,7,237,6,45,6,252,5,180,5,207,5,178,3,123,6,253,3,208,6,188,4,112,5,209,3,236,6,137,4,34,7,140,4,182,6,149,5,181,7,55,6,161,4,96,3,84,8,37,4,7,7,46,3,46,7,245,2,56,8,35,5,6,8,234,4,65,8,147,3,27,9,162,3,187,5,123,4,30,10,159,5,197,8,208,6,42,8,84,6,54,9,174,5,106,10,226,5,84,7,45,7,22,8,183,7,203,6,41,6,170,2,9,5,48,6,253,7,174,5,50,8,194,9,212,7,151,10,18,8,214,2,52,6,196,10,32,9,228,0,79,3,152,9,123,6,36,0,45,1,150,7,165,7,66,254,160,255,106,8,116,5,253,5,77,4,14,0,96,2,101,252,36,253,103,5,190,7,65,5,184,3,88,253,65,1,1,5,244,4,198,249,109,1,173,3,178,3,55,249,202,252,70,9,227,10,29,7,228,10,61,254,215,251,239,253,231,250,62,254,12,253,15,254,161,252,128,254,149,253,99,254,99,253,195,254,230,253,181,254,212,253,98,254,4,254,88,254,134,254,238,254,188,254,78,254,154,253,30,255,12,254,24,255,254,253,249,254,135,254,214,254,102,254,105,255,58,253,82,255,206,252,107,255,100,254,100,255,83,254,224,254,50,254,70,255,53,255,86,255,210,254,65,255,191,254,125,255,109,255,215,254,117,254,28,255,42,255,11,255,64,255,189,255,196,254,185,255,185,254,152,255,51,255,162,255,73,255,113,255,218,255,63,255,161,255,16,0,180,255,132,255,8,255,23,0,19,255,24,0,12,255,18,0,120,255,44,0,145,255,223,255,232,255,231,255,0,0,149,0,19,0,23,0,113,255,158,0,87,255,174,0,75,255,133,0,201,255,165,0,230,255,111,0,84,0,98,0,75,0,87,0,183,0,141,255,245,255,248,255,130,0,11,0,170,0,254,0,77,0,205,0,17,0,183,0,112,0,6,1,194,0,202,0,31,1,95,0,189,0,214,255,151,255,234,0,179,0,39,0,186,0,163,0,89,1,76,1,199,0,43,1,161,0,202,255,29,1,178,255,25,1,123,255,141,0,74,255,111,0,249,0,85,1,15,1,108,1,93,0,147,1,75,0,135,1,92,0,254,1,118,255,220,0,71,255,227,255,222,255,105,1,141,255,64,1,3,0,42,2,99,0,30,1,218,0,79,2,11,255,150,1,244,254,197,1,0,0,68,2,25,0,94,2,19,1,20,2,148,0,194,1,183,255,227,2,227,254,6,2,224,254,94,0,53,255,162,2,116,255,182,255,205,0,202,2,142,255,43,1,176,0,155,3,182,0,45,2,240,0,193,2,240,255,1,2,229,1,81,2,37,1,128,1,195,1,105,2,218,255,50,0,51,2,17,2,47,1,209,0,203,1,107,1,177,1,196,1,194,1,198,1,111,1,94,2,221,1,229,2,176,1,97,1,112,1,11,1,105,1,204,2,17,1,71,2,197,1,166,0,254,1,172,0,201,0,117,2,18,1,191,0,56,2,127,2,46,1,42,1,122,2,131,1,131,2,94,1,75,2,48,2,100,2,53,2,88,2,20,3,231,1,160,2,0,2,247,3,65,1,77,1,101,1,86,3,131,255,157,1,218,1,200,2,17,0,105,255,52,2,29,1,14,1,15,255,203,3,121,3,233,1,220,0,254,1,128,3,37,2,156,3,71,1,57,3,34,1,143,3,28,2,84,4,158,0,37,3,199,0,189,3,255,1,218,2,100,0,106,3,13,0,23,3,179,1,120,2,164,2,204,3,249,0,132,3,211,1,194,4,13,3,50,4,73,2,17,3,233,255,157,2,11,1,19,4,107,2,60,4,103,2,121,4,110,2,137,3,148,3,25,4,80,0,75,1,72,2,51,4,89,0,127,2,220,3,193,3,2,3,208,2,30,3,187,2,236,1,191,1,131,3,115,2,15,1,164,4,213,2,53,5,87,0,91,2,64,3,67,6,104,2,103,4,122,3,225,5,232,3,132,4,98,3,241,3,227,3,59,3,125,4,90,3,49,3,170,5,5,3,40,5,244,1,109,5,56,1,129,4,236,255,60,4,64,0,3,5,2,0,148,4,143,1,77,7,2,2,170,6,246,1,100,6,118,3,242,5,160,1,88,2,107,4,70,5,251,4,110,5,121,3,3,7,146,3,230,6,227,0,159,4,226,4,34,7,249,1,62,7,151,3,49,9,57,255,175,1,152,0,199,6,43,255,228,255,136,1,54,5,103,255,204,255,210,3,127,4,189,254,112,254,45,3,167,6,120,255,84,0,169,5,223,7,181,254,113,255,119,255,168,4,0,255,22,2,99,255,7,4,205,254,73,254,30,2,219,2,183,254,92,254,159,255,104,2,150,254,88,255,190,254,110,1,9,255,146,255,45,255,89,0,60,255,203,254,20,0,59,0,148,254,49,254,226,254,89,0,176,254,175,0,80,254,141,0,133,254,66,255,78,254,60,255,177,255,150,0,234,254,29,255,232,254,166,0,213,253,90,254,101,255,29,2,146,254,54,0,227,255,173,255,211,254,250,252,186,0,116,2,115,254,248,254,242,0,37,1,59,255,183,253,124,0,154,1,53,0,123,255,10,0,84,1,198,253,215,251,65,0,66,254,68,0,19,254,127,1,169,3,155,254,57,253,153,254,6,255,91,253,212,251,36,1,230,255,107,1,6,0,95,2,33,5,129,255,246,255,233,5,94,7,201,2,204,3,189,5,133,8,163,5,224,7,115,184,188,67,8,172,10,68,59,151,102,68,225,122,167,68,205,196,212,68,123,204,255,68,20,78,25,69,92,87,43,69,51,203,66,69,61,66,81,69,163,1,163,0,226,255,250,254,57,254,235,252,106,250,47,253,238,3,152,2,13,1,25,0,107,2,4,1,183,0,96,0,56,252,178,250,124,254,135,0,75,253,67,3,200,1,154,0,81,4,191,2,57,2,107,1,89,6,46,5,217,3,236,2,36,255,219,0,76,0,48,255,81,250,130,249,49,0,149,0,60,252,84,255,16,253,176,254,113,2,209,0,6,255,190,255,7,252,186,252,254,255,61,1,136,247,51,250,118,255,123,0,172,248,205,247,247,253,85,0,57,252,146,254,73,253,143,252,103,252,13,252,5,253,75,252,132,255,0,255,160,254,108,253,178,0,207,1,98,1,48,1,48,249,177,253,230,254,79,0,55,247,175,0,99,3,243,1,118,255,76,255,75,255,235,255,13,247,39,251,52,254,248,253,253,252,195,1,246,255,204,254,15,1,191,255,4,0,214,0,233,254,77,254,213,255,164,254,98,253,35,0,191,255,45,255,38,3,23,2,85,0,41,1,57,0,239,0,210,2,237,1,225,0,149,2,72,3,35,2,228,253,136,254,14,0,93,1,213,1,209,2,75,1,162,0,224,253,16,253,194,255,246,255,142,1,168,255,212,2,189,2,237,255,235,253,162,255,89,2,136,0,185,255,87,253,21,253,90,255,168,254,5,1,206,255,161,0,204,255,229,1,81,1,117,249,50,0,190,0,163,255,22,247,25,255,62,255,174,255,161,255,173,253,102,255,128,0,126,3,245,1,76,2,201,1,167,254,206,0,122,0,110,0,137,253,29,255,199,253,3,0,152,1,239,0,141,1,226,0,59,255,254,255,128,0,235,1,1,5,136,3,36,1,215,0,26,2,50,1,3,1,253,1,91,253,233,251,13,0,65,1,89,253,180,253,154,254,44,255,210,253,243,0,134,2,223,1,230,1,86,1,122,2,20,2,107,0,34,3,75,1,136,0,144,255,114,254,249,251,226,254,186,254,63,253,32,1,16,1,19,5,120,4,154,4,92,3,89,254,121,0,127,254,108,255,217,254,210,254,190,252,205,252,16,0,232,255,55,255,36,254,43,2,91,0,11,255,38,1,218,255,133,254,62,252,59,251,89,251,18,250,239,254,117,254,122,254,11,252,123,253,61,2,205,248,250,251,249,1,212,1,232,2,179,3,97,2,237,1,79,253,108,251,140,253,121,255,254,251,195,0,155,1,196,0,46,6,123,4,63,2,81,1,41,251,247,252,120,253,114,255,83,2,57,3,199,3,223,2,74,251,54,252,175,255,170,254,23,253,13,0,184,255,119,1,198,1,19,0,127,5,153,3,145,249,84,255,93,3,50,2,160,3,1,6,39,4,228,2,88,246,72,252,8,1,82,0,10,254,59,252,202,250,123,0,99,3,212,4,22,2,171,0,240,246,52,254,12,3,107,1,90,251,151,253,252,0,195,255,82,255,34,0,243,3,20,3,227,246,247,0,167,1,153,0,240,255,157,254,6,1,193,1,216,249,207,251,224,253,141,254,153,253,207,254,27,4,37,3,175,2,16,2,6,0,74,255,167,3,107,3,234,3,41,3,199,0,1,1,126,0,76,0,184,253,142,251,87,2,44,2,175,251,145,250,201,249,249,253,47,252,211,250,108,0,91,1,46,253,49,252,109,1,101,0,111,255,169,2,249,0,103,255,0,0,178,254,198,253,159,0,156,1,29,1,176,254,151,253,71,252,58,252,119,3,177,2,29,251,84,0,71,255,114,254,176,253,177,1,20,4,141,2,85,0,73,1,216,255,105,1,79,254,63,253,210,1,62,2,102,255,142,2,80,2,34,1,89,255,72,0,93,1,175,0,162,2,41,1,209,3,208,2,211,4,180,4,245,2,232,1,112,254,243,254,26,2,116,1,186,250,149,250,86,251,165,255,238,4,108,3,7,3,188,2,169,253,218,255,82,254,46,253,184,7,94,6,223,3,96,2,111,0,20,1,30,255,160,255,77,252,124,254,245,255,249,255,209,254,237,253,185,252,82,1,198,6,174,6,125,5,245,3,252,253,169,252,123,253,210,0,80,253,96,254,1,2,230,0,202,252,131,253,134,251,192,254,72,252,110,253,74,253,183,0,142,255,145,253,50,3,162,2,65,255,52,255,219,2,123,2,51,0,197,4,115,3,64,2,70,252,81,254,58,3,86,2,170,254,13,253,124,252,105,254,154,251,158,254,50,255,0,254,221,253,214,252,155,254,148,253,66,0,3,2,183,255,102,254,152,252,79,252,92,250,53,251,191,0,239,255,224,253,25,255,252,249,224,253,123,252,138,252,67,0,239,255,66,0,244,255,102,249,187,253,152,255,240,254,204,251,94,251,203,248,136,254,140,251,98,252,92,254,198,255,253,254,112,253,146,251,215,253,252,6,203,4,199,1,129,0,206,1,185,1,16,255,240,253,72,3,2,2,130,0,181,255,90,4,111,2,153,0,216,0,44,4,52,2,250,255,236,254,95,4,215,2,190,0,188,255,192,2,50,1,119,0,248,254,73,1,61,0,156,255,156,0,108,1,123,0,183,0,48,255,85,255,133,255,220,0,191,255,206,254,194,255,146,1,17,0,108,253,86,252,246,254,0,0,129,1,235,0,20,1,29,1,64,1,12,1,176,254,56,255,44,253,17,0,172,255,125,1,224,253,173,1,238,1,7,2,139,255,32,1,48,1,73,1,131,2,157,0,189,2,252,1,176,4,113,2,28,3,96,2,230,3,165,1,236,1,120,2,180,4,12,3,190,1,132,0,233,4,76,3,35,2,193,1,61,3,146,2,29,2,214,1,108,4,234,4,150,3,127,2,35,2,51,0,167,1,23,1,9,0,136,1,83,0,94,0,30,2,31,2,229,0,109,255,58,255,129,0,194,0,71,255,161,252,215,250,210,254,30,0,171,253,139,253,237,255,114,0,124,252,199,251,210,1,97,1,53,250,219,249,15,0,113,255,84,249,245,247,17,253,196,0,172,248,237,247,126,253,254,254,225,246,66,250,62,254,204,253,184,253,70,255,152,252,98,254,243,248,36,252,155,251,226,250,42,253,151,251,28,0,169,0,241,251,160,252,50,253,10,255,228,1,36,0,23,255,207,255,9,1,67,0,33,1,211,1,178,0,31,2,42,3,28,2,84,0,26,1,160,2,191,2,49,252,247,252,129,0,31,1,86,252,29,255,187,3,83,2,175,249,223,254,68,3,137,2,201,248,41,255,82,4,206,2,14,248,195,251,138,2,184,1,203,247,239,253,139,3,63,2,37,248,176,254,158,2,204,0,171,246,76,253,104,1,137,0,148,247,100,247,247,255,24,1,246,254,119,0,39,0,193,0,78,0,197,255,136,255,226,0,49,252,166,252,243,252,185,251,149,253,99,254,61,254,182,252,64,251,215,250,211,252,141,252,160,250,177,249,118,254,84,254,31,253,167,251,219,253,234,252,144,252,49,252,57,252,126,253,39,252,138,252,7,251,175,250,39,254,220,252,135,250,129,250,160,0,247,254,105,252,237,254,8,255,6,255,50,253,132,254,97,0,153,255,137,254,27,255,97,254,63,255,121,255,213,253,116,2,105,1,119,0,216,0,67,2,108,1,135,1,209,0,122,2,10,2,102,255,108,255,14,2,133,1,170,0,33,0,105,0,11,1,64,0,124,1,33,250,24,252,226,255,143,254,210,251,58,0,135,2,223,0,16,250,221,254,109,2,51,1,5,250,156,0,250,2,148,1,19,248,141,0,222,2,243,1,199,248,118,253,50,1,0,2,69,255,152,255,197,255,182,1,134,0,26,255,156,0,70,255,195,255,252,254,240,255,10,0,199,253,253,255,91,254,215,254,67,249,247,253,166,254,178,0,174,250,197,255,212,255,157,0,158,247,51,254,42,254,163,254,134,247,255,255,143,254,135,255,213,249,139,254,124,252,9,252,163,251,177,253,155,253,240,252,207,253,122,0,181,255,63,254,252,255,85,255,133,255,140,254,192,0,168,0,180,255,124,255,252,0,149,255,84,1,210,0,136,1,253,1,16,1,181,0,147,255,145,0,218,0,119,0,96,254,249,254,229,1,9,1,75,255,248,255,226,254,226,0,12,255,38,255,69,0,222,254,98,255,191,0,255,255,192,255,176,253,166,255,213,0,160,255,255,0,179,1,178,0,176,255,143,254,238,255,223,255,176,255,214,255,159,1,140,0,34,255,119,4,139,2,137,2,73,1,255,2,44,2,249,0,235,0,180,3,157,1,186,1,23,1,141,0,83,1,100,1,45,2,42,254,86,255,99,0,237,0,199,253,224,252,96,1,53,2,26,1,217,1,214,1,76,1,57,255,78,253,252,250,107,252,63,255,86,254,224,252,158,251,230,255,141,254,22,254,63,255,125,2,83,2,7,2,74,1,152,1,141,255,79,0,12,0,221,1,87,0,153,255,136,254,102,253,165,254,235,254,221,254,2,254,31,254,169,0,41,1,195,252,30,253,51,255,85,255,192,254,228,253,72,1,27,1,165,252,66,252,186,1,254,255,44,2,174,2,130,0,56,0,103,5,244,3,243,2,171,1,100,2,229,2,116,2,41,2,173,254,228,252,134,0,21,1,135,253,195,251,254,255,10,255,144,252,245,251,185,249,216,251,30,252,38,254,142,251,24,254,98,254,229,252,73,0,50,255,248,255,117,255,183,1,204,0,80,255,190,253,23,0,131,0,243,254,11,253,65,255,245,0,147,255,174,254,112,0,60,1,120,0,106,254,138,255,99,2,76,255,70,255,123,253,115,0,83,255,34,0,250,253,23,254,105,255,61,0,185,253,180,252,220,0,118,255,87,253,4,252,135,1,239,255,170,253,191,254,157,0,217,254,129,0,155,0,98,252,149,252,37,252,29,1,241,0,173,255,131,255,131,255,108,2,85,2,176,1,92,0,137,1,78,0,153,1,61,0,119,254,29,253,99,254,20,253,83,0,54,0,105,1,27,0,196,251,130,0,175,254,74,253,227,249,41,1,62,1,237,255,175,248,36,0,51,0,195,254,237,246,10,255,231,0,172,255,254,246,241,252,40,0,77,255,71,247,94,252,38,254,50,254,14,253,170,255,224,254,142,253,149,246,57,254,193,255,171,0,181,251,186,251,230,255,113,255,87,251,57,254,106,254,131,254,163,253,46,255,160,255,205,255,188,253,36,254,236,254,241,255,85,251,134,253,77,251,143,252,134,254,35,255,99,253,72,252,82,2,178,0,109,254,92,253,251,2,71,1,89,2,34,1,172,0,44,1,203,0,157,0,200,255,176,254,100,1,24,0,28,255,216,254,253,254,227,255,70,255,7,1,160,1,14,0,159,254,117,1,244,255,40,255,1,1,96,0,174,0,57,0,10,250,152,253,70,252,13,254,15,254,104,255,179,254,125,0,105,0,200,0,179,0,159,255,181,254,32,255,253,2,185,2,248,2,0,1,45,1,59,0,199,1,171,255,204,0,32,1,254,253,240,0,251,0,147,255,0,1,161,1,222,255,99,254,101,0,174,1,128,1,156,0,225,255,246,255,206,0,170,1,77,2,145,0,143,0,71,0,40,3,138,3,77,1,93,1,218,3,170,3,77,2,75,1,20,5,56,3,187,0,253,1,38,4,141,2,123,1,210,1,182,5,169,3,145,1,18,1,19,3,93,3,9,1,2,0,97,2,41,2,28,0,49,1,158,3,84,1,106,0,130,1,241,0,245,254,109,255,225,0,78,255,234,253,91,1,246,1,125,253,131,254,141,1,30,0,117,253,35,253,77,254,142,1,105,254,42,253,28,254,8,255,235,252,110,252,74,254,36,254,14,254,122,254,75,0,217,254,60,252,178,253,162,253,150,0,135,255,207,255,101,255,178,255,167,3,38,2,133,1,38,0,191,254,127,0,168,1,59,1,227,254,143,255,27,1,3,1,146,2,203,0,66,1,230,1,135,3,249,1,236,2,161,1,99,2,167,1,43,2,0,2,239,0,173,255,190,253,237,255,173,254,37,253,93,1,13,0,90,252,137,250,142,255,152,254,107,0,180,2,182,0,90,0,37,251,254,249,241,249,43,253,200,253,121,252,173,250,243,253,251,253,171,252,163,252,20,252,88,255,78,253,189,252,63,0,119,255,212,253,221,253,144,0,226,254,207,252,229,1,63,1,109,255,104,254,14,2,246,0,165,254,78,254,41,1,228,255,222,254,41,254,170,251,251,250,52,254,153,254,36,252,230,252,67,5,19,5,178,2,11,2,192,4,44,4,70,4,245,2,57,3,116,4,240,2,238,1,228,4,85,5,171,4,130,3,9,2,29,4,20,2,176,1,178,254,40,255,199,254,249,254,96,255,52,0,40,254,101,255,127,0,136,0,132,254,44,0,83,3,154,1,94,255,23,254,123,0,1,255,228,252,101,253,66,4,149,3,21,3,237,1,117,5,173,4,46,2,202,0,205,255,138,255,170,254,67,253,83,0,108,0,214,255,71,254,61,0,95,0,31,1,0,1,229,255,89,0,12,2,19,2,95,1,227,0,80,2,33,2,185,2,155,0,92,255,51,1,126,2,18,1,23,254,206,255,242,2,240,0,90,255,132,255,140,255,189,253,68,251,193,255,190,0,217,254,240,251,240,250,147,0,136,254,79,255,143,255,73,3,217,4,27,4,156,2,2,0,37,1,39,2,48,1,184,251,71,252,8,255,120,1,18,253,59,252,87,0,4,2,237,254,252,253,177,2,135,1,133,254,125,253,108,3,82,2,122,254,11,252,123,253,61,2,149,255,200,253,79,253,198,252,255,251,229,255,184,254,53,255,93,3,237,2,36,2,233,0,132,249,237,251,195,1,108,0,108,253,148,253,174,1,236,0,21,0,116,254,122,251,137,253,92,5,18,5,199,3,65,2,101,4,101,4,77,2,198,1,189,254,159,252,45,254,153,0,44,254,69,253,220,252,3,254,120,254,50,253,52,255,221,255,165,253,187,251,201,253,94,255,7,254,20,252,154,255,94,1,219,0,224,0,167,1,252,0,139,1,79,2,96,2,107,1,22,253,160,255,117,1,172,0,171,0,39,1,202,2,83,1,233,0,77,0,107,0,21,1,157,0,153,0,13,254,156,254,11,6,49,4,64,2,238,1,220,254,173,254,8,254,176,253,121,252,184,255,149,253,31,254,198,249,163,251,201,253,2,255,231,252,5,254,204,253,221,254,20,254,236,253,246,1,48,2,130,254,171,1,88,2,230,0,29,255,221,1,251,0,75,0,29,1,74,3,45,3,220,1,226,250,203,250,186,0,121,1,181,253,107,252,131,2,125,1,94,251,215,253,155,1,82,0,153,251,204,252,82,255,228,253,164,253,119,0,31,2,205,0,132,254,145,2,141,3,55,2,112,0,214,254,138,254,114,0,167,252,5,255,56,0,159,0,145,1,89,1,222,255,116,255,145,255,161,253,41,0,102,2,99,1,142,255,179,255,218,1,66,2,56,0,170,5,156,3,74,4,140,5,229,2,144,1,246,0,22,0,76,2,57,1,135,255,71,1,63,3,216,1,142,251,160,253,88,3,40,2,39,251,208,251,126,2,88,2,154,254,254,0,179,254,209,254,122,253,227,2,102,1,74,0,202,4,135,6,197,4,81,3,193,8,88,6,215,3,124,2,49,7,197,5,237,2,128,1,94,1,7,1,87,0,128,0,146,248,83,252,112,255,192,255,58,249,1,255,32,1,225,255,172,245,42,251,110,1,235,0,149,249,188,251,192,250,208,254,227,253,205,251,164,251,123,0,102,251,4,255,208,252,76,255,8,252,21,2,53,2,233,0,25,254,82,254,68,255,78,1,99,3,212,4,22,2,171,0,202,249,185,249,123,2,118,2,108,247,54,1,156,3,156,1,202,246,184,254,188,3,17,2,177,245,135,254,118,2,22,1,214,245,61,1,31,3,43,1,154,246,133,0,84,1,31,0,148,247,68,250,131,0,125,0,96,251,22,254,117,255,46,0,24,253,191,1,123,3,52,2,67,0,61,254,134,2,92,2,215,253,83,254,148,252,140,1,162,0,190,255,25,5,147,3,223,1,67,2,64,4,26,3,194,1,22,1,54,2,68,1,223,251,102,255,148,0,79,255,15,246,168,0,46,4,80,2,209,246,214,255,51,3,89,1,216,246,61,253,209,2,250,0,129,247,39,250,203,254,122,0,178,255,183,255,120,0,173,0,252,255,6,1,249,254,251,254,81,254,192,255,107,254,36,253,207,245,116,0,173,255,63,255,11,250,80,252,35,254,43,253,4,254,51,1,170,0,172,0,64,3,161,1,64,3,174,2,31,255,177,0,126,3,50,3,30,254,123,254,255,4,15,4,129,254,201,0,162,254,40,0,218,2,123,2,226,0,14,2,247,1,206,1,82,1,142,1,23,2,202,2,40,0,230,254,202,5,191,5,61,4,219,2,25,6,48,4,141,3,181,2,139,5,2,5,121,3,111,3,129,4,216,2,162,4,72,3,30,255,106,4,181,3,177,2,18,254,38,252,236,249,128,255,200,253,47,253,55,253,230,255,61,1,12,2,70,0,135,0,107,254,159,252,26,249,116,253,82,255,223,252,117,3,5,3,103,255,165,255,75,4,239,2,6,254,131,251,85,3,134,2,241,0,14,3,7,2,27,2,61,7,164,6,77,4,172,2,31,251,50,250,48,254,188,0,131,252,127,250,224,250,171,254,121,255,182,1,81,255,18,0,87,4,208,3,63,1,208,0,106,250,24,249,83,0,202,1,238,253,24,252,51,1,129,0,184,252,241,255,227,255,156,254,113,252,100,252,133,251,14,255,137,255,240,253,127,0,123,255,7,253,3,253,190,0,173,255,197,254,127,3,10,2,231,0,34,255,102,0,193,255,84,254,60,1,187,2,123,1,70,0,25,0,204,2,58,1,148,255,251,1,106,3,54,2,238,0,108,0,173,3,7,2,195,0,169,1,196,255,85,254,1,1,139,0,153,255,138,253,190,1,78,1,114,1,156,1,48,0,84,255,78,253,229,254,45,2,187,0,226,254,158,0,227,1,140,0,14,1,168,254,137,253,156,3,67,2,140,255,132,0,142,0,210,1,188,255,192,255,230,0,111,255,210,254,226,253,221,252,112,252,250,3,225,2,251,252,247,3,118,2,41,1,220,245,95,0,189,1,80,1,182,247,235,1,254,1,191,0,27,251,161,0,254,255,188,254,86,250,135,253,56,253,151,255,182,252,2,255,101,254,100,0,128,253,222,254,242,3,251,2,118,253,57,1,145,4,218,2,140,0,249,1,6,4,254,2,4,3,31,1,43,4,55,3,239,1,237,2,49,1,67,1,92,255,206,1,78,0,143,1,170,254,150,252,69,0,85,2,240,255,108,2,109,2,81,1,118,255,68,254,247,254,218,0,84,0,62,254,185,3,154,2,34,255,221,252,29,2,92,2,103,252,160,250,244,0,116,0,183,252,45,253,118,2,76,2,140,0,151,2,38,1,112,1,167,3,22,4,113,3,247,2,210,6,184,5,148,3,116,2,180,1,195,3,25,1,1,0,137,255,74,0,30,2,213,0,1,0,201,253,45,1,241,0,4,1,179,1,222,0,140,1,168,3,189,3,84,4,191,2,254,1,250,1,40,3,222,1,89,2,182,2,192,3,108,2,204,3,229,2,212,3,88,2,66,3,205,2,255,2,172,2,131,2,204,3,167,3,126,2,245,1,149,2,208,2,83,3,151,255,136,253,209,254,139,255,83,254,130,0,21,3,186,1,246,253,68,255,192,2,117,1,9,253,42,0,46,3,11,2,237,253,143,251,117,1,66,2,86,253,77,251,57,254,29,1,117,251,215,249,182,251,44,0,81,0,174,255,200,2,107,1,221,1,246,0,186,3,110,2,68,6,86,6,253,4,123,3,129,5,91,3,156,3,124,3,6,3,17,4,179,3,118,4,40,0,222,253,181,255,32,1,152,253,150,255,71,253,230,255,87,255,96,255,133,252,29,253,233,254,128,254,251,251,162,254,245,6,28,5,22,4,48,3,44,6,253,5,192,5,154,4,225,5,52,4,192,4,131,3,122,3,136,3,52,2,142,2,152,3,180,2,253,3,88,3,19,254,132,0,177,0,249,1,71,0,195,0,228,255,97,0,200,1,95,1,92,255,88,0,183,1,22,1,216,255,94,1,115,5,181,3,234,0,161,255,219,252,40,254,38,0,93,255,111,1,158,255,233,1,11,2,1,4,154,4,188,4,138,3,63,1,34,5,46,3,205,1,133,255,225,253,220,252,191,1,20,253,188,254,127,252,153,251,31,253,11,254,235,252,55,253,203,2,9,3,215,4,154,3,157,7,147,7,88,5,97,3,218,2,112,3,246,2,132,1,153,252,198,1,17,0,5,255,131,254,214,252,209,249,239,0,247,253,58,252,232,252,3,1,134,252,178,250,254,252,183,255,166,0,93,1,44,255,67,1,184,252,211,254,217,1,179,1,89,253,48,254,216,2,95,1,100,255,57,255,155,2,176,1,29,0,4,255,159,1,224,1,37,253,133,254,145,0,47,2,240,253,137,253,122,251,97,255,189,1,17,1,123,0,127,2,117,1,130,255,32,3,56,2,84,0,94,255,208,2,200,2,194,252,232,253,71,255,222,0,152,1,196,1,245,1,3,3,127,252,181,250,189,255,186,1,232,252,130,250,54,2,90,2,167,0,186,254,253,1,74,1,161,255,142,253,38,253,168,254,132,6,193,4,11,3,199,1,36,5,60,3,72,2,207,2,148,1,225,255,245,3,21,3,89,0,107,0,123,3,37,2,103,3,45,6,149,3,159,2,98,3,199,5,9,5,86,3,135,1,44,4,98,4,44,3,78,0,206,253,89,1,51,2,173,1,153,255,161,1,19,3,134,255,75,254,155,1,20,3,111,252,95,254,90,2,242,2,30,255,240,255,151,0,248,2,68,253,118,0,152,255,242,255,152,251,48,0,28,1,137,1,122,254,93,254,129,253,140,255,114,252,50,1,60,1,243,255,183,4,216,3,53,3,157,2,85,251,75,253,140,0,43,255,140,252,96,254,57,255,210,253,152,253,245,0,108,254,104,253,6,1,56,0,151,253,44,253,171,255,21,254,192,254,112,253,198,253,193,252,127,255,240,253,30,250,193,255,145,254,127,254,154,254,191,254,4,0,51,0,146,254,42,255,63,1,255,1,146,0,159,2,239,255,221,254,146,255,208,1,117,255,16,254,54,255,220,0,200,254,137,253,108,253,183,255,113,253,204,252,106,253,115,253,248,250,167,252,82,254,71,252,65,252,248,254,207,255,44,254,184,255,131,254,162,254,205,253,63,255,105,254,55,0,104,254,221,252,11,0,203,254,137,2,188,0,58,255,0,254,205,1,177,255,54,254,218,250,249,254,122,255,245,253,135,249,77,254,17,254,3,253,57,0,165,254,98,254,178,1,139,251,14,255,104,253,167,252,34,0,188,255,61,253,174,254,50,0,71,0,247,255,174,254,70,253,129,250,102,0,118,255,204,252,202,254,43,254,133,251,158,1,67,0,245,254,36,4,46,3,161,5,12,6,80,5,248,4,218,6,103,7,125,6,227,7,85,8,28,7,16,7,14,9,53,7,132,2,163,255,198,1,90,3,73,1,120,255,233,1,254,254,128,255,58,255,23,253,215,255,204,255,247,254,39,252,90,1,137,0,223,1,51,249,20,253,84,253,117,251,67,249,145,254,129,252,135,251,240,252,24,254,78,252,56,252,171,255,122,254,43,253,215,0,172,254,85,255,252,3,148,3,177,7,52,2,179,0,234,2,150,2,209,3,198,6,119,3,110,2,146,3,171,3,88,3,141,4,53,1,176,2,35,3,149,3,161,0,58,2,118,0,236,255,229,254,208,252,214,255,204,0,52,251,187,254,50,254,61,252,54,255,113,255,36,252,28,254,151,254,66,253,46,252,35,254,210,254,234,252,92,251,156,255,238,252,192,251,226,251,77,252,108,249,54,255,181,252,242,252,241,251,158,250,123,252,144,253,146,255,171,255,100,1,213,0,246,255,19,254,108,1,6,3,169,1,54,3,223,1,173,255,45,2,8,2,32,252,232,249,196,253,165,253,27,253,230,255,10,254,130,253,121,252,209,0,50,1,147,0,196,254,175,253,172,253,171,255,45,255,31,255,106,252,239,253,117,0,233,0,73,254,30,253,77,4,239,2,121,2,177,5,180,6,231,5,229,6,177,5,142,3,98,4,132,4,81,3,74,5,100,3,214,1,153,252,130,251,252,248,153,252,163,252,32,252,138,255,155,0,212,0,229,251,175,252,162,253,163,251,199,248,66,245,5,252,109,250,179,248,114,1,72,255,98,254,191,3,237,1,104,0,190,3,15,4,31,2,154,0,141,2,201,0,225,4,251,1,150,0,151,2,247,1,230,0,111,2,9,3,163,2,147,2,88,0,146,255,75,3,244,0,224,0,126,1,29,2,46,1,212,2,177,1,154,2,142,4,222,2,85,1,118,255,20,0,115,254,97,251,88,254,210,255,191,254,160,254,132,255,53,5,253,3,56,4,6,1,110,1,211,2,154,3,27,1,217,253,31,0,132,253,157,253,79,253,71,253,97,254,72,252,245,252,55,255,207,250,170,253,153,254,71,252,251,250,166,0,237,1,49,1,221,0,78,3,191,2,98,2,72,3,168,3,6,3,45,253,212,250,19,251,155,254,255,251,148,250,184,251,160,250,147,254,120,250,167,248,160,253,250,248,65,249,94,253,223,253,107,251,65,253,166,2,18,3,148,0,133,255,184,2,8,5,132,2,94,1,246,255,158,1,102,2,15,0,137,0,88,1,45,255,210,252,24,250,205,252,121,254,94,252,180,253,47,0,177,253,126,252,115,252,183,251,93,255,8,251,113,251,99,255,72,250,11,250,123,254,6,251,92,251,144,253,159,2,213,0,198,1,124,0,238,254,243,253,39,253,16,254,104,255,192,250,122,0,135,0,167,244,179,253,118,254,64,249,185,1,206,255,196,5,136,3,19,3,60,1,236,0,72,254,165,254,217,0,157,1,113,252,107,252,121,0,57,254,92,252,202,0,164,255,47,254,137,254,232,1,134,1,218,1,108,3,217,2,60,1,233,248,224,250,99,253,87,0,194,3,176,1,51,2,7,255,222,251,250,0,29,1,81,4,117,4,171,1,184,2,242,251,128,249,210,249,76,252,90,1,160,0,203,254,240,254,166,252,158,2,112,2,226,4,80,252,104,254,102,253,162,253,192,254,128,254,20,254,230,0,65,0,78,1,206,255,240,255,240,255,78,253,139,250,255,6,180,6,119,5,174,9,15,8,124,5,221,4,191,5,146,5,130,254,243,251,254,255,173,0,114,254,121,4,211,5,232,7,9,7,4,3,250,4,226,5,149,5,199,6,209,7,55,4,194,4,249,4,126,251,197,248,207,250,216,252,147,251,184,251,61,254,247,251,70,249,65,0,66,2,172,255,60,250,126,246,14,249,3,253,170,250,18,254,38,255,174,253,93,252,81,1,20,255,50,2,53,9,102,10,146,7,209,5,252,4,106,3,189,0,102,1,118,1,17,250,23,247,214,246,57,252,9,251,209,247,140,253,92,251,250,249,125,6,19,4,34,2,53,2,37,4,220,2,192,255,188,252,78,254,76,254,160,255,203,0,54,4,192,4,100,6,139,3,254,5,218,3,70,1,197,3,77,3,142,0,172,255,197,0,214,1,75,9,34,6,109,4,214,1,190,4,139,1,96,5,176,4,101,4,18,4,92,1,225,253,46,251,136,254,41,255,75,255,225,1,101,248,171,249,46,255,18,253,95,251,134,1,29,0,113,254,27,0,52,3,212,4,243,2,183,2,211,3,153,1,82,255,173,4,11,4,144,3,76,5,54,7,32,252,99,250,228,1,51,250,92,249,208,0,100,254,180,4,152,5,241,254,128,3,120,4,96,254,241,6,154,5,96,249,172,245,52,255,3,249,241,249,9,4,136,249,233,249,23,5,27,251,203,249,57,4,99,253,185,251,190,255,86,253,64,1,167,254,147,2,49,1,45,4,244,250,220,252,237,255,157,249,245,250,29,0,109,249,15,254,71,0,225,254,249,255,156,255,18,254,62,252,19,255,84,3,89,7,204,6,63,251,149,250,227,0,108,253,46,1,117,1,96,0,63,4,233,4,206,251,123,249,160,0,229,1,28,8,6,7,90,252,36,255,40,2,172,253,156,253,237,0,80,1,184,6,111,3,131,2,117,2,178,1,243,4,10,2,97,6,15,0,244,0,71,254,195,5,205,2,184,0,27,7,54,6,173,6,220,3,5,1,169,3,45,8,41,9,240,5,91,8,66,7,70,6,191,253,189,253,77,251,68,252,135,0,24,254,48,254,51,0,174,254,139,253,164,254,45,253,122,4,25,8,162,5,144,8,186,5,143,3,92,250,220,249,26,247,120,5,198,2,17,5,55,5,121,2,160,3,154,5,146,8,34,10,118,9,156,8,89,7,214,3,194,8,62,7,124,1,24,3,121,4,193,255,229,253,158,1,4,255,60,252,198,254,19,251,85,253,244,252,193,252,242,253,19,252,126,249,145,251,88,254,181,249,60,254,213,254,244,4,24,4,130,2,123,4,85,3,88,3,93,253,176,254,139,0,220,8,63,5,138,5,29,0,0,3,29,3,56,251,167,1,52,2,218,250,198,251,245,0,234,250,212,252,61,2,238,250,175,249,134,2,56,252,66,3,211,2,225,3,116,6,235,7,65,255,207,252,176,1,150,2,60,0,198,0,114,2,229,3,50,5,112,6,171,7,9,5,195,249,163,255,211,255,192,251,37,0,172,255,117,6,47,10,33,9,41,4,248,7,73,9,115,4,22,9,70,8,91,3,101,1,230,5,152,2,203,4,75,4,223,1,80,5,144,3,105,7,218,6,227,7,144,4,117,7,248,6,143,1,34,0,0,1,175,253,208,254,227,251,35,2,158,6,127,5,135,2,157,255,171,254,212,5,111,6,166,4,38,0,124,253,44,255,139,1,78,3,222,0,64,253,3,253,52,253,44,253,84,248,12,245,106,255,35,1,174,255,209,4,179,5,239,3,116,255,101,255,153,0,183,1,41,1,32,6,7,250,102,254,132,253,0,6,199,1,19,255,208,250,117,255,252,254,19,2,42,2,100,3,13,1,240,4,94,2,23,255,115,3,207,1,230,2,88,2,136,255,183,255,165,1,212,0,73,254,198,255,36,3,250,250,39,251,216,2,38,1,22,254,50,0,177,253,119,252,26,251,42,0,81,253,147,0,231,255,17,1,84,2,201,254,189,4,89,2,14,253,81,3,72,2,173,1,95,2,75,2,166,253,90,255,205,1,228,252,201,252,9,3,100,5,142,3,219,6,119,0,137,5,204,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+748904);
/* memory initializer */ allocate([37,255,144,252,196,249,231,251,14,252,182,1,55,253,157,250,78,0,0,0,65,254,101,251,144,251,217,250,219,249,200,8,231,6,29,5,178,3,47,6,152,5,126,4,226,1,180,1,43,254,172,251,106,2,65,254,58,252,64,4,28,251,21,250,142,255,176,251,40,248,189,253,210,0,101,2,241,1,73,248,99,250,130,2,11,251,168,252,243,3,146,249,95,251,39,4,237,249,96,253,180,4,100,249,166,251,111,2,45,252,210,250,3,251,27,2,109,255,126,3,182,250,127,252,78,254,120,3,219,1,172,1,153,0,128,254,82,1,44,250,1,254,103,1,50,252,165,251,42,254,105,0,218,253,165,2,87,252,135,251,109,3,124,1,252,254,210,0,149,6,156,3,232,4,239,6,166,4,71,4,139,5,119,2,21,2,115,2,43,1,165,254,101,254,234,253,135,2,118,253,29,0,173,253,134,254,169,250,27,6,122,5,97,4,185,5,65,4,130,5,136,2,208,247,190,251,250,255,55,1,62,255,155,252,129,253,193,252,160,1,118,251,56,251,69,5,33,251,83,252,21,7,111,247,61,248,197,1,149,253,169,250,68,252,186,249,76,248,29,250,105,251,223,251,176,251,135,254,89,2,201,0,84,7,57,3,118,1,82,254,213,250,29,0,139,250,31,251,205,250,17,252,32,250,192,3,135,250,39,248,197,0,157,250,99,248,20,255,203,251,123,0,166,1,103,2,245,4,34,2,206,254,246,5,136,3,170,4,252,6,153,4,142,253,140,252,10,250,199,0,254,2,224,5,215,251,94,3,197,0,246,251,19,249,137,252,224,252,145,0,87,2,146,251,249,253,114,2,75,251,122,248,244,1,114,252,239,251,141,250,60,250,225,249,55,252,245,253,74,3,34,0,2,7,134,2,94,3,73,251,160,248,22,252,178,255,247,255,96,253,20,4,247,2,80,0,168,253,115,4,251,3,57,0,208,7,142,5,191,252,134,5,97,4,78,251,94,6,236,4,51,254,140,5,220,4,1,6,207,3,253,0,229,254,68,1,153,254,87,2,61,255,106,0,76,2,62,0,181,253,11,253,133,2,205,0,51,0,177,4,246,2,71,251,161,2,122,254,144,253,45,6,173,3,105,255,255,3,223,2,4,11,21,5,178,2,210,254,12,2,157,255,124,252,204,249,91,251,60,4,251,0,238,0,222,7,0,7,242,3,221,4,97,6,205,6,53,251,252,249,72,251,147,253,200,1,147,255,40,0,191,255,20,3,219,252,69,253,186,250,185,253,136,3,64,3,223,252,20,2,82,2,180,7,128,5,71,5,103,251,168,248,190,247,251,252,56,2,180,3,9,252,55,4,236,4,169,251,226,1,126,255,242,6,20,4,12,3,45,250,245,0,144,3,196,254,139,251,107,252,232,253,94,250,214,246,239,252,246,249,60,248,45,248,1,1,141,3,199,248,135,253,71,251,254,249,130,248,226,251,70,6,191,8,40,6,201,253,36,250,248,249,1,251,195,0,89,5,207,252,37,1,195,4,243,253,118,2,173,4,94,249,135,246,208,248,209,254,219,2,235,2,111,251,5,255,13,1,74,252,181,255,148,6,98,251,59,254,237,3,193,249,73,2,122,1,229,247,197,253,85,254,239,253,121,251,109,251,229,254,51,255,204,253,228,252,222,4,205,2,229,8,159,3,27,2,58,254,47,2,184,1,51,253,180,5,79,6,250,251,28,4,74,6,111,251,118,255,79,3,226,0,39,0,156,253,29,251,150,255,39,253,117,253,200,3,22,5,54,253,132,253,191,6,97,1,45,4,154,1,226,252,100,255,75,4,194,253,150,3,190,1,226,250,244,3,210,1,128,5,55,6,253,2,149,5,100,5,221,6,157,7,164,7,74,9,42,6,255,7,100,8,148,3,98,0,249,255,101,7,138,5,93,8,92,1,125,5,43,6,152,0,110,4,9,7,245,254,154,0,115,5,114,251,213,1,30,4,138,251,107,254,207,251,195,250,40,247,211,249,148,254,101,3,170,6,118,251,37,2,14,6,55,251,116,248,126,249,51,250,71,248,249,247,65,249,118,252,158,255,151,248,233,0,212,5,124,3,108,0,181,254,64,249,110,251,92,249,220,251,188,7,254,6,210,251,51,249,139,248,245,255,3,6,37,5,192,249,94,0,241,1,165,1,187,1,59,255,214,249,163,254,30,252,169,253,229,253,116,4,59,252,117,250,127,255,195,250,175,0,65,254,137,254,31,5,7,8,141,254,118,253,205,254,207,251,93,2,109,1,247,247,143,255,174,1,140,2,146,3,199,3,12,252,206,249,237,246,225,5,224,4,47,2,6,1,26,254,111,254,65,249,62,5,10,6,50,0,56,0,176,1,182,254,119,0,164,253,19,250,200,251,214,252,178,3,103,4,31,4,136,250,89,249,80,249,10,251,64,253,219,250,39,3,29,7,119,4,200,10,70,6,123,8,96,4,153,1,106,255,109,255,148,1,191,3,135,9,119,7,141,8,118,252,115,255,158,252,120,252,114,255,54,254,211,253,60,253,113,249,194,252,105,250,209,249,206,248,190,250,194,251,188,249,240,254,147,3,84,251,4,3,32,4,130,253,46,251,151,248,12,254,175,255,202,252,247,250,179,249,33,253,139,255,17,3,168,0,190,251,109,4,154,3,184,251,22,253,104,5,31,1,221,253,217,251,160,250,103,247,76,251,128,247,222,249,35,249,25,250,63,247,253,252,55,249,75,4,62,3,204,249,212,2,219,4,250,249,181,2,37,3,102,249,16,255,129,6,92,249,252,255,100,253,101,8,48,3,18,4,206,252,207,248,22,0,4,253,5,254,193,1,129,251,151,253,33,1,181,252,196,249,16,255,242,1,22,255,111,253,16,253,224,1,142,6,193,254,31,254,193,0,213,252,171,0,137,255,176,247,54,255,176,252,181,6,116,4,164,6,134,252,242,249,19,246,205,252,54,252,175,0,198,252,46,251,6,253,169,253,234,255,122,2,213,252,37,252,122,252,189,254,203,0,26,0,129,254,21,255,243,252,113,254,238,4,138,3,92,252,137,250,156,250,144,253,93,0,87,0,98,254,229,253,77,253,37,0,121,2,254,1,125,254,36,254,206,250,143,1,66,0,7,1,105,254,207,255,177,254,95,254,17,4,73,7,245,252,191,251,96,250,22,253,166,252,64,3,187,253,9,253,141,254,95,253,6,254,40,8,208,253,134,253,101,251,15,1,241,0,14,0,74,254,12,255,115,254,207,1,178,4,23,4,162,253,227,252,98,250,205,255,189,254,225,1,32,255,184,253,241,253,238,1,113,3,170,2,79,254,206,254,22,252,42,2,147,2,222,0,171,0,96,255,159,254,169,2,6,7,29,6,172,252,99,251,97,249,176,254,102,253,114,0,187,253,12,253,24,253,61,255,119,1,241,1,47,254,220,252,182,251,154,0,26,1,125,255,206,255,65,255,49,253,67,1,220,2,6,6,46,253,205,252,132,250,105,0,6,255,185,0,78,255,10,254,26,253,65,1,254,1,87,4,189,254,201,253,58,252,127,0,228,1,82,1,96,255,52,0,174,254,220,2,87,5,18,6,142,253,222,252,96,249,226,254,182,253,164,2,73,253,169,254,142,254,22,254,39,1,101,7,138,253,194,253,10,252,176,255,133,2,187,255,250,255,194,254,148,254,14,3,170,5,14,4,199,254,35,253,141,250,120,0,60,0,221,1,248,254,183,253,133,255,199,2,221,4,121,2,165,255,157,254,8,252,3,3,246,2,5,1,253,0,81,0,38,254,162,3,167,8,184,6,216,252,181,251,123,248,208,253,242,252,169,0,220,252,206,251,68,255,142,253,201,255,125,5,74,253,52,253,86,251,108,253,98,1,73,1,254,253,201,255,225,253,110,1,9,4,158,4,110,253,65,252,179,250,201,255,72,255,93,0,163,253,226,254,106,253,148,1,193,1,59,3,226,254,162,254,17,251,116,2,50,1,227,0,240,255,147,0,145,253,186,0,155,3,98,8,94,253,134,252,186,249,69,254,28,255,83,1,143,254,234,252,103,254,231,0,86,0,189,5,64,254,187,253,219,251,82,2,194,1,79,255,132,255,86,255,65,254,159,2,135,4,124,5,36,254,101,253,25,250,179,255,118,255,204,2,79,255,140,254,131,254,195,1,166,3,147,3,6,255,80,254,202,252,16,1,60,3,190,1,26,0,19,0,225,255,186,2,156,6,120,8,122,253,47,252,124,248,77,255,39,254,12,1,133,254,23,253,77,253,11,0,127,0,9,4,24,254,107,252,199,252,61,0,67,1,135,0,147,0,111,255,82,253,173,2,18,3,146,6,6,254,176,252,239,250,35,0,90,0,222,0,233,255,166,254,98,253,199,1,79,2,7,5,53,255,175,253,194,251,140,2,96,1,181,1,39,0,63,0,55,254,73,3,241,4,57,8,248,253,142,252,208,249,184,254,57,253,141,5,172,253,170,254,186,255,209,0,173,0,136,7,89,254,170,253,103,252,165,1,93,2,218,255,254,255,11,255,129,255,128,3,177,7,111,4,133,254,250,253,213,249,173,0,118,0,241,2,201,255,131,254,204,255,217,3,253,3,241,2,254,255,221,254,133,252,241,2,224,3,167,1,8,1,131,0,60,255,127,3,226,8,239,9,133,253,192,251,61,246,239,253,42,252,14,2,4,253,194,252,220,253,76,254,60,1,87,2,93,253,84,252,22,253,199,255,236,0,245,255,55,255,175,255,226,252,16,0,77,3,22,6,31,253,39,252,68,251,44,254,17,0,34,1,233,254,184,253,68,253,183,0,54,3,193,2,247,254,20,254,93,251,165,1,152,0,212,1,122,254,166,0,244,254,39,0,14,6,76,7,133,253,58,252,221,249,59,254,20,254,142,3,228,254,253,251,181,255,75,255,123,255,60,7,67,254,144,253,106,251,164,1,111,1,207,255,123,254,44,255,87,255,195,2,49,4,184,4,229,253,58,253,87,250,83,0,93,255,228,1,20,255,225,253,157,254,82,1,151,4,46,3,10,255,203,254,66,252,94,2,248,2,60,0,166,0,248,255,93,255,206,254,57,7,3,10,21,253,255,251,9,249,93,254,66,254,209,0,50,253,202,253,234,253,6,254,181,2,89,3,49,254,71,253,198,251,69,1,175,1,50,255,241,255,248,255,5,253,33,2,151,3,238,5,157,253,241,252,223,250,0,1,201,255,208,0,91,255,164,254,106,253,65,1,168,2,162,3,186,254,83,254,73,252,228,1,190,1,58,2,59,255,72,0,183,255,141,3,175,5,205,6,205,253,31,253,74,248,132,255,96,254,206,2,34,254,108,254,198,254,240,255,190,1,100,6,217,253,231,253,18,253,198,255,126,2,214,0,55,0,71,255,241,254,124,4,21,5,188,4,29,254,97,253,16,251,117,0,29,1,31,2,52,255,121,254,145,255,1,2,2,6,86,3,142,255,66,255,46,252,109,3,83,2,208,1,4,1,4,1,201,254,236,2,235,8,168,8,251,253,79,252,133,247,186,254,60,253,122,1,212,252,77,253,24,255,208,253,175,2,129,5,36,253,78,253,188,252,153,254,133,2,130,1,247,254,62,0,90,253,145,0,108,6,184,4,213,253,36,252,47,251,178,255,14,0,114,0,185,254,154,254,23,254,136,1,165,2,185,2,55,255,20,255,140,251,181,2,193,1,178,0,13,255,0,1,79,254,99,2,105,5,152,9,156,253,123,252,72,250,205,254,239,255,243,1,197,254,101,253,2,255,0,1,172,1,183,5,26,254,90,254,224,251,143,2,114,1,18,0,154,255,71,255,236,254,243,2,42,6,55,5,24,254,165,253,118,250,182,0,163,255,102,3,183,255,54,254,164,254,67,3,94,3,189,3,230,254,179,254,22,253,35,2,71,3,172,1,17,1,167,255,13,0,172,3,172,6,16,10,94,254,196,251,34,249,212,255,154,254,3,1,15,254,125,253,208,253,99,0,45,2,193,3,91,254,2,253,107,252,39,1,70,1,184,0,175,0,15,0,142,253,20,2,110,3,189,7,69,254,0,253,5,251,221,0,156,0,12,1,39,0,149,254,7,254,183,2,4,3,116,4,94,255,53,254,112,252,197,2,188,1,146,2,25,0,47,1,200,254,244,4,130,5,179,6,215,254,2,253,212,248,249,254,148,255,46,4,106,254,243,255,127,255,57,0,182,1,174,10,138,254,25,254,189,252,48,1,184,2,164,0,104,0,21,255,5,0,75,6,108,7,119,5,27,255,186,253,211,250,149,1,192,0,49,3,169,255,74,254,111,0,4,4,175,4,225,3,68,0,81,255,90,252,9,4,93,4,195,1,222,1,200,0,8,255,79,8,136,10,250,7,189,252,213,250,173,247,225,252,76,253,210,1,212,252,248,251,43,254,146,253,32,1,152,3,67,253,183,252,210,251,101,254,0,2,8,0,122,254,165,255,24,253,226,255,19,4,137,4,202,252,132,251,124,251,218,254,210,255,110,0,101,254,138,254,90,253,214,0,19,2,156,2,106,254,92,254,86,251,231,1,232,0,47,1,194,254,91,0,40,254,123,0,208,4,141,9,46,253,72,252,41,250,30,253,93,253,52,5,225,253,162,253,45,255,161,255,158,255,228,5,219,253,254,253,87,251,217,1,211,0,73,0,224,254,144,255,123,254,25,2,52,5,234,4,201,253,13,253,247,249,71,0,229,254,120,2,86,255,31,254,19,254,169,2,234,3,49,3,156,254,181,254,147,252,163,1,194,2,90,1,241,0,222,255,186,254,121,1,158,7,91,7,41,253,205,251,167,249,23,255,225,253,116,0,244,253,218,252,183,253,183,255,222,1,217,2,224,254,99,252,137,251,173,0,191,1,204,255,68,0,27,255,162,253,193,1,17,2,5,7,177,253,149,252,173,250,183,0,112,255,68,1,153,255,60,254,102,253,111,2,232,1,152,4,18,255,1,254,20,252,70,1,40,2,202,1,136,0,108,0,193,254,114,2,63,5,91,7,22,254,122,253,62,249,70,255,63,254,216,3,30,253,180,255,86,255,218,253,243,2,0,10,16,254,2,254,77,252,210,0,182,2,204,255,84,0,190,254,57,255,66,4,89,6,200,4,136,254,165,253,140,250,87,1,74,0,120,2,81,255,10,254,224,255,204,3,52,5,222,2,52,0,217,254,167,251,41,4,150,3,160,0,137,1,107,0,115,254,190,4,89,10,205,6,136,253,79,251,157,248,49,253,235,254,97,1,117,253,144,252,134,255,45,255,209,0,58,5,206,253,54,253,221,251,48,255,132,1,159,0,192,254,195,255,217,253,37,1,68,4,163,5,120,253,159,252,27,251,207,255,113,255,49,1,111,254,29,255,183,253,49,2,20,2,159,3,139,255,69,254,92,251,251,1,180,1,36,1,177,255,233,0,54,254,159,2,1,4,92,9,135,253,182,252,11,250,204,254,226,254,128,2,139,254,147,253,105,254,162,1,253,0,25,5,197,254,187,253,143,251,60,2,173,2,231,254,61,0,188,255,141,254,223,3,77,4,218,5,19,254,85,253,174,250,209,255,164,0,192,2,0,255,198,254,244,254,119,2,181,3,28,4,138,255,164,254,191,252,68,0,156,4,56,2,152,0,117,0,34,0,89,4,110,7,191,8,167,253,65,252,86,249,113,255,23,254,224,1,180,254,113,253,194,253,54,0,97,1,168,4,50,254,116,253,228,252,150,0,37,2,112,0,195,0,145,255,253,253,167,2,84,4,111,6,210,253,19,253,63,251,247,255,16,1,85,1,203,255,247,254,233,253,233,1,75,3,18,5,136,255,30,254,248,251,120,2,31,2,152,1,179,0,50,1,242,253,100,4,184,5,196,8,95,254,238,252,230,249,32,255,128,254,84,5,135,254,53,254,231,255,129,1,233,1,126,8,180,254,117,253,195,252,32,2,41,2,61,0,22,0,143,255,167,255,104,4,189,6,244,5,40,255,139,254,139,249,161,0,60,1,140,3,91,255,34,255,189,255,82,5,151,4,21,3,73,0,4,255,1,253,226,2,164,3,104,2,106,1,246,0,130,255,19,3,94,10,211,11,77,253,174,251,114,247,203,253,180,253,12,2,178,253,45,252,22,254,249,254,141,1,214,3,191,253,187,252,79,252,234,255,179,1,207,255,66,255,138,255,139,253,168,255,216,4,233,5,132,253,229,251,5,252,221,254,189,0,3,1,255,254,42,254,139,253,145,0,177,3,126,3,186,254,148,254,186,251,31,2,4,1,118,2,54,255,189,0,47,255,101,1,99,5,43,8,199,253,205,251,87,250,54,253,17,255,151,3,92,254,63,253,172,255,147,255,142,255,103,9,99,254,239,253,103,251,226,1,112,1,131,0,70,255,184,255,125,255,93,3,231,4,196,4,157,253,110,253,195,250,227,0,135,255,119,2,80,255,23,254,38,255,233,2,151,4,189,3,191,254,108,255,88,252,159,2,198,3,216,0,84,1,253,255,113,255,213,1,56,7,133,9,39,253,63,252,109,249,43,255,2,255,65,1,1,254,74,254,247,253,130,255,213,2,135,3,172,254,83,253,248,251,60,1,224,1,20,0,23,0,167,255,217,253,97,1,27,4,253,6,224,253,11,253,172,250,42,1,231,255,180,1,156,255,120,254,249,253,211,1,242,2,54,4,46,255,114,254,202,251,108,2,146,2,118,2,33,0,147,0,78,255,153,3,151,6,129,7,187,254,240,253,70,248,2,0,227,254,142,3,141,254,22,254,26,255,0,0,85,2,218,7,16,254,117,254,190,252,37,0,177,3,245,0,181,0,96,255,112,255,201,5,93,5,77,5,157,254,167,253,10,251,42,1,66,1,160,2,63,255,176,254,77,0,65,4,253,5,154,3,177,0,217,255,155,251,228,3,13,3,24,2,200,1,110,1,80,254,135,5,136,9,231,8,46,254,10,253,235,246,209,254,3,254,131,1,41,253,211,253,66,0,111,255,131,2,224,4,224,253,92,253,108,252,31,255,94,3,76,2,104,255,40,0,235,253,167,1,143,5,22,6,196,253,181,252,135,251,128,255,85,0,205,1,18,255,255,254,184,253,93,2,236,2,93,3,24,0,54,255,127,250,29,3,231,1,47,1,75,255,108,1,74,255,104,2,98,5,126,11,18,254,172,252,95,250,220,254,61,0,44,3,172,255,45,253,74,255,43,2,20,2,226,5,147,254,19,254,223,251,54,3,76,2,11,0,242,255,238,255,26,255,233,3,121,5,171,5,38,254,199,253,244,250,46,1,62,0,38,4,186,255,136,254,34,255,214,3,206,3,125,4,60,255,22,255,229,252,223,1,74,4,243,1,106,1,58,0,70,0,123,4,21,8,41,11,25,254,146,252,224,248,73,0,224,254,92,1,154,254,12,254,4,254,199,0,209,2,218,4,178,255,71,253,229,252,105,1,24,2,196,0,118,1,110,0,33,253,79,3,27,4,104,7,146,254,55,253,98,251,59,1,64,1,173,1,72,0,41,255,62,254,247,2,118,3,83,5,226,255,84,254,190,252,93,3,115,2,28,3,118,0,212,1,233,254,75,5,91,7,101,7,68,255,126,253,180,249,63,0,81,255,174,4,94,254,45,255,51,0,158,1,75,2,41,10,22,255,211,253,166,252,168,1,121,3,222,0,136,0,155,255,83,0,133,5,230,8,103,5,172,255,67,254,147,250,158,1,57,1,21,4,29,0,169,254,65,0,16,6,111,6,212,3,183,0,165,255,195,252,249,4,133,5,104,1,41,2,16,1,149,255,51,6,77,12,43,10,6,0,82,0,125,255,154,0,200,255,33,253,183,0,191,255,247,254,9,0,46,255,151,254,113,0,206,2,25,7,242,3,190,4,37,6,89,3,53,5,228,8,59,3,32,6,141,7,205,2,197,7,158,8,70,3,148,4,31,7,209,2,232,3,106,8,30,1,220,1,229,5,9,255,237,253,230,0,147,0,174,255,57,2,26,0,79,255,80,252,229,255,239,254,180,2,92,255,248,254,73,255,224,0,22,3,15,4,131,3,178,3,89,2,229,1,3,3,126,4,12,2,165,2,135,3,116,255,119,1,10,3,154,1,164,2,173,1,45,1,18,2,241,3,207,2,134,2,38,0,226,0,111,1,40,0,145,0,211,255,7,254,34,1,121,0,135,255,46,1,127,0,166,0,132,255,129,254,68,252,154,254,57,254,47,252,203,2,110,3,126,3,210,3,155,3,211,0,221,1,16,1,64,0,188,0,178,255,17,0,113,255,191,255,38,0,131,2,74,2,109,2,122,255,86,254,117,253,91,1,33,2,4,11,164,4,166,10,138,9,142,0,176,255,199,6,27,1,130,0,205,1,250,254,113,254,135,251,101,254,155,0,174,1,73,1,119,1,11,3,53,0,30,255,117,255,127,255,20,255,146,6,29,1,232,2,47,5,226,2,185,2,128,6,56,1,153,1,10,1,69,1,208,2,135,0,1,0,221,0,197,1,8,0,203,0,145,0,43,1,128,2,248,2,29,0,212,1,126,2,103,0,173,1,123,1,164,1,186,3,164,3,46,5,186,4,234,4,192,2,244,3,128,4,90,255,68,254,246,254,196,254,126,255,136,254,191,0,127,4,112,7,16,255,225,253,20,251,144,255,12,1,183,4,70,0,38,4,47,6,22,1,80,5,38,6,254,254,240,254,0,253,19,0,51,2,192,8,253,255,247,254,135,0,217,254,177,253,124,254,140,0,98,1,50,255,252,254,8,254,229,252,79,254,50,253,217,250,109,0,75,1,194,3,83,254,169,255,140,2,216,254,170,1,251,3,17,255,7,3,83,3,233,1,54,5,49,4,178,254,180,254,25,0,31,2,182,4,15,7,70,1,61,0,215,2,66,2,81,3,125,5,48,255,235,254,73,1,104,255,64,0,157,2,78,254,90,253,41,253,58,254,185,255,251,0,93,2,224,1,254,0,30,254,11,0,228,3,223,254,139,1,230,1,210,2,25,4,160,5,226,255,196,254,238,252,150,255,141,255,149,253,93,3,194,5,132,5,31,4,86,5,160,4,44,3,213,4,157,3,42,0,5,255,192,253,86,1,141,0,58,254,88,255,176,255,79,5,170,254,112,253,29,249,100,0,53,3,213,2,222,3,235,2,32,3,76,1,184,1,56,2,151,2,123,1,84,3,112,0,165,0,143,254,85,2,142,3,26,1,248,255,66,3,1,5,160,254,60,2,183,2,206,1,198,8,14,7,89,1,190,0,94,5,160,1,147,3,118,8,168,0,174,255,24,1,252,253,66,254,72,3,47,0,21,2,44,0,150,254,57,253,137,251,22,0,193,0,192,5,171,255,233,0,21,7,194,255,67,2,224,5,38,2,176,3,213,6,211,2,138,2,124,4,204,3,116,3,115,5,87,254,131,2,0,0,232,3,184,3,74,4,249,0,166,5,160,2,178,254,169,255,124,8,214,253,90,7,112,10,140,0,34,7,61,7,152,3,213,6,30,10,52,4,141,7,246,7,119,255,69,254,237,249,245,4,150,4,212,1,19,254,134,255,241,5,61,254,9,4,190,4,226,1,159,6,94,4,47,3,137,2,128,1,66,254,76,253,107,0,193,254,163,253,138,255,49,255,7,254,13,2,44,254,244,255,176,10,75,0,142,7,25,5,112,3,54,9,219,8,5,5,39,6,212,7,208,255,208,254,94,251,77,254,51,254,5,255,146,254,108,254,221,253,223,254,163,253,171,253,230,253,214,252,91,255,136,255,3,0,100,1,127,2,217,4,222,5,96,0,177,0,238,2,77,254,183,253,106,251,156,254,109,0,177,255,27,254,32,1,213,7,9,0,92,4,219,2,112,3,86,8,178,3,247,254,49,6,41,4,133,4,186,4,75,3,14,254,100,253,175,1,118,1,65,1,27,255,160,5,53,8,101,5,193,1,205,1,131,4,151,255,39,0,128,254,249,254,111,1,182,0,141,254,108,253,5,3,68,255,127,4,203,3,53,5,96,6,155,5,6,3,243,4,197,4,30,254,192,252,47,250,19,255,46,255,92,3,122,3,79,6,40,4,216,1,38,4,168,4,185,0,53,4,221,3,200,253,32,252,88,249,63,254,122,252,5,248,114,255,135,254,54,254,46,255,214,253,251,251,245,255,109,4,217,8,183,254,93,253,131,252,6,255,145,2,163,4,7,2,230,5,243,6,8,2,27,2,123,5,15,2,141,5,22,5,205,253,153,252,32,251,109,255,49,254,111,3,180,255,30,9,24,11,51,2,13,10,81,9,120,2,134,7,104,11,207,2,231,7,48,7,223,253,45,253,84,4,129,0,131,255,116,3,137,5,96,6,157,3,162,255,30,6,215,6,171,254,253,5,15,6,79,2,139,1,238,254,180,255,213,3,15,11,153,0,169,11,52,7,8,4,5,10,189,10,228,5,16,11,87,7,23,3,175,4,26,2,66,255,59,254,209,5,234,254,220,253,134,4,11,255,149,7,252,7,0,4,24,6,114,6,0,2,253,0,210,1,194,255,189,254,127,4,39,254,136,254,251,1,79,254,100,5,114,8,131,3,151,7,165,5,134,0,192,2,184,1,204,1,13,2,228,255,62,254,23,1,58,5,0,0,203,3,252,0,67,254,141,253,33,252,164,254,166,253,112,250,142,1,200,2,120,6,149,255,58,1,78,255,93,0,178,8,190,8,6,2,81,3,144,2,50,254,57,253,65,254,174,0,222,255,167,4,137,255,42,0,237,3,140,254,18,1,246,2,12,4,48,9,46,7,163,2,188,6,218,5,174,1,6,5,85,8,127,255,73,254,0,0,139,254,32,3,96,8,6,0,51,6,174,9,222,1,84,2,80,8,84,254,32,253,225,5,129,1,178,0,212,3,139,0,193,1,201,4,242,253,182,252,42,252,145,0,18,6,218,4,111,2,168,5,144,2,93,1,248,3,202,5,31,0,232,254,159,1,196,254,212,2,105,6,104,1,34,4,44,2,76,254,154,254,177,4,157,254,99,4,147,7,145,1,48,6,200,8,241,253,12,252,99,1,233,0,238,0,185,8,218,253,127,252,129,253,147,254,11,254,165,7,133,1,68,7,85,6,162,0,108,4,240,4,19,255,150,4,110,5,128,253,101,254,116,0,28,255,158,6,250,8,103,6,138,8,219,8,50,2,249,4,98,10,67,1,82,1,238,6,66,2,83,4,84,3,22,0,82,2,166,3,113,255,206,2,190,1,0,0,1,2,2,4,4,5,6,7,8,9,9,11,11,12,13,13,15,15,16,16,18,18,19,19,21,21,22,22,23,24,24,25,26,26,27,27,28,29,29,30,30,30,31,32,32,33,33,33,34,34,35,35,35,36,36,36,37,37,37,38,38,63,128,176,208,240,128,167,197,227,128,158,187,216,123,150,178,205,116,142,169,195,111,135,160,185,105,128,152,175,100,122,144,166,95,116,137,158,90,110,130,150,85,104,123,142,81,99,117,135,77,94,111,128,73,89,105,122,69,85,100,116,66,80,95,110,62,76,90,104,59,72,86,99,56,69,81,94,53,65,77,89,51,62,73,85,48,59,69,80,46,56,66,76,43,53,63,72,41,50,59,69,39,48,56,65,37,45,54,62,35,43,51,59,33,41,48,56,32,39,46,53,30,37,43,50,29,35,41,48,27,33,39,45,26,31,37,43,24,30,35,41,23,28,33,39,22,27,32,37,21,26,30,35,20,24,29,33,19,23,27,31,18,22,26,30,17,21,25,28,16,20,23,27,15,19,22,25,14,18,21,24,14,17,20,23,13,16,19,22,12,15,18,21,12,14,17,20,11,14,16,19,11,13,15,18,10,12,15,17,10,12,14,16,9,11,13,15,9,11,12,14,8,10,12,14,8,9,11,13,7,9,11,12,7,9,10,12,7,8,10,11,6,8,9,11,6,7,9,10,6,7,8,9,2,2,2,2,255,255,39,186,255,255,187,58,254,255,49,187,255,255,145,59,255,255,202,187,255,255,228,59,255,255,176,187,0,0,0,0,1,128,39,60,1,192,209,188,255,159,57,61,1,48,138,189,0,48,183,61,5,96,221,189,2,16,247,61,0,20,96,63,2,16,247,61,5,96,221,189,0,48,183,61,1,48,138,189,255,159,57,61,1,192,209,188,1,128,39,60,0,0,0,0,255,255,176,187,255,255,228,59,255,255,202,187,255,255,145,59,254,255,49,187,255,255,187,58,255,255,39,186,0,0,0,0,128,187,0,0,0,119,1,0,68,172,0,0,0,125,0,0,104,247,184,249,218,251,199,253,136,255,82,1,95,3,85,6,223,249,160,252,216,254,200,0,158,2,127,4,173,6,81,9,171,246,5,249,49,251,51,253,17,255,234,0,2,3,194,5,164,250,38,254,133,0,120,2,76,4,35,6,27,8,112,10,125,245,117,247,4,249,101,250,162,251,187,252,197,253,196,254,197,255,201,0,214,1,247,2,53,4,177,5,116,7,191,9,203,248,223,251,246,253,179,255,45,1,135,2,207,3,5,5,46,6,81,7,115,8,148,9,175,10,201,11,227,12,241,13,59,242,33,243,247,243,182,244,120,245,49,246,232,246,155,247,69,248,231,248,134,249,38,250,195,250,92,251,248,251,148,252,47,253,207,253,118,254,28,255,202,255,119,0,40,1,228,1,171,2,127,3,99,4,93,5,115,6,173,7,56,9,38,11,237,243,174,246,177,248,111,250,3,252,119,253,196,254,236,255,11,1,32,2,42,3,41,4,25,5,254,5,220,6,178,7,123,8,55,9,232,9,140,10,38,11,180,11,61,12,191,12,58,13,171,13,19,14,117,14,205,14,30,15,107,15,180,15,151,253,190,0,34,3,203,5,55,240,78,240,98,240,119,240,142,240,166,240,190,240,217,240,244,240,15,241,45,241,76,241,109,241,141,241,174,241,209,241,246,241,29,242,71,242,116,242,164,242,212,242,7,243,60,243,116,243,175,243,238,243,51,244,128,244,209,244,44,245,140,245,251,245,115,246,232,246,102,247,232,247,107,248,240,248,132,249,28,250,188,250,95,251,30,252,226,252,168,253,138,254,146,255,152,0,191,1,208,2,214,3,205,4,176,5,146,6,124,7,82,8,49,9,35,10,37,11,46,12,35,13,4,14,230,14,96,201,32,0,32,77,31,0,32,0,0,0,3,0,0,0,0,0,0,0,0,64,127,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,56,153,32,0,32,77,31,0,32,0,0,0,3,0,0,0,0,0,0,0,0,64,127,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,32,129,32,0,136,102,32,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,32,129,32,0,112,82,32,0,40,48,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,8,255,31,0,72,233,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,152,213,31,0,120,194,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,144,172,31,0,168,154,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,88,137,31,0,200,39,31,0,40,0,0,0,3,0,0,0,57,180,200,118,190,159,230,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,72,106,31,0,200,39,31,0,40,0,0,0,3,0,0,0,57,180,200,118,190,159,230,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,232,25,31,0,152,13,31,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,208,253,30,0,152,13,31,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,198,35,0,108,0,0,0,240,175,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,0,72,0,110,0,150,0,190,0,233,0,20,1,67,1,114,1,166,1,217,1,18,2,75,2,138,2,202,2,18,3,90,3,172,3,255,3,97,4,195,4,59,5,178,5,76,6,229,6,188,7,147,8,253,9,103,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,255,226,11,174,4,26,2,78,1,172,0,58,0,226,255,226,11,174,4,26,2,78,1,172,0,58,0,226,255,196,255,88,148,18,0,216,178,11,0,216,148,18,0,0,0,0,0,221,255,221,255,153,244,109,247,27,249,78,250,61,251,1,252,166,252,54,253,181,253,39,254,142,254,236,254,66,255,146,255,103,11,147,8,229,6,178,5,195,4,255,3,90,3,202,2,75,2,217,1,114,1,20,1,190,0,110,0,35,0,221,255,0,0,0,0,205,204,204,63,0,0,128,63,205,204,76,63,61,10,23,63,0,0,0,63,61,10,215,62,123,20,174,62,92,143,66,62,174,71,225,61,143,194,117,61,41,92,15,61,227,165,155,60,88,57,52,60,244,253,212,59,111,18,131,59,10,215,35,59,52,128,183,58,23,183,81,58,250,237,235,57,82,73,157,57,7,66,50,57,172,197,167,56,172,197,39,56,172,197,167,55,172,197,39,55,172,197,167,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,63,195,245,168,62,0,0,128,62,231,251,41,62,0,0,0,62,231,251,169,61,0,0,128,61,0,0,0,61,36,151,127,60,243,1,1,60,31,132,128,59,3,65,0,59,117,31,128,58,174,14,0,58,248,7,128,57,248,7,0,57,154,2,128,56,154,2,0,56,154,2,128,55,156,252,255,54,154,2,128,54,5,244,255,53,226,0,128,53,229,250,255,52,229,250,127,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,237,221,221,221,221,255,255,255,255,191,255,254,237,221,204,222,239,255,255,255,254,237,220,203,203,187,204,222,239,255,254,237,220,187,170,170,170,187,221,255,255,254,220,187,169,153,153,153,171,205,239,254,236,203,169,136,135,120,137,171,205,255,254,203,169,135,119,102,119,137,171,222,253,220,170,135,118,101,102,103,137,188,239,221,186,152,118,85,85,86,120,154,205,237,220,169,135,101,84,69,86,121,172,221,221,202,152,101,84,68,85,103,154,189,222,235,169,135,101,68,85,102,137,171,221,237,202,152,118,85,85,86,120,154,204,222,252,186,135,118,101,102,119,137,187,221,254,219,169,135,118,103,119,137,171,205,223,239,203,169,136,135,136,137,171,204,237,255,237,203,169,153,153,153,170,188,222,239,255,253,219,186,170,170,171,204,222,253,255,255,253,220,204,188,204,220,222,239,239,255,255,255,222,221,205,221,238,255,254,223,255,255,239,221,221,221,221,221,253,176,0,0,0,189,205,204,204,204,204,205,239,255,255,207,254,220,220,204,187,204,204,222,239,255,238,221,204,203,186,170,187,188,221,255,220,221,203,186,169,153,154,154,188,223,255,189,219,186,153,136,136,136,154,188,239,221,204,186,152,135,119,119,137,154,188,221,204,186,152,135,118,102,103,120,154,204,220,203,169,135,102,101,102,103,136,171,204,204,169,135,102,85,85,86,103,137,188,204,202,152,118,101,85,85,102,120,154,204,187,169,135,102,85,85,86,103,137,172,188,202,152,118,101,85,85,102,120,154,188,204,185,135,102,85,85,86,119,137,171,205,203,169,135,102,102,102,103,137,171,189,223,202,152,135,118,102,119,137,154,188,207,221,170,152,135,119,119,136,154,188,221,255,220,186,153,136,136,137,154,171,188,223,255,220,186,170,153,153,170,187,204,221,255,255,236,187,186,170,171,187,220,223,223,255,253,238,204,188,187,204,221,206,254,207,255,221,221,205,220,203,189,205,221,176,0,0,0,189,221,204,204,204,204,205,221,239,255,221,238,221,205,204,204,204,205,223,255,255,222,221,204,187,187,186,187,205,222,255,253,221,204,186,170,153,154,170,188,222,255,205,203,186,153,152,136,137,154,188,223,237,204,186,152,136,119,119,136,154,188,222,204,186,153,135,118,102,103,120,154,205,220,203,169,135,118,101,86,103,137,171,204,204,186,152,118,85,85,86,103,137,188,204,202,152,118,101,85,85,86,120,154,204,204,185,135,101,85,69,86,103,137,172,204,203,152,118,101,85,85,102,120,155,204,204,186,135,118,85,85,86,120,153,188,205,203,169,135,102,102,102,119,137,171,204,221,203,152,135,118,102,119,137,155,188,206,237,186,152,135,119,120,137,154,188,220,238,220,186,153,136,136,153,154,188,205,207,254,221,187,170,153,154,170,188,204,220,255,254,220,203,187,187,187,188,205,222,223,255,255,237,204,204,204,204,221,222,253,223,255,237,221,220,204,204,204,204,221,176,0,0,0,189,205,220,204,204,204,205,223,255,255,221,255,223,236,204,220,205,221,223,255,255,238,204,204,187,187,187,172,204,239,239,253,221,204,187,170,153,154,171,188,223,255,221,203,186,153,152,136,137,154,188,221,252,219,186,169,136,119,119,136,154,188,237,188,186,169,135,118,102,103,136,154,189,221,203,169,135,102,101,86,103,137,172,206,204,186,152,118,85,85,86,103,138,188,220,219,169,118,101,85,85,86,120,170,204,204,185,135,102,85,69,85,103,137,188,204,219,168,118,101,85,85,102,120,155,204,204,186,151,102,85,85,86,120,154,188,207,220,169,135,102,101,102,119,137,171,204,253,203,168,135,118,102,119,137,171,188,207,253,203,153,135,119,120,137,170,204,204,255,220,186,169,152,136,153,154,188,221,207,254,221,187,170,169,170,170,187,189,220,255,255,221,188,187,187,187,204,205,254,207,255,253,253,221,220,204,204,221,222,254,207,255,221,205,221,204,205,204,205,205,176,0,0,0,191,238,221,221,205,221,221,239,255,255,222,255,253,237,221,204,221,239,255,255,255,254,239,221,204,203,187,204,222,255,255,254,253,220,187,170,170,170,187,205,223,255,255,220,186,169,153,137,153,171,205,255,253,221,202,169,136,135,120,137,171,205,255,222,203,169,135,118,102,119,137,171,223,254,220,169,135,118,101,86,103,137,172,239,237,202,152,118,85,85,86,120,154,205,237,219,169,118,101,84,85,86,121,171,206,221,186,135,102,84,68,85,103,154,189,221,219,169,134,101,84,85,102,121,171,205,221,202,152,118,85,85,86,120,154,205,223,252,185,135,102,101,102,119,137,188,221,255,220,169,135,118,102,119,137,171,205,223,255,203,169,136,135,120,137,171,188,237,255,253,203,169,153,153,153,171,188,223,239,255,237,203,186,170,170,171,204,205,237,255,255,253,220,203,188,204,205,222,239,239,255,255,255,237,222,221,222,221,223,255,191,255,239,223,237,220,221,221,222,237,176,0,0,0,172,203,186,170,170,170,170,171,188,205,188,220,204,187,170,170,170,171,187,205,221,188,203,186,169,153,153,153,170,171,205,219,203,170,169,152,136,136,153,154,187,204,187,186,153,136,136,136,136,137,154,187,186,186,153,136,119,119,119,120,137,154,187,171,169,136,119,118,102,103,120,137,171,170,169,152,119,118,102,102,103,120,153,170,170,152,135,118,102,102,102,103,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,102,101,85,86,103,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,118,102,102,102,119,136,154,170,169,152,119,102,102,102,119,120,153,170,186,169,136,119,118,102,119,120,137,171,171,186,153,136,119,119,119,136,137,170,186,188,186,153,136,136,136,136,137,154,171,188,203,186,153,152,136,137,153,154,171,203,204,203,186,169,153,153,153,170,187,204,189,221,203,187,170,170,170,171,187,204,220,189,204,187,170,170,170,170,171,187,204,160,0,0,0,155,187,170,170,154,154,170,171,187,205,187,204,187,186,170,170,170,170,187,205,220,188,187,170,153,153,153,153,154,187,205,202,187,170,153,152,136,136,153,154,171,203,171,170,153,136,136,119,136,137,154,171,186,186,153,136,119,119,119,120,137,154,186,170,169,136,119,118,102,103,120,137,170,170,169,152,119,118,102,102,103,120,137,170,170,152,135,118,102,102,102,103,136,154,169,169,136,118,102,101,102,102,119,137,170,170,152,119,102,101,85,102,103,120,154,153,169,136,118,102,101,102,102,120,137,169,170,152,135,118,102,102,102,119,136,154,170,169,136,119,102,102,102,119,120,137,170,171,169,136,119,102,102,119,120,137,170,171,186,153,136,119,119,119,120,137,154,170,187,186,153,136,135,120,136,137,154,171,171,203,170,153,152,136,136,153,154,171,186,204,203,170,169,153,153,153,154,171,188,189,220,204,186,170,170,170,170,187,188,219,189,204,186,170,169,153,170,170,171,187,144,0,0,0,155,187,170,169,153,153,154,170,187,204,187,220,187,170,170,153,154,170,187,188,221,188,187,170,153,153,153,153,154,171,188,203,187,170,153,136,136,136,137,153,171,187,171,170,153,136,135,119,120,136,153,171,186,170,153,136,119,119,119,119,136,154,170,170,153,136,119,118,102,103,119,137,154,170,169,136,119,118,102,102,103,120,137,170,154,152,135,118,102,102,102,119,120,153,153,153,135,118,102,102,102,102,119,137,153,153,152,119,102,102,102,102,103,120,153,153,169,135,118,102,102,102,102,119,137,153,154,152,135,118,102,102,102,119,136,154,154,169,136,119,102,102,102,119,120,137,169,170,153,136,119,118,102,119,120,137,154,170,170,152,135,119,119,119,120,137,154,186,187,170,152,136,135,119,136,137,154,171,171,187,169,153,136,136,136,137,154,171,187,204,187,170,153,153,153,153,154,171,188,188,220,187,186,170,153,170,170,187,188,203,188,203,186,170,153,153,153,170,170,187,160,0,0,0,155,187,170,169,153,153,170,171,187,205,187,204,203,186,170,170,170,170,187,188,220,188,187,170,169,153,153,153,154,187,188,203,187,170,153,152,136,136,137,154,171,203,171,170,153,136,136,120,136,136,154,171,186,186,153,136,119,119,119,120,137,154,187,170,169,136,119,119,102,119,120,137,154,170,169,152,119,118,102,102,103,120,137,170,170,152,135,118,102,102,102,103,136,154,153,169,136,118,102,101,102,102,119,137,169,154,152,119,102,101,85,102,103,136,154,153,169,136,118,102,85,102,102,120,137,169,170,152,135,118,102,102,102,119,136,154,154,169,136,119,102,102,102,119,120,153,170,170,169,136,119,118,102,119,120,137,170,170,186,153,136,119,119,119,120,137,154,186,187,170,153,136,135,119,136,137,154,171,171,187,170,153,152,136,136,153,154,171,203,205,203,170,169,153,153,153,154,171,188,189,220,203,186,170,170,170,170,187,188,219,188,203,186,170,154,153,153,170,170,187,144,0,0,0,172,187,186,170,170,170,170,171,188,221,204,220,203,186,170,170,170,170,187,205,237,188,203,170,169,153,153,153,170,187,205,203,203,170,153,152,136,136,153,154,187,204,187,170,153,136,136,120,136,137,154,188,186,186,153,136,119,119,119,120,137,170,187,170,169,136,119,118,102,119,120,137,170,186,169,152,119,102,102,102,103,120,153,170,170,152,135,118,102,102,102,119,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,102,101,85,102,103,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,118,102,102,102,119,136,154,170,169,152,119,102,102,102,103,120,153,170,171,169,136,119,118,102,119,120,137,170,171,186,153,136,119,119,119,120,137,154,186,188,186,153,136,136,120,136,137,154,187,188,203,186,169,152,136,136,153,154,171,203,221,203,186,169,153,153,153,170,187,204,205,237,203,187,170,170,170,171,187,204,220,189,220,187,170,170,170,170,170,187,188,160,0,0,0,191,238,221,221,221,222,238,255,255,255,191,255,254,237,221,221,222,255,255,255,255,239,254,221,204,203,188,205,222,255,255,254,254,220,203,186,170,171,188,221,255,255,238,221,187,169,153,153,154,188,222,255,253,220,187,169,136,119,136,153,172,223,255,221,203,169,135,118,102,120,138,188,239,253,220,185,135,102,85,86,120,154,205,255,221,186,152,118,85,69,86,120,171,222,253,219,169,118,85,68,69,103,137,188,239,237,186,151,101,68,68,86,120,155,205,238,220,169,134,85,68,85,103,137,188,221,238,203,152,118,85,85,102,120,171,206,239,253,186,152,118,102,102,120,154,205,238,255,220,186,136,119], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+759144);
/* memory initializer */ allocate([119,120,154,188,223,239,255,220,186,152,136,137,154,188,205,239,255,254,220,186,169,153,170,187,205,239,239,255,254,220,203,187,187,188,221,239,254,255,255,254,221,220,204,205,221,223,255,255,255,255,255,254,239,238,238,255,255,255,207,255,255,255,254,237,222,238,239,239,176,0,0,0,173,205,203,188,203,204,205,221,222,239,189,222,221,204,204,204,220,221,255,255,255,221,221,203,187,187,187,187,221,239,239,221,220,204,187,170,169,170,187,204,255,254,205,204,170,153,152,136,153,171,206,254,204,203,186,152,136,119,119,137,171,205,254,205,187,153,135,118,102,119,137,172,222,220,219,169,135,102,85,86,103,138,188,253,204,186,152,118,85,85,86,120,155,205,220,203,153,118,85,68,69,103,137,171,221,204,186,135,101,84,68,86,120,154,205,220,203,168,118,101,84,85,103,137,171,220,205,186,152,118,85,85,102,120,154,189,205,236,185,135,118,102,102,120,154,187,220,222,203,169,135,119,119,120,137,171,205,206,253,203,169,152,136,136,153,171,204,221,239,253,219,170,153,153,154,171,204,221,223,253,253,204,187,170,170,187,188,221,252,239,239,237,221,204,188,188,204,237,238,223,255,255,253,237,220,220,221,221,221,237,190,221,221,221,220,220,205,204,204,221,176,0,0,0,189,221,220,204,204,204,205,221,239,255,221,254,221,204,204,203,204,221,222,255,255,222,221,203,186,170,170,187,205,222,255,253,221,203,170,169,153,153,171,188,239,255,205,203,170,152,136,136,137,154,188,222,236,203,170,152,135,119,119,136,154,188,238,204,186,152,119,102,102,103,137,171,205,236,202,153,135,102,85,86,103,137,171,221,203,169,135,102,85,85,86,120,154,189,220,186,152,118,85,85,85,102,120,171,205,203,169,135,101,85,69,86,103,138,188,204,202,152,118,85,85,85,103,121,171,204,204,185,135,118,85,85,102,120,154,188,221,203,169,135,102,102,102,119,137,171,204,221,203,153,135,118,103,119,137,171,205,222,221,186,153,136,119,136,137,170,188,221,239,220,186,169,152,136,153,170,188,221,223,255,220,203,170,170,170,171,188,205,237,255,254,220,204,187,187,187,204,205,239,239,255,255,237,220,204,204,205,222,238,254,223,255,254,237,221,220,205,221,221,238,192,0,0,0,190,221,204,204,204,204,205,221,239,239,205,253,237,204,204,204,204,221,238,255,255,222,220,203,187,186,171,187,204,221,255,253,221,203,170,169,153,154,171,188,222,254,205,203,186,153,136,136,137,170,189,239,220,220,170,152,135,119,119,137,154,205,253,204,186,152,119,102,102,119,137,171,205,220,203,169,135,102,85,86,103,137,172,221,204,185,135,102,85,85,86,120,154,189,204,202,152,118,85,84,85,103,121,171,221,203,169,135,101,84,69,86,103,138,188,204,203,152,118,85,85,85,103,137,171,204,204,186,151,118,85,85,102,120,154,188,205,219,169,135,102,102,102,119,137,171,220,221,203,169,135,119,119,120,137,171,205,221,237,186,169,136,119,136,137,155,188,221,222,220,187,169,153,153,153,171,188,206,207,254,220,203,170,170,170,171,188,221,237,255,238,237,203,187,187,187,204,206,238,223,255,255,237,221,220,204,205,221,254,254,191,254,221,221,205,204,221,204,221,238,176,0,0,0,191,255,254,238,238,222,255,255,255,255,207,255,255,238,221,221,238,255,255,255,255,255,254,237,204,203,204,205,223,255,255,255,254,220,203,186,170,171,188,223,255,255,238,220,187,169,153,153,154,188,223,255,254,237,203,169,136,119,136,154,188,223,255,238,203,169,135,118,102,120,138,188,239,253,220,185,135,102,85,86,120,154,205,255,221,202,152,118,85,69,86,120,171,223,254,220,169,118,85,68,69,103,137,188,239,237,202,151,101,68,68,86,120,155,206,238,220,169,118,85,68,85,103,137,188,238,238,203,152,118,85,85,102,120,171,206,239,253,186,152,118,102,102,120,154,189,239,255,236,185,152,119,119,120,154,188,223,255,255,220,186,152,136,136,154,187,222,255,255,254,220,186,169,153,170,187,205,255,255,255,254,236,203,187,187,188,205,239,255,255,255,255,237,220,204,205,222,255,255,255,255,255,255,254,238,238,255,255,255,255,191,255,255,255,255,255,238,255,255,255,192,0,0,0,172,187,187,170,170,170,187,188,205,222,188,221,203,187,186,170,187,187,204,221,237,204,203,186,170,169,153,170,187,204,222,219,203,186,169,153,153,153,154,171,205,220,188,186,169,152,136,136,136,153,171,205,203,186,169,136,119,119,119,136,154,171,204,171,169,136,119,102,102,103,120,154,188,202,186,152,119,102,102,102,103,137,154,187,170,169,135,102,85,85,102,119,137,171,186,169,152,118,101,85,85,102,120,154,187,170,153,135,102,85,85,86,103,137,171,187,169,152,118,101,85,85,103,120,154,187,187,169,135,102,101,85,102,120,137,171,187,186,152,135,102,102,102,119,137,170,187,187,170,152,135,119,103,119,136,154,187,188,203,169,152,135,119,120,136,154,171,203,204,203,170,153,136,136,137,154,171,188,189,220,203,170,153,153,153,154,171,188,220,222,237,203,186,170,170,170,187,188,205,205,238,221,204,187,187,187,187,204,221,220,174,221,204,187,187,187,187,187,188,204,160,0,0,0,155,186,170,170,169,170,170,187,188,220,171,203,187,170,170,170,170,171,188,205,237,187,187,170,153,153,153,153,170,188,205,218,186,170,153,152,136,136,153,170,188,204,171,170,153,136,135,119,136,137,170,188,202,186,153,136,119,119,119,136,137,171,187,170,153,136,119,102,102,119,120,137,171,186,169,152,119,102,102,102,103,136,154,186,154,152,135,102,102,86,102,119,137,171,170,169,135,118,101,85,86,102,120,153,170,170,152,119,102,85,85,102,103,137,154,170,169,136,118,102,85,86,103,120,154,170,170,153,135,102,102,102,102,119,137,154,170,169,152,119,102,102,102,119,136,154,186,187,169,136,119,118,103,119,136,153,171,171,186,169,136,135,119,119,136,137,170,186,187,186,169,136,136,136,136,153,170,187,172,219,186,169,153,153,153,153,170,187,203,205,204,187,170,169,153,154,170,187,204,188,237,220,187,186,170,170,186,187,204,204,172,204,203,187,170,170,170,170,187,187,160,0,0,0,155,186,170,153,153,153,153,170,187,204,187,204,186,170,169,153,154,170,187,204,220,187,186,170,153,153,153,153,154,171,204,202,186,169,153,136,136,136,137,154,171,203,171,169,152,136,119,119,136,137,154,171,186,170,152,136,119,119,119,120,137,154,186,154,153,135,119,102,102,103,120,137,170,169,169,136,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,153,135,118,102,85,102,102,120,137,169,153,152,119,102,101,86,102,119,136,154,153,153,135,118,102,102,102,103,120,137,169,153,152,119,118,102,102,102,119,136,154,170,169,136,119,102,102,102,119,136,153,170,170,153,136,119,119,103,119,120,137,170,170,186,153,136,119,119,119,136,137,154,186,171,170,153,136,136,136,136,137,154,171,171,187,170,153,152,136,136,153,154,171,187,204,203,170,169,153,153,153,170,171,188,188,220,203,186,170,170,170,170,187,204,203,188,203,187,170,170,153,154,170,171,187,144,0,0,0,155,187,170,170,169,170,170,171,187,204,171,220,187,186,170,170,170,171,187,204,236,188,187,170,169,153,153,153,171,188,205,203,187,170,153,136,136,136,153,170,188,204,171,170,153,136,136,120,136,137,170,188,186,186,153,136,119,119,119,120,137,170,187,170,169,136,119,102,102,119,120,153,171,170,169,136,119,102,102,102,103,136,154,186,154,152,135,102,101,85,102,119,137,170,169,169,135,118,101,85,86,102,120,153,170,170,152,119,102,85,85,102,103,137,154,170,169,136,118,102,85,86,103,120,153,170,170,153,135,102,102,102,102,119,137,171,170,170,152,119,118,102,102,119,136,154,186,171,169,136,119,119,119,119,136,153,171,171,186,169,136,135,119,119,136,153,171,186,188,186,169,152,136,136,136,153,170,187,187,203,186,169,153,152,153,153,170,187,203,205,203,186,170,170,153,154,170,187,205,205,237,220,187,187,170,170,171,188,205,220,172,204,187,186,170,170,170,170,187,188,160,0,0,0,172,187,187,170,170,170,187,187,204,206,172,221,203,187,170,170,171,187,204,222,254,188,203,186,170,153,154,170,171,204,222,219,203,186,169,153,152,153,154,171,204,221,187,186,153,136,136,136,136,153,171,205,203,186,169,136,119,119,119,136,153,171,204,171,169,136,119,102,102,103,120,154,188,202,170,152,119,102,101,102,103,136,154,187,170,169,135,102,85,85,102,119,137,171,186,169,136,118,101,85,85,103,120,154,187,170,153,135,102,85,85,86,119,137,171,186,170,152,118,101,85,85,103,120,154,187,187,169,135,118,101,85,102,120,137,171,187,186,152,135,102,102,102,119,137,154,187,187,170,152,135,119,119,119,136,154,187,188,203,169,152,135,119,120,136,154,171,203,204,203,169,153,136,136,137,153,171,188,189,220,203,170,153,153,153,154,171,188,220,222,220,203,186,170,170,170,171,188,205,206,254,220,204,187,187,187,187,204,205,236,190,220,204,203,187,187,187,187,188,204,160,0,0,0,206,237,222,221,221,238,239,255,255,255,190,255,238,221,221,221,222,255,255,255,255,239,237,220,204,188,204,205,238,255,255,253,237,204,187,170,170,171,188,223,255,255,221,220,186,153,152,153,154,188,223,255,253,220,186,152,135,119,136,154,188,239,255,221,203,152,135,102,102,120,154,189,239,253,220,169,135,102,85,102,120,155,205,255,221,186,151,102,84,69,86,121,172,222,254,219,169,118,85,68,69,103,138,189,255,221,202,151,101,68,68,86,120,171,206,238,220,169,135,101,68,85,103,138,189,239,238,203,152,118,85,85,102,121,171,222,239,237,186,152,118,102,103,120,154,189,254,239,236,186,152,119,119,120,154,188,222,239,255,220,186,153,136,137,154,171,205,238,255,254,220,187,170,170,170,187,205,239,239,255,255,220,204,187,187,188,205,222,255,255,255,255,237,221,205,205,221,223,255,239,255,255,255,254,254,238,239,255,255,255,191,255,255,255,238,238,238,239,239,255,192,0,0,0,206,221,221,204,204,205,221,238,239,255,206,254,221,220,204,204,204,205,238,255,255,223,237,203,186,170,170,187,204,223,255,254,237,203,170,153,153,153,171,205,223,255,221,203,169,152,136,136,137,154,188,239,253,219,185,152,119,119,119,137,171,205,254,220,186,152,119,102,102,103,137,171,205,252,203,152,119,102,85,86,103,137,172,222,203,169,135,102,85,85,86,120,154,189,220,202,152,118,85,84,85,103,121,171,205,220,169,135,101,84,69,86,120,154,189,220,202,152,118,85,85,85,103,137,171,205,220,186,135,102,85,85,102,120,154,204,221,219,169,135,102,102,102,120,137,188,221,237,203,169,135,119,119,120,137,171,206,222,236,186,169,136,136,136,137,171,205,238,255,236,187,169,153,153,153,171,204,223,239,255,220,203,186,170,170,171,189,222,255,255,255,237,204,203,187,204,204,223,255,255,255,255,238,221,220,221,221,238,255,255,191,255,255,239,237,221,221,223,255,255,208,0,0,0,206,237,220,204,204,204,205,221,239,255,206,254,221,204,187,187,188,205,222,255,255,238,221,203,186,170,170,171,204,222,255,253,220,203,170,153,153,153,170,188,222,255,221,203,169,152,136,136,137,154,188,223,237,203,169,136,119,119,119,136,154,188,238,204,186,152,118,102,102,103,137,155,205,236,186,152,118,102,85,86,103,137,171,221,203,169,135,102,85,85,86,120,154,188,220,186,152,118,85,85,85,103,120,171,205,203,169,135,101,85,85,86,103,138,188,220,186,152,118,85,85,85,103,120,171,205,204,169,135,102,85,85,102,120,154,188,221,203,169,135,102,102,102,119,137,171,205,221,202,152,135,119,103,119,137,171,205,222,236,186,153,136,119,120,137,170,188,221,238,220,186,169,152,137,153,170,188,222,239,254,220,187,170,170,170,171,204,222,254,255,254,237,203,187,187,187,204,222,255,239,255,255,237,220,204,204,221,222,255,255,223,255,238,221,221,205,221,222,238,255,208,0,0,0,189,220,220,204,188,204,205,221,222,238,190,254,221,204,203,187,204,205,238,255,255,222,220,203,186,170,170,187,204,239,255,253,221,203,170,153,153,154,171,204,222,254,205,203,170,152,136,136,137,170,204,238,236,203,169,152,119,119,119,137,171,205,237,204,186,152,119,102,102,119,137,171,206,220,186,152,119,102,85,86,119,138,172,221,203,169,135,102,85,85,86,120,154,189,220,186,152,118,85,68,85,103,137,171,204,203,169,135,101,84,69,86,120,154,188,220,202,152,118,85,85,85,103,137,171,220,204,186,135,118,85,85,102,120,154,188,220,203,169,135,118,102,102,120,153,172,220,221,203,169,135,119,119,120,137,171,205,221,236,202,169,136,136,136,137,171,188,221,222,220,203,169,153,153,153,171,188,222,222,254,221,203,186,170,170,171,188,222,221,239,238,221,204,187,187,188,204,222,239,239,255,254,238,221,205,205,205,221,255,254,206,237,238,221,221,204,221,205,222,222,192,0,0,0,190,238,237,221,221,221,221,238,239,255,190,255,254,221,220,205,221,238,255,255,255,239,237,220,203,187,187,204,221,255,255,253,238,204,187,170,170,170,188,222,255,255,221,220,186,153,152,137,154,171,221,255,253,220,186,152,135,119,120,153,172,222,255,221,203,152,135,102,102,120,154,188,223,237,220,169,135,102,85,86,120,154,189,238,220,186,151,102,85,69,86,120,171,206,237,219,168,118,85,68,69,103,137,188,222,220,186,135,101,84,68,86,120,155,206,221,219,169,118,101,68,85,103,137,188,222,221,202,152,118,85,85,102,120,171,221,238,236,186,152,118,102,103,120,154,189,238,239,220,185,152,119,119,120,154,188,222,238,254,219,170,152,136,136,154,171,206,254,255,237,219,186,170,153,170,187,205,239,239,255,254,220,187,187,187,188,205,239,254,255,255,254,237,204,204,204,221,239,255,255,255,255,255,238,222,222,238,239,255,255,191,255,254,238,237,222,237,222,238,254,192,0,0,0,172,204,187,187,187,187,187,204,221,238,188,221,204,187,187,187,187,188,205,238,254,205,203,186,170,170,170,170,187,205,238,236,203,186,169,153,153,153,154,187,205,237,188,186,153,136,136,136,137,154,187,205,219,186,169,136,119,119,119,136,154,188,221,187,169,136,119,102,102,119,136,154,188,203,186,152,119,102,85,102,119,137,171,204,187,169,135,102,85,85,102,120,154,188,203,169,152,118,101,68,85,103,120,154,187,187,169,135,102,84,69,86,119,137,171,187,186,152,118,101,85,86,103,120,154,187,187,169,135,118,101,86,102,120,153,171,187,186,153,135,118,102,102,119,137,171,204,204,186,152,135,119,119,119,137,154,188,204,203,186,153,136,135,136,136,154,171,204,221,203,186,153,152,136,153,154,171,205,205,237,203,186,170,153,153,170,171,204,220,223,237,204,187,186,170,171,187,204,221,222,254,237,220,203,187,187,204,205,222,253,174,221,221,204,203,187,187,204,204,221,176,0,0,0,171,186,170,153,153,153,154,170,187,204,187,204,186,170,169,153,154,170,187,204,221,188,186,169,153,153,153,153,170,187,204,202,186,169,152,136,136,136,137,154,187,203,171,169,152,136,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,154,187,154,152,135,119,102,102,119,120,137,170,169,169,136,119,102,102,102,103,120,154,170,153,152,119,102,102,102,102,119,137,154,169,153,135,118,102,85,86,103,120,137,170,153,152,119,102,101,86,102,119,136,154,169,153,135,118,102,85,102,103,120,137,170,154,152,119,102,102,102,102,119,137,154,170,169,136,119,102,102,102,119,136,154,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,137,170,187,187,170,153,136,136,136,136,153,170,187,187,203,170,153,153,136,137,153,170,187,203,204,203,186,169,153,153,153,170,187,204,204,220,203,187,170,170,170,171,187,205,220,173,204,187,170,170,170,170,170,187,188,176,0,0,0,155,170,169,153,153,153,153,170,171,188,171,203,186,169,153,153,153,170,171,188,220,171,170,169,153,136,136,153,154,171,188,202,186,153,152,136,136,136,137,154,171,187,170,169,136,135,119,119,120,136,154,171,185,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,119,120,137,170,169,153,135,119,102,102,102,103,120,153,170,153,136,119,102,102,102,102,119,136,154,169,152,135,118,102,102,102,103,120,137,169,153,136,119,102,102,86,102,119,136,154,153,152,135,118,102,102,102,103,120,137,169,153,152,119,102,102,102,102,119,136,154,153,169,136,119,102,102,102,119,120,153,170,170,153,136,119,119,119,119,120,137,170,170,170,152,136,119,119,119,136,137,154,186,171,170,153,136,136,136,136,137,154,171,171,187,170,153,152,136,136,153,154,171,203,188,187,170,153,153,153,153,170,171,188,188,220,203,186,170,170,170,170,187,204,204,188,203,186,170,153,153,154,170,187,188,160,0,0,0,155,187,170,169,153,153,170,171,187,188,171,220,187,170,170,154,170,170,187,205,220,188,187,170,153,153,153,153,170,187,205,202,187,169,152,136,136,136,153,154,171,204,171,169,152,136,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,170,187,170,153,135,119,102,102,119,120,137,171,170,169,136,119,102,102,102,103,136,154,170,154,152,135,102,102,86,102,119,136,154,169,169,135,118,102,85,86,103,120,137,170,154,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,170,152,135,102,102,102,102,119,137,154,170,169,152,119,102,102,102,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,153,171,187,187,186,153,136,136,136,136,153,170,187,187,203,170,169,153,137,153,153,170,187,203,204,203,186,170,153,153,170,170,187,204,205,221,204,187,170,170,170,187,188,205,220,173,203,187,170,170,170,170,170,187,204,160,0,0,0,172,204,187,187,171,171,187,188,204,221,172,221,204,187,187,186,187,188,205,222,253,205,203,186,170,169,170,170,188,205,222,219,204,186,169,153,153,153,154,187,205,237,188,186,153,136,136,136,137,154,171,205,203,186,169,136,119,119,119,136,154,187,220,187,169,136,119,102,102,119,136,154,188,203,186,152,119,102,85,102,119,137,171,204,170,169,135,102,85,85,102,120,153,171,186,170,152,118,101,68,85,103,136,154,187,187,169,135,102,84,69,86,119,137,171,187,186,152,118,101,85,86,103,136,154,187,187,169,135,118,101,86,102,120,153,171,187,186,153,135,118,102,102,119,137,171,203,204,186,152,135,119,119,119,137,154,188,204,203,186,152,136,135,136,137,154,172,204,205,203,186,153,152,136,153,154,171,205,205,221,203,186,170,153,153,170,187,204,220,222,221,204,187,170,170,170,187,204,222,221,254,237,220,203,187,187,204,204,221,237,189,237,220,204,187,187,187,204,204,221,176,0,0,0,207,255,255,239,238,255,255,255,255,255,207,255,255,254,238,238,239,255,255,255,255,255,255,238,221,220,205,222,255,255,255,255,255,237,204,187,187,188,206,239,255,255,255,253,203,170,153,154,171,205,255,255,255,254,203,169,136,136,137,171,205,255,255,239,220,169,135,119,119,136,171,206,255,254,237,186,135,102,85,102,121,172,223,255,255,203,152,118,84,69,103,138,188,255,255,236,185,134,84,51,69,104,155,222,255,254,219,152,117,67,52,86,137,188,239,255,237,186,135,101,68,85,120,155,206,255,255,220,169,134,101,85,103,138,188,239,255,254,219,168,135,102,119,137,172,223,255,255,237,203,169,136,136,137,171,205,255,255,255,237,203,169,153,154,171,205,239,255,255,255,237,204,187,187,187,205,223,255,255,255,255,254,221,204,204,221,239,255,255,255,255,255,255,253,238,238,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,192,0,0,0,206,221,204,204,204,188,220,221,238,255,189,253,220,204,187,187,188,205,222,255,255,222,220,203,186,170,171,187,204,222,255,237,220,187,170,153,153,153,171,188,221,238,204,203,169,152,136,136,137,154,188,223,236,203,169,152,119,119,119,137,155,205,253,204,186,152,119,102,102,119,137,171,205,220,203,152,119,102,85,86,103,137,188,221,203,169,135,102,85,85,86,120,154,205,220,202,152,118,85,68,85,103,137,171,220,203,169,135,101,84,69,86,120,154,189,204,202,152,118,85,85,85,103,137,171,205,204,185,135,118,85,85,102,120,154,189,221,219,169,135,118,102,103,120,154,187,221,221,203,169,135,119,119,120,137,171,205,221,236,186,169,136,136,136,153,170,204,238,238,220,187,169,153,153,154,171,204,222,238,254,220,187,186,170,170,187,204,221,238,255,254,221,204,188,187,188,205,222,239,239,255,254,237,221,205,204,206,222,254,254,175,254,238,221,221,205,221,222,238,255,208,0,0,0,222,237,220,204,204,204,204,221,239,255,206,254,221,204,187,187,188,205,222,255,255,238,220,203,170,170,170,171,188,222,255,253,220,187,169,153,153,153,170,188,222,255,221,203,169,152,136,136,137,154,188,222,236,203,169,136,119,119,119,136,154,188,222,204,169,136,118,102,102,103,137,171,205,220,186,152,118,101,85,86,103,137,171,221,203,169,135,101,85,85,86,120,154,188,220,186,152,118,85,85,85,103,121,171,205,203,169,135,101,85,85,86,119,138,188,220,186,152,118,85,85,85,103,137,171,205,204,169,135,102,85,85,102,120,154,188,220,203,169,135,102,102,102,120,137,171,221,221,186,152,135,119,119,120,137,171,205,221,220,186,153,136,119,136,137,171,205,238,238,220,186,169,152,137,153,170,188,222,238,254,220,187,170,170,170,171,204,222,255,255,254,221,203,187,187,187,205,222,239,255,255,255,237,220,204,205,221,238,255,255,207,255,254,221,221,221,221,222,238,255,208,0,0,0,223,253,221,204,204,204,205,238,255,255,191,254,237,204,204,187,204,221,223,255,255,254,237,203,186,170,170,187,204,239,255,253,237,203,170,153,153,153,171,188,222,255,221,203,169,152,136,136,137,170,189,223,253,219,169,152,119,119,119,137,155,205,255,204,186,152,118,102,102,119,137,171,205,236,187,152,119,101,85,86,103,137,188,222,203,169,135,101,85,85,86,120,154,189,220,202,152,118,85,84,85,103,137,171,205,203,169,135,101,85,69,86,120,154,189,220,202,152,118,85,85,85,103,137,171,221,220,169,135,102,85,85,102,120,154,189,221,203,169,135,102,102,102,120,153,188,221,221,202,153,135,119,119,120,137,171,205,238,236,186,153,136,136,136,137,171,205,221,255,220,186,169,153,153,153,171,188,222,255,255,221,203,186,170,170,187,205,222,255,255,254,237,204,203,187,188,205,238,239,255,255,255,254,221,220,221,221,238,255,255,207,255,254,238,221,221,221,222,239,255,208,0,0,0,207,238,238,221,222,222,238,238,254,239,175,255,254,237,221,221,222,239,255,255,255,239,254,220,204,203,188,205,222,255,255,254,254,220,187,170,170,171,204,222,255,255,238,220,186,169,153,153,154,188,222,255,254,236,186,153,135,119,136,154,188,223,255,237,203,169,135,102,102,120,154,189,239,253,220,169,135,101,85,102,120,155,205,255,221,186,152,102,84,69,86,137,172,222,237,219,169,118,84,68,69,103,154,189,238,237,186,151,101,68,68,86,120,171,222,254,220,169,135,101,68,85,103,154,189,238,237,203,152,118,85,85,103,137,172,222,238,237,186,152,118,102,103,120,155,205,254,255,220,186,152,135,119,136,154,188,223,255,254,220,186,153,152,153,154,188,223,255,255,254,220,187,170,170,171,188,222,255,255,255,254,221,204,187,187,204,221,239,255,255,255,254,238,221,220,221,222,255,255,255,255,255,255,238,238,238,239,255,255,255,207,255,255,255,254,238,238,255,255,255,192,0,0,0,188,204,187,186,170,170,187,188,205,222,188,220,203,187,170,170,171,187,205,222,254,204,203,186,170,153,153,170,187,204,222,235,203,170,153,152,136,153,154,171,205,221,187,186,153,136,136,136,136,154,171,205,219,186,153,136,119,119,119,136,154,171,204,171,169,136,119,102,102,119,136,154,188,202,170,152,119,102,102,102,119,137,171,204,170,153,135,102,85,85,102,120,137,171,186,169,136,118,101,68,85,103,136,154,187,170,152,135,102,84,69,86,119,137,171,187,169,152,118,101,85,86,103,136,154,187,187,169,135,118,101,86,102,120,153,171,187,186,152,135,118,102,103,119,137,170,187,187,186,152,135,119,119,119,137,154,188,204,203,170,152,136,135,136,137,154,187,204,205,203,170,153,136,136,153,154,171,204,205,221,203,170,169,153,153,170,171,204,221,222,220,203,187,170,170,171,187,204,222,222,254,237,204,187,187,187,188,205,222,237,174,221,220,204,187,187,187,204,205,221,176,0,0,0,171,186,170,153,153,153,154,170,187,204,171,203,186,170,153,153,154,170,187,204,221,187,186,169,153,152,137,153,170,187,205,202,186,169,152,136,136,136,137,154,187,204,171,169,152,135,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,154,187,154,152,135,119,102,102,103,120,137,171,169,153,135,119,102,102,102,103,136,154,170,153,152,119,102,102,102,102,119,137,154,169,153,135,118,102,85,86,103,120,137,170,153,152,119,102,101,85,102,119,136,154,169,153,135,118,102,101,102,103,120,153,170,154,152,135,118,102,102,102,119,137,154,170,169,136,119,102,102,102,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,137,170,187,187,186,153,136,136,136,136,153,170,187,187,203,170,169,153,136,137,153,170,187,203,205,203,170,169,153,153,154,170,187,204,205,220,203,187,170,170,170,171,188,205,220,172,204,187,170,170,170,170,171,187,204,176,0,0,0,171,186,169,153,153,153,153,170,171,204,171,203,186,170,153,153,153,170,171,204,220,187,186,169,153,136,136,153,154,171,204,202,186,153,152,136,136,136,137,154,171,187,170,169,136,135,119,119,120,137,154,171,185,169,152,135,119,119,119,120,137,154,187,154,152,135,118,102,102,119,120,137,170,169,153,135,118,102,102,102,103,120,153,170,153,136,119,102,102,102,102,119,136,154,169,152,135,118,102,101,102,103,120,137,170,153,136,119,102,101,86,102,119,136,154,169,153,135,118,102,102,102,103,120,137,170,153,152,119,118,102,102,102,119,137,154,169,169,136,119,118,102,102,119,136,153,170,170,153,136,119,119,119,119,120,137,171,170,170,153,136,119,119,119,136,137,154,186,187,170,153,136,136,136,136,137,154,187,187,203,170,153,152,136,136,153,154,187,203,204,203,170,169,153,153,153,170,187,204,204,220,203,186,170,170,170,170,187,205,220,188,203,186,170,170,170,170,170,187,204,176,0,0,0,171,187,170,153,153,153,154,170,187,204,171,204,187,170,153,153,170,170,187,205,220,188,187,169,153,153,153,153,170,187,205,202,186,169,152,136,136,136,137,154,187,204,171,169,152,135,119,119,136,137,154,187,186,170,152,135,119,119,119,120,137,170,187,154,152,135,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,136,154,170,153,152,119,102,102,86,102,119,137,154,169,153,135,118,102,85,86,103,120,153,170,153,152,119,102,101,85,102,119,136,154,169,169,135,118,102,86,102,103,120,153,170,154,152,135,102,102,102,102,119,137,154,170,169,136,119,102,102,102,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,153,170,187,187,186,153,136,136,136,136,153,170,188,187,203,170,169,153,136,153,153,170,187,203,205,204,186,170,169,153,154,170,187,205,204,220,204,187,170,170,170,171,187,204,220,173,204,187,170,170,170,170,171,187,204,176,0,0,0,188,203,187,170,170,170,171,188,204,221,172,220,203,186,170,170,170,187,204,222,238,204,203,170,169,153,153,170,171,188,222,235,203,170,153,152,136,137,154,171,188,221,187,170,153,136,135,120,136,153,171,205,203,186,153,135,119,119,119,136,153,171,204,171,169,135,119,102,102,119,136,154,188,202,169,152,119,102,86,102,119,137,154,187,170,152,135,102,85,85,102,120,137,171,186,169,135,118,85,85,85,103,120,154,187,170,152,119,101,85,85,86,119,137,171,186,169,136,118,101,85,86,103,120,154,187,170,169,135,118,101,86,102,120,137,171,187,186,152,135,118,102,102,119,137,170,187,187,170,152,135,119,119,119,136,154,188,188,203,169,152,136,119,120,137,154,171,204,204,203,169,153,136,136,137,154,171,204,205,220,187,170,153,153,153,154,171,188,221,222,220,203,186,170,170,170,187,204,222,222,238,221,204,187,187,187,188,204,222,237,190,221,204,203,187,187,187,188,204,222,192,0,0,0,223,255,255,255,255,255,255,255,255,255,191,255,255,254,237,222,239,255,255,255,255,255,255,237,204,204,204,221,255,255,255,255,255,236,203,186,170,187,205,239,255,255,255,221,187,169,153,153,170,189,239,255,255,253,203,169,136,119,136,154,205,255,255,254,219,169,135,102,103,120,154,205,255,255,220,185,135,101,85,86,120,171,223,255,253,202,152,101,84,69,86,137,188,239,254,220,169,118,84,68,69,103,154,205,255,254,202,151,101,68,68,86,121,172,223,255,236,185,135,85,68,85,103,154,205,255,255,219,168,118,85,85,103,137,172,223,255,253,203,152,118,102,103,137,171,207,255,255,253,202,152,135,119,137,154,205,255,255,255,236,187,169,153,153,170,188,223,255,255,255,221,203,186,170,171,204,223,255,255,255,255,254,220,204,204,205,239,255,255,255,255,255,255,253,221,222,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,224,0,0,0,206,237,221,220,204,204,205,222,238,222,175,254,221,220,204,204,204,221,239,255,255,239,221,203,187,170,171,187,205,238,255,238,237,203,170,153,153,154,171,205,238,255,221,203,169,152,136,136,153,171,205,239,237,220,169,152,119,119,119,137,171,206,238,204,186,152,119,102,102,119,137,171,222,236,203,152,118,101,85,86,120,154,188,221,204,169,135,101,85,85,86,120,155,205,220,202,152,118,85,68,85,103,137,172,221,204,169,135,101,84,69,86,120,154,205,220,203,152,118,85,85,85,103,137,172,222,220,186,152,118,85,85,102,120,155,205,221,219,169,135,118,102,102,120,154,188,221,221,203,169,135,119,119,120,153,171,222,237,237,203,169,152,136,136,153,171,205,238,222,236,203,170,153,153,154,171,204,239,238,254,237,203,187,170,171,187,205,239,255,255,255,237,220,204,204,204,205,239,255,254,255,255,238,237,221,221,222,238,255,255,175,238,238,237,221,221,221,237,239,255,208,0,0,0,206,221,204,204,204,188,204,221,221,238,190,254,221,204,187,187,188,205,238,255,254,222,220,203,186,170,170,187,204,222,255,237,220,203,170,153,153,153,171,188,222,254,221,203,169,152,136,136,137,171,204,222,220,203,169,136,119,119,119,137,171,205,237,204,186,152,119,102,102,119,137,171,205,220,186,152,119,101,85,102,119,138,188,221,188,169,135,101,85,85,86,120,154,189,220,186,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,188,204,186,152,118,101,85,85,103,137,171,204,204,185,135,118,85,85,102,120,154,189,220,203,169,135,118,102,102,120,154,188,221,221,203,169,135,119,119,120,137,171,205,221,221,186,169,136,136,136,153,171,205,221,222,220,187,169,153,153,154,171,188,222,237,238,220,203,186,170,170,171,204,222,254,239,254,221,204,203,187,188,204,222,239,238,255,238,237,220,204,221,221,222,255,255,190,238,237,221,221,205,205,221,238,239,208,0,0,0,206,237,221,204,204,220,221,222,239,239,174,254,237,220,204,204,204,222,239,255,254,238,221,219,187,186,171,188,205,238,255,237,237,203,170,153,153,154,187,205,239,254,221,203,170,152,136,136,153,171,205,239,237,219,185,152,119,119,120,137,171,205,238,204,186,152,118,102,102,119,137,172,222,220,203,152,118,101,85,86,119,154,188,237,204,185,135,101,85,85,86,120,155,205,220,202,152,118,85,68,85,103,137,188,221,204,169,135,101,84,69,86,120,154,189,220,203,152,118,85,85,85,103,137,172,221,220,186,152,118,85,85,102,120,154,205,221,220,185,135,118,102,102,120,154,188,221,222,219,169,136,119,119,120,153,171,221,238,237,203,169,152,136,136,153,171,205,238,255,237,203,170,153,153,154,171,205,222,238,255,221,204,187,170,171,187,204,222,238,255,254,237,220,203,204,204,205,238,255,238,255,255,254,237,221,221,222,238,239,255,174,238,238,237,237,221,221,222,238,254,208,0,0,0,255,255,255,255,255,255,255,255,255,255,175,255,255,255,237,223,255,255,255,255,255,255,255,253,204,204,204,221,255,255,255,255,255,221,203,186,170,187,205,255,255,255,255,252,187,169,153,153,171,189,255,255,255,253,202,169,135,119,136,154,189,255,255,253,203,169,135,102,103,120,154,205,255,255,252,185,135,101,85,86,120,171,223,255,253,202,151,101,84,69,86,137,172,255,255,220,169,118,84,68,69,103,154,207,255,253,202,151,101,68,68,86,121,172,223,255,252,185,134,101,68,85,103,154,205,255,255,219,168,118,85,85,103,137,172,239,255,255,202,152,118,102,103,137,171,207,255,255,253,186,152,135,119,137,155,205,255,255,255,252,186,169,153,153,171,188,255,255,255,255,237,203,186,170,171,205,239,255,255,255,255,253,220,204,204,205,255,255,255,255,255,255,255,253,221,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,240,0,0,0,206,221,204,204,188,188,204,221,222,238,174,238,221,204,187,187,204,205,222,255,254,222,220,203,186,170,170,187,205,222,239,237,220,187,170,153,153,154,171,188,222,254,205,203,169,152,136,136,153,171,205,223,236,203,169,136,119,119,120,137,171,205,238,204,186,152,119,102,102,119,137,171,205,219,186,152,119,101,85,102,120,154,188,221,187,169,135,101,85,85,102,120,154,189,219,186,152,118,85,68,85,103,137,171,204,203,169,135,101,84,68,86,120,154,188,220,186,152,118,101,84,85,103,137,171,204,204,186,152,118,101,85,103,120,154,188,204,203,169,135,118,102,102,120,154,172,221,221,203,169,136,119,119,120,137,171,205,221,221,203,169,152,136,136,153,171,188,237,238,220,203,170,153,153,154,171,188,222,238,254,220,203,186,170,170,187,188,221,238,239,254,221,204,203,187,188,205,221,239,238,255,254,237,221,204,204,221,238,239,254,158,237,221,221,220,204,221,221,222,239,192,0,0,0,172,187,186,170,170,170,170,187,204,205,156,220,187,187,170,170,170,187,204,222,237,188,203,170,169,153,153,154,171,188,221,219,187,170,153,152,136,137,153,171,188,220,187,170,153,136,135,120,136,153,171,188,202,186,153,135,119,119,119,136,153,171,204,171,169,135,118,102,102,103,120,154,172,202,169,152,118,102,102,102,119,137,154,187,170,152,119,102,85,85,102,120,137,171,186,169,135,118,101,85,85,103,120,154,187,170,152,119,102,85,85,86,119,137,171,186,169,136,118,101,85,86,103,120,154,187,170,153,135,118,101,86,102,120,137,171,186,186,152,135,118,102,102,119,137,170,187,187,169,152,135,119,119,119,136,154,188,187,187,169,152,136,119,120,136,154,171,203,188,187,170,153,136,136,137,154,171,204,204,204,187,170,153,153,153,154,171,189,220,205,204,187,186,170,170,170,187,204,222,204,238,220,203,187,187,187,187,204,221,237,157,204,203,187,187,187,187,188,204,221,192,0,0,0,171,186,170,153,153,153,154,170,187,188,155,203,186,170,169,153,170,170,187,204,220,187,186,169,153,153,153,153,170,187,205,186,186,169,152,136,136,136,153,154,187,203,170,169,152,136,119,119,136,137,154,188,186,169,152,135,119,119,119,120,137,170,187,154,152,135,119,102,102,119,120,153,171,169,169,136,119,102,102,102,119,136,154,170,153,152,119,102,101,86,102,119,137,170,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,153,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,102,120,137,170,170,169,152,119,118,102,103,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,135,119,120,136,153,170,186,171,186,153,152,136,136,136,153,170,187,187,203,186,169,153,153,153,153,170,187,203,188,203,186,170,169,153,170,170,187,204,188,220,204,187,170,170,170,171,188,204,220,156,203,186,170,170,170,170,171,187,204,160,0,0,0,171,187,170,170,169,170,170,171,187,204,155,204,187,186,170,170,170,171,188,205,220,188,187,170,153,153,153,154,171,188,205,202,187,170,153,136,136,136,153,170,188,203,171,169,152,136,119,119,136,153,170,204,186,170,152,135,119,119,119,120,153,171,187,170,153,135,118,102,102,119,120,154,172,186,169,136,118,102,102,102,119,136,154,187,154,152,119,102,85,85,102,119,137,171,185,169,135,118,101,85,86,103,120,154,186,154,152,119,102,85,85,102,119,137,171,170,169,135,118,101,85,86,103,120,154,186,170,152,135,118,102,102,102,120,137,171,170,186,152,119,118,102,102,119,137,154,186,171,169,152,135,119,119,119,136,154,171,187,187,169,152,136,119,120,136,154,171,203,188,186,169,152,136,136,137,153,171,188,187,204,187,170,153,153,153,154,171,188,203,205,204,187,170,170,170,170,187,188,205,204,220,204,203,187,187,171,187,204,205,220,156,203,187,186,170,170,170,187,187,204,160,0,0,0,206,221,204,204,204,204,205,222,238,239,158,254,221,204,203,187,204,221,239,255,255,222,220,203,186,170,171,187,205,238,255,253,220,203,170,153,153,154,171,205,239,255,221,203,169,152,136,136,153,171,205,239,236,203,169,152,119,119,120,137,171,205,238,204,186,152,119,102,102,120,137,171,222,236,202,152,119,101,85,102,120,154,188,221,203,169,135,101,85,85,102,120,155,205,220,186,152,118,85,68,85,103,137,172,221,204,169,135,101,84,68,86,120,154,189,220,203,152,118,101,68,85,103,137,171,221,204,186,152,118,101,85,103,120,155,189,221,219,185,136,118,102,103,120,154,188,221,221,203,169,136,119,119,120,153,171,205,221,237,203,169,152,136,136,153,171,205,237,238,237,203,170,153,153,154,171,204,222,238,254,221,203,186,170,170,187,204,222,254,239,254,221,220,203,187,204,205,238,255,254,255,255,238,221,220,221,221,238,255,255,174,254,238,237,221,221,221,222,238,255,192,0,0,0,223,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,237,221,255,255,255,255,255,255,255,221,204,204,205,222,255,255,255,255,255,220,187,170,171,188,221,255,255,255,255,236,186,153,137,154,187,223,255,255,255,253,186,152,119,119,137,188,239,255,255,255,203,152,101,85,103,138,188,255,255,255,220,169,117,68,68,103,155,207,255,255,254,202,135,84,51,69,121,172,223,255,255,220,169,117,67,52,87,138,206,255,255,255,203,151,100,68,69,121,172,223,255,255,253,186,135,101,85,104,155,205,255,255,255,220,185,135,119,120,154,189,255,255,255,255,220,186,152,137,154,188,223,255,255,255,254,220,187,170,171,188,223,255,255,255,255,255,221,204,204,205,255,255,255,255,255,255,255,254,221,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,208,0,0,0,189,221,220,204,204,204,204,204,221,205,158,254,221,221,204,204,205,221,238,254,253,222,237,220,187,187,187,188,205,222,239,236,221,204,186,170,170,170,187,205,237,237,205,204,186,169,153,153,154,187,205,223,220,220,186,153,136,119,136,154,188,205,237,205,203,169,135,102,102,120,154,188,222,220,203,169,135,101,85,102,120,155,189,237,204,186,151,101,84,69,102,137,171,205,220,203,168,118,84,68,69,103,138,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,237,205,202,152,118,101,85,103,137,171,205,220,220,186,152,119,102,103,136,155,204,237,205,203,170,152,135,119,137,154,188,221,220,220,204,170,153,153,153,170,188,222,237,222,221,204,186,170,170,171,188,221,238,220,254,221,204,203,187,187,188,205,238,254,223,238,221,221,204,204,204,221,238,239,237,255,238,237,221,221,222,239,239,255,238,157,221,205,221,221,221,221,222,238,254,192,0,0,0,206,221,204,203,187,188,204,205,221,222,174,238,220,204,187,187,188,205,221,239,254,222,220,203,186,170,170,187,204,221,239,237,220,203,170,153,153,154,171,188,222,238,204,203,169,152,136,136,153,170,188,222,220,203,169,152,119,119,120,137,171,204,221,204,186,152,119,102,102,119,137,171,205,219,186,152,119,101,85,86,119,154,188,221,187,169,135,101,85,85,86,120,154,205,219,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,85,85,85,103,137,171,204,204,186,136,118,85,85,103,120,154,189,204,203,169,135,118,102,103,120,154,188,221,205,203,169,136,119,119,120,153,171,205,220,220,186,169,136,136,136,153,171,205,221,221,220,187,169,153,153,154,171,204,222,221,237,220,187,186,170,170,187,204,222,254,223,238,220,204,187,187,188,204,222,255,254,254,254,221,221,204,204,221,222,255,254,174,237,221,221,204,204,205,221,238,239,208,0,0,0,222,237,221,204,204,204,204,221,221,222,159,255,237,221,221,204,205,221,238,239,254,239,237,220,187,187,187,204,206,238,255,237,237,220,186,170,170,170,187,205,238,253,222,220,186,153,152,137,154,171,205,239,221,220,186,152,135,119,120,154,187,205,237,205,203,168,135,102,102,120,154,188,222,220,219,169,135,101,85,102,120,154,188,237,205,186,151,101,84,69,102,121,171,205,220,203,168,118,84,68,69,103,138,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,118,101,69,86,103,154,188,221,221,202,152,118,101,85,103,137,171,205,221,220,186,152,118,102,103,136,154,189,221,221,203,170,152,135,119,136,154,188,206,222,237,203,170,153,136,137,154,188,205,237,239,237,203,186,170,170,170,188,205,238,222,254,221,204,187,187,187,204,205,222,254,223,254,221,220,204,204,204,222,238,239,238,255,239,238,222,221,221,222,239,255,255,174,221,221,237,221,221,221,222,238,238,192,0,0,0,223,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,221,204,204,205,221,255,255,255,255,255,220,203,170,171,188,223,255,255,255,255,220,186,153,137,154,188,223,255,255,255,253,186,152,119,119,137,188,223,255,255,255,203,152,102,85,103,138,189,255,255,255,252,169,118,68,69,103,155,205,255,255,255,202,135,84,51,69,120,172,255,255,255,252,169,117,67,36,87,138,206,255,255,255,203,151,101,68,70,121,172,223,255,255,253,186,135,101,86,104,155,205,255,255,255,220,185,135,119,120,154,189,255,255,255,255,220,186,153,137,154,188,255,255,255,255,255,220,187,170,171,188,223,255,255,255,255,255,221,204,204,205,223,255,255,255,255,255,255,255,221,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,208,0,0,0,206,237,205,204,204,204,204,205,221,221,158,254,221,220,204,188,204,221,238,239,254,222,221,204,187,187,187,188,204,222,239,237,237,203,186,170,170,170,187,205,222,238,221,204,186,153,152,153,154,171,204,222,220,220,186,152,136,119,136,153,171,205,237,204,186,153,135,118,103,120,154,188,221,220,203,169,135,102,85,102,120,154,188,221,204,186,152,118,84,69,103,137,171,205,220,203,168,118,84,52,85,103,154,188,220,204,186,151,101,68,52,86,120,155,205,220,203,169,135,101,68,86,104,154,188,221,204,186,152,118,101,86,103,137,171,205,220,203,186,152,119,102,119,136,154,188,221,205,203,169,152,135,120,137,154,188,222,221,236,203,170,153,136,153,154,187,205,237,222,220,203,186,170,170,170,187,205,239,237,238,220,203,187,187,187,188,205,239,238,239,254,221,204,204,204,204,221,222,255,237,255,238,237,221,205,221,221,238,255,255,142,221,221,204,204,205,221,221,222,238,192,0,0,0,155,187,170,170,169,170,170,170,187,187,155,204,187,186,170,170,170,187,188,204,236,188,187,170,169,153,153,170,170,188,205,187,187,170,153,152,136,137,154,171,188,203,171,170,153,136,136,136,136,153,171,188,186,186,153,136,119,119,119,136,153,171,203,170,169,136,119,102,102,119,136,154,171,186,169,152,119,102,85,102,119,137,170,187,154,152,135,102], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+769384);
/* memory initializer */ allocate([85,85,102,120,153,171,169,169,135,118,85,85,85,103,120,154,186,154,152,135,101,85,85,86,119,137,171,170,169,136,118,101,85,86,103,136,154,186,170,169,135,118,101,86,102,120,153,171,170,170,152,135,118,102,102,120,137,170,186,171,169,152,135,119,119,120,137,154,187,186,187,169,152,136,136,136,137,154,171,203,188,187,169,153,136,136,153,154,171,188,187,204,187,170,169,153,153,170,171,188,204,188,204,187,186,170,170,171,187,188,221,204,221,220,203,187,187,187,188,204,205,236,140,187,187,186,170,170,170,187,188,204,160,0,0,0,155,170,169,153,153,153,153,170,171,187,155,203,186,170,169,153,170,170,187,204,203,171,186,169,153,153,153,153,170,171,204,186,186,169,152,136,136,136,153,154,187,203,170,169,152,136,119,119,136,137,154,187,185,169,152,135,119,119,119,120,137,170,186,154,153,135,119,102,102,119,120,153,171,169,169,136,119,102,102,102,119,136,154,170,153,152,119,102,101,86,102,119,137,170,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,103,120,137,170,169,169,152,119,118,102,103,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,135,119,120,136,153,170,186,171,186,153,152,136,136,136,153,170,187,187,203,170,169,153,153,153,153,170,187,203,188,203,186,170,169,153,170,170,187,204,187,220,203,187,170,170,170,187,187,204,220,155,187,170,170,170,170,170,170,187,188,160,0,0,0,155,187,170,170,170,170,170,170,187,188,139,220,203,187,170,170,171,187,188,221,220,188,203,186,169,153,153,170,171,188,205,203,203,186,153,152,136,153,154,171,188,203,171,170,153,136,135,136,136,154,171,188,186,186,153,136,119,119,119,136,154,171,203,170,169,136,118,102,102,119,136,154,187,186,169,152,118,102,85,102,119,137,154,186,170,152,135,102,85,85,102,120,137,171,186,169,136,118,85,85,85,103,136,154,186,170,152,135,101,85,85,86,119,137,171,170,169,152,118,101,85,86,103,136,154,186,170,169,135,118,101,86,102,120,153,171,170,186,152,135,118,102,102,119,137,171,187,171,170,152,135,119,119,120,137,154,188,187,203,170,152,136,135,136,137,154,171,203,188,187,170,153,152,136,153,154,171,204,187,204,187,170,169,153,154,170,171,204,204,189,204,187,186,170,170,171,187,204,205,204,221,204,203,187,187,187,188,204,221,220,140,187,187,187,170,170,187,187,187,204,160,0,0,0,189,221,221,204,204,204,204,205,205,221,142,254,237,221,204,204,205,221,239,255,253,222,237,204,203,187,187,204,205,238,239,237,221,204,187,170,170,170,187,205,238,253,221,220,186,169,153,153,154,187,205,238,236,220,186,169,136,119,136,154,188,206,237,205,203,169,135,118,103,120,154,188,222,220,203,169,135,102,85,102,120,154,188,237,204,186,152,118,84,69,103,137,171,205,220,203,169,118,84,52,69,104,154,188,221,204,186,152,101,68,52,86,121,171,205,220,219,169,135,101,68,86,120,154,188,221,221,186,152,118,101,85,103,137,171,206,220,220,186,152,119,102,119,137,171,204,221,221,219,170,152,135,120,137,154,188,222,221,237,203,170,153,153,153,170,188,205,237,222,221,203,186,170,170,171,188,205,239,237,255,237,220,203,187,187,188,221,238,254,223,254,221,220,204,204,221,221,238,255,253,255,254,238,237,221,221,238,238,255,255,157,221,222,221,221,205,221,238,222,239,192,0,0,0,207,254,238,222,221,221,221,237,221,221,159,255,255,255,238,238,238,239,255,255,255,255,255,238,221,221,205,221,222,239,255,238,255,237,220,203,187,204,205,238,255,254,239,237,204,186,170,170,187,205,238,255,254,238,220,186,152,136,153,171,205,222,254,239,220,186,152,119,119,137,171,205,255,238,237,202,152,118,85,103,137,172,222,255,238,203,168,118,84,69,103,138,189,223,238,237,186,135,84,51,69,120,171,222,255,222,203,168,117,67,36,87,138,189,239,237,237,186,151,101,68,70,120,171,221,254,223,220,169,135,101,86,120,154,205,239,238,237,219,169,135,119,120,154,188,223,254,223,237,203,169,152,136,154,187,221,255,253,254,221,203,170,170,170,188,221,254,254,223,238,221,204,203,187,188,205,239,255,253,254,254,221,220,204,221,222,255,255,255,223,254,255,238,237,238,239,255,255,255,253,255,255,255,239,255,255,255,255,255,255,140,221,221,221,221,221,237,254,239,255,192,0,0,0,205,221,220,204,204,204,204,204,221,221,158,254,221,220,204,204,204,221,221,238,238,222,221,204,187,187,187,187,205,221,239,237,221,203,186,170,170,170,171,204,222,237,205,203,186,153,152,137,154,171,204,222,220,220,186,152,135,119,136,153,171,205,237,204,186,152,135,102,102,120,153,171,205,220,203,169,135,102,85,102,120,154,188,221,204,186,151,102,84,69,102,137,171,205,220,203,168,118,84,68,69,103,137,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,134,101,68,85,103,154,188,221,204,186,152,118,101,86,103,137,171,205,220,220,170,152,119,102,103,136,154,189,237,205,203,169,152,119,119,136,154,188,222,221,220,203,170,153,136,137,154,188,205,238,221,220,203,170,170,170,170,188,205,239,237,238,220,203,187,187,187,188,205,238,254,222,238,221,220,204,204,204,221,238,255,237,255,238,238,221,221,221,222,238,255,255,157,237,221,221,221,221,221,222,238,255,208,0,0,0,206,221,204,203,187,187,188,204,205,221,174,238,220,204,187,187,188,204,221,222,237,222,220,203,186,170,170,171,188,205,222,221,220,203,170,153,153,153,170,188,205,237,205,203,169,152,136,136,137,170,188,221,220,203,169,152,119,119,119,137,170,188,221,204,186,152,119,102,102,119,137,171,205,203,186,152,119,101,85,86,120,137,171,220,187,169,135,101,85,85,86,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,85,85,85,103,137,171,204,188,170,136,118,101,85,103,120,154,188,204,203,169,135,118,102,103,120,154,188,220,204,186,169,136,119,119,120,153,171,205,220,204,186,169,136,136,136,153,171,204,221,205,204,186,169,153,153,154,171,204,222,221,237,204,187,170,170,170,187,204,222,238,222,221,220,203,187,187,188,204,222,239,237,254,237,221,204,204,204,221,222,239,254,173,221,221,204,204,204,205,221,222,238,208,0,0,0,189,221,220,204,204,204,204,204,221,221,158,254,237,220,204,204,204,205,222,238,237,222,237,204,203,187,187,187,204,221,239,221,237,203,187,170,170,170,187,204,221,237,221,204,186,153,152,153,154,171,205,222,220,220,186,153,136,119,136,153,171,205,237,204,186,169,135,102,103,120,154,188,205,204,203,169,135,101,85,102,120,154,188,220,204,186,152,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,138,188,220,204,186,151,101,68,68,86,120,171,205,204,203,169,135,101,68,85,103,154,188,220,204,186,152,118,101,85,103,137,171,205,204,204,186,152,119,102,103,136,154,188,220,205,203,169,152,135,119,136,154,188,221,220,220,203,170,153,136,153,154,187,205,237,222,220,203,186,170,170,171,187,205,222,221,237,220,203,187,187,187,204,205,222,237,223,237,221,204,204,204,204,221,222,239,221,238,238,221,221,221,221,222,238,239,254,157,221,204,204,204,204,205,221,221,222,176,0,0,0,223,255,255,254,253,221,221,221,221,221,143,255,255,255,254,254,255,255,255,255,254,255,255,255,255,255,238,254,255,255,255,239,255,255,238,221,221,221,254,255,239,255,255,254,253,204,187,188,204,223,255,255,255,255,237,203,186,170,171,205,222,255,255,255,253,203,169,136,136,154,205,239,255,255,255,236,169,134,102,120,155,206,255,255,255,237,202,134,84,69,120,172,222,255,255,255,203,168,100,34,70,138,189,255,255,239,254,186,134,66,36,104,172,222,255,255,254,220,168,117,68,86,138,189,255,255,255,237,203,152,118,102,121,172,223,255,255,255,237,202,152,136,137,171,221,255,255,255,255,221,187,170,170,171,205,255,255,255,255,255,221,204,187,204,221,255,255,255,255,255,254,237,221,221,222,239,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,158,254,255,239,255,254,255,255,255,255,224,0,0,0,189,221,204,203,187,187,204,204,205,221,157,254,221,204,203,187,188,204,221,238,254,222,221,204,187,170,171,187,188,221,238,237,221,203,170,169,153,154,171,204,221,237,205,203,170,152,136,136,153,171,188,222,220,203,186,152,135,119,120,137,171,205,237,204,186,152,119,102,102,120,137,171,205,204,203,169,135,102,85,102,120,154,188,221,187,169,135,102,84,85,102,120,154,205,203,186,152,118,84,68,69,103,137,171,204,188,169,135,101,84,68,86,120,154,188,203,202,152,118,101,84,85,103,137,171,204,204,186,152,118,101,86,103,137,171,205,204,203,169,136,118,102,103,120,154,188,220,204,202,169,136,119,119,136,154,187,205,220,220,186,169,152,136,137,154,171,205,221,222,220,187,170,153,153,170,187,205,222,221,237,220,203,186,170,171,187,205,222,254,222,237,220,204,203,187,204,221,222,239,237,239,238,221,221,220,221,221,238,255,254,141,220,204,204,204,204,204,205,222,238,192,0,0,0,172,203,186,170,170,170,170,171,187,188,156,220,203,187,170,170,170,187,188,205,220,188,203,170,169,153,153,170,171,188,205,203,203,170,153,152,136,153,153,171,188,220,187,186,153,136,136,136,136,153,171,188,186,186,153,136,119,119,119,136,154,171,203,171,169,135,118,102,102,119,136,154,187,186,169,152,118,102,85,102,119,137,171,187,170,152,135,102,85,85,102,120,137,171,186,169,136,118,85,85,85,103,120,154,187,170,152,135,101,85,85,86,119,137,171,186,169,152,118,101,85,86,103,136,154,187,170,153,135,118,101,86,102,120,153,171,186,186,152,135,118,102,102,119,137,170,187,171,170,152,135,119,119,119,137,154,188,187,187,169,152,136,135,136,137,154,187,203,188,187,170,153,136,136,153,154,171,205,203,220,187,170,169,153,153,170,187,204,220,189,204,187,186,170,170,187,187,204,222,204,237,204,203,187,187,187,188,205,222,237,140,204,187,187,187,187,187,188,204,221,176,0,0,0,171,186,170,153,153,153,153,170,171,187,155,203,187,170,170,170,170,170,187,204,219,187,186,170,153,153,153,153,170,187,204,186,186,169,153,136,136,136,153,170,187,203,171,169,152,136,119,120,136,137,170,187,186,170,152,135,119,119,119,136,153,170,186,154,153,135,119,102,102,119,136,153,171,169,169,136,119,102,102,102,119,136,154,186,154,152,119,102,85,85,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,101,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,103,119,137,154,186,170,169,136,135,119,119,119,136,154,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,152,136,136,137,153,170,188,186,203,170,169,153,153,153,154,170,187,203,188,203,186,170,170,170,170,171,187,205,187,204,203,187,186,170,170,187,188,205,220,155,187,186,170,170,170,170,171,187,204,160,0,0,0,172,187,170,170,170,170,170,170,187,188,156,220,203,187,170,170,170,187,188,205,220,188,187,170,169,153,153,170,171,188,205,187,203,170,153,152,136,137,153,171,188,203,171,170,153,136,136,120,136,153,171,188,186,186,153,135,119,119,119,136,154,171,203,170,169,136,118,102,102,119,136,154,187,186,169,152,118,102,85,102,119,137,154,187,170,152,135,102,85,85,102,120,137,171,170,169,135,118,85,85,85,103,136,154,186,170,152,135,101,85,85,86,119,137,171,170,169,136,118,101,85,86,103,136,154,186,170,153,135,118,101,86,103,120,153,171,170,186,152,135,118,102,103,120,137,170,187,171,170,152,135,119,119,120,137,154,188,186,187,169,152,136,135,136,137,154,171,203,188,187,170,153,136,136,153,154,171,188,187,204,187,170,169,153,153,170,171,188,219,189,204,187,186,170,170,170,187,204,221,204,221,204,203,187,187,187,188,204,205,220,140,203,187,186,170,170,187,187,188,204,160,0,0,0,189,220,204,203,187,187,187,204,204,205,141,238,221,204,203,187,204,204,221,238,253,221,220,203,186,170,171,187,188,221,239,221,220,203,170,169,153,154,171,188,221,237,204,203,170,152,136,136,153,171,188,221,220,203,169,152,135,119,120,137,171,204,220,204,186,152,119,102,102,119,137,171,205,203,187,169,135,102,85,102,120,154,188,220,187,169,135,102,84,85,102,120,154,188,203,186,152,118,84,68,69,103,137,171,204,187,169,135,101,84,68,86,120,154,188,203,186,152,118,101,84,86,103,137,171,204,188,186,152,118,101,86,103,136,155,189,204,203,169,136,118,102,103,120,154,188,221,205,187,169,136,119,119,136,154,171,205,204,220,187,169,152,136,137,153,171,205,221,221,204,186,170,153,153,170,171,204,222,221,237,220,203,186,170,171,187,205,222,238,222,221,220,203,187,187,188,205,222,255,237,255,222,221,220,204,205,221,238,239,254,157,221,204,204,204,204,205,221,222,238,192,0,0,0,239,255,255,254,239,221,221,221,221,221,159,255,255,255,255,238,222,255,239,255,255,255,255,253,221,221,221,221,238,255,255,239,255,253,220,204,187,188,205,222,255,254,255,254,220,186,170,170,171,205,239,255,255,255,220,186,152,136,137,171,205,239,255,239,220,186,152,118,119,137,171,205,255,238,237,202,152,102,85,102,137,171,222,255,238,219,168,118,68,69,103,138,205,255,254,253,186,134,84,51,69,120,171,222,255,222,219,168,117,67,52,86,138,189,239,254,253,186,135,101,68,69,120,171,222,255,238,220,169,135,101,85,104,154,205,255,254,253,203,169,135,118,119,154,188,239,255,239,253,203,169,136,136,154,188,223,255,253,254,220,203,170,154,170,188,223,255,255,223,254,221,204,187,187,205,221,255,255,253,255,254,237,220,220,221,238,255,255,255,223,255,238,239,237,238,239,255,255,255,253,255,255,255,255,255,255,255,255,255,255,141,221,205,222,221,223,255,255,255,255,224,0,0,0,222,221,221,220,204,204,204,204,205,221,158,254,237,221,204,204,204,221,222,239,253,238,237,220,203,187,187,188,205,222,239,237,237,204,186,170,170,170,187,204,222,253,222,204,186,153,152,153,154,171,205,222,221,220,186,152,135,119,136,154,171,205,237,205,203,168,135,102,103,120,154,188,221,220,203,169,135,101,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,135,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,205,186,152,118,101,85,103,137,172,206,220,204,186,152,118,102,103,137,171,205,237,205,203,169,152,135,119,136,154,188,222,236,221,203,170,153,137,153,170,188,222,238,221,220,203,186,170,170,171,188,221,239,236,237,220,203,187,187,187,204,221,239,254,223,238,221,204,204,204,205,237,254,255,252,255,254,237,221,221,221,238,254,255,255,157,237,221,221,221,221,237,222,239,255,208,0,0,0,206,221,220,204,187,187,188,204,205,221,174,238,221,204,203,187,188,204,221,238,238,222,221,203,186,170,170,187,188,205,222,221,220,203,170,153,153,154,170,188,205,237,221,203,169,152,136,136,137,170,188,205,220,203,169,152,119,119,120,137,170,188,221,204,186,152,119,102,102,119,137,171,205,220,202,152,119,101,85,102,120,153,171,220,187,169,135,101,85,85,102,120,154,188,203,186,152,118,84,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,84,85,103,137,171,204,188,170,152,118,101,85,103,120,154,205,220,203,169,135,118,102,103,120,154,188,221,204,186,169,136,119,119,120,153,171,205,220,220,186,169,152,136,136,153,171,205,237,205,204,186,170,153,153,154,171,204,222,237,237,204,187,170,170,170,187,205,222,254,222,221,204,204,187,187,204,205,222,255,237,254,237,221,204,204,205,221,238,239,255,173,221,220,204,204,204,205,221,238,239,208,0,0,0,206,237,221,204,204,204,204,204,204,221,158,255,238,221,204,204,204,205,222,239,253,239,237,220,203,187,187,187,204,221,239,221,237,204,187,170,170,170,171,204,221,237,222,220,186,169,152,137,154,171,204,222,221,220,186,152,135,119,136,153,171,205,237,205,203,168,135,102,103,120,154,187,205,220,219,169,135,101,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,168,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,136,154,188,221,205,203,169,152,135,120,137,154,188,205,221,220,203,170,153,152,153,154,187,205,221,222,220,203,186,170,170,171,187,205,221,221,237,220,203,187,187,187,188,204,222,237,222,237,221,204,204,204,204,205,222,239,221,254,238,221,221,221,221,222,238,239,254,157,221,221,221,221,204,221,221,222,222,192,0,0,0,223,255,254,238,221,221,220,204,221,205,143,255,255,255,254,222,238,223,239,255,254,239,255,255,221,220,204,221,222,238,255,223,255,238,220,203,187,188,205,221,255,254,255,253,220,186,170,170,171,205,238,255,238,238,204,186,152,136,137,171,204,239,255,255,220,186,136,119,119,137,171,205,239,254,237,202,151,101,85,103,137,172,222,254,238,219,168,117,68,69,103,138,189,238,237,252,186,135,84,51,69,120,155,222,255,221,203,168,117,67,52,87,138,188,239,253,220,186,135,101,68,69,120,171,222,255,222,220,169,135,101,85,104,154,205,239,253,237,203,169,135,119,120,154,188,239,255,222,236,203,169,136,136,154,188,221,255,255,255,220,187,170,170,170,188,221,239,255,239,254,221,204,187,187,204,221,255,255,254,254,238,221,220,204,205,223,239,255,255,239,255,255,238,237,238,238,255,255,255,253,255,255,255,239,255,255,255,255,255,255,141,221,222,237,222,255,239,255,255,255,208,0,0,0,207,221,220,204,204,203,204,204,204,205,142,254,237,221,204,204,204,204,238,239,253,222,237,204,187,187,187,188,205,222,239,237,237,203,186,170,170,170,187,204,222,253,221,204,186,153,153,153,154,171,205,238,220,220,186,152,136,119,136,153,171,205,237,204,202,152,135,102,103,120,154,187,221,220,203,169,135,102,85,102,120,154,188,221,204,186,152,102,84,69,103,137,171,205,220,203,168,118,84,68,69,103,154,188,221,204,186,151,101,68,52,86,121,171,205,220,203,169,135,101,68,86,104,154,188,221,204,186,152,118,101,86,103,137,171,205,220,204,186,152,119,102,103,136,154,188,237,205,203,170,152,135,119,136,154,188,222,220,220,203,170,153,136,153,154,188,205,238,222,220,203,186,170,170,170,188,205,223,237,237,220,203,187,187,187,188,205,238,254,222,237,221,204,204,204,204,221,239,255,237,254,238,237,221,205,221,222,255,255,255,124,204,204,204,220,205,221,222,238,255,208,0,0,0,188,203,186,170,170,170,170,171,187,188,140,221,203,187,186,170,171,187,188,205,220,204,203,186,170,153,154,170,171,188,221,203,203,186,169,153,137,153,154,171,188,220,187,186,153,136,136,136,137,154,171,204,187,186,169,136,119,119,119,136,154,171,203,171,169,136,119,102,102,119,137,154,188,186,170,152,119,102,85,102,120,137,171,203,170,169,135,102,85,85,102,120,154,171,186,169,152,118,85,68,85,103,137,154,187,170,153,135,102,84,69,86,120,153,171,186,170,152,118,101,85,86,103,137,170,187,170,169,136,118,101,86,102,120,154,171,186,186,153,135,118,102,103,120,137,171,203,187,170,153,135,119,119,120,137,154,188,187,203,170,153,136,136,136,137,154,187,204,188,187,170,153,153,137,153,170,187,205,203,204,203,170,169,153,170,170,187,204,220,189,220,187,186,170,170,187,187,204,222,204,221,220,204,187,187,187,204,205,221,237,140,203,187,187,187,187,187,188,204,221,176,0,0,0,171,186,170,169,153,153,153,170,170,187,155,204,187,170,170,170,170,170,187,204,203,188,186,170,153,153,153,153,170,187,204,186,187,169,153,136,136,136,153,170,187,203,171,169,152,136,119,120,136,153,170,187,186,170,152,135,119,119,119,136,153,170,186,170,153,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,101,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,102,119,136,154,186,170,169,152,135,119,119,119,136,154,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,152,136,136,137,153,170,188,187,203,186,169,153,153,153,154,170,188,203,188,203,186,170,170,170,170,171,188,205,203,220,203,187,186,170,171,187,188,205,220,155,187,186,170,170,170,170,187,188,204,176,0,0,0,172,203,187,170,170,170,170,171,187,188,140,220,203,187,170,170,187,187,204,205,220,189,203,186,170,153,170,170,187,204,221,203,203,186,169,153,153,153,154,171,188,219,187,186,153,136,136,136,137,154,171,188,187,186,169,136,119,119,120,136,154,187,203,171,169,136,119,102,102,119,137,154,187,186,186,152,119,102,85,102,120,137,171,187,170,153,135,102,85,85,102,120,153,187,186,169,152,118,85,68,85,103,137,170,187,170,153,135,101,84,69,86,120,153,171,186,170,152,118,101,85,86,103,137,154,187,171,169,136,118,101,86,103,120,154,171,186,186,153,135,118,102,103,120,137,171,187,187,186,152,136,119,119,120,137,154,188,187,187,170,153,136,136,136,137,154,171,203,188,187,170,153,153,153,153,154,171,204,203,220,187,170,170,153,154,170,187,204,220,205,204,203,187,170,170,171,187,204,221,204,221,204,204,187,187,187,204,204,222,237,140,203,187,187,187,187,187,187,204,205,176,0,0,0,223,238,237,220,204,188,204,204,220,205,126,255,238,221,204,204,205,222,238,239,253,239,237,220,204,187,187,187,204,238,255,237,238,220,187,170,170,170,187,205,223,254,222,220,186,169,153,153,154,171,205,239,237,236,186,153,136,119,136,154,187,221,237,221,203,153,135,118,103,120,154,188,206,221,219,169,135,102,85,102,120,154,205,237,204,186,152,118,84,69,103,137,171,205,220,203,169,118,84,52,69,103,154,188,221,204,186,151,101,68,52,86,121,171,205,236,203,169,135,101,68,86,120,154,188,221,204,186,152,118,101,86,103,137,171,206,221,220,186,152,119,102,119,137,171,205,237,221,203,170,152,135,120,137,154,188,223,237,237,203,170,153,137,153,170,188,222,239,222,221,204,186,170,170,171,188,222,254,253,254,221,204,187,187,187,204,221,255,255,223,239,237,221,204,204,205,238,254,255,253,239,238,254,221,221,237,238,255,255,255,141,221,221,221,221,221,237,254,239,255,208,0,0,0,255,255,255,255,254,237,221,221,221,204,143,255,255,255,255,253,254,239,255,255,253,255,255,255,254,205,220,221,221,255,255,239,255,255,220,204,188,188,221,221,255,255,255,254,221,187,170,170,187,204,223,255,255,255,220,186,152,136,137,171,204,222,255,255,253,186,152,119,119,137,171,221,255,255,254,203,152,101,85,103,137,172,223,255,255,219,168,117,68,69,103,138,205,255,255,253,186,135,84,51,69,120,171,206,255,239,203,168,117,67,52,87,138,189,255,254,253,202,151,101,68,69,120,171,221,255,239,220,169,135,101,85,103,154,206,255,254,255,219,169,135,118,119,154,188,255,255,239,252,203,169,136,136,154,188,223,255,254,254,220,203,170,170,170,188,222,255,255,223,254,220,220,187,187,204,223,255,255,253,255,254,237,221,220,222,254,255,255,255,223,255,255,239,238,239,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,140,220,220,222,254,255,255,255,255,255,240,0,0,0,222,238,221,220,204,204,204,204,204,204,143,255,238,221,221,221,221,221,221,254,237,255,254,221,204,204,204,204,205,221,239,221,238,220,203,187,171,187,188,205,222,237,222,221,203,170,153,153,170,188,205,238,221,221,203,169,136,136,137,154,188,221,237,205,203,169,135,119,119,136,154,188,222,221,220,186,135,102,85,103,137,171,205,221,205,202,152,118,84,69,103,138,172,222,220,219,169,135,84,51,69,120,154,205,221,205,202,152,117,67,52,86,137,172,206,220,220,186,135,101,68,85,120,154,205,237,205,203,169,135,101,85,103,138,188,222,220,220,186,152,135,118,119,137,171,205,238,205,220,186,153,136,136,137,171,205,223,220,237,203,186,169,153,154,171,188,239,254,206,221,204,187,170,187,187,204,222,255,237,237,237,220,204,204,204,221,222,255,255,222,238,221,221,221,221,222,238,255,255,253,238,238,238,238,222,238,239,255,255,255,141,221,221,221,221,221,237,238,239,255,224,0,0,0,223,237,220,204,187,187,187,188,204,204,174,254,237,204,187,187,187,204,205,222,237,238,221,203,186,170,170,171,188,205,222,221,220,203,170,153,153,153,170,187,205,220,221,203,169,152,136,136,137,154,188,205,204,203,169,136,119,119,119,137,154,188,220,204,186,152,118,102,102,119,137,171,188,204,186,152,118,101,85,102,119,137,171,204,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,204,187,169,136,118,101,85,102,120,154,189,219,203,169,135,118,102,102,120,154,188,221,204,186,153,136,119,119,120,137,171,205,220,203,186,153,136,136,136,153,171,205,237,205,203,186,169,153,153,154,171,204,222,236,221,204,187,170,170,170,187,205,222,254,206,221,204,203,187,187,188,205,222,255,252,238,221,220,204,204,204,221,238,255,255,157,204,204,204,204,204,221,222,238,255,224,0,0,0,239,255,237,221,220,204,204,204,204,204,143,255,238,221,220,204,204,221,221,238,237,255,253,220,203,187,187,188,204,221,238,223,254,220,187,170,170,170,187,204,222,253,239,220,186,153,152,153,154,171,204,222,222,236,186,152,135,119,136,154,171,205,237,221,203,168,119,102,103,120,154,188,221,221,219,169,135,101,85,102,120,154,189,221,221,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,237,205,186,152,118,101,85,103,137,171,222,236,220,186,152,119,102,103,136,171,205,238,221,203,169,152,135,119,136,154,188,239,237,221,203,170,153,152,153,154,188,222,254,221,220,203,186,170,170,171,188,222,255,253,254,220,203,187,187,187,204,222,255,255,222,221,221,220,204,204,205,222,255,255,253,254,237,221,237,221,238,255,255,255,255,140,220,221,205,221,222,222,239,255,255,224,0,0,0,255,255,255,255,253,221,220,221,204,204,127,255,255,255,255,253,255,255,255,255,253,255,255,255,253,221,221,221,223,255,255,223,255,255,221,203,187,188,204,223,255,255,255,253,220,186,170,170,187,204,223,255,255,255,251,186,152,136,137,171,204,223,255,255,220,186,151,119,119,137,171,205,255,255,253,203,152,101,85,103,137,188,223,255,255,220,168,117,68,69,103,138,189,255,255,253,186,135,84,51,69,120,171,223,255,255,220,152,117,67,52,86,138,205,255,255,253,202,151,101,68,69,120,172,223,255,239,220,169,135,101,85,104,154,206,255,255,254,203,169,135,119,120,154,188,223,255,255,253,203,169,152,136,154,188,223,255,253,255,221,187,170,170,170,188,222,255,255,223,253,221,203,187,187,205,223,255,255,253,255,223,221,220,220,221,223,255,255,255,223,255,254,239,239,223,255,255,255,255,253,255,255,254,255,255,255,255,255,255,255,140,205,221,237,255,255,255,255,255,255,240,0,0,0,239,255,239,238,221,221,221,221,220,221,127,255,255,254,237,238,222,239,255,255,255,255,255,254,220,204,205,221,238,239,255,239,255,253,220,203,187,188,205,207,255,254,255,253,219,186,170,170,171,204,222,255,255,253,220,170,153,137,153,171,188,223,255,253,220,186,152,119,120,137,171,205,255,239,237,202,152,118,86,103,137,188,222,254,222,203,169,118,84,69,104,154,188,239,238,237,186,135,100,35,70,120,171,221,254,254,219,169,118,67,36,87,138,189,222,237,253,186,152,101,68,86,121,171,205,255,221,220,185,135,102,86,120,154,189,239,253,253,203,169,136,119,120,154,188,222,255,222,220,187,169,152,137,154,172,222,255,254,254,221,203,170,170,170,187,205,239,255,223,237,220,204,187,187,188,221,255,255,253,255,239,221,220,204,221,221,239,255,255,223,255,238,238,221,222,238,255,255,255,253,255,255,255,237,221,255,255,255,255,255,124,204,204,221,220,206,239,255,255,255,224,0,0,0,188,204,187,187,170,170,170,186,187,187,141,237,220,203,187,187,187,187,204,205,236,205,204,187,170,170,170,170,187,204,221,204,220,186,169,153,153,153,170,187,204,220,188,186,169,136,136,136,137,154,171,205,187,187,169,136,119,119,120,137,154,188,204,187,169,136,119,102,103,120,137,154,188,187,186,152,119,101,85,102,120,137,171,203,171,169,135,101,85,85,102,120,154,188,186,186,152,118,85,68,85,103,137,171,203,171,169,135,101,84,69,86,120,154,188,186,186,152,119,101,85,85,103,137,171,203,171,169,136,118,101,85,102,120,154,188,203,186,169,135,119,102,102,120,137,171,204,187,186,153,136,119,119,120,137,171,188,203,203,186,153,136,136,136,137,170,188,220,188,203,186,169,153,153,153,170,187,221,219,204,187,186,170,170,170,170,188,205,237,205,204,204,187,187,187,187,204,205,239,236,221,221,204,204,203,204,205,222,238,254,140,204,203,187,187,187,204,204,222,222,192,0,0,0,172,186,170,153,153,153,153,170,170,187,155,204,187,170,170,169,170,170,187,204,203,188,186,169,153,153,153,153,170,187,188,187,186,169,152,136,136,136,153,170,171,203,171,169,152,136,119,120,136,153,154,187,170,169,152,135,119,119,119,136,153,170,186,170,152,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,102,119,136,154,186,170,169,152,135,119,119,119,136,153,171,186,186,153,152,136,119,120,136,153,171,187,171,186,169,152,136,136,136,153,170,188,186,187,170,169,153,153,153,153,170,188,204,188,203,186,170,170,170,170,171,188,205,203,204,203,187,186,170,171,187,188,205,220,155,187,170,170,170,170,170,187,188,205,176,0,0,0,188,204,187,187,170,170,171,171,187,188,141,237,204,203,186,186,187,187,204,205,220,205,204,187,170,170,170,170,187,188,205,204,203,186,169,153,153,153,170,171,188,220,188,186,153,136,136,136,137,154,171,188,187,186,169,136,119,119,120,137,154,171,203,187,169,136,118,102,102,119,137,154,188,186,186,152,118,101,85,102,120,137,171,203,171,169,135,102,85,85,103,120,154,187,186,186,152,118,85,68,85,103,137,171,187,170,169,135,101,84,69,86,120,154,171,186,186,152,119,101,85,86,103,137,171,187,171,169,136,118,101,85,103,120,154,188,186,186,153,135,119,102,102,120,137,171,203,187,170,153,136,119,119,120,137,170,188,203,203,170,153,136,136,136,137,154,188,220,188,203,170,153,153,153,153,170,188,205,203,204,187,170,170,169,170,170,187,204,221,189,204,204,187,186,171,187,188,205,222,220,237,204,203,187,187,204,204,205,222,238,140,187,187,187,187,187,187,204,205,221,192,0,0,0,239,255,239,237,220,204,204,204,204,204,127,255,255,255,221,220,222,222,255,255,253,255,255,254,221,204,188,204,222,238,255,239,254,237,203,187,171,187,188,221,239,254,239,237,203,170,153,154,171,188,222,239,237,237,203,169,152,136,137,154,188,222,253,238,219,169,135,119,119,137,171,205,239,237,236,186,135,102,85,103,137,171,205,238,222,203,152,118,68,69,103,138,188,223,237,220,185,134,84,51,69,120,155,205,237,221,203,152,117,67,52,87,137,188,222,253,221,186,135,101,68,70,120,155,205,239,238,203,169,135,101,86,103,138,188,223,254,221,203,169,135,119,119,137,172,206,239,222,220,186,169,136,136,137,171,205,239,253,237,220,187,169,169,154,187,205,239,255,239,237,204,203,187,187,188,205,222,255,237,255,237,220,204,204,204,222,239,255,255,223,255,221,221,221,222,222,239,255,255,253,255,255,254,238,254,255,255,255,255,255,141,222,220,237,221,222,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,253,220,204,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,252,203,206,255,255,255,255,255,255,252,187,170,171,188,223,255,255,255,255,252,186,152,137,171,205,255,255,255,255,253,186,135,102,120,171,205,255,255,255,255,219,151,84,69,121,172,255,255,255,255,252,168,100,34,70,138,207,255,255,255,255,202,150,66,36,104,172,255,255,255,255,252,169,117,67,87,154,207,255,255,255,255,203,168,118,103,137,189,255,255,255,255,253,203,169,136,154,188,255,255,255,255,255,252,203,170,171,189,255,255,255,255,255,255,253,204,187,205,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,220,221,255,255,255,255,255,255,255,240,0,0,0,223,255,223,221,221,204,219,204,204,204,143,255,254,253,221,204,204,221,221,222,253,255,255,221,204,187,187,188,221,221,255,223,253,221,203,186,170,170,172,204,255,253,255,221,202,169,153,153,154,171,205,239,223,221,203,169,136,136,136,153,172,205,253,222,203,169,135,118,119,120,154,188,223,237,236,169,135,102,85,103,120,155,190,255,221,202,152,118,84,69,103,137,172,223,253,203,169,134,84,52,69,120,154,189,239,220,186,152,101,67,52,86,137,172,222,252,219,169,135,101,68,85,120,154,189,223,221,187,168,119,101,85,103,138,172,223,252,220,186,152,119,118,119,137,171,206,239,205,203,170,152,136,136,137,171,205,223,253,237,203,186,169,153,154,170,205,255,255,222,220,203,186,170,170,187,205,222,255,253,253,221,204,203,187,204,221,254,255,255,206,237,237,220,204,221,223,255,255,255,252,255,255,239,239,239,254,255,255,255,255,141,221,222,239,223,223,255,255,255,255,240,0,0,0,255,255,237,220,204,204,204,204,204,221,175,255,237,220,204,187,188,204,205,222,237,255,237,204,187,170,170,171,188,205,222,239,253,203,170,153,153,153,170,188,205,221,238,219,169,152,136,136,137,154,188,205,221,220,169,152,119,119,119,137,154,188,221,220,186,152,118,102,102,119,137,171,205,220,203,152,118,101,85,102,119,137,172,205,204,169,135,101,85,85,102,120,154,189,220,186,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,189,220,186,152,118,101,85,85,103,137,172,221,204,169,135,118,85,85,102,120,155,205,236,203,169,135,118,102,102,120,154,188,238,204,186,153,135,119,119,120,153,172,222,252,204,186,153,136,136,136,154,171,206,255,221,204,186,169,153,153,154,171,205,239,253,237,204,187,170,170,171,187,205,239,255,222,237,220,203,187,188,204,221,239,255,253,254,237,221,220,221,221,222,255,255,255,173,221,221,221,221,221,238,239,255,255,240,0,0,0,255,255,255,255,239,221,221,221,220,204,143,255,255,255,221,222,237,221,221,255,253,255,255,253,204,204,204,203,205,222,239,223,255,236,219,187,170,171,187,204,223,253,255,253,203,169,153,153,170,188,221,239,223,237,203,169,136,136,136,154,188,204,253,254,219,169,135,118,119,120,154,188,222,223,252,186,135,102,85,103,120,155,189,254,239,202,152,118,84,69,103,137,171,206,237,220,169,134,84,51,69,104,154,188,237,237,186,152,117,67,52,87,137,172,221,237,220,169,135,101,68,86,120,154,189,255,255,203,169,135,101,86,103,137,188,223,237,220,186,152,135,118,119,137,171,206,255,206,203,186,153,136,136,137,171,221,255,255,253,203,186,169,153,154,171,205,223,255,223,238,204,186,170,171,187,204,223,255,254,253,221,204,187,204,204,205,255,255,255,221,222,221,220,205,204,221,239,255,255,252,255,237,221,221,255,255,255,255,255,255,140,205,205,221,238,222,254,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,253,223,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,207,255,255,255,255,255,255,255,255,203,187,188,205,255,255,255,255,255,255,202,153,153,171,207,255,255,255,255,255,202,151,119,137,188,255,255,255,255,255,220,151,84,70,138,191,255,255,255,255,253,185,116,18,87,155,255,255,255,255,255,203,151,66,36,121,189,255,255,255,255,253,185,134,68,87,155,255,255,255,255,255,252,169,135,119,138,207,255,255,255,255,255,220,170,153,154,207,255,255,255,255,255,254,204,187,187,207,255,255,255,255,255,255,255,255,204,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,143,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,223,253,220,221,205,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,204,207,223,255,255,255,255,255,255,204,187,188,207,223,255,255,255,255,253,204,186,169,170,188,223,255,255,255,255,204,169,136,136,154,189,223,255,255,255,251,185,135,102,120,154,205,255,255,255,253,202,135,84,69,120,171,223,255,255,255,219,168,100,34,70,138,189,255,255,255,252,186,134,66,36,104,171,205,255,255,255,219,168,117,68,86,138,189,255,255,255,255,202,152,118,102,121,172,255,255,255,255,252,186,152,136,137,171,207,255,255,255,253,252,186,170,154,172,204,255,255,255,255,255,220,203,187,204,223,255,255,255,255,255,221,223,220,204,254,255,255,255,255,255,255,255,255,207,223,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,125,220,220,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,203,204,255,255,255,255,255,255,255,251,169,154,188,255,255,255,255,255,255,203,152,119,137,191,255,255,255,255,255,252,168,84,70,138,207,255,255,255,255,255,202,116,18,71,171,255,255,255,255,255,252,167,66,36,122,207,255,255,255,255,255,202,134,68,88,172,255,255,255,255,255,254,186,135,120,155,255,255,255,255,255,255,252,186,153,171,207,255,255,255,255,255,255,252,204,204,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,240,0,0,0,204,203,186,170,169,153,154,170,171,188,156,204,187,170,170,170,170,170,187,188,220,204,187,170,153,153,153,153,170,187,204,187,187,169,152,136,136,136,153,154,187,203,187,169,152,136,119,119,136,137,170,187,186,186,152,135,119,119,119,120,137,171,187,170,153,135,118,102,102,119,136,153,171,186,169,136,118,102,102,102,119,136,154,170,154,152,119,102,85,86,102,119,137,171,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,171,169,169,135,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,171,186,169,152,119,118,102,102,119,136,154,187,170,169,136,135,119,119,119,136,154,187,186,186,153,136,135,119,120,136,153,171,204,187,186,153,152,136,136,136,153,171,188,203,203,186,169,153,153,153,154,170,188,204,188,203,186,170,170,170,170,171,188,205,220,220,203,187,187,186,187,187,204,221,238,156,203,187,186,170,170,187,187,204,221,208,0,0,0,223,255,255,237,238,237,221,220,205,220,127,255,255,254,237,221,221,253,255,238,253,255,255,222,221,204,204,221,221,255,255,239,255,221,220,204,187,204,189,221,239,254,255,253,220,187,170,170,187,205,222,239,223,254,220,186,153,153,153,171,204,222,253,253,236,202,152,135,120,137,171,205,255,222,253,202,152,118,102,120,154,188,221,254,221,203,169,134,84,69,120,154,206,223,238,220,186,151,100,35,70,121,171,221,253,238,219,169,118,66,36,103,154,188,222,239,238,202,152,117,68,86,137,171,222,254,238,220,186,136,118,102,120,155,205,239,221,253,203,169,152,119,136,154,188,223,255,223,221,203,169,153,153,154,188,222,255,253,238,221,203,170,170,171,204,222,255,255,223,253,220,204,188,203,204,206,255,255,253,239,254,221,220,205,205,221,255,255,255,207,238,221,238,222,222,255,255,255,255,252,255,255,223,255,254,239,239,255,255,255,124,205,204,221,238,239,255,255,255,255,240,0,0,0,255,255,255,255,252,207,223,220,203,205,127,255,255,255,255,253,255,255,255,255,255,255,255,255,255,253,223,255,255,255,255,255,255,255,255,253,204,221,255,255,255,255,255,255,255,220,204,188,205,223,255,255,255,255,255,220,187,170,187,188,255,255,255,255,255,252,169,152,137,171,205,223,255,255,255,253,186,135,102,120,171,207,255,255,255,255,203,151,84,69,121,188,223,255,255,255,252,185,100,34,70,154,207,255,255,255,253,186,134,66,35,104,172,223,255,255,255,220,169,117,68,87,155,207,223,255,255,253,203,168,118,103,138,188,255,255,255,255,255,187,169,136,154,188,207,255,255,255,255,252,203,187,171,188,207,255,255,253,255,253,223,204,204,205,221,255,255,255,255,255,255,253,255,205,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,125,221,223,253,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,223,255,253,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,205,221,204,255,255,255,255,255,255,253,220,187,187,207,255,255,255,255,255,252,203,169,170,188,221,255,255,255,255,255,203,151,119,137,172,223,255,255,255,255,252,168,100,70,138,189,255,255,255,255,255,185,116,18,71,155,207,255,255,255,255,203,151,66,36,121,189,255,255,255,255,221,186,134,68,88,156,207,255,255,255,255,219,169,135,120,154,223,255,255,255,255,255,188,186,153,171,189,255,255,255,255,255,223,204,187,188,206,255,255,255,255,255,255,239,220,204,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,141,255,255,255,223,223,255,255,255,255,240,0,0,0,207,237,204,237,187,203,187,204,188,204,109,255,237,220,204,189,204,220,238,255,252,237,223,205,204,203,204,205,205,222,255,207,237,236,203,186,187,187,204,204,221,252,221,220,186,186,169,154,170,187,205,239,220,220,203,169,152,136,153,155,188,205,253,188,203,170,152,119,119,137,170,189,205,220,204,186,152,118,86,103,137,171,204,220,188,187,168,118,68,69,103,154,188,206,220,219,185,135,100,35,70,120,171,188,236,204,186,152,118,67,52,87,137,187,205,219,203,186,151,101,68,86,120,155,189,221,205,203,169,135,102,86,120,154,187,223,235,220,186,169,135,119,120,138,187,205,253,204,219,187,153,152,136,154,170,188,223,220,221,188,187,170,153,170,171,188,206,254,223,253,204,187,170,187,187,204,220,255,236,255,220,220,204,187,188,205,237,237,254,222,238,237,205,204,204,221,221,239,239,236,239,254,237,237,222,237,238,254,255,255,108,204,221,221,221,188,204,237,221,239,192,0,0,0,255,255,255,255,237,221,221,222,239,255,207,255,255,221,220,204,205,222,221,255,255,255,255,236], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+779624);
/* memory initializer */ allocate([203,186,170,187,204,223,255,255,255,220,186,169,153,154,170,188,239,255,253,220,186,152,136,136,153,170,188,223,255,221,186,152,119,119,119,137,171,188,255,253,202,152,118,102,102,119,137,171,205,237,219,168,118,101,85,86,120,137,188,223,220,185,135,101,85,85,86,120,155,205,237,202,152,118,85,68,85,103,137,172,239,220,169,135,101,84,69,86,120,154,205,253,218,152,118,85,85,85,103,137,172,223,220,185,135,118,85,85,102,120,171,223,253,203,169,135,118,102,102,120,154,190,239,222,203,169,135,119,119,120,154,188,223,254,220,186,169,152,136,136,154,188,254,255,254,220,186,169,153,153,170,188,223,255,255,253,220,187,187,170,187,188,223,255,255,255,255,222,220,204,205,206,239,255,255,254,255,255,223,221,237,222,255,255,255,255,190,254,255,255,255,255,255,255,255,255,240,0,0,0,239,254,255,253,236,221,204,204,204,221,111,255,255,255,253,221,255,223,255,255,255,255,255,253,237,204,205,255,237,255,223,255,255,255,221,204,204,204,221,239,255,254,255,254,253,204,203,187,189,253,239,255,223,238,253,203,186,169,171,188,221,223,255,255,220,203,169,136,136,154,188,223,255,255,254,220,169,135,102,120,155,204,221,254,237,220,186,151,84,69,121,171,221,255,253,221,203,168,100,34,70,138,188,223,254,221,220,186,134,66,36,104,171,205,255,237,221,203,169,117,68,87,138,189,223,255,223,221,203,152,118,103,137,188,205,255,255,255,220,186,152,136,137,171,205,222,254,223,253,237,187,169,170,188,205,223,255,239,255,255,220,202,187,188,205,223,255,255,223,255,220,221,204,204,221,239,255,255,253,255,255,239,221,220,223,255,255,255,255,207,255,255,223,221,253,253,255,255,255,253,237,255,254,223,255,255,255,255,255,255,108,221,220,204,253,253,221,223,255,255,224,0,0,0,255,255,255,223,253,205,220,253,221,221,143,255,255,255,223,255,255,255,255,255,255,255,255,255,205,255,221,223,255,255,255,255,255,255,253,204,204,205,222,223,255,255,255,255,252,203,187,203,204,207,253,255,255,253,253,203,170,169,170,188,205,255,255,255,223,187,169,136,136,154,188,223,255,255,255,220,169,135,102,120,154,204,255,253,255,220,186,135,84,69,121,171,220,223,255,253,202,152,100,34,70,138,189,255,255,223,220,185,134,66,36,104,156,207,223,255,255,203,169,117,68,86,138,189,255,255,255,221,187,152,118,102,121,171,223,255,255,255,204,186,153,136,137,171,221,255,255,239,255,204,186,170,170,171,205,255,255,255,255,255,220,187,187,188,205,255,255,255,223,255,221,220,221,205,221,255,255,255,255,255,253,255,221,223,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,253,255,255,255,255,255,125,221,223,253,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,187,188,255,255,255,255,255,255,255,203,169,154,191,255,255,255,255,255,255,250,152,119,137,175,255,255,255,255,255,251,168,100,70,138,207,255,255,255,255,255,185,116,18,71,154,255,255,255,255,255,251,151,66,36,121,191,255,255,255,255,255,234,134,68,87,155,255,255,255,255,255,255,185,135,120,155,255,255,255,255,255,255,255,170,153,170,255,255,255,255,255,255,255,253,251,187,239,255,255,255,255,255,255,255,255,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,253,205,204,207,187,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,254,254,252,255,255,255,255,255,255,255,255,255,188,188,204,255,255,255,255,255,255,252,186,153,170,188,223,255,255,255,255,255,185,152,136,170,191,255,255,255,255,205,185,135,102,120,154,207,255,255,255,255,202,135,84,69,121,171,223,255,255,253,251,168,100,34,70,138,189,255,255,255,255,185,134,66,36,104,171,255,255,255,255,252,168,117,68,86,155,205,255,255,255,255,202,152,118,102,137,204,255,255,255,255,255,186,152,136,137,187,255,255,255,255,223,251,203,170,170,188,223,255,255,255,255,255,220,204,171,188,255,255,255,255,255,255,255,252,205,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,108,188,207,255,205,255,255,255,255,255,240,0,0,0,220,219,186,170,169,170,169,171,187,204,175,253,187,186,169,170,154,171,187,205,220,203,187,170,153,153,137,154,170,187,204,204,187,170,153,136,136,136,153,170,171,203,187,185,136,135,119,119,136,137,170,187,202,170,152,135,119,119,119,120,137,171,202,170,152,135,102,102,102,103,120,154,171,187,170,136,119,102,102,102,103,120,154,187,170,152,119,102,85,86,102,119,137,155,170,169,135,118,101,85,86,102,120,153,171,170,152,119,102,85,85,102,119,137,156,169,169,135,118,102,85,102,103,120,154,187,154,152,135,118,102,102,102,120,137,154,186,169,152,135,118,102,103,119,136,155,188,170,153,152,119,119,119,119,137,154,188,202,170,153,136,135,119,119,137,153,171,221,203,203,169,137,136,136,136,153,170,188,203,220,186,169,153,152,153,154,186,188,220,236,204,171,186,154,154,170,171,188,239,236,236,203,187,187,186,187,187,204,220,238,172,188,203,186,202,186,188,187,221,221,240,0,0,0,191,223,204,237,186,188,203,187,187,207,111,255,220,255,239,237,253,255,255,255,253,223,255,253,255,220,223,253,253,253,255,239,255,255,255,220,187,203,252,255,255,252,207,252,255,203,187,171,204,191,253,255,255,255,203,187,169,169,172,190,238,254,237,207,255,218,169,136,136,170,205,205,255,220,255,251,169,134,102,120,171,204,253,252,207,221,218,134,84,70,121,173,207,255,204,255,203,169,100,34,71,138,203,255,255,207,253,185,134,66,36,104,155,206,253,204,253,187,169,118,68,87,138,188,238,222,237,255,219,168,118,102,120,172,205,223,253,255,251,203,169,136,137,155,207,207,255,223,252,223,202,169,170,170,207,221,255,252,255,253,204,204,187,171,204,207,255,252,207,221,252,255,203,205,255,223,255,255,252,255,223,223,207,252,207,255,255,223,253,207,255,207,255,252,223,255,255,255,255,204,255,255,255,207,253,252,255,255,255,255,109,204,205,189,220,253,205,207,255,255,176,0,0,0,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,204,255,255,255,255,255,255,255,255,204,203,204,204,207,255,255,255,255,255,188,186,169,170,207,255,255,255,255,255,251,169,136,136,154,191,255,255,255,255,251,185,134,102,120,154,207,255,255,255,255,185,135,84,69,120,172,255,255,255,255,251,168,100,34,70,138,188,255,255,255,252,202,134,66,36,104,156,255,255,255,255,252,168,117,68,86,138,204,255,255,255,255,186,152,118,102,137,188,255,255,255,255,255,186,152,136,137,172,255,255,255,255,255,251,203,170,169,187,207,255,255,255,255,255,255,188,187,207,239,255,255,255,255,255,255,255,255,222,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,207,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,249,255,255,159,111,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,156,255,255,255,255,255,255,255,255,255,120,255,255,255,255,255,255,255,255,255,101,71,255,255,255,255,255,255,255,255,148,18,88,255,255,255,255,255,255,255,248,82,20,255,255,255,255,255,255,255,255,248,84,120,159,255,255,255,255,255,255,255,223,135,255,255,255,255,255,255,255,255,255,153,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,249,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,152,152,255,255,255,255,255,255,255,255,249,116,87,159,255,255,255,255,255,255,250,133,18,89,159,255,255,255,255,255,255,249,82,20,137,255,255,255,255,255,255,255,151,84,103,255,255,255,255,255,255,255,255,248,137,159,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,255,252,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,246,255,255,255,255,95,255,255,255,246,246,111,104,245,255,255,255,255,246,102,246,255,111,255,255,255,246,255,255,255,255,246,111,255,255,255,255,255,255,255,102,246,111,255,255,255,255,111,255,111,102,102,255,111,246,255,255,111,207,255,111,255,246,111,111,255,111,255,246,86,246,246,86,255,255,102,255,255,255,255,255,255,101,86,111,255,246,255,111,255,255,246,102,246,255,102,111,255,111,255,111,246,255,102,111,86,246,255,255,255,255,255,255,246,111,70,245,111,111,255,245,107,175,255,95,255,255,111,111,246,255,255,255,255,111,246,102,245,255,95,255,255,111,255,255,255,245,85,246,246,255,255,111,255,255,111,246,255,246,246,255,255,255,255,111,255,255,255,246,111,111,255,255,255,255,255,255,255,255,111,246,255,111,255,255,255,111,246,255,246,255,255,255,255,255,255,255,255,255,246,255,255,255,255,255,246,255,255,255,111,111,255,255,255,255,240,0,0,0,255,255,255,159,255,255,255,249,255,159,79,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,255,255,249,255,255,255,255,255,255,152,152,255,255,255,255,255,255,255,255,249,248,103,143,255,255,255,255,255,255,248,151,84,71,159,255,255,255,255,255,255,143,116,18,87,143,249,255,255,159,255,159,152,82,36,127,255,255,255,255,255,255,255,247,84,88,255,255,255,255,255,255,255,255,247,248,159,159,255,255,255,255,255,255,249,255,137,255,159,255,255,255,255,255,249,249,255,255,255,255,255,255,255,255,255,249,249,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,249,153,255,159,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,186,255,255,255,255,255,255,255,255,255,170,186,255,255,191,255,255,255,255,255,168,119,154,255,255,255,255,255,255,255,248,84,69,154,255,255,255,255,255,255,250,132,34,71,175,255,255,255,255,255,255,168,66,20,122,223,255,255,255,255,255,255,150,68,89,175,255,255,255,255,255,255,251,151,120,171,255,255,255,255,255,255,255,191,250,191,255,255,255,255,255,255,255,255,251,191,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,255,251,255,255,255,255,255,255,255,240,0,0,0,255,251,255,255,255,255,255,248,255,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,247,255,255,255,255,255,255,255,255,255,247,255,255,255,255,255,255,255,255,246,255,255,255,255,255,255,255,255,255,247,118,247,255,255,255,255,255,239,255,255,111,103,111,255,255,255,255,255,255,255,247,247,85,95,255,255,255,255,255,255,247,85,68,70,127,127,255,255,255,255,247,245,84,68,87,102,127,255,255,255,255,246,117,68,52,70,111,255,255,255,255,255,127,85,69,69,86,255,255,255,253,207,111,127,117,87,86,127,255,255,255,255,255,255,255,118,102,127,255,255,255,255,255,255,247,127,247,127,255,255,255,255,255,255,255,255,247,255,255,247,255,255,255,255,255,255,111,127,255,247,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,127,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,143,255,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,167,120,255,255,255,255,255,255,255,255,252,68,69,143,255,255,255,255,255,255,255,115,34,72,255,255,255,255,255,255,255,247,66,36,127,255,255,255,255,255,255,255,134,67,76,255,255,255,255,255,255,255,255,248,119,143,255,255,255,255,255,255,255,255,248,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,79,249,255,255,255,255,255,255,255,255,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,143,255,255,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,207,255,255,255,247,127,255,255,255,255,255,255,255,248,117,103,120,255,255,255,255,255,255,249,118,67,70,143,255,255,255,255,255,255,246,99,35,88,143,255,255,255,255,255,255,175,67,35,87,255,255,255,255,255,252,255,133,84,69,143,255,255,255,255,255,255,143,247,85,104,255,255,255,255,255,255,255,255,248,191,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,79,248,248,255,255,255,255,255,255,255,240,0,0,0,255,255,251,255,255,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,191,191,255,255,255,255,255,255,255,255,250,175,255,255,255,255,255,255,255,255,249,135,136,159,255,255,255,255,255,255,170,135,102,120,175,191,255,255,255,255,191,167,84,69,106,255,255,255,255,255,255,247,100,34,70,137,223,255,255,255,251,255,118,66,36,104,191,255,255,255,255,255,249,117,68,87,169,255,255,250,255,255,255,151,118,103,143,255,255,255,255,255,255,175,186,152,138,187,255,255,255,255,255,255,175,250,175,191,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,207,255,255,255,255,255,79,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,249,159,255,207,153,255,63,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,120,143,255,255,255,255,255,255,255,255,100,71,255,255,255,255,255,255,255,250,132,34,72,255,255,255,255,255,255,255,247,66,20,127,255,255,255,255,255,255,255,247,68,111,255,255,255,255,255,255,255,255,153,136,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,239,255,255,238,239,255,255,63,255,254,238,238,239,255,255,255,255,255,255,255,255,255,254,238,238,238,238,238,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,255,255,254,238,238,238,238,238,238,238,238,238,238,238,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,246,255,255,255,255,255,255,255,255,255,100,86,255,255,255,255,255,255,255,255,243,18,70,255,254,238,238,238,238,238,238,82,36,238,238,238,238,238,238,238,238,238,68,110,238,238,238,238,238,239,255,255,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,254,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,131,71,255,255,255,255,255,255,255,255,244,18,79,255,255,255,255,255,255,255,247,66,36,255,255,255,255,255,255,255,255,247,68,119,255,255,255,255,255,255,255,255,253,143,255,255,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,156,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,255,255,255,255,255,255,255,255,255,240,0,0,0,190,221,236,221,221,220,222,238,255,255,205,254,253,221,220,205,221,238,239,255,255,222,253,204,204,187,187,204,205,255,255,253,237,220,187,170,170,170,187,205,255,255,223,236,187,169,153,153,153,171,205,255,253,236,187,169,136,119,120,137,171,205,254,237,203,169,135,118,102,119,137,171,205,252,220,169,135,118,101,102,103,137,188,223,220,202,152,118,85,85,86,120,154,205,221,219,169,135,101,84,85,86,121,172,221,220,186,151,101,84,68,85,103,138,189,222,203,169,118,101,84,85,102,121,171,205,237,202,152,118,85,85,86,120,154,189,222,220,185,135,102,101,102,119,137,172,220,239,203,169,135,118,102,119,137,171,205,223,254,203,169,136,119,120,137,171,204,237,255,237,203,169,153,153,153,171,188,223,223,255,237,204,186,170,170,171,188,222,253,255,255,254,220,203,187,188,204,238,239,239,255,255,254,238,204,221,221,223,239,255,223,255,254,255,221,221,221,221,222,222,176,0,0,0,173,203,187,188,203,252,219,205,255,255,207,255,189,204,220,219,255,255,255,255,255,207,204,220,187,171,186,188,205,221,221,251,221,251,171,170,154,170,170,188,255,255,207,252,203,186,153,153,153,171,188,207,251,219,186,169,152,135,120,136,170,188,223,207,251,169,136,119,119,119,137,170,191,207,204,169,152,118,101,86,103,137,171,252,203,218,168,118,101,85,86,120,154,188,203,251,169,135,101,68,69,86,121,155,204,191,186,151,117,84,68,86,104,154,190,251,219,169,134,101,68,69,103,137,170,204,223,187,152,118,85,85,102,120,154,172,220,252,169,135,102,102,102,120,138,171,187,252,188,185,135,118,119,119,137,171,220,188,252,187,169,152,136,136,153,154,203,203,255,252,202,170,153,153,169,155,188,205,223,255,207,187,186,170,170,187,188,207,221,255,255,253,204,203,187,204,187,219,255,207,255,255,221,253,191,220,203,191,223,252,255,255,254,237,255,203,188,220,188,188,160,0,0,0,205,223,221,221,220,221,221,222,255,255,223,255,254,221,220,204,205,222,239,255,255,239,253,220,187,187,187,187,205,223,255,253,254,220,187,170,154,170,171,205,239,255,223,220,186,169,152,136,137,170,189,223,253,236,186,153,136,119,119,137,154,188,239,221,203,153,135,118,102,103,136,171,205,253,219,169,135,102,101,86,103,137,171,237,220,186,152,118,85,85,86,119,138,189,221,203,168,118,101,85,85,102,120,171,205,220,185,135,101,85,68,85,103,137,189,221,203,168,118,101,85,85,102,120,155,205,220,186,152,118,85,85,86,120,154,188,222,219,169,135,102,101,102,103,137,171,221,237,203,169,135,118,102,119,137,155,204,222,236,203,169,136,119,120,137,154,188,237,255,221,186,169,152,136,137,170,188,221,223,255,253,187,170,170,170,171,188,221,237,255,254,253,203,187,187,188,188,221,239,239,255,255,254,220,204,204,204,222,223,254,223,255,255,254,221,220,205,221,222,222,192,0,0,0,238,238,238,222,238,238,221,222,238,238,238,238,237,221,221,222,238,238,238,238,238,238,238,238,238,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,221,221,221,221,221,221,221,221,77,221,221,221,221,222,238,238,227,238,228,238,238,238,238,238,238,238,238,238,94,238,238,238,238,238,238,238,238,238,238,62,78,238,238,238,238,238,238,238,68,68,77,221,221,221,221,221,221,221,68,77,221,212,77,221,221,221,221,221,212,211,61,77,221,221,221,221,221,222,238,228,228,238,238,238,238,238,238,238,238,238,78,238,68,238,228,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,228,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,237,237,238,238,238,238,238,238,238,238,238,78,238,238,238,238,238,237,237,237,238,224,0,0,0,173,221,221,221,221,220,253,255,255,255,221,255,223,221,204,204,204,223,255,255,255,239,221,220,204,187,187,188,204,223,255,254,253,236,187,170,154,170,171,205,223,255,205,205,186,169,152,136,153,154,205,223,253,220,186,169,136,119,120,137,154,189,255,204,203,169,135,118,102,119,137,154,223,252,219,185,135,102,101,102,103,137,172,221,221,186,152,118,85,85,86,120,138,205,237,203,168,118,101,85,85,102,120,155,222,220,186,135,101,85,69,85,103,138,189,205,203,168,118,85,84,85,86,120,171,205,237,186,152,118,85,85,86,120,154,188,205,251,169,135,102,101,102,103,137,171,205,255,219,168,135,118,102,119,137,171,204,223,253,202,152,136,119,119,137,154,188,237,255,253,203,169,152,136,153,170,188,221,223,255,220,203,170,170,154,171,188,206,237,255,255,253,204,187,188,187,204,221,255,239,255,255,255,220,204,205,220,223,255,239,223,255,254,252,236,205,204,221,205,221,176,0,0,0,172,203,187,187,186,171,187,204,204,239,188,221,204,203,187,187,187,188,204,238,254,204,204,187,170,170,170,170,171,204,222,236,204,186,170,153,152,153,154,171,188,221,188,186,169,152,136,136,136,153,171,188,219,187,169,152,135,119,119,120,153,171,204,187,170,152,119,118,102,119,120,154,172,203,186,152,135,102,102,102,103,120,154,187,187,169,135,118,101,85,102,119,137,171,187,186,152,118,101,85,85,102,120,154,171,187,153,135,102,85,85,86,103,137,170,171,186,152,118,101,85,85,102,120,154,187,187,169,135,118,101,85,102,119,137,171,187,186,152,135,102,102,102,103,136,154,187,204,170,152,119,118,102,119,120,153,171,188,203,169,152,135,119,119,136,153,171,187,204,203,169,152,136,136,136,153,170,188,189,221,187,170,153,153,153,153,170,187,204,238,220,203,186,170,170,170,171,188,205,207,254,221,204,187,186,187,187,188,205,220,206,221,220,203,187,187,187,187,187,204,160,0,0,0,155,187,186,170,170,170,171,187,204,221,188,220,204,187,186,170,170,171,203,205,238,189,204,187,170,153,153,154,170,188,205,219,204,170,169,153,136,137,153,154,188,220,188,186,153,152,136,119,136,137,154,188,203,186,169,136,135,119,119,120,137,154,187,171,169,136,119,118,102,103,120,137,171,186,170,152,119,102,102,102,103,120,154,186,170,153,135,118,102,102,102,103,137,170,170,169,136,118,102,85,86,102,120,137,170,170,152,119,102,85,85,102,103,136,154,170,169,136,118,102,85,86,102,120,137,170,186,152,135,102,102,102,102,119,136,154,171,186,152,119,102,102,102,103,136,154,170,186,169,136,119,102,102,119,120,153,171,171,187,169,136,119,119,119,120,137,171,187,204,186,169,136,136,136,136,137,154,188,188,203,186,153,153,136,137,153,170,187,203,221,220,186,169,153,153,170,170,187,205,190,238,204,203,186,170,170,187,188,205,219,205,236,187,187,186,170,170,171,187,188,144,0,0,0,155,186,170,170,153,153,170,170,187,204,187,203,187,170,170,170,170,170,187,204,220,188,187,170,153,153,153,153,170,171,204,202,187,170,153,152,136,136,137,154,171,203,171,170,153,136,135,119,136,136,154,171,186,170,153,136,119,119,119,120,137,154,170,170,169,136,119,118,102,119,119,137,154,170,169,152,119,118,102,102,103,120,137,170,154,152,135,118,102,102,102,119,136,154,153,169,136,118,102,102,102,102,119,137,169,154,152,119,102,101,86,102,103,120,154,153,169,135,118,102,101,102,102,119,137,169,170,152,135,102,102,102,102,119,136,154,154,169,136,119,102,102,102,119,120,153,170,170,153,136,119,102,102,119,120,137,154,170,186,153,136,119,119,119,120,137,154,170,187,170,153,136,135,120,136,137,154,171,171,203,170,153,136,136,136,137,154,171,186,205,203,170,169,153,153,153,154,171,188,189,220,203,186,170,170,170,170,187,188,203,204,203,186,170,153,153,153,170,170,187,144,0,0,0,155,187,186,170,170,170,170,187,188,221,204,203,188,186,170,170,170,171,172,205,222,189,203,170,153,153,153,153,170,187,204,202,188,186,153,152,136,137,137,154,187,204,171,170,153,136,135,119,136,137,154,187,186,186,153,136,119,119,119,120,137,170,204,170,169,136,135,118,102,119,120,137,171,186,185,152,119,102,102,102,119,120,153,170,170,153,135,118,102,102,102,103,136,154,170,169,135,118,102,101,86,102,120,137,170,170,152,135,102,101,85,102,103,136,154,170,169,136,118,102,85,86,102,120,137,170,170,153,135,118,102,102,102,119,136,154,170,169,152,119,102,102,102,103,120,154,186,171,169,135,119,102,102,119,120,153,170,187,186,153,136,119,119,119,120,137,171,186,187,170,153,136,135,136,136,137,154,171,189,187,186,169,152,136,136,153,154,171,187,221,203,171,169,153,153,154,170,188,188,189,220,187,187,170,169,170,170,187,220,220,190,220,187,170,170,170,170,170,171,187,144,0,0,0,156,187,187,170,170,170,171,187,204,222,203,236,204,187,170,170,171,187,188,221,238,189,203,186,170,153,153,170,171,188,206,219,203,186,169,153,136,137,153,170,188,220,188,186,169,152,136,136,136,153,170,188,203,187,169,136,135,119,119,120,137,171,188,171,169,152,119,118,102,119,120,153,171,186,186,152,135,118,102,102,103,120,154,187,170,153,135,118,102,85,102,103,137,154,170,169,136,118,102,85,85,102,120,153,170,170,152,135,102,85,85,86,103,136,154,170,169,136,118,101,85,86,102,120,153,170,171,153,135,118,102,86,102,119,137,154,171,186,152,119,102,102,102,119,136,154,170,187,169,152,119,118,102,119,120,153,171,187,203,169,136,119,119,119,136,153,170,187,204,186,169,152,136,136,136,153,170,188,188,220,186,169,153,136,153,153,170,187,203,205,220,187,170,153,153,170,170,187,205,189,237,204,187,187,170,170,171,188,204,220,189,220,203,187,170,170,170,187,187,188,144,0,0,0,189,237,221,221,221,222,238,255,255,239,191,255,253,221,221,221,238,255,255,255,255,239,237,220,204,204,204,221,255,255,255,253,254,220,203,187,187,187,204,239,255,255,222,220,187,170,153,153,170,188,223,255,237,236,203,169,152,136,136,154,189,239,255,221,203,169,136,118,103,120,154,205,239,253,220,186,152,118,85,86,120,155,205,238,222,203,152,118,84,68,86,121,172,222,237,220,185,135,84,68,69,103,154,205,237,222,203,152,101,68,68,86,120,171,222,222,252,185,135,85,68,69,103,154,188,237,238,219,168,118,85,85,103,137,171,206,239,253,202,152,118,102,103,120,155,189,237,255,253,186,152,135,119,136,154,188,222,223,254,220,186,153,153,153,154,187,205,237,255,255,236,187,170,170,170,187,205,254,239,255,255,236,220,187,187,204,204,222,253,255,255,255,254,237,220,205,221,222,239,239,255,255,255,255,238,254,222,238,255,255,207,255,255,238,221,222,254,221,222,238,176,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,191,221,220,204,188,205,221,223,255,255,205,223,220,203,203,203,204,205,255,255,255,222,220,204,187,186,171,187,205,255,255,252,221,187,170,153,153,154,171,205,223,255,220,187,169,152,136,136,137,171,188,223,252,204,169,152,135,119,119,137,171,189,255,204,186,152,119,102,102,119,137,171,221,252,202,153,135,102,85,86,103,137,171,255,204,169,135,102,85,85,86,120,154,190,236,186,152,118,85,84,85,103,137,171,205,204,169,135,101,84,69,86,120,154,188,221,203,152,118,85,85,85,103,120,171,204,204,186,151,118,85,85,102,120,154,188,223,219,169,135,118,102,102,119,137,171,205,221,219,168,135,119,103,119,137,170,189,255,221,202,169,136,119,136,137,154,188,220,255,253,203,170,153,137,153,170,188,207,207,255,253,203,186,170,170,171,188,220,255,255,255,253,203,187,187,187,204,205,223,255,255,255,254,220,204,204,221,204,254,223,223,255,255,221,204,205,204,207,221,221,192,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,191,221,237,237,221,222,238,255,255,255,206,255,255,254,222,238,239,255,255,255,255,239,254,221,204,204,204,221,222,255,255,254,254,237,204,187,187,187,205,239,255,255,222,221,187,170,153,153,171,205,237,255,254,253,203,169,152,136,136,154,189,239,255,223,220,185,135,118,103,120,154,206,255,254,221,186,151,118,85,86,120,155,206,255,237,219,168,118,84,68,86,121,172,239,238,236,185,134,84,68,69,103,154,205,254,238,203,152,101,68,68,86,121,172,239,253,236,185,135,85,68,69,103,154,205,253,239,219,168,118,85,85,103,137,172,223,238,253,203,152,118,102,103,120,171,205,238,255,253,186,152,135,119,136,154,188,223,239,255,237,186,169,153,153,170,188,221,238,255,255,220,203,170,170,171,188,205,238,239,255,255,237,204,204,204,204,205,239,254,255,255,255,237,221,221,221,221,239,255,255,255,255,255,255,238,254,239,255,255,255,191,239,255,238,237,238,237,254,254,238,176,0,0,0,172,203,187,187,187,171,187,204,205,222,188,221,204,187,187,187,187,188,205,223,253,188,203,186,170,170,170,170,187,205,238,235,203,186,169,153,153,153,170,171,205,221,188,186,153,136,136,136,137,154,171,205,203,186,169,136,119,119,119,136,154,188,204,187,169,152,119,102,102,119,136,154,188,203,186,152,119,102,101,102,119,137,171,187,187,169,135,102,85,85,102,120,153,171,186,186,152,118,101,84,85,103,120,154,187,187,169,135,102,84,69,86,119,137,171,187,186,152,118,101,85,85,103,120,154,187,187,169,135,118,101,85,102,120,137,171,187,186,153,135,118,102,102,119,137,170,187,204,186,152,135,119,119,119,136,154,171,188,203,186,153,136,135,120,136,154,171,203,205,203,186,153,152,136,153,154,171,188,205,221,203,186,170,153,153,170,171,188,220,222,221,203,187,186,170,170,187,204,221,206,238,221,204,203,187,187,187,204,221,236,189,221,204,204,187,187,187,187,204,204,160,0,0,0,155,186,169,153,153,153,154,171,188,204,187,204,187,170,170,153,169,170,187,189,220,171,186,169,153,153,153,153,154,187,205,202,186,169,153,136,136,136,137,154,187,203,171,169,152,136,136,119,136,137,154,187,185,169,152,135,119,119,119,120,137,170,187,154,152,135,119,102,102,119,120,137,170,169,169,136,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,153,135,118,102,85,86,103,120,137,170,154,152,119,102,101,85,102,119,136,154,153,169,136,118,102,101,102,103,120,137,169,153,152,135,118,102,102,102,119,136,154,154,169,152,119,102,102,102,119,136,153,170,170,169,136,119,119,119,119,120,137,170,170,186,153,136,119,119,119,136,137,154,170,187,186,153,136,136,136,136,137,154,171,187,203,170,169,152,136,137,153,154,171,187,204,187,170,169,153,153,153,154,171,188,189,221,203,187,170,170,170,170,187,188,219,189,203,186,170,170,170,170,170,171,187,160,0,0,0,155,170,169,153,153,153,154,170,187,204,187,203,186,170,169,153,154,170,171,204,220,171,170,169,153,153,153,153,154,171,188,202,186,153,152,136,136,136,137,154,171,203,170,169,136,136,119,119,120,137,154,171,185,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,119,120,137,170,169,153,135,119,102,102,102,103,120,137,170,153,152,119,102,102,102,102,119,136,154,169,153,135,118,102,102,102,102,120,137,170,153,152,119,102,101,86,102,103,136,154,153,153,135,118,102,102,102,103,120,137,169,154,152,119,118,102,102,102,119,136,154,170,169,136,119,118,102,102,119,120,137,170,170,153,136,119,119,103,119,120,137,154,170,170,153,136,119,119,119,120,137,154,170,187,170,153,136,136,136,136,136,153,171,171,187,170,153,152,136,136,153,153,170,187,204,203,186,169,153,153,153,154,171,187,189,220,203,187,170,170,170,170,187,188,203,205,203,187,170,170,153,170,170,171,187,160,0,0,0,155,186,170,169,170,170,171,187,188,205,171,204,187,187,170,170,186,188,205,237,236,188,187,186,169,169,169,170,171,188,222,219,187,186,153,153,153,153,154,171,188,220,171,170,153,136,136,136,136,153,171,204,186,186,153,136,135,119,119,120,137,171,204,170,169,136,119,102,102,119,120,154,187,186,170,152,119,102,102,102,103,137,154,186,170,153,135,102,85,85,102,119,137,171,170,170,152,118,101,85,85,103,120,154,186,170,153,135,102,85,85,86,103,137,170,186,169,152,118,101,85,86,103,120,154,186,171,169,135,118,101,85,102,120,137,170,171,186,152,135,102,102,102,119,137,154,170,187,169,152,135,119,103,119,136,154,171,172,203,170,152,135,119,120,137,153,170,186,204,203,169,153,136,136,137,153,170,187,172,204,187,170,153,153,153,154,171,187,203,206,220,203,186,170,170,170,170,187,204,190,237,220,204,187,187,187,170,188,204,219,173,221,187,187,187,186,170,187,187,188,144,0,0,0,155,187,170,170,170,170,187,188,205,205,171,204,203,187,170,170,187,188,205,222,253,188,187,170,170,154,170,170,187,205,222,219,187,170,153,153,137,153,154,171,205,220,187,170,153,136,136,136,137,154,187,204,202,186,153,136,119,119,119,136,154,187,204,171,169,136,119,102,102,119,136,154,188,202,170,152,119,102,101,102,103,137,170,203,170,153,135,102,85,85,102,119,137,171,186,170,152,118,101,85,85,103,120,154,187,170,169,135,102,85,69,86,103,137,171,187,186,152,118,101,85,85,103,120,154,187,187,169,135,118,101,85,102,120,137,171,187,186,153,135,118,102,102,119,137,154,187,188,186,152,135,119,119,119,136,154,171,188,203,186,153,136,119,120,136,153,171,187,205,203,170,153,152,136,137,153,170,187,189,237,203,186,169,153,153,170,170,188,203,222,237,204,187,170,170,170,187,187,205,189,254,237,204,204,187,187,187,188,204,219,173,221,204,204,187,187,171,187,187,188,144,0,0,0,175,223,223,253,221,205,223,253,255,221,159,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,223,255,255,255,255,255,255,255,223,223,205,255,255,255,255,255,255,255,253,223,204,205,253,255,255,255,253,255,255,253,186,136,172,223,253,255,255,255,255,255,202,116,70,156,255,255,255,255,255,223,252,133,34,71,223,255,255,253,255,255,255,216,66,19,123,223,255,255,255,255,255,220,166,67,88,207,253,255,255,255,255,255,253,168,120,171,223,255,255,255,255,255,255,252,219,188,223,223,255,255,255,255,255,252,255,221,253,223,223,255,253,255,255,255,255,255,255,223,255,255,253,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,175,255,255,255,253,223,221,253,255,221,160,0,0,0,223,255,253,221,205,222,221,255,255,255,207,255,255,237,220,204,205,239,255,255,255,255,238,221,187,186,187,189,221,255,255,255,253,204,186,170,153,170,187,206,255,255,255,236,186,153,136,137,154,171,206,255,254,252,202,152,135,119,120,153,171,221,255,221,187,152,119,102,102,119,153,188,223,237,203,169,135,102,85,86,120,154,188,255,252,185,135,101,85,85,86,120,171,207,252,219,168,118,85,68,69,103,138,188,237,220,202,135,101,84,69,86,120,155,206,254,219,169,118,85,68,85,103,137,188,221,220,202,152,118,85,85,102,120,171,207,237,253,186,135,118,102,102,120,154,190,239,223,203,169,136,119,119,120,154,188,207,254,255,220,169,152,136,136,154,188,223,239,255,254,203,186,153,154,170,188,205,255,255,255,253,205,203,187,187,188,239,255,255,255,255,254,237,220,220,221,207,255,255,254,255,255,223,239,221,238,255,222,255,255,191,255,253,255,254,237,254,255,255,255,192,0,0,0,223,238,237,221,204,204,221,238,239,255,222,255,237,204,204,188,204,221,238,255,255,239,237,204,187,170,170,187,205,222,255,254,253,203,170,169,153,153,171,188,239,255,221,203,170,152,136,136,137,170,188,239,253,219,169,152,119,119,119,137,155,205,238,221,186,152,119,102,102,103,137,171,206,236,203,152,119,102,85,86,103,137,188,222,204,169,135,102,85,85,86,120,154,205,220,186,152,118,85,84,85,103,137,171,205,203,169,135,101,84,69,86,119,154,189,220,202,152,118,85,85,85,103,137,171,221,220,185,135,102,85,85,102,120,154,205,221,203,169,135,102,102,102,120,154,188,237,237,203,153,135,119,119,120,137,171,205,222,236,186,153,136,135,136,137,171,205,239,255,221,187,169,153,153,153,171,204,239,255,255,220,203,186,170], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+789864);
/* memory initializer */ allocate([170,187,205,239,255,255,255,237,204,187,187,188,220,222,255,239,255,255,238,237,220,221,237,239,255,255,223,255,254,237,221,221,221,221,239,255,208,0,0,0,205,205,220,204,205,222,221,255,255,255,221,254,220,204,203,204,205,221,255,255,255,223,221,203,187,186,187,188,205,239,239,253,252,203,169,169,153,154,171,205,223,254,206,203,169,152,136,136,153,171,205,239,252,203,170,152,119,119,119,137,171,206,254,204,186,152,119,102,102,119,137,172,222,236,202,152,119,101,85,86,119,154,188,221,204,169,135,101,85,85,86,120,154,205,236,186,152,118,85,68,85,103,137,171,221,204,185,135,101,84,69,86,120,154,189,220,203,152,118,85,85,85,103,137,171,221,220,186,152,118,85,85,102,120,154,205,221,220,185,135,118,102,102,120,153,187,223,222,203,169,136,119,119,120,137,171,205,221,237,187,169,152,136,136,137,170,189,221,255,237,203,170,153,153,154,171,188,222,239,255,253,204,186,170,170,171,188,221,238,255,255,237,220,203,188,203,205,205,255,239,255,255,255,221,236,220,204,239,239,255,207,255,255,253,237,221,220,221,221,223,208,0,0,0,191,238,237,239,237,238,254,239,254,255,174,255,254,238,238,255,255,255,255,255,255,255,253,221,221,221,221,238,255,255,255,254,254,237,204,203,187,204,222,239,255,255,255,221,203,170,170,170,187,205,239,255,254,254,203,169,152,136,137,171,205,255,255,238,220,169,136,119,119,137,171,222,255,255,253,186,151,118,85,102,137,172,223,254,238,219,168,118,84,69,103,138,189,255,238,237,186,135,84,51,69,104,155,223,254,255,219,168,117,67,52,86,137,188,239,238,253,202,135,101,68,69,104,155,206,255,255,236,185,134,101,85,103,138,189,239,255,255,220,169,135,102,119,137,171,207,255,255,254,203,169,136,136,137,171,205,239,255,255,254,203,170,153,154,170,188,222,255,255,255,254,220,187,187,187,204,222,255,255,255,255,255,237,221,205,221,222,255,255,255,255,255,255,239,239,239,239,255,255,255,255,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,239,255,192,0,0,0,174,221,237,221,221,221,221,254,238,255,189,255,238,237,237,238,239,254,255,255,254,238,237,221,204,204,221,222,238,255,255,238,238,220,203,187,187,188,221,238,255,254,222,220,187,170,153,170,187,205,239,255,237,221,203,169,152,136,137,171,205,239,254,221,219,169,135,119,119,137,171,206,255,237,220,186,151,118,85,103,137,172,222,254,221,203,168,118,84,69,103,138,188,239,221,220,185,135,84,51,69,104,155,205,238,222,203,168,117,67,52,86,137,188,223,221,237,186,151,101,68,69,120,154,205,238,222,220,185,135,101,85,103,137,188,222,221,238,219,169,135,102,119,137,171,205,253,222,237,203,169,136,136,137,154,188,223,221,254,237,203,170,153,153,170,188,222,254,223,255,237,204,187,171,187,188,222,239,221,255,255,238,220,204,204,205,221,238,254,223,255,255,238,237,221,221,221,222,254,237,255,255,255,239,238,238,254,255,255,254,157,238,221,222,221,221,221,221,254,237,176,0,0,0,171,170,169,153,153,153,153,154,171,204,187,203,186,169,153,153,153,170,171,188,220,171,186,169,153,136,153,153,154,171,204,202,186,169,152,136,136,136,137,154,171,187,170,169,152,135,119,119,136,137,153,171,186,169,152,135,119,119,119,120,137,154,170,154,152,135,119,102,102,119,120,137,170,169,153,135,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,85,102,103,120,137,169,153,152,119,102,101,86,102,119,136,154,153,153,135,118,102,101,102,103,120,137,170,153,152,135,118,102,102,102,119,137,154,169,169,136,119,118,102,103,119,136,154,170,170,153,136,119,119,119,119,120,137,170,170,169,153,136,119,119,119,136,137,154,186,171,170,153,136,136,136,136,153,154,171,171,203,169,153,152,136,137,153,170,171,203,188,186,170,169,153,153,153,170,187,204,188,204,203,186,170,170,170,171,187,204,220,172,187,186,170,153,153,170,170,171,204,160,0,0,0,155,170,169,153,153,153,153,154,171,188,171,203,186,170,153,153,153,170,171,187,204,171,186,169,153,136,137,153,154,171,188,186,186,169,152,136,136,136,137,153,171,187,170,169,152,136,119,119,120,137,153,171,169,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,119,120,137,154,169,169,136,119,102,102,102,103,120,137,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,86,102,103,120,137,169,153,136,119,102,101,86,102,119,136,154,153,152,135,118,102,102,102,103,120,137,169,153,152,119,118,102,102,102,119,137,154,169,169,136,119,102,102,102,119,136,153,170,154,153,136,119,119,119,119,136,137,170,170,170,152,136,119,119,119,136,137,154,186,171,169,153,136,136,136,136,137,154,171,171,187,170,153,152,136,136,153,154,171,203,188,187,170,169,153,153,154,170,171,188,188,220,187,186,170,170,170,170,187,204,220,172,187,186,170,169,153,170,170,171,188,160,0,0,0,171,186,169,153,153,153,153,170,187,189,171,203,186,170,153,153,154,170,187,188,220,188,186,169,153,137,136,153,154,171,205,186,186,169,152,136,136,136,137,154,187,188,171,169,152,135,119,119,120,137,154,188,185,169,152,135,119,119,119,120,137,154,186,154,153,135,119,102,102,119,120,137,171,169,153,135,119,102,102,102,103,120,154,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,101,102,102,120,137,170,153,152,119,102,101,86,102,103,136,154,153,153,135,118,102,102,102,103,120,137,170,154,152,135,102,102,102,102,119,136,154,169,169,136,119,102,102,102,119,136,153,170,154,153,136,119,119,119,119,120,137,170,170,170,153,136,119,119,119,136,137,154,186,171,170,153,136,136,136,136,153,154,187,187,203,170,153,152,136,136,153,170,187,203,204,203,170,153,153,153,153,170,187,204,188,220,188,186,170,170,170,171,187,204,220,173,203,186,170,170,154,170,170,187,204,160,0,0,0,172,204,204,188,203,203,204,204,205,221,156,237,205,204,203,204,204,205,238,239,253,205,204,203,187,187,187,188,205,222,239,220,204,186,170,153,154,170,187,188,222,253,205,187,169,152,136,137,154,171,204,238,220,203,169,152,135,119,136,153,171,205,237,188,186,152,119,102,103,120,137,187,206,220,203,168,135,102,85,102,120,154,188,220,188,186,135,102,85,69,102,120,154,205,204,203,168,118,85,68,69,103,137,172,204,204,186,135,101,84,68,86,120,154,189,204,203,169,135,101,68,85,103,137,171,220,204,186,152,118,101,85,102,120,154,189,205,204,170,152,118,102,102,120,154,188,220,221,203,169,152,135,119,120,137,171,205,221,237,203,170,153,136,136,153,170,188,220,222,221,203,186,169,153,153,170,188,221,221,238,221,204,187,170,170,171,188,205,221,223,254,238,220,204,203,204,204,205,222,222,255,255,238,221,220,205,221,221,237,237,174,221,221,205,204,204,204,205,221,221,160,0,0,0,223,254,238,221,221,221,238,239,239,255,191,255,255,221,221,221,221,255,255,255,255,255,255,221,204,187,188,205,222,239,255,255,254,220,203,170,170,171,188,222,255,255,239,220,187,169,153,153,154,188,222,255,254,237,186,153,136,119,120,154,188,223,255,237,203,169,135,102,102,120,154,188,239,253,220,169,135,102,85,86,120,154,206,255,237,186,151,101,85,69,86,121,171,222,253,203,169,118,85,68,69,103,138,188,239,221,186,135,101,68,68,86,120,171,222,238,220,169,118,85,68,85,103,154,189,239,238,202,152,118,85,85,103,137,172,223,254,237,186,152,118,102,103,120,155,205,238,255,220,186,152,119,119,136,154,188,239,255,254,220,186,153,136,137,170,188,222,255,255,255,220,186,170,170,171,188,222,255,255,255,255,220,203,187,187,204,221,255,255,255,255,255,237,221,205,221,222,255,255,255,255,255,255,255,255,254,255,255,255,255,191,255,255,255,255,254,255,255,255,255,192,0,0,0,255,255,255,255,255,255,255,250,175,250,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,250,255,255,255,255,255,255,250,255,159,170,186,255,255,255,255,255,250,255,255,152,137,255,255,255,255,255,255,255,250,118,120,120,143,255,255,255,255,255,255,247,100,86,120,255,255,255,255,255,255,169,116,34,87,159,255,255,255,255,255,255,151,82,20,105,175,255,255,255,255,255,249,134,68,87,138,255,255,255,255,255,255,153,118,119,137,255,255,255,255,255,255,255,201,137,153,255,255,255,255,255,255,255,255,159,175,250,255,255,255,250,255,255,255,255,255,250,255,255,255,255,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,255,250,255,255,255,255,255,250,255,255,175,255,255,255,255,255,255,255,121,250,207,255,255,255,255,255,255,175,160,0,0,0,205,221,204,203,187,204,204,221,238,238,205,238,221,204,187,187,188,205,222,239,255,222,220,203,186,170,170,171,188,222,255,253,220,187,170,153,153,153,170,188,222,254,204,203,169,152,136,136,137,154,188,222,236,203,169,136,119,119,119,136,154,188,221,204,186,152,119,102,102,103,136,171,205,220,202,152,119,101,85,86,103,137,171,221,187,169,135,101,85,85,86,120,154,188,220,186,152,118,85,85,85,103,137,171,205,187,169,135,101,85,69,86,119,154,188,220,186,152,118,85,85,85,103,137,171,204,204,169,135,102,85,85,102,120,154,189,220,203,169,135,102,102,102,120,153,172,221,221,186,152,135,119,119,120,137,171,205,221,220,186,153,136,120,136,137,170,188,221,238,220,186,169,153,153,153,171,188,222,222,254,220,187,170,170,170,171,204,221,237,255,254,220,203,187,187,188,204,222,239,239,255,255,237,221,204,204,221,238,239,254,207,255,238,221,221,221,221,221,221,238,192,0,0,0,206,222,220,204,204,204,221,221,239,255,191,239,237,220,204,204,205,221,255,255,255,254,221,203,187,186,187,188,205,239,255,253,237,203,186,169,153,154,187,205,239,255,221,204,186,153,136,136,137,171,205,239,237,204,186,152,135,119,119,137,171,222,255,204,186,152,119,102,102,103,137,172,222,237,203,169,119,102,85,86,103,138,188,222,220,186,135,101,85,85,86,120,154,206,237,203,152,118,85,68,85,103,137,172,221,220,185,135,101,84,69,86,120,154,189,236,203,152,118,85,85,85,103,137,172,223,221,186,151,102,85,85,102,120,171,205,221,219,169,135,102,102,102,120,154,189,223,222,203,169,135,119,119,120,154,172,223,223,253,203,169,136,136,136,153,187,205,238,255,252,203,170,153,153,154,187,205,239,255,254,236,203,186,170,170,187,205,239,237,239,255,237,221,203,203,204,221,222,255,239,255,255,238,237,221,222,238,238,255,254,174,255,238,238,238,237,253,237,254,255,208,0,0,0,207,254,255,238,239,239,223,255,255,255,191,255,255,254,238,221,223,239,255,255,255,239,255,253,221,203,188,205,223,255,255,255,255,221,203,186,170,187,188,223,255,255,239,221,203,169,153,153,154,188,223,255,255,253,203,169,136,119,136,154,188,223,255,254,203,169,135,102,102,120,154,189,255,254,220,185,135,102,85,86,120,155,222,255,238,202,152,101,84,69,86,121,172,239,255,220,169,118,84,68,69,103,138,205,255,237,202,151,101,68,68,86,121,172,223,254,236,169,134,101,68,85,103,154,205,255,238,203,152,118,85,85,103,137,172,223,255,253,202,152,118,102,103,137,171,206,239,255,236,186,152,135,119,137,155,205,239,255,255,236,186,153,153,153,170,188,223,255,255,254,220,187,170,170,171,204,223,255,255,255,255,221,203,203,204,205,223,255,255,255,255,255,254,221,221,223,255,255,255,255,255,255,255,255,254,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,192,0,0,0,171,187,170,170,153,170,170,171,204,205,187,204,187,170,170,170,170,187,188,221,238,188,187,169,153,153,153,153,170,187,205,218,186,169,153,136,136,136,153,170,188,204,171,169,152,136,119,119,136,137,154,188,202,169,152,135,119,119,119,120,137,171,187,170,153,135,118,102,102,103,120,153,171,186,169,136,118,102,102,102,103,136,154,187,154,152,119,102,101,86,102,119,137,170,185,169,135,118,101,85,86,103,120,154,171,154,152,119,102,85,85,102,119,137,170,170,169,135,118,102,85,102,103,120,154,170,170,152,135,118,102,102,102,119,137,170,170,169,152,119,102,102,102,119,136,154,187,187,169,136,119,119,119,119,136,153,171,187,186,169,136,135,119,119,136,153,170,187,188,186,169,152,136,136,136,153,170,188,188,204,187,169,153,153,153,154,170,187,204,221,204,187,170,170,169,170,171,187,205,205,221,220,203,187,170,170,187,188,205,236,174,221,204,187,170,170,171,187,188,205,176,0,0,0,155,186,170,169,153,153,170,170,187,203,155,203,186,170,170,169,170,170,187,205,220,188,187,170,153,153,153,153,170,187,205,202,187,170,153,136,136,136,153,154,188,204,171,169,152,136,135,119,136,137,154,188,186,170,153,135,119,119,119,120,137,170,187,170,153,136,119,102,102,103,120,137,171,185,169,136,119,102,102,102,103,136,154,187,154,152,135,102,101,86,102,119,137,171,169,169,135,118,101,85,86,103,120,153,170,154,152,119,102,85,85,102,119,137,170,169,169,135,118,101,85,102,103,120,154,186,170,152,135,102,102,102,103,120,137,170,170,169,152,119,102,102,103,119,136,154,186,170,169,136,119,119,119,119,136,154,171,170,186,153,136,119,119,120,136,153,170,187,187,186,153,152,136,136,137,153,170,188,187,203,186,169,153,153,153,153,170,187,203,205,204,187,170,169,153,170,171,187,221,188,220,204,203,186,170,186,187,188,204,220,156,204,187,186,170,170,170,170,187,188,160,0,0,0,155,170,169,153,153,153,153,170,171,188,171,203,186,170,153,153,153,170,171,204,220,171,186,169,153,152,153,153,154,171,188,202,186,169,152,136,136,136,137,154,171,203,170,169,152,136,119,119,120,137,154,171,185,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,85,102,103,120,137,170,153,136,119,102,101,85,102,119,136,154,169,153,135,118,102,102,102,103,120,137,170,153,152,119,102,102,102,102,119,137,154,169,169,136,119,102,102,103,119,136,154,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,153,170,186,171,170,153,136,136,136,136,153,154,187,171,187,170,153,153,136,137,153,170,187,203,188,203,170,169,153,153,154,170,187,188,188,220,203,186,170,170,170,171,187,204,203,172,187,186,170,170,170,170,170,171,187,160,0,0,0,172,203,187,170,170,170,170,187,188,204,156,220,203,186,170,170,170,171,188,221,236,188,203,170,169,153,153,154,171,188,206,203,203,186,153,152,136,137,153,171,188,220,187,186,152,136,119,119,136,137,170,188,203,186,152,135,119,119,119,120,153,171,203,171,169,136,119,102,102,103,120,153,188,186,169,136,119,102,102,102,103,137,154,187,170,152,135,102,85,85,102,119,137,171,186,169,135,118,101,85,85,103,120,154,187,170,152,119,102,85,85,102,119,137,171,186,169,136,118,101,85,86,103,120,154,187,170,152,135,118,101,102,102,120,137,171,187,170,152,119,102,102,102,119,137,170,203,187,169,152,119,119,119,119,137,154,188,187,186,169,152,135,119,120,136,153,171,204,188,187,153,152,136,136,137,154,171,205,204,220,187,170,153,153,153,170,171,204,220,221,220,187,170,170,170,170,188,204,205,221,222,205,203,187,187,187,188,205,221,237,157,204,204,187,187,187,187,188,204,221,176,0,0,0,174,222,221,237,220,204,220,221,221,221,158,255,255,253,238,238,238,222,238,239,253,239,238,237,221,221,221,222,239,238,239,222,239,221,220,204,204,204,221,238,239,253,223,237,204,187,187,187,188,205,221,255,222,238,220,186,153,153,154,188,206,254,253,223,220,186,152,135,136,154,188,222,254,221,238,203,168,118,102,103,154,188,238,253,222,220,169,134,84,69,104,155,205,239,237,237,203,151,100,50,70,121,188,222,254,222,236,185,134,66,36,87,154,205,239,221,237,203,152,117,68,86,121,172,222,238,223,237,202,152,118,102,120,155,205,255,237,239,220,186,152,119,120,154,188,222,254,223,237,220,186,153,153,154,188,221,239,238,255,237,204,187,170,187,188,221,239,254,223,254,238,220,204,204,204,222,239,255,238,254,254,238,238,221,221,237,238,238,254,238,239,255,238,238,222,238,254,255,255,238,255,255,254,239,239,254,255,255,255,255,174,221,221,238,221,221,238,222,238,254,176,0,0,0,207,255,255,255,254,239,254,239,255,239,175,255,255,255,255,239,255,255,255,255,255,255,255,255,238,222,222,255,255,255,255,239,255,255,236,204,204,204,223,255,255,255,255,254,236,186,170,170,188,223,255,255,255,255,236,186,152,136,137,171,222,255,255,255,253,186,152,119,119,137,172,223,255,255,254,203,152,102,85,102,137,188,223,255,255,220,168,118,68,69,103,138,205,255,255,253,202,134,84,51,69,104,172,223,255,255,220,168,117,67,52,86,138,189,239,254,254,202,135,101,68,69,120,172,223,255,255,237,185,134,101,85,103,155,206,255,255,255,219,169,135,102,119,138,189,239,255,255,255,219,169,152,136,154,188,239,255,255,255,254,220,186,170,171,188,222,255,255,255,255,254,221,204,188,205,222,239,255,254,255,255,255,237,221,221,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,254,255,255,255,255,255,255,192,0,0,0,206,222,221,221,204,221,221,238,222,239,174,254,238,221,204,204,221,238,255,255,255,223,222,220,204,187,187,204,221,254,239,238,253,220,186,170,154,170,188,221,239,255,221,220,186,169,136,136,153,171,205,255,252,220,186,152,135,119,120,137,172,221,254,221,202,152,119,102,102,119,137,188,222,252,219,169,135,102,85,86,120,154,205,239,221,186,135,102,85,85,86,120,171,222,236,203,168,118,85,68,69,103,137,189,239,204,186,135,101,84,68,86,120,155,205,221,219,168,118,85,68,85,103,137,188,238,221,202,152,118,85,85,103,137,171,206,237,220,185,135,118,102,103,120,154,188,254,237,203,169,136,119,119,136,154,188,222,237,238,203,170,152,136,137,154,188,221,238,239,237,204,186,169,153,170,187,205,239,237,254,237,220,187,187,187,204,205,239,254,255,255,237,221,220,205,205,221,238,255,238,255,255,254,238,222,221,238,239,255,255,159,238,237,254,239,238,223,238,238,255,208,0,0,0,206,221,220,204,203,204,204,221,238,238,190,254,221,204,203,187,188,205,222,255,255,222,220,203,186,170,170,187,204,222,255,253,220,203,170,153,153,154,171,188,222,238,205,203,169,152,136,136,137,170,188,222,236,203,170,152,135,119,119,137,171,205,238,204,186,152,119,102,102,103,137,171,205,236,202,152,135,102,85,86,103,137,188,221,203,169,135,102,85,85,86,120,154,205,220,186,152,118,85,68,85,103,137,171,205,204,169,135,101,84,69,86,120,154,204,220,186,152,118,85,85,85,103,137,171,205,204,186,135,102,85,85,103,120,154,205,221,203,169,135,102,102,103,120,154,188,221,221,202,169,135,119,119,120,153,171,205,221,236,186,169,136,136,136,153,171,205,221,222,220,187,169,153,153,154,171,204,222,238,238,220,203,186,170,170,187,204,222,238,239,254,221,204,187,187,188,205,222,239,238,255,255,237,221,220,205,221,222,239,254,190,254,238,237,221,221,221,221,238,238,208,0,0,0,206,237,220,204,204,204,205,221,221,221,157,255,221,204,204,204,204,205,238,239,253,238,221,204,187,170,170,187,204,222,239,222,237,203,186,169,153,154,171,205,222,254,221,203,170,153,136,136,153,171,205,239,220,203,186,152,135,119,119,137,171,205,253,220,186,152,119,102,102,103,137,171,206,236,219,169,135,101,85,86,119,138,189,237,204,185,135,101,85,85,86,120,155,205,220,203,152,118,85,68,85,103,137,187,221,204,185,135,101,84,69,86,120,154,205,220,219,152,118,85,69,85,103,137,171,221,204,186,151,118,85,85,103,136,170,205,220,219,169,135,118,102,103,120,154,188,221,204,203,169,135,119,119,136,154,171,205,222,237,203,169,152,136,137,154,171,204,221,238,220,203,170,153,153,170,171,204,238,222,253,221,203,186,186,171,187,204,221,253,255,254,221,220,204,204,204,220,221,254,239,255,239,238,221,221,221,221,223,255,239,173,221,221,222,220,221,221,220,221,222,192,0,0,0,207,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,253,221,253,255,255,255,255,255,255,255,221,204,188,204,223,255,255,255,255,255,220,186,170,170,188,223,255,255,255,255,220,186,152,136,137,172,223,255,255,255,252,186,136,118,119,137,172,223,255,255,253,202,152,102,85,103,137,188,255,255,255,252,168,118,68,69,103,138,207,255,255,253,186,135,84,51,69,104,171,223,255,255,220,168,117,67,52,86,138,189,255,255,255,202,135,101,68,69,120,171,223,255,255,252,185,134,101,85,103,154,205,255,255,255,220,169,135,102,119,138,188,223,255,255,255,220,169,136,136,153,188,223,255,255,255,253,204,186,170,170,188,207,255,255,255,255,255,236,204,188,204,222,255,255,255,255,255,255,253,221,221,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,208,0,0,0,206,237,221,205,204,204,221,222,222,238,158,255,237,221,220,204,205,222,254,255,255,223,237,204,203,187,187,188,221,239,255,254,238,220,186,170,154,170,187,205,223,254,221,220,186,169,152,137,154,171,205,239,237,220,186,153,136,119,136,153,171,205,238,204,203,168,135,102,103,120,154,188,222,236,219,169,135,102,85,102,120,154,189,237,204,186,152,118,84,85,102,121,171,206,220,203,168,118,84,52,69,103,138,188,237,220,186,135,101,84,52,86,120,171,205,220,219,169,135,101,68,86,103,154,188,221,205,202,152,118,101,86,103,137,171,205,221,220,186,152,119,102,103,136,154,188,237,222,220,169,152,119,119,137,154,188,221,221,253,203,170,153,136,153,154,188,205,254,239,237,203,186,170,170,170,188,205,239,237,255,237,204,187,187,187,204,221,238,254,239,255,237,221,204,204,204,221,223,255,237,255,255,238,237,221,221,238,239,255,254,158,221,237,221,221,221,237,221,222,238,176,0,0,0,171,187,170,170,170,170,170,171,188,205,155,220,203,186,170,170,170,171,188,221,237,188,187,170,153,153,153,154,170,188,205,203,187,170,153,136,136,136,153,170,188,220,171,170,153,136,119,119,136,137,170,204,202,186,153,135,119,119,119,120,137,171,203,170,153,135,119,102,102,103,120,154,171,186,169,136,119,102,102,102,103,136,154,187,170,152,135,102,85,85,102,119,137,171,186,169,135,118,101,85,86,103,120,154,186,170,152,119,102,85,85,102,119,137,171,170,169,135,118,101,85,86,103,120,154,186,170,152,135,102,102,102,103,120,137,171,186,186,152,119,102,102,102,119,137,154,187,187,169,136,119,119,119,119,137,154,188,187,187,169,136,135,119,120,136,154,171,203,188,187,169,152,136,136,137,154,171,188,204,220,187,170,153,153,153,154,171,188,220,205,220,187,170,170,170,170,171,188,221,204,221,204,187,187,187,187,188,204,221,236,141,204,203,187,186,170,187,187,188,205,176,0,0,0,155,186,169,153,153,153,154,170,187,188,155,204,187,170,170,153,170,170,187,205,220,171,186,170,153,153,153,153,154,187,204,202,186,169,153,136,136,136,153,154,187,203,171,169,152,136,119,119,136,137,154,187,186,169,152,136,119,119,119,120,137,170,187,154,153,135,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,120,154,186,154,152,119,102,101,86,102,119,137,154,169,153,135,118,102,85,86,103,120,153,170,154,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,154,152,135,102,102,102,103,120,137,170,170,169,136,119,102,102,103,119,137,154,170,170,169,136,119,119,119,119,136,154,171,170,186,153,136,135,119,120,136,153,170,187,187,186,153,136,136,136,137,153,170,187,187,203,186,169,153,153,153,153,170,187,203,188,203,186,170,169,154,170,171,187,204,188,220,204,187,170,170,170,187,188,204,220,156,203,187,170,170,170,170,170,187,188,160,0,0,0,171,186,170,170,153,154,170,171,187,204,139,204,187,170,170,170,170,171,188,205,220,188,187,170,153,153,153,153,170,188,205,203,187,170,153,136,136,136,153,170,188,204,171,170,153,136,135,119,136,137,154,188,186,170,153,135,119,119,119,120,137,171,187,170,169,136,119,102,102,103,120,154,171,186,169,136,119,102,102,102,103,136,154,186,154,152,119,102,85,85,102,119,137,171,170,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,171,169,169,135,118,101,85,86,103,120,154,186,170,152,135,102,102,102,103,120,137,171,170,169,152,119,102,102,103,119,137,170,186,171,169,152,119,119,119,120,137,154,171,187,186,169,136,135,119,136,137,154,171,187,188,186,169,152,136,136,137,154,171,188,187,204,186,169,153,153,153,154,171,188,203,205,204,187,170,170,170,170,171,187,205,205,221,204,203,187,186,187,187,188,205,220,156,203,187,186,170,170,170,171,187,188,160,0,0,0,189,220,204,204,187,187,204,204,221,221,141,238,221,204,204,203,204,221,239,238,254,222,220,204,187,171,187,187,204,221,255,237,221,203,186,169,153,170,171,188,221,253,205,203,170,153,136,136,153,170,188,222,220,203,170,152,135,119,120,137,170,205,221,204,186,152,135,102,102,119,137,171,206,220,203,169,135,102,85,102,120,138,188,221,204,169,135,102,85,85,102,120,155,188,219,186,152,118,85,68,69,103,137,172,204,203,185,135,101,84,52,86,120,154,204,204,202,152,118,85,84,86,103,137,171,220,204,186,152,118,101,86,103,137,154,204,204,203,169,135,118,102,103,120,154,188,220,204,187,169,136,119,119,136,154,187,205,221,236,203,169,152,136,137,154,171,204,221,221,236,187,170,153,153,170,171,204,221,221,254,220,203,187,170,171,187,188,221,237,239,238,221,204,203,187,204,204,221,222,238,255,238,222,221,205,220,221,237,239,238,158,238,221,221,220,204,204,205,221,222,192,0,0,0,239,255,255,255,255,255,255,255,255,254,175,255,255,255,255,239,255,255,255,255,255,255,255,255,237,221,221,223,255,255,255,255,255,253,220,203,187,204,221,255,255,255,255,237,220,186,170,170,187,205,255,255,255,255,220,186,152,136,137,171,205,255,255,255,236,186,152,118,103,137,171,221,255,255,237,202,152,102,85,102,137,188,223,255,255,219,168,118,84,68,103,138,188,255,255,253,186,135,84,51,69,104,171,239,255,255,219,168,101,67,52,86,138,189,239,254,253,202,135,100,68,86,120,171,222,255,239,220,185,134,101,86,103,154,205,255,254,255,220,169,135,102,119,138,188,223,255,239,253,203,169,136,136,154,187,222,255,255,255,237,203,170,169,170,187,205,255,255,255,255,221,220,203,187,188,206,255,255,253,255,255,255,221,221,221,223,255,255,255,239,255,255,255,255,238,239,255,255,255,253,255,255,255,255,255,255,255,255,255,255,141,221,221,223,238,239,255,255,255,255,208,0,0,0,239,237,237,221,204,205,221,221,237,222,158,255,254,221,220,204,221,222,238,254,254,254,237,221,204,187,187,204,221,238,239,237,254,220,187,170,170,170,188,205,239,255,222,220,186,169,153,153,154,188,205,239,236,220,187,169,136,119,136,154,188,206,238,221,203,169,135,102,102,120,154,188,239,221,203,169,135,102,85,102,120,154,205,238,220,186,152,102,84,69,86,137,172,205,220,203,169,118,84,68,69,103,154,188,237,204,186,151,101,68,68,86,121,171,221,221,219,169,134,85,68,85,103,154,189,221,222,203,152,118,85,85,103,137,171,222,237,220,186,152,118,102,103,137,171,205,238,222,220,170,152,135,120,137,154,188,222,237,237,219,186,153,153,153,154,188,221,239,238,237,203,186,170,170,187,188,205,239,253,239,221,220,203,187,187,204,222,238,255,223,255,237,221,204,221,205,222,239,255,253,255,255,238,238,223,222,238,239,255,255,157,237,222,222,222,237,238,238,255,239,224,0,0,0,222,237,220,204,188,204,204,221,221,221,174,254,221,204,203,187,204,204,222,239,254,222,220,203,186,170,170,187,204,222,239,237,220,203,170,153,153,153,171,188,222,238,205,203,169,152,136,136,137,170,188,222,236,203,169,152,135,119,119,137,170,204,237,204,186,152,119,102,102,119,137,171,205,220,186,152,135,101,85,86,119,137,188,221,203,169,135,101,85,85,86,120,154,189,219,186,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,188,204,186,152,118,85,85,85,103,137,171,221,204,186,135,118,85,85,103,120,154,189,220,203,169,135,118,102,103,120,154,188,221,221,203,169,135,119,119,136,153,171,205,221,220,186,169,136,136,136,153,171,205,222,222,220,187,170,153,153,154,171,204,222,238,238,220,203,186,170,170,187,204,222,254,223,237,221,204,203,187,188,204,222,239,237,255,238,237,221,205,205,221,238,255,255,174,238,221,221,221,221,221,222,238,239,224,0,0,0,207,237,221,220,220,220,204,205,221,221,142,254,238,221,220,204,205,221,238,238,254,239,238,220,204,187,187,204,205,222,239,222,254,220,187,170,170,171,188,205,221,237,222,220,187,169,153,153,154,187,205,223,221,236,186,153,136,119,136,154,187,221,253,221,203,169,135,102,102,120,154,188,221,236,220,169,135,102,85,86,120,154,189,236,204,186,152,117,84,69,86,137,171,206,220,203,168,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,121,171,205,220,220,169,134,85,68,85,120,154,188,221,221,202,152,118,85,86,103,137,172,221,221,220,186,152,118,102,119,137,171,189,237,205,220,185,152,135,120,137,154,188,222,237,222,203,186,153,152,153,171,187,205,238,222,237,220,186,170,170,171,188,205,238,221,238,220,220,188,188,187,204,205,221,253,223,238,222,220,205,205,221,221,222,238,237,239,239,255,238,237,222,237,221,255,253,157,221,222,205,220,221,221,237,222,239,192,0,0,0,223,255,255,255,254,255,255,253,223,221,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,220,205,223,255,255,255,255,255,255,253,204,187,187,204,223,255,255,255,255,253,187,169,153,154,188,255,255,255,255,255,203,152,135,120,138,188,255,255,255,255,203,168,118,85,103,154,205,255,255,255,253,185,118,84,69,104,155,207,255,255,255,203,151,84,35,69,121,188,255,255,255,252,169,117,67,36,87,155,207,255,255,255,219,152,101,68,86,121,188,255,255,255,253,202,135,101,86,120,171,207,255,255,255,220,186,136,119,120,154,207,255,255,255,255,252,186,153,153,170,205,255,255,255,255,255,220,187,186,187,205,255,255,255,255,255,255,221,252,204,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,240,0,0,0,206,221,221,204,204,204,204,205,221,221,158,239,221,204,203,204,204,205,222,255,254,222,237,204,203,186,186,187,205,205,238,238,237,204,186,169,153,154,187,189,221,254,222,203,186,153,136,136,153,171,188,222,220,204,186,152,135,119,120,137,171,205,238,205,186,152,135,102,102,120,137,187,206,220,203,169,135,102,85,102,120,154,188,221,204,186,135,102,84,69,86,120,155,205,203,203,152,118,85,68,69,103,137,188,205,204,185,135,101,84,68,86,120,154,189,220,203,168,118,101,68,86,103,137,172,221,204,186,152,118,101,86,103,137,171,205,220,204,169,136,118,102,103,136,154,188,221,205,203,169,136,119,119,136,154,188,221,220,236,187,169,152,136,153,153,187,205,221,206,220,203,170,169,153,170,187,189,223,221,238,221,203,187,186,171,188,205,222,254,222,238,221,204,204,204,204,221,222,239,237,255,238,221,221,220,222,221,238,239,253,141,221,220,204,204,204,220,221,222,222,192,0,0,0,172,187,186,170,170,170,170,170,187,188,140,220,203,187,186,170,170,187,188,205,220,188,203,186,170,153,153,154,171,188,220,203,203,186,169,152,136,153,153,171,188,220,188,186,153,136,136,136,136,153,171,204,186,186,153,136,119,119,119,136,153,171,203,171,169,136,119,102,102,119,136,154,188,186,169,152,119,102,85,102,119,137,154,187,170,153,135,102,85,85,102,120,137,171,186,169,135,118,85,85,85,103,120,154,187,170,152,119,101,85,85,86,119,137,171,186,169,136,118,101,85,86,103,136,154,187,170,169,135,102,101,86,102,120,153,171,186,186,152,135,118,102,102,120,137,171,187,171,169,152,135,119,119,119,137,154,188,187,187,169,152,136,119,136,137,154,171,203,188,187,169,153,136,136,153,154,171,205,204,204,186,170,153,153,153,170,187,205,236,205,220,187,186,170,170,171,188,204,222,204,237,204,204,203,187,187,188,204,222,221,140,203,203,187,187,187,187,203,204,204,176,0,0,0,155,170,169,153,153,153,153,170,171,187,155,203,186,170,169,153,170,170,187,204,220,171,186,169,153,153,153,153,170,171,204,186,186,169,152,136,136,136,153,154,171,203,170,169,152,136,119,119,136,137,170,187,169,170,152,135,119,119,119,120,137,170,186,154,152,135,119,102,102,119,120,153,170,169,169,136,119,102,102,102,119,136,154,170,153,152,119,102,101,86,102,119,137,170,169,153,135,118,101,85,86,103,120,153,170,154,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,103,120,137,170,169,169,152,119,118,102,103,119,136,154,186,170,169,136,119,119,119,119,136,153,171,170,186,153,136,135,119,120,136,153,170,186,171,186,153,152,136,136,136,153,170,187,187,187,170,169,153,153,153,153,170,187,203,188,203,186,170,169,153,170,170,187,204,187,204,203,187,186,170,170,171,187,204,220,155,187,170,170,170,170,170,170,187,188,160,0,0,0,172,187,170,170,170,170,170,170,187,187,139,220,203,186,170,170,170,187,188,204,219,188,203,170,169,153,153,170,171,188,205,187,187,170,153,152,136,153,154,171,187,219,187,170,153,136,136,136,136,153,171,188,186,186,153,136,119,119,119,136,154,171,203,170,169,136,119,102,102,119,136,154,187,186,169,152,119,102,85,102,119,137,170,186,170,152,135,102,85,85,102,120,137,171,170,169,136,118,85,85,85,103,136,154,186,170,152,135,101,84,85,86,120,137,171,170,170,152,118,101,85,86,103,136,154,186,171,169,135,118,101,86,103,120,153,171,170,186,152,135,118,102,102,120,137,170,186,171,170,152,135,119,119,120,137,154,187,186,187,170,152,136,136,136,137,154,171,203,188,187,170,153,152,136,153,154,171,204,187,204,187,170,169,153,153,170,171,204,203,188,204,187,171,170,170,170,171,188,205,188,220,204,203,187,187,187,187,204,205,220,139,187,187,170,170,170,170,187,188,204,160,0,0,0,190,221,204,204,204,188,204,204,204,220,142,238,221,220,204,204,204,205,221,239,253,238,237,204,187,187,187,188,204,221,238,221,237,204,186,170,169,170,171,204,222,253,205,220,186,153,152,137,154,171,204,222,220,220,186,152,135,119,120,153,171,205,237,205,187,153,135,102,102,120,138,187,205,221,203,169,135,102,85,102,120,154,188,221,188,186,151,102,84,69,102,137,171,205,204,203,152,118,84,68,69,103,137,188,221,188,186,135,101,68,68,86,120,154,205,204,203,169,134,101,68,86,103,154,172,221,204,186,152,118,101,86,103,137,171,205,220,204,169,152,118,102,103,136,154,188,221,205,203,169,152,135,119,136,154,188,221,220,221,203,169,153,136,153,154,171,205,221,205,221,203,186,170,170,170,188,205,239,221,238,220,203,187,186,187,188,204,222,238,238,254,221,204,188,204,204,221,222,255,237,254,238,221,221,221,221,221,238,239,253,157,237,204,220,204,220,221,221,238,237,192,0,0,0,223,255,255,255,254,255,254,255,238,254,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,238,255,255,255,255,255,255,255,254,220,220,221,238,255,255,255,255,255,253,220,187,187,205,223,255,255,255,255,253,219,170,154,171,204,223,255,255,255,253,203,169,136,136,154,189,239,255,255,255,220,169,135,102,120,155,205,255,255,255,253,186,134,84,69,120,172,222,255,255,255,219,152,100,34,70,137,188,255,255,255,253,186,134,66,36,104,155,222,255,253,255,204,168,117,68,86,138,189,255,255,255,237,203,152,118,102,121,172,223,255,255,255,252,202,152,136,137,171,223,255,255,255,255,220,187,170,154,171,205,255,255,255,255,254,221,203,187,188,205,239,255,255,239,254,254,221,220,205,222,255,255,255,254,255,255,255,239,222,255,255,255,255,255,239,255,255,239,253,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,141,221,221,222,222,222,255,255,255,255,208,0,0,0,206,237,220,204,204,204,204,205,204,221,158,238,238,237,220,205,205,221,221,239,237,238,221,204,204,187,203,204,221,222,239,221,238,204,187,170,170,171,188,204,222,238,222,220,186,169,153,153,170,188,204,222,220,220,186,153,136,120,136,154,188,205,221,205,203,169,135,102,103,120,154,188,222,220,219,169,135,101,85,86,120,171,205,237,205,186,152,101,84,69,87,137,187,205,220,219,169,118,84,68,69,104,154,188,221,221,186,152,101,68,68,86,121,171,205,220,219,169,135,85,68,85,104,154,204,237,204,203,168,118,85,85,103,137,171,221,220,220,186,152,119,102,103,137,171,205,237,205,204,186,152,136,120,137,154,204,222,236,220,203,186,153,153,153,170,188,221,238,221,221,203,186,170,170,187,188,222,238,237,237,221,220,203,187,187,189,205,254,238,206,238,221,221,220,221,221,222,238,238,236,254,238,254,253,221,221,238,239,239,254,141,220,221,221,205,221,221,221,222,254,208,0,0,0,206,221,204,203,187,187,187,204,205,221,173,238,221,204,187,187,187,204,221,222,253,222,220,203,186,170,170,171,188,205,238,221,220,203,170,153,153,153,170,188,205,221,205,203,169,152,136,136,137,170,188,221,204,203,169,136,119,119,119,137,154,188,220,204,170,152,119,102,102,119,137,171,205,203,186,152,119,101,85,102,120,137,172,204,187,169,135,101,85,85,86,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,220,187,185,136,118,85,85,102,120,154,188,203,203,169,135,118,102,103,120,154,188,220,204,186,169,136,119,119,120,137,171,205,220,220,186,153,136,136,136,153,171,204,237,205,204,186,169,153,153,154,171,188,222,221,221,220,187,170,170,170,187,204,222,254,222,221,204,203,187,187,188,205,222,239,237,238,237,221,204,204,204,221,222,239,255,173,221,205,204,204,204,205,221,222,238,208,0,0,0,205,221,220,204,204,203,204,204,204,220,157,254,237,220,204,204,204,205,221,222,237,222,237,204,187,187,187,187,204,205,222,221,236,203,186,170,170,170,171,188,222,220,205,220,186,153,152,153,154,171,188,222,204,220,186,152,135,119,136,154,171,204,220,204,186,168,135,102,103,120,154,187,205,204,203,169,135,101,85,102,120,154,188,220,204,186,152,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,220,204,186,151,101,68,68,86,121,171,205,204,203,169,135,101,68,85,104,154,188,220,204,186,152,118,101,85,103,137,171,205,204,203,186,152,119,102,103,136,170,188,220,205,203,169,152,135,119,137,154,188,222,220,220,187,170,153,152,153,154,187,205,237,205,220,203,170,170,170,170,187,205,238,220,237,204,203,187,187,187,188,205,222,237,222,221,220,204,204,204,204,221,222,239,221,238,237,221,221,220,221,221,238,239,254,157,220,220,204,204,204,204,221,221,222,192,0,0,0,223,255,254,238,221,221,221,220,221,221,143,255,255,255,238,237,223,222,255,255,254,255,255,237,220,221,220,221,222,255,255,238,255,221,220,203,187,187,204,222,255,254,255,237,220,186,170,170,171,205,222,255,237,254,220,186,152,136,137,171,205,239,255,223,220,186,152,118,119,137,171,205,255,254,237,202,152,102,85,103,137,188,222,254,237,219,168,118,68,68,103,138,189,223,253,252,186,134,84,51,69,120,171,206,254,238,203,168,117,67,52,87,137,188,255,254,237,186,135,101,68,69,120,171,222,255,223,220,169,135,101,86,104,154,205,239,254,238,203,169,135,118,120,138,188,223,255,222,237,203,169,152,136,154,188,222,255,254,238,221,203,170,153,170,188,206,255,255,239,255,221,204,187,187,204,222,239,255,254,254,239,221,220,205,205,222,255,255,255,255,254,255,238,237,222,238,239,255,255,254,255,255,255,255,255,255,255,255,255,255,158,223,255,255,253,254,255,255,255,255,224,0,0,0,206,237,221,220,204,204,204,204,221,221,158,255,238,222,220,204,205,221,238,239,254,255,237,220,203,187,187,204,205,238,255,221,254,204,187,170,170,170,187,205,221,238,222,220,186,169,153,153,154,171,222,222,221,236,202,153,136,119,136,154,187,205,237,205,203,169,135,102,103,120,154,188,221,220,219,169,135,101,85,102,120,154,188,237,204,202,152,101,84,69,102,137,171,221,220,203,168,118,84,68,69,103,154,189,220,204,186,135,101,68,68,86,120,171,205,236,203,169,134,101,68,85,104,154,189,221,205,203,152,118,85,85,103,137,172,222,220,220,186,152,119,102,103,137,171,205,253,206,203,186,152,135,119,137,154,188,238,220,221,203,170,153,153,153,170,188,222,254,222,221,204,170,170,170,171,188,222,255,237,238,221,204,187,187,187,205,222,239,255,222,238,222,221,204,205,222,238,239,255,237,255,254,238,221,221,238,238,255,255,255,141,205,205,221,220,205,237,238,238,255,176,0,0,0,155,187,186,170,170,170,170,170,187,187,139,204,203,187,170,170,170,187,188,205,220,188,203,170,170,153,153,170,171,188,205,187,187,170,153,152,136,153,154,171,188,203,187,170,153,136,135,136,137,153,171,188,186,186,153,135,119,119,119,136,153,171,203,171,169,136,118,102,102,119,136,154,187,186,170,152,118,102,85,102,119,137,170,187,170,152,135,102,85,85,102,120,153,171,186,169,136,118,85,85,85,103,136,154,186,170,152,135,101,85,85,86,119,137,171,186,169,152,118,101,85,86,103,136,154,187,170,169,135,118,101,86,102,120,153,171,186,186,152,135,118,102,102,119,137,170,187,171,170,152,135,119,119,119,137,154,188,186,203,170,152,136,136,136,137,154,171,203,188,187,170,153,152,136,137,154,171,204,203,204,187,170,169,153,153,170,171,204,220,188,204,187,186,170,170,170,187,204,222,204,221,204,203,187,187,187,188,204,221,237,140,187,187,187,171,171,187,188,204,205,160,0,0,0,155,186,170,153,153,153,153,170,170,187,139,204,187,170,170,170,170,170,187,204,203,187,186,170,153,153,153,153,170,187,204,186,186,169,153,136,136,137,153,170,187,203,171,169,152,136,119,136,136,153,170,187,170,170,152,135,119,119,119,136,153,170,186,154,153,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,137,154,186,154,152,119,102,85,85,102,120,137,171,169,169,135,118,101,85,86,103,136,154,170,154,152,135,102,85,85,102,119,137,170,169,169,136,118,101,85,86,103,120,154,170,154,153,135,118,102,102,102,120,137,171,169,169,152,135,118,102,102,119,137,154,186,171,169,152,135,119,119,119,136,154,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,153,136,136,137,153,170,188,186,203,186,170,153,153,153,154,170,187,203,188,203,187,170,170,170,170,171,187,205,187,220,203,187,186,170,187,187,188,205,220,155,187,170,170,170,170,170,171,187,188,160,0,0,0,155,187,170,170,170,170,170,170,187,187,139,204,203,187,170,170,170,187,188,205,219,188,187,170,169,153,153,170,171,187,205,187,203,170,153,152,136,153,153,171,188,203,171,170,153,136,136,136,136,154,171,188,186,186,153,135,119,119,119,136,154,171,187,171,169,135,118,102,102,119,136,154,187,186,170,152,118,102,85,102,119,137,170,187,170,168,135,102,85,85,102,120,153,171,170,169,136,118,85,85,85,103,136,154,186,170,152,135,101,85,85,86,120,137,171,170,169,152,118,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+800104);
/* memory initializer */ allocate([85,86,103,136,154,186,170,169,135,118,101,86,102,120,153,171,170,186,152,135,118,102,102,119,137,170,187,171,170,152,135,119,119,119,137,154,187,186,187,169,153,136,136,136,137,154,187,203,188,187,170,153,152,136,153,154,171,205,187,204,187,170,169,153,154,170,171,188,220,188,204,187,186,170,170,170,187,204,221,203,221,204,203,187,187,187,204,204,221,220,139,187,187,187,170,170,171,187,187,204,160,0,0,0,189,236,204,203,203,187,204,204,204,205,141,237,237,220,203,187,188,205,205,239,253,222,237,203,187,170,170,187,204,206,238,221,221,203,186,153,153,154,170,188,222,237,221,203,186,153,136,136,153,170,188,221,220,219,170,152,135,119,120,137,171,188,220,205,186,152,119,102,102,120,137,171,205,203,202,169,135,101,85,102,120,153,188,220,187,169,135,102,84,85,102,120,154,188,203,186,152,118,84,68,85,103,137,172,204,204,169,135,101,84,68,86,120,154,188,219,203,152,118,101,84,85,103,137,172,220,204,186,152,118,101,85,103,137,171,205,220,203,169,136,118,102,103,120,154,188,220,204,187,169,136,119,119,136,154,188,221,220,220,186,169,152,136,137,154,171,205,221,205,220,187,170,153,153,170,187,205,222,236,237,220,203,186,170,171,187,204,222,237,222,237,220,204,188,188,204,221,222,255,237,255,221,221,221,205,221,221,238,239,254,157,221,221,221,204,204,204,221,238,238,192,0,0,0,223,254,237,222,221,221,221,221,204,221,159,255,255,238,222,221,221,222,238,239,253,239,239,238,221,204,204,205,205,238,255,223,255,237,204,203,187,187,204,221,222,254,222,221,204,170,170,170,171,188,221,255,238,253,203,186,152,136,137,170,188,223,255,238,220,185,135,119,119,137,171,205,239,238,236,186,151,102,85,103,137,171,206,254,222,203,168,118,68,69,103,138,188,222,237,236,185,135,84,51,69,120,155,206,238,221,203,152,117,67,52,86,138,188,223,237,236,202,135,101,68,69,120,171,222,238,221,219,169,135,101,85,103,154,205,255,237,222,203,169,135,119,119,138,188,239,255,223,220,186,169,136,136,154,187,206,239,253,237,220,203,170,170,170,187,205,239,255,223,237,220,203,187,187,188,205,239,255,253,238,221,221,204,205,205,221,255,255,255,223,239,239,221,238,222,238,239,255,255,253,255,255,254,254,255,239,255,255,255,255,140,221,222,222,237,221,238,255,255,255,224,0,0,0,205,221,204,204,204,204,204,204,204,205,157,254,237,220,204,204,204,205,222,239,237,222,221,204,203,187,187,187,188,221,239,221,221,204,187,170,170,170,187,188,221,237,205,219,186,153,152,137,154,171,204,238,220,220,186,152,136,119,136,153,171,205,221,204,186,152,135,102,103,120,154,171,221,220,203,169,135,101,85,102,120,154,189,221,204,186,152,101,84,69,103,137,171,206,219,203,169,118,84,68,69,103,138,188,220,204,186,151,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,206,220,204,170,152,119,102,103,136,155,189,237,205,203,169,152,135,119,136,154,188,238,220,221,203,170,153,152,153,170,188,222,238,205,220,187,170,170,170,171,188,221,255,236,221,220,203,187,187,187,204,221,239,254,207,238,221,204,204,204,205,222,239,255,237,238,237,221,221,221,221,238,254,255,254,140,221,221,221,221,221,221,238,238,239,208,0,0,0,222,221,204,204,187,187,187,204,204,204,158,238,221,204,203,187,188,204,221,222,237,222,220,203,187,170,170,187,188,205,222,221,221,203,170,169,153,154,170,188,205,237,205,203,170,152,136,136,153,170,188,221,220,203,169,152,119,119,120,137,171,188,220,204,186,152,119,102,103,120,137,171,204,204,203,153,135,101,85,102,120,154,188,220,203,169,135,101,84,85,103,120,154,188,203,186,152,118,84,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,203,186,152,135,101,84,85,103,137,172,220,188,186,152,118,101,85,103,137,155,205,203,203,169,136,119,102,103,120,154,188,221,204,187,169,136,119,119,120,153,171,205,220,204,186,169,152,136,136,153,171,205,221,205,204,187,170,153,153,170,171,188,222,236,221,204,187,186,170,171,187,204,222,238,222,221,204,203,187,187,204,205,222,239,237,238,221,221,204,204,205,221,238,239,254,173,221,204,204,204,204,205,221,222,239,208,0,0,0,206,221,221,204,204,204,204,204,204,204,157,255,237,221,204,204,204,221,222,238,253,222,237,204,203,187,187,188,204,221,239,221,221,204,186,170,170,170,187,204,222,236,221,220,186,153,153,153,154,171,205,222,220,220,186,152,135,119,136,154,171,205,237,204,186,152,119,102,103,120,154,172,205,220,203,169,135,101,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,220,186,152,119,102,103,136,154,204,221,205,203,186,152,135,119,136,154,188,221,220,221,203,170,153,153,153,154,187,205,237,205,220,203,186,170,170,171,188,205,238,220,237,220,204,187,187,187,188,205,222,253,206,237,221,204,204,204,205,221,238,255,237,238,238,222,221,221,222,222,238,255,254,157,220,205,221,204,205,221,221,222,238,208,0,0,0,207,255,238,221,205,204,220,204,221,205,143,255,255,254,237,238,221,222,238,255,253,239,255,238,221,204,205,221,222,238,239,222,254,237,220,203,187,188,204,222,239,254,238,238,204,186,170,170,171,204,206,239,237,237,220,186,152,136,137,170,205,222,254,222,220,186,136,119,119,137,171,205,239,238,237,203,152,101,85,103,137,172,222,254,238,219,169,117,68,69,103,138,189,239,237,236,202,135,84,51,69,120,171,206,254,221,203,168,117,67,52,87,138,189,239,237,220,186,151,101,68,69,120,171,222,238,222,203,169,135,101,85,104,154,205,239,253,237,203,169,135,118,120,154,188,238,255,223,220,186,169,136,136,154,188,222,239,237,254,221,203,186,170,170,188,222,222,254,223,237,220,204,187,187,204,222,238,255,237,239,237,221,205,221,221,238,255,254,254,223,254,222,238,238,222,238,255,239,254,254,255,238,238,239,255,239,255,255,255,255,157,221,221,221,221,238,238,254,255,255,224,0,0,0,189,220,204,187,187,204,204,188,188,205,141,238,221,220,204,204,204,205,221,238,237,222,237,220,187,187,187,188,204,205,223,220,220,204,186,170,170,170,187,204,221,237,205,204,186,153,153,153,154,171,204,222,220,220,186,153,136,119,136,153,171,205,237,205,203,152,135,102,103,120,154,188,205,204,203,169,135,101,85,102,120,154,189,220,205,186,151,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,237,204,186,151,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,205,186,152,118,101,85,103,137,172,206,204,220,186,152,119,102,103,137,154,188,237,204,203,169,152,135,119,137,154,188,223,220,220,203,170,153,153,153,170,188,221,237,206,220,203,186,170,170,170,187,205,223,220,237,221,204,187,187,187,204,221,238,238,222,237,221,204,204,204,205,221,223,239,237,255,238,237,220,221,221,238,238,255,254,124,205,204,204,204,205,221,221,237,238,192,0,0,0,171,187,170,170,170,170,170,170,170,187,139,220,203,186,170,170,170,171,188,204,220,188,187,170,169,153,153,154,170,188,205,187,203,170,153,152,136,153,154,171,188,203,171,170,152,136,136,136,136,153,171,188,186,186,153,136,119,119,119,136,153,171,203,170,169,135,118,102,102,119,136,154,187,186,169,152,118,102,85,102,119,137,154,187,170,152,135,102,85,85,102,120,153,171,169,169,136,118,85,85,85,103,136,154,187,170,152,135,102,85,85,86,119,137,171,170,169,152,118,101,85,86,103,136,154,187,170,169,135,118,101,86,102,120,153,171,186,186,152,135,118,102,102,119,137,154,187,171,170,152,135,119,119,119,137,154,187,186,187,169,152,136,135,136,137,154,171,203,171,187,170,153,152,136,153,154,171,188,203,203,187,170,169,153,153,170,171,188,220,188,204,187,170,170,170,170,187,204,221,203,221,204,187,187,187,187,188,204,222,237,139,187,187,187,186,170,187,187,204,205,176,0,0,0,171,186,170,153,153,153,153,170,170,187,139,204,187,170,170,170,170,170,187,204,203,187,186,169,153,153,153,153,170,171,188,186,186,169,152,136,136,136,153,170,171,203,171,169,152,136,119,120,136,153,170,187,170,169,152,135,119,119,119,136,153,170,186,154,152,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,153,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,102,119,137,154,186,170,169,152,135,119,119,119,136,154,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,153,136,136,136,153,170,188,186,187,186,169,153,153,153,154,170,188,203,188,187,186,170,170,170,170,171,188,205,203,204,203,187,186,170,171,187,188,204,220,139,187,170,170,170,170,170,171,187,204,176,0,0,0,172,187,186,170,170,170,170,170,187,187,140,220,187,187,170,170,170,187,188,205,220,188,187,170,169,153,153,170,171,187,204,187,187,170,153,152,136,137,154,171,187,203,187,170,153,136,135,136,137,153,171,188,186,186,153,135,119,119,119,136,154,171,187,170,169,135,118,102,102,119,137,154,187,186,169,152,118,102,85,102,119,137,170,187,170,152,135,101,85,85,102,120,153,171,170,169,136,118,85,85,86,103,120,154,186,170,152,135,101,85,85,86,120,137,171,170,169,152,118,101,85,86,103,136,154,186,170,169,135,118,102,86,102,120,137,171,170,186,152,135,118,102,102,119,137,170,187,171,169,152,135,119,119,119,137,154,187,186,187,169,152,136,136,136,137,154,171,203,188,187,170,153,152,136,137,154,171,204,187,204,187,170,169,153,153,170,171,188,219,189,204,187,170,170,170,171,187,188,205,203,220,204,187,187,187,187,187,204,221,220,140,187,187,186,170,170,187,187,188,204,160,0,0,0,189,221,205,203,203,187,203,203,204,204,125,255,221,204,203,187,204,205,221,222,237,221,220,204,187,171,171,187,204,221,238,221,221,203,186,169,153,170,171,188,205,236,205,203,170,153,136,137,153,170,188,221,220,219,186,152,135,119,120,153,171,188,221,204,186,152,119,102,103,120,137,171,205,204,203,169,135,101,85,102,120,154,188,220,188,185,135,101,84,85,103,121,155,188,204,186,152,118,84,68,69,103,137,172,205,204,169,135,101,84,68,86,120,155,189,219,202,168,135,101,84,85,103,137,187,205,187,186,152,118,101,85,103,137,170,205,220,203,169,136,119,102,103,120,154,188,221,204,187,169,152,119,119,136,154,187,222,220,220,186,169,152,136,137,154,187,221,237,221,220,187,170,169,153,170,188,205,239,220,237,220,187,187,170,187,188,204,238,238,222,237,221,204,204,204,204,205,238,239,253,254,221,221,220,221,221,222,237,255,254,141,205,205,204,204,204,205,221,238,239,192,0,0,0,223,255,255,255,255,254,237,221,221,220,143,255,255,255,255,255,255,255,239,255,253,255,255,255,255,238,237,221,239,255,255,255,255,255,221,220,204,204,205,223,255,255,255,255,236,203,187,171,188,221,255,255,255,255,237,187,169,153,154,171,205,255,255,239,253,202,152,119,119,137,172,223,255,255,254,219,168,118,86,103,138,189,223,255,255,252,185,118,84,69,104,155,205,255,255,253,203,151,84,35,70,121,172,239,255,255,236,169,118,67,36,87,155,205,255,255,253,203,152,101,68,70,121,188,239,255,239,221,186,135,102,86,120,171,223,255,255,254,220,169,136,119,120,154,205,255,255,223,253,203,170,153,153,171,189,223,255,253,255,221,203,187,170,187,204,254,255,255,239,253,237,220,204,204,205,239,255,255,253,255,239,221,221,222,238,255,255,255,255,207,255,255,239,238,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,124,205,221,221,253,239,255,255,255,255,240,0,0,0,222,238,221,220,204,204,204,204,204,204,158,255,238,237,204,204,204,205,221,238,253,239,237,220,203,187,187,188,204,221,239,221,237,220,187,170,170,170,187,204,221,254,222,220,186,153,153,153,154,171,204,222,221,220,186,152,136,119,136,153,171,205,237,221,202,152,119,102,103,120,154,188,221,220,219,169,135,101,85,102,120,154,205,237,204,186,151,101,84,69,103,137,171,205,220,203,168,118,84,68,69,103,154,188,237,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,237,204,186,152,118,101,85,103,137,172,222,236,220,186,152,119,102,103,120,155,205,237,205,203,169,152,135,119,136,154,188,239,236,220,203,170,153,153,153,170,188,222,254,206,220,203,186,170,170,171,188,222,255,236,237,220,204,187,187,187,205,222,239,255,207,237,221,220,204,204,205,222,239,255,252,254,254,221,221,222,238,238,255,255,255,141,221,205,221,221,221,221,238,255,255,208,0,0,0,222,237,220,204,187,187,187,188,204,204,158,254,237,204,203,187,187,204,205,222,237,238,221,203,186,170,170,171,187,204,222,221,220,203,170,153,153,153,170,187,205,221,221,203,169,152,136,136,137,154,187,205,204,203,169,136,119,119,119,137,154,188,220,204,186,152,118,102,102,119,137,171,205,204,186,152,118,101,85,102,120,137,171,204,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,204,187,169,135,118,101,85,102,120,154,189,203,203,169,135,118,102,102,120,154,188,221,204,186,153,136,119,119,120,137,171,205,220,203,186,153,136,136,136,153,171,205,238,205,203,186,169,153,153,154,171,204,222,236,221,204,187,170,170,170,187,204,222,255,206,221,204,187,187,187,188,205,222,255,253,238,221,205,204,204,204,221,239,255,255,173,220,204,204,204,204,221,222,239,255,224,0,0,0,223,237,238,221,220,204,204,204,204,204,159,255,254,237,220,204,204,205,221,238,237,239,238,220,204,187,187,188,204,221,238,222,238,220,187,170,170,170,187,188,221,237,222,220,186,153,152,153,154,171,204,222,221,220,186,152,135,119,136,153,171,205,221,221,203,168,119,102,103,120,154,188,221,204,219,169,135,101,85,102,120,154,188,220,204,186,151,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,220,204,186,151,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,172,205,220,220,186,152,119,102,103,136,155,205,221,205,203,170,152,135,119,136,154,188,223,221,220,203,170,153,137,153,170,188,221,237,205,220,203,186,170,170,171,188,221,239,237,237,220,204,187,187,187,204,221,238,254,205,237,221,204,204,204,205,222,255,255,253,254,238,237,221,221,238,222,254,255,254,156,205,204,204,204,221,221,222,239,255,208,0,0,0,239,255,255,255,238,221,221,221,204,205,127,255,255,255,255,255,239,238,254,255,253,255,255,255,239,220,221,221,255,239,255,223,255,254,221,204,187,188,205,221,223,254,255,255,220,186,170,170,171,204,223,255,239,255,220,186,152,136,153,171,205,223,254,255,252,186,152,119,119,137,171,205,255,255,253,203,151,101,85,103,137,187,223,255,255,220,168,117,68,69,103,154,205,255,255,253,186,135,84,51,69,120,171,223,255,254,219,168,117,67,52,87,138,189,255,255,237,186,135,101,68,69,120,171,223,255,255,220,169,135,101,85,103,155,207,255,255,253,203,169,135,118,120,154,188,223,255,239,236,203,169,152,136,154,188,223,255,254,255,205,203,170,170,171,188,223,255,255,239,255,221,203,187,187,220,238,255,255,253,254,239,221,220,221,221,238,255,255,255,239,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,141,220,221,222,255,255,255,255,255,255,240,0,0,0,207,222,221,220,204,204,204,220,204,205,143,255,238,220,220,188,205,222,221,239,237,238,238,220,187,187,187,187,205,237,238,237,254,220,186,170,170,170,171,204,221,237,222,204,186,153,136,137,153,171,188,222,221,220,186,152,135,119,136,153,171,206,221,221,202,152,119,102,103,120,153,171,206,221,203,169,135,101,85,102,120,155,189,221,204,186,135,101,84,69,103,137,171,206,220,203,169,118,84,68,69,103,138,188,205,204,186,135,101,84,68,86,120,155,205,236,203,169,135,101,68,85,103,138,188,221,205,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,120,154,189,237,205,203,169,152,135,119,136,154,188,222,220,220,203,170,153,136,153,154,188,221,238,206,220,187,170,170,170,170,188,205,239,237,238,220,204,187,187,187,188,221,238,254,222,238,221,204,204,204,205,223,238,255,236,239,238,221,221,221,221,239,255,255,254,141,221,220,220,221,221,221,222,239,239,208,0,0,0,172,187,170,170,170,154,170,170,171,187,139,220,203,187,170,170,170,171,187,204,219,188,187,170,169,153,153,154,170,188,205,187,203,170,153,136,136,153,153,170,188,203,171,170,153,136,135,136,136,153,171,188,186,186,153,135,119,119,119,136,153,171,203,171,169,135,118,102,102,119,136,154,187,170,169,152,118,102,86,102,119,137,170,186,170,152,135,102,85,85,102,120,153,171,170,169,136,118,85,85,85,103,136,154,186,170,152,135,102,85,85,86,119,137,171,170,169,152,118,101,85,86,103,120,154,187,170,153,135,118,102,86,102,120,137,171,186,170,152,135,118,102,102,119,137,170,187,171,169,152,135,119,119,119,136,154,187,186,186,169,152,136,119,120,137,154,171,203,172,186,169,153,136,136,153,154,171,204,203,203,186,170,153,153,153,170,171,188,220,188,203,187,170,170,170,170,187,204,222,219,220,204,187,187,187,187,188,205,221,236,139,187,187,187,170,170,187,187,204,205,176,0,0,0,171,186,170,153,153,153,153,154,170,187,155,204,187,170,170,153,170,170,187,188,203,188,186,169,153,153,153,153,170,171,188,186,186,169,152,136,136,136,153,154,171,203,171,169,152,136,119,119,136,153,154,187,170,169,152,135,119,119,119,136,153,170,186,154,152,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,170,153,152,119,102,101,86,102,120,137,170,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,169,136,118,102,85,102,103,120,153,170,154,152,135,118,102,102,102,119,137,170,169,169,152,135,118,102,102,119,136,154,186,154,169,136,135,119,119,119,136,153,171,170,186,153,136,136,119,120,136,153,170,187,171,170,153,152,136,136,136,153,170,188,186,187,170,169,153,153,153,153,170,188,203,188,187,186,170,169,154,170,171,187,205,203,220,203,187,170,170,170,187,188,205,220,155,187,170,170,170,170,170,171,187,204,176,0,0,0,188,203,187,170,170,170,170,170,187,187,140,221,203,186,170,170,170,187,188,204,220,205,203,170,169,153,153,154,170,188,205,203,203,170,153,152,136,137,153,170,188,203,188,170,152,136,119,120,136,153,171,188,187,186,152,135,119,119,119,136,153,171,203,171,169,135,118,102,102,119,136,154,171,186,169,136,118,102,86,102,119,137,170,187,170,152,119,102,85,85,102,120,137,171,186,169,135,118,85,85,86,103,120,154,186,170,152,119,102,85,85,86,119,137,171,186,169,136,118,101,85,86,103,136,154,187,170,169,135,118,102,86,102,120,137,171,186,186,152,135,118,102,102,119,137,170,187,171,169,152,135,119,119,119,136,154,188,187,187,169,152,136,119,120,137,154,171,204,188,187,169,153,136,136,153,154,171,204,203,204,187,170,153,153,153,154,171,204,220,189,204,187,186,170,170,171,187,188,221,204,220,204,203,187,187,187,188,204,222,237,139,187,187,186,170,187,187,188,204,205,176,0,0,0,207,237,237,220,204,204,204,204,204,204,126,255,254,221,220,205,221,206,238,255,253,223,221,220,220,204,188,204,205,221,254,221,238,220,187,187,170,187,187,221,222,237,222,221,186,169,153,153,170,187,205,221,221,220,187,169,136,136,137,154,188,222,237,205,203,169,135,118,119,136,154,188,222,221,220,186,135,101,85,103,137,171,205,220,221,186,152,118,84,69,103,137,188,206,220,219,169,134,84,51,69,120,154,205,221,205,202,152,117,67,52,87,137,172,206,204,219,185,135,101,68,86,120,154,189,253,205,203,169,135,101,86,103,137,188,221,220,221,186,152,135,119,119,137,171,205,237,205,203,186,153,136,136,137,171,205,223,236,237,219,186,169,153,154,171,188,222,222,207,221,203,187,170,170,171,188,222,223,237,254,221,204,203,203,204,205,222,238,253,223,239,253,221,221,220,237,237,238,255,253,255,253,238,237,221,223,238,254,255,255,141,221,220,205,221,205,205,221,237,238,208,0,0,0,255,255,255,255,253,254,207,205,204,204,143,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,221,255,205,221,255,255,255,255,255,255,219,204,187,204,207,255,255,255,255,255,204,186,170,171,188,223,255,255,255,255,203,169,136,136,154,189,255,255,255,255,253,169,135,102,120,155,205,255,255,255,220,186,134,84,69,120,172,223,255,255,255,251,168,100,34,70,137,189,255,255,223,220,185,134,66,36,104,155,221,255,255,255,204,168,117,68,86,138,191,255,255,255,207,202,152,118,102,121,173,255,255,255,253,253,186,152,136,137,171,220,255,255,223,255,220,202,170,170,171,207,255,255,255,255,255,219,204,187,204,253,223,255,255,255,255,255,255,221,207,223,255,255,255,255,255,255,253,255,205,255,255,255,255,255,239,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,141,255,223,255,255,255,255,255,255,255,240,0,0,0,223,253,221,220,204,203,204,204,204,204,143,255,238,221,220,204,205,220,237,223,252,255,238,220,204,203,187,188,204,222,239,223,253,204,187,171,170,171,187,204,222,237,221,220,187,170,153,153,154,188,205,221,221,253,203,169,136,136,137,154,187,205,221,220,203,169,135,119,119,136,154,188,222,221,220,169,135,102,85,103,137,171,205,237,204,202,152,118,84,69,103,137,172,222,220,203,169,135,84,51,69,120,154,188,221,220,186,152,117,67,52,86,137,171,205,220,203,169,135,101,68,86,120,154,189,221,221,203,169,135,101,85,103,137,188,222,220,204,186,152,135,118,119,137,171,205,238,205,203,186,153,136,136,137,171,205,222,252,237,187,186,169,153,154,171,189,223,254,205,237,203,187,186,170,187,204,237,255,236,238,220,204,204,188,204,221,223,239,255,205,237,221,205,205,220,221,223,239,255,252,255,253,238,237,238,238,239,255,255,255,141,220,205,205,221,237,238,254,255,255,224,0,0,0,255,255,237,220,204,204,204,204,221,221,175,255,253,220,203,187,188,204,221,239,254,255,237,203,187,170,170,171,188,205,239,238,237,203,170,153,153,153,170,188,205,254,237,203,169,152,136,136,137,154,188,221,221,219,169,152,119,119,119,137,154,188,221,204,186,152,118,102,102,119,137,171,205,220,202,152,118,101,85,102,119,137,171,221,203,169,135,101,85,85,86,120,154,188,220,186,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,189,220,186,152,118,101,85,85,103,137,171,221,203,169,135,118,101,85,102,120,155,205,236,203,169,135,118,102,102,120,154,188,222,204,186,169,135,119,119,120,153,171,223,237,220,186,153,136,136,136,154,171,205,255,221,204,186,169,153,153,154,171,205,255,253,237,204,187,186,170,171,188,205,239,255,223,237,220,204,187,187,204,221,239,255,253,255,237,221,221,221,221,222,255,255,255,173,221,221,221,220,221,222,239,255,255,240,0,0,0,239,255,237,220,220,204,204,204,205,221,159,255,254,221,204,204,204,205,221,238,253,254,238,204,203,187,187,187,188,222,238,222,255,220,187,170,153,170,171,204,206,221,237,236,186,153,136,136,154,171,188,238,205,220,186,152,135,119,120,137,171,204,237,221,202,152,119,102,102,120,137,171,205,221,219,169,135,101,85,102,120,154,188,221,220,186,151,101,84,85,102,120,171,189,204,203,168,118,84,68,85,103,137,172,222,204,169,135,101,68,68,86,120,155,205,220,203,168,118,101,84,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,220,169,136,118,102,103,120,154,189,221,221,203,169,136,135,119,136,154,188,223,221,220,203,169,152,136,137,154,188,206,254,221,220,187,186,169,170,170,188,222,223,253,253,204,203,187,186,187,188,221,239,255,223,221,220,204,204,204,204,221,238,255,253,238,222,221,221,221,221,239,239,255,255,156,204,204,205,220,237,238,239,255,254,240,0,0,0,255,255,255,255,254,221,237,221,204,221,143,255,255,254,254,221,221,223,255,255,254,255,255,255,254,221,221,220,238,239,255,255,255,254,221,204,187,187,205,223,255,253,255,222,220,187,170,170,170,204,207,255,223,255,204,186,152,136,153,171,205,253,255,237,237,186,135,119,119,137,171,205,255,221,237,203,151,101,85,103,137,188,255,239,239,219,168,117,68,69,103,154,205,239,237,236,202,135,84,51,69,120,171,223,254,222,203,168,117,67,52,87,137,205,239,253,236,202,151,101,68,69,121,171,222,223,254,220,169,135,101,85,103,154,205,255,254,222,203,169,135,119,120,154,188,239,255,255,253,203,169,152,136,154,188,222,255,255,223,204,187,170,169,171,188,221,254,255,223,238,236,204,187,188,189,237,255,255,255,239,253,221,204,220,205,223,255,255,255,207,222,239,222,253,239,255,255,255,255,253,255,253,255,238,238,255,255,255,255,255,124,203,205,222,255,238,223,255,255,255,240,0,0,0,205,237,219,204,186,171,187,187,187,187,127,253,205,203,186,187,187,191,220,220,253,221,220,187,170,170,170,187,187,237,207,236,220,186,170,153,152,153,170,187,205,223,220,186,169,136,136,136,153,154,188,206,220,219,169,136,119,119,119,137,154,205,207,204,185,152,119,102,102,119,137,170,204,220,202,152,119,101,85,102,119,137,172,204,187,169,135,101,85,85,102,120,154,188,219,202,152,118,85,68,85,103,137,170,204,203,169,135,101,84,69,86,120,154,188,219,186,152,118,101,85,85,103,137,171,205,187,169,136,118,101,85,103,120,154,189,203,203,169,135,118,102,102,120,137,172,207,204,186,153,136,119,119,120,137,171,205,204,219,170,153,136,136,136,153,171,204,221,223,203,170,169,152,153,154,171,189,223,252,238,219,186,170,170,170,187,189,222,255,207,221,221,188,187,187,188,204,222,255,221,221,237,205,205,220,204,206,223,255,255,141,187,237,204,203,205,207,221,223,255,240,0,0,0,189,203,186,170,153,153,154,170,170,187,124,220,203,186,170,170,170,171,187,188,220,204,187,170,153,153,153,154,170,187,204,203,186,169,153,136,136,136,153,154,188,220,187,170,152,136,119,119,136,153,170,187,186,170,152,135,119,119,119,136,153,171,187,170,153,135,118,102,102,119,136,154,171,185,169,136,118,102,102,102,119,136,154,171,154,152,119,102,85,85,102,120,137,171,185,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,154,185,169,136,118,101,85,86,103,120,154,186,154,152,135,118,102,102,102,120,137,171,186,170,152,135,118,102,102,119,136,154,187,171,169,152,135,119,119,119,136,154,172,186,186,169,136,135,119,120,136,154,171,204,187,186,169,152,136,136,137,153,171,205,203,203,186,169,153,153,153,154,187,204,222,188,204,187,170,170,170,171,187,205,206,219,222,204,203,187,187,187,188,204,221,237,156,203,187,171,170,186,187,187,205,221,208,0,0,0,188,187,170,153,153,153,153,170,171,187,156,204,187,170,153,153,154,170,171,188,220,188,186,169,153,153,153,153,154,171,188,187,186,169,152,136,136,136,153,154,171,187,170,169,152,135,119,119,136,137,154,171,186,169,152,135,119,119,119,120,137,154,186,170,152,135,118,102,102,119,120,137,171,169,169,136,118,102,102,102,119,136,154,170,153,152,119,102,101,102,102,119,137,154,169,153,135,118,101,85,102,103,120,153,170,153,152,119,102,101,85,102,119,137,154,169,153,135,118,102,85,102,103,120,154,170,154,152,135,118,102,102,102,119,137,170,169,169,136,119,118,102,102,119,136,154,187,170,153,136,119,119,119,119,136,153,171,186,186,153,136,135,119,119,136,153,171,187,171,170,153,136,136,136,136,153,170,188,187,187,170,153,153,153,153,153,170,187,220,188,187,170,170,153,153,170,170,188,205,219,205,203,187,170,170,170,171,188,205,221,156,187,186,170,170,170,170,187,204,221,192,0,0,0,204,203,186,170,170,154,170,170,187,187,140,205,187,186,170,170,170,171,188,204,220,204,186,186,169,153,153,154,170,171,204,204,203,169,153,136,136,137,153,154,187,203,187,170,152,136,119,120,136,153,170,188,187,170,152,135,119,119,119,136,153,171,187,170,169,135,118,102,102,119,136,153,171,170,169,136,118,102,86,102,119,137,154,187,154,152,119,102,85,85,102,120,137,171,170,169,135,118,85,85,86,103,121,154,187,170,152,119,102,85,85,102,119,137,170,169,169,136,118,101,85,86,103,120,154,170,170,152,135,118,102,102,102,120,153,171,186,186,152,135,118,102,102,119,137,170,188,171,170,152,135,119,119,119,136,154,188,186,186,169,152,136,119,120,136,154,187,203,171,186,169,153,136,136,137,154,171,204,203,219,170,170,153,153,153,154,187,205,220,188,187,186,170,170,170,171,187,204,222,219,204,204,187,187,187,187,188,204,206,221,123,187,186,170,170,170,187,203,204,204,192,0,0,0,255,255,255,255,223,220,254,205,204,221,127,255,255,255,255,223,255,255,223,255,255,255,255,255,253,255,223,255,221,255,255,255,255,255,252,220,189,223,253,223,255,255,255,255,252,220,204,187,204,255,223,255,253,255,253,203,170,170,172,187,190,223,255,239,223,220,169,152,137,170,203,255,255,255,255,204,169,134,102,120,171,205,255,253,255,253,186,134,84,69,121,172,207,223,255,255,204,168,100,34,70,138,190,223,255,255,253,202,134,66,36,104,171,207,255,255,255,220,169,117,68,86,138,205,223,254,255,253,219,152,118,102,137,188,223,255,255,255,252,186,153,136,137,187,221,255,255,255,253,204,186,169,154,188,221,255,255,255,255,255,220,188,187,204,204,255,255,255,255,255,220,253,221,221,223,255,255,255,255,255,255,255,220,253,255,255,255,255,255,255,255,255,253,223,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,127,205,223,253,238,223,255,255,255,255,240,0,0,0,255,255,223,255,253,255,252,255,252,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,253,255,223,255,223,255,255,255,255,252,252,204,207,221,255,252,255,255,255,207,221,187,186,172,203,253,255,255,255,255,255,170,153,137,170,175,255,255,255,207,252,186,135,102,121,171,221,255,255,255,255,203,151,84,69,121,188,255,255,255,255,255,185,100,34,70,138,221,221,255,255,253,220,150,66,35,105,187,207,255,255,255,252,185,117,68,87,155,191,255,255,207,255,255,169,118,102,137,251,255,255,255,255,255,203,169,136,153,173,255,255,255,255,255,255,220,170,171,204,255,255,255,255,255,223,255,219,187,191,207,255,255,255,255,255,255,221,253,253,252,255,255,255,255,255,255,255,220,220,223,255,255,255,255,255,255,255,255,255,255,255,221,255,255,255,255,255,255,255,255,255,255,255,255,255,127,223,253,255,250,189,255,255,255,255,240,0,0,0,137,153,152,136,136,136,136,152,152,154,106,203,154,169,153,153,170,154,171,170,218,154,169,137,153,137,153,137,138,153,170,154,170,153,136,136,136,136,137,169,170,170,137,169,152,136,136,136,136,137,154,185,169,169,152,120,119,119,119,136,137,154,169,137,152,135,118,118,119,119,136,153,154,168,152,136,118,102,102,119,119,136,137,152,137,152,135,118,102,102,103,120,136,155,168,153,135,118,101,85,102,119,136,152,168,137,136,135,118,101,86,103,119,136,153,152,153,120,119,102,101,102,103,120,138,153,137,152,120,119,102,102,103,119,136,171,152,153,137,135,119,118,103,119,136,137,169,154,154,152,119,119,119,119,120,137,155,152,169,153,136,136,135,120,136,136,154,169,138,153,153,137,136,136,136,153,138,170,169,171,170,152,136,137,136,137,154,186,169,172,186,185,170,153,153,154,153,170,173,169,186,171,171,169,154,154,186,170,156,187,139,169,168,153,152,136,153,154,170,171,160,0,0,0,255,255,254,221,204,204,220,221,237,239,223,255,237,220,187,187,188,204,222,255,255,255,254,203,186,170,170,171,188,222,255,255,253,203,170,153,153,153,170,188,221,255,253,203,169,152,135,136,137,154,188,255,254,220,169,136,119,119,119,136,154,188,223,220,186,152,118,102,102,103,137,171,205,238,187,152,118,101,85,86,103,137,171,223,203,169,135,101,85,85,86,120,154,189,220,186,152,118,85,69,85,103,137,171,221,203,169,135,101,85,69,86,120,154,188,220,186,152,118,101,85,85,103,137,172,221,204,169,135,118,85,85,102,120,155,205,236,202,169,135,102,102,102,120,154,188,223,220,186,153,135,119,119,120,137,171,223,255,220,186,153,136,136,136,153,171,205,255,254,203,186,153,153,153,154,171,205,255,255,253,220,203,170,170,170,188,205,255,255,255,239,221,203,187,187,204,221,255,255,255,255,255,253,221,221,222,222,255,255,255,207,254,254,254,239,221,223,255,255,255,240,0,0,0,155,170,153,169,137,137,153,152,153,187,107,171,186,170,153,153,153,186,171,190,251,155,170,153,153,153,153,169,172,155,186,201,185,169,153,136,137,136,137,170,170,186,153,153,136,136,119,135,136,137,170,170,169,154,136,135,119,119,120,136,153,170,169,154,153,135,118,102,103,119,136,153,187,169,153,136,119,102,102,102,120,136,153,185,154,152,135,102,85,86,103,120,137,170,153,153,135,118,101,85,86,119,120,138,169,153,153,135,102,85,85,102,120,153,171,168,153,152,118,102,85,86,103,120,153,169,153,152,152,119,102,102,103,120,152,155,169,153,152,135,119,102,119,119,137,153,202,154,169,136,135,119,119,119,136,154,171,153,186,153,136,136,135,136,136,137,155,185,171,169,170,136,136,136,136,154,186,171,169,234,170,154,169,154,137,153,154,172,171,172,218,186,170,154,153,170,171,186,204,170,251,219,186,170,170,186,187,187,252,251,122,153,153,153,153,153,153,154,170,171,160,0,0,0,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,251,169,170,187,255,255,255,255,255,255,251,152,119,137,175,255,255,255,255,255,255,168,84,70,138,255,255,255,255,255,255,218,116,18,71,171,255,255,255,255,255,255,167,66,36,121,191,255,255,255,255,255,186,134,68,87,175,255,255,255,255,255,255,185,135,119,155,255,255,255,255,255,255,251,186,154,171,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,240,0,0,0,138,152,136,135,119,247,111,136,143,170,89,250,175,175,138,135,138,168,250,169,249,154,175,152,154,121,137,120,154,250,255,172,136,143,135,136,168,137,154,135,175,250,122,169,135,120,119,152,120,137,170,250,168,152,153,135,120,135,119,135,135,250,232,139,151,118,136,119,103,119,120,120,138,135,169,143,119,119,103,151,136,120,153,168,121,137,119,118,102,118,119,119,143,137,152,249,136,151,102,87,103,120,119,169,136,120,135,135,102,102,102,103,104,151,249,136,168,120,135,118,102,119,104,119,136,137,153,168,120,119,119,118,103,118,119,137,169,138,135,135,119,104,118,118,136,154,154,170,167,151,135,135,135,119,153,119,154,135,154,153,121,121,118,135,152,153,168,136,152,154,169,153,151,152,138,152,154,255,168,250,127,138,143,152,138,168,255,249,168,175,153,153,136,153,170,152,154,170,175,170,250,249,154,250,249,138,168,152,175,169,159,250,137,135,120,152,135,138,135,153,144,0,0,0,255,255,255,255,255,251,255,191,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,250,191,255,255,255,255,255,255,255,255,186,136,171,255,255,255,255,255,255,255,248,101,87,159,255,255,255,255,255,255,255,132,18,88,175,255,255,255,255,255,255,248,82,20,143,255,255,255,255,255,255,251,150,84,104,175,255,255,255,255,255,255,250,168,137,175,255,255,255,255,255,255,255,255,235,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,111,251,255,255,255,191,255,255,255,255,240,0,0,0,255,239,254,239,255,254,238,229,255,255,255,254,238,238,238,239,255,255,255,255,255,255,254,238,238,238,78,238,238,238,238,239,255,255,95,255,255,245,255,255,255,255,255,255,255,254,238,94,238,238,238,238,238,238,238,238,238,238,229,229,238,238,238,239,255,85,245,95,245,255,95,95,255,255,244,255,255,255,255,255,85,255,255,255,255,245,255,245,255,95,79,254,238,238,238,238,238,238,238,227,229,238,94,238,238,238,229,78,238,94,94,229,94,94,85,238,238,84,238,229,94,229,230,94,238,238,238,239,245,255,245,255,245,255,255,255,255,255,255,95,245,255,95,255,245,255,255,255,255,255,245,255,95,245,95,255,255,255,255,255,244,255,255,255,255,255,255,255,255,255,255,255,255,245,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,95,255,255,255,254,255,254,255,95,254,255,255,255,255,255,255,254,255,254,254,255,255,255,254,255,240,0,0,0,120,246,102,104,118,103,103,152,120,127,104,152,159,248,247,254,143,255,159,255,159,136,127,136,159,121,159,255,143,159,249,150,153,151,120,103,247,152,255,121,153,248,119,248,137,151,120,137,247,143,255,255,120,153,121,151,151,119,153,127,121,153,152,119,159,103,103,103,120,152,159,153,137,246,159,121,120,118,102,248,120,137,120,248,135,136,153,135,119,105,121,120,247,159,119,249,153,118,119,119,104,135,120,159,151,136,120,137,151,118,119,119,137,143,143,103,137,152,137,120,119,135,120,121,120,150,104,159,168,151,120,120,143,137,121,143,103,255,143,153,119,102,102,118,134,248,246,153,159,127,137,151,121,136,111,136,137,104,255,255,249,152,137,248,255,152,159,247,120,121,249,119,137,248,151,137,249,152,119,159,159,137,159,153,152,159,153,159,152,137,152,255,159,248,249,136,159,127,249,103,255,153,152,249,255,137,159,255,159,249,89,119,152,104,150,119,104,137,247,111,96,0,0,0,104,137,120,119,103,136,136,255,121,153,105,249,249,136,135,121,143,249,248,249,247,143,152,120,121,249,248,136,121,127,249,151,255,143,152,120,119,103,248,249,255,249,120,248,136,135,136,119,152,247,152,255,152,159,248,152,135,118,121,151,120,137,140,119,136,120,119,119,136,119,120,121,159,136,121,119,119,119,103,119,119,143,153,151,135,119,120,135,120,118,119,120,159,153,247,119,152,118,118,119,104,127,120,255,249,120,136,135,136,118,103,136,121,120,249,135,137,151,119,104,103,119,119,119,142,120,120,138,136,119,135,119,103,136,136,143,135,137,136,119,118,119,121,119,119,143,136,121,248,119,120,119,136,119,120,152,137,137,255,248,136,153,119,152,120,135,153,153,152,248,152,255,255,121,136,119,121,143,136,248,136,255,136,120,153,159,136,249,248,136,153,185,247,136,153,249,153,159,255,153,255,143,152,143,137,153,248,153,143,249,95,137,119,135,153,120,136,119,248,143,128,0,0,0,94,222,229,222,238,237,221,222,238,238,78,237,221,221,221,222,238,238,238,238,238,238,238,237,221,77,221,221,221,221,221,222,238,238,238,238,238,94,238,238,238,238,238,238,238,238,238,221,93,221,221,221,221,221,221,221,221,213,69,221,221,221,221,222,238,238,229,238,238,229,238,238,94,238,238,238,229,229,238,229,84,238,238,238,238,238,69,238,238,85,238,238,229,237,221,221,221,221,221,221,221,93,221,221,221,85,221,221,85,93,77,221,221,69,221,93,221,221,221,221,84,221,221,221,221,221,221,222,94,238,94,238,238,94,238,238,229,238,238,238,78,238,78,238,238,238,238,238,238,94,238,228,229,238,238,238,238,238,238,238,238,238,229,238,238,238,94,238,238,238,238,238,238,238,85,238,238,238,238,238,238,238,238,238,238,229,94,238,238,238,238,237,238,237,238,238,238,238,238,238,238,229,237,237,238,238,238,94,238,238,237,237,238,229,238,238,237,237,237,238,224,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,159,255,249,248,249,79,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,254,255,255,255,255,255,255,255,248,100,104,159,255,255,255,255,255,255,255,133,18,111,255,255,255,255,255,255,255,255,82,20,223,255,255,255,255,255,255,255,249,84,95,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,89,255,255,255,250,255,255,255,255,255,240,0,0,0,247,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,247,127,255,255,255,111,255,246,246,255,127,255,255,255,255,246,255,255,255,255,247,246,255,246,255,255,255,246,255,255,102,246,255,246,255,255,255,255,255,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+810344);
/* memory initializer */ allocate([87,103,111,255,255,255,253,191,247,247,111,102,111,102,246,255,255,246,246,255,117,118,245,102,102,102,255,255,246,255,255,245,87,102,255,255,127,255,255,246,255,86,86,117,119,255,111,255,255,255,247,246,246,246,68,245,246,255,255,255,255,255,255,102,86,117,86,246,255,253,198,175,246,111,255,85,87,95,127,255,255,247,255,255,101,111,255,104,127,255,255,111,255,246,246,95,101,111,111,255,255,255,246,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,246,111,255,255,255,255,111,255,255,255,255,255,111,255,255,255,255,255,255,255,111,255,255,255,255,255,246,255,255,111,255,255,255,255,255,95,127,127,255,255,127,255,127,255,255,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,246,111,255,255,255,255,255,255,255,255,255,18,255,255,255,255,255,255,255,255,255,97,21,255,255,255,255,255,255,255,255,255,245,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,159,255,255,255,255,255,255,255,255,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,238,238,238,222,238,238,221,222,238,238,238,237,221,221,221,222,238,238,238,238,238,238,238,237,221,221,221,221,221,221,221,222,238,238,238,238,94,238,238,238,238,238,238,238,238,238,94,237,213,85,221,221,221,221,221,221,221,221,221,221,221,221,221,222,238,238,229,229,238,238,238,238,238,238,238,238,238,229,238,229,238,238,238,238,238,238,94,94,238,85,84,238,238,238,238,237,221,221,213,93,68,93,221,221,221,221,93,213,213,93,221,211,221,221,221,221,221,221,221,93,212,53,93,221,221,221,221,213,94,228,84,83,238,238,238,238,238,238,238,229,238,238,94,238,238,238,238,238,229,238,94,238,229,94,238,94,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,94,238,228,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,229,238,238,237,238,237,221,237,237,237,237,238,238,238,238,238,238,238,238,238,237,238,238,237,238,237,237,238,224,0,0,0,189,220,205,204,204,220,221,255,255,255,221,239,237,220,204,204,204,223,239,255,255,223,253,220,187,187,170,187,205,223,255,253,237,204,187,169,153,153,170,188,223,255,205,204,186,153,136,136,137,154,188,223,236,220,186,152,135,119,119,136,154,188,238,221,186,168,135,118,102,103,136,154,205,221,219,169,135,102,102,102,103,137,171,205,204,169,135,118,85,85,86,119,137,189,220,203,152,118,101,85,85,102,120,154,189,204,169,135,101,85,85,86,103,137,173,205,202,152,118,101,85,85,102,120,154,204,220,185,135,102,85,85,86,119,138,188,221,219,169,135,102,85,102,103,137,171,205,236,202,152,135,102,102,119,136,154,188,222,220,186,153,135,119,119,137,154,188,220,254,236,186,153,136,136,137,154,188,205,223,254,220,187,169,153,154,170,188,205,238,255,255,220,203,186,171,187,204,221,222,223,255,255,237,204,204,204,204,221,239,237,223,255,223,221,221,220,204,205,237,206,176,0,0,0,238,238,238,222,238,238,221,222,238,238,238,238,237,221,221,222,238,238,238,238,238,238,238,238,238,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,78,238,237,221,221,221,221,221,221,221,221,212,221,221,221,221,222,238,238,238,78,78,78,238,238,238,238,238,238,238,238,238,238,78,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,228,227,77,221,221,221,221,221,221,221,221,221,221,77,77,221,221,221,221,221,221,221,68,77,77,221,221,221,221,78,228,238,62,78,238,238,238,238,238,238,238,227,238,229,238,238,238,238,238,238,238,238,228,238,238,238,78,238,238,238,238,238,238,238,238,78,62,238,238,238,238,238,238,238,238,238,228,238,238,238,238,238,238,238,238,78,238,78,238,238,238,238,238,238,238,238,238,238,238,238,238,237,237,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,224,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,156,187,170,170,170,154,170,171,188,205,187,204,187,187,170,170,170,171,188,205,220,188,203,170,169,153,153,170,171,171,205,219,203,170,153,153,136,136,137,154,187,204,171,170,169,152,136,136,136,137,154,187,186,186,153,136,119,119,119,120,137,154,187,170,169,136,119,118,102,119,120,137,171,186,170,152,119,102,102,102,103,120,153,170,170,153,135,118,102,102,102,119,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,102,101,85,86,103,136,154,170,169,136,118,102,85,86,102,120,153,170,170,153,135,118,102,86,102,119,137,154,170,169,152,119,102,102,102,119,136,153,170,171,169,136,119,118,102,119,120,137,171,171,186,153,136,119,119,119,136,137,170,186,187,186,153,152,136,136,136,137,154,171,188,204,186,153,152,136,136,153,170,187,187,221,204,186,169,153,153,153,170,187,204,189,221,203,187,170,170,170,170,187,188,203,188,203,186,170,169,154,170,170,186,188,144,0,0,0,155,186,169,153,153,153,153,154,187,204,187,204,202,170,170,154,169,170,187,189,220,188,187,170,169,153,152,153,169,171,187,203,186,170,153,136,136,136,137,153,171,187,170,169,152,136,136,119,136,136,154,171,170,170,152,136,119,119,119,120,136,153,186,154,153,136,119,118,102,119,119,137,154,169,153,152,119,102,102,102,119,120,137,170,153,152,135,118,102,102,102,119,136,154,153,153,136,118,102,102,102,103,119,137,153,153,152,119,102,102,86,102,103,120,153,153,169,135,118,102,102,102,102,119,137,169,153,152,135,118,102,102,102,119,136,153,153,169,136,119,102,102,102,119,120,137,169,170,153,136,119,118,103,119,120,137,154,154,169,152,135,119,119,119,120,136,154,185,171,170,153,136,135,119,136,137,153,171,171,202,170,153,136,136,136,137,153,171,187,187,187,170,153,153,153,153,153,170,188,188,204,203,170,154,153,154,154,171,188,204,188,202,170,169,153,153,153,154,170,171,160,0,0,0,171,186,170,153,153,153,153,154,171,188,187,204,187,170,153,153,153,170,171,187,204,188,186,170,153,153,137,153,153,170,188,186,186,169,153,136,136,136,136,153,170,187,170,169,152,136,135,119,136,136,153,170,170,169,152,136,119,119,119,119,136,153,170,154,153,136,119,119,103,119,119,137,154,153,169,136,119,118,102,102,119,120,137,169,153,152,135,118,102,102,102,119,120,153,153,152,135,119,102,102,102,102,119,137,153,153,136,119,118,102,102,102,103,120,153,153,153,135,119,102,102,102,103,119,137,153,153,152,119,118,102,102,102,119,136,153,153,153,136,119,102,102,102,119,120,137,169,154,152,135,119,119,103,119,120,137,154,154,169,152,135,119,119,119,120,136,153,169,171,169,152,136,119,119,136,136,153,171,170,186,169,152,136,136,136,137,153,170,186,187,186,169,153,153,137,153,153,170,187,188,203,187,170,169,153,153,170,170,188,203,188,187,170,153,153,153,153,154,170,187,160,0,0,0,156,186,170,154,153,153,153,154,171,203,171,204,186,170,169,153,169,170,170,188,204,172,186,170,153,153,153,153,154,170,188,187,203,169,153,136,136,136,137,154,171,204,170,170,153,136,119,119,120,136,153,170,170,186,152,136,119,119,119,120,137,154,170,154,153,136,119,118,103,119,119,136,154,153,153,136,119,102,102,102,103,120,137,169,153,152,119,118,102,102,102,103,136,137,153,152,135,119,102,102,102,102,119,136,169,153,152,135,102,102,102,102,103,120,137,153,153,135,118,102,102,102,103,119,137,153,154,136,135,118,102,102,102,119,136,154,153,169,136,119,118,102,102,119,120,137,169,170,153,135,119,119,103,119,119,137,154,170,186,152,136,119,119,119,120,137,153,170,171,170,152,136,135,119,136,137,154,171,170,186,170,153,136,136,136,137,154,170,187,204,186,169,169,153,152,153,153,171,171,172,204,186,170,169,153,154,154,187,188,203,188,187,170,169,153,153,154,154,170,187,160,0,0,0,155,187,170,170,169,170,170,187,188,221,203,220,187,186,170,170,170,171,187,205,221,204,187,170,169,153,153,154,170,188,205,219,187,170,153,136,136,136,153,154,188,204,171,170,153,136,136,136,136,137,154,171,186,170,153,136,119,119,119,120,137,154,187,170,153,136,119,119,102,119,120,137,171,170,169,152,119,102,102,102,103,120,153,170,170,152,135,118,102,102,102,119,136,154,169,169,136,118,102,85,86,102,120,137,170,170,152,135,102,101,85,102,103,136,154,169,169,136,118,102,85,86,102,120,137,170,170,153,135,118,102,102,102,119,136,154,170,185,152,119,102,102,102,103,120,153,170,170,169,136,119,118,102,119,120,137,154,170,186,169,136,119,119,119,120,137,154,186,188,186,153,136,136,136,136,137,154,171,172,203,186,153,152,136,136,137,154,171,187,220,203,186,169,153,153,153,170,171,188,205,221,203,186,170,170,170,170,187,188,219,189,204,187,170,170,170,154,170,187,188,144,0,0,0,189,220,221,204,204,205,222,237,255,255,207,255,238,221,220,205,205,222,255,255,255,255,237,220,203,187,187,188,205,239,255,255,254,220,187,170,169,170,171,205,239,255,221,204,186,153,136,136,153,171,205,239,253,220,186,153,136,119,120,137,171,206,254,221,202,152,135,118,102,119,137,171,223,253,203,169,135,102,85,86,119,154,188,238,220,186,151,118,85,85,86,120,154,205,237,203,152,118,85,68,85,103,137,172,221,220,185,135,101,84,68,86,120,154,188,221,203,168,118,85,68,85,103,137,171,205,221,186,152,118,85,85,102,120,154,205,222,220,169,135,118,102,102,120,154,188,221,253,219,169,135,119,119,120,153,172,205,223,253,203,169,136,136,136,153,171,205,239,255,253,203,170,153,153,154,171,205,239,223,254,237,203,186,170,171,188,204,222,255,255,255,253,220,188,203,204,205,222,255,239,255,255,254,238,221,222,222,239,255,255,223,255,255,238,237,221,238,223,238,254,176,0,0,0,189,220,204,204,203,204,204,239,255,223,205,255,205,204,204,204,189,223,255,255,255,253,220,187,187,171,186,188,220,223,255,253,220,203,170,169,153,154,187,188,255,255,204,219,169,153,136,136,137,171,204,223,252,220,169,152,135,119,120,137,171,205,255,188,186,152,119,102,102,119,137,171,207,252,187,169,135,102,85,86,119,137,171,207,204,169,135,102,85,85,86,120,154,189,252,187,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,189,220,203,168,118,85,85,85,103,137,171,205,236,186,135,118,85,85,102,120,154,189,205,203,169,135,102,102,102,119,137,171,204,221,219,153,135,119,119,119,137,171,188,207,253,187,169,136,136,136,137,155,204,252,255,221,186,154,153,153,153,170,188,253,223,253,253,203,170,170,170,170,188,207,253,255,255,220,203,187,187,187,205,221,223,223,255,255,253,253,204,204,252,205,254,254,223,255,253,221,252,220,221,204,206,253,176,0,0,0,207,221,220,204,204,205,221,239,255,255,253,254,221,204,204,204,204,206,255,255,255,239,221,203,187,170,170,187,204,223,255,253,237,203,170,169,153,153,170,188,223,255,221,203,170,153,136,136,137,154,189,239,252,219,186,152,135,119,119,136,154,189,255,204,186,152,119,102,102,103,137,171,205,252,203,169,135,102,85,86,103,137,171,223,204,169,135,102,85,85,86,120,154,189,220,202,152,118,85,85,85,102,120,171,205,204,169,135,101,85,69,86,103,138,189,220,202,152,118,85,85,85,103,121,171,205,220,185,135,102,85,85,102,120,154,189,222,219,169,135,102,102,102,119,137,172,205,253,203,152,135,118,103,119,137,171,205,223,253,186,153,136,119,120,137,170,188,221,255,253,186,169,153,137,153,170,188,221,239,255,237,203,170,170,170,171,188,221,255,255,255,237,203,187,187,187,204,221,239,239,255,255,254,221,204,204,221,238,255,254,255,255,255,253,237,221,221,221,237,238,192,0,0,0,174,205,204,236,205,204,205,239,255,255,221,253,220,220,205,204,221,237,223,255,255,207,223,204,187,187,187,188,204,223,255,253,253,203,187,170,153,169,171,205,255,255,222,203,186,153,136,136,137,170,205,255,253,220,170,152,135,119,119,136,154,189,253,204,186,153,135,102,102,103,136,172,207,236,203,169,135,102,85,86,103,137,172,221,221,186,151,102,85,85,86,120,154,188,220,203,152,118,85,84,85,103,121,171,221,220,185,135,101,84,69,86,119,154,188,221,203,152,118,85,85,85,103,137,172,189,220,185,151,102,85,85,102,120,154,205,205,219,169,135,102,102,102,120,153,172,220,254,202,152,135,118,103,120,153,172,205,205,237,186,153,136,120,136,153,171,205,220,255,252,186,169,153,137,153,171,188,221,207,255,253,187,170,170,170,171,203,205,220,255,255,221,204,187,187,188,204,221,255,223,255,255,238,222,220,205,223,238,255,253,223,255,238,220,221,204,204,204,204,253,176,0,0,0,174,237,222,221,221,222,223,255,255,255,205,254,255,238,221,221,206,255,255,255,255,239,238,220,203,203,187,204,222,239,255,253,254,220,203,170,170,170,188,205,239,255,223,220,187,169,153,153,154,171,223,255,253,221,186,169,136,119,120,137,171,222,255,221,219,169,135,118,102,119,137,188,254,253,219,185,135,102,85,86,119,154,189,255,221,202,152,102,85,85,86,120,155,206,253,235,169,118,85,68,69,103,137,189,255,221,186,151,101,84,68,86,120,155,205,237,219,169,118,85,68,85,103,137,188,253,237,203,152,118,85,85,102,120,171,223,253,236,185,135,102,102,102,120,154,188,237,223,252,169,135,119,119,120,154,172,222,239,255,203,169,136,136,136,154,187,206,254,255,254,203,186,153,153,170,171,205,239,239,255,237,220,203,187,187,188,205,238,255,255,255,254,220,204,204,204,221,223,255,255,255,255,255,239,222,222,239,255,255,255,191,255,255,221,237,205,221,204,221,222,176,0,0,0,172,187,187,170,170,170,171,187,204,222,172,220,203,187,186,170,170,187,205,221,254,204,203,186,170,153,153,170,171,188,222,219,203,170,169,153,136,137,153,171,188,237,187,186,153,136,136,136,136,153,171,204,203,186,169,136,119,119,119,120,153,171,204,171,169,136,119,102,102,119,120,153,188,186,170,152,119,102,102,102,103,136,154,187,170,152,135,102,85,85,102,119,137,171,186,169,136,118,101,85,85,103,120,154,187,170,152,135,102,85,85,86,119,137,171,186,169,136,118,101,85,86,103,120,154,187,187,169,135,102,101,86,102,119,137,171,187,186,152,119,102,102,102,119,137,154,187,187,169,152,119,119,103,119,136,154,187,188,203,169,152,135,119,119,136,153,171,203,204,203,169,152,136,136,137,154,171,188,189,220,187,170,153,153,153,154,171,188,204,238,220,203,170,170,170,170,187,188,205,205,253,220,203,187,187,187,187,204,221,236,189,221,204,203,187,187,187,187,203,204,160,0,0,0,138,169,153,153,152,153,153,154,171,188,170,187,186,169,153,153,153,154,187,205,220,171,186,169,153,153,136,153,154,170,188,201,170,169,152,136,136,136,137,153,171,203,171,169,152,136,119,119,120,136,153,171,185,169,136,135,119,119,119,119,136,154,170,154,152,135,119,118,102,119,120,137,170,169,153,136,119,102,102,102,119,120,137,169,153,152,135,102,102,102,102,119,136,154,153,153,135,118,102,102,102,103,120,137,153,137,136,119,102,102,102,102,119,120,154,153,152,135,118,102,102,102,103,120,137,153,153,152,135,118,102,102,102,119,136,153,153,169,136,119,118,102,102,119,120,137,169,154,153,135,119,119,103,119,120,137,154,154,170,153,136,119,119,119,120,137,154,186,171,169,152,136,136,136,136,153,153,171,171,187,170,153,136,136,136,137,153,170,186,188,187,170,153,153,153,153,154,170,171,173,221,187,170,169,169,154,170,171,187,219,172,203,170,169,153,153,153,154,170,171,144,0,0,0,155,170,170,153,153,153,154,170,187,204,186,203,187,170,170,169,170,170,187,204,220,171,187,170,153,153,153,153,170,171,204,202,186,169,153,136,136,136,137,154,171,203,171,169,152,136,119,119,136,137,154,187,186,170,152,136,119,119,119,120,137,154,187,154,153,136,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,120,153,170,154,152,135,102,102,102,102,119,136,154,169,153,135,118,102,85,102,102,120,137,170,154,152,119,102,101,85,102,119,136,154,169,169,135,118,102,86,102,103,120,137,170,170,152,119,102,102,102,102,119,137,154,170,169,136,119,102,102,102,119,136,154,170,170,169,136,119,119,103,119,136,137,171,171,186,153,136,119,119,119,136,137,170,186,187,170,153,136,136,136,136,153,154,171,171,203,170,153,152,136,137,153,154,171,187,204,203,186,169,153,153,154,170,171,188,189,220,203,187,170,170,170,170,187,188,219,188,203,187,170,170,154,170,170,170,187,144,0,0,0,171,186,170,169,153,154,170,170,188,189,187,204,187,186,170,169,169,170,187,205,221,188,186,170,153,153,153,153,170,171,189,203,187,169,153,136,136,136,137,154,171,204,171,170,153,136,119,119,136,137,154,171,186,170,152,136,119,119,119,120,137,154,187,170,153,135,119,102,102,103,120,137,171,170,169,136,119,102,102,102,103,120,153,170,154,152,119,102,102,102,102,119,136,154,170,153,135,118,102,85,86,102,120,137,170,153,152,119,102,101,86,102,103,136,154,169,169,135,118,102,101,102,103,120,153,170,154,152,119,118,102,102,102,119,136,154,170,169,136,119,102,102,102,119,136,154,170,170,169,136,119,118,103,119,120,153,171,171,186,153,136,119,119,119,136,153,170,187,188,186,153,136,136,136,136,137,170,187,188,204,170,153,152,136,137,153,154,187,203,205,203,170,169,153,153,153,170,171,204,189,220,203,187,170,170,170,187,187,204,219,173,203,187,186,170,170,170,170,187,188,160,0,0,0,172,187,186,170,170,170,171,187,205,222,188,220,203,187,170,170,170,187,204,221,253,188,203,186,169,153,153,170,171,188,206,219,187,170,153,152,136,137,153,171,188,221,187,186,153,136,136,136,136,153,171,188,203,186,153,136,119,119,119,136,137,171,204,171,169,136,119,102,102,119,120,154,171,186,169,152,119,102,102,102,103,136,154,187,170,153,135,102,101,85,102,119,137,171,186,169,136,118,101,85,85,103,120,153,187,170,152,119,102,85,85,86,119,137,171,186,169,136,118,101,85,86,103,120,154,187,170,153,135,118,101,86,102,119,137,171,187,186,152,119,102,102,102,119,137,154,187,187,170,152,119,118,103,119,136,154,171,187,203,169,152,135,119,119,136,153,171,187,204,186,169,152,136,136,137,153,170,188,188,204,187,170,153,153,153,154,171,188,220,221,220,187,170,170,170,170,171,188,205,206,253,220,203,187,171,187,187,204,205,220,189,220,204,187,187,170,171,187,188,204,160,0,0,0,190,237,221,221,221,221,221,239,255,255,190,255,237,221,205,221,222,255,255,255,255,239,237,220,204,188,188,221,222,255,255,253,221,220,187,170,170,187,204,222,255,255,222,220,186,169,153,153,154,188,222,255,253,220,186,153,136,136,136,154,188,223,255,221,203,169,135,118,103,120,154,189,255,253,220,169,135,102,85,102,120,155,205,254,221,186,152,118,84,69,86,137,171,238,253,219,169,118,84,68,69,103,154,189,238,221,186,152,101,68,68,86,120,171,222,237,236,169,135,85,68,69,103,154,188,237,237,203,152,118,85,85,103,137,171,206,238,253,186,152,118,102,103,120,154,189,238,255,220,186,152,135,119,136,154,188,222,239,254,220,186,153,136,153,154,187,205,254,239,254,220,186,170,170,170,187,205,223,239,255,254,220,204,203,187,188,205,223,255,255,255,255,237,221,204,205,221,222,255,255,255,255,255,255,222,237,238,239,255,255,190,255,255,238,238,222,237,221,238,254,176,0,0,0,172,220,204,204,204,204,221,223,254,255,188,237,221,204,204,204,204,222,255,255,255,205,220,204,187,171,171,188,205,239,255,252,220,203,170,169,153,154,171,204,255,254,205,203,170,153,136,136,153,171,205,239,252,203,186,152,135,119,119,137,171,206,254,204,186,152,119,102,102,119,137,171,222,220,203,169,135,102,85,86,119,138,188,222,204,185,135,102,85,85,86,120,155,205,220,186,152,118,85,68,69,103,137,172,221,204,185,135,101,84,69,86,120,154,205,221,203,152,118,85,85,85,103,137,172,205,204,186,152,118,85,85,102,120,154,204,205,219,169,135,102,102,102,120,154,188,221,221,203,169,135,119,119,120,137,171,221,222,237,187,169,136,136,136,153,171,204,221,255,236,203,170,153,153,154,170,188,221,223,255,254,203,186,170,170,187,204,237,221,255,255,238,204,203,187,204,204,221,238,223,255,255,254,237,220,205,205,221,222,237,207,255,254,238,221,221,205,204,221,221,176,0,0,0,205,221,220,204,204,204,205,222,255,255,221,237,220,204,203,187,204,205,238,255,255,222,221,203,187,170,170,187,205,223,255,253,220,187,170,153,153,153,171,188,222,255,205,203,169,152,136,136,137,170,188,239,252,203,169,152,119,119,119,137,155,205,238,204,186,152,119,102,102,103,137,171,205,236,202,152,135,102,85,86,103,137,172,222,203,169,135,102,85,85,86,120,154,205,220,186,152,118,85,84,85,103,137,171,205,204,169,135,101,84,69,86,120,154,188,220,202,152,118,85,85,85,103,137,171,204,204,186,135,102,85,85,102,120,154,188,221,203,169,135,102,102,102,120,153,171,221,221,202,169,135,119,119,120,137,171,205,222,220,186,169,136,136,136,137,170,188,221,238,220,187,169,153,153,153,170,188,222,223,255,221,203,186,170,170,171,188,221,253,255,255,237,204,187,187,187,204,221,239,223,255,254,237,221,204,204,205,222,239,254,207,255,255,222,221,221,205,221,222,238,192,0,0,0,190,221,204,204,204,205,223,238,255,255,205,222,204,204,204,204,205,222,255,255,255,221,204,187,187,187,187,187,205,223,255,253,220,203,186,169,153,170,171,205,255,255,204,187,169,152,136,136,153,171,207,255,252,203,169,152,119,119,119,137,171,206,255,205,186,152,119,102,102,119,137,171,221,252,203,152,135,101,85,86,119,138,189,255,204,185,135,101,85,85,86,120,154,205,237,203,152,118,85,68,85,103,137,171,221,204,185,135,101,84,69,86,120,154,189,221,203,168,118,85,85,85,103,137,171,205,237,186,152,118,85,85,102,120,154,189,205,252,185,135,118,102,102,120,153,171,253,255,203,169,135,119,119,120,137,171,205,223,253,187,169,152,136,136,137,171,204,221,255,222,204,170,153,153,153,170,188,221,207,255,221,203,187,186,170,187,188,205,237,255,255,221,221,204,187,204,204,205,221,223,255,255,254,237,220,205,237,222,223,238,191,255,255,254,237,220,221,204,204,221,176,0,0,0,189,221,220,204,220,205,221,222,255,239,190,238,221,220,204,205,221,222,255,255,254,222,221,203,187,187,187,204,222,239,255,253,221,203,186,170,170,171,188,206,255,254,205,219,186,153,152,153,154,172,221,255,253,220,186,153,135,119,120,153,188,222,238,220,186,152,135,118,102,120,154,188,223,252,219,169,135,102,85,102,120,154,189,254,204,186,152,102,85,69,86,120,171,206,221,203,168,118,85,68,69,103,138,188,222,221,186,135,101,68,68,86,120,155,205,221,219,169,134,85,68,85,103,137,188,222,221,203,152,118,85,85,103,137,171,205,222,252,186,152,118,102,103,120,154,188,221,255,220,170,152,119,119,136,153,171,205,222,254,219,186,152,136,137,154,171,205,222,239,238,204,186,169,153,154,171,204,237,239,255,253,220,187,187,187,187,205,222,239,255,255,254,221,205,204,204,204,222,239,239,255,255,254,237,221,221,221,238,255,254,191,238,238,254,237,221,221,221,222,238,192,0,0,0,156,203,187,186,186,187,187,204,205,222,172,221,204,187,187,187,187,188,205,239,254,205,203,187,170,170,170,170,187,205,239,219,203,186,169,153,153,153,154,187,205,237,188,186,169,136,136,136,137,154,187,205,219,186,169,136,119,119,119,136,154,188,220,187,169,152,119,102,102,119,137,154,188,203,186,152,119,102,85,102,119,137,171,204,187,169,135,102,85,85,102,120,154,188,187,186,152,118,85,84,85,103,136,154,187,187,169,135,101,84,69,86,120,137,171,187,186,152,118,101,85,85,103,136,170,187,187,169,135,118,101,85,102,120,154,188,187,186,169,135,118,102,102,119,137,171,203,204,186,152,135,119,119,120,137,154,188,188,203,186,153,136,136,136,137,154,187,204,205,203,170,153,152,137,153,154,187,205,204,221,203,186,170,169,154,170,188,204,220,222,237,204,187,186,170,171,187,204,205,205,254,237,220,204,187,203,204,205,221,236,173,221,204,204,187,187,187,203,204,204,160,0,0,0,155,186,170,169,169,154,170,171,187,204,171,220,187,170,170,170,170,171,187,205,237,187,187,170,153,153,153,153,170,187,205,202,187,169,153,136,136,136,153,154,187,220,171,170,152,136,119,119,136,137,154,187,186,170,152,136,119,119,119,120,137,171,187,170,153,135,119,102,102,103,120,137,171,186,169,136,119,102,102,102,103,120,154,187,154,152,135,102,101,86,102,119,137,154,169,169,135,118,101,85,86,103,120,153,170,170,152,119,102,85,85,102,119,137,154,170,169,135,118,102,85,102,103,120,153,170,170,152,135,118,102,102,102,120,137,171,170,169,152,119,102,102,102,119,136,154,186,170,169,136,119,119,119,119,136,153,171,187,186,153,136,119,119,119,136,153,171,187,188,186,153,152,136,136,136,153,170,188,188,203,186,169,153,153,153,153,170,187,203,205,203,187,170,169,153,170,170,187,204,205,236,220,187,187,170,170,187,188,205,220,173,204,203,186,170,170,170,171,187,188,160,0,0,0,171,186,170,153,153,153,153,170,187,204,171,203,186,170,169,153,154,170,187,204,220,188,186,169,153,153,137,153,154,171,204,202,186,169,152,136,136,136,137,154,171,203,170,169,152,136,119,119,120,137,154,187,186,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,153,135,118,102,85,86,103,120,137,170,153,136,119,102,101,86,102,119,136,154,169,153,135,118,102,102,102,103,120,137,170,154,152,119,102,102,102,102,119,137,154,169,169,136,119,102,102,102,119,136,153,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,137,170,186,187,170,153,136,136,136,136,153,154,187,187,203,170,153,152,136,137,153,170,171,203,188,203,186,169,153,153,153,170,187,205,188,220,203,186,170,170,170,170,187,204,220,172,203,186,170,170,170,170,170,187,204,160,0,0,0,155,186,170,169,153,153,154,170,187,204,171,204,186,170,170,170,170,170,187,204,221,171,186,170,153,153,153,153,170,171,205,202,186,169,152,136,136,136,153,154,187,203,171,169,152,136,119,119,136,137,154,188,186,186,152,136,119,119,119,120,137,154,187,154,153,135,119,102,102,119,120,137,171,169,169,136,119,102,102,102,103,136,154,170,154,152,119,102,102,86,102,119,137,170,169,169,135,118,101,85,86,103,120,154,170,153,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,137,170,154,152,135,118,102,102,103,119,137,170,170,169,136,119,102,102,103,119,136,154,170,170,169,136,119,119,119,119,136,153,171,171,170,153,136,119,119,119,136,137,170,186,187,170,153,136,136,136,136,153,170,172,187,203,170,169,153,153,153,153,170,187,203,189,203,186,170,153,153,154,170,171,205,205,220,203,187,170,170,170,187,187,204,220,172,204,187,170,170,170,170,170,171,204,160,0,0,0,155,187,170,170,170,170,171,187,188,204,155,204,203,187,170,170,171,187,205,221,237,188,203,186,170,153,154,170,187,204,221,203,203,170,153,153,137,153,154,171,204,220,187,186,153,136,136,136,136,154,171,205,202,186,153,136,119,119,119,136,154,187,204,171,169,136,119,102,102,119,136,154,188,186,170,152,119,102,85,102,119,137,171,187,170,153,135,102,85,85,102,120,154,171,186,169,152,118,85,85,85,103,136,154,187,170,153,135,101,84,69,86,120,137,171,186,186,152,118,101,85,86,103,136,154,187,171,169,135,118,101,86,102,120,153,171,187,186,153,135,118,102,102,119,137,170,187,188,186,152,135,119,119,119,137,154,171,187,203,170,152,136,136,136,137,154,171,203,204,203,170,153,152,136,153,154,171,188,188,220,203,170,169,153,153,170,171,188,220,206,220,203,187,170,170,170,187,188,205,205,237,221,204,203,187,187,187,204,205,236,173,204,204,187,187,187,187,187,187,204,160,0,0,0,206,254,237,221,221,221,221,222,238,238,191,255,254,253,221,221,222,238,255,255,254,255,254,237,204,203,204,204,222,239,255,238,255,236,203,186,170,171,188,221,255,254,239,237,203,170,153,153,170,188,222,255,238,253,203,169,136,136,137,154,188,222,255,222,203,169,135,118,119,120,154,189,239,237,236,185,135,102,85,102,121,171,206,254,221,202,152,118,84,69,103,137,172,222,237,219,169,134,84,67,69,104,154,205,238,221,186,152,117,67,52,86,121,171,222,237,220,185,135,101,68,85,120,154,205,238,221,203,169,118,101,85,103,137,188,223,237,237,186,152,119,102,119,137,171,205,254,222,236,186,153,136,120,137,171,189,239,237,254,220,186,169,153,153,171,188,223,254,239,254,220,187,186,170,187,205,222,239,253,254,238,221,204,204,204,221,222,255,255,239,255,238,238,221,221,221,238,239,255,254,255,255,255,238,254,238,239,255,255,255,174,238,238,238,221,222,239,254,238,255,192,0,0,0,190,220,220,204,203,203,204,204,221,205,173,237,221,204,204,204,188,205,206,239,254,238,220,203,187,186,171,187,204,222,223,220,220,203,170,153,153,154,171,205,222,253,205,203,169,153,136,136,153,170,188,239,220,219,170,152,119,119,119,137,171,205,221,204,186,152,119,102,102,119,137,171,222,220,203,152,119,101,85,86,119,137,188,221,204,169,135,101,85,85,86,120,155,188,219,202,152,118,85,68,85,103,137,172,221,203,169,135,101,84,69,86,120,154,188,220,186,152,118,101,85,85,103,137,172,221,204,186,136,118,85,85,102,120,154,189,204,203,169,135,118,102,102,120,154,188,220,205,203,169,135,119,119,120,137,172,206,220,221,202,169,136,136,136,153,171,205,237,221,220,203,170,153,153,154,172,205,238,221,239,220,203,186,170,170,187,204,237,253,238,238,221,220,203,187,188,205,222,239,237,255,237,237,221,220,205,221,238,239,254,173,237,221,221,205,220,221,222,237,237,176,0,0,0,205,221,204,204,187,188,204,205,222,239,206,254,221,204,187,187,187,204,222,255,255,222,220,203,186,170,170,171,188,206,255,237,220,187,170,153,153,153,170,188,222,254,221,203,169,152,136,136,136,154,188,222,236,203,169,136,119,119,119,136,154,188,222,204,185,152,119,102,102,103,136,155,205,220,186,152,118,101,85,86,103,137,171,221,187,169,135,101,85,85,86,120,154,188,219,186,152,118,85,85,85,103,120,171,204,203,169,135,101,85,85,86,119,138,188,204,186,152,118,85,85,85,103,137,171,204,203,169,135,102,85,85,102,120,154,188,220,203,169,135,102,102,102,120,137,172,221,221,186,152,135,119,119,120,137,171,205,221,220,186,153,136,119,136,137,171,189,221,222,220,186,153,152,137,153,171,188,222,237,253,220,187,170,170,170,171,204,222,254,239,238,220,203,187,187,188,205,222,255,254,255,238,221,220,204,204,221,238,239,255,207,238,237,221,221,204,205,221,223,238,192,0,0,0,189,204,204,187,187,188,188,204,204,221,172,221,221,204,204,188,188,204,221,223,253,222,236,203,187,170,170,187,204,205,222,204,221,203,170,169,153,154,171,204,221,237,205,187,170,153,136,136,153,170,188,221,219,203,170,152,135,119,120,137,171,204,237,188,186,152,119,102,103,119,137,171,205,203,203,169,135,102,85,102,120,154,188,220,188,169,135,102,85,85,102,120,154,188,203,202,152,118,85,68,69,103,137,171,204,187,185,135,101,68,68,86,120,154,188,203,202,168,118,101,68,86,103,137,171,204,204,186,152,118,101,86,103,120,154,189,204,203,169,135,118,102,103,120,154,188,220,205,187,169,136,119,119,120,154,171,205,204,220,187,169,152,136,136,153,171,205,220,205,220,187,170,153,153,154,171,188,205,204,237,220,203,187,170,170,187,204,221,221,222,221,221,204,187,187,204,204,205,223,221,255,237,221,220,204,205,221,238,238,253,173,220,220,204,204,188,204,204,220,222,176,0,0,0,174,237,221,221,221,220,221,221,221,221,158,255,255,237,237,221,238,239,254,255,253,223,238,221,221,221,221,221,239,254,255,237,254,221,204,203,188,204,222,238,238,254,223,221,203,186,170,171,188,221,223,239,237,237,219,186,153,136,153,171,205,239,253,222,220,186,152,119,119,137,171,221,255,221,237,186,152,118,85,103,137,188,221,254,222,203,169,118,84,69,103,154,205,239,237,237,202,135,84,51,69,120,171,206,237,222,219,168,117,67,36,87,138,188,222,237,237,202,151,101,68,70,120,172,205,237,222,221,186,135,101,86,104,154,189,239,221,254,220,169,135,119,120,138,188,222,238,239,253,219,170,152,136,154,171,205,255,221,254,237,203,186,170,170,187,205,223,254,223,254,237,220,203,187,188,204,222,255,238,255,255,254,221,205,221,221,239,239,254,255,255,254,254,238,237,238,238,255,255,239,255,255,255,239,254,239,254,255,255,254,173,221,221,221,237,222], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+820584);
/* memory initializer */ allocate([222,238,221,238,176,0,0,0,189,220,203,187,170,171,187,188,205,205,173,237,204,187,170,186,171,188,205,223,253,221,204,187,170,169,154,170,187,205,238,220,219,186,169,153,153,153,154,171,205,221,188,186,169,136,136,136,137,154,187,205,203,186,169,136,119,119,119,136,154,187,204,187,169,136,119,102,102,119,137,154,188,203,186,152,119,102,85,102,119,137,171,204,187,169,135,102,85,85,102,120,154,172,202,169,152,118,85,68,85,103,136,154,187,171,169,135,101,84,69,86,120,153,171,187,186,152,118,101,85,86,103,137,154,187,187,169,135,118,101,85,103,120,154,172,187,186,152,135,118,102,103,120,137,171,204,188,186,152,135,119,119,120,137,154,188,204,203,170,153,136,136,136,137,154,187,204,205,203,170,153,152,153,153,170,188,205,204,221,203,186,170,153,154,170,187,205,221,206,221,204,187,186,170,187,188,205,238,221,253,237,204,204,188,188,204,221,238,254,157,221,204,204,187,187,188,204,221,238,176,0,0,0,155,186,170,170,153,153,170,170,187,204,155,220,187,170,170,170,170,171,188,204,220,187,187,170,153,153,153,154,170,187,205,202,187,169,153,136,136,136,153,170,188,220,171,169,152,136,119,120,136,137,170,188,186,186,152,135,119,119,119,120,153,171,187,154,153,135,119,102,102,119,120,154,171,186,169,136,119,102,102,102,119,136,154,186,154,152,119,102,101,86,102,119,137,171,170,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,69,102,119,137,171,169,169,135,118,102,85,86,103,120,154,170,170,152,135,118,102,102,102,119,137,171,170,169,152,119,118,102,102,119,137,154,186,171,169,152,119,119,119,119,136,154,171,187,186,169,136,135,119,120,136,153,171,187,187,186,169,152,136,136,136,153,171,188,187,204,186,169,153,153,153,153,170,188,204,204,204,187,170,170,170,170,171,188,205,204,221,220,203,187,170,171,187,188,204,221,156,203,187,186,170,170,170,187,187,204,160,0,0,0,155,170,169,153,153,153,153,170,171,188,171,203,186,170,153,153,153,170,171,204,204,171,186,169,153,136,137,153,154,171,188,186,186,169,152,136,136,136,137,154,171,203,170,169,152,135,119,119,120,137,154,171,185,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,103,120,137,170,169,153,135,119,102,102,102,119,120,153,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,85,102,103,120,137,170,153,136,119,102,101,86,102,119,136,154,169,153,135,118,102,102,102,103,120,137,170,153,152,119,102,102,102,102,119,137,154,169,169,136,119,102,102,102,119,136,154,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,137,170,186,171,170,153,136,136,136,136,153,170,187,187,187,170,153,152,136,137,153,170,187,203,188,203,170,169,153,153,154,170,187,204,188,220,203,186,170,170,170,171,187,204,220,172,187,186,170,170,154,170,170,187,188,160,0,0,0,155,186,169,169,153,153,153,170,171,187,155,204,187,170,169,153,170,170,187,188,220,188,186,170,153,153,153,153,170,171,204,186,186,169,153,136,136,136,137,154,171,203,171,169,152,136,119,119,136,137,154,187,186,170,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,119,120,137,171,169,169,136,119,102,102,102,119,136,154,170,154,152,119,102,102,86,102,119,137,154,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,153,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,103,120,137,170,169,169,136,119,102,102,103,119,136,154,170,170,169,136,119,119,119,119,136,153,171,186,186,153,136,135,119,119,136,153,170,187,171,170,153,136,136,136,136,153,170,187,187,203,186,169,153,153,153,153,170,187,203,188,203,170,170,153,153,170,170,187,204,187,204,203,187,170,170,170,171,188,204,220,156,187,186,170,170,170,170,170,187,188,160,0,0,0,173,204,204,204,203,187,188,188,204,220,157,237,237,204,204,204,204,205,221,238,237,223,221,204,187,187,187,187,205,221,238,220,221,203,186,170,170,170,187,204,222,236,204,203,186,153,153,153,154,171,204,222,204,204,186,153,136,136,136,154,171,205,220,204,186,153,135,119,119,136,154,187,205,204,203,169,135,102,86,103,136,170,188,220,188,186,152,118,84,69,103,137,171,205,203,203,169,135,84,51,69,120,154,188,220,188,186,152,118,67,52,86,137,171,205,204,203,169,135,101,68,86,120,154,188,204,205,186,153,135,101,86,103,137,171,205,204,204,186,152,135,118,119,136,154,188,220,205,204,170,152,136,136,136,154,187,205,220,220,187,170,153,153,153,154,171,205,220,206,221,203,186,170,170,170,187,205,222,221,221,221,204,187,187,187,188,205,221,237,223,238,221,220,203,204,204,204,238,239,221,238,238,237,221,205,205,222,238,238,254,157,205,205,204,204,204,204,221,221,222,176,0,0,0,207,255,254,255,238,222,222,239,238,238,175,255,255,254,238,237,239,239,255,255,255,255,255,254,221,205,204,222,239,255,255,239,255,238,220,187,187,187,205,222,255,255,255,253,203,186,153,154,171,205,254,255,255,254,203,169,152,136,137,155,205,239,254,255,220,185,135,118,119,120,171,205,239,254,237,186,151,102,85,103,121,171,222,255,239,203,152,118,84,69,103,137,188,239,254,236,185,134,84,51,69,104,155,206,255,254,203,152,117,67,52,86,137,188,239,254,237,185,135,101,68,85,120,155,206,255,255,219,169,135,101,85,103,138,189,255,255,237,203,152,135,102,119,137,172,239,255,255,237,203,153,136,136,137,171,206,239,254,255,221,203,169,153,154,171,205,255,255,255,255,237,203,187,187,188,221,239,255,255,255,255,238,220,204,204,221,255,255,255,239,255,255,238,238,222,222,255,255,255,255,255,255,255,255,239,255,255,255,255,255,159,255,255,238,254,239,255,255,255,255,192,0,0,0,206,221,221,204,204,204,204,205,221,221,158,238,221,204,204,187,188,205,222,255,254,239,221,204,186,170,170,187,204,222,255,221,236,203,170,153,153,154,171,204,222,237,221,203,170,152,136,136,137,171,188,223,236,219,169,152,119,119,119,137,171,205,237,204,186,152,119,102,102,119,137,171,206,236,202,152,119,101,85,102,119,138,188,221,204,169,135,101,85,85,86,120,154,205,220,186,152,118,85,68,85,103,137,172,221,187,169,135,101,84,69,86,120,154,189,220,202,152,118,85,85,85,103,137,172,221,204,186,136,118,85,85,102,120,155,205,220,219,169,135,118,102,102,120,154,188,221,221,203,169,135,119,119,120,137,188,222,237,237,202,169,136,136,136,153,171,205,221,222,220,203,169,153,153,154,171,204,222,253,254,220,187,187,170,170,188,204,222,254,223,238,221,220,204,204,204,205,238,255,237,254,254,237,221,205,221,222,254,255,255,174,238,237,221,221,221,221,238,254,239,208,0,0,0,222,221,220,204,187,187,204,205,222,238,190,238,221,204,187,187,187,205,222,239,254,222,220,203,186,170,170,171,188,221,239,237,220,203,170,153,153,153,170,188,222,238,220,203,169,152,136,136,137,154,188,222,236,203,169,136,119,119,119,137,154,188,221,204,186,152,118,102,102,103,137,171,205,220,186,152,118,101,85,86,103,137,171,221,203,169,135,101,85,85,86,120,154,188,219,186,152,118,85,85,85,103,137,171,220,203,169,135,101,85,69,86,120,154,188,204,186,152,118,85,85,85,103,137,171,205,204,169,135,102,85,85,102,120,154,189,220,203,169,135,102,102,102,120,153,172,221,220,186,153,135,119,119,120,137,171,205,221,220,186,153,136,136,136,153,171,205,238,222,220,186,169,153,153,153,171,188,222,238,237,220,187,170,170,170,171,188,222,254,223,238,220,203,187,187,188,204,222,255,254,255,238,237,220,204,204,221,238,255,255,191,238,221,221,220,221,221,222,239,255,224,0,0,0,223,238,221,221,204,221,205,222,239,254,175,255,253,220,204,204,204,237,238,255,255,255,221,204,187,170,187,187,205,238,255,254,237,203,170,169,153,154,171,205,238,254,221,203,169,152,136,136,153,171,205,239,237,220,170,152,119,119,119,137,171,205,253,221,186,152,119,102,102,119,137,171,207,236,203,168,119,101,85,86,119,138,188,222,204,169,135,101,85,85,86,120,154,206,220,202,152,118,85,68,85,103,137,172,221,204,169,135,101,84,69,86,120,154,205,220,202,152,118,85,85,85,103,137,172,221,220,186,135,118,85,85,102,120,155,205,221,220,169,135,118,102,102,120,154,188,222,222,203,169,135,119,119,120,153,187,205,237,237,203,169,152,136,136,153,171,205,238,238,237,203,170,153,153,154,171,205,239,237,255,221,203,187,170,170,188,205,222,255,239,255,253,220,203,188,204,221,239,255,254,255,255,238,221,221,221,222,255,255,255,174,238,237,237,221,221,222,238,239,255,208,0,0,0,223,255,255,238,254,222,238,255,222,255,159,255,255,255,221,222,239,255,255,255,255,255,255,254,220,204,204,221,239,255,255,255,255,236,203,186,170,171,205,239,255,255,255,253,203,169,153,153,154,188,223,255,255,253,203,169,135,119,136,154,189,255,255,239,219,169,135,102,102,120,154,205,255,255,252,185,135,101,85,102,120,155,206,255,238,202,152,101,84,69,86,137,172,223,254,220,169,118,84,68,69,103,154,205,255,237,202,151,101,68,68,86,121,172,223,254,220,169,134,101,68,85,103,154,205,255,238,203,152,118,85,85,103,137,172,255,255,253,202,152,118,102,103,136,171,206,255,255,252,186,152,135,119,137,155,205,255,254,255,220,186,153,152,153,171,205,255,255,255,255,237,203,186,170,171,205,239,255,255,255,255,221,204,204,204,206,255,255,255,255,255,255,254,237,221,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,238,222,254,255,255,255,255,208,0,0,0,190,238,221,221,204,204,221,221,221,237,159,255,254,221,221,205,221,239,238,255,254,239,237,220,204,187,188,204,221,238,255,238,238,220,187,170,170,171,188,221,239,254,221,204,202,169,153,153,154,188,205,239,222,220,186,153,136,136,136,154,188,222,254,222,203,169,135,119,119,120,154,188,222,237,220,169,135,102,85,103,137,171,205,238,221,186,152,118,84,69,103,137,172,223,237,219,169,135,84,51,69,120,154,204,253,220,202,152,117,67,52,86,137,171,206,221,220,169,135,101,68,86,120,154,189,238,221,202,169,119,101,86,103,137,172,222,237,237,202,152,119,118,119,137,171,205,254,238,220,186,152,136,120,137,154,188,222,237,254,204,186,169,153,153,170,188,222,238,239,253,220,187,170,170,171,188,222,255,238,255,237,220,204,187,187,205,221,239,255,239,255,254,237,221,220,221,222,255,255,254,255,255,254,238,238,238,255,255,255,255,158,222,221,222,221,205,221,254,239,255,176,0,0,0,171,186,170,169,153,153,154,170,187,204,139,203,187,170,170,170,170,171,188,205,220,188,187,170,153,153,153,153,170,188,205,202,187,169,153,136,136,136,153,170,187,204,171,169,152,136,119,119,136,137,170,188,186,170,152,135,119,119,119,120,137,171,203,170,153,135,119,102,102,119,120,153,171,185,169,136,119,102,102,102,119,136,154,186,154,152,119,102,101,86,102,119,137,171,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,135,118,101,85,86,103,120,154,186,154,152,135,118,102,102,102,120,137,171,170,169,152,119,118,102,102,119,136,154,186,171,169,136,119,119,119,119,136,153,171,170,186,169,136,135,119,120,136,153,170,187,188,186,169,152,136,136,136,153,170,188,187,203,186,169,153,153,153,154,170,188,203,189,203,187,170,170,170,170,171,188,205,204,221,204,187,186,170,187,187,187,204,220,156,204,187,186,170,170,170,187,187,204,176,0,0,0,171,170,169,153,153,153,153,170,171,188,171,203,186,170,169,153,153,170,187,204,220,187,186,169,153,153,153,153,154,171,204,202,186,169,152,136,136,136,137,154,171,203,170,169,152,135,119,119,120,137,154,187,185,169,152,135,119,119,119,120,137,154,187,154,152,135,118,102,102,103,120,137,171,169,153,135,119,102,102,102,103,120,154,170,153,152,119,102,102,102,102,119,137,154,169,153,135,118,102,85,86,103,120,137,170,153,152,119,102,101,86,102,119,136,154,169,153,135,118,102,102,102,103,120,153,170,154,152,119,102,102,102,102,119,137,170,169,169,136,119,102,102,102,119,136,154,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,153,170,186,171,170,153,136,136,136,136,153,170,188,187,203,170,153,153,136,153,153,170,187,203,188,203,186,170,153,153,170,170,187,204,188,220,203,187,170,170,170,171,187,205,220,156,203,186,170,170,170,170,170,187,188,160,0,0,0,172,187,170,170,153,153,170,170,188,204,156,204,187,170,170,170,170,170,187,221,237,188,186,170,153,153,153,153,170,187,205,203,187,169,153,136,136,136,153,170,188,203,171,169,152,136,119,119,136,137,170,188,186,186,152,135,119,119,119,120,153,171,187,170,153,135,118,102,102,119,120,153,171,186,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,119,137,170,169,153,135,118,101,85,86,103,120,154,170,153,152,119,102,85,85,102,119,137,170,170,169,135,118,102,85,86,103,120,154,170,170,152,135,118,102,102,102,120,137,171,170,169,152,119,118,102,102,119,136,154,187,171,169,152,119,119,119,119,136,154,171,187,186,169,136,135,119,120,136,153,171,203,188,186,169,152,136,136,137,153,170,188,187,203,186,169,153,153,153,153,171,188,204,205,203,186,170,170,170,170,171,188,205,204,237,204,187,187,187,171,187,188,220,221,156,203,187,187,170,170,170,187,188,205,176,0,0,0,188,220,187,187,187,187,187,204,205,222,157,237,204,187,186,171,187,188,221,239,254,221,204,186,170,170,154,170,188,205,223,236,220,170,153,153,137,153,154,187,205,221,204,186,153,136,136,136,137,154,187,205,219,186,169,136,119,119,119,137,154,188,221,187,169,136,118,102,102,119,137,155,188,203,186,152,118,102,85,102,119,137,171,204,187,153,135,102,85,85,102,120,154,188,219,169,136,118,85,68,85,103,137,155,204,187,169,135,102,84,69,86,119,137,172,203,186,152,118,101,85,86,103,136,170,204,187,169,135,118,101,86,102,120,154,188,203,187,153,135,118,102,102,119,137,171,204,204,186,152,135,119,119,120,137,170,188,220,220,170,153,136,136,136,137,154,187,221,205,204,186,153,152,137,153,170,188,205,205,237,203,186,170,153,154,170,188,205,237,223,237,204,187,187,171,187,187,205,222,237,238,221,220,204,187,204,204,221,238,238,157,205,204,204,203,188,204,204,205,221,192,0,0,0,255,255,254,255,253,221,220,237,221,221,159,255,255,255,254,239,255,255,255,255,254,255,255,254,237,221,205,221,239,255,255,255,255,254,205,187,187,188,221,239,255,254,255,255,220,186,170,170,171,205,222,255,239,253,220,186,152,136,137,171,205,239,255,255,237,186,136,119,119,137,171,205,255,255,253,202,152,102,85,103,137,172,223,255,239,203,168,117,68,69,103,138,189,255,255,252,186,135,84,51,69,104,171,223,255,255,219,168,117,67,52,86,138,189,239,255,253,186,135,101,68,69,120,171,223,255,255,236,169,135,101,85,104,154,205,255,255,255,204,169,135,118,119,138,188,255,255,255,254,203,169,152,136,154,188,223,255,255,255,222,203,186,169,170,188,205,255,255,255,255,221,220,187,187,204,222,255,255,254,255,255,254,221,204,220,223,255,255,255,239,255,255,255,237,239,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,141,221,221,254,237,223,255,255,255,255,208,0,0,0,206,221,220,204,204,204,204,204,204,220,157,238,238,220,204,204,204,221,222,238,238,238,237,220,203,187,187,188,205,222,239,221,237,203,187,170,170,170,187,204,222,238,221,203,186,153,153,137,154,171,205,238,220,204,186,153,136,119,136,153,171,205,221,205,186,153,135,102,102,120,154,188,221,220,203,169,135,102,85,102,120,154,188,221,204,186,151,102,84,69,102,121,171,205,220,203,168,118,84,68,69,103,138,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,138,188,221,204,186,152,118,101,85,103,137,171,205,220,220,186,152,118,102,103,136,154,189,237,205,203,169,152,135,119,136,154,188,222,220,221,203,170,153,152,137,154,187,205,238,222,221,203,186,170,170,170,188,221,223,237,237,220,204,187,187,187,188,205,255,254,206,255,221,204,204,204,205,221,239,255,253,254,255,222,221,221,221,222,239,255,254,157,221,221,221,221,221,221,238,239,239,208,0,0,0,206,221,204,204,187,188,204,204,221,221,174,254,221,204,203,187,188,204,222,239,254,222,221,203,186,170,170,187,204,222,238,237,221,203,170,153,153,153,171,188,222,237,205,203,169,152,136,136,137,170,188,222,220,203,169,152,119,119,119,137,171,204,221,204,186,152,119,102,102,119,137,171,205,220,202,152,119,102,85,86,119,137,188,221,203,169,135,101,85,85,86,120,154,189,219,186,152,118,85,68,85,103,137,171,220,187,169,135,101,84,69,86,120,154,188,204,186,152,118,85,85,85,103,137,171,205,204,185,135,118,85,85,103,120,154,189,204,203,169,135,118,102,103,120,154,188,221,205,203,169,135,119,119,120,153,171,205,221,220,186,169,136,136,136,153,171,205,237,222,220,187,169,153,153,154,171,205,222,237,237,220,187,186,170,170,187,204,222,254,223,238,221,204,187,187,188,205,222,255,237,255,238,221,221,204,221,221,238,255,255,174,221,221,221,221,204,221,221,238,239,208,0,0,0,206,237,221,220,204,204,204,221,221,221,159,254,237,221,205,220,204,221,222,239,253,239,222,204,203,187,187,204,205,222,239,221,237,220,187,170,170,170,171,205,239,253,221,219,186,153,152,137,154,171,205,238,221,220,186,152,135,119,120,153,171,205,253,221,203,152,119,102,102,120,154,188,221,220,203,169,135,101,85,86,120,154,189,221,204,186,151,101,84,85,86,121,171,205,220,203,168,118,85,68,85,103,138,188,237,204,186,135,101,84,68,86,120,171,205,220,203,169,118,85,68,85,103,138,188,220,205,202,152,118,85,85,103,137,171,205,220,220,186,152,118,102,103,136,154,204,221,221,204,170,152,119,119,136,154,188,221,220,237,203,169,153,136,137,154,188,206,237,223,220,203,186,169,170,170,188,221,239,237,238,221,204,204,187,187,188,221,238,238,239,254,237,220,220,204,205,221,239,255,254,255,238,253,221,221,221,237,223,255,255,157,221,205,221,221,221,221,222,222,239,208,0,0,0,223,255,254,254,222,205,221,237,221,222,143,255,255,239,237,238,238,255,255,255,255,255,255,254,221,220,221,221,255,255,255,255,255,254,204,187,187,187,205,223,255,255,255,253,204,186,169,154,171,205,239,255,255,254,220,169,136,136,137,170,205,255,255,239,236,185,135,118,119,136,171,206,255,255,253,186,151,102,85,102,137,172,223,255,238,219,168,118,84,69,103,138,189,255,253,221,185,134,84,51,69,104,155,207,255,239,203,152,101,67,52,86,137,188,255,253,237,186,135,101,68,85,120,155,221,254,239,220,169,135,101,85,103,154,189,255,255,253,203,168,135,102,119,137,188,223,255,255,221,187,169,136,136,137,171,207,255,255,255,236,203,170,169,154,187,221,255,255,255,253,237,203,187,187,204,205,255,255,255,255,255,237,220,205,205,221,255,255,255,255,255,255,239,238,237,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,157,222,239,254,237,239,255,255,255,255,240,0,0,0,188,204,203,187,187,187,187,187,204,221,157,237,220,187,187,187,187,188,205,223,237,221,220,187,170,170,170,170,187,205,223,220,204,187,169,153,153,153,170,187,205,221,204,186,169,152,136,136,137,154,188,205,219,203,169,136,119,119,119,136,154,188,204,187,170,152,119,102,102,119,137,170,188,203,186,152,119,101,85,102,119,137,171,203,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,170,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,86,103,137,171,204,187,169,135,118,101,85,103,120,154,188,187,186,169,135,118,102,102,120,137,171,204,188,186,153,135,119,119,120,137,171,188,220,203,186,153,136,136,136,153,170,188,204,205,203,186,153,152,153,154,171,187,221,204,220,204,187,170,170,170,171,188,205,222,205,221,204,187,187,187,187,189,221,239,221,237,221,204,204,188,204,205,221,238,253,141,204,204,187,187,187,203,204,221,222,176,0,0,0,171,186,170,170,153,153,154,170,171,187,139,204,187,186,170,170,170,171,188,204,220,188,187,170,169,153,153,154,170,187,205,202,187,170,153,152,136,137,153,170,187,203,171,170,153,136,119,120,136,153,170,188,186,186,153,136,119,119,119,120,153,171,187,170,153,135,118,102,102,119,120,154,171,186,169,136,119,102,102,102,119,137,154,186,154,152,135,102,85,85,102,120,137,171,169,169,135,118,101,85,86,103,120,154,186,154,152,119,102,85,85,102,119,137,171,169,169,136,118,101,85,86,103,120,154,186,154,152,135,118,101,86,102,120,137,171,170,170,152,135,118,102,102,119,137,170,186,171,169,152,119,119,119,119,136,154,187,186,186,169,152,136,119,136,136,154,171,203,187,186,169,153,136,136,137,154,171,188,187,203,186,170,153,153,153,154,171,188,204,188,203,187,170,170,170,170,187,204,205,203,220,204,187,187,187,187,187,204,205,220,140,187,186,171,170,170,171,187,187,204,176,0,0,0,155,186,170,153,153,153,153,170,171,187,155,203,187,170,170,154,170,170,187,204,220,188,186,169,153,153,153,153,170,187,204,186,186,169,153,136,136,136,153,154,187,203,170,169,152,136,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,170,186,154,153,135,119,102,102,119,120,153,171,169,169,136,119,102,102,102,119,136,154,170,154,152,119,102,101,86,102,119,137,170,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,102,120,137,170,169,169,152,119,118,102,102,119,137,154,186,170,169,136,119,119,119,119,136,153,171,170,186,153,136,135,119,120,136,153,171,187,171,186,153,152,136,136,136,153,170,188,187,203,186,169,153,153,153,153,170,187,203,188,203,186,170,169,153,170,171,187,204,203,220,203,187,170,170,170,187,188,205,220,155,187,186,170,170,170,170,171,187,188,160,0,0,0,172,187,186,170,170,170,170,171,187,188,140,204,187,186,170,170,170,171,188,204,220,188,187,170,169,153,153,170,171,188,205,203,187,170,153,136,136,137,153,170,188,203,187,186,153,136,119,120,136,153,171,188,186,186,153,135,119,119,119,136,153,171,203,170,169,135,118,102,102,103,136,154,188,186,169,136,118,102,86,102,119,136,154,187,170,152,135,102,85,85,102,120,137,171,170,169,135,118,85,85,86,103,120,154,186,170,152,119,101,85,85,102,119,137,171,170,169,136,118,101,85,86,103,136,154,186,170,153,135,118,101,102,103,120,153,171,170,186,152,135,102,102,102,119,137,170,187,187,169,152,135,119,119,120,136,154,187,187,187,169,152,136,119,136,137,154,171,203,188,187,169,153,136,136,137,154,171,204,187,204,187,170,169,153,153,170,171,188,204,205,204,187,170,170,170,170,187,204,221,204,221,204,203,187,187,187,187,204,206,236,156,203,187,186,170,170,171,187,188,204,176,0,0,0,191,220,204,203,187,187,187,204,204,205,125,253,221,204,203,187,188,204,221,239,253,222,220,203,187,170,170,187,204,206,238,220,220,203,170,153,153,154,171,204,205,237,205,203,169,153,136,136,153,171,188,222,204,203,169,152,119,119,120,137,170,189,221,204,186,152,119,102,102,120,137,171,205,204,202,168,119,102,85,102,120,154,188,220,188,169,135,101,84,85,102,120,154,189,203,186,152,118,84,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,204,202,152,118,101,84,86,103,137,172,204,204,186,152,118,101,86,103,136,154,189,220,203,169,136,118,102,103,120,154,188,220,205,187,169,136,119,119,136,153,171,205,220,220,186,169,152,136,136,153,171,205,253,221,220,187,170,153,153,154,171,188,221,237,237,220,203,186,170,170,187,204,222,238,223,238,220,204,187,187,188,205,222,239,237,238,253,221,204,204,204,221,238,255,238,141,220,220,204,204,204,205,221,221,238,192,0,0,0,206,239,253,221,221,221,221,221,220,221,143,255,255,254,253,222,254,254,239,255,253,255,255,238,220,205,220,221,238,255,255,223,255,237,220,203,187,188,205,222,239,254,239,238,204,186,169,154,171,204,222,255,238,254,220,186,152,136,137,155,205,222,255,222,220,186,151,118,119,137,171,205,255,221,237,186,151,102,85,102,137,172,205,254,222,219,168,118,84,69,103,138,188,238,237,236,185,134,84,51,69,104,155,206,254,221,203,168,117,67,52,86,138,188,239,238,236,186,135,101,68,70,120,171,205,254,237,219,169,135,101,85,103,154,189,223,253,237,203,169,135,102,119,138,188,222,255,222,221,186,169,136,136,153,171,221,239,253,254,220,203,170,153,170,188,205,255,255,223,254,221,204,187,187,204,221,239,255,237,255,238,221,220,204,205,221,239,255,255,223,254,238,238,237,238,223,254,255,255,252,255,239,239,254,238,255,255,255,255,255,140,204,221,221,221,221,222,255,239,255,208,0,0,0,206,237,221,205,204,204,204,204,204,221,158,254,237,221,204,204,204,221,222,239,253,239,237,220,203,187,187,187,204,221,223,221,237,204,186,170,170,170,187,204,222,237,221,220,186,153,152,137,154,171,205,221,221,220,186,152,135,119,136,153,171,205,237,204,202,152,135,102,103,120,154,172,221,220,203,169,135,102,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,168,118,84,68,69,103,138,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,120,155,188,221,204,203,169,152,135,119,136,154,188,222,220,236,203,170,153,136,153,154,188,221,254,206,220,203,186,170,170,170,188,206,239,252,237,220,203,187,187,187,204,221,239,255,222,237,221,204,204,204,205,221,238,255,253,254,238,237,237,221,221,223,255,255,255,157,221,220,220,221,221,221,238,239,239,208,0,0,0,206,221,220,204,187,187,187,204,204,221,174,238,221,204,203,187,187,204,221,238,237,222,220,203,186,170,170,187,188,205,222,221,220,203,170,153,153,153,170,188,221,237,205,203,169,152,136,136,153,170,188,221,220,203,169,152,119,119,120,137,171,188,221,204,186,152,119,102,102,119,137,171,205,203,202,152,119,101,85,102,120,154,172,220,187,169,135,101,84,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,203,186,152,118,101,85,85,103,137,171,204,187,186,152,118,101,85,103,120,154,189,204,203,169,135,118,102,103,120,154,188,221,204,186,169,136,119,119,120,153,171,205,220,220,186,169,152,136,136,153,171,205,237,205,204,186,170,153,153,154,171,204,222,220,237,204,187,170,170,170,187,204,222,238,222,221,220,203,187,187,188,205,222,255,253,238,237,221,204,204,204,221,238,255,255,157,221,221,204,204,204,205,222,238,239,224,0,0,0,222,238,221,204,204,204,204,204,204,220,158,254,237,221,204,204,204,221,221,239,253,223,237,220,203,187,187,188,204,221,222,222,237,204,187,170,170,170,187,204,205,237,222,220,186,153,153,153,154,171,204,222,220,220,186,152,135,119,136,153,171,205,221,205,186,168,119,102,103,120,154,187,221,204,203,169,135,101,85,102,120,154,188,220,205,186,151,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,220,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,136,155,204,237,205,203,170,152,135,120,137,154,188,222,221,220,203,170,153,136,153,170,188,205,237,222,220,203,186,170,170,170,188,221,222,236,221,220,203,187,187,187,204,221,239,254,222,238,221,204,204,204,204,221,238,255,253,238,238,221,220,221,221,221,239,255,255,157,220,220,204,204,205,221,237,238,238,208,0,0,0,223,255,239,237,221,205,220,204,205,221,143,255,255,255,238,221,222,239,239,255,254,255,255,238,221,204,204,221,238,239,255,223,255,237,204,187,187,187,205,222,255,254,239,253,203,170,153,154,171,188,222,255,238,253,203,169,152,136,137,155,204,238,253,239,219,169,135,118,103,136,155,205,255,253,221,186,151,102,85,102,137,171,222,255,221,203,152,118,84,69,103,138,188,223,254,236,169,134,84,51,69,104,155,205,254,221,203,152,101,67,52,86,137,188,223,237,220,186,135,101,68,86,120,171,205,238,222,203,169,118,101,86,103,138,189,223,253,253,203,152,135,102,119,137,172,239,255,223,221,187,169,136,136,153,171,206,255,253,239,221,203,170,153,154,187,205,239,255,239,254,221,204,187,187,188,205,239,255,254,255,222,221,204,204,204,222,239,255,255,223,255,255,238,237,238,239,255,255,255,254,255,255,255,255,255,254,239,255,255,255,157,221,221,238,221,223,255,255,255,255,224,0,0,0,189,204,203,187,187,187,187,187,204,204,141,238,204,204,187,187,187,204,205,239,237,205,220,203,170,170,170,171,188,205,221,204,220,187,170,153,153,153,170,188,204,237,205,203,169,152,136,136,137,154,188,205,204,203,169,136,119,119,120,137,154,188,220,187,186,152,119,102,102,119,137,171,188,203,186,152,119,101,85,102,120,137,171,220,187,169,135,102,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,187,186,152,118,101,85,85,103,137,171,204,187,169,136,118,101,85,102,120,154,188,203,203,169,135,118,102,103,120,154,171,204,188,186,169,136,119,119,120,153,171,205,204,204,186,153,152,136,136,153,171,188,220,205,204,186,169,153,153,153,170,204,221,220,237,204,187,170,170,170,171,188,221,237,206,237,204,187,187,187,187,204,205,238,220,238,237,220,204,204,204,204,221,238,254,124,204,204,203,203,187,204,204,222,222,192,0,0,0,172,187,186,170,170,154,170,170,171,187,140,220,203,187,170,170,170,187,187,204,220,188,203,186,169,153,153,170,171,188,205,187,187,170,153,153,136,153,154,171,188,203,171,170,153,136,136,136,136,154,171,188,186,186,153,136,119,119,119,136,154,171,203,170,169,136,118,102,102,119,137,154,187,186,170,152,118,102,86,102,119,137,170,187,170,152,135,102,85,85,102,120,153,171,170,169,152,118,85,69,86,103,136,154,186,170,152,135,102,84,69,86,120,137,171,170,169,152,118,101,85,86,103,136,154,186,170,169,135,118,102,86,102,120,153,171,170,186,153,135,118,102,103,120,137,170,187,171,170,152,135,119,119,120,137,154,188,186,187,169,152,136,136,136,137,154,187,203,188,186,170,153,152,137,153,154,171,204,187,203,187,170,169,153,153,170,171,204,220,189,204,187,170,170,170,171,187,204,221,203,221,204,203,187,187,187,188,204,222,237,139,187,187,186,170,170,187,187,188,204,160,0,0,0,155,186,170,153,153,153,153,170,170,187,155,203,187,170,170,154,170,170,187,188,219,187,186,169,153,153,153,153,170,187,204,186,186,169,152,136,136,136,153,170,187,203,171,169,152,136,119,120,136,153,170,187,170,170,152,135,119,119,119,136,153,170,186,154,152,135,118,102,102,119,136,153,171,169,169,136,119,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,153,152,119,102,85,85,102,119,137,154,169,169,136,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,102,119,136,154,186,170,169,152,135,119,119,119,136,153,171,170,186,169,152,136,119,120,136,153,170,186,171,186,169,152,136,136,136,153,170,188,186,203,170,169,153,153,153,154,170,187,203,188,203,186,170,170,153,170,170,187,204,203,204,203,187,186,170,170,187,188,204,220,155,187,170,170,170,170,170,170,187,188,160,0,0,0,171,187,170,170,153,153,170,170,187,187,139,204,187,186,170,170,170,171,187,204,219,188,187,170,169,153,153,154,170,187,204,187,187,170,153,136,136,137,153,170,188,203,171,170,152,136,135,136,136,153,171,188,186,186,152,135,119,119,119,136,153,171,186,170,169,135,118,102,102,119,136,154,171,170,169,152,118,102,86,102,119,137,154,186,154,152,135,102,85,85,102,120,153,171,169,169,135,118,85,85,86,103,136,154,186,154,152,135,102,85,85,86,119,137,171,169,169,136,118,101,85,86,103,136,154,186,170,153,135,118,102,86,102,120,137,171,170,186,152,135,118,102,102,119,137,170,186,171,169,152,135,119,119,119,136,154,187,186,186,169,152,136,136,136,136,154,171,203,172,186,169,153,136,136,153,154,171,188,187,203,186,170,153,153,153,170,171,188,203,188,203,187,170,170,170,170,187,188,205,203,221,204,187,187,187,187,187,204,220,220,139,187,170,170,170,170,170,187,187,204,160,0,0,0,189,204,204,187,187,187,187,187,187,204,125,254,220,203,187,187,187,188,205,238,237,221,220,187,186,170,170,171,188,205,222,220,220,203,169,153,153,153,170,187,205,237,205,186,169,152,136,136,137,154,172,205,204,187,169,136,119,119,119,137,154,188,221,188,169,152,119,102,102,119,137,171,204,203,186,152,119,101,85,102,120,137,171,204,187,169,135,101,84,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,86,103,137,171,204,187,169,136,118,101,85,103,120,154,188,203,203,169,135,118,102,103,120,153,187,204,204,186,153,136,119,119,120,137,171,204,204,220,186,153,136,136,136,153,171,188,221,204,204,186,169,153,153,154,171,188,222,220,221,204,187,186,170,170,171,204,222,237,222,221,204,203,187,187,187,204,221,239,237,237,238,236,204,204,204,221,222,255,254,141,204,204,204,204,204,204,204,221,239,208,0,0,0,223,255,255,237,220,221,221,205,204,204,143,255,255,238,238,237,238,239,255,255,253,255,255,254,221,221,205,205,238,239,239,238,255,237,221,203,187,188,205,221,239,253,239,222,220,186,170,170,171,205,222,255,222,254,220,169,152,136,153,171,204,239,253,239,220,185,135,119,119,137,171,205,239,238,221,202,152,102,85,103,137,172,222,254,237,219,168,118,68,69,103,138,189,239,221,237,186,135,84,51,69,120,171,206,254,222,203,168,117,67,52,86,137,188,239,237,237,202,135,101,68,69,120,171,206,238,221,220,169,135,101,85,104,154,205,223,253,253,203,169,135,118,119,137,188,222,239,206,220,203,169,152,136,153,187,221,255,237,239,236,203,170,169,170,187,221,239,255,205,237,220,204,187,187,188,221,255,255,252,254,221,221,220,205,205,221,255,255,255,206,222,237,221,238,222,238,239,255,255,252,254,254,222,238,222,255,239,255,255,255,124,204,204,205,221,222,238,222,255,255,192,0,0,0,206,221,221,204,204,204,204,204,204,204,158,254,237,220,204,204,204,205,222,238,253,223,237,204,203,187,187,188,204,221,238,221,237,220,186,170,170,170,187,204,222,237,221,220,186,153,152,153,154,171,205,222,220,220,186,152,135,119,136,153,171,205,237,204,203,153,135,102,103,120,154,188,205,220,203,169,135,101,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,121,171,205,204,203,169,135,101,68,85,103,154,188,220,204,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,136,154,205,237,205,203,169,152,135,119,136,154,188,222,220,220,203,170,153,152,153,154,188,222,237,205,220,203,186,170,170,171,188,205,239,220,237,220,204,187,187,187,204,205,222,254,206,237,221,220,204,204,205,221,238,255,236,254,238,237,221,221,221,238,238,255,255,141,221,220,221,221,221,221,221,238,238,208,0,0,0,205,221,204,203,187,187,187,188,204,204,174,238,221,204,187,187,187,204,205,222,237,222,220,203,186,170,170,171,188,205,222,221,220,203,170,153,153,153,170,188,205,221,205,203,169,152,136,136,137,154,188,205,204,203,169,136,119,119,119,137,154,188,220,204,186,152,118,102,102,119,137,171,205,203,186,152,118,101,85,102,120,137,171,204,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,204,187,169,136,118,101,85,102,120,154,188,203,203,169,135,118,102,102,120,154,188,221,204,186,153,135,119,119,120,137,171,205,220,204,186,153,136,136,136,153,171,205,237,205,203,186,169,153,153,154,171,204,222,220,221,204,187,170,170,170,187,204,222,254,206,221,204,203,187,187,188,205,222,255,237,238,221,220,204,204,204,221,238,239,254,173,220,204,204,204,204,204,221,238,239,208,0,0,0,206,221,221,204,204,204,204,204,204,205,158,255,237,221,204,204,204,221,221,222,253,238,237,204,203,187,187,187,205,221,238,221,237,204,186,170,170,170,187,188,221,237,221,204,186,153,152,153,154,171,205,222,221,220,186,152,135,119,136,154,171,205,221,205,203,152,135,102,103,120,154,187,205,220,203,169,135,101,85,102,120,154,188,220,204,186,152,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,220,204,186,151,101,68,68,86,120,171,205,204,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,219,186,152,119,102,103,136,154,205,237,205,203,169,152,135,119,136,154,188,222,220,220,203,170,153,153,153,154,188,205,237,206,220,187,186,170,170,170,188,205,239,236,237,220,203,187,187,187,188,205,238,254,206,237,221,204,204,204,204,221,239,255,253,238,238,221,221,221,221,222,239,239,255,156,205,220,220,204,205,221,221,238,254,208,0,0,0,207,254,237,237,220,204,204,204,204,204,126,255,255,254,238,221,221,222,238,239,253,223,254,254,220,204,204,204,221,238,239,222,254,238,204,187,187,187,204,205,239,253,239,237,203,186,169,154,171,188,221,238,222,237,203,169,152,136,137,170,204,222,237,222,219,185,135,118,119,137,171,205,239,222,220,186,151,102,85,103,137,172,206,253,221,203,168,117,84,69,103,138,189,223,237,236,185,135,84,51,69,120,171,205,237,221,203,168,117,67,52,86,137,188,239,237,220,186,135,101,68,70,120,171,205,237,221,219,169,135,101,85,103,154,188,239,221,237,203,169,135,118,119,137,188,222,254,223,220,203,169,136,136,153,171,205,255,237,238,221,187,170,153,170,171,205,239,255,222,237,204,203,187,187,188,221,239,255,254,255,237,221,204,204,205,222,254,255,255,223,254,238,222,222,222,238,255,255,255,253,255,239,238,254,238,239,255,255,255,255,140,221,220,222,222,237,237,255,238,255,208,0,0,0,207,238,221,204,204,204,204,204,204,221,142,255,237,220,204,204,204,221,222,239,254,239,237,204,187,187,187,188,205,238,238,222,237,203,186,170,169,170,171,205,222,253,237,220,186,153,152,153,154,171,204,223,220,204,186,152,135,119,136,154,171,205,237,220,186,152,135,102,103,120,154,188,206,220,219,169,135,102,85,102,120,154,188,220,204,186,152,102,84,85,103,137,171,205,220,203,168,118,84,52,85,103,154,188,220,204,186,152,101,83,52,86,120,154,205,220,203,169,135,101,84,86,103,153,188,221,204,202,152,119,101,86,103,137,171,205,220,220,186,152,119,102,103,136,154,189,237,205,203,169,152,135,119,136,154,188,222,236,221,203,170,153,153,153,154,187,205,238,222,220,203,170,170,154,170,187,206,239,253,238,221,204,187,187,187,188,205,222,255,222,237,221,220,204,204,204,221,239,255,253,255,253,237,221,221,221,222,239,255,254,124,204,204,204,204,204,221,221,238,254,208,0,0,0,171,187,170,170,170,170,170,170,171,187,139,220,203,186,170,170,170,187,204,205,235,188,187,170,169,153,153,170,171,188,205,187,203,170,153,152,136,153,154,171,188,203,171,170,152,136,136,136,137,154,171,188,186,186,153,135,119,119,119,136,154,171,203,170,169,135,118,102,102,119,137,154,187,186,169,152,118,102,86,102,119,137,170,187,170,152,135,102,85,85,102,120,154,171,170,169,136,118,85,69,86,103,136,154,186,170,152,135,102,85,69,86,120,137,171,170,169,152,118,101,85,86,103,136,154,186,170,169,135,118,102,86,102,120,153,171,186,186,153,135,118,102,102,119,137,170,187,171,170,152,135,119,119,119,136,154,188,186,187,170,153,136,136,136,136,154,171,203,188,187,170,153,152,136,153,154,171,204,187,204,187,170,169,153,153,170,171,188,220,189,204,187,187,170,170,170,187,188,221,203,220,204,203,187,187,187,187,204,205,236,139,187,187,186,170,170,171,187,188,204,160,0,0,0,171,186,170,153,153,153,153,170,170,187,139,203,187,170,170,170,170,170,187,188,203,187,186,170,153,153,153,153,170,187,204,186,186,169,152,136,136,137,153,170,187,203,171,169,152,136,119,120,136,153,170,187,170,169,152,135,119,119,119,136,153,170,186,154,152,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,171,169,169,152,135,118,102,102,119,136,154,186,170,169,152,135,119,119,119,136,153,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,152,136,136,136,153,170,188,186,203,186,169,153,153,153,154,170,188,203,188,203,186,170,170,170,170,171,187,205,203,204,203,187,186,170,171,187,188,204,220,139,187,170,170,170,170,170,171,187,204,160,0,0,0,172,203,186,170,170,170,170,170,187,187,140,220,203,187,170,170,171,187,188,205,220,188,203,186,169,153,154,170,171,188,205,203,203,170,153,152,137,153,154,171,188,203,187,186,153,136,136,136,137,154,171,188,187,186,153,135,119,119,120,136,154,171,203,170,169,135,118,102,102,119,137,154,188,186,169,152,118,102,86,102,119,137,170,187,170,152,135,102,85,85,102,120,153,171,186,169,136,118,85,69,86,103,136,154,187,170,152,135,102,84,69,86,120,137,171,186,169,152,118,101,85,86,103,136,154,187,170,169,135,118,102,86,102,120,153,171,186,186,153,135,118,102,102,119,137,170,203,171,170,153,136,119,119,119,137,154,188,187,187,170,153,136,136,136,137,154,171,203,188,187,170,153,152,136,153,154,171,204,203,204,187,170,169,153,153,170,171,204,220,189,204,187,186,170,170,171,187,205,221,220,221,204,203,187,187,187,188,204,222,237,140,187,187,187,187,171,187,188,204,205,176,0,0,0,206,220,204,203,187,187,187,204,188,204,125,254,221,204,203,187,188,204,221,238,253,222,220,203,187,170,170,187,204,205,222,221,221,203,170,153,153,154,171,204,221,253,205,203,169,152,136,136,153,171,188,221,204,203,169,152,135,119,120,137,171,189,220,204,186,152,119,102,103,120,137,171,205,219,203,169,135,101,85,102,120,154,188,220,203,169,135,101,84,85,103,120,155,188,203,186,152,118,84,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,203,203,152,119,101,84,85,103,137,172,204,188,186,152,118,101,85,103,137,154,189,204,203,169,136,119,102,103,120,154,188,221,204,187,169,136,119,119,136,153,187,205,220,220,186,169,152,136,137,153,171,205,221,222,220,187,170,153,153,170,171,204,222,252,221,220,187,186,170,171,188,205,223,238,222,222,220,204,203,188,188,205,222,255,237,254,237,221,204,205,204,222,222,255,255,140,204,220,204,204,204,221,205,222,255,208,0,0,0,239,255,238,237,237,221,220,204,204,204,143,255,255,255,254,237,237,221,255,255,253,255,255,238,221,220,205,221,221,255,255,222,255,237,220,203,187,204,204,221,255,253,239,238,220,187,170,170,187,205,222,255,239,254,219,186,152,136,153,171,204,222,255,239,221,185,135,119,119,137,171,206,239,237,237,202,151,102,85,103,137,172,221,255,221,219,168,117,68,69,103,138,189,255,237,236,186,135,84,51,69,120,171,222,254,221,203,168,117,67,52,87,138,189,254,253,236,202,135,101,68,69,120,172,223,255,222,220,169,135,101,85,103,154,205,255,253,253,203,169,135,119,119,138,189,239,255,207,221,203,169,136], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+830824);
/* memory initializer */ allocate([136,154,188,222,255,237,253,237,203,170,170,170,188,222,238,255,222,253,221,203,187,187,204,238,255,255,253,254,238,221,221,205,221,238,254,255,255,223,238,238,221,237,221,239,239,255,255,253,238,238,239,239,254,255,255,255,255,255,124,204,204,221,221,222,254,255,255,255,240,0,0,0,239,239,237,221,204,204,204,204,204,204,143,255,239,221,220,204,204,221,222,238,237,239,237,220,203,187,187,188,204,221,238,222,254,220,187,170,170,170,187,204,221,253,238,220,186,153,153,153,154,171,205,222,221,221,186,152,135,119,136,154,171,205,237,221,202,152,135,102,103,120,154,188,222,220,203,169,135,101,85,102,120,154,188,238,204,186,151,101,84,69,103,137,171,206,220,203,169,118,84,68,69,103,154,188,237,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,238,204,186,152,118,101,85,103,137,172,222,236,204,186,152,119,102,103,120,155,205,238,205,203,169,152,135,119,136,154,189,239,252,220,203,170,153,152,153,154,188,223,255,206,220,203,186,170,170,171,188,222,255,252,237,221,204,187,187,187,205,222,239,255,206,237,221,220,204,205,221,223,255,255,252,254,238,238,238,221,238,255,255,255,255,141,221,221,221,221,222,239,239,255,255,240,0,0,0,223,238,221,204,203,187,187,204,204,204,175,254,237,204,187,187,187,204,205,222,237,239,221,203,186,170,170,171,188,205,222,221,237,203,170,153,153,153,170,187,205,237,221,203,169,152,136,136,137,154,188,205,220,203,169,136,119,119,120,137,154,188,220,204,186,152,118,102,102,119,137,171,204,204,186,152,118,101,85,102,119,137,171,204,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,221,187,169,135,118,101,85,102,120,154,189,219,203,169,135,118,102,102,120,154,188,221,204,186,153,135,119,119,120,137,171,205,236,204,186,153,136,136,136,153,171,205,238,205,203,186,169,153,153,154,171,205,239,236,221,203,187,170,170,170,187,205,223,255,206,221,204,203,187,187,188,205,239,255,252,238,221,221,204,204,205,221,239,255,255,173,221,204,204,204,205,221,238,239,255,224,0,0,0,223,254,237,221,204,204,204,204,204,204,143,255,254,221,220,204,221,221,221,238,236,239,238,220,203,187,187,188,204,221,239,222,238,220,187,170,170,170,187,204,221,237,238,220,186,153,153,153,154,171,204,222,221,236,186,152,135,119,136,154,171,205,221,221,203,168,119,102,103,120,154,188,205,221,220,169,135,101,85,102,120,154,204,221,204,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,238,204,202,152,118,101,85,103,137,171,222,221,220,186,152,119,102,103,120,155,205,238,205,203,170,152,135,119,136,154,188,239,236,221,203,170,153,153,153,170,188,222,254,206,220,203,186,170,170,171,188,222,239,252,237,220,204,187,187,187,204,222,239,255,206,237,221,220,204,204,221,222,255,255,253,254,238,221,221,221,221,239,255,255,255,140,204,204,220,221,221,222,238,255,255,224,0,0,0,239,255,255,253,237,221,220,204,204,204,127,255,255,255,254,222,223,222,239,255,253,255,255,255,237,221,204,205,238,238,255,223,255,255,237,204,188,187,205,221,239,253,255,254,236,186,170,170,187,204,223,239,223,255,220,186,152,136,153,171,204,239,255,255,237,186,135,119,119,137,171,221,239,223,255,202,151,101,85,103,137,188,223,254,239,220,168,117,68,69,103,154,189,239,254,253,202,135,84,51,69,120,171,207,255,223,220,168,117,67,52,87,138,205,239,237,253,202,151,101,68,69,120,171,223,255,239,220,185,135,101,85,104,155,207,255,253,238,203,169,135,118,120,154,205,255,255,223,237,203,169,152,136,154,188,223,255,253,253,220,203,170,170,170,205,223,255,255,223,253,221,204,203,204,205,222,255,255,253,254,254,221,220,221,221,239,255,255,255,223,254,238,238,222,238,255,255,255,255,252,239,255,255,255,255,255,255,255,255,255,141,204,205,222,239,255,255,255,255,255,240,0,0,0,239,255,223,222,221,204,204,204,204,204,127,255,239,255,253,238,254,221,239,255,253,255,255,238,221,221,221,205,223,255,255,223,254,237,220,203,187,188,204,221,255,253,255,253,219,186,170,170,187,204,221,255,255,254,219,170,152,137,153,171,204,255,255,254,220,186,152,119,120,137,172,204,255,253,253,202,152,118,102,103,137,172,205,254,221,203,169,118,84,69,103,154,204,223,221,237,186,151,100,35,70,120,171,221,255,221,203,169,118,67,36,87,154,205,255,254,220,202,152,101,68,86,120,172,222,253,221,220,170,135,102,86,120,154,189,255,254,221,203,169,135,119,120,153,188,239,255,223,237,203,169,152,137,154,188,221,255,253,255,236,203,186,170,170,172,222,239,255,223,254,204,220,187,187,188,221,239,255,254,255,222,237,221,204,221,223,255,255,255,223,254,255,255,236,237,255,255,255,255,254,255,255,237,254,237,255,255,255,255,255,108,203,188,205,220,207,223,239,255,255,224,0,0,0,189,204,187,170,170,170,170,170,171,187,141,220,203,187,170,170,170,187,188,205,220,205,203,170,169,153,153,170,171,188,205,203,203,186,153,153,137,153,154,171,188,219,188,170,153,136,136,136,137,154,171,205,187,186,153,136,119,119,120,137,154,171,203,171,169,136,118,102,102,119,137,154,188,186,186,152,118,102,86,102,120,137,171,187,170,153,135,102,85,85,102,120,154,187,186,169,152,118,85,68,86,103,136,154,187,170,153,135,102,84,69,86,120,137,171,186,169,152,118,101,85,86,103,137,154,187,170,169,135,118,102,86,102,120,154,171,186,186,153,135,118,102,102,119,137,171,204,171,170,152,135,119,119,119,137,154,188,202,203,170,153,136,136,136,137,154,188,204,188,187,170,153,153,136,153,154,187,205,219,220,203,170,170,153,154,170,187,205,221,189,204,187,186,170,170,171,187,204,222,219,221,204,203,187,187,187,204,205,222,237,140,187,187,187,187,187,187,188,221,222,192,0,0,0,188,187,170,153,153,153,153,154,170,187,155,203,186,170,169,153,154,170,187,188,219,188,186,169,153,153,153,153,170,171,188,186,186,169,152,136,136,136,153,154,171,203,171,169,152,135,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,170,186,154,152,135,118,102,102,119,120,153,171,169,169,135,118,102,102,102,119,136,154,170,153,152,119,102,101,86,102,119,137,154,169,153,135,118,101,85,102,103,120,153,170,153,152,119,102,101,85,102,119,137,154,169,153,135,118,102,101,102,103,120,153,170,154,152,135,118,102,102,102,119,137,170,169,169,152,119,118,102,102,119,136,154,186,154,169,136,119,119,119,119,136,153,171,186,186,153,136,135,119,119,136,153,170,187,171,170,153,152,136,136,136,153,170,188,186,187,170,169,153,153,153,153,170,188,204,188,187,170,170,153,153,170,170,187,205,203,204,203,187,170,170,170,187,188,205,221,155,187,170,170,170,170,170,187,188,205,192,0,0,0,189,203,187,170,170,170,170,171,187,187,141,220,203,187,186,170,171,187,204,205,219,204,203,170,170,153,154,170,171,187,205,188,203,170,153,152,153,153,154,171,188,219,187,186,152,136,136,136,137,154,171,188,187,186,152,135,119,119,120,136,154,187,203,171,169,135,118,102,103,119,137,154,187,186,185,152,118,102,86,102,120,137,171,187,170,153,135,101,85,85,103,120,154,171,186,169,136,118,85,68,86,103,137,154,187,170,153,135,102,84,69,86,120,137,171,186,170,152,119,101,85,86,103,136,154,187,170,169,136,118,102,86,102,120,153,187,186,186,153,135,118,102,102,119,137,171,203,171,170,152,136,119,119,119,137,154,188,203,187,170,153,136,136,136,137,154,188,204,188,187,170,153,153,136,153,154,171,205,203,203,187,170,169,153,154,170,187,204,221,189,220,187,187,170,170,171,187,204,222,219,221,204,203,187,187,188,204,205,221,237,139,187,187,187,187,187,187,188,205,221,192,0,0,0,238,255,223,221,204,204,221,204,204,204,127,255,255,253,222,221,222,222,239,255,254,255,255,237,205,204,204,220,221,238,255,223,255,222,204,187,187,187,188,221,254,254,255,237,203,170,153,170,170,188,206,239,238,237,203,169,136,136,137,171,204,222,255,223,219,169,135,119,119,137,171,205,222,237,252,186,151,102,85,103,137,171,206,237,222,203,168,117,68,69,103,138,188,222,237,236,185,135,84,51,69,120,171,206,255,222,203,152,117,67,52,87,137,188,222,253,220,186,151,101,68,70,120,171,205,254,222,203,169,135,101,86,103,154,188,223,221,237,203,169,135,119,119,137,172,223,255,239,220,187,169,136,136,153,171,205,255,255,253,220,187,170,153,154,171,206,223,255,223,253,220,187,187,187,188,205,239,255,253,255,222,204,204,204,205,221,238,255,255,223,239,238,237,221,221,221,255,255,255,253,254,239,254,238,239,239,255,255,255,255,124,204,221,221,237,222,238,239,255,255,240,0,0,0,255,255,255,255,255,255,220,204,203,187,127,255,255,255,255,255,255,221,255,255,252,255,255,255,255,221,253,223,255,223,223,255,255,255,255,204,204,205,255,253,255,253,255,255,252,219,186,187,203,221,253,255,255,255,253,203,169,153,154,188,221,255,255,255,255,203,152,119,120,154,188,221,253,255,255,221,168,118,85,104,154,188,255,255,255,252,201,118,84,69,104,171,204,255,255,253,202,151,84,35,69,121,188,255,255,255,220,185,118,67,36,87,154,207,255,255,253,219,168,101,68,86,121,189,255,255,255,220,186,135,101,86,120,172,223,255,253,252,253,186,136,119,120,154,205,255,255,223,255,220,186,153,153,171,205,255,255,253,255,253,220,187,186,187,221,255,255,255,223,253,255,221,220,203,220,255,255,255,252,255,223,221,253,253,221,255,255,255,255,207,255,253,255,255,255,255,255,255,255,252,255,255,255,255,253,255,255,255,255,255,124,203,221,207,255,223,255,255,255,255,240,0,0,0,239,239,253,220,220,204,204,204,204,204,159,255,254,221,220,204,204,204,221,223,253,255,255,204,203,187,187,187,188,220,239,239,253,220,186,170,153,170,171,204,222,253,254,220,186,153,136,137,154,170,204,221,237,220,186,152,135,119,120,137,171,205,238,221,186,152,119,102,102,120,137,172,205,221,203,169,135,101,85,102,120,154,188,237,220,186,135,101,84,69,102,121,171,205,236,203,168,118,84,68,85,103,137,189,238,204,186,135,101,84,68,86,120,171,222,236,203,152,118,101,84,85,103,138,188,254,204,186,152,118,101,85,103,137,171,223,252,203,169,136,118,102,103,120,154,190,255,204,203,169,136,119,119,120,154,188,255,252,221,187,170,153,136,137,154,188,223,255,221,220,187,186,169,154,170,188,222,255,252,237,204,204,187,187,188,204,222,255,255,221,221,237,220,220,221,221,255,255,255,252,255,254,222,221,221,222,255,255,255,255,156,221,221,223,222,238,255,255,255,255,240,0,0,0,255,255,254,220,204,204,204,205,221,222,191,255,254,220,204,187,188,204,221,239,255,255,253,204,187,170,170,171,188,205,239,239,253,203,170,153,153,153,170,188,221,254,254,203,169,152,136,136,137,154,188,223,221,220,169,136,119,119,119,137,154,188,221,220,186,152,118,102,102,119,137,171,205,220,203,152,118,101,85,86,119,137,172,221,204,169,135,101,85,85,102,120,154,189,220,186,152,118,85,68,85,103,137,171,221,203,169,135,101,84,69,86,120,154,189,220,186,152,118,101,85,85,103,137,172,222,204,169,135,118,101,85,102,120,155,205,236,203,169,135,118,102,102,120,154,188,239,204,186,153,135,119,119,120,137,172,223,253,220,186,153,136,136,136,153,171,206,255,221,220,186,169,153,153,154,187,205,255,253,237,204,187,170,170,171,188,221,255,255,223,237,220,204,187,188,204,222,255,255,254,255,238,221,220,221,221,239,255,255,255,190,237,221,221,221,221,239,255,255,255,240,0,0,0,255,255,255,254,221,253,236,220,205,206,159,255,255,253,221,204,220,221,222,239,253,255,255,237,220,203,187,204,204,221,239,223,254,221,203,170,170,170,188,205,221,253,255,220,186,153,152,153,154,171,204,221,223,237,186,152,135,119,136,154,171,205,253,237,203,152,119,102,103,120,154,172,221,221,235,169,135,101,85,102,120,154,188,221,221,186,151,101,84,69,103,137,171,222,221,203,169,118,84,68,69,103,138,188,253,221,186,151,101,68,68,86,120,171,205,221,220,169,135,101,68,85,103,154,189,238,221,186,152,118,101,85,103,137,172,221,237,220,186,152,119,102,103,120,155,207,254,221,219,170,152,135,119,136,154,189,223,253,221,187,169,153,137,137,170,189,238,255,222,220,187,170,170,170,171,189,223,255,253,221,220,203,187,187,188,205,223,255,255,222,221,220,204,204,204,221,254,255,255,252,255,223,254,222,221,223,255,255,255,255,156,204,220,220,221,221,221,255,255,255,240,0,0,0,255,255,255,255,255,255,252,187,187,203,127,255,255,255,255,255,255,255,255,255,252,255,255,255,255,253,255,207,255,255,255,223,255,255,253,255,205,220,255,255,255,255,255,255,255,252,187,204,204,205,255,255,223,255,255,203,170,169,171,189,207,255,255,255,255,204,169,136,136,154,188,255,255,255,255,252,185,118,102,120,155,205,255,255,255,255,202,134,84,69,121,171,255,255,255,255,251,168,100,34,70,138,207,255,255,255,253,186,134,66,36,104,171,223,255,255,255,220,184,117,68,86,138,207,255,255,223,253,203,152,118,103,137,188,255,255,255,255,253,186,169,136,137,187,207,255,255,223,255,204,187,170,170,188,223,255,255,255,255,253,204,204,188,204,207,255,255,255,207,253,255,204,221,253,255,255,255,255,255,255,255,255,221,223,223,255,255,255,255,223,255,255,223,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,123,205,220,205,223,255,255,255,255,255,240,0,0,0,255,223,253,203,191,188,220,186,203,203,127,223,221,223,204,188,252,252,255,255,252,221,255,221,220,251,219,203,207,220,255,188,255,250,251,251,171,204,204,255,255,255,253,252,187,170,169,154,187,204,204,255,204,253,203,155,137,136,153,171,173,205,255,252,186,170,151,119,120,137,170,191,255,203,252,185,151,118,102,119,137,170,252,251,188,187,169,118,84,85,103,138,172,220,221,204,185,151,100,35,70,120,156,203,252,207,187,168,118,67,36,103,153,172,207,207,188,201,151,101,68,86,120,154,205,255,220,202,169,135,102,102,120,154,187,255,255,255,203,169,135,119,119,138,188,188,252,252,207,204,153,152,136,153,154,207,207,255,255,252,203,170,154,169,170,207,255,255,255,255,254,236,170,171,172,204,223,255,252,223,205,205,188,203,207,251,220,253,255,223,255,220,253,220,252,223,221,207,255,250,220,223,253,253,205,223,223,221,223,255,108,187,204,204,219,253,207,255,221,255,208,0,0,0,188,203,170,170,153,153,169,170,170,171,140,204,187,186,170,170,170,171,203,205,219,188,202,186,154,153,153,154,170,187,206,203,187,170,153,152,136,137,154,171,188,203,187,169,152,136,136,136,137,153,171,188,186,186,152,135,119,119,120,137,154,171,203,171,169,135,119,102,103,119,137,154,188,186,169,152,118,102,102,102,119,137,154,187,170,152,135,102,85,86,103,120,137,171,186,169,136,118,101,68,86,103,136,154,187,154,152,135,102,84,69,86,120,137,170,185,169,136,119,101,85,86,103,136,154,187,154,169,135,118,102,86,102,120,153,171,186,186,153,135,118,102,102,119,137,171,203,171,169,152,136,119,119,119,136,154,188,218,187,169,152,136,135,136,136,154,171,203,172,186,170,153,152,136,137,153,171,205,202,203,186,186,169,153,153,170,171,204,220,189,204,187,186,170,186,170,187,190,237,203,204,221,203,187,187,187,187,205,254,254,140,187,187,170,171,187,187,204,205,221,192,0,0,0,188,187,170,169,153,153,153,170,171,188,172,204,186,170,153,153,154,170,187,188,220,188,186,169,153,152,153,153,154,171,188,187,186,169,152,136,136,136,137,154,171,203,171,169,152,135,119,119,136,137,154,187,186,169,152,119,119,119,119,120,137,154,186,170,152,135,118,102,102,119,120,137,171,169,169,135,118,102,102,102,119,136,154,170,153,152,119,102,101,102,102,119,137,154,169,153,135,118,101,85,102,103,120,153,170,153,136,119,102,101,85,102,119,136,154,169,153,135,118,102,101,102,103,120,153,170,153,152,135,118,102,102,102,119,137,170,169,169,136,119,118,102,102,119,136,154,186,170,153,136,119,119,119,119,136,153,171,186,170,153,136,135,119,119,136,153,171,187,171,170,153,136,136,136,136,153,170,188,203,187,170,153,153,152,153,153,170,188,220,188,187,186,170,153,153,154,171,188,205,220,220,203,186,170,170,170,171,188,205,237,172,187,186,170,170,170,170,187,204,222,208,0,0,0,188,186,186,170,170,170,170,170,170,187,140,204,187,186,170,170,187,187,205,220,219,188,188,169,153,153,153,154,170,187,204,171,202,170,152,136,136,137,153,170,204,186,187,169,152,136,120,136,136,153,170,187,170,170,152,135,119,119,119,136,153,170,186,186,152,135,118,102,103,119,136,154,186,170,169,136,118,102,102,102,119,136,170,170,170,152,135,102,85,86,103,120,153,170,170,169,136,118,101,68,86,103,136,154,170,154,152,135,102,84,69,102,120,137,171,170,185,152,118,102,85,86,103,136,154,186,170,153,136,119,102,102,102,120,153,171,186,170,152,135,119,102,102,119,137,154,187,171,169,152,135,119,119,119,137,154,187,171,218,169,152,136,119,136,136,154,172,187,188,171,169,153,152,136,137,154,170,189,203,187,187,169,169,153,153,170,172,188,204,188,204,186,170,170,170,170,171,188,205,203,205,187,203,186,187,187,172,187,221,221,122,170,170,186,170,170,171,187,187,205,176,0,0,0,255,255,255,255,252,191,223,187,171,191,111,255,255,255,255,223,255,255,255,255,253,255,255,255,255,204,253,255,223,255,255,223,255,255,255,252,187,223,252,255,255,255,255,255,255,255,188,191,207,191,255,255,253,255,253,255,187,186,171,252,252,255,255,255,255,220,202,153,153,172,223,255,255,255,255,205,186,135,119,137,155,191,255,255,255,255,203,151,84,70,138,219,255,255,255,255,205,169,100,18,87,155,191,223,255,255,255,186,151,82,36,121,171,207,255,255,255,252,169,134,84,87,155,253,255,253,255,252,204,169,135,119,138,172,223,255,255,255,255,187,153,153,154,175,207,255,255,223,255,191,172,186,170,204,191,255,255,253,255,255,203,188,187,223,221,255,255,255,223,255,223,252,205,255,255,255,255,255,255,255,253,253,223,252,255,255,255,255,255,207,255,253,223,252,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,107,207,223,223,255,207,255,255,255,255,240,0,0,0,255,255,175,255,191,171,251,159,187,171,107,255,251,255,175,170,251,250,187,255,255,255,251,191,185,251,186,187,191,255,255,250,255,250,251,187,170,255,250,191,191,255,191,250,175,187,153,154,169,191,251,251,171,251,186,169,152,154,153,170,251,187,255,175,250,170,152,120,120,137,175,191,175,251,191,186,153,118,102,136,153,191,255,191,255,250,152,119,84,86,121,155,191,187,187,175,171,168,100,34,87,136,154,255,171,175,153,184,119,82,37,121,169,170,255,250,187,186,152,118,84,102,120,153,191,251,159,250,154,152,118,102,120,138,250,171,175,251,186,184,152,136,120,154,171,255,251,175,191,186,170,153,169,159,138,250,255,170,255,187,175,169,168,137,171,250,187,255,251,255,255,251,169,171,175,191,187,187,187,255,191,251,255,250,191,175,175,251,255,175,191,255,255,187,255,255,191,255,255,255,255,255,255,255,251,255,251,255,255,251,111,170,171,171,186,250,250,187,255,251,240,0,0,0,255,222,255,255,255,220,204,207,205,207,111,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,220,255,255,255,255,255,255,255,255,255,253,205,255,255,255,255,255,255,255,255,207,220,252,223,255,255,255,255,255,255,221,204,220,221,223,255,255,255,255,207,235,186,187,188,221,253,223,252,255,221,203,152,120,154,204,255,255,255,223,255,253,184,84,70,155,205,223,255,255,255,205,218,116,34,72,172,252,255,255,255,255,252,167,66,20,122,223,255,255,221,255,253,218,150,68,88,188,253,255,255,255,223,252,218,151,120,172,221,255,255,255,255,252,252,202,170,171,207,255,253,255,223,255,253,252,220,188,205,223,223,255,252,255,253,255,223,204,253,253,255,255,255,255,255,255,255,252,223,255,253,255,255,255,255,221,255,255,207,255,255,255,255,255,255,255,255,223,255,255,223,255,255,255,252,255,255,255,255,255,255,255,255,255,255,107,221,205,221,255,223,255,255,255,255,240,0,0,0,255,255,255,221,221,205,221,222,223,255,207,255,255,220,204,203,204,189,238,239,255,255,255,220,187,186,170,187,204,223,239,255,253,204,186,153,153,153,170,188,223,255,254,220,170,152,136,136,137,171,188,222,255,220,185,152,119,119,119,137,170,204,255,252,202,152,118,102,102,119,137,171,205,254,203,168,118,101,85,86,119,153,188,222,220,185,135,101,85,85,102,120,154,205,220,202,152,118,85,68,85,103,137,171,221,204,169,135,101,84,69,86,120,154,205,236,202,152,118,85,85,85,103,137,171,223,204,185,135,118,85,85,102,120,171,207,253,203,169,135,118,102,102,120,154,188,255,221,202,169,135,119,119,120,154,188,223,253,220,186,169,136,136,136,154,172,223,255,255,220,186,169,153,153,170,187,223,255,255,255,221,203,186,170,171,188,223,255,255,255,255,220,220,204,204,205,222,255,255,255,255,255,238,221,221,222,239,255,255,255,223,255,254,254,221,239,255,255,255,255,240,0,0,0,207,254,253,220,207,253,237,204,188,236,127,239,255,239,239,238,255,255,255,255,253,223,221,255,221,253,239,239,238,239,255,207,239,255,223,239,223,222,239,239,255,253,238,253,253,221,221,204,221,238,254,253,237,255,238,220,204,188,188,206,237,255,254,239,205,255,187,170,170,188,221,238,255,255,255,252,203,152,119,137,188,222,255,253,222,223,220,168,84,70,138,207,239,239,220,255,220,202,116,18,71,172,237,238,254,238,239,251,167,66,36,122,189,238,239,222,237,222,202,134,68,104,173,221,238,253,222,238,252,185,135,120,171,207,221,255,253,255,252,204,186,154,171,190,239,239,253,223,255,253,204,204,204,220,205,255,255,239,255,254,222,221,204,253,239,223,255,254,255,255,237,221,221,239,239,255,255,255,222,255,254,255,237,254,254,255,239,255,255,206,239,255,255,253,222,255,239,255,255,253,255,239,254,238,255,254,255,255,255,255,126,221,204,204,206,206,206,237,255,255,192,0,0,0,255,255,255,248,255,143,248,248,249,248,95,255,249,248,255,255,255,255,255,255,255,143,255,255,248,153,255,255,255,255,255,255,255,255,249,255,136,159,255,255,255,255,255,255,248,254,143,143,143,248,255,255,255,255,255,255,136,120,255,255,248,143,255,255,255,249,143,248,249,249,143,255,143,143,248,137,143,104,104,136,136,248,255,255,255,248,136,120,100,86,255,143,248,255,255,248,255,136,100,34,72,136,143,255,255,233,143,255,247,82,37,120,143,248,255,255,159,255,248,135,68,88,143,255,255,255,255,255,249,143,247,118,136,249,255,255,159,255,255,255,121,136,249,255,255,255,255,255,255,248,255,248,255,255,255,255,248,255,255,152,255,255,143,249,255,143,255,255,143,255,255,248,255,152,248,255,255,255,255,255,255,255,255,143,255,255,255,159,255,143,255,255,255,143,255,143,255,248,255,255,255,255,255,255,143,255,255,255,255,255,111,153,255,207,248,255,255,255,255,255,240,0,0,0,127,135,135,102,104,135,119,119,104,255,87,255,136,255,136,136,143,136,255,255,248,111,247,120,248,143,135,120,135,255,247,135,247,248,127,248,136,136,135,136,143,135,248,136,247,247,255,143,136,127,143,248,247,143,143,247,119,247,104,143,143,255,247,105,143,136,118,120,111,119,111,255,127,136,248,143,247,135,136,247,127,248,143,119,104,135,247,134,135,103,103,127,120,248,119,119,136,103,247,118,136,120,119,255,143,127,136,135,103,103,119,119,120,143,127,119,127,135,118,104,135,119,103,127,126,232,203,136,127,247,119,135,111,143,135,127,104,136,247,136,247,246,135,248,135,255,247,136,248,143,143,247,136,127,255,143,255,119,248,136,120,143,247,120,119,136,143,247,143,248,255,248,143,136,120,119,127,248,120,248,136,136,127,143,127,143,167,120,127,255,255,135,143,120,135,143,143,135,143,119,248,247,136,143,143,255,248,135,127,248,143,135,143,135,120,127,247,119,120,248,112,0,0,0,87,120,102,119,102,118,119,118,135,121,104,173,152,137,152,218,185,153,153,157,152,121,170,137,152,136,136,152,170,136,154,135,137,169,153,137,152,152,153,137,169,153,122,136,121,152,136,135,135,152,136,154,118,152,119,136,135,151,136,152,152,153,136,121,137,153,120,135,136,136,137,169,152,135,153,135,120,120,135,135,135,151,153,151,121,152,152,120,135,152,135,120,136,154,118,153,119,120,120,119,135,120,136,153,167,121,136,137,135,119,135,136,120,136,137,119,136,151,136,135,135,103,136,137,137,136,121,137,136,120,135,119,119,120,137,138,118,137,151,119,151,135,119,153,137,153,150,106,168,136,136,136,137,135,136,136,153,135,154,168,136,152,120,136,136,136,153,152,121,153,136,136,152,136,135,136,136,169,120,170,152,152,168,136,136,136,136,136,167,138,152,137,138,136,136,154,137,137,153,120,169,153,216,137,152,138,137,152,170,135,105,136,135,135,120,119,103,135,119,121,80,0,0,0,255,255,255,255,255,255,255,255,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,171,191,255,255,255,255,255,255,255,255,133,104,255,255,255,255,255,255,255,255,245,18,111,255,255,255,255,255,255,255,255,97,21,191,255,255,255,255,255,255,255,248,101,159,255,255,255,255,255,255,255,255,187,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,251,187,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,239,255,251,255,255,255,255,255,255,255,169,153,191,255,255,255,255,255,255,255,151,102,136,191,255,255,255,255,255,251,183,83,69,122,255,255,255,255,255,255,249,99,34,70,175,255,255,255,255,255,255,150,66,36,121,255,255,255,255,255,255,186,133,68,87,175,255,255,255,255,255,255,250,134,103,159,255,255,255,255,255,255,252,249,153,191,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,187,191,253,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,143,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,136,255,255,255,255,255,255,255,255,246,18,255,255,255,255,255,255,255,255,255,243,7,255,255,255,255,255,255,255,255,248,188,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,143,255,255,255,255,255,255,255,255,255,249,255,255,255,255,255,111,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,239,255,255,229,239,255,255,63,255,238,238,229,239,255,255,255,255,255,255,255,254,238,238,238,238,238,238,238,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,94,94,238,238,238,238,238,238,238,238,238,238,238,238,238,238,239,255,255,255,244,95,95,255,245,255,255,255,255,255,84,85,95,95,255,255,255,255,255,255,95,79,255,84,255,255,255,255,254,238,238,78,229,230,238,94,238,238,238,238,229,229,229,238,94,238,238,238,238,238,238,238,94,238,68,238,238,238,238,94,239,255,245,69,63,63,255,255,255,255,245,255,255,255,79,79,255,255,255,255,255,255,255,255,255,95,95,255,255,255,255,255,255,255,255,245,255,95,255,255,255,255,255,255,255,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,254,255,255,254,255,254,255,255,254,255,255,255,255,255,255,255,255,255,255,254,255,254,255,254,240,0,0,0,255,255,255,255,255,255,255,255,159,175,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,255,175,255,255,255,255,255,255,159,255,255,251,255,255,255,255,255,175,153,155,255,255,255,255,255,255,255,255,167,103,127,171,255,255,255,255,255,255,167,84,69,121,255,255,255,255,255,255,255,100,34,71,255,255,255,255,255,255,255,166,66,35,105,255,255,255,255,255,255,250,117,67,87,159,255,255,255,255,255,255,249,119,103,154,190,255,255,255,255,255,255,250,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,255,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,223,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,191,186,170,175,95,255,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,250,153,170,255,255,255,255,255,255,255,252,101,86,255,255,255,255,239,255,255,255,148,18,89,255,255,255,255,255,255,255,249,82,20,157,255,255,255,255,255,255,255,151,84,111,255,255,255,255,255,255,255,255,170,170,175,255,255,255,255,255,255,255,250,250,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,191,251,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,254,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,255,111,249,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,170,175,255,169,170,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,175,255,251,255,255,255,255,255,255,255,255,159,175,255,255,255,175,250,255,175,255,175,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,168,167,103,127,255,255,255,255,255,255,255,215,83,69,122,255,255,255,255,255,255,250,100,34,71,175,255,255,255,255,175,249,151,66,36,104,175,255,255,255,255,255,250,118,68,88,159,255,255,255,255,255,255,255,118,103,255,250,255,255,255,255,255,255,249,169,175,255,255,255,255,255,255,255,175,255,255,175,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,202,175,255,250,255,255,255,255,255,255,250,250,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,79,169,175,255,250,159,255,255,255,255,240,0,0,0,95,239,86,111,246,102,238,239,111,255,86,230,230,238,238,239,255,255,255,255,254,238,230,238,238,238,230,238,238,238,238,239,255,255,111,255,255,255,255,255,255,254,238,238,230,238,238,110,238,238,238,238,238,238,110,78,110,238,238,238,230,238,238,239,246,245,111,86,255,255,255,255,255,245,255,255,255,244,111,111,255,255,255,254,238,229,230,102,101,110,229,238,230,238,238,238,238,229,86,69,238,238,238,238,238,238,238,238,230,230,101,101,238,238,238,230,238,238,230,102,110,110,238,238,230,238,110,239,246,246,255,86,255,111,255,255,255,255,255,255,255,255,85,111,102,245,246,255,246,255,255,255,255,111,255,255,255,255,255,255,255,255,246,245,246,255,111,254,238,238,238,238,238,238,230,238,238,254,110,254,255,254,255,110,246,254,255,102,255,254,255,254,239,255,255,254,254,254,254,254,255,255,255,255,255,95,255,254,255,255,95,255,101,111,246,254,102,254,102,94,80,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,127,168,255,255,247,255,63,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,239,255,255,255,255,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,223,255,255,255,255,255,255,255,255,255,255,255,255,255,248,118,119,255,255,255,255,255,255,255,134,84,69,127,255,255,255,255,255,255,249,100,34,72,255,255,255,255,255,255,255,246,66,36,95,255,255,255,255,255,255,127,245,68,91,255,255,255,255,255,255,255,255,247,246,127,255,255,255,255,255,255,255,255,135,127,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,143,255,255,255,255,240,0,0,0,238,238,238,222,238,238,237,213,238,238,62,238,238,221,221,222,238,238,238,238,238,238,238,238,238,238,237,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,237,221,221,221,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,228,33,238,238,238,238,238,238,238,221,221,209,29,221,221,221,221,221,221,221,221,221,221,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,237,224,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,117,79,255,255,255,255,255,255,255,255,244,18,71,255,255,255,255,255,255,255,255,66,20,255,255,255,255,255,255,255,255,255,84,191,255,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,255,255,255,255,255,255,255,255,255,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,127,255,255,255,255,255,79,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,207,255,255,255,255,255,255,255,255,255,255,255,255,255,119,103,175,255,255,255,255,255,255,255,246,68,69,247,255,255,255,255,255,255,246,84,34,70,159,255,255,255,255,255,255,245,66,52,95,255,255,255,255,255,255,255,117,67,79,127,255,255,255,255,255,255,255,247,86,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,255,255,255,127,255,255,255,255,240,0,0,0,238,238,238,222,238,238,237,222,238,238,238,238,238,221,221,222,238,238,238,238,238,238,238,238,238,238,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,221,221,221,221,221,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,83,78,238,238,238,238,238,238,238,238,229,18,238,238,238,238,237,221,221,221,221,210,36,221,221,221,221,221,221,221,221,221,211,61,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,62,229,238,238,238,238,238,238,238,237,224,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,1,0,0,0,0,0,0,0,221,36,6,129,149,67,0,64,82,184,30,133,235,81,1,192,242,210,77,98,16,88,255,63,113,61,10,215,163,112,249,191,204,238,201,195,66,173,227,63,136,26,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,2,0,0,210,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,215,34,0,200,155,34,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,32,95,34,0,200,155,34,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,104,24,31,0,216,39,34,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+841064);
/* memory initializer */ allocate([232,247,33,0,216,39,34,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,240,206,33,0,120,167,33,0,56,0,0,0,84,65,82,86,16,138,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,184,96,33,0,120,167,33,0,56,0,0,0,84,65,82,86,16,138,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,168,34,33,0,216,255,32,0,16,0,0,0,5,0,0,0,152,229,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,136,202,32,0,112,176,32,0,64,0,0,0,3,0,0,0,79,233,47,55,239,198,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,120,154,32,0,112,176,32,0,64,0,0,0,3,0,0,0,79,233,47,55,239,198,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,56,130,32,0,32,104,32,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,8,83,32,0,32,104,32,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,224,50,32,0,16,0,32,0,76,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,80,234,31,0,120,214,31,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,216,195,31,0,8,173,31,0,84,0,0,0,82,76,79,67,176,155,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,40,138,31,0,48,121,31,0,88,0,0,0,82,76,79,67,200,106,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,96,79,31,0,168,40,31,0,92,0,0,0,82,76,79,67,200,106,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,179,31,0,108,0,0,0,224,252,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,96,11,46,194,239,147,48,155,152,34,50,21,86,248,50,12,160,47,51,34,148,245,50,173,165,30,50,163,68,141,48,162,136,43,45,44,216,154,48,55,154,38,50,27,20,251,50,107,152,47,51,136,206,242,50,125,193,26,50,147,213,134,48,252,244,69,45,111,255,161,48,107,170,42,50,240,205,253,50,44,137,47,51,140,5,240,50,27,236,22,50,235,160,128,48,147,242,98,45,252,102,169,48,34,201,46,50,167,65,0,51,78,114,47,51,116,57,237,50,147,37,19,50,233,74,117,48,16,84,129,45,51,16,177,48,67,246,50,50,248,153,1,51,214,83,47,51,133,106,234,50,242,109,15,50,87,195,105,48,121,137,146,45,142,252,184,48,179,49,55,50,198,239,2,51,199,45,47,51,2,153,231,50,64,197,11,50,134,168,94,48,77,64,165,45,147,45,193,48,86,123,59,50,241,66,4,51,37,0,47,51,48,197,228,50,130,43,8,50,81,247,83,48,254,150,185,45,166,164,201,48,11,211,63,50,85,147,5,51,246,202,46,51,83,239,225,50,189,160,4,50,120,173,73,48,228,204,207,45,79,99,210,48,175,56,68,50,207,224,6,51,64,142,46,51,176,23,223,50,247,36,1,50,224,199,63,48,211,237,231,45,230,106,219,48,30,172,72,50,63,43,8,51,11,74,46,51,135,62,220,50,88,112,251,49,86,68,54,48,170,252,0,46,14,189,228,48,51,45,77,50,127,114,9,51,94,254,45,51,28,100,217,50,183,180,244,49,102,31,45,48,79,237,14,46,26,91,238,48,195,187,81,50,112,182,10,51,67,171,45,51,179,136,214,50,5,23,238,49,123,87,36,48,99,3,30,46,153,70,248,48,161,87,86,50,237,246,11,51,196,80,45,51,138,172,211,50,55,151,231,49,25,233,27,48,248,128,46,46,120,64,1,49,161,0,91,50,213,51,13,51,235,238,44,51,229,207,208,50,63,53,225,49,90,210,19,48,38,214,63,46,209,133,6,49,145,182,95,50,6,109,14,51,195,133,44,51,3,243,205,50,9,241,218,49,105,16,12,48,118,172,82,46,4,244,11,49,61,121,100,50,96,162,15,51,91,21,44,51,34,22,203,50,128,202,212,49,226,160,4,48,249,200,102,46,229,139,17,49,112,72,105,50,194,211,16,51,192,157,43,51,133,57,200,50,136,193,206,49,69,2,251,47,253,83,124,46,9,78,23,49,242,35,110,50,7,1,18,51,253,30,43,51,103,93,197,50,8,214,200,49,135,94,237,47,169,176,137,46,71,59,29,49,137,11,115,50,18,42,19,51,36,153,42,51,9,130,194,50,220,7,195,49,171,80,224,47,245,252,149,46,58,84,35,49,246,254,119,50,194,78,20,51,69,12,42,51,165,167,191,50,228,86,189,49,137,212,211,47,2,28,163,46,173,153,41,49,251,253,124,50,246,110,21,51,111,120,41,51,118,206,188,50,244,194,183,49,19,229,199,47,127,23,177,46,62,12,48,49,42,4,129,50,144,138,22,51,179,221,40,51,186,246,185,50,233,75,178,49,120,126,188,47,136,255,191,46,175,172,54,49,222,142,131,50,110,161,23,51,38,60,40,51,170,32,183,50,142,241,172,49,210,155,177,47,96,215,207,46,160,123,61,49,246,30,134,50,116,179,24,51,218,147,39,51,129,76,180,50,187,179,167,49,49,56,167,47,10,169,224,46,203,121,68,49,78,180,136,50,127,192,25,51,225,228,38,51,117,122,177,50,57,146,162,49,151,80,157,47,179,131,242,46,204,167,75,49,192,78,139,50,119,200,26,51,80,47,38,51,192,170,174,50,210,140,157,49,111,223,147,47,199,189,2,47,88,6,83,49,37,238,141,50,59,203,27,51,62,115,37,51,152,221,171,50,77,163,152,49,120,225,138,47,31,195,12,47,4,150,90,49,84,146,144,50,173,200,28,51,191,176,36,51,49,19,169,50,117,213,147,49,62,83,130,47,41,100,23,47,125,87,98,49,34,59,147,50,179,192,29,51,234,231,35,51,193,75,166,50,5,35,143,49,33,94,116,47,53,158,34,47,95,75,106,49,104,232,149,50,47,179,30,51,215,24,35,51,124,135,163,50,194,139,138,49,7,229,100,47,163,125,46,47,65,114,114,49,246,153,152,50,4,160,31,51,158,67,34,51,148,198,160,50,104,15,134,49,10,51,86,47,157,6,59,47,189,204,122,49,162,79,155,50,28,135,32,51,87,104,33,51,59,9,158,50,180,173,129,49,118,65,72,47,231,96,11,46,194,239,147,48,155,152,34,50,21,86,248,50,12,160,47,51,34,148,245,50,173,165,30,50,163,68,141,48,162,136,43,45,44,216,154,48,55,154,38,50,27,20,251,50,107,152,47,51,136,206,242,50,125,193,26,50,147,213,134,48,252,244,69,45,111,255,161,48,107,170,42,50,240,205,253,50,44,137,47,51,140,5,240,50,27,236,22,50,235,160,128,48,147,242,98,45,252,102,169,48,34,201,46,50,167,65,0,51,78,114,47,51,116,57,237,50,147,37,19,50,233,74,117,48,16,84,129,45,51,16,177,48,67,246,50,50,248,153,1,51,214,83,47,51,133,106,234,50,242,109,15,50,87,195,105,48,121,137,146,45,142,252,184,48,179,49,55,50,198,239,2,51,199,45,47,51,2,153,231,50,64,197,11,50,134,168,94,48,77,64,165,45,147,45,193,48,86,123,59,50,241,66,4,51,37,0,47,51,48,197,228,50,130,43,8,50,81,247,83,48,254,150,185,45,166,164,201,48,11,211,63,50,85,147,5,51,246,202,46,51,83,239,225,50,189,160,4,50,120,173,73,48,228,204,207,45,79,99,210,48,175,56,68,50,207,224,6,51,64,142,46,51,176,23,223,50,247,36,1,50,224,199,63,48,211,237,231,45,230,106,219,48,30,172,72,50,63,43,8,51,11,74,46,51,135,62,220,50,88,112,251,49,86,68,54,48,170,252,0,46,14,189,228,48,51,45,77,50,127,114,9,51,94,254,45,51,28,100,217,50,183,180,244,49,102,31,45,48,79,237,14,46,26,91,238,48,195,187,81,50,112,182,10,51,67,171,45,51,179,136,214,50,5,23,238,49,123,87,36,48,99,3,30,46,153,70,248,48,161,87,86,50,237,246,11,51,196,80,45,51,138,172,211,50,55,151,231,49,25,233,27,48,248,128,46,46,120,64,1,49,161,0,91,50,213,51,13,51,235,238,44,51,229,207,208,50,63,53,225,49,90,210,19,48,38,214,63,46,209,133,6,49,145,182,95,50,6,109,14,51,195,133,44,51,3,243,205,50,9,241,218,49,105,16,12,48,118,172,82,46,4,244,11,49,61,121,100,50,96,162,15,51,91,21,44,51,34,22,203,50,128,202,212,49,226,160,4,48,249,200,102,46,229,139,17,49,112,72,105,50,194,211,16,51,192,157,43,51,133,57,200,50,136,193,206,49,69,2,251,47,253,83,124,46,9,78,23,49,242,35,110,50,7,1,18,51,253,30,43,51,103,93,197,50,8,214,200,49,135,94,237,47,169,176,137,46,71,59,29,49,137,11,115,50,18,42,19,51,36,153,42,51,9,130,194,50,220,7,195,49,171,80,224,47,245,252,149,46,58,84,35,49,246,254,119,50,194,78,20,51,69,12,42,51,165,167,191,50,228,86,189,49,137,212,211,47,2,28,163,46,173,153,41,49,251,253,124,50,246,110,21,51,111,120,41,51,118,206,188,50,244,194,183,49,19,229,199,47,127,23,177,46,62,12,48,49,42,4,129,50,144,138,22,51,179,221,40,51,186,246,185,50,233,75,178,49,120,126,188,47,136,255,191,46,175,172,54,49,222,142,131,50,110,161,23,51,38,60,40,51,170,32,183,50,142,241,172,49,210,155,177,47,96,215,207,46,160,123,61,49,246,30,134,50,116,179,24,51,218,147,39,51,129,76,180,50,187,179,167,49,49,56,167,47,10,169,224,46,203,121,68,49,78,180,136,50,127,192,25,51,225,228,38,51,117,122,177,50,57,146,162,49,151,80,157,47,179,131,242,46,204,167,75,49,192,78,139,50,119,200,26,51,80,47,38,51,192,170,174,50,210,140,157,49,111,223,147,47,199,189,2,47,88,6,83,49,37,238,141,50,59,203,27,51,62,115,37,51,152,221,171,50,77,163,152,49,120,225,138,47,31,195,12,47,4,150,90,49,84,146,144,50,173,200,28,51,191,176,36,51,49,19,169,50,117,213,147,49,62,83,130,47,41,100,23,47,125,87,98,49,34,59,147,50,179,192,29,51,234,231,35,51,193,75,166,50,5,35,143,49,33,94,116,47,53,158,34,47,95,75,106,49,104,232,149,50,47,179,30,51,215,24,35,51,124,135,163,50,194,139,138,49,7,229,100,47,163,125,46,47,65,114,114,49,246,153,152,50,4,160,31,51,158,67,34,51,148,198,160,50,104,15,134,49,10,51,86,47,157,6,59,47,189,204,122,49,162,79,155,50,28,135,32,51,87,104,33,51,59,9,158,50,180,173,129,49,118,65,72,47,211,96,139,46,134,152,162,50,244,159,175,51,152,165,158,50,135,136,171,45,33,154,166,50,83,152,175,51,104,193,154,50,225,244,197,45,84,170,170,50,20,137,175,51,7,236,150,50,118,242,226,45,11,201,174,50,55,114,175,51,128,37,147,50,0,84,1,46,44,246,178,50,190,83,175,51,222,109,143,50,102,137,18,46,156,49,183,50,175,45,175,51,44,197,139,50,55,64,37,46,62,123,187,50,13,0,175,51,111,43,136,50,229,150,57,46,241,210,191,50,222,202,174,51,173,160,132,50,200,204,79,46,149,56,196,50,41,142,174,51,229,36,129,50,181,237,103,46,2,172,200,50,243,73,174,51,53,112,123,50,153,252,128,46,23,45,205,50,70,254,173,51,149,180,116,50,60,237,142,46,166,187,209,50,43,171,173,51,231,22,110,50,78,3,158,46,132,87,214,50,172,80,173,51,24,151,103,50,223,128,174,46,132,0,219,50,212,238,172,51,32,53,97,50,13,214,191,46,115,182,223,50,172,133,172,51,236,240,90,50,90,172,210,46,31,121,228,50,68,21,172,51,99,202,84,50,217,200,230,46,81,72,233,50,168,157,171,51,108,193,78,50,217,83,252,46,210,35,238,50,230,30,171,51,237,213,72,50,151,176,9,47,105,11,243,50,13,153,170,51,193,7,67,50,225,252,21,47,213,254,247,50,45,12,170,51,204,86,61,50,235,27,35,47,214,253,252,50,87,120,169,51,220,194,55,50,103,23,49,47,23,4,1,51,157,221,168,51,210,75,50,50,111,255,63,47,203,142,3,51,16,60,168,51,119,241,44,50,68,215,79,47,228,30,6,51,194,147,167,51,165,179,39,50,236,168,96,47,60,180,8,51,202,228,166,51,35,146,34,50,147,131,114,47,173,78,11,51,57,47,166,51,189,140,29,50,182,189,130,47,17,238,13,51,39,115,165,51,56,163,24,50,13,195,140,47,63,146,16,51,168,176,164,51,96,213,19,50,21,100,151,47,14,59,19,51,212,231,163,51,241,34,15,50,32,158,162,47,83,232,21,51,193,24,163,51,175,139,10,50,139,125,174,47,225,153,24,51,136,67,162,51,85,15,6,50,132,6,187,47,140,79,27,51,65,104,161,51,161,173,1,50,91,65,200,47,37,9,30,51,6,135,160,51,154,204,250,49,238,50,214,47,127,198,32,51,239,159,159,51,32,114,242,49,231,228,228,47,102,135,35,51,24,179,158,51,64,75,234,49,255,93,244,47,170,75,38,51,157,192,157,51,96,87,226,49,45,83,2,48,25,19,41,51,152,200,156,51,230,149,218,49,101,225,10,48,128,221,43,51,37,203,155,51,59,6,211,49,91,223,19,48,168,170,46,51,99,200,154,51,176,167,203,49,129,80,29,48,93,122,49,51,107,192,153,51,176,121,196,49,25,56,39,48,105,76,52,51,94,179,152,51,135,123,189,49,185,155,49,48,146,32,55,51,90,161,151,51,150,172,182,49,95,126,60,48,160,246,57,51,123,138,150,51,39,12,176,49,248,228,71,48,93,206,60,51,226,110,149,51,150,153,169,49,109,212,83,48,138,167,63,51,174,78,148,51,35,84,163,49,141,80,96,48,238,129,66,51,253,41,147,51,49,59,157,49,102,94,109,48,77,93,69,51,243,0,146,51,246,77,151,49,33,2,123,48,105,57,72,51,173,211,144,51,209,139,145,49,207,160,132,48,7,22,75,51,77,162,143,51,242,243,139,49,85,16,140,48,230,242,77,51,244,108,142,51,191,133,134,49,70,210,147,48,199,207,80,51,194,51,141,51,101,64,129,49,4,233,155,48,109,172,83,51,217,246,139,51,119,70,120,49,101,87,164,48,149,136,86,51,92,182,138,51,249,90,110,49,78,31,173,48,0,100,89,51,109,114,137,51,240,188,100,49,61,68,182,48,104,62,92,51,45,43,136,51,199,106,91,49,198,199,191,48,145,23,95,51,190,224,134,51,50,99,82,49,93,173,201,48,52,239,97,51,67,147,133,51,140,164,73,49,53,247,211,48,18,197,100,51,223,66,132,51,123,45,65,49,103,168,222,48,227,152,103,51,181,239,130,51,116,252,56,49,54,195,233,48,100,106,106,51,230,153,129,51,27,16,49,49,202,74,245,48,84,57,109,51,150,65,128,51,229,102,41,49,218,160,0,49,108,5,112,51,207,205,125,51,88,255,33,49,128,213,6,49,102,206,114,51,249,19,123,51,23,216,26,49,143,68,13,49,1,148,117,51,243,85,120,51,174,239,19,49,5,0,0,0,43,1,0,0,14,0,0,0,8,0,0,0,82,0,0,0,61,1,0,0,255,255,255,255,0,0,0,0,214,0,72,0,42,0,40,0,18,0,4,0,4,0,2,0,2,0,2,0,2,0,2,0,1,0,1,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,113,0,68,0,49,0,42,0,40,0,32,0,27,0,15,0,10,0,5,0,3,0,3,0,3,0,3,0,2,0,2,0,2,0,2,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,95,1,122,0,76,0,61,0,41,0,42,0,24,0,30,0,22,0,19,0,11,0,9,0,10,0,8,0,5,0,5,0,4,0,5,0,5,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,2,0,2,0,3,0,2,0,2,0,2,0,3,0,3,0,2,0,2,0,2,0,3,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,1,0,2,0,2,0,1,0,2,0,1,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,2,0,1,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,181,0,110,0,78,0,63,0,61,0,62,0,60,0,61,0,33,0,41,0,41,0,19,0,17,0,19,0,12,0,11,0,9,0,11,0,10,0,6,0,8,0,7,0,6,0,4,0,5,0,5,0,4,0,4,0,3,0,4,0,3,0,5,0,3,0,4,0,3,0,3,0,3,0,3,0,3,0,3,0,2,0,2,0,4,0,2,0,3,0,2,0,3,0,3,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,3,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,2,0,1,0,2,0,2,0,2,0,2,0,1,0,2,0,1,0,1,0,1,0,2,0,2,0,1,0,2,0,1,0,2,0,2,0,2,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,55,1,91,0,61,0,28,0,10,0,6,0,5,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,61,1,92,0,62,0,60,0,19,0,17,0,10,0,7,0,6,0,5,0,5,0,3,0,3,0,3,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,2,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,4,10,5,6,4,40,40,40,40,76,0,0,0,0,0,0,4,10,5,6,4,40,40,40,40,76,0,0,0,0,0,0,0,0,1,0,160,0,167,0,168,0,169,0,175,0,176,0,178,0,183,0,184,0,198,0,215,0,216,0,230,0,247,0,248,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,46,1,47,1,48,1,49,1,52,1,53,1,54,1,55,1,56,1,57,1,58,1,59,1,60,1,61,1,62,1,65,1,66,1,67,1,68,1,69,1,70,1,71,1,72,1,74,1,75,1,76,1,77,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,115,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,123,1,124,1,125,1,126,1,146,1,160,1,161,1,175,1,176,1,24,2,25,2,26,2,27,2,198,2,199,2,216,2,217,2,219,2,220,2,221,2,0,3,1,3,3,3,9,3,35,3,122,3,132,3,133,3,134,3,136,3,137,3,138,3,140,3,142,3,143,3,144,3,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,170,3,171,3,172,3,173,3,174,3,175,3,176,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,194,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,202,3,203,3,204,3,205,3,206,3,1,4,2,4,3,4,4,4,5,4,6,4,7,4,8,4,9,4,10,4,11,4,12,4,14,4,15,4,16,4,17,4,18,4,19,4,20,4,21,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,48,4,49,4,50,4,51,4,52,4,53,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,81,4,82,4,83,4,84,4,85,4,86,4,87,4,88,4,89,4,90,4,91,4,92,4,94,4,95,4,144,4,145,4,176,5,177,5,178,5,179,5,180,5,181,5,182,5,183,5,184,5,185,5,187,5,188,5,189,5,190,5,191,5,192,5,193,5,194,5,195,5,208,5,209,5,210,5,211,5,212,5,213,5,214,5,215,5,216,5,217,5,218,5,219,5,220,5,221,5,222,5,223,5,224,5,225,5,226,5,227,5,228,5,229,5,230,5,231,5,232,5,233,5,234,5,240,5,241,5,242,5,243,5,244,5,12,6,27,6,31,6,33,6,34,6,35,6,36,6,37,6,38,6,39,6,40,6,41,6,42,6,43,6,44,6,45,6,46,6,47,6,48,6,49,6,50,6,51,6,52,6,53,6,54,6,55,6,56,6,57,6,58,6,64,6,65,6,66,6,67,6,68,6,69,6,70,6,71,6,72,6,73,6,74,6,75,6,76,6,77,6,78,6,79,6,80,6,81,6,82,6,121,6,126,6,134,6,136,6,145,6,152,6,169,6,175,6,186,6,190,6,193,6,210,6,1,14,2,14,3,14,4,14,5,14,6,14,7,14,8,14,9,14,10,14,11,14,12,14,13,14,14,14,15,14,16,14,17,14,18,14,19,14,20,14,21,14,22,14,23,14,24,14,25,14,26,14,27,14,28,14,29,14,30,14,31,14,32,14,33,14,34,14,35,14,36,14,37,14,38,14,39,14,40,14,41,14,42,14,43,14,44,14,45,14,46,14,47,14,48,14,49,14,50,14,51,14,52,14,53,14,54,14,55,14,56,14,57,14,58,14,63,14,64,14,65,14,66,14,67,14,68,14,69,14,70,14,71,14,72,14,73,14,74,14,75,14,76,14,77,14,78,14,79,14,80,14,81,14,82,14,83,14,84,14,85,14,86,14,87,14,88,14,89,14,90,14,91,14,2,30,3,30,10,30,11,30,30,30,31,30,64,30,65,30,86,30,87,30,96,30,97,30,106,30,107,30,128,30,129,30,130,30,131,30,132,30,133,30,242,30,243,30,12,32,13,32,14,32,15,32,19,32,20,32,21,32,23,32,24,32,25,32,26,32,28,32,29,32,30,32,32,32,33,32,34,32,38,32,48,32,57,32,58,32,170,32,171,32,172,32,175,32,22,33,34,33,25,34,26,34,72,34,100,34,101,34,32,35,33,35,0,37,2,37,12,37,16,37,20,37,24,37,28,37,36,37,44,37,52,37,60,37,80,37,81,37,82,37,83,37,84,37,85,37,86,37,87,37,88,37,89,37,90,37,91,37,92,37,93,37,94,37,95,37,96,37,97,37,98,37,99,37,100,37,101,37,102,37,103,37,104,37,105,37,106,37,107,37,108,37,128,37,132,37,136,37,140,37,144,37,145,37,146,37,147,37,160,37,0,0,108,0,101,0,103,0,97,0,99,0,121,0,95,0,97,0,116,0,116,0,114,0,105,0,98,0,0,0,0,0,0,0,0,255,6,255,255,7,6,7,5,255,2,255,6,5,6,0,32,70,234,172,131,130,158,215,216,208,175,69,244,98,151,122,241,121,140,11,166,96,77,53,238,122,176,0,222,28,78,88,35,246,125,218,147,205,115,21,53,213,13,98,121,141,249,71,8,190,28,0,108,0,0,0,112,81,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,172,79,0,0,0,0,0,104,172,79,0,0,0,0,0,120,172,79,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,0,4,7,10,0,0,0,0,0,136,172,79,0,0,0,0,0,0,0,228,1,248,1,0,0,228,1,20,0,184,0,0,0,97,97,114,0,248,1,97,98,107,0,249,1,97,99,101,0,2,0,97,99,104,0,3,0,97,100,97,0,4,0,97,100,121,0,5,0,97,102,97,0,6,0,97,102,104,0,7,0,97,102,114,0,251,1,97,105,110,0,9,0,97,107,97,0,252,1,97,107,107,0,11,0,97,108,98,0,246,1,97,108,101,0,13,0,97,108,103,0,14,0,97,108,116,0,15,0,97,109,104,0,253,1,97,110,103,0,17,0,97,110,112,0,18,0,97,112,97,0,19,0,97,114,97,0,255,1,97,114,99,0,21,0,97,114,103,0,254,1,97,114,109,0,236,1,97,114,110,0,24,0,97,114,112,0,25,0,97,114,116,0,26,0,97,114,119,0,27,0,97,115,109,0,0,2,97,115,116,0,29,0,97,116,104,0,30,0,97,117,115,0,31,0,97,118,97,0,1,2,97,118,101,0,250,1,97,119,97,0,34,0,97,121,109,0,2,2,97,122,101,0,3,2,98,97,100,0,37,0,98,97,105,0,38,0,98,97,107,0,4,2,98,97,108,0,40,0,98,97,109,0,9,2,98,97,110,0,42,0,98,97,113,0,233,1,98,97,115,0,44,0,98,97,116,0,45,0,98,101,106,0,46,0,98,101,108,0,5,2,98,101,109,0,48,0,98,101,110,0,10,2,98,101,114,0,50,0,98,104,111,0,51,0,98,105,104,0,7,2,98,105,107,0,53,0,98,105,110,0,54,0,98,105,115,0,8,2,98,108,97,0,56,0,98,110,116,0,57,0,98,111,115,0,13,2,98,114,97,0,59,0,98,114,101,0,12,2,98,116,107,0,61,0,98,117,97,0,62,0,98,117,103,0,63,0,98,117,108,0,6,2,98,117,114,0,242,1,98,121,110,0,66,0,99,97,100,0,67,0,99,97,105,0,68,0,99,97,114,0,69,0,99,97,116,0,14,2,99,97,117,0,71,0,99,101,98,0,72,0,99,101,108,0,73,0,99,104,97,0,16,2,99,104,98,0,75,0,99,104,101,0,15,2,99,104,103,0,77,0,99,104,105,0,247,1,99,104,107,0,79,0,99,104,109,0,80,0,99,104,110,0,81,0,99,104,111,0,82,0,99,104,112,0,83,0,99,104,114,0,84,0,99,104,117,0,20,2,99,104,118,0,21,2,99,104,121,0,87,0,99,109,99,0,88,0,99,111,112,0,89,0,99,111,114,0,81,2,99,111,115,0,17,2,99,112,101,0,92,0,99,112,102,0,93,0,99,112,112,0,94,0,99,114,101,0,18,2,99,114,104,0,96,0,99,114,112,0,97,0,99,115,98,0,98,0,99,117,115,0,99,0,99,122,101,0,229,1,100,97,107,0,101,0,100,97,110,0,23,2,100,97,114,0,103,0,100,97,121,0,104,0,100,101,108,0,105,0,100,101,110,0,106,0,100,103,114,0,107,0,100,105,110,0,108,0,100,105,118,0,25,2,100,111,105,0,110,0,100,114,97,0,111,0,100,115,98,0,112,0,100,117,97,0,113,0,100,117,109,0,114,0,100,117,116,0,243,1,100,121,117,0,116,0,100,122,111,0,26,2,101,102,105,0,118,0,101,103,121,0,119,0,101,107,97,0,120,0,101,108,120,0,121,0,101,110,103,0,29,2,101,110,109,0,123,0,101,112,111,0,30,2,101,115,116,0,32,2,101,119,101,0,27,2,101,119,111,0,127,0,102,97,110,0,128,0,102,97,111,0,38,2,102,97,116,0,130,0,102,105,106,0,37,2,102,105,108,0,132,0,102,105,110,0,36,2,102,105,117,0,134,0,102,111,110,0,135,0,102,114,101,0,235,1,102,114,109,0,137,0,102,114,111,0,138,0,102,114,114,0,139,0,102,114,115,0,140,0,102,114,121,0,40,2,102,117,108,0,35,2,102,117,114,0,143,0,103,97,97,0,144,0,103,97,121,0,145,0,103,98,97,0,146,0,103,101,109,0,147,0,103,101,111,0,238,1,103,101,114,0,231,1,103,101,122,0,150,0,103,105,108,0,151,0,103,108,97,0,42,2,103,108,101,0,41,2,103,108,103,0,43,2,103,108,118,0,46,2,103,109,104,0,156,0,103,111,104,0,157,0,103,111,110,0,158,0,103,111,114,0,159,0,103,111,116,0,160,0,103,114,98,0,161,0,103,114,99,0,162,0,103,114,101,0,232,1,103,114,110,0,44,2,103,115,119,0,165,0,103,117,106,0,45,2,103,119,105,0,167,0,104,97,105,0,168,0,104,97,116,0,52,2,104,97,117,0,47,2,104,97,119,0,171,0,104,101,98,0,48,2,104,101,114,0,55,2,104,105,108,0,174,0,104,105,109,0,175,0,104,105,110,0,49,2,104,105,116,0,177,0,104,109,110,0,178,0,104,109,111,0,50,2,104,114,118,0,51,2,104,115,98,0,181,0,104,117,110,0,53,2,104,117,112,0,183,0,105,98,97,0,184,0,105,98,111,0,59,2,105,99,101,0,237,1,105,100,111,0,62,2,105,105,105,0,60,2,105,106,111,0,189,0,105,107,117,0,65,2,105,108,101,0,58,2,105,108,111,0,192,0,105,110,97,0,56,2,105,110,99,0,194,0,105,110,100,0,57,2,105,110,101,0,196,0,105,110,104,0,197,0,105,112,107,0,61,2,105,114,97,0,199,0,105,114,111,0,200,0,105,116,97,0,64,2,106,97,118,0,67,2,106,98,111,0,203,0,106,112,110,0,66,2,106,112,114,0,205,0,106,114,98,0,206,0,107,97,97,0,207,0,107,97,98,0,208,0,107,97,99,0,209,0,107,97,108,0,73,2,107,97,109,0,211,0,107,97,110,0,75,2,107,97,114,0,213,0,107,97,115,0,78,2,107,97,117,0,77,2,107,97,119,0,216,0,107,97,122,0,72,2,107,98,100,0,218,0,107,104,97,0,219,0,107,104,105,0,220,0,107,104,109,0,74,2,107,104,111,0,222,0,107,105,107,0,70,2,107,105,110,0,128,2,107,105,114,0,82,2,107,109,98,0,226,0,107,111,107,0,227,0,107,111,109,0,80,2,107,111,110,0,69,2,107,111,114,0,76,2,107,111,115,0,231,0,107,112,101,0,232,0,107,114,99,0,233,0,107,114,108,0,234,0,107,114,111,0,235,0,107,114,117,0,236,0,107,117,97,0,71,2,107,117,109,0,238,0,107,117,114,0,79,2,107,117,116,0,240,0,108,97,100,0,241,0,108,97,104,0,242,0,108,97,109,0,243,0,108,97,111,0,88,2,108,97,116,0,83,2,108,97,118,0,91,2,108,101,122,0,247,0,108,105,109,0,86,2,108,105,110,0,87,2,108,105,116,0,89,2,108,111,108,0,251,0,108,111,122,0,252,0,108,116,122,0,84,2,108,117,97,0,254,0,108,117,98,0,90,2,108,117,103,0,85,2,108,117,105,0,1,1,108,117,110,0,2,1,108,117,111,0,3,1,108,117,115,0,4,1,109,97,99,0,239,1,109,97,100,0,6,1,109,97,103,0,7,1,109,97,104,0,93,2,109,97,105,0,9,1,109,97,107,0,10,1,109,97,108,0,96,2,109,97,110,0,12,1,109,97,111,0,240,1,109,97,112,0,14,1,109,97,114,0,98,2,109,97,115,0,16,1,109,97,121,0,241,1,109,100,102,0,18,1,109,100,114,0,19,1,109,101,110,0,20,1,109,103,97,0,21,1,109,105,99,0,22,1,109,105,110,0,23,1,109,105,115,0,24,1,109,107,104,0,25,1,109,108,103,0,92,2,109,108,116,0,100,2,109,110,99,0,28,1,109,110,105,0,29,1,109,110,111,0,30,1,109,111,104,0,31,1,109,111,110,0,97,2,109,111,115,0,33,1,109,117,108,0,34,1,109,117,110,0,35,1,109,117,115,0,36,1,109,119,108,0,37,1,109,119,114,0,38,1,109,121,110,0,39,1,109,121,118,0,40,1,110,97,104,0,41,1,110,97,105,0,42,1,110,97,112,0,43,1,110,97,117,0,102,2,110,97,118,0,111,2,110,98,108,0,110,2,110,100,101,0,104,2,110,100,111,0,106,2,110,100,115,0,49,1,110,101,112,0,105,2,110,101,119,0,51,1,110,105,97,0,52,1,110,105,99,0,53,1,110,105,117,0,54,1,110,110,111,0,108,2,110,111,98,0,103,2,110,111,103,0,57,1,110,111,110,0,58,1,110,111,114,0,109,2,110,113,111,0,60,1,110,115,111,0,61,1,110,117,98,0,62,1,110,119,99,0,63,1,110,121,97,0,112,2,110,121,109,0,65,1,110,121,110,0,66,1,110,121,111,0,67,1,110,122,105,0,68,1,111,99,105,0,113,2,111,106,105,0,114,2,111,114,105,0,116,2,111,114,109,0,115,2,111,115,97,0,73,1,111,115,115,0,117,2,111,116,97,0,75,1,111,116,111,0,76,1,112,97,97,0,77,1,112,97,103,0,78,1,112,97,108,0,79,1,112,97,109,0,80,1,112,97,110,0,118,2,112,97,112,0,82,1,112,97,117,0,83,1,112,101,111,0,84,1,112,101,114,0,234,1,112,104,105,0,86,1,112,104,110,0,87,1,112,108,105,0,119,2,112,111,108,0,120,2,112,111,110,0,90,1,112,111,114,0,122,2,112,114,97,0,92,1,112,114,111,0,93,1,112,117,115,0,121,2,113,117,101,0,123,2,114,97,106,0,96,1,114,97,112,0,97,1,114,97,114,0,98,1,114,111,97,0,99,1,114,111,104,0,124,2,114,111,109,0,101,1,114,117,109,0,244,1,114,117,110,0,125,2,114,117,112,0,104,1,114,117,115,0,127,2,115,97,100,0,106,1,115,97,103,0,133,2,115,97,104,0,108,1,115,97,105,0,109,1,115,97,108,0,110,1,115,97,109,0,111,1,115,97,110,0,129,2,115,97,115,0,113,1,115,97,116,0,114,1,115,99,110,0,115,1,115,99,111,0,116,1,115,101,108,0,117,1,115,101,109,0,118,1,115,103,97,0,119,1,115,103,110,0,120,1,115,104,110,0,121,1,115,105,100,0,122,1,115,105,110,0,134,2,115,105,111,0,124,1,115,105,116,0,125,1,115,108,97,0,126,1,115,108,111,0,245,1,115,108,118,0,136,2,115,109,97,0,129,1,115,109,101,0,132,2,115,109,105,0,131,1,115,109,106,0,132,1,115,109,110,0,133,1,115,109,111,0,137,2,115,109,115,0,135,1,115,110,97,0,138,2,115,110,100,0,131,2,115,110,107,0,138,1,115,111,103,0,139,1,115,111,109,0,139,2,115,111,110,0,141,1,115,111,116,0,143,2,115,112,97,0,31,2,115,114,100,0,130,2,115,114,110,0,145,1,115,114,112,0,141,2,115,114,114,0,147,1,115,115,97,0,148,1,115,115,119,0,142,2,115,117,107,0,150,1,115,117,110,0,144,2,115,117,115,0,152,1,115,117,120,0,153,1,115,119,97,0,146,2,115,119,101,0,145,2,115,121,99,0,156,1,115,121,114,0,157,1,116,97,104,0,160,2,116,97,105,0,159,1,116,97,109,0,147,2,116,97,116,0,158,2,116,101,108,0,148,2,116,101,109,0,163,1,116,101,114,0,164,1,116,101,116,0,165,1,116,103,107,0,149,2,116,103,108,0,153,2,116,104,97,0,150,2,116,105,98,0,228,1,116,105,103,0,170,1,116,105,114,0,151,2,116,105,118,0,172,1,116,107,108,0,173,1,116,108,104,0,174,1,116,108,105,0,175,1,116,109,104,0,176,1,116,111,103,0,177,1,116,111,110,0,155,2,116,112,105,0,179,1,116,115,105,0,180,1,116,115,110,0,154,2,116,115,111,0,157,2,116,117,107,0,152,2,116,117,109,0,184,1,116,117,112,0,185,1,116,117,114,0,156,2,116,117,116,0,187,1,116,118,108,0,188,1,116,119,105,0,159,2,116,121,118,0,190,1,117,100,109,0,191,1,117,103,97,0,192,1,117,105,103,0,161,2,117,107,114,0,162,2,117,109,98,0,195,1,117,110,100,0,196,1,117,114,100,0,163,2,117,122,98,0,164,2,118,97,105,0,199,1,118,101,110,0,165,2,118,105,101,0,166,2,118,111,108,0,167,2,118,111,116,0,203,1,119,97,107,0,204,1,119,97,108,0,205,1,119,97,114,0,206,1,119,97,115,0,207,1,119,101,108,0,230,1,119,101,110,0,209,1,119,108,110,0,168,2,119,111,108,0,169,2,120,97,108,0,212,1,120,104,111,0,170,2,121,97,111,0,214,1,121,97,112,0,215,1,121,105,100,0,171,2,121,111,114,0,172,2,121,112,107,0,218,1,122,97,112,0,219,1,122,98,108,0,220,1,122,101,110,0,221,1,122,104,97,0,173,2,122,110,100,0,223,1,122,117,108,0,175,2,122,117,110,0,225,1,122,120,120,0,226,1,122,122,97,0,227,1,98,111,100,0,11,2,99,101,115,0,19,2,99,121,109,0,22,2,100,101,117,0,24,2,101,108,108,0,28,2,101,117,115,0,33,2,102,97,115,0,34,2,102,114,97,0,39,2,104,121,101,0,54,2,105,115,108,0,63,2,107,97,116,0,68,2,109,107,100,0,95,2,109,114,105,0,94,2,109,115,97,0,99,2,109,121,97,0,101,2,110,108,100,0,107,2,114,111,110,0,126,2,115,108,107,0,135,2,115,113,105,0,140,2,122,104,111,0,174,2,97,97,0,0,0,0,97,98,0,0,1,0,97,101,0,0,33,0,97,102,0,0,8,0,97,107,0,0,10,0,97,109,0,0,16,0,97,110,0,0,22,0,97,114,0,0,20,0,97,115,0,0,28,0,97,118,0,0,32,0,97,121,0,0,35,0,97,122,0,0,36,0,98,97,0,0,39,0,98,101,0,0,47,0,98,103,0,0,64,0,98,104,0,0,52,0,98,105,0,0,55,0,98,109,0,0,41,0,98,110,0,0,49,0,98,111,0,0,169,1,98,114,0,0,60,0,98,115,0,0,58,0,99,97,0,0,70,0,99,101,0,0,76,0,99,104,0,0,74,0,99,111,0,0,91,0,99,114,0,0,95,0,99,115,0,0,100,0,99,117,0,0,85,0,99,118,0,0,86,0,99,121,0,0,208,1,100,97,0,0,102,0,100,101,0,0,149,0,100,118,0,0,109,0,100,122,0,0,117,0,101,101,0,0,126,0,101,108,0,0,163,0,101,110,0,0,122,0,101,111,0,0,124,0,101,115,0,0,143,1,101,116,0,0,125,0,101,117,0,0,43,0,102,97,0,0,85,1,102,102,0,0,142,0,102,105,0,0,133,0,102,106,0,0,131,0,102,111,0,0,129,0,102,114,0,0,136,0,102,121,0,0,141,0,103,97,0,0,153,0,103,100,0,0,152,0,103,108,0,0,154,0,103,110,0,0,164,0,103,117,0,0,166,0,103,118,0,0,155,0,104,97,0,0,170,0,104,101,0,0,172,0,104,105,0,0,176,0,104,111,0,0,179,0,104,114,0,0,180,0,104,116,0,0,169,0,104,117,0,0,182,0,104,121,0,0,23,0,104,122,0,0,173], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+851304);
/* memory initializer */ allocate([105,97,0,0,193,0,105,100,0,0,195,0,105,101,0,0,191,0,105,103,0,0,185,0,105,105,0,0,188,0,105,107,0,0,198,0,105,111,0,0,187,0,105,115,0,0,186,0,105,116,0,0,201,0,105,117,0,0,190,0,106,97,0,0,204,0,106,118,0,0,202,0,107,97,0,0,148,0,107,103,0,0,229,0,107,105,0,0,223,0,107,106,0,0,237,0,107,107,0,0,217,0,107,108,0,0,210,0,107,109,0,0,221,0,107,110,0,0,212,0,107,111,0,0,230,0,107,114,0,0,215,0,107,115,0,0,214,0,107,117,0,0,239,0,107,118,0,0,228,0,107,119,0,0,90,0,107,121,0,0,225,0,108,97,0,0,245,0,108,98,0,0,253,0,108,103,0,0,0,1,108,105,0,0,248,0,108,110,0,0,249,0,108,111,0,0,244,0,108,116,0,0,250,0,108,117,0,0,255,0,108,118,0,0,246,0,109,103,0,0,26,1,109,104,0,0,8,1,109,105,0,0,13,1,109,107,0,0,5,1,109,108,0,0,11,1,109,110,0,0,32,1,109,114,0,0,15,1,109,115,0,0,17,1,109,116,0,0,27,1,109,121,0,0,65,0,110,97,0,0,44,1,110,98,0,0,56,1,110,100,0,0,47,1,110,101,0,0,50,1,110,103,0,0,48,1,110,108,0,0,115,0,110,110,0,0,55,1,110,111,0,0,59,1,110,114,0,0,46,1,110,118,0,0,45,1,110,121,0,0,64,1,111,99,0,0,69,1,111,106,0,0,70,1,111,109,0,0,72,1,111,114,0,0,71,1,111,115,0,0,74,1,112,97,0,0,81,1,112,105,0,0,88,1,112,108,0,0,89,1,112,115,0,0,94,1,112,116,0,0,91,1,113,117,0,0,95,1,114,109,0,0,100,1,114,110,0,0,103,1,114,111,0,0,102,1,114,117,0,0,105,1,114,119,0,0,224,0,115,97,0,0,112,1,115,99,0,0,144,1,115,100,0,0,137,1,115,101,0,0,130,1,115,103,0,0,107,1,115,105,0,0,123,1,115,107,0,0,127,1,115,108,0,0,128,1,115,109,0,0,134,1,115,110,0,0,136,1,115,111,0,0,140,1,115,113,0,0,12,0,115,114,0,0,146,1,115,115,0,0,149,1,115,116,0,0,142,1,115,117,0,0,151,1,115,118,0,0,155,1,115,119,0,0,154,1,116,97,0,0,160,1,116,101,0,0,162,1,116,103,0,0,166,1,116,104,0,0,168,1,116,105,0,0,171,1,116,107,0,0,183,1,116,108,0,0,167,1,116,110,0,0,181,1,116,111,0,0,178,1,116,114,0,0,186,1,116,115,0,0,182,1,116,116,0,0,161,1,116,119,0,0,189,1,116,121,0,0,158,1,117,103,0,0,193,1,117,107,0,0,194,1,117,114,0,0,197,1,117,122,0,0,198,1,118,101,0,0,200,1,118,105,0,0,201,1,118,111,0,0,202,1,119,97,0,0,210,1,119,111,0,0,211,1,120,104,0,0,213,1,121,105,0,0,216,1,121,111,0,0,217,1,122,97,0,0,222,1,122,104,0,0,78,0,122,117,0,0,224,1,0,0,0,0,0,0,0,0,1,2,3,5,8,13,21,0,254,255,255,255,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,1,0,0,0,0,1,1,0,0,2,2,0,1,2,2,1,0,3,3,0,1,3,3,1,2,3,3,2,0,48,1,48,2,48,183,0,37,32,38,32,168,0,3,48,173,0,21,32,37,34,60,255,60,34,24,32,25,32,28,32,29,32,20,48,21,48,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,16,48,17,48,177,0,215,0,247,0,96,34,100,34,101,34,30,34,52,34,176,0,50,32,51,32,3,33,43,33,224,255,225,255,229,255,66,38,64,38,32,34,165,34,18,35,2,34,7,34,97,34,82,34,167,0,59,32,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,189,37,188,37,146,33,144,33,145,33,147,33,148,33,19,48,106,34,107,34,26,34,61,34,29,34,53,34,43,34,44,34,8,34,11,34,134,34,135,34,130,34,131,34,42,34,41,34,39,34,40,34,226,255,210,33,212,33,0,34,3,34,180,0,94,255,199,2,216,2,221,2,218,2,217,2,184,0,219,2,161,0,191,0,208,2,46,34,17,34,15,34,164,0,9,33,48,32,193,37,192,37,183,37,182,37,100,38,96,38,97,38,101,38,103,38,99,38,153,34,200,37,163,37,208,37,209,37,146,37,164,37,165,37,168,37,167,37,166,37,169,37,104,38,15,38,14,38,28,38,30,38,182,0,32,32,33,32,149,33,151,33,153,33,150,33,152,33,109,38,105,38,106,38,108,38,127,50,28,50,22,33,199,51,34,33,194,51,216,51,33,33,172,32,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,2,255,3,255,4,255,5,255,6,255,7,255,8,255,9,255,10,255,11,255,12,255,13,255,14,255,15,255,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,26,255,27,255,28,255,29,255,30,255,31,255,32,255,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,59,255,230,255,61,255,62,255,63,255,64,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,91,255,92,255,93,255,227,255,49,49,50,49,51,49,52,49,53,49,54,49,55,49,56,49,57,49,58,49,59,49,60,49,61,49,62,49,63,49,64,49,65,49,66,49,67,49,68,49,69,49,70,49,71,49,72,49,73,49,74,49,75,49,76,49,77,49,78,49,79,49,80,49,81,49,82,49,83,49,84,49,85,49,86,49,87,49,88,49,89,49,90,49,91,49,92,49,93,49,94,49,95,49,96,49,97,49,98,49,99,49,100,49,101,49,102,49,103,49,104,49,105,49,106,49,107,49,108,49,109,49,110,49,111,49,112,49,113,49,114,49,115,49,116,49,117,49,118,49,119,49,120,49,121,49,122,49,123,49,124,49,125,49,126,49,127,49,128,49,129,49,130,49,131,49,132,49,133,49,134,49,135,49,136,49,137,49,138,49,139,49,140,49,141,49,142,49,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,0,0,0,0,0,0,0,0,0,0,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,37,2,37,12,37,16,37,24,37,20,37,28,37,44,37,36,37,52,37,60,37,1,37,3,37,15,37,19,37,27,37,23,37,35,37,51,37,43,37,59,37,75,37,32,37,47,37,40,37,55,37,63,37,29,37,48,37,37,37,56,37,66,37,18,37,17,37,26,37,25,37,22,37,21,37,14,37,13,37,30,37,31,37,33,37,34,37,38,37,39,37,41,37,42,37,45,37,46,37,49,37,50,37,53,37,54,37,57,37,58,37,61,37,62,37,64,37,65,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,51,150,51,151,51,19,33,152,51,196,51,163,51,164,51,165,51,166,51,153,51,154,51,155,51,156,51,157,51,158,51,159,51,160,51,161,51,162,51,202,51,141,51,142,51,143,51,207,51,136,51,137,51,200,51,167,51,168,51,176,51,177,51,178,51,179,51,180,51,181,51,182,51,183,51,184,51,185,51,128,51,129,51,130,51,131,51,132,51,186,51,187,51,188,51,189,51,190,51,191,51,144,51,145,51,146,51,147,51,148,51,38,33,192,51,193,51,138,51,139,51,140,51,214,51,197,51,173,51,174,51,175,51,219,51,169,51,170,51,171,51,172,51,221,51,208,51,211,51,195,51,201,51,220,51,198,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,0,208,0,170,0,38,1,0,0,50,1,0,0,63,1,65,1,216,0,82,1,186,0,222,0,102,1,74,1,0,0,96,50,97,50,98,50,99,50,100,50,101,50,102,50,103,50,104,50,105,50,106,50,107,50,108,50,109,50,110,50,111,50,112,50,113,50,114,50,115,50,116,50,117,50,118,50,119,50,120,50,121,50,122,50,123,50,208,36,209,36,210,36,211,36,212,36,213,36,214,36,215,36,216,36,217,36,218,36,219,36,220,36,221,36,222,36,223,36,224,36,225,36,226,36,227,36,228,36,229,36,230,36,231,36,232,36,233,36,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,106,36,107,36,108,36,109,36,110,36,189,0,83,33,84,33,188,0,190,0,91,33,92,33,93,33,94,33,230,0,17,1,240,0,39,1,49,1,51,1,56,1,64,1,66,1,248,0,83,1,223,0,254,0,103,1,75,1,73,1,0,50,1,50,2,50,3,50,4,50,5,50,6,50,7,50,8,50,9,50,10,50,11,50,12,50,13,50,14,50,15,50,16,50,17,50,18,50,19,50,20,50,21,50,22,50,23,50,24,50,25,50,26,50,27,50,156,36,157,36,158,36,159,36,160,36,161,36,162,36,163,36,164,36,165,36,166,36,167,36,168,36,169,36,170,36,171,36,172,36,173,36,174,36,175,36,176,36,177,36,178,36,179,36,180,36,181,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,126,36,127,36,128,36,129,36,130,36,185,0,178,0,179,0,116,32,127,32,129,32,130,32,131,32,132,32,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,1,172,4,172,7,172,8,172,9,172,10,172,16,172,17,172,18,172,19,172,20,172,21,172,22,172,23,172,25,172,26,172,27,172,28,172,29,172,32,172,36,172,44,172,45,172,47,172,48,172,49,172,56,172,57,172,60,172,64,172,75,172,77,172,84,172,88,172,92,172,112,172,113,172,116,172,119,172,120,172,122,172,128,172,129,172,131,172,132,172,133,172,134,172,137,172,138,172,139,172,140,172,144,172,148,172,156,172,157,172,159,172,160,172,161,172,168,172,169,172,170,172,172,172,175,172,176,172,184,172,185,172,187,172,188,172,189,172,193,172,196,172,200,172,204,172,213,172,215,172,224,172,225,172,228,172,231,172,232,172,234,172,236,172,239,172,240,172,241,172,243,172,245,172,246,172,252,172,253,172,0,173,4,173,6,173,12,173,13,173,15,173,17,173,24,173,28,173,32,173,41,173,44,173,45,173,52,173,53,173,56,173,60,173,68,173,69,173,71,173,73,173,80,173,84,173,88,173,97,173,99,173,108,173,109,173,112,173,115,173,116,173,117,173,118,173,123,173,124,173,125,173,127,173,129,173,130,173,136,173,137,173,140,173,144,173,156,173,157,173,164,173,183,173,192,173,193,173,196,173,200,173,208,173,209,173,211,173,220,173,224,173,228,173,248,173,249,173,252,173,255,173,0,174,1,174,8,174,9,174,11,174,13,174,20,174,48,174,49,174,52,174,55,174,56,174,58,174,64,174,65,174,67,174,69,174,70,174,74,174,76,174,77,174,78,174,80,174,84,174,86,174,92,174,93,174,95,174,96,174,97,174,101,174,104,174,105,174,108,174,112,174,120,174,121,174,123,174,124,174,125,174,132,174,133,174,140,174,188,174,189,174,190,174,192,174,196,174,204,174,205,174,207,174,208,174,209,174,216,174,217,174,220,174,232,174,235,174,237,174,244,174,248,174,252,174,7,175,8,175,13,175,16,175,44,175,45,175,48,175,50,175,52,175,60,175,61,175,63,175,65,175,66,175,67,175,72,175,73,175,80,175,92,175,93,175,100,175,101,175,121,175,128,175,132,175,136,175,144,175,145,175,149,175,156,175,184,175,185,175,188,175,192,175,199,175,200,175,201,175,203,175,205,175,206,175,212,175,220,175,232,175,233,175,240,175,241,175,244,175,248,175,0,176,1,176,4,176,12,176,16,176,20,176,28,176,29,176,40,176,68,176,69,176,72,176,74,176,76,176,78,176,83,176,84,176,85,176,87,176,89,176,93,176,124,176,125,176,128,176,132,176,140,176,141,176,143,176,145,176,152,176,153,176,154,176,156,176,159,176,160,176,161,176,162,176,168,176,169,176,171,176,172,176,173,176,174,176,175,176,177,176,179,176,180,176,181,176,184,176,188,176,196,176,197,176,199,176,200,176,201,176,208,176,209,176,212,176,216,176,224,176,229,176,8,177,9,177,11,177,12,177,16,177,18,177,19,177,24,177,25,177,27,177,28,177,29,177,35,177,36,177,37,177,40,177,44,177,52,177,53,177,55,177,56,177,57,177,64,177,65,177,68,177,72,177,80,177,81,177,84,177,85,177,88,177,92,177,96,177,120,177,121,177,124,177,128,177,130,177,136,177,137,177,139,177,141,177,146,177,147,177,148,177,152,177,156,177,168,177,204,177,208,177,212,177,220,177,221,177,223,177,232,177,233,177,236,177,240,177,249,177,251,177,253,177,4,178,5,178,8,178,11,178,12,178,20,178,21,178,23,178,25,178,32,178,52,178,60,178,88,178,92,178,96,178,104,178,105,178,116,178,117,178,124,178,132,178,133,178,137,178,144,178,145,178,148,178,152,178,153,178,154,178,160,178,161,178,163,178,165,178,166,178,170,178,172,178,176,178,180,178,200,178,201,178,204,178,208,178,210,178,216,178,217,178,219,178,221,178,226,178,228,178,229,178,230,178,232,178,235,178,236,178,237,178,238,178,239,178,243,178,244,178,245,178,247,178,248,178,249,178,250,178,251,178,255,178,0,179,1,179,4,179,8,179,16,179,17,179,19,179,20,179,21,179,28,179,84,179,85,179,86,179,88,179,91,179,92,179,94,179,95,179,100,179,101,179,103,179,105,179,107,179,110,179,112,179,113,179,116,179,120,179,128,179,129,179,131,179,132,179,133,179,140,179,144,179,148,179,160,179,161,179,168,179,172,179,196,179,197,179,200,179,203,179,204,179,206,179,208,179,212,179,213,179,215,179,217,179,219,179,221,179,224,179,228,179,232,179,252,179,16,180,24,180,28,180,32,180,40,180,41,180,43,180,52,180,80,180,81,180,84,180,88,180,96,180,97,180,99,180,101,180,108,180,128,180,136,180,157,180,164,180,168,180,172,180,181,180,183,180,185,180,192,180,196,180,200,180,208,180,213,180,220,180,221,180,224,180,227,180,228,180,230,180,236,180,237,180,239,180,241,180,248,180,20,181,21,181,24,181,27,181,28,181,36,181,37,181,39,181,40,181,41,181,42,181,48,181,49,181,52,181,56,181,64,181,65,181,67,181,68,181,69,181,75,181,76,181,77,181,80,181,84,181,92,181,93,181,95,181,96,181,97,181,160,181,161,181,164,181,168,181,170,181,171,181,176,181,177,181,179,181,180,181,181,181,187,181,188,181,189,181,192,181,196,181,204,181,205,181,207,181,208,181,209,181,216,181,236,181,16,182,17,182,20,182,24,182,37,182,44,182,52,182,72,182,100,182,104,182,156,182,157,182,160,182,164,182,171,182,172,182,177,182,212,182,240,182,244,182,248,182,0,183,1,183,5,183,40,183,41,183,44,183,47,183,48,183,56,183,57,183,59,183,68,183,72,183,76,183,84,183,85,183,96,183,100,183,104,183,112,183,113,183,115,183,117,183,124,183,125,183,128,183,132,183,140,183,141,183,143,183,144,183,145,183,146,183,150,183,151,183,152,183,153,183,156,183,160,183,168,183,169,183,171,183,172,183,173,183,180,183,181,183,184,183,199,183,201,183,236,183,237,183,240,183,244,183,252,183,253,183,255,183,0,184,1,184,7,184,8,184,9,184,12,184,16,184,24,184,25,184,27,184,29,184,36,184,37,184,40,184,44,184,52,184,53,184,55,184,56,184,57,184,64,184,68,184,81,184,83,184,92,184,93,184,96,184,100,184,108,184,109,184,111,184,113,184,120,184,124,184,141,184,168,184,176,184,180,184,184,184,192,184,193,184,195,184,197,184,204,184,208,184,212,184,221,184,223,184,225,184,232,184,233,184,236,184,240,184,248,184,249,184,251,184,253,184,4,185,24,185,32,185,60,185,61,185,64,185,68,185,76,185,79,185,81,185,88,185,89,185,92,185,96,185,104,185,105,185,107,185,109,185,116,185,117,185,120,185,124,185,132,185,133,185,135,185,137,185,138,185,141,185,142,185,172,185,173,185,176,185,180,185,188,185,189,185,191,185,193,185,200,185,201,185,204,185,206,185,207,185,208,185,209,185,210,185,216,185,217,185,219,185,221,185,222,185,225,185,227,185,228,185,229,185,232,185,236,185,244,185,245,185,247,185,248,185,249,185,250,185,0,186,1,186,8,186,21,186,56,186,57,186,60,186,64,186,66,186,72,186,73,186,75,186,77,186,78,186,83,186,84,186,85,186,88,186,92,186,100,186,101,186,103,186,104,186,105,186,112,186,113,186,116,186,120,186,131,186,132,186,133,186,135,186,140,186,168,186,169,186,171,186,172,186,176,186,178,186,184,186,185,186,187,186,189,186,196,186,200,186,216,186,217,186,252,186,0,187,4,187,13,187,15,187,17,187,24,187,28,187,32,187,41,187,43,187,52,187,53,187,54,187,56,187,59,187,60,187,61,187,62,187,68,187,69,187,71,187,73,187,77,187,79,187,80,187,84,187,88,187,97,187,99,187,108,187,136,187,140,187,144,187,164,187,168,187,172,187,180,187,183,187,192,187,196,187,200,187,208,187,211,187,248,187,249,187,252,187,255,187,0,188,2,188,8,188,9,188,11,188,12,188,13,188,15,188,17,188,20,188,21,188,22,188,23,188,24,188,27,188,28,188,29,188,30,188,31,188,36,188,37,188,39,188,41,188,45,188,48,188,49,188,52,188,56,188,64,188,65,188,67,188,68,188,69,188,73,188,76,188,77,188,80,188,93,188,132,188,133,188,136,188,139,188,140,188,142,188,148,188,149,188,151,188,153,188,154,188,160,188,161,188,164,188,167,188,168,188,176,188,177,188,179,188,180,188,181,188,188,188,189,188,192,188,196,188,205,188,207,188,208,188,209,188,213,188,216,188,220,188,244,188,245,188,246,188,248,188,252,188,4,189,5,189,7,189,9,189,16,189,20,189,36,189,44,189,64,189,72,189,73,189,76,189,80,189,88,189,89,189,100,189,104,189,128,189,129,189,132,189,135,189,136,189,137,189,138,189,144,189,145,189,147,189,149,189,153,189,154,189,156,189,164,189,176,189,184,189,212,189,213,189,216,189,220,189,233,189,240,189,244,189,248,189,0,190,3,190,5,190,12,190,13,190,16,190,20,190,28,190,29,190,31,190,68,190,69,190,72,190,76,190,78,190,84,190,85,190,87,190,89,190,90,190,91,190,96,190,97,190,100,190,104,190,106,190,112,190,113,190,115,190,116,190,117,190,123,190,124,190,125,190,128,190,132,190,140,190,141,190,143,190,144,190,145,190,152,190,153,190,168,190,208,190,209,190,212,190,215,190,216,190,224,190,227,190,228,190,229,190,236,190,1,191,8,191,9,191,24,191,25,191,27,191,28,191,29,191,64,191,65,191,68,191,72,191,80,191,81,191,85,191,148,191,176,191,197,191,204,191,205,191,208,191,212,191,220,191,223,191,225,191,60,192,81,192,88,192,92,192,96,192,104,192,105,192,144,192,145,192,148,192,152,192,160,192,161,192,163,192,165,192,172,192,173,192,175,192,176,192,179,192,180,192,181,192,182,192,188,192,189,192,191,192,192,192,193,192,197,192,200,192,201,192,204,192,208,192,216,192,217,192,219,192,220,192,221,192,228,192,229,192,232,192,236,192,244,192,245,192,247,192,249,192,0,193,4,193,8,193,16,193,21,193,28,193,29,193,30,193,31,193,32,193,35,193,36,193,38,193,39,193,44,193,45,193,47,193,48,193,49,193,54,193,56,193,57,193,60,193,64,193,72,193,73,193,75,193,76,193,77,193,84,193,85,193,88,193,92,193,100,193,101,193,103,193,104,193,105,193,112,193,116,193,120,193,133,193,140,193,141,193,142,193,144,193,148,193,150,193,156,193,157,193,159,193,161,193,165,193,168,193,169,193,172,193,176,193,189,193,196,193,200,193,204,193,212,193,215,193,216,193,224,193,228,193,232,193,240,193,241,193,243,193,252,193,253,193,0,194,4,194,12,194,13,194,15,194,17,194,24,194,25,194,28,194,31,194,32,194,40,194,41,194,43,194,45,194,47,194,49,194,50,194,52,194,72,194,80,194,81,194,84,194,88,194,96,194,101,194,108,194,109,194,112,194,116,194,124,194,125,194,127,194,129,194,136,194,137,194,144,194,152,194,155,194,157,194,164,194,165,194,168,194,172,194,173,194,180,194,181,194,183,194,185,194,220,194,221,194,224,194,227,194,228,194,235,194,236,194,237,194,239,194,241,194,246,194,248,194,249,194,251,194,252,194,0,195,8,195,9,195,12,195,13,195,19,195,20,195,21,195,24,195,28,195,36,195,37,195,40,195,41,195,69,195,104,195,105,195,108,195,112,195,114,195,120,195,121,195,124,195,125,195,132,195,136,195,140,195,192,195,216,195,217,195,220,195,223,195,224,195,226,195,232,195,233,195,237,195,244,195,245,195,248,195,8,196,16,196,36,196,44,196,48,196,52,196,60,196,61,196,72,196,100,196,101,196,104,196,108,196,116,196,117,196,121,196,128,196,148,196,156,196,184,196,188,196,233,196,240,196,241,196,244,196,248,196,250,196,255,196,0,197,1,197,12,197,16,197,20,197,28,197,40,197,41,197,44,197,48,197,56,197,57,197,59,197,61,197,68,197,69,197,72,197,73,197,74,197,76,197,77,197,78,197,83,197,84,197,85,197,87,197,88,197,89,197,93,197,94,197,96,197,97,197,100,197,104,197,112,197,113,197,115,197,116,197,117,197,124,197,125,197,128,197,132,197,135,197,140,197,141,197,143,197,145,197,149,197,151,197,152,197,156,197,160,197,169,197,180,197,181,197,184,197,185,197,187,197,188,197,189,197,190,197,196,197,197,197,198,197,199,197,200,197,201,197,202,197,204,197,206,197,208,197,209,197,212,197,216,197,224,197,225,197,227,197,229,197,236,197,237,197,238,197,240,197,244,197,246,197,247,197,252,197,253,197,254,197,255,197,0,198,1,198,5,198,6,198,7,198,8,198,12,198,16,198,24,198,25,198,27,198,28,198,36,198,37,198,40,198,44,198,45,198,46,198,48,198,51,198,52,198,53,198,55,198,57,198,59,198,64,198,65,198,68,198,72,198,80,198,81,198,83,198,84,198,85,198,92,198,93,198,96,198,108,198,111,198,113,198,120,198,121,198,124,198,128,198,136,198,137,198,139,198,141,198,148,198,149,198,152,198,156,198,164,198,165,198,167,198,169,198,176,198,177,198,180,198,184,198,185,198,186,198,192,198,193,198,195,198,197,198,204,198,205,198,208,198,212,198,220,198,221,198,224,198,225,198,232,198,233,198,236,198,240,198,248,198,249,198,253,198,4,199,5,199,8,199,12,199,20,199,21,199,23,199,25,199,32,199,33,199,36,199,40,199,48,199,49,199,51,199,53,199,55,199,60,199,61,199,64,199,68,199,74,199,76,199,77,199,79,199,81,199,82,199,83,199,84,199,85,199,86,199,87,199,88,199,92,199,96,199,104,199,107,199,116,199,117,199,120,199,124,199,125,199,126,199,131,199,132,199,133,199,135,199,136,199,137,199,138,199,142,199,144,199,145,199,148,199,150,199,151,199,152,199,154,199,160,199,161,199,163,199,164,199,165,199,166,199,172,199,173,199,176,199,180,199,188,199,189,199,191,199,192,199,193,199,200,199,201,199,204,199,206,199,208,199,216,199,221,199,228,199,232,199,236,199,0,200,1,200,4,200,8,200,10,200,16,200,17,200,19,200,21,200,22,200,28,200,29,200,32,200,36,200,44,200,45,200,47,200,49,200,56,200,60,200,64,200,72,200,73,200,76,200,77,200,84,200,112,200,113,200,116,200,120,200,122,200,128,200,129,200,131,200,133,200,134,200,135,200,139,200,140,200,141,200,148,200,157,200,159,200,161,200,168,200,188,200,189,200,196,200,200,200,204,200,212,200,213,200,215,200,217,200,224,200,225,200,228,200,245,200,252,200,253,200,0,201,4,201,5,201,6,201,12,201,13,201,15,201,17,201,24,201,44,201,52,201,80,201,81,201,84,201,88,201,96,201,97,201,99,201,108,201,112,201,116,201,124,201,136,201,137,201,140,201,144,201,152,201,153,201,155,201,157,201,192,201,193,201,196,201,199,201,200,201,202,201,208,201,209,201,211,201,213,201,214,201,217,201,218,201,220,201,221,201,224,201,226,201,228,201,231,201,236,201,237,201,239,201,240,201,241,201,248,201,249,201,252,201,0,202,8,202,9,202,11,202,12,202,13,202,20,202,24,202,41,202,76,202,77,202,80,202,84,202,92,202,93,202,95,202,96,202,97,202,104,202,125,202,132,202,152,202,188,202,189,202,192,202,196,202,204,202,205,202,207,202,209,202,211,202,216,202,217,202,224,202,236,202,244,202,8,203,16,203,20,203,24,203,32,203,33,203,65,203,72,203,73,203,76,203,80,203,88,203,89,203,93,203,100,203,120,203,121,203,156,203,184,203,212,203,228,203,231,203,233,203,12,204,13,204,16,204,20,204,28,204,29,204,33,204,34,204,39,204,40,204,41,204,44,204,46,204,48,204,56,204,57,204,59,204,60,204,61,204,62,204,68,204,69,204,72,204,76,204,84,204,85,204,87,204,88,204,89,204,96,204,100,204,102,204,104,204,112,204,117,204,152,204,153,204,156,204,160,204,168,204,169,204,171,204,172,204,173,204,180,204,181,204,184,204,188,204,196,204,197,204,199,204,201,204,208,204,212,204,228,204,236,204,240,204,1,205,8,205,9,205,12,205,16,205,24,205,25,205,27,205,29,205,36,205,40,205,44,205,57,205,92,205,96,205,100,205,108,205,109,205,111,205,113,205,120,205,136,205,148,205,149,205,152,205,156,205,164,205,165,205,167,205,169,205,176,205,196,205,204,205,208,205,232,205,236,205,240,205,248,205,249,205,251,205,253,205,4,206,8,206,12,206,20,206,25,206,32,206,33,206,36,206,40,206,48,206,49,206,51,206,53,206,88,206,89,206,92,206,95,206,96,206,97,206,104,206,105,206,107,206,109,206,116,206,117,206,120,206,124,206,132,206,133,206,135,206,137,206,144,206,145,206,148,206,152,206,160,206,161,206,163,206,164,206,165,206,172,206,173,206,193,206,228,206,229,206,232,206,235,206,236,206,244,206,245,206,247,206,248,206,249,206,0,207,1,207,4,207,8,207,16,207,17,207,19,207,21,207,28,207,32,207,36,207,44,207,45,207,47,207,48,207,49,207,56,207,84,207,85,207,88,207,92,207,100,207,101,207,103,207,105,207,112,207,113,207,116,207,120,207,128,207,133,207,140,207,161,207,168,207,176,207,196,207,224,207,225,207,228,207,232,207,240,207,241,207,243,207,245,207,252,207,0,208,4,208,17,208,24,208,45,208,52,208,53,208,56,208,60,208,68,208,69,208,71,208,73,208,80,208,84,208,88,208,96,208,108,208,109,208,112,208,116,208,124,208,125,208,129,208,164,208,165,208,168,208,172,208,180,208,181,208,183,208,185,208,192,208,193,208,196,208,200,208,201,208,208,208,209,208,211,208,212,208,213,208,220,208,221,208,224,208,228,208,236,208,237,208,239,208,240,208,241,208,248,208,13,209,48,209,49,209,52,209,56,209,58,209,64,209,65,209,67,209,68,209,69,209,76,209,77,209,80,209,84,209,92,209,93,209,95,209,97,209,104,209,108,209,124,209,132,209,136,209,160,209,161,209,164,209,168,209,176,209,177,209,179,209,181,209,186,209,188,209,192,209,216,209,244,209,248,209,7,210,9,210,16,210,44,210,45,210,48,210,52,210,60,210,61,210,63,210,65,210,72,210,92,210,100,210,128,210,129,210,132,210,136,210,144,210,145,210,149,210,156,210,160,210,164,210,172,210,177,210,184,210,185,210,188,210,191,210,192,210,194,210,200,210,201,210,203,210,212,210,216,210,220,210,228,210,229,210,240,210,241,210,244,210,248,210,0,211,1,211,3,211,5,211,12,211,13,211,14,211,16,211,20,211,22,211,28,211,29,211,31,211,32,211,33,211,37,211,40,211,41,211,44,211,48,211,56,211,57,211,59,211,60,211,61,211,68,211,69,211,124,211,125,211,128,211,132,211,140,211,141,211,143,211,144,211,145,211,152,211,153,211,156,211,160,211,168,211,169,211,171,211,173,211,180,211,184,211,188,211,196,211,197,211,200,211,201,211,208,211,216,211,225,211,227,211,236,211,237,211,240,211,244,211,252,211,253,211,255,211,1,212,8,212,29,212,64,212,68,212,92,212,96,212,100,212,109,212,111,212,120,212,121,212,124,212,127,212,128,212,130,212,136,212,137,212,139,212,141,212,148,212,169,212,204,212,208,212,212,212,220,212,223,212,232,212,236,212,240,212,248,212,251,212,253,212,4,213,8,213,12,213,20,213,21,213,23,213,60,213,61,213,64,213,68,213,76,213,77,213,79,213,81,213,88,213,89,213,92,213,96,213,101,213,104,213,105,213,107,213,109,213,116,213,117,213,120,213,124,213,132,213,133,213,135,213,136,213,137,213,144,213,165,213,200,213,201,213,204,213,208,213,210,213,216,213,217,213,219,213,221,213,228,213,229,213,232,213,236,213,244,213,245,213,247,213,249,213,0,214,1,214,4,214,8,214,16,214,17,214,19,214,20,214,21,214,28,214,32,214,36,214,45,214,56,214,57,214,60,214,64,214,69,214,72,214,73,214,75,214,77,214,81,214,84,214,85,214,88,214,92,214,103,214,105,214,112,214,113,214,116,214,131,214,133,214,140,214,141,214,144,214,148,214,157,214,159,214,161,214,168,214,172,214,176,214,185,214,187,214,196,214,197,214,200,214,204,214,209,214,212,214,215,214,217,214,224,214,228,214,232,214,240,214,245,214,252,214,253,214,0,215,4,215,17,215,24,215,25,215,28,215,32,215,40,215,41,215,43,215,45,215,52,215,53,215,56,215,60,215,68,215,71,215,73,215,80,215,81,215,84,215,86,215,87,215,88,215,89,215,96,215,97,215,99,215,101,215,105,215,108,215,112,215,116,215,124,215,125,215,129,215,136,215,137,215,140,215,144,215,152,215,153,215,155,215,157,215,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,61,79,115,79,71,80,249,80,160,82,239,83,117,84,229,84,9,86,193,90,182,91,135,102,182,103,183,103,239,103,76,107,194,115,194,117,60,122,219,130,4,131,87,136,136,136,54,138,200,140,207,141,251,142,230,143,213,153,59,82,116,83,4,84,106,96,100,97,188,107,207,115,26,129,186,137,210,137,163,149,131,79,10,82,190,88,120,89,230,89,114,94,121,94,199,97,192,99,70,103,236,103,127,104,151,111,78,118,11,119,245,120,8,122,255,122,33,124,157,128,110,130,113,130,235,138,147,149,107,78,157,85,247,102,52,110,163,120,237,122,91,132,16,137,78,135,168,151,216,82,78,87,42,88,76,93,31,97,190,97,33,98,98,101,209,103,68,106,27,110,24,117,179,117,227,118,176,119,58,125,175,144,81,148,82,148,149,159,35,83,172,92,50,117,219,128,64,146,152,149,91,82,8,88,220,89,161,92,23,93,183,94,58,95,74,95,119,97,95,108,122,117,134,117,224,124,115,125,177,125,140,127,84,129,33,130,145,133,65,137,27,139,252,146,77,150,71,156,203,78,247,78,11,80,241,81,79,88,55,97,62,97,104,97,57,101,234,105,17,111,165,117,134,118,214,118,135,123,165,130,203,132,0,249,167,147,139,149,128,85,162,91,81,87,1,249,179,124,185,127,181,145,40,80,187,83,69,92,232,93,210,98,110,99,218,100,231,100,32,110,172,112,91,121,221,141,30,142,2,249,125,144,69,146,248,146,126,78,246,78,101,80,254,93,250,94,6,97,87,105,113,129,84,134,71,142,117,147,43,154,94,78,145,80,112,103,64,104,9,81,141,82,146,82,162,106,188,119,16,146,212,158,171,82,47,96,242,143,72,80,169,97,237,99,202,100,60,104,132,106,192,111,136,129,161,137,148,150,5,88,125,114,172,114,4,117,121,125,109,126,169,128,139,137,116,139,99,144,81,157,137,98,122,108,84,111,80,125,58,127,35,138,124,81,74,97,157,123,25,139,87,146,140,147,172,78,211,79,30,80,190,80,6,81,193,82,205,82,127,83,112,87,131,88,154,94,145,95,118,97,172,97,206,100,108,101,111,102,187,102,244,102,151,104,135,109,133,112,241,112,159,116,165,116,202,116,217,117,108,120,236,120,223,122,246,122,69,125,147,125,21,128,63,128,27,129,150,131,102,139,21,143,21,144,225,147,3,152,56,152,90,154,232,155,194,79,83,85,58,88,81,89,99,91,70,92,184,96,18,98,66,104,176,104,232,104,170,110,76,117,120,118,206,120,61,122,251,124,107,126,124,126,8,138,161,138,63,140,142,150,196,157,228,83,233,83,74,84,113,84,250,86,209,89,100,91,59,92,171,94,247,98,55,101,69,101,114,101,160,102,175,103,193,105,189,108,252,117,144,118,126,119,63,122,148,127,3,128,161,128,143,129,230,130,253,130,240,131,193,133,49,136,180,136,165,138,3,249,156,143,46,147,199,150,103,152,216,154,19,159,237,84,155,101,242,102,143,104,64,122,55,140,96,157,240,86,100,87,17,93,6,102,177,104,205,104,254,110,40,116,158,136,228,155,104,108,4,249,168,154,155,79,108,81,113,81,159,82,84,91,229,93,80,96,109,96,241,98,167,99,59,101,217,115,122,122,163,134,162,140,143,151,50,78,225,91,8,98,156,103,220,116,209,121,211,131,135,138,178,138,232,141,78,144,75,147,70,152,211,94,232,105,255,133,237,144,5,249,160,81,152,91,236,91,99,97,250,104,62,107,76,112,47,116,216,116,161,123,80,127,197,131,192,137,171,140,220,149,40,153,46,82,93,96,236,98,2,144,138,79,73,81,33,83,217,88,227,94,224,102,56,109,154,112,194,114,214,115,80,123,241,128,91,148,102,83,155,99,107,127,86,78,128,80,74,88,222,88,42,96,39,97,208,98,208,105,65,155,143,91,24,125,177,128,95,143,164,78,209,80,172,84,172,85,12,91,160,93,231,93,42,101,78,101,33,104,75,106,225,114,142,118,239,119,94,125,249,127,160,129,78,133,223,134,3,143,78,143,202,144,3,153,85,154,171,155,24,78,69,78,93,78,199,78,241,79,119,81,254,82,64,83,227,83,229,83,142,84,20,86,117,87,162,87,199,91,135,93,208,94,252,97,216,98,81,101,184,103,233,103,203,105,80,107,198,107,236,107,66,108,157,110,120,112,215,114,150,115,3,116,191,119,233,119,118,122,127,125,9,128,252,129,5,130,10,130,223,130,98,136,51,139,252,140,192,142,17,144,177,144,100,146,182,146,210,153,69,154,233,156,215,157,156,159,11,87,64,92,202,131,160,151,171,151,180,158,27,84,152,122,164,127,217,136,205,142,225,144,0,88,72,92,152,99,159,122,174,91,19,95,121,122,174,122,142,130,172,142,38,80,56,82,248,82,119,83,8,87,243,98,114,99,10,107,195,109,55,119,165,83,87,115,104,133,118,142,213,149,58,103,195,106,112,111,109,138,204,142,75,153,6,249,119,102,120,107,180,140,60,155,7,249,235,83,45,87,78,89,198,99,251,105,234,115,69,120,186,122,197,122,254,124,117,132,143,137,115,141,53,144,168,149,251,82,71,87,71,117,96,123,204,131,30,146,8,249,88,106,75,81,75,82,135,82,31,98,216,104,117,105,153,150,197,80,164,82,228,82,195,97,164,101,57,104,255,105,126,116,75,123,185,130,235,131,178,137,57,139,209,143,73,153,9,249,202,78,151,89,210,100,17,102,142,106,52,116,129,121,189,121,169,130,126,136,127,136,95,137,10,249,38,147,11,79,202,83,37,96,113,98,114,108,26,125,102,125,152,78,98,81,220,119,175,128,1,79,14,79,118,81,128,81,220,85,104,86,59,87,250,87,252,87,20,89,71,89,147,89,196,91,144,92,14,93,241,93,126,94,204,95,128,98,215,101,227,101,30,103,31,103,94,103,203,104,196,104,95,106,58,107,35,108,125,108,130,108,199,109,152,115,38,116,42,116,130,116,163,116,120,117,127,117,129,120,239,120,65,121,71,121,72,121,122,121,149,123,0,125,186,125,136,127,6,128,45,128,140,128,24,138,79,139,72,140,119,141,33,147,36,147,226,152,81,153,14,154,15,154,101,154,146,158,202,125,118,79,9,84,238,98,84,104,209,145,171,85,58,81,11,249,12,249,28,90,230,97,13,249,207,98,255,98,14,249,15,249,16,249,17,249,18,249,19,249,163,144,20,249,21,249,22,249,23,249,24,249,254,138,25,249,26,249,27,249,28,249,150,102,29,249,86,113,30,249,31,249,227,150,32,249,79,99,122,99,87,83,33,249,143,103,96,105,115,110,34,249,55,117,35,249,36,249,37,249,13,125,38,249,39,249,114,136,202,86,24,90,40,249,41,249,42,249,43,249,44,249,67,78,45,249,103,81,72,89,240,103,16,128,46,249,115,89,116,94,154,100,202,121,245,95,108,96,200,98,123,99,231,91,215,91,170,82,47,249,116,89,41,95,18,96,48,249,49,249,50,249,89,116,51,249,52,249,53,249,54,249,55,249,56,249,209,153,57,249,58,249,59,249,60,249,61,249,62,249,63,249,64,249,65,249,66,249,67,249,195,111,68,249,69,249,191,129,178,143,241,96,70,249,71,249,102,129,72,249,73,249,63,92,74,249,75,249,76,249,77,249,78,249,79,249,80,249,81,249,233,90,37,138,123,103,16,125,82,249,83,249,84,249,85,249,86,249,87,249,253,128,88,249,89,249,60,92,229,108,63,83,186,110,26,89,54,131,57,78,182,78,70,79,174,85,24,87,199,88,86,95,183,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+861544);
/* memory initializer */ allocate([230,101,128,106,181,107,77,110,237,119,239,122,30,124,222,125,203,134,146,136,50,145,91,147,187,100,190,111,122,115,184,117,84,144,86,85,77,87,186,97,212,100,199,102,225,109,91,110,109,111,185,111,240,117,67,128,189,129,65,133,131,137,199,138,90,139,31,147,147,108,83,117,84,123,15,142,93,144,16,85,2,88,88,88,98,94,7,98,158,100,224,104,118,117,214,124,179,135,232,158,227,78,136,87,110,87,39,89,13,92,177,92,54,94,133,95,52,98,225,100,179,115,250,129,139,136,184,140,138,150,219,158,133,91,183,95,179,96,18,80,0,82,48,82,22,87,53,88,87,88,14,92,96,92,246,92,139,93,166,94,146,95,188,96,17,99,137,99,23,100,67,104,249,104,194,106,216,109,33,110,212,110,228,111,254,113,220,118,121,119,177,121,59,122,4,132,169,137,237,140,243,141,72,142,3,144,20,144,83,144,253,144,77,147,118,150,220,151,210,107,6,112,88,114,162,114,104,115,99,119,191,121,228,123,155,126,128,139,169,88,199,96,102,101,253,101,190,102,140,108,30,113,201,113,90,140,19,152,109,78,129,122,221,78,172,81,205,81,213,82,12,84,167,97,113,103,80,104,223,104,30,109,124,111,188,117,179,119,229,122,244,128,99,132,133,146,92,81,151,101,92,103,147,103,216,117,199,122,115,131,90,249,70,140,23,144,45,152,111,92,192,129,154,130,65,144,111,144,13,146,151,95,157,93,89,106,200,113,123,118,73,123,228,133,4,139,39,145,48,154,135,85,246,97,91,249,105,118,133,127,63,134,186,135,248,136,143,144,92,249,27,109,217,112,222,115,97,125,61,132,93,249,106,145,241,153,94,249,130,78,117,83,4,107,18,107,62,112,27,114,45,134,30,158,76,82,163,143,80,93,229,100,44,101,22,107,235,111,67,124,156,126,205,133,100,137,189,137,201,98,216,129,31,136,202,94,23,103,106,109,252,114,5,116,111,116,130,135,222,144,134,79,13,93,160,95,10,132,183,81,160,99,101,117,174,78,6,80,105,81,201,81,129,104,17,106,174,124,177,124,231,124,111,130,210,138,27,143,207,145,182,79,55,81,245,82,66,84,236,94,110,97,62,98,197,101,218,106,254,111,42,121,220,133,35,136,173,149,98,154,106,154,151,158,206,158,155,82,198,102,119,107,29,112,43,121,98,143,66,151,144,97,0,98,35,101,35,111,73,113,137,116,244,125,111,128,238,132,38,143,35,144,74,147,189,81,23,82,163,82,12,109,200,112,194,136,201,94,130,101,174,107,194,111,62,124,117,115,228,78,54,79,249,86,95,249,186,92,186,93,28,96,178,115,45,123,154,127,206,127,70,128,30,144,52,146,246,150,72,151,24,152,97,159,139,79,167,111,174,121,180,145,183,150,222,82,96,249,136,100,196,100,211,106,94,111,24,112,16,114,231,118,1,128,6,134,92,134,239,141,5,143,50,151,111,155,250,157,117,158,140,120,127,121,160,125,201,131,4,147,127,158,147,158,214,138,223,88,4,95,39,103,39,112,207,116,96,124,126,128,33,81,40,112,98,114,202,120,194,140,218,140,244,140,247,150,134,78,218,80,238,91,214,94,153,101,206,113,66,118,173,119,74,128,252,132,124,144,39,155,141,159,216,88,65,90,98,92,19,106,218,109,15,111,59,118,47,125,55,126,30,133,56,137,228,147,75,150,137,82,210,101,243,103,180,105,65,109,156,110,15,112,9,116,96,116,89,117,36,118,107,120,44,139,94,152,109,81,46,98,120,150,150,79,43,80,25,93,234,109,184,125,42,143,139,95,68,97,23,104,97,249,134,150,210,82,139,128,220,81,204,81,94,105,28,122,190,125,241,131,117,150,218,79,41,82,152,83,15,84,14,85,101,92,167,96,78,103,168,104,108,109,129,114,248,114,6,116,131,116,98,249,226,117,108,124,121,127,184,127,137,131,207,136,225,136,204,145,208,145,226,150,201,155,29,84,126,111,208,113,152,116,250,133,170,142,163,150,87,156,159,158,151,103,203,109,51,116,232,129,22,151,44,120,203,122,32,123,146,124,105,100,106,116,242,117,188,120,232,120,172,153,84,155,187,158,222,91,85,94,32,111,156,129,171,131,136,144,7,78,77,83,41,90,210,93,78,95,98,97,61,99,105,102,252,102,255,110,43,111,99,112,158,119,44,132,19,133,59,136,19,143,69,153,59,156,28,85,185,98,43,103,171,108,9,131,106,137,122,151,161,78,132,89,216,95,217,95,27,103,178,125,84,127,146,130,43,131,189,131,30,143,153,144,203,87,185,89,146,90,208,91,39,102,154,103,133,104,207,107,100,113,117,127,183,140,227,140,129,144,69,155,8,129,138,140,76,150,64,154,165,158,95,91,19,108,27,115,242,118,223,118,12,132,170,81,147,137,77,81,149,81,201,82,201,104,148,108,4,119,32,119,191,125,236,125,98,151,181,158,197,110,17,133,165,81,13,84,125,84,14,102,157,102,39,105,159,110,191,118,145,119,23,131,194,132,159,135,105,145,152,146,244,156,130,136,174,79,146,81,223,82,198,89,61,94,85,97,120,100,121,100,174,102,208,103,33,106,205,107,219,107,95,114,97,114,65,116,56,119,219,119,23,128,188,130,5,131,0,139,40,139,140,140,40,103,144,108,103,114,238,118,102,119,70,122,169,157,127,107,146,108,34,89,38,103,153,132,111,83,147,88,153,89,223,94,207,99,52,102,115,103,58,110,43,115,215,122,215,130,40,147,217,82,235,93,174,97,203,97,10,98,199,98,171,100,224,101,89,105,102,107,203,107,33,113,247,115,93,117,70,126,30,130,2,131,106,133,163,138,191,140,39,151,97,157,168,88,216,158,17,80,14,82,59,84,79,85,135,101,118,108,10,125,11,125,94,128,138,134,128,149,239,150,255,82,149,108,105,114,115,84,154,90,62,92,75,93,76,95,174,95,42,103,182,104,99,105,60,110,68,110,9,119,115,124,142,127,135,133,14,139,247,143,97,151,244,158,183,92,182,96,13,97,171,97,79,101,251,101,252,101,17,108,239,108,159,115,201,115,225,125,148,149,198,91,28,135,16,139,93,82,90,83,205,98,15,100,178,100,52,103,56,106,202,108,192,115,158,116,148,123,149,124,27,126,138,129,54,130,132,133,235,143,249,150,193,153,52,79,74,83,205,83,219,83,204,98,44,100,0,101,145,101,195,105,238,108,88,111,237,115,84,117,34,118,228,118,252,118,208,120,251,120,44,121,70,125,44,130,224,135,212,143,18,152,239,152,195,82,212,98,165,100,36,110,81,111,124,118,203,141,177,145,98,146,238,154,67,155,35,80,141,80,74,87,168,89,40,92,71,94,119,95,63,98,62,101,185,101,193,101,9,102,139,103,156,105,194,110,197,120,33,125,170,128,128,129,43,130,179,130,161,132,140,134,42,138,23,139,166,144,50,150,144,159,13,80,243,79,99,249,249,87,152,95,220,98,146,99,111,103,67,110,25,113,195,118,204,128,218,128,244,136,245,136,25,137,224,140,41,143,77,145,106,150,47,79,112,79,27,94,207,103,34,104,125,118,126,118,68,155,97,94,10,106,105,113,212,113,106,117,100,249,65,126,67,133,233,133,220,152,16,79,79,123,112,127,165,149,225,81,6,94,181,104,62,108,78,108,219,108,175,114,196,123,3,131,213,108,58,116,251,80,136,82,193,88,216,100,151,106,167,116,86,118,167,120,23,134,226,149,57,151,101,249,94,83,1,95,138,139,168,143,175,143,138,144,37,82,165,119,73,156,8,159,25,78,2,80,117,81,91,92,119,94,30,102,58,102,196,103,197,104,179,112,1,117,197,117,201,121,221,122,39,143,32,153,8,154,221,79,33,88,49,88,246,91,110,102,101,107,17,109,122,110,125,111,228,115,43,117,233,131,220,136,19,137,92,139,20,143,15,79,213,80,16,83,92,83,147,91,169,95,13,103,143,121,121,129,47,131,20,133,7,137,134,137,57,143,59,143,165,153,18,156,44,103,118,78,248,79,73,89,1,92,239,92,240,92,103,99,210,104,253,112,162,113,43,116,43,126,236,132,2,135,34,144,210,146,243,156,13,78,216,78,239,79,133,80,86,82,111,82,38,84,144,84,224,87,43,89,102,90,90,91,117,91,204,91,156,94,102,249,118,98,119,101,167,101,110,109,165,110,54,114,38,123,63,124,54,127,80,129,81,129,154,129,64,130,153,130,169,131,3,138,160,140,230,140,251,140,116,141,186,141,232,144,220,145,28,150,68,150,217,153,231,156,23,83,6,82,41,84,116,86,179,88,84,89,110,89,255,95,164,97,110,98,16,102,126,108,26,113,198,118,137,124,222,124,27,125,172,130,193,140,240,150,103,249,91,79,23,95,127,95,194,98,41,93,11,103,218,104,124,120,67,126,108,157,21,78,153,80,21,83,42,83,81,83,131,89,98,90,135,94,178,96,138,97,73,98,121,98,144,101,135,103,167,105,212,107,214,107,215,107,216,107,184,108,104,249,53,116,250,117,18,120,145,120,213,121,216,121,131,124,203,125,225,127,165,128,62,129,194,129,242,131,26,135,232,136,185,138,108,139,187,140,25,145,94,151,219,152,59,159,172,86,42,91,108,95,140,101,179,106,175,107,92,109,241,111,21,112,93,114,173,115,167,140,211,140,59,152,145,97,55,108,88,128,1,154,77,78,139,78,155,78,213,78,58,79,60,79,127,79,223,79,255,80,242,83,248,83,6,85,227,85,219,86,235,88,98,89,17,90,235,91,250,91,4,92,243,93,43,94,153,95,29,96,104,99,156,101,175,101,246,103,251,103,173,104,123,107,153,108,215,108,35,110,9,112,69,115,2,120,62,121,64,121,96,121,193,121,233,123,23,125,114,125,134,128,13,130,142,131,209,132,199,134,223,136,80,138,94,138,29,139,220,140,102,141,173,143,170,144,252,152,223,153,157,158,74,82,105,249,20,103,106,249,152,80,42,82,113,92,99,101,85,108,202,115,35,117,157,117,151,123,156,132,120,145,48,151,119,78,146,100,186,107,94,113,169,133,9,78,107,249,73,103,238,104,23,110,159,130,24,133,107,136,247,99,129,111,18,146,175,152,10,78,183,80,207,80,31,81,70,85,170,85,23,86,64,91,25,92,224,92,56,94,138,94,160,94,194,94,243,96,81,104,97,106,88,110,61,114,64,114,192,114,248,118,101,121,177,123,212,127,243,136,244,137,115,138,97,140,222,140,28,151,94,88,189,116,253,140,199,85,108,249,97,122,34,125,114,130,114,114,31,117,37,117,109,249,25,123,133,88,251,88,188,93,143,94,182,94,144,95,85,96,146,98,127,99,77,101,145,102,217,102,248,102,22,104,242,104,128,114,94,116,110,123,110,125,214,125,114,127,229,128,18,130,175,133,127,137,147,138,29,144,228,146,205,158,32,159,21,89,109,89,45,94,220,96,20,102,115,102,144,103,80,108,197,109,95,111,243,119,169,120,198,132,203,145,43,147,217,78,202,80,72,81,132,85,11,91,163,91,71,98,126,101,203,101,50,110,125,113,1,116,68,116,135,116,191,116,108,118,170,121,218,125,85,126,168,127,122,129,179,129,57,130,26,134,236,135,117,138,227,141,120,144,145,146,37,148,77,153,174,155,104,83,81,92,84,105,196,108,41,109,43,110,12,130,155,133,59,137,45,138,170,138,234,150,103,159,97,82,185,102,178,107,150,126,254,135,13,141,131,149,93,150,29,101,137,109,238,113,110,249,206,87,211,89,172,91,39,96,250,96,16,98,31,102,95,102,41,115,249,115,219,118,1,119,108,123,86,128,114,128,101,129,160,138,146,145,22,78,226,82,114,107,23,109,5,122,57,123,48,125,111,249,176,140,236,83,47,86,81,88,181,91,15,92,17,92,226,93,64,98,131,99,20,100,45,102,179,104,188,108,136,109,175,110,31,112,164,112,210,113,38,117,143,117,142,117,25,118,17,123,224,123,43,124,32,125,57,125,44,133,109,133,7,134,52,138,13,144,97,144,181,144,183,146,246,151,55,154,215,79,108,92,95,103,145,109,159,124,140,126,22,139,22,141,31,144,107,91,253,93,13,100,192,132,92,144,225,152,135,115,139,91,154,96,126,103,222,109,31,138,166,138,1,144,12,152,55,82,112,249,81,112,142,120,150,147,112,136,215,145,238,79,215,83,253,85,218,86,130,87,253,88,194,90,136,91,171,92,192,92,37,94,1,97,13,98,75,98,136,99,28,100,54,101,120,101,57,106,138,107,52,108,25,109,49,111,231,113,233,114,120,115,7,116,178,116,38,118,97,119,192,121,87,122,234,122,185,124,143,125,172,125,97,126,158,127,41,129,49,131,144,132,218,132,234,133,150,136,176,138,144,139,56,143,66,144,131,144,108,145,150,146,185,146,139,150,167,150,168,150,214,150,0,151,8,152,150,153,211,154,26,155,212,83,126,88,25,89,112,91,191,91,209,109,90,111,159,113,33,116,185,116,133,128,253,131,225,93,135,95,170,95,66,96,236,101,18,104,111,105,83,106,137,107,53,109,243,109,227,115,254,118,172,119,77,123,20,125,35,129,28,130,64,131,244,132,99,133,98,138,196,138,135,145,30,147,6,152,180,153,12,98,83,136,240,143,101,146,7,93,39,93,105,93,95,116,157,129,104,135,213,111,254,98,210,127,54,137,114,137,30,78,88,78,231,80,221,82,71,83,127,98,7,102,105,126,5,136,94,150,141,79,25,83,54,86,203,89,164,90,56,92,78,92,77,92,2,94,17,95,67,96,189,101,47,102,66,102,190,103,244,103,28,115,226,119,58,121,197,127,148,132,205,132,150,137,102,138,105,138,225,138,85,140,122,140,244,87,212,91,15,95,111,96,237,98,13,105,150,107,92,110,132,113,210,123,85,135,88,139,254,142,223,152,254,152,56,79,129,79,225,79,123,84,32,90,184,91,60,97,176,101,104,102,252,113,51,117,94,121,51,125,78,129,227,129,152,131,170,133,206,133,3,135,10,138,171,142,155,143,113,249,197,143,49,89,164,91,230,91,137,96,233,91,11,92,195,95,129,108,114,249,241,109,11,112,26,117,175,130,246,138,192,78,65,83,115,249,217,150,15,108,158,78,196,79,82,81,94,85,37,90,232,92,17,98,89,114,189,130,170,131,254,134,89,136,29,138,63,150,197,150,19,153,9,157,93,157,10,88,179,92,189,93,68,94,225,96,21,97,225,99,2,106,37,110,2,145,84,147,78,152,16,156,119,159,137,91,184,92,9,99,79,102,72,104,60,119,193,150,141,151,84,152,159,155,161,101,1,139,203,142,188,149,53,85,169,92,214,93,181,94,151,102,76,118,244,131,199,149,211,88,188,98,206,114,40,157,240,78,46,89,15,96,59,102,131,107,231,121,38,157,147,83,192,84,195,87,22,93,27,97,214,102,175,109,141,120,126,130,152,150,68,151,132,83,124,98,150,99,178,109,10,126,75,129,77,152,251,106,76,127,175,157,26,158,95,78,59,80,182,81,28,89,249,96,246,99,48,105,58,114,54,128,116,249,206,145,49,95,117,249,118,249,4,125,229,130,111,132,187,132,229,133,141,142,119,249,111,79,120,249,121,249,228,88,67,91,89,96,218,99,24,101,109,101,152,102,122,249,74,105,35,106,11,109,1,112,108,113,210,117,13,118,179,121,112,122,123,249,138,127,124,249,68,137,125,249,147,139,192,145,125,150,126,249,10,153,4,87,161,95,188,101,1,111,0,118,166,121,158,138,173,153,90,155,108,159,4,81,182,97,145,98,141,106,198,129,67,80,48,88,102,95,9,113,0,138,250,138,124,91,22,134,250,79,60,81,180,86,68,89,169,99,249,109,170,93,109,105,134,81,136,78,89,79,127,249,128,249,129,249,130,89,130,249,131,249,95,107,93,108,132,249,181,116,22,121,133,249,7,130,69,130,57,131,63,143,93,143,134,249,24,153,135,249,136,249,137,249,166,78,138,249,223,87,121,95,19,102,139,249,140,249,171,117,121,126,111,139,141,249,6,144,91,154,165,86,39,88,248,89,31,90,180,91,142,249,246,94,143,249,144,249,80,99,59,99,145,249,61,105,135,108,191,108,142,109,147,109,245,109,20,111,146,249,223,112,54,113,89,113,147,249,195,113,213,113,148,249,79,120,111,120,149,249,117,123,227,125,150,249,47,126,151,249,77,136,223,142,152,249,153,249,154,249,91,146,155,249,246,156,156,249,157,249,158,249,133,96,133,109,159,249,177,113,160,249,161,249,177,149,173,83,162,249,163,249,164,249,211,103,165,249,142,112,48,113,48,116,118,130,210,130,166,249,187,149,229,154,125,158,196,102,167,249,193,113,73,132,168,249,169,249,75,88,170,249,171,249,184,93,113,95,172,249,32,102,142,102,121,105,174,105,56,108,243,108,54,110,65,111,218,111,27,112,47,112,80,113,223,113,112,115,173,249,91,116,174,249,212,116,200,118,78,122,147,126,175,249,176,249,241,130,96,138,206,143,177,249,72,147,178,249,25,151,179,249,180,249,66,78,42,80,181,249,8,82,225,83,243,102,109,108,202,111,10,115,127,119,98,122,174,130,221,133,2,134,182,249,212,136,99,138,125,139,107,140,183,249,179,146,184,249,19,151,16,152,148,78,13,79,201,79,178,80,72,83,62,84,51,84,218,85,98,88,186,88,103,89,27,90,228,91,159,96,185,249,202,97,86,101,255,101,100,102,167,104,90,108,179,111,207,112,172,113,82,115,125,123,8,135,164,138,50,156,7,159,75,92,131,108,68,115,137,115,58,146,171,110,101,116,31,118,105,122,21,126,10,134,64,81,197,88,193,100,238,116,21,117,112,118,193,127,149,144,205,150,84,153,38,110,230,116,169,122,170,122,229,129,217,134,120,135,27,138,73,90,140,91,155,91,161,104,0,105,99,109,169,115,19,116,44,116,151,120,233,125,235,127,24,129,85,129,158,131,76,140,46,150,17,152,240,102,128,95,250,101,137,103,106,108,139,115,45,80,3,90,106,107,238,119,22,89,108,93,205,93,37,115,79,117,186,249,187,249,229,80,249,81,47,88,45,89,150,89,218,89,229,91,188,249,189,249,162,93,215,98,22,100,147,100,254,100,190,249,220,102,191,249,72,106,192,249,255,113,100,116,193,249,136,122,175,122,71,126,94,126,0,128,112,129,194,249,239,135,129,137,32,139,89,144,195,249,128,144,82,153,126,97,50,107,116,109,31,126,37,137,177,143,209,79,173,80,151,81,199,82,199,87,137,88,185,91,184,94,66,97,149,105,140,109,103,110,182,110,148,113,98,116,40,117,44,117,115,128,56,131,201,132,10,142,148,147,222,147,196,249,142,78,81,79,118,80,42,81,200,83,203,83,243,83,135,91,211,91,36,92,26,97,130,97,244,101,91,114,151,115,64,116,194,118,80,121,145,121,185,121,6,125,189,127,139,130,213,133,94,134,194,143,71,144,245,144,234,145,133,150,232,150,233,150,214,82,103,95,237,101,49,102,47,104,92,113,54,122,193,144,10,152,145,78,197,249,82,106,158,107,144,111,137,113,24,128,184,130,83,133,75,144,149,150,242,150,251,151,26,133,49,155,144,78,138,113,196,150,67,81,159,83,225,84,19,87,18,87,163,87,155,90,196,90,195,91,40,96,63,97,244,99,133,108,57,109,114,110,144,110,48,114,63,115,87,116,209,130,129,136,69,143,96,144,198,249,98,150,88,152,27,157,8,103,138,141,94,146,77,79,73,80,222,80,113,83,13,87,212,89,1,90,9,92,112,97,144,102,45,110,50,114,75,116,239,125,195,128,14,132,102,132,63,133,95,135,91,136,24,137,2,139,85,144,203,151,79,155,115,78,145,79,18,81,106,81,199,249,47,85,169,85,122,91,165,91,124,94,125,94,190,94,160,96,223,96,8,97,9,97,196,99,56,101,9,103,200,249,212,103,218,103,201,249,97,105,98,105,185,108,39,109,202,249,56,110,203,249,225,111,54,115,55,115,204,249,92,116,49,117,205,249,82,118,206,249,207,249,173,125,254,129,56,132,213,136,152,138,219,138,237,138,48,142,66,142,74,144,62,144,122,144,73,145,201,145,110,147,208,249,209,249,9,88,210,249,211,107,137,128,178,128,211,249,212,249,65,81,107,89,57,92,213,249,214,249,100,111,167,115,228,128,7,141,215,249,23,146,143,149,216,249,217,249,218,249,219,249,127,128,14,98,28,112,104,125,141,135,220,249,160,87,105,96,71,97,183,107,190,138,128,146,177,150,89,78,31,84,235,109,45,133,112,150,243,151,238,152,214,99,227,108,145,144,221,81,201,97,186,129,249,157,157,79,26,80,0,81,156,91,15,97,255,97,236,100,5,105,197,107,145,117,227,119,169,127,100,130,143,133,251,135,99,136,188,138,112,139,171,145,140,78,229,78,10,79,221,249,222,249,55,89,232,89,223,249,242,93,27,95,91,95,33,96,224,249,225,249,226,249,227,249,62,114,229,115,228,249,112,117,205,117,229,249,251,121,230,249,12,128,51,128,132,128,225,130,81,131,231,249,232,249,189,140,179,140,135,144,233,249,234,249,244,152,12,153,235,249,236,249,55,112,202,118,202,127,204,127,252,127,26,139,186,78,193,78,3,82,112,83,237,249,189,84,224,86,251,89,197,91,21,95,205,95,110,110,238,249,239,249,106,125,53,131,240,249,147,134,141,138,241,249,109,151,119,151,242,249,243,249,0,78,90,79,126,79,249,88,229,101,162,110,56,144,176,147,185,153,251,78,236,88,138,89,217,89,65,96,244,249,245,249,20,122,246,249,79,131,195,140,101,81,68,83,247,249,248,249,249,249,205,78,105,82,85,91,191,130,212,78,58,82,168,84,201,89,255,89,80,91,87,91,92,91,99,96,72,97,203,110,153,112,110,113,134,115,247,116,181,117,193,120,43,125,5,128,234,129,40,131,23,133,201,133,238,138,199,140,204,150,92,79,250,82,188,86,171,101,40,102,124,112,184,112,53,114,189,125,141,130,76,145,192,150,114,157,113,91,231,104,152,107,122,111,222,118,145,92,171,102,91,111,180,123,42,124,54,136,220,150,8,78,215,78,32,83,52,88,187,88,239,88,108,89,7,92,51,94,132,94,53,95,140,99,178,102,86,103,31,106,163,106,12,107,63,111,70,114,250,249,80,115,139,116,224,122,167,124,120,129,223,129,231,129,138,131,108,132,35,133,148,133,207,133,221,136,19,141,172,145,119,149,156,150,141,81,201,84,40,87,176,91,77,98,80,103,61,104,147,104,61,110,211,110,125,112,33,126,193,136,161,140,9,143,75,159,78,159,45,114,143,123,205,138,26,147,71,79,78,79,50,81,128,84,208,89,149,94,181,98,117,103,110,105,23,106,174,108,26,110,217,114,42,115,189,117,184,123,53,125,231,130,249,131,87,132,247,133,91,138,175,140,135,142,25,144,184,144,206,150,95,159,227,82,10,84,225,90,194,91,88,100,117,101,244,110,196,114,251,249,132,118,77,122,27,123,77,124,62,126,223,127,123,131,43,139,202,140,100,141,225,141,95,142,234,143,249,143,105,144,209,147,67,79,122,79,179,80,104,81,120,81,77,82,106,82,97,88,124,88,96,89,8,92,85,92,219,94,155,96,48,98,19,104,191,107,8,108,177,111,78,113,32,116,48,117,56,117,81,117,114,118,76,123,139,123,173,123,198,123,143,126,110,138,62,143,73,143,63,146,147,146,34,147,43,148,251,150,90,152,107,152,30,153,7,82,42,98,152,98,89,109,100,118,202,122,192,123,118,125,96,83,190,92,151,94,56,111,185,112,152,124,17,151,142,155,222,158,165,99,122,100,118,135,1,78,149,78,173,78,92,80,117,80,72,84,195,89,154,91,64,94,173,94,247,94,129,95,197,96,58,99,63,101,116,101,204,101,118,102,120,102,254,103,104,105,137,106,99,107,64,108,192,109,232,109,31,110,94,110,30,112,161,112,142,115,253,115,58,117,91,119,135,120,142,121,11,122,125,122,190,124,142,125,71,130,2,138,234,138,158,140,45,145,74,145,216,145,102,146,204,146,32,147,6,151,86,151,92,151,2,152,14,159,54,82,145,82,124,85,36,88,29,94,31,95,140,96,208,99,175,104,223,111,109,121,44,123,205,129,186,133,253,136,248,138,68,142,141,145,100,150,155,150,61,151,76,152,74,159,206,79,70,81,203,81,169,82,50,86,20,95,107,95,170,99,205,100,233,101,65,102,250,102,249,102,29,103,157,104,215,104,253,105,21,111,110,111,103,113,229,113,42,114,170,116,58,119,86,121,90,121,223,121,32,122,149,122,151,124,223,124,68,125,112,126,135,128,251,133,164,134,84,138,191,138,153,141,129,142,32,144,109,144,227,145,59,150,213,150,229,156,207,101,7,124,179,141,195,147,88,91,10,92,82,83,217,98,29,115,39,80,151,91,158,95,176,96,107,97,213,104,217,109,46,116,46,122,66,125,156,125,49,126,107,129,42,142,53,142,126,147,24,148,80,79,80,87,230,93,167,94,43,99,106,127,59,78,79,79,143,79,90,80,221,89,196,128,106,84,104,84,254,85,79,89,153,91,222,93,218,94,93,102,49,103,241,103,42,104,232,108,50,109,74,110,141,111,183,112,224,115,135,117,76,124,2,125,44,125,162,125,31,130,219,134,59,138,133,138,112,141,138,142,51,143,49,144,78,145,82,145,68,148,208,153,249,122,165,124,202,79,1,81,198,81,200,87,239,91,251,92,89,102,61,106,90,109,150,110,236,111,12,113,111,117,227,122,34,136,33,144,117,144,203,150,255,153,1,131,45,78,242,78,70,136,205,145,125,83,219,106,107,105,65,108,122,132,158,88,142,97,254,102,239,98,221,112,17,117,199,117,82,126,184,132,73,139,8,141,75,78,234,83,171,84,48,87,64,87,215,95,1,99,7,99,111,100,47,101,232,101,122,102,157,103,179,103,98,107,96,108,154,108,44,111,229,119,37,120,73,121,87,121,25,125,162,128,2,129,243,129,157,130,183,130,24,135,140,138,252,249,4,141,190,141,114,144,244,118,25,122,55,122,84,126,119,128,7,85,212,85,117,88,47,99,34,100,73,102,75,102,109,104,155,105,132,107,37,109,177,110,205,115,104,116,161,116,91,117,185,117,225,118,30,119,139,119,230,121,9,126,29,126,251,129,47,133,151,136,58,138,209,140,235,142,176,143,50,144,173,147,99,150,115,150,7,151,132,79,241,83,234,89,201,90,25,94,78,104,198,116,190,117,233,121,146,122,163,129,237,134,234,140,204,141,237,143,159,101,21,103,253,249,247,87,87,111,221,125,47,143,246,147,198,150,181,95,242,97,132,111,20,78,152,79,31,80,201,83,223,85,111,93,238,93,33,107,100,107,203,120,154,123,254,249,73,142,202,142,110,144,73,99,62,100,64,119,132,122,47,147,127,148,106,159,176,100,175,111,230,113,168,116,218,116,196,122,18,124,130,126,178,124,152,126,154,139,10,141,125,148,16,153,76,153,57,82,223,91,230,100,45,103,46,125,237,80,195,83,121,88,88,97,89,97,250,97,172,101,217,122,146,139,150,139,9,80,33,80,117,82,49,85,60,90,224,94,112,95,52,97,94,101,12,102,54,102,162,102,205,105,196,110,50,111,22,115,33,118,147,122,57,129,89,130,214,131,188,132,181,80,240,87,192,91,232,91,105,95,161,99,38,120,181,125,220,131,33,133,199,145,245,145,138,81,245,103,86,123,172,140,196,81,187,89,189,96,85,134,28,80,255,249,84,82,58,92,125,97,26,98,211,98,242,100,165,101,204,110,32,118,10,129,96,142,95,150,187,150,223,78,67,83,152,85,41,89,221,93,197,100,201,108,250,109,148,115,127,122,27,130,166,133,228,140,16,142,119,144,231,145,225,149,33,150,198,151,248,81,242,84,134,85,185,95,164,100,136,111,180,125,31,143,77,143,53,148,201,80,22,92,190,108,251,109,27,117,187,119,61,124,100,124,121,138,194,138,30,88,190,89,22,94,119,99,82,114,138,117,107,119,220,138,188,140,18,143,243,94,116,102,248,109,125,128,193,131,203,138,81,151,214,155,0,250,67,82,255,102,149,109,239,110,224,125,230,138,46,144,94,144,212,154,29,82,127,82,232,84,148,97,132,98,219,98,162,104,18,105,90,105,53,106,146,112,38,113,93,120,1,121,14,121,210,121,13,122,150,128,120,130,213,130,73,131,73,133,130,140,133,141,98,145,139,145,174,145,195,79,209,86,237,113,215,119,0,135,248,137,248,91,214,95,81,103,168,144,226,83,90,88,245,91,164,96,129,97,96,100,61,126,112,128,37,133,131,146,174,100,172,80,20,93,0,103,156,88,189,98,168,99,14,105,120,105,30,106,107,110,186,118,203,121,187,130,41,132,207,138,168,141,253,143,18,145,75,145,156,145,16,147,24,147,154,147,219,150,54,154,13,156,17,78,92,117,93,121,250,122,81,123,201,123,46,126,196,132,89,142,116,142,248,142,16,144,37,102,63,105,67,116,250,81,46,103,220,158,69,81,224,95,150,108,242,135,93,136,119,136,180,96,181,129,3,132,5,141,214,83,57,84,52,86,54,90,49,92,138,112,224,127,90,128,6,129,237,129,163,141,137,145,95,154,242,157,116,80,196,78,160,83,251,96,44,110,100,92,136,79,36,80,228,85,217,92,95,94,101,96,148,104,187,108,196,109,190,113,212,117,244,117,97,118,26,122,73,122,199,125,251,125,110,127,244,129,169,134,28,143,201,150,179,153,82,159,71,82,197,82,237,152,170,137,3,78,210,103,6,111,181,79,226,91,149,103,136,108,120,109,27,116,39,120,221,145,124,147,196,135,228,121,49,122,235,95,214,78,164,84,62,85,174,88,165,89,240,96,83,98,214,98,54,103,85,105,53,130,64,150,177,153,221,153,44,80,83,83,68,85,124,87,1,250,88,98,2,250,226,100,107,102,221,103,193,111,239,111,34,116,56,116,23,138,56,148,81,84,6,86,102,87,72,95,154,97,78,107,88,112,173,112,187,125,149,138,106,89,43,129,162,99,8,119,61,128,170,140,84,88,45,100,187,105,149,91,17,94,111,110,3,250,105,133,76,81,240,83,42,89,32,96,75,97,134,107,112,108,240,108,30,123,206,128,212,130,198,141,176,144,177,152,4,250,199,100,164,111,145,100,4,101,78,81,16,84,31,87,14,138,95,97,118,104,5,250,219,117,82,123,113,125,26,144,6,88,204,105,127,129,42,137,0,144,57,152,120,80,87,89,172,89,149,98,15,144,42,155,93,97,121,114,214,149,97,87,70,90,244,93,138,98,173,100,250,100,119,103,226,108,62,109,44,114,54,116,52,120,119,127,173,130,219,141,23,152,36,82,66,87,127,103,72,114,227,116,169,140,166,143,17,146,42,150,107,81,237,83,76,99,105,79,4,85,150,96,87,101,155,108,127,109,76,114,253,114,23,122,135,137,157,140,109,95,142,111,249,112,168,129,14,97,191,79,79,80,65,98,71,114,199,123,232,125,233,127,77,144,173,151,25,154,182,140,106,87,115,94,176,103,13,132,85,138,32,84,22,91,99,94,226,94,10,95,131,101,186,128,61,133,137,149,91,150,72,79,5,83,13,83,15,83,134,84,250,84,3,87,3,94,22,96,155,98,177,98,85,99,6,250,225,108,102,109,177,117,50,120,222,128,47,129,222,130,97,132,178,132,141,136,18,137,11,144,234,146,253,152,145,155,69,94,180,102,221,102,17,112,6,114,7,250,245,79,125,82,106,95,83,97,83,103,25,106,2,111,226,116,104,121,104,136,121,140,199,152,196,152,67,154,193,84,31,122,83,105,247,138,74,140,168,152,174,153,124,95,171,98,178,117,174,118,171,136,127,144,66,150,57,83,60,95,197,95,204,108,204,115,98,117,139,117,70,123,254,130,157,153,79,78,60,144,11,78,85,79,166,83,15,89,200,94,48,102,179,108,85,116,119,131,102,135,192,140,80,144,30,151,21,156,209,88,120,91,80,134,20,139,180,157,210,91,104,96,141,96,241,101,87,108,34,111,163,111,26,112,85,127,240,127,145,149,146,149,80,150,211,151,114,82,68,143,253,81,43,84,184,84,99,85,138,85,187,106,181,109,216,125,102,130,156,146,119,150,121,158,8,84,200,84,210,118,228,134,164,149,212,149,92,150,162,78,9,79,238,89,230,90,247,93,82,96,151,98,109,103,65,104,134,108,47,110,56,127,155,128,42,130,8,250,9,250,5,152,165,78,85,80,179,84,147,87,90,89,105,91,179,91,200,97,119,105,119,109,35,112,249,135,227,137,114,138,231,138,130,144,237,153,184,154,190,82,56,104,22,80,120,94,79,103,71,131,76,136,171,78,17,84,174,86,230,115,21,145,255,151,9,153,87,153,153,153,83,86,159,88,91,134,49,138,178,97,246,106,123,115,210,142,71,107,170,150,87,154,85,89,0,114,107,141,105,151,212,79,244,92,38,95,248,97,91,102,235,108,171,112,132,115,185,115,254,115,41,119,77,119,67,125,98,125,35,126,55,130,82,136,10,250,226,140,73,146,111,152,81,91,116,122,64,136,1,152,204,90,224,79,84,83,62,89,253,92,62,99,121,109,249,114,5,129,7,129,162,131,207,146,48,152,168,78,68,81,17,82,139,87,98,95,194,108,206,110,5,112,80,112,175,112,146,113,233,115,105,116,74,131,162,135,97,136,8,144,162,144,163,147,168,153,110,81,87,95,224,96,103,97,179,102,89,133,74,142,175,145,139,151,78,78,146,78,124,84,213,88,250,88,125,89,181,92,39,95,54,98,72,98,10,102,103,102,235,107,105,109,207,109,86,110,248,110,148,111,224,111,233,111,93,112,208,114,37,116,90,116,224,116,147,118,92,121,202,124,30,126,225,128,166,130,107,132,191,132,78,134,95,134,116,135,119,139,106,140,172,147,0,152,101,152,209,96,22,98,119,145,90,90,15,102,247,109,62,110,63,116,66,155,253,95,218,96,15,123,196,84,24,95,94,108,211,108,42,109,216,112,5,125,121,134,12,138,59,157,22,83,140,84,5,91,58,106,107,112,117,117,141,121,190,121,177,130,239,131,113,138,65,139,168,140,116,151,11,250,244,100,43,101,186,120,187,120,107,122,56,78,154,85,80,89,166,91,123,94,163,96,219,99,97,107,101,102,83,104,25,110,101,113,176,116,8,125,132,144,105,154,37,156,59,109,209,110,62,115,65,140,202,149,240,81,76,94,168,95,77,96,246,96,48,97,76,97,67,102,68,102,165,105,193,108,95,110,201,110,98,111,76,113,156,116,135,118,193,123,39,124,82,131,87,135,81,144,141,150,195,158,47,83,222,86,251,94,138,95,98,96,148,96,247,97,102,102,3,103,156,106,238,109,174,111,112,112,106,115,106,126,190,129,52,131,212,134,168,138,196,140,131,82,114,115,150,91,107,106,4,148,238,84,134,86,93,91,72,101,133,101,201,102,159,104,141,109,198,109,59,114,180,128,117,145,77,154,175,79,25,80,154,83,14,84,60,84,137,85,197,85,63,94,140,95,61,103,102,113,221,115,5,144,219,82,243,82,100,88,206,88,4,113,143,113,251,113,176,133,19,138,136,102,168,133,167,85,132,102,74,113,49,132,73,83,153,85,193,107,89,95,189,95,238,99,137,102,71,113,241,138,29,143,190,158,17,79,58,100,203,112,102,117,103,134,100,96,78,139,248,157,71,81,246,81,8,83,54,109,248,128,209,158,21,102,35,107,152,112,213,117,3,84,121,92,7,125,22,138,32,107,61,107,70,107,56,84,112,96,61,109,213,127,8,130,214,80,222,81,156,85,107,86,205,86,236,89,9,91,12,94,153,97,152,97,49,98,94,102,230,102,153,113,185,113,186,113,167,114,167,121,0,122,178,127,112,138,0,0,0,0,13,0,0,0,9,0,0,0,6,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,6,14,43,52,1,1,1,1,3,1,2,16,1,0,0,0,0,1,2,3,4,5,6,6,7,2,1,0,10,10,4,5,6,7,8,9,10,11,12,9,14,11,12,13,14,15,16,13,16,17,18,19,20,21,22,22,23,23,24,24,25,25,26,26,27,27,27,28,28,28,29,29,29,30,30,30,31,31,31,31,32,32,32,32,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,0,0,0,0,0,1,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,14,15,15,15,16,16,16,16,17,17,17,17,17,18,18,18,18,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,248,154,34,0,108,0,0,0,144,124,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,245,33,0,80,204,33,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,40,166,33,0,128,136,33,0,12,0,0,0,5,0,0,0,136,92,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,184,30,33,0,160,253,32,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,21,31,0,108,0,0,0,0,110,13,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,1,48,2,48,12,255,14,255,251,48,26,255,27,255,31,255,1,255,155,48,156,48,180,0,64,255,168,0,62,255,227,255,63,255,253,48,254,48,157,48,158,48,3,48,221,78,5,48,6,48,7,48,252,48,21,32,16,32,15,255,92,0,28,48,22,32,92,255,38,32,37,32,24,32,25,32,28,32,29,32,8,255,9,255,20,48,21,48,59,255,61,255,91,255,93,255,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,16,48,17,48,11,255,18,34,177,0,215,0,247,0,29,255,96,34,28,255,30,255,102,34,103,34,30,34,52,34,66,38,64,38,176,0,50,32,51,32,3,33,229,255,4,255,162,0,163,0,5,255,3,255,6,255,10,255,32,255,167,0,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,189,37,188,37,59,32,18,48,146,33,144,33,145,33,147,33,19,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,34,11,34,134,34,135,34,130,34,131,34,42,34,41,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,34,40,34,172,0,210,33,212,33,0,34,3,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,34,165,34,18,35,2,34,7,34,97,34,82,34,106,34,107,34,26,34,61,34,29,34,53,34,43,34,44,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,33,48,32,111,38,109,38,106,38,32,32,33,32,182,0,0,0,0,0,0,0,0,0,239,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,0,0,0,0,0,0,0,0,0,0,0,0,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,0,0,0,0,0,0,0,0,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,2,37,12,37,16,37,24,37,20,37,28,37,44,37,36,37,52,37,60,37,1,37,3,37,15,37,19,37,27,37,23,37,35,37,51,37,43,37,59,37,75,37,32,37,47,37,40,37,55,37,63,37,29,37,48,37,37,37,56,37,66,37], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+871784);
/* memory initializer */ allocate([156,78,22,85,3,90,63,150,192,84,27,97,40,99,246,89,34,144,117,132,28,131,80,122,170,96,225,99,37,110,237,101,102,132,166,130,245,155,147,104,39,87,161,101,113,98,155,91,208,89,123,134,244,152,98,125,190,125,142,155,22,98,159,124,183,136,137,91,181,94,9,99,151,102,72,104,199,149,141,151,79,103,229,78,10,79,77,79,157,79,73,80,242,86,55,89,212,89,1,90,9,92,223,96,15,97,112,97,19,102,5,105,186,112,79,117,112,117,251,121,173,125,239,125,195,128,14,132,99,136,2,139,85,144,122,144,59,83,149,78,165,78,223,87,178,128,193,144,239,120,0,78,241,88,162,110,56,144,50,122,40,131,139,130,47,156,65,81,112,83,189,84,225,84,224,86,251,89,21,95,242,152,235,109,228,128,45,133,98,150,112,150,160,150,251,151,11,84,243,83,135,91,207,112,189,127,194,143,232,150,111,83,92,157,186,122,17,78,147,120,252,129,38,110,24,86,4,85,29,107,26,133,59,156,229,89,169,83,102,109,220,116,143,149,66,86,145,78,75,144,242,150,79,131,12,153,225,83,182,85,48,91,113,95,32,102,243,102,4,104,56,108,243,108,41,109,91,116,200,118,78,122,52,152,241,130,91,136,96,138,237,146,178,109,171,117,202,118,197,153,166,96,1,139,138,141,178,149,142,105,173,83,134,81,18,87,48,88,68,89,180,91,246,94,40,96,169,99,244,99,191,108,20,111,142,112,20,113,89,113,213,113,63,115,1,126,118,130,209,130,151,133,96,144,91,146,27,157,105,88,188,101,90,108,37,117,249,81,46,89,101,89,128,95,220,95,188,98,250,101,42,106,39,107,180,107,139,115,193,127,86,137,44,157,14,157,196,158,161,92,150,108,123,131,4,81,75,92,182,97,198,129,118,104,97,114,89,78,250,79,120,83,105,96,41,110,79,122,243,151,11,78,22,83,238,78,85,79,61,79,161,79,115,79,160,82,239,83,9,86,15,89,193,90,182,91,225,91,209,121,135,102,156,103,182,103,76,107,179,108,107,112,194,115,141,121,190,121,60,122,135,123,177,130,219,130,4,131,119,131,239,131,211,131,102,135,178,138,41,86,168,140,230,143,78,144,30,151,138,134,196,79,232,92,17,98,89,114,59,117,229,129,189,130,254,134,192,140,197,150,19,153,213,153,203,78,26,79,227,137,222,86,74,88,202,88,251,94,235,95,42,96,148,96,98,96,208,97,18,98,208,98,57,101,65,155,102,102,176,104,119,109,112,112,76,117,134,118,117,125,165,130,249,135,139,149,142,150,157,140,241,81,190,82,22,89,179,84,179,91,22,93,104,97,130,105,175,109,141,120,203,132,87,136,114,138,167,147,184,154,108,109,168,153,217,134,163,87,255,103,206,134,14,146,131,82,135,86,4,84,211,94,225,98,185,100,60,104,56,104,187,107,114,115,186,120,107,122,154,137,210,137,107,141,3,143,237,144,163,149,148,150,105,151,102,91,179,92,125,105,77,152,78,152,155,99,32,123,43,106,127,106,182,104,13,156,95,111,114,82,157,85,112,96,236,98,59,109,7,110,209,110,91,132,16,137,68,143,20,78,57,156,246,83,27,105,58,106,132,151,42,104,92,81,195,122,178,132,220,145,140,147,91,86,40,157,34,104,5,131,49,132,165,124,8,82,197,130,230,116,126,78,131,79,160,81,210,91,10,82,216,82,231,82,251,93,154,85,42,88,230,89,140,91,152,91,219,91,114,94,121,94,163,96,31,97,99,97,190,97,219,99,98,101,209,103,83,104,250,104,62,107,83,107,87,108,34,111,151,111,69,111,176,116,24,117,227,118,11,119,255,122,161,123,33,124,233,125,54,127,240,127,157,128,102,130,158,131,179,137,204,138,171,140,132,144,81,148,147,149,145,149,162,149,101,150,211,151,40,153,24,130,56,78,43,84,184,92,204,93,169,115,76,118,60,119,169,92,235,127,11,141,193,150,17,152,84,152,88,152,1,79,14,79,113,83,156,85,104,86,250,87,71,89,9,91,196,91,144,92,12,94,126,94,204,95,238,99,58,103,215,101,226,101,31,103,203,104,196,104,95,106,48,94,197,107,23,108,125,108,127,117,72,121,99,91,0,122,0,125,189,95,143,137,24,138,180,140,119,141,204,142,29,143,226,152,14,154,60,155,128,78,125,80,0,81,147,89,156,91,47,98,128,98,236,100,58,107,160,114,145,117,71,121,169,127,251,135,188,138,112,139,172,99,202,131,160,151,9,84,3,84,171,85,84,104,88,106,112,138,39,120,117,103,205,158,116,83,162,91,26,129,80,134,6,144,24,78,69,78,199,78,17,79,202,83,56,84,174,91,19,95,37,96,81,101,61,103,66,108,114,108,227,108,120,112,3,116,118,122,174,122,8,123,26,125,254,124,102,125,231,101,91,114,187,83,69,92,232,93,210,98,224,98,25,99,32,110,90,134,49,138,221,141,248,146,1,111,166,121,90,155,168,78,171,78,172,78,155,79,160,79,209,80,71,81,246,122,113,81,246,81,84,83,33,83,127,83,235,83,172,85,131,88,225,92,55,95,74,95,47,96,80,96,109,96,31,99,89,101,75,106,193,108,194,114,237,114,239,119,248,128,5,129,8,130,78,133,247,144,225,147,255,151,87,153,90,154,240,78,221,81,45,92,129,102,109,105,64,92,242,102,117,105,137,115,80,104,129,124,197,80,228,82,71,87,254,93,38,147,164,101,35,107,61,107,52,116,129,121,189,121,75,123,202,125,185,130,204,131,127,136,95,137,57,139,209,143,209,145,31,84,128,146,93,78,54,80,229,83,58,83,215,114,150,115,233,119,230,130,175,142,198,153,200,153,210,153,119,81,26,97,94,134,176,85,122,122,118,80,211,91,71,144,133,150,50,78,219,106,231,145,81,92,72,92,152,99,159,122,147,108,116,151,97,143,170,122,138,113,136,150,130,124,23,104,112,126,81,104,108,147,242,82,27,84,171,133,19,138,164,127,205,142,225,144,102,83,136,136,65,121,194,79,190,80,17,82,68,81,83,85,45,87,234,115,139,87,81,89,98,95,132,95,117,96,118,97,103,97,169,97,178,99,58,100,108,101,111,102,66,104,19,110,102,117,61,122,251,124,76,125,153,125,75,126,107,127,14,131,74,131,205,134,8,138,99,138,102,139,253,142,26,152,143,157,184,130,206,143,232,155,135,82,31,98,131,100,192,111,153,150,65,104,145,80,32,107,122,108,84,111,116,122,80,125,64,136,35,138,8,103,246,78,57,80,38,80,101,80,124,81,56,82,99,82,167,85,15,87,5,88,204,90,250,94,178,97,248,97,243,98,114,99,28,105,41,106,125,114,172,114,46,115,20,120,111,120,121,125,12,119,169,128,139,137,25,139,226,140,210,142,99,144,117,147,122,150,85,152,19,154,120,158,67,81,159,83,179,83,123,94,38,95,27,110,144,110,132,115,254,115,67,125,55,130,0,138,250,138,80,150,78,78,11,80,228,83,124,84,250,86,209,89,100,91,241,93,171,94,39,95,56,98,69,101,175,103,86,110,208,114,202,124,180,136,161,128,225,128,240,131,78,134,135,138,232,141,55,146,199,150,103,152,19,159,148,78,146,78,13,79,72,83,73,84,62,84,47,90,140,95,161,95,159,96,167,104,142,106,90,116,129,120,158,138,164,138,119,139,144,145,94,78,201,155,164,78,124,79,175,79,25,80,22,80,73,81,108,81,159,82,185,82,254,82,154,83,227,83,17,84,14,84,137,85,81,87,162,87,125,89,84,91,93,91,143,91,229,93,231,93,247,93,120,94,131,94,154,94,183,94,24,95,82,96,76,97,151,98,216,98,167,99,59,101,2,102,67,102,244,102,109,103,33,104,151,104,203,105,95,108,42,109,105,109,47,110,157,110,50,117,135,118,108,120,63,122,224,124,5,125,24,125,94,125,177,125,21,128,3,128,175,128,177,128,84,129,143,129,42,130,82,131,76,136,97,136,27,139,162,140,252,140,202,144,117,145,113,146,63,120,252,146,164,149,77,150,5,152,153,153,216,154,59,157,91,82,171,82,247,83,8,84,213,88,247,98,224,111,106,140,95,143,185,158,75,81,59,82,74,84,253,86,64,122,119,145,96,157,210,158,68,115,9,111,112,129,17,117,253,95,218,96,168,154,219,114,188,143,100,107,3,152,202,78,240,86,100,87,190,88,90,90,104,96,199,97,15,102,6,102,57,104,177,104,247,109,213,117,58,125,110,130,66,155,155,78,80,79,201,83,6,85,111,93,230,93,238,93,251,103,153,108,115,116,2,120,80,138,150,147,223,136,80,87,167,94,43,99,181,80,172,80,141,81,0,103,201,84,94,88,187,89,176,91,105,95,77,98,161,99,61,104,115,107,8,110,125,112,199,145,128,114,21,120,38,120,109,121,142,101,48,125,220,131,193,136,9,143,155,150,100,82,40,87,80,103,106,127,161,140,180,81,66,87,42,150,58,88,138,105,180,128,178,84,14,93,252,87,149,120,250,157,92,79,74,82,139,84,62,100,40,102,20,103,245,103,132,122,86,123,34,125,47,147,92,104,173,155,57,123,25,83,138,81,55,82,223,91,246,98,174,100,230,100,45,103,186,107,169,133,209,150,144,118,214,155,76,99,6,147,171,155,191,118,82,102,9,78,152,80,194,83,113,92,232,96,146,100,99,101,95,104,230,113,202,115,35,117,151,123,130,126,149,134,131,139,219,140,120,145,16,153,172,101,171,102,139,107,213,78,212,78,58,79,127,79,58,82,248,83,242,83,227,85,219,86,235,88,203,89,201,89,255,89,80,91,77,92,2,94,43,94,215,95,29,96,7,99,47,101,92,91,175,101,189,101,232,101,157,103,98,107,123,107,15,108,69,115,73,121,193,121,248,124,25,125,43,125,162,128,2,129,243,129,150,137,94,138,105,138,102,138,140,138,238,138,199,140,220,140,204,150,252,152,111,107,139,78,60,79,141,79,80,81,87,91,250,91,72,97,1,99,66,102,33,107,203,110,187,108,62,114,189,116,212,117,193,120,58,121,12,128,51,128,234,129,148,132,158,143,80,108,127,158,15,95,88,139,43,157,250,122,248,142,141,91,235,150,3,78,241,83,247,87,49,89,201,90,164,91,137,96,127,110,6,111,190,117,234,140,159,91,0,133,224,123,114,80,244,103,157,130,97,92,74,133,30,126,14,130,153,81,4,92,104,99,102,141,156,101,110,113,62,121,23,125,5,128,29,139,202,142,110,144,199,134,170,144,31,80,250,82,58,92,83,103,124,112,53,114,76,145,200,145,43,147,229,130,194,91,49,95,249,96,59,78,214,83,136,91,75,98,49,103,138,107,233,114,224,115,46,122,107,129,163,141,82,145,150,153,18,81,215,83,106,84,255,91,136,99,57,106,172,125,0,151,218,86,206,83,104,84,151,91,49,92,222,93,238,79,1,97,254,98,50,109,192,121,203,121,66,125,77,126,210,127,237,129,31,130,144,132,70,136,114,137,144,139,116,142,47,143,49,144,75,145,108,145,198,150,156,145,192,78,79,79,69,81,65,83,147,95,14,98,212,103,65,108,11,110,99,115,38,126,205,145,131,146,212,83,25,89,191,91,209,109,93,121,46,126,155,124,126,88,159,113,250,81,83,136,240,143,202,79,251,92,37,102,172,119,227,122,28,130,255,153,198,81,170,95,236,101,111,105,137,107,243,109,150,110,100,111,254,118,20,125,225,93,117,144,135,145,6,152,230,81,29,82,64,98,145,102,217,102,26,110,182,94,210,125,114,127,248,102,175,133,247,133,248,138,169,82,217,83,115,89,143,94,144,95,85,96,228,146,100,150,183,80,31,81,221,82,32,83,71,83,236,83,232,84,70,85,49,85,23,86,104,89,190,89,60,90,181,91,6,92,15,92,17,92,26,92,132,94,138,94,224,94,112,95,127,98,132,98,219,98,140,99,119,99,7,102,12,102,45,102,118,102,126,103,162,104,31,106,53,106,188,108,136,109,9,110,88,110,60,113,38,113,103,113,199,117,1,119,93,120,1,121,101,121,240,121,224,122,17,123,167,124,57,125,150,128,214,131,139,132,73,133,93,136,243,136,31,138,60,138,84,138,115,138,97,140,222,140,164,145,102,146,126,147,24,148,156,150,152,151,10,78,8,78,30,78,87,78,151,81,112,82,206,87,52,88,204,88,34,91,56,94,197,96,254,100,97,103,86,103,68,109,182,114,115,117,99,122,184,132,114,139,184,145,32,147,49,86,244,87,254,152,237,98,13,105,150,107,237,113,84,126,119,128,114,130,230,137,223,152,85,135,177,143,59,92,56,79,225,79,181,79,7,85,32,90,221,91,233,91,195,95,78,97,47,99,176,101,75,102,238,104,155,105,120,109,241,109,51,117,185,117,31,119,94,121,230,121,51,125,227,129,175,130,170,133,170,137,58,138,171,142,155,143,50,144,221,145,7,151,186,78,193,78,3,82,117,88,236,88,11,92,26,117,61,92,78,129,10,138,197,143,99,150,109,151,37,123,207,138,8,152,98,145,243,86,168,83,23,144,57,84,130,87,37,94,168,99,52,108,138,112,97,119,139,124,224,127,112,136,66,144,84,145,16,147,24,147,143,150,94,116,196,154,7,93,105,93,112,101,162,103,168,141,219,150,110,99,73,103,25,105,197,131,23,152,192,150,254,136,132,111,122,100,248,91,22,78,44,112,93,117,47,102,196,81,54,82,226,82,211,89,129,95,39,96,16,98,63,101,116,101,31,102,116,102,242,104,22,104,99,107,5,110,114,114,31,117,219,118,190,124,86,128,240,88,253,136,127,137,160,138,147,138,203,138,29,144,146,145,82,151,89,151,137,101,14,122,6,129,187,150,45,94,220,96,26,98,165,101,20,102,144,103,243,119,77,122,77,124,62,126,10,129,172,140,100,141,225,141,95,142,169,120,7,82,217,98,165,99,66,100,152,98,45,138,131,122,192,123,172,138,234,150,118,125,12,130,73,135,217,78,72,81,67,83,96,83,163,91,2,92,22,92,221,93,38,98,71,98,176,100,19,104,52,104,201,108,69,109,23,109,211,103,92,111,78,113,125,113,203,101,127,122,173,123,218,125,74,126,168,127,122,129,27,130,57,130,166,133,110,138,206,140,245,141,120,144,119,144,173,146,145,146,131,149,174,155,77,82,132,85,56,111,54,113,104,81,133,121,85,126,179,129,206,124,76,86,81,88,168,92,170,99,254,102,253,102,90,105,217,114,143,117,142,117,14,121,86,121,223,121,151,124,32,125,68,125,7,134,52,138,59,150,97,144,32,159,231,80,117,82,204,83,226,83,9,80,170,85,238,88,79,89,61,114,139,91,100,92,29,83,227,96,243,96,92,99,131,99,63,99,187,99,205,100,233,101,249,102,227,93,205,105,253,105,21,111,229,113,137,78,233,117,248,118,147,122,223,124,207,125,156,125,97,128,73,131,88,131,108,132,188,132,251,133,197,136,112,141,1,144,109,144,151,147,28,151,18,154,207,80,151,88,142,97,211,129,53,133,8,141,32,144,195,79,116,80,71,82,115,83,111,96,73,99,95,103,44,110,179,141,31,144,215,79,94,92,202,140,207,101,154,125,82,83,150,136,118,81,195,99,88,91,107,91,10,92,13,100,81,103,92,144,214,78,26,89,42,89,112,108,81,138,62,85,21,88,165,89,240,96,83,98,193,103,53,130,85,105,64,150,196,153,40,154,83,79,6,88,254,91,16,128,177,92,47,94,133,95,32,96,75,97,52,98,255,102,240,108,222,110,206,128,127,129,212,130,139,136,184,140,0,144,46,144,138,150,219,158,219,155,227,78,240,83,39,89,44,123,141,145,76,152,249,157,221,110,39,112,83,83,68,85,133,91,88,98,158,98,211,98,162,108,239,111,34,116,23,138,56,148,193,111,254,138,56,131,231,81,248,134,234,83,233,83,70,79,84,144,176,143,106,89,49,129,253,93,234,122,191,143,218,104,55,140,248,114,72,156,61,106,176,138,57,78,88,83,6,86,102,87,197,98,162,99,230,101,78,107,225,109,91,110,173,112,237,119,239,122,170,123,187,125,61,128,198,128,203,134,149,138,91,147,227,86,199,88,62,95,173,101,150,102,128,106,181,107,55,117,199,138,36,80,229,119,48,87,27,95,101,96,122,102,96,108,244,117,26,122,110,127,244,129,24,135,69,144,179,153,201,123,92,117,249,122,81,123,196,132,16,144,233,121,146,122,54,131,225,90,64,119,45,78,242,78,153,91,224,95,189,98,60,102,241,103,232,108,107,134,119,136,59,138,78,145,243,146,208,153,23,106,38,112,42,115,231,130,87,132,175,140,1,78,70,81,203,81,139,85,245,91,22,94,51,94,129,94,20,95,53,95,107,95,180,95,242,97,17,99,162,102,29,103,110,111,82,114,58,117,58,119,116,128,57,129,120,129,118,135,191,138,220,138,133,141,243,141,154,146,119,149,2,152,229,156,197,82,87,99,244,118,21,103,136,108,205,115,195,140,174,147,115,150,37,109,156,88,14,105,204,105,253,143,154,147,219,117,26,144,90,88,2,104,180,99,251,105,67,79,44,111,216,103,187,143,38,133,180,125,84,147,63,105,112,111,106,87,247,88,44,91,44,125,42,114,10,84,227,145,180,157,173,78,78,79,92,80,117,80,67,82,158,140,72,84,36,88,154,91,29,94,149,94,173,94,247,94,31,95,140,96,181,98,58,99,208,99,175,104,64,108,135,120,142,121,11,122,224,125,71,130,2,138,230,138,68,142,19,144,184,144,45,145,216,145,14,159,229,108,88,100,226,100,117,101,244,110,132,118,27,123,105,144,209,147,186,110,242,84,185,95,164,100,77,143,237,143,68,146,120,81,107,88,41,89,85,92,151,94,251,109,143,126,28,117,188,140,226,142,91,152,185,112,29,79,191,107,177,111,48,117,251,150,78,81,16,84,53,88,87,88,172,89,96,92,146,95,151,101,92,103,33,110,123,118,223,131,237,140,20,144,253,144,77,147,37,120,58,120,170,82,166,94,31,87,116,89,18,96,18,80,90,81,172,81,205,81,0,82,16,85,84,88,88,88,87,89,149,91,246,92,139,93,188,96,149,98,45,100,113,103,67,104,188,104,223,104,215,118,216,109,111,110,155,109,111,112,200,113,83,95,216,117,119,121,73,123,84,123,82,123,214,124,113,125,48,82,99,132,105,133,228,133,14,138,4,139,70,140,15,142,3,144,15,144,25,148,118,150,45,152,48,154,216,149,205,80,213,82,12,84,2,88,14,92,167,97,158,100,30,109,179,119,229,122,244,128,4,132,83,144,133,146,224,92,7,157,63,83,151,95,179,95,156,109,121,114,99,119,191,121,228,123,210,107,236,114,173,138,3,104,97,106,248,81,129,122,52,105,74,92,246,156,235,130,197,91,73,145,30,112,120,86,111,92,199,96,102,101,140,108,90,140,65,144,19,152,81,84,199,102,13,146,72,89,163,144,133,81,77,78,234,81,153,133,14,139,88,112,122,99,75,147,98,105,180,153,4,126,119,117,87,83,96,105,223,142,227,150,93,108,140,78,60,92,16,95,233,143,2,83,209,140,137,128,121,134,255,94,229,101,115,78,101,81,130,89,63,92,238,151,251,78,138,89,205,95,141,138,225,111,176,121,98,121,231,91,113,132,43,115,177,113,116,94,245,95,123,99,154,100,195,113,152,124,67,78,252,94,75,78,220,87,162,86,169,96,195,111,13,125,253,128,51,129,191,129,178,143,151,137,164,134,244,93,138,98,173,100,135,137,119,103,226,108,62,109,54,116,52,120,70,90,117,127,173,130,172,153,243,79,195,94,221,98,146,99,87,101,111,103,195,118,76,114,204,128,186,128,41,143,77,145,13,80,249,87,146,90,133,104,115,105,100,113,253,114,183,140,242,88,224,140,106,150,25,144,127,135,228,121,231,119,41,132,47,79,101,82,90,83,205,98,207,103,202,108,125,118,148,123,149,124,54,130,132,133,235,143,221,102,32,111,6,114,27,126,171,131,193,153,166,158,253,81,177,123,114,120,184,123,135,128,72,123,232,106,97,94,140,128,81,117,96,117,107,81,98,146,140,110,122,118,151,145,234,154,16,79,112,127,156,98,79,123,165,149,233,156,122,86,89,88,228,134,188,150,52,79,36,82,74,83,205,83,219,83,6,94,44,100,145,101,127,103,62,108,78,108,72,114,175,114,237,115,84,117,65,126,44,130,233,133,169,140,196,123,198,145,105,113,18,152,239,152,61,99,105,102,106,117,228,118,208,120,67,133,238,134,42,83,81,83,38,84,131,89,135,94,124,95,178,96,73,98,121,98,171,98,144,101,212,107,204,108,178,117,174,118,145,120,216,121,203,125,119,127,165,128,171,136,185,138,187,140,127,144,94,151,219,152,11,106,56,124,153,80,62,92,174,95,135,103,216,107,53,116,9,119,142,127,59,159,202,103,23,122,57,83,139,117,237,154,102,95,157,129,241,131,152,128,60,95,197,95,98,117,70,123,60,144,103,104,235,89,155,90,16,125,126,118,44,139,245,79,106,95,25,106,55,108,2,111,226,116,104,121,104,136,85,138,121,140,223,94,207,99,197,117,210,121,215,130,40,147,242,146,156,132,237,134,45,156,193,84,108,95,140,101,92,109,21,112,167,140,211,140,59,152,79,101,246,116,13,78,216,78,224,87,43,89,102,90,204,91,168,81,3,94,156,94,22,96,118,98,119,101,167,101,110,102,110,109,54,114,38,123,80,129,154,129,153,130,92,139,160,140,230,140,116,141,28,150,68,150,174,79,171,100,102,107,30,130,97,132,106,133,232,144,1,92,83,105,168,152,122,132,87,133,15,79,111,82,169,95,69,94,13,103,143,121,121,129,7,137,134,137,245,109,23,95,85,98,184,108,207,78,105,114,146,155,6,82,59,84,116,86,179,88,164,97,110,98,26,113,110,89,137,124,222,124,27,125,240,150,135,101,94,128,25,78,117,79,117,81,64,88,99,94,115,94,10,95,196,103,38,78,61,133,137,149,91,150,115,124,1,152,251,80,193,88,86,118,167,120,37,82,165,119,17,133,134,123,79,80,9,89,71,114,199,123,232,125,186,143,212,143,77,144,191,79,201,82,41,90,1,95,173,151,221,79,23,130,234,146,3,87,85,99,105,107,43,117,220,136,20,143,66,122,223,82,147,88,85,97,10,98,174,102,205,107,63,124,233,131,35,80,248,79,5,83,70,84,49,88,73,89,157,91,240,92,239,92,41,93,150,94,177,98,103,99,62,101,185,101,11,103,213,108,225,108,249,112,50,120,43,126,222,128,179,130,12,132,236,132,2,135,18,137,42,138,74,140,166,144,210,146,253,152,243,156,108,157,79,78,161,78,141,80,86,82,74,87,168,89,61,94,216,95,217,95,63,98,180,102,27,103,208,103,210,104,146,81,33,125,170,128,168,129,0,139,140,140,191,140,126,146,50,150,32,84,44,152,23,83,213,80,92,83,168,88,178,100,52,103,103,114,102,119,70,122,230,145,195,82,161,108,134,107,0,88,76,94,84,89,44,103,251,127,225,81,198,118,105,100,232,120,84,155,187,158,203,87,185,89,39,102,154,103,206,107,233,84,217,105,85,94,156,129,149,103,170,155,254,103,82,156,93,104,166,78,227,79,200,83,185,98,43,103,171,108,196,143,173,79,109,126,191,158,7,78,98,97,128,110,43,111,19,133,115,84,42,103,69,155,243,93,149,123,172,92,198,91,28,135,74,110,209,132,20,122,8,129,153,89,141,124,17,108,32,119,217,82,34,89,33,113,95,114,219,119,39,151,97,157,11,105,127,90,24,90,165,81,13,84,125,84,14,102,223,118,247,143,152,146,244,156,234,89,93,114,197,110,77,81,201,104,191,125,236,125,98,151,186,158,120,100,33,106,2,131,132,89,95,91,219,107,27,115,242,118,178,125,23,128,153,132,50,81,40,103,217,158,238,118,98,103,255,82,5,153,36,92,59,98,126,124,176,140,79,85,182,96,11,125,128,149,1,83,95,78,182,81,28,89,58,114,54,128,206,145,37,95,226,119,132,83,121,95,4,125,172,133,51,138,141,142,86,151,243,103,174,133,83,148,9,97,8,97,185,108,82,118,237,138,56,143,47,85,81,79,42,81,199,82,203,83,165,91,125,94,160,96,130,97,214,99,9,103,218,103,103,110,140,109,54,115,55,115,49,117,80,121,213,136,152,138,74,144,145,144,245,144,196,150,141,135,21,89,136,78,89,79,14,78,137,138,63,143,16,152,173,80,124,94,150,89,185,91,184,94,218,99,250,99,193,100,220,102,74,105,216,105,11,109,182,110,148,113,40,117,175,122,138,127,0,128,73,132,201,132,129,137,33,139,10,142,101,144,125,150,10,153,126,97,145,98,50,107,131,108,116,109,204,127,252,127,192,109,133,127,186,135,248,136,101,103,177,131,60,152,247,150,27,109,97,125,61,132,106,145,113,78,117,83,80,93,4,107,235,111,205,133,45,134,167,137,41,82,15,84,101,92,78,103,168,104,6,116,131,116,226,117,207,136,225,136,204,145,226,150,120,150,139,95,135,115,203,122,78,132,160,99,101,117,137,82,65,109,156,110,9,116,89,117,107,120,146,124,134,150,220,122,141,159,182,79,110,97,197,101,92,134,134,78,174,78,218,80,33,78,204,81,238,91,153,101,129,104,188,109,31,115,66,118,173,119,28,122,231,124,111,130,210,138,124,144,207,145,117,150,24,152,155,82,209,125,43,80,152,83,151,103,203,109,208,113,51,116,232,129,42,143,163,150,87,156,159,158,96,116,65,88,153,109,47,125,94,152,228,78,54,79,139,79,183,81,177,82,186,93,28,96,178,115,60,121,211,130,52,146,183,150,246,150,10,151,151,158,98,159,166,102,116,107,23,82,163,82,200,112,194,136,201,94,75,96,144,97,35,111,73,113,62,124,244,125,111,128,238,132,35,144,44,147,66,84,111,155,211,106,137,112,194,140,239,141,50,151,180,82,65,90,202,94,4,95,23,103,124,105,148,105,106,109,15,111,98,114,252,114,237,123,1,128,126,128,75,135,206,144,109,81,147,158,132,121,139,128,50,147,214,138,45,80,140,84,113,138,106,107,196,140,7,129,209,96,160,103,242,157,153,78,152,78,16,156,107,138,193,133,104,133,0,105,126,110,151,120,85,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,95,16,78,21,78,42,78,49,78,54,78,60,78,63,78,66,78,86,78,88,78,130,78,133,78,107,140,138,78,18,130,13,95,142,78,158,78,159,78,160,78,162,78,176,78,179,78,182,78,206,78,205,78,196,78,198,78,194,78,215,78,222,78,237,78,223,78,247,78,9,79,90,79,48,79,91,79,93,79,87,79,71,79,118,79,136,79,143,79,152,79,123,79,105,79,112,79,145,79,111,79,134,79,150,79,24,81,212,79,223,79,206,79,216,79,219,79,209,79,218,79,208,79,228,79,229,79,26,80,40,80,20,80,42,80,37,80,5,80,28,79,246,79,33,80,41,80,44,80,254,79,239,79,17,80,6,80,67,80,71,80,3,103,85,80,80,80,72,80,90,80,86,80,108,80,120,80,128,80,154,80,133,80,180,80,178,80,201,80,202,80,179,80,194,80,214,80,222,80,229,80,237,80,227,80,238,80,249,80,245,80,9,81,1,81,2,81,22,81,21,81,20,81,26,81,33,81,58,81,55,81,60,81,59,81,63,81,64,81,82,81,76,81,84,81,98,81,248,122,105,81,106,81,110,81,128,81,130,81,216,86,140,81,137,81,143,81,145,81,147,81,149,81,150,81,164,81,166,81,162,81,169,81,170,81,171,81,179,81,177,81,178,81,176,81,181,81,189,81,197,81,201,81,219,81,224,81,85,134,233,81,237,81,240,81,245,81,254,81,4,82,11,82,20,82,14,82,39,82,42,82,46,82,51,82,57,82,79,82,68,82,75,82,76,82,94,82,84,82,106,82,116,82,105,82,115,82,127,82,125,82,141,82,148,82,146,82,113,82,136,82,145,82,168,143,167,143,172,82,173,82,188,82,181,82,193,82,205,82,215,82,222,82,227,82,230,82,237,152,224,82,243,82,245,82,248,82,249,82,6,83,8,83,56,117,13,83,16,83,15,83,21,83,26,83,35,83,47,83,49,83,51,83,56,83,64,83,70,83,69,83,23,78,73,83,77,83,214,81,94,83,105,83,110,83,24,89,123,83,119,83,130,83,150,83,160,83,166,83,165,83,174,83,176,83,182,83,195,83,18,124,217,150,223,83,252,102,238,113,238,83,232,83,237,83,250,83,1,84,61,84,64,84,44,84,45,84,60,84,46,84,54,84,41,84,29,84,78,84,143,84,117,84,142,84,95,84,113,84,119,84,112,84,146,84,123,84,128,84,118,84,132,84,144,84,134,84,199,84,162,84,184,84,165,84,172,84,196,84,200,84,168,84,171,84,194,84,164,84,190,84,188,84,216,84,229,84,230,84,15,85,20,85,253,84,238,84,237,84,250,84,226,84,57,85,64,85,99,85,76,85,46,85,92,85,69,85,86,85,87,85,56,85,51,85,93,85,153,85,128,85,175,84,138,85,159,85,123,85,126,85,152,85,158,85,174,85,124,85,131,85,169,85,135,85,168,85,218,85,197,85,223,85,196,85,220,85,228,85,212,85,20,86,247,85,22,86,254,85,253,85,27,86,249,85,78,86,80,86,223,113,52,86,54,86,50,86,56,86,107,86,100,86,47,86,108,86,106,86,134,86,128,86,138,86,160,86,148,86,143,86,165,86,174,86,182,86,180,86,194,86,188,86,193,86,195,86,192,86,200,86,206,86,209,86,211,86,215,86,238,86,249,86,0,87,255,86,4,87,9,87,8,87,11,87,13,87,19,87,24,87,22,87,199,85,28,87,38,87,55,87,56,87,78,87,59,87,64,87,79,87,105,87,192,87,136,87,97,87,127,87,137,87,147,87,160,87,179,87,164,87,170,87,176,87,195,87,198,87,212,87,210,87,211,87,10,88,214,87,227,87,11,88,25,88,29,88,114,88,33,88,98,88,75,88,112,88,192,107,82,88,61,88,121,88,133,88,185,88,159,88,171,88,186,88,222,88,187,88,184,88,174,88,197,88,211,88,209,88,215,88,217,88,216,88,229,88,220,88,228,88,223,88,239,88,250,88,249,88,251,88,252,88,253,88,2,89,10,89,16,89,27,89,166,104,37,89,44,89,45,89,50,89,56,89,62,89,210,122,85,89,80,89,78,89,90,89,88,89,98,89,96,89,103,89,108,89,105,89,120,89,129,89,157,89,94,79,171,79,163,89,178,89,198,89,232,89,220,89,141,89,217,89,218,89,37,90,31,90,17,90,28,90,9,90,26,90,64,90,108,90,73,90,53,90,54,90,98,90,106,90,154,90,188,90,190,90,203,90,194,90,189,90,227,90,215,90,230,90,233,90,214,90,250,90,251,90,12,91,11,91,22,91,50,91,208,90,42,91,54,91,62,91,67,91,69,91,64,91,81,91,85,91,90,91,91,91,101,91,105,91,112,91,115,91,117,91,120,91,136,101,122,91,128,91,131,91,166,91,184,91,195,91,199,91,201,91,212,91,208,91,228,91,230,91,226,91,222,91,229,91,235,91,240,91,246,91,243,91,5,92,7,92,8,92,13,92,19,92,32,92,34,92,40,92,56,92,57,92,65,92,70,92,78,92,83,92,80,92,79,92,113,91,108,92,110,92,98,78,118,92,121,92,140,92,145,92,148,92,155,89,171,92,187,92,182,92,188,92,183,92,197,92,190,92,199,92,217,92,233,92,253,92,250,92,237,92,140,93,234,92,11,93,21,93,23,93,92,93,31,93,27,93,17,93,20,93,34,93,26,93,25,93,24,93,76,93,82,93,78,93,75,93,108,93,115,93,118,93,135,93,132,93,130,93,162,93,157,93,172,93,174,93,189,93,144,93,183,93,188,93,201,93,205,93,211,93,210,93,214,93,219,93,235,93,242,93,245,93,11,94,26,94,25,94,17,94,27,94,54,94,55,94,68,94,67,94,64,94,78,94,87,94,84,94,95,94,98,94,100,94,71,94,117,94,118,94,122,94,188,158,127,94,160,94,193,94,194,94,200,94,208,94,207,94,214,94,227,94,221,94,218,94,219,94,226,94,225,94,232,94,233,94,236,94,241,94,243,94,240,94,244,94,248,94,254,94,3,95,9,95,93,95,92,95,11,95,17,95,22,95,41,95,45,95,56,95,65,95,72,95,76,95,78,95,47,95,81,95,86,95,87,95,89,95,97,95,109,95,115,95,119,95,131,95,130,95,127,95,138,95,136,95,145,95,135,95,158,95,153,95,152,95,160,95,168,95,173,95,188,95,214,95,251,95,228,95,248,95,241,95,221,95,179,96,255,95,33,96,96,96,25,96,16,96,41,96,14,96,49,96,27,96,21,96,43,96,38,96,15,96,58,96,90,96,65,96,106,96,119,96,95,96,74,96,70,96,77,96,99,96,67,96,100,96,66,96,108,96,107,96,89,96,129,96,141,96,231,96,131,96,154,96,132,96,155,96,150,96,151,96,146,96,167,96,139,96,225,96,184,96,224,96,211,96,180,96,240,95,189,96,198,96,181,96,216,96,77,97,21,97,6,97,246,96,247,96,0,97,244,96,250,96,3,97,33,97,251,96,241,96,13,97,14,97,71,97,62,97,40,97,39,97,74,97,63,97,60,97,44,97,52,97,61,97,66,97,68,97,115,97,119,97,88,97,89,97,90,97,107,97,116,97,111,97,101,97,113,97,95,97,93,97,83,97,117,97,153,97,150,97,135,97,172,97,148,97,154,97,138,97,145,97,171,97,174,97,204,97,202,97,201,97,247,97,200,97,195,97,198,97,186,97,203,97,121,127,205,97,230,97,227,97,246,97,250,97,244,97,255,97,253,97,252,97,254,97,0,98,8,98,9,98,13,98,12,98,20,98,27,98,30,98,33,98,42,98,46,98,48,98,50,98,51,98,65,98,78,98,94,98,99,98,91,98,96,98,104,98,124,98,130,98,137,98,126,98,146,98,147,98,150,98,212,98,131,98,148,98,215,98,209,98,187,98,207,98,255,98,198,98,212,100,200,98,220,98,204,98,202,98,194,98,199,98,155,98,201,98,12,99,238,98,241,98,39,99,2,99,8,99,239,98,245,98,80,99,62,99,77,99,28,100,79,99,150,99,142,99,128,99,171,99,118,99,163,99,143,99,137,99,159,99,181,99,107,99,105,99,190,99,233,99,192,99,198,99,227,99,201,99,210,99,246,99,196,99,22,100,52,100,6,100,19,100,38,100,54,100,29,101,23,100,40,100,15,100,103,100,111,100,118,100,78,100,42,101,149,100,147,100,165,100,169,100,136,100,188,100,218,100,210,100,197,100,199,100,187,100,216,100,194,100,241,100,231,100,9,130,224,100,225,100,172,98,227,100,239,100,44,101,246,100,244,100,242,100,250,100,0,101,253,100,24,101,28,101,5,101,36,101,35,101,43,101,52,101,53,101,55,101,54,101,56,101,75,117,72,101,86,101,85,101,77,101,88,101,94,101,93,101,114,101,120,101,130,101,131,101,138,139,155,101,159,101,171,101,183,101,195,101,198,101,193,101,196,101,204,101,210,101,219,101,217,101,224,101,225,101,241,101,114,103,10,102,3,102,251,101,115,103,53,102,54,102,52,102,28,102,79,102,68,102,73,102,65,102,94,102,93,102,100,102,103,102,104,102,95,102,98,102,112,102,131,102,136,102,142,102,137,102,132,102,152,102,157,102,193,102,185,102,201,102,190,102,188,102,196,102,184,102,214,102,218,102,224,102,63,102,230,102,233,102,240,102,245,102,247,102,15,103,22,103,30,103,38,103,39,103,56,151,46,103,63,103,54,103,65,103,56,103,55,103,70,103,94,103,96,103,89,103,99,103,100,103,137,103,112,103,169,103,124,103,106,103,140,103,139,103,166,103,161,103,133,103,183,103,239,103,180,103,236,103,179,103,233,103,184,103,228,103,222,103,221,103,226,103,238,103,185,103,206,103,198,103,231,103,156,106,30,104,70,104,41,104,64,104,77,104,50,104,78,104,179,104,43,104,89,104,99,104,119,104,127,104,159,104,143,104,173,104,148,104,157,104,155,104,131,104,174,106,185,104,116,104,181,104,160,104,186,104,15,105,141,104,126,104,1,105,202,104,8,105,216,104,34,105,38,105,225,104,12,105,205,104,212,104,231,104,213,104,54,105,18,105,4,105,215,104,227,104,37,105,249,104,224,104,239,104,40,105,42,105,26,105,35,105,33,105,198,104,121,105,119,105,92,105,120,105,107,105,84,105,126,105,110,105,57,105,116,105,61,105,89,105,48,105,97,105,94,105,93,105,129,105,106,105,178,105,174,105,208,105,191,105,193,105,211,105,190,105,206,105,232,91,202,105,221,105,187,105,195,105,167,105,46,106,145,105,160,105,156,105,149,105,180,105,222,105,232,105,2,106,27,106,255,105,10,107,249,105,242,105,231,105,5,106,177,105,30,106,237,105,20,106,235,105,10,106,18,106,193,106,35,106,19,106,68,106,12,106,114,106,54,106,120,106,71,106,98,106,89,106,102,106,72,106,56,106,34,106,144,106,141,106,160,106,132,106,162,106,163,106,151,106,23,134,187,106,195,106,194,106,184,106,179,106,172,106,222,106,209,106,223,106,170,106,218,106,234,106,251,106,5,107,22,134,250,106,18,107,22,107,49,155,31,107,56,107,55,107,220,118,57,107,238,152,71,107,67,107,73,107,80,107,89,107,84,107,91,107,95,107,97,107,120,107,121,107,127,107,128,107,132,107,131,107,141,107,152,107,149,107,158,107,164,107,170,107,171,107,175,107,178,107,177,107,179,107,183,107,188,107,198,107,203,107,211,107,223,107,236,107,235,107,243,107,239,107,190,158,8,108,19,108,20,108,27,108,36,108,35,108,94,108,85,108,98,108,106,108,130,108,141,108,154,108,129,108,155,108,126,108,104,108,115,108,146,108,144,108,196,108,241,108,211,108,189,108,215,108,197,108,221,108,174,108,177,108,190,108,186,108,219,108,239,108,217,108,234,108,31,109,77,136,54,109,43,109,61,109,56,109,25,109,53,109,51,109,18,109,12,109,99,109,147,109,100,109,90,109,121,109,89,109,142,109,149,109,228,111,133,109,249,109,21,110,10,110,181,109,199,109,230,109,184,109,198,109,236,109,222,109,204,109,232,109,210,109,197,109,250,109,217,109,228,109,213,109,234,109,238,109,45,110,110,110,46,110,25,110,114,110,95,110,62,110,35,110,107,110,43,110,118,110,77,110,31,110,67,110,58,110,78,110,36,110,255,110,29,110,56,110,130,110,170,110,152,110,201,110,183,110,211,110,189,110,175,110,196,110,178,110,212,110,213,110,143,110,165,110,194,110,159,110,65,111,17,111,76,112,236,110,248,110,254,110,63,111,242,110,49,111,239,110,50,111,204,110,62,111,19,111,247,110,134,111,122,111,120,111,129,111,128,111,111,111,91,111,243,111,109,111,130,111,124,111,88,111,142,111,145,111,194,111,102,111,179,111,163,111,161,111,164,111,185,111,198,111,170,111,223,111,213,111,236,111,212,111,216,111,241,111,238,111,219,111,9,112,11,112,250,111,17,112,1,112,15,112,254,111,27,112,26,112,116,111,29,112,24,112,31,112,48,112,62,112,50,112,81,112,99,112,153,112,146,112,175,112,241,112,172,112,184,112,179,112,174,112,223,112,203,112,221,112,217,112,9,113,253,112,28,113,25,113,101,113,85,113,136,113,102,113,98,113,76,113,86,113,108,113,143,113,251,113,132,113,149,113,168,113,172,113,215,113,185,113,190,113,210,113,201,113,212,113,206,113,224,113,236,113,231,113,245,113,252,113,249,113,255,113,13,114,16,114,27,114,40,114,45,114,44,114,48,114,50,114,59,114,60,114,63,114,64,114,70,114,75,114,88,114,116,114,126,114,130,114,129,114,135,114,146,114,150,114,162,114,167,114,185,114,178,114,195,114,198,114,196,114,206,114,210,114,226,114,224,114,225,114,249,114,247,114,15,80,23,115,10,115,28,115,22,115,29,115,52,115,47,115,41,115,37,115,62,115,78,115,79,115,216,158,87,115,106,115,104,115,112,115,120,115,117,115,123,115,122,115,200,115,179,115,206,115,187,115,192,115,229,115,238,115,222,115,162,116,5,116,111,116,37,116,248,115,50,116,58,116,85,116,63,116,95,116,89,116,65,116,92,116,105,116,112,116,99,116,106,116,118,116,126,116,139,116,158,116,167,116,202,116,207,116,212,116,241,115,224,116,227,116,231,116,233,116,238,116,242,116,240,116,241,116,248,116,247,116,4,117,3,117,5,117,12,117,14,117,13,117,21,117,19,117,30,117,38,117,44,117,60,117,68,117,77,117,74,117,73,117,91,117,70,117,90,117,105,117,100,117,103,117,107,117,109,117,120,117,118,117,134,117,135,117,116,117,138,117,137,117,130,117,148,117,154,117,157,117,165,117,163,117,194,117,179,117,195,117,181,117,189,117,184,117,188,117,177,117,205,117,202,117,210,117,217,117,227,117,222,117,254,117,255,117,252,117,1,118,240,117,250,117,242,117,243,117,11,118,13,118,9,118,31,118,39,118,32,118,33,118,34,118,36,118,52,118,48,118,59,118,71,118,72,118,70,118,92,118,88,118,97,118,98,118,104,118,105,118,106,118,103,118,108,118,112,118,114,118,118,118,120,118,124,118,128,118,131,118,136,118,139,118,142,118,150,118,147,118,153,118,154,118,176,118,180,118,184,118,185,118,186,118,194,118,205,118,214,118,210,118,222,118,225,118,229,118,231,118,234,118,47,134,251,118,8,119,7,119,4,119,41,119,36,119,30,119,37,119,38,119,27,119,55,119,56,119,71,119,90,119,104,119,107,119,91,119,101,119,127,119,126,119,121,119,142,119,139,119,145,119,160,119,158,119,176,119,182,119,185,119,191,119,188,119,189,119,187,119,199,119,205,119,215,119,218,119,220,119,227,119,238,119,252,119,12,120,18,120,38,121,32,120,42,121,69,120,142,120,116,120,134,120,124,120,154,120,140,120,163,120,181,120,170,120,175,120,209,120,198,120,203,120,212,120,190,120,188,120,197,120,202,120,236,120,231,120,218,120,253,120,244,120,7,121,18,121,17,121,25,121,44,121,43,121,64,121,96,121,87,121,95,121,90,121,85,121,83,121,122,121,127,121,138,121,157,121,167,121,75,159,170,121,174,121,179,121,185,121,186,121,201,121,213,121,231,121,236,121,225,121,227,121,8,122,13,122,24,122,25,122,32,122,31,122,128,121,49,122,59,122,62,122,55,122,67,122,87,122,73,122,97,122,98,122,105,122,157,159,112,122,121,122,125,122,136,122,151,122,149,122,152,122,150,122,169,122,200,122,176,122,182,122,197,122,196,122,191,122,131,144,199,122,202,122,205,122,207,122,213,122,211,122,217,122,218,122,221,122,225,122,226,122,230,122,237,122,240,122,2,123,15,123,10,123,6,123,51,123,24,123,25,123,30,123,53,123,40,123,54,123,80,123,122,123,4,123,77,123,11,123,76,123,69,123,117,123,101,123,116,123,103,123,112,123,113,123,108,123,110,123,157,123,152,123,159,123,141,123,156,123,154,123,139,123,146,123,143,123,93,123,153,123,203,123,193,123,204,123,207,123,180,123,198,123,221,123,233,123,17,124,20,124,230,123,229,123,96,124,0,124,7,124,19,124,243,123,247,123,23,124,13,124,246,123,35,124,39,124,42,124,31,124,55,124,43,124,61,124,76,124,67,124,84,124,79,124,64,124,80,124,88,124,95,124,100,124,86,124,101,124,108,124,117,124,131,124,144,124,164,124,173,124,162,124,171,124,161,124,168,124,179,124,178,124,177,124,174,124,185,124,189,124,192,124,197,124,194,124,216,124,210,124,220,124,226,124,59,155,239,124,242,124,244,124,246,124,250,124,6,125,2,125,28,125,21,125,10,125,69,125,75,125,46,125,50,125,63,125,53,125,70,125,115,125,86,125,78,125,114,125,104,125,110,125,79,125,99,125,147,125,137,125,91,125,143,125,125,125,155,125,186,125,174,125,163,125,181,125,199,125,189,125,171,125,61,126,162,125,175,125,220,125,184,125,159,125,176,125,216,125,221,125,228,125,222,125,251,125,242,125,225,125,5,126,10,126,35,126,33,126,18,126,49,126,31,126,9,126,11,126,34,126,70,126,102,126,59,126,53,126,57,126,67,126,55,126,50,126,58,126,103,126,93,126,86,126,94,126,89,126,90,126,121,126,106,126,105,126,124,126,123,126,131,126,213,125,125,126,174,143,127,126,136,126,137,126,140,126,146,126,144,126,147,126,148,126,150,126,142,126,155,126,156,126,56,127,58,127,69,127,76,127,77,127,78,127,80,127,81,127,85,127,84,127,88,127,95,127,96,127,104,127,105,127,103,127,120,127,130,127,134,127,131,127,136,127,135,127,140,127,148,127,158,127,157,127,154,127,163,127,175,127,178,127,185,127,174,127,182,127,184,127,113,139,197,127,198,127,202,127,213,127,212,127,225,127,230,127,233,127,243,127,249,127,220,152], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+883180);
/* memory initializer */ allocate([6,128,4,128,11,128,18,128,24,128,25,128,28,128,33,128,40,128,63,128,59,128,74,128,70,128,82,128,88,128,90,128,95,128,98,128,104,128,115,128,114,128,112,128,118,128,121,128,125,128,127,128,132,128,134,128,133,128,155,128,147,128,154,128,173,128,144,81,172,128,219,128,229,128,217,128,221,128,196,128,218,128,214,128,9,129,239,128,241,128,27,129,41,129,35,129,47,129,75,129,139,150,70,129,62,129,83,129,81,129,252,128,113,129,110,129,101,129,102,129,116,129,131,129,136,129,138,129,128,129,130,129,160,129,149,129,164,129,163,129,95,129,147,129,169,129,176,129,181,129,190,129,184,129,189,129,192,129,194,129,186,129,201,129,205,129,209,129,217,129,216,129,200,129,218,129,223,129,224,129,231,129,250,129,251,129,254,129,1,130,2,130,5,130,7,130,10,130,13,130,16,130,22,130,41,130,43,130,56,130,51,130,64,130,89,130,88,130,93,130,90,130,95,130,100,130,98,130,104,130,106,130,107,130,46,130,113,130,119,130,120,130,126,130,141,130,146,130,171,130,159,130,187,130,172,130,225,130,227,130,223,130,210,130,244,130,243,130,250,130,147,131,3,131,251,130,249,130,222,130,6,131,220,130,9,131,217,130,53,131,52,131,22,131,50,131,49,131,64,131,57,131,80,131,69,131,47,131,43,131,23,131,24,131,133,131,154,131,170,131,159,131,162,131,150,131,35,131,142,131,135,131,138,131,124,131,181,131,115,131,117,131,160,131,137,131,168,131,244,131,19,132,235,131,206,131,253,131,3,132,216,131,11,132,193,131,247,131,7,132,224,131,242,131,13,132,34,132,32,132,189,131,56,132,6,133,251,131,109,132,42,132,60,132,90,133,132,132,119,132,107,132,173,132,110,132,130,132,105,132,70,132,44,132,111,132,121,132,53,132,202,132,98,132,185,132,191,132,159,132,217,132,205,132,187,132,218,132,208,132,193,132,198,132,214,132,161,132,33,133,255,132,244,132,23,133,24,133,44,133,31,133,21,133,20,133,252,132,64,133,99,133,88,133,72,133,65,133,2,134,75,133,85,133,128,133,164,133,136,133,145,133,138,133,168,133,109,133,148,133,155,133,234,133,135,133,156,133,119,133,126,133,144,133,201,133,186,133,207,133,185,133,208,133,213,133,221,133,229,133,220,133,249,133,10,134,19,134,11,134,254,133,250,133,6,134,34,134,26,134,48,134,63,134,77,134,85,78,84,134,95,134,103,134,113,134,147,134,163,134,169,134,170,134,139,134,140,134,182,134,175,134,196,134,198,134,176,134,201,134,35,136,171,134,212,134,222,134,233,134,236,134,223,134,219,134,239,134,18,135,6,135,8,135,0,135,3,135,251,134,17,135,9,135,13,135,249,134,10,135,52,135,63,135,55,135,59,135,37,135,41,135,26,135,96,135,95,135,120,135,76,135,78,135,116,135,87,135,104,135,110,135,89,135,83,135,99,135,106,135,5,136,162,135,159,135,130,135,175,135,203,135,189,135,192,135,208,135,214,150,171,135,196,135,179,135,199,135,198,135,187,135,239,135,242,135,224,135,15,136,13,136,254,135,246,135,247,135,14,136,210,135,17,136,22,136,21,136,34,136,33,136,49,136,54,136,57,136,39,136,59,136,68,136,66,136,82,136,89,136,94,136,98,136,107,136,129,136,126,136,158,136,117,136,125,136,181,136,114,136,130,136,151,136,146,136,174,136,153,136,162,136,141,136,164,136,176,136,191,136,177,136,195,136,196,136,212,136,216,136,217,136,221,136,249,136,2,137,252,136,244,136,232,136,242,136,4,137,12,137,10,137,19,137,67,137,30,137,37,137,42,137,43,137,65,137,68,137,59,137,54,137,56,137,76,137,29,137,96,137,94,137,102,137,100,137,109,137,106,137,111,137,116,137,119,137,126,137,131,137,136,137,138,137,147,137,152,137,161,137,169,137,166,137,172,137,175,137,178,137,186,137,189,137,191,137,192,137,218,137,220,137,221,137,231,137,244,137,248,137,3,138,22,138,16,138,12,138,27,138,29,138,37,138,54,138,65,138,91,138,82,138,70,138,72,138,124,138,109,138,108,138,98,138,133,138,130,138,132,138,168,138,161,138,145,138,165,138,166,138,154,138,163,138,196,138,205,138,194,138,218,138,235,138,243,138,231,138,228,138,241,138,20,139,224,138,226,138,247,138,222,138,219,138,12,139,7,139,26,139,225,138,22,139,16,139,23,139,32,139,51,139,171,151,38,139,43,139,62,139,40,139,65,139,76,139,79,139,78,139,73,139,86,139,91,139,90,139,107,139,95,139,108,139,111,139,116,139,125,139,128,139,140,139,142,139,146,139,147,139,150,139,153,139,154,139,58,140,65,140,63,140,72,140,76,140,78,140,80,140,85,140,98,140,108,140,120,140,122,140,130,140,137,140,133,140,138,140,141,140,142,140,148,140,124,140,152,140,29,98,173,140,170,140,189,140,178,140,179,140,174,140,182,140,200,140,193,140,228,140,227,140,218,140,253,140,250,140,251,140,4,141,5,141,10,141,7,141,15,141,13,141,16,141,78,159,19,141,205,140,20,141,22,141,103,141,109,141,113,141,115,141,129,141,153,141,194,141,190,141,186,141,207,141,218,141,214,141,204,141,219,141,203,141,234,141,235,141,223,141,227,141,252,141,8,142,9,142,255,141,29,142,30,142,16,142,31,142,66,142,53,142,48,142,52,142,74,142,71,142,73,142,76,142,80,142,72,142,89,142,100,142,96,142,42,142,99,142,85,142,118,142,114,142,124,142,129,142,135,142,133,142,132,142,139,142,138,142,147,142,145,142,148,142,153,142,170,142,161,142,172,142,176,142,198,142,177,142,190,142,197,142,200,142,203,142,219,142,227,142,252,142,251,142,235,142,254,142,10,143,5,143,21,143,18,143,25,143,19,143,28,143,31,143,27,143,12,143,38,143,51,143,59,143,57,143,69,143,66,143,62,143,76,143,73,143,70,143,78,143,87,143,92,143,98,143,99,143,100,143,156,143,159,143,163,143,173,143,175,143,183,143,218,143,229,143,226,143,234,143,239,143,135,144,244,143,5,144,249,143,250,143,17,144,21,144,33,144,13,144,30,144,22,144,11,144,39,144,54,144,53,144,57,144,248,143,79,144,80,144,81,144,82,144,14,144,73,144,62,144,86,144,88,144,94,144,104,144,111,144,118,144,168,150,114,144,130,144,125,144,129,144,128,144,138,144,137,144,143,144,168,144,175,144,177,144,181,144,226,144,228,144,72,98,219,144,2,145,18,145,25,145,50,145,48,145,74,145,86,145,88,145,99,145,101,145,105,145,115,145,114,145,139,145,137,145,130,145,162,145,171,145,175,145,170,145,181,145,180,145,186,145,192,145,193,145,201,145,203,145,208,145,214,145,223,145,225,145,219,145,252,145,245,145,246,145,30,146,255,145,20,146,44,146,21,146,17,146,94,146,87,146,69,146,73,146,100,146,72,146,149,146,63,146,75,146,80,146,156,146,150,146,147,146,155,146,90,146,207,146,185,146,183,146,233,146,15,147,250,146,68,147,46,147,25,147,34,147,26,147,35,147,58,147,53,147,59,147,92,147,96,147,124,147,110,147,86,147,176,147,172,147,173,147,148,147,185,147,214,147,215,147,232,147,229,147,216,147,195,147,221,147,208,147,200,147,228,147,26,148,20,148,19,148,3,148,7,148,16,148,54,148,43,148,53,148,33,148,58,148,65,148,82,148,68,148,91,148,96,148,98,148,94,148,106,148,41,146,112,148,117,148,119,148,125,148,90,148,124,148,126,148,129,148,127,148,130,149,135,149,138,149,148,149,150,149,152,149,153,149,160,149,168,149,167,149,173,149,188,149,187,149,185,149,190,149,202,149,246,111,195,149,205,149,204,149,213,149,212,149,214,149,220,149,225,149,229,149,226,149,33,150,40,150,46,150,47,150,66,150,76,150,79,150,75,150,119,150,92,150,94,150,93,150,95,150,102,150,114,150,108,150,141,150,152,150,149,150,151,150,170,150,167,150,177,150,178,150,176,150,180,150,182,150,184,150,185,150,206,150,203,150,201,150,205,150,77,137,220,150,13,151,213,150,249,150,4,151,6,151,8,151,19,151,14,151,17,151,15,151,22,151,25,151,36,151,42,151,48,151,57,151,61,151,62,151,68,151,70,151,72,151,66,151,73,151,92,151,96,151,100,151,102,151,104,151,210,82,107,151,113,151,121,151,133,151,124,151,129,151,122,151,134,151,139,151,143,151,144,151,156,151,168,151,166,151,163,151,179,151,180,151,195,151,198,151,200,151,203,151,220,151,237,151,79,159,242,151,223,122,246,151,245,151,15,152,12,152,56,152,36,152,33,152,55,152,61,152,70,152,79,152,75,152,107,152,111,152,112,152,113,152,116,152,115,152,170,152,175,152,177,152,182,152,196,152,195,152,198,152,233,152,235,152,3,153,9,153,18,153,20,153,24,153,33,153,29,153,30,153,36,153,32,153,44,153,46,153,61,153,62,153,66,153,73,153,69,153,80,153,75,153,81,153,82,153,76,153,85,153,151,153,152,153,165,153,173,153,174,153,188,153,223,153,219,153,221,153,216,153,209,153,237,153,238,153,241,153,242,153,251,153,248,153,1,154,15,154,5,154,226,153,25,154,43,154,55,154,69,154,66,154,64,154,67,154,62,154,85,154,77,154,91,154,87,154,95,154,98,154,101,154,100,154,105,154,107,154,106,154,173,154,176,154,188,154,192,154,207,154,209,154,211,154,212,154,222,154,223,154,226,154,227,154,230,154,239,154,235,154,238,154,244,154,241,154,247,154,251,154,6,155,24,155,26,155,31,155,34,155,35,155,37,155,39,155,40,155,41,155,42,155,46,155,47,155,50,155,68,155,67,155,79,155,77,155,78,155,81,155,88,155,116,155,147,155,131,155,145,155,150,155,151,155,159,155,160,155,168,155,180,155,192,155,202,155,185,155,198,155,207,155,209,155,210,155,227,155,226,155,228,155,212,155,225,155,58,156,242,155,241,155,240,155,21,156,20,156,9,156,19,156,12,156,6,156,8,156,18,156,10,156,4,156,46,156,27,156,37,156,36,156,33,156,48,156,71,156,50,156,70,156,62,156,90,156,96,156,103,156,118,156,120,156,231,156,236,156,240,156,9,157,8,157,235,156,3,157,6,157,42,157,38,157,175,157,35,157,31,157,68,157,21,157,18,157,65,157,63,157,62,157,70,157,72,157,93,157,94,157,100,157,81,157,80,157,89,157,114,157,137,157,135,157,171,157,111,157,122,157,154,157,164,157,169,157,178,157,196,157,193,157,187,157,184,157,186,157,198,157,207,157,194,157,217,157,211,157,248,157,230,157,237,157,239,157,253,157,26,158,27,158,30,158,117,158,121,158,125,158,129,158,136,158,139,158,140,158,146,158,149,158,145,158,157,158,165,158,169,158,184,158,170,158,173,158,97,151,204,158,206,158,207,158,208,158,212,158,220,158,222,158,221,158,224,158,229,158,232,158,239,158,244,158,246,158,247,158,249,158,251,158,252,158,253,158,7,159,8,159,183,118,21,159,33,159,44,159,62,159,74,159,82,159,84,159,99,159,95,159,96,159,97,159,102,159,103,159,108,159,106,159,119,159,114,159,118,159,149,159,156,159,160,159,47,88,199,105,89,144,100,116,220,81,153,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,4,5,4,4,4,6,6,0,0,0,0,0,0,0,0,12,0,0,0,0,2,2,3,3,3,3,5,3,2,2,2,0,0,0,0,12,0,0,0,0,2,3,4,3,3,3,3,4,3,2,2,0,0,0,0,12,0,0,0,0,3,4,4,3,3,3,3,3,2,2,2,0,0,0,0,13,0,0,0,0,4,4,3,3,3,3,2,3,3,2,1,1,0,0,0,9,0,0,0,0,4,4,4,4,3,3,3,2,0,0,0,0,0,0,0,10,0,0,0,0,4,4,4,4,3,3,2,2,2,0,0,0,0,0,0,12,0,0,0,0,4,4,4,3,3,2,3,2,2,2,2,0,0,0,0,10,0,0,0,1,2,3,4,4,7,5,5,4,1,0,0,0,0,0,0,11,0,0,0,2,3,4,4,4,7,5,4,3,3,2,0,0,0,0,0,12,0,0,0,2,4,5,5,5,5,6,4,4,3,1,1,0,0,0,0,13,0,0,0,3,3,4,4,5,6,6,4,4,3,2,1,1,0,0,0,11,0,0,0,3,4,4,5,5,5,6,5,4,2,2,0,0,0,0,0,13,0,0,0,3,4,5,5,5,5,6,4,3,3,2,1,1,0,0,0,13,0,0,0,3,4,5,5,5,6,5,4,3,3,2,1,1,0,0,0,9,0,0,0,3,4,4,5,5,5,6,5,5,0,0,0,0,0,0,0,11,14,16,18,20,22,23,24,26,28,30,32,34,36,39,40,42,45,47,49,52,55,57,60,1,16,18,20,22,24,27,30,34,37,40,44,48,52,56,61,66,71,76,82,88,94,101,108,19,34,39,42,45,51,54,60,65,69,73,78,83,88,93,99,105,111,117,124,130,136,142,149,19,31,33,36,39,41,45,47,52,55,58,61,64,68,72,76,79,82,86,90,94,98,102,107,49,66,71,71,77,82,88,88,93,99,103,107,111,115,120,124,128,132,137,142,147,152,157,164,11,17,19,20,21,22,24,26,27,29,32,34,35,37,40,42,46,50,53,57,61,65,68,74,7,20,22,24,27,30,34,37,41,45,49,53,58,63,68,74,80,86,92,99,106,113,120,126,21,37,40,45,48,52,58,61,66,72,76,81,86,91,96,101,107,112,118,124,130,136,143,151,19,31,32,34,37,40,43,45,48,51,54,57,60,63,66,69,72,75,78,82,86,90,94,98,60,82,88,93,99,104,104,109,115,120,124,128,132,137,142,147,152,157,163,169,173,177,181,186,1,11,11,13,13,13,14,15,16,17,19,20,21,22,23,24,25,26,27,28,29,30,31,32,11,13,13,14,17,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,160,120,80,60,40,30,176,120,88,60,88,72,44,36,60,45,160,60,176,60,20,15,22,18,0,0,0,0,0,0,0,0,26,0,46,0,54,0,66,0,70,0,74,0,78,0,90,0,46,0,50,0,62,0,66,0,70,0,78,0,86,0,106,0,54,0,62,0,62,0,68,0,74,0,84,0,102,0,114,0,66,0,66,0,68,0,74,0,82,0,98,0,108,0,122,0,70,0,70,0,74,0,82,0,94,0,102,0,114,0,142,0,74,0,78,0,84,0,98,0,102,0,110,0,134,0,166,0,78,0,86,0,102,0,108,0,114,0,134,0,154,0,202,0,90,0,106,0,114,0,122,0,142,0,166,0,202,0,254,0,38,0,58,0,62,0,70,0,74,0,78,0,82,0,90,0,58,0,62,0,66,0,70,0,74,0,78,0,86,0,94,0,62,0,66,0,70,0,72,0,76,0,82,0,90,0,98,0,70,0,70,0,72,0,74,0,78,0,86,0,94,0,102,0,74,0,74,0,76,0,78,0,82,0,90,0,98,0,106,0,78,0,78,0,82,0,86,0,90,0,94,0,102,0,110,0,82,0,86,0,90,0,94,0,98,0,102,0,106,0,114,0,90,0,94,0,98,0,102,0,106,0,110,0,114,0,118,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,78,0,78,0,78,0,78,0,78,0,78,0,78,0,170,0,170,0,170,0,170,0,170,0,170,0,170,0,170,0,242,0,242,0,242,0,242,0,242,0,242,0,242,0,242,0,212,0,212,0,212,0,212,0,212,0,212,0,212,0,212,0,222,0,222,0,222,0,222,0,222,0,222,0,222,0,222,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,214,0,214,0,214,0,214,0,214,0,214,0,214,0,214,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,38,0,58,0,62,0,70,0,74,0,78,0,82,0,90,0,58,0,62,0,66,0,70,0,74,0,78,0,86,0,94,0,62,0,66,0,70,0,72,0,76,0,82,0,90,0,98,0,70,0,70,0,72,0,74,0,78,0,86,0,94,0,102,0,74,0,74,0,76,0,78,0,82,0,90,0,98,0,106,0,78,0,78,0,82,0,86,0,90,0,94,0,102,0,110,0,82,0,86,0,90,0,94,0,98,0,102,0,106,0,114,0,90,0,94,0,98,0,102,0,106,0,110,0,114,0,118,0,38,0,58,0,62,0,70,0,74,0,78,0,82,0,90,0,58,0,62,0,66,0,70,0,74,0,78,0,86,0,94,0,62,0,66,0,70,0,72,0,76,0,82,0,90,0,98,0,70,0,70,0,72,0,74,0,78,0,86,0,94,0,102,0,74,0,74,0,76,0,78,0,82,0,90,0,98,0,106,0,78,0,78,0,82,0,86,0,90,0,94,0,102,0,110,0,82,0,86,0,90,0,94,0,98,0,102,0,106,0,114,0,90,0,94,0,98,0,102,0,106,0,110,0,114,0,118,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,78,0,78,0,78,0,78,0,78,0,78,0,78,0,170,0,170,0,170,0,170,0,170,0,170,0,170,0,170,0,242,0,242,0,242,0,242,0,242,0,242,0,242,0,242,0,212,0,212,0,212,0,212,0,212,0,212,0,212,0,212,0,222,0,222,0,222,0,222,0,222,0,222,0,222,0,222,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,214,0,214,0,214,0,214,0,214,0,214,0,214,0,214,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,30,0,62,0,74,0,82,0,62,0,74,0,82,0,94,0,74,0,82,0,94,0,122,0,82,0,94,0,122,0,146,0,30,0,62,0,74,0,82,0,62,0,74,0,82,0,86,0,74,0,82,0,86,0,94,0,82,0,86,0,94,0,102,0,0,4,8,12,1,5,9,13,2,6,10,14,3,7,11,15,43,0,86,1,129,1,214,1,43,2,43,2,86,2,214,2,86,1,86,1,214,1,1,2,43,2,86,2,214,2,1,3,129,1,214,1,43,2,43,2,86,2,214,2,214,2,43,3,214,1,214,1,43,2,43,2,86,2,214,2,1,3,86,3,214,1,43,2,43,2,86,2,171,2,214,2,86,3,1,4,43,2,43,2,86,2,171,2,214,2,86,3,1,4,129,4,43,2,43,2,86,2,214,2,43,3,214,3,171,4,171,5,43,2,86,2,214,2,43,3,214,3,171,4,171,5,1,7,86,0,171,4,86,9,86,9,1,19,1,19,1,19,1,19,171,4,171,4,86,9,86,9,1,19,1,19,1,19,1,19,86,9,86,9,1,19,1,19,171,26,171,26,171,26,171,26,86,9,86,9,1,19,1,19,171,26,171,26,171,26,171,26,1,19,1,19,171,26,171,26,171,26,171,26,171,26,171,26,1,19,1,19,171,26,171,26,171,26,171,26,171,26,171,26,1,19,1,19,171,26,171,26,171,26,171,26,171,26,171,26,1,19,1,19,171,26,171,26,171,26,171,26,171,26,171,26,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,129,3,129,3,129,3,129,3,129,3,129,3,129,3,129,3,43,4,43,4,43,4,43,4,43,4,43,4,43,4,43,4,214,4,214,4,214,4,214,4,214,4,214,4,214,4,214,4,129,5,129,5,129,5,129,5,129,5,129,5,129,5,129,5,43,6,43,6,43,6,43,6,43,6,43,6,43,6,43,6,214,6,214,6,214,6,214,6,214,6,214,6,214,6,214,6,129,7,129,7,129,7,129,7,129,7,129,7,129,7,129,7,43,8,43,8,43,8,43,8,43,8,43,8,43,8,43,8,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,22,0,171,0,214,0,1,1,1,1,43,1,43,1,86,1,171,0,171,0,1,1,1,1,43,1,43,1,86,1,129,1,214,0,1,1,1,1,43,1,43,1,86,1,86,1,129,1,1,1,1,1,1,1,43,1,43,1,86,1,129,1,171,1,1,1,1,1,43,1,43,1,86,1,129,1,171,1,1,2,1,1,43,1,43,1,86,1,129,1,171,1,1,2,86,2,43,1,43,1,43,1,129,1,129,1,214,1,86,2,214,2,43,1,43,1,129,1,129,1,214,1,86,2,214,2,129,3,86,0,86,2,171,4,171,4,86,9,86,9,86,9,86,9,86,2,86,2,171,4,171,4,86,9,86,9,86,9,86,9,171,4,171,4,86,9,86,9,86,13,86,13,86,13,86,13,171,4,171,4,86,9,86,9,86,13,86,13,86,13,86,13,86,9,86,9,86,13,86,13,86,13,86,13,86,13,86,13,86,9,86,9,86,13,86,13,86,13,86,13,86,13,86,13,86,9,86,9,86,13,86,13,86,13,86,13,86,13,86,13,86,9,86,9,86,13,86,13,86,13,86,13,86,13,86,13,171,1,171,1,214,1,171,1,171,1,171,1,214,1,214,1,171,1,171,1,214,1,171,1,171,1,171,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,171,1,171,1,214,1,214,1,171,1,171,1,214,1,214,1,171,1,171,1,214,1,171,1,171,1,171,1,214,1,214,1,171,1,171,1,214,1,171,1,171,1,171,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,171,6,171,6,129,9,129,9,86,13,86,13,86,13,86,13,171,6,171,6,129,9,129,9,86,13,86,13,86,13,86,13,129,9,129,9,86,13,86,13,214,18,214,18,214,18,214,18,129,9,129,9,86,13,86,13,214,18,214,18,214,18,214,18,86,13,86,13,214,18,214,18,86,13,86,13,86,13,86,13,86,13,86,13,214,18,214,18,86,13,86,13,86,13,86,13,86,13,86,13,214,18,214,18,86,13,86,13,86,13,86,13,86,13,86,13,214,18,214,18,86,13,86,13,86,13,86,13,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,214,4,214,4,214,4,214,4,214,4,214,4,214,4,214,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,86,0,171,0,171,0,214,0,214,0,214,0,214,0,1,1,171,0,171,0,214,0,214,0,214,0,214,0,1,1,1,1,171,0,214,0,214,0,214,0,214,0,1,1,1,1,1,1,214,0,214,0,214,0,214,0,1,1,1,1,1,1,43,1,214,0,214,0,214,0,1,1,1,1,1,1,43,1,43,1,214,0,214,0,1,1,1,1,1,1,43,1,43,1,43,1,214,0,1,1,1,1,1,1,43,1,43,1,43,1,86,1,1,1,1,1,1,1,43,1,43,1,43,1,86,1,86,1,86,3,86,3,171,4,171,4,171,6,171,6,171,6,171,6,86,3,86,3,171,4,171,4,171,6,171,6,171,6,171,6,171,4,171,4,171,6,171,6,86,9,86,9,86,9,86,9,171,4,171,4,171,6,171,6,86,9,86,9,86,9,86,9,171,6,171,6,86,9,86,9,171,6,171,6,171,6,171,6,171,6,171,6,86,9,86,9,171,6,171,6,171,6,171,6,171,6,171,6,86,9,86,9,171,6,171,6,171,6,171,6,171,6,171,6,86,9,86,9,171,6,171,6,171,6,171,6,22,0,214,0,1,1,43,1,214,0,1,1,43,1,86,1,1,1,43,1,86,1,171,1,43,1,86,1,171,1,1,2,129,0,1,4,171,5,171,5,1,4,1,4,171,5,171,5,171,5,171,5,1,8,1,8,171,5,171,5,1,8,1,8,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,43,0,43,0,43,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,107,0,214,0,1,1,43,1,214,0,1,1,43,1,43,1,1,1,43,1,43,1,86,1,43,1,43,1,86,1,86,1,1,2,1,4,214,4,214,4,1,4,1,4,214,4,214,4,214,4,214,4,171,5,171,5,214,4,214,4,171,5,171,5,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,43,0,43,0,43,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,128,2,224,1,64,1,240,0,160,0,120,0,192,2,224,1,96,1,240,0,96,1,32,1,176,0,144,0,0,0,0,0,0,8,1,9,16,24,2,3,17,25,10,11,32,40,48,56,4,5,6,7,33,41,49,57,18,19,26,27,12,13,14,15,34,35,43,42,50,51,59,58,20,21,22,23,31,30,29,28,36,37,38,39,47,46,45,44,52,53,54,55,63,62,61,60,0,1,4,5,8,12,2,3,9,13,6,7,10,11,14,15,0,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,8,0,0,0,6,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,255,255,255,1,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,1,0,0,0,255,255,255,255,255,255,255,255,1,0,0,0,32,11,29,0,108,0,0,0,16,75,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,102,31,0,108,0,0,0,192,61,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,102,230,62,205,204,76,63,143,194,117,63,0,0,128,63,226,2,46,5,32,9,250,13,244,17,30,22,55,26,50,30,46,34,25,38,209,41,208,45,33,50,147,54,195,58,197,15,80,192,13,0,144,195,13,0,144,193,13,0,144,194,13,0,240,192,13,0,144,195,13,0,253,49,81,63,225,64,200,60,63,144,156,61,9,193,170,188,177,191,44,189,132,127,145,60,206,0,151,60,150,63,31,189,227,111,219,61,26,48,56,190,20,176,13,62,220,126,121,188,229,127,114,189,199,47,188,61,6,16,30,190,21,112,47,62,5,192,120,189,216,159,4,189,217,95,54,189,250,207,10,62,92,255,174,188,237,183,38,190,32,8,16,62,59,0,98,60,79,64,147,188,10,128,209,189,201,143,184,61,61,96,30,61,174,127,23,189,63,224,161,189,19,96,88,61,66,96,229,61,245,215,11,190,194,192,243,188,21,56,9,62,243,143,158,189,158,63,237,60,133,95,42,189,156,192,244,188,14,48,51,62,249,135,229,62,240,247,179,62,178,127,30,61,252,143,172,189,244,55,49,190,250,207,106,62,34,252,139,186,21,112,175,189,197,255,189,189,237,183,22,62,15,128,184,61,253,159,131,190,252,143,236,61,236,223,53,61,26,48,136,61,245,243,134,190,255,151,123,62,193,111,131,189,118,192,53,189,171,63,194,60,128,127,10,61,199,15,149,189,51,224,140,61,128,128,53,188,82,128,168,188,193,111,131,189,237,239,60,62,232,135,49,190,42,0,6,61,203,47,195,61,6,16,30,190,231,255,37,62,197,143,145,189,63,0,233,189,19,96,88,62,19,16,243,189,60,191,168,60,80,224,93,189,88,255,103,58,6,132,158,62,1,172,29,63,1,116,151,62,0,96,204,61,254,207,214,189,255,255,178,61,255,191,35,190,0,160,70,61,255,159,41,189,2,0,150,60,252,79,243,61,255,31,59,189,0,128,174,188,1,96,22,61,2,8,36,190,1,224,21,61,255,215,39,62,1,0,58,189,255,63,176,188,0,112,180,189,255,255,118,61,3,128,224,60,254,63,180,60,252,63,242,189,0,24,4,62,3,192,31,190,0,0,72,62,0,0,1,189,3,168,19,190,250,207,255,61,0,0,8,190,0,80,200,61,0,32,133,61,1,128,121,189,1,96,101,189,0,128,165,61,255,63,95,189,4,0,75,188,255,63,143,60,255,63,155,61,253,127,225,189,0,48,196,61,0,96,42,189,1,96,160,189,251,255,237,61,255,191,159,188,0,48,128,189,0,64,135,188,1,128,148,61,254,191,245,61,2,176,67,190,255,255,50,61,0,16,225,189,253,199,24,62,252,255,56,60,2,192,141,60,255,95,17,189,0,96,178,189,255,63,111,61,4,0,156,58,255,31,151,189,254,223,215,61,255,239,185,61,2,80,251,189,255,111,214,61,0,68,60,63,1,112,163,62,255,119,36,190,255,191,190,188,0,0,128,61,253,191,231,188,255,31,91,61,254,175,207,189,0,64,138,61,255,255,162,60,0,32,134,189,0,112,155,61,255,47,221,189,254,103,0,62,0,176,131,189,251,255,58,188,254,127,156,188,3,112,5,62,255,103,43,190,0,176,139,61,0,64,104,61,255,15,173,189,1,0,186,60,0,128,14,61,255,191,190,188,0,224,73,189,4,192,253,61,0,240,14,190,0,96,186,61,255,95,17,189,0,192,182,60,0,64,9,189,3,192,200,60,1,0,167,59,0,128,178,188,255,127,151,60,254,255,139,188,255,191,159,60,1,0,172,58,255,191,92,189,0,192,201,61,0,224,173,189,0,64,166,60,255,191,190,60,1,0,233,59,0,64,122,189,255,95,33,61,0,224,105,61,1,224,216,189,0,0,1,61,0,96,169,61,254,127,252,189,0,128,226,61,2,176,3,190,254,95,37,62,3,112,5,190,255,95,67,61,254,255,87,59,3,0,145,188,255,63,77,61,0,160,153,189,255,63,239,60,255,255,135,60,0,192,158,61,253,131,108,63,21,112,239,61,7,64,252,189,223,191,185,61,143,255,2,189,208,128,250,188,250,207,154,61,1,48,190,189,2,240,175,61,38,112,139,189,172,31,91,61,49,96,73,189,221,63,86,61,80,224,93,189,101,224,64,61,151,0,252,188,212,127,86,60,13,252,168,187,193,254,107,60,197,255,29,189,222,255,135,61,58,32,169,189,20,176,157,61,2,160,74,189,206,255,43,60,2,129,206,60,155,31,63,189,174,127,87,61,100,32,79,189,149,159,84,61,32,240,128,189,192,63,165,61,28,64,191,189,199,15,181,61,62,64,119,189,100,63,139,60,155,0,195,60,117,32,43,189,107,128,210,60,249,191,163,60,128,128,132,132,124,124,127,133,129,123,133,127,123,129,140,140,116,116,131,141,125,115,141,131,115,125,119,137,137,119,137,119,119,137,140,149,116,107,149,140,107,116,124,144,132,112,144,124,112,132,150,150,106,106,130,152,126,104,152,130,104,126,151,162,105,94,162,151,94,105,162,162,94,94,139,163,117,93,163,139,93,117,113,149,143,107,149,113,107,143,120,157,136,99,157,120,99,136,127,167,129,89,167,127,89,129,164,177,92,79,177,164,79,92,150,177,106,79,177,150,79,106,178,178,78,78,101,155,155,101,155,101,101,155,137,180,119,76,180,137,76,119,106,163,150,93,163,106,93,150,115,172,141,84,172,115,84,141,180,195,76,61,195,180,61,76,164,195,92,61,195,164,61,92,196,196,60,60,150,198,106,58,198,150,58,106,124,186,132,70,186,124,70,132,91,171,165,85,171,91,85,165,99,180,157,76,180,99,76,157,134,202,122,54,202,134,54,122,182,215,74,41,215,182,41,74,200,215,56,41,215,200,41,56,164,216,92,40,216,164,40,92,108,193,148,63,193,108,63,148,217,217,39,39,128,128,0,0,3,0,4,0,3,0,6,0,3,0,1,0,5,0,9,0,5,0,25,0,5,0,13,0,5,0,29,0,5,0,35,0,6,0,19,0,6,0,51,0,6,0,11,0,6,0,43,0,6,0,27,0,6,0,7,0,8,0,135,0,8,0,39,0,8,0,167,0,8,0,103,0,8,0,231,0,8,0,151,0,8,0,87,0,8,0,55,0,8,0,183,0,8,0,247,0,8,0,15,0,9,0,143,0,9,0,143,1,9,0,79,1,9,0,207,0,9,0,47,0,9,0,47,1,9,0,175,1,9,0,111,0,9,0,239,0,9,0,239,1,9,0,31,0,10,0,31,2,10,0,31,1,10,0,31,3,10,0,159,0,10,0,159,2,10,0,159,1,10,0,159,3,10,0,95,0,10,0,95,2,10,0,95,1,10,0,95,3,10,0,223,0,10,0,223,2,10,0,223,1,10,0,223,3,10,0,63,0,13,0,63,16,13,0,63,8,13,0,63,24,13,0,63,4,13,0,63,20,13,0,63,12,13,0,63,28,13,0,63,2,13,0,63,18,13,0,63,10,13,0,63,26,13,0,63,6,13,0,63,22,13,0,63,14,13,0,63,30,13,0,63,1,13,0,63,17,13,0,63,9,13,0,63,25,13,0,63,5,13,0,63,21,13,0,63,13,13,0,63,29,13,0,63,3,13,0,63,19,13,0,63,11,13,0,63,27,13,0,63,7,13,0,63,23,13,0,63,15,13,0,63,31,13,0,191,0,13,0,191,16,13,0,191,8,13,0,191,24,13,0,191,4,13,0,191,20,13,0,191,12,13,0,191,28,13,0,191,2,13,0,191,18,13,0,191,10,13,0,191,26,13,0,191,6,13,0,191,22,13,0,191,14,13,0,191,30,13,0,191,1,13,0,191,17,13,0,191,9,13,0,191,25,13,0,191,5,13,0,191,21,13,0,191,13,13,0,191,29,13,0,191,3,13,0,191,19,13,0,191,11,13,0,191,27,13,0,191,7,13,0,191,23,13,0,191,15,13,0,191,31,13,0,127,0,14,0,127,32,14,0,127,16,14,0,127,48,14,0,127,8,14,0,127,40,14,0,127,24,14,0,127,56,14,0,127,4,14,0,127,36,14,0,127,20,14,0,2,0,3,0,17,0,5,0,5,0,5,0,21,0,5,0,3,0,6,0,59,0,6,0,71,0,8,0,199,0,8,0,23,0,8,0,215,0,8,0,119,0,8,0,15,1,9,0,79,0,9,0,207,1,9,0,175,0,9,0,111,1,9,0,0,0,0,0,0,128,190,255,28,0,104,0,169,0,224,0,18,1,62,1,102,1,139,1,173,1,203,1,232,1,2,2,27,2,54,2,54,2,27,2,2,2,232,1,203,1,173,1,139,1,102,1,62,1,18,1,224,0,169,0,104,0,28,0,190,255,0,128,0,128,4,0,135,0,213,0,17,1,67,1,117,1,169,1,169,1,117,1,67,1,17,1,213,0,135,0,4,0,0,128,0,128,135,0,17,1,117,1,117,1,17,1,135,0,0,128,116,0,109,1,109,1,116,0,198,1,0,0,110,2,0,0,112,2,0,0,200,1,0,0,114,2,0,0,116,2,0,0,50,1,0,0,40,3,0,0,64,0,0,0,36,3,0,0,140,2,0,0,192,0,0,0,176,1,0,0,188,0,0,0,166,1,0,0,110,2,0,0,198,1,0,0,110,2,0,0,112,2,0,0,200,1,0,0,114,2,0,0,116,2,0,0,118,2,0,0,120,2,0,0,122,2,0,0,124,2,0,0,126,2,0,0,128,2,0,0,130,2,0,0,132,2,0,0,134,2,0,0,136,2,0,0,111,78,12,53,182,49,118,53,128,68,146,53,208,239,125,52,250,53,149,180,185,42,13,181,156,145,248,180,181,225,53,55,246,189,76,183,246,58,184,183,36,22,179,183,47,254,166,183,185,134,145,183,29,15,73,183,232,241,243,182,45,92,211,182,151,109,38,55,1,78,92,55,92,32,120,55,225,112,166,55,240,150,222,55,254,9,14,56,235,99,46,56,45,211,80,56,117,9,249,183,148,108,24,184,112,148,37,184,36,13,52,184,143,177,69,184,152,157,99,184,18,127,129,184,222,134,134,184,253,139,236,56,206,12,26,57,55,246,61,57,191,100,102,57,58,62,136,57,182,75,157,57,246,222,177,57,157,175,193,57,30,210,222,185,185,207,237,185,12,26,254,185,166,12,6,186,137,169,11,186,143,156,15,186,64,107,17,186,10,80,17,186,118,96,128,58,13,144,147,58,99,69,166,58,150,29,184,58,225,207,200,58,82,5,216,58,4,102,229,58,187,235,240,58,7,232,248,186,114,241,254,186,141,204,0,187,237,104,0,187,119,87,252,186,156,231,243,186,242,93,231,186,162,167,214,186,6,255,138,59,148,153,150,59,20,11,161,59,24,29,170,59,238,149,177,59,48,61,183,59,204,220,186,59,21,61,188,59,178,62,187,187,236,156,183,187,56,63,177,187,251,254,167,187,219,190,155,187,97,103,140,187,159,208,115,187,24,116,72,187,82,35,161,60,122,12,174,60,215,160,186,60,37,200,198,60,125,106,210,60,172,112,221,60,135,196,231,60,49,81,241,60,199,2,250,188,236,227,0,189,0,72,4,189,146,38,7,189,158,121,9,189,59,60,11,189,177,106,12,189,147,2,13,189,43,254,147,188,168,181,134,188,76,196,114,188], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+893420);
/* memory initializer */ allocate([177,55,88,188,47,244,61,188,148,38,36,188,149,249,10,188,213,41,229,187,6,61,182,59,119,112,137,59,248,1,62,59,150,148,220,58,44,92,16,58,60,38,1,186,94,53,189,186,114,179,22,187,149,233,124,187,68,108,98,187,180,235,70,187,81,214,42,187,138,146,14,187,220,249,228,186,40,217,173,186,177,207,112,186,251,84,10,58,99,96,37,57,245,183,69,185,127,31,5,186,240,35,81,186,94,128,138,186,244,49,168,186,179,156,193,186,63,211,89,186,207,93,51,186,197,94,13,186,89,109,209,185,246,184,139,185,235,56,20,185,96,101,210,183,121,206,176,56,133,90,63,185,99,219,140,185,204,214,179,185,6,237,212,185,49,2,240,185,26,94,2,186,35,185,9,186,166,214,14,186,215,112,169,184,170,246,95,184,238,253,218,183,59,146,223,181,49,119,155,55,170,97,21,56,180,63,81,56,185,31,108,56,105,103,116,184,22,159,130,184,232,60,147,184,49,249,156,184,212,166,159,184,81,67,153,184,4,64,143,184,36,49,135,184,95,200,75,184,80,31,65,184,36,41,62,184,122,97,46,184,19,15,27,184,91,124,7,184,29,64,233,183,30,100,197,183,51,24,243,53,249,117,25,181,26,35,207,181,252,189,48,182,91,246,139,182,162,229,4,183,195,53,48,183,180,183,25,183,203,229,235,182,192,100,214,182,253,254,154,182,100,146,90,182,107,20,27,182,103,98,192,181,184,52,33,181,122,158,70,55,61,113,48,55,237,128,89,50,44,166,23,51,246,144,10,51,242,178,62,179,204,131,225,180,206,94,88,181,86,152,28,181,86,152,28,181,206,94,88,181,204,131,225,180,242,178,62,179,246,144,10,51,44,166,23,51,237,128,89,50,61,113,48,55,122,158,70,183,184,52,33,53,103,98,192,53,107,20,27,54,100,146,90,54,253,254,154,54,192,100,214,54,203,229,235,54,180,183,25,183,195,53,48,183,162,229,4,183,91,246,139,182,252,189,48,182,26,35,207,181,249,117,25,181,51,24,243,53,30,100,197,55,29,64,233,55,91,124,7,56,19,15,27,56,122,97,46,56,36,41,62,56,80,31,65,56,95,200,75,56,36,49,135,184,4,64,143,184,81,67,153,184,212,166,159,184,49,249,156,184,232,60,147,184,22,159,130,184,105,103,116,184,185,31,108,184,180,63,81,184,170,97,21,184,49,119,155,183,59,146,223,53,238,253,218,55,170,246,95,56,215,112,169,56,166,214,14,186,35,185,9,186,26,94,2,186,49,2,240,185,6,237,212,185,204,214,179,185,99,219,140,185,133,90,63,185,121,206,176,184,96,101,210,55,235,56,20,57,246,184,139,57,89,109,209,57,197,94,13,58,207,93,51,58,63,211,89,58,179,156,193,186,244,49,168,186,94,128,138,186,240,35,81,186,127,31,5,186,245,183,69,185,99,96,37,57,251,84,10,58,177,207,112,58,40,217,173,58,220,249,228,58,138,146,14,59,81,214,42,59,180,235,70,59,68,108,98,59,149,233,124,59,114,179,22,187,94,53,189,186,60,38,1,186,44,92,16,58,150,148,220,58,248,1,62,59,119,112,137,59,6,61,182,59,213,41,229,59,149,249,10,60,148,38,36,60,47,244,61,60,177,55,88,60,76,196,114,60,168,181,134,60,43,254,147,60,147,2,13,189,177,106,12,189,59,60,11,189,158,121,9,189,146,38,7,189,0,72,4,189,236,227,0,189,199,2,250,188,49,81,241,188,135,196,231,188,172,112,221,188,125,106,210,188,37,200,198,188,215,160,186,188,122,12,174,188,82,35,161,188,24,116,72,187,159,208,115,187,97,103,140,187,219,190,155,187,251,254,167,187,56,63,177,187,236,156,183,187,178,62,187,187,21,61,188,187,204,220,186,187,48,61,183,187,238,149,177,187,24,29,170,187,20,11,161,187,148,153,150,187,6,255,138,187,162,167,214,186,242,93,231,186,156,231,243,186,119,87,252,186,237,104,0,187,141,204,0,187,114,241,254,186,7,232,248,186,187,235,240,186,4,102,229,186,82,5,216,186,225,207,200,186,150,29,184,186,99,69,166,186,13,144,147,186,118,96,128,186,10,80,17,186,64,107,17,186,143,156,15,186,137,169,11,186,166,12,6,186,12,26,254,185,185,207,237,185,30,210,222,185,157,175,193,185,246,222,177,185,182,75,157,185,58,62,136,185,191,100,102,185,55,246,61,185,206,12,26,185,253,139,236,184,222,134,134,184,18,127,129,184,152,157,99,184,143,177,69,184,36,13,52,184,112,148,37,184,148,108,24,184,117,9,249,183,45,211,80,184,235,99,46,184,254,9,14,184,240,150,222,183,225,112,166,183,92,32,120,183,1,78,92,183,151,109,38,183,45,92,211,182,232,241,243,182,29,15,73,183,185,134,145,183,47,254,166,183,36,22,179,183,246,58,184,183,246,189,76,183,181,225,53,183,156,145,248,52,185,42,13,53,250,53,149,52,208,239,125,180,128,68,146,181,182,49,118,181,111,78,12,181,144,6,29,0,108,0,0,0,16,75,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,36,1,0,154,153,1,0,37,73,2,0,52,51,3,0,0,0,4,0,86,85,5,0,0,0,8,0,0,0,0,0,60,0,0,0,58,0,0,0,64,0,0,0,62,0,0,0,68,0,0,0,66,0,0,0,72,0,0,0,70,0,0,0,56,0,0,0,54,0,0,0,132,0,0,0,34,1,0,0,38,1,0,0,36,1,0,0,0,2,4,6,8,9,10,11,12,13,14,15,16,0,0,0,0,0,0,0,171,170,42,63,205,204,204,62,37,73,146,62,57,142,99,62,137,136,8,62,8,33,132,61,33,8,2,61,0,8,45,8,91,8,138,8,185,8,234,8,28,9,79,9,131,9,185,9,239,9,39,10,96,10,154,10,214,10,18,11,80,11,144,11,209,11,19,12,86,12,156,12,226,12,43,13,116,13,192,13,13,14,92,14,172,14,254,14,82,15,168,15,2,0,2,0,6,0,3,0,14,0,4,0,12,0,5,0,13,0,5,0,16,0,6,0,17,0,6,0,18,0,6,0,22,0,7,0,27,0,8,0,32,0,9,0,33,0,9,0,26,0,9,0,27,0,9,0,28,0,9,0,29,0,9,0,30,0,9,0,31,0,9,0,35,0,11,0,34,0,11,0,87,0,12,0,86,0,12,0,85,0,12,0,84,0,12,0,83,0,12,0,15,0,4,0,20,0,6,0,20,0,7,0,30,0,8,0,15,0,10,0,33,0,11,0,80,0,12,0,11,0,5,0,21,0,7,0,14,0,10,0,9,0,10,0,21,0,6,0,29,0,8,0,13,0,10,0,81,0,12,0,19,0,6,0,35,0,9,0,7,0,11,0,23,0,7,0,34,0,9,0,82,0,12,0,28,0,8,0,12,0,10,0,31,0,8,0,11,0,10,0,37,0,9,0,10,0,10,0,36,0,9,0,6,0,11,0,33,0,10,0,32,0,10,0,8,0,10,0,32,0,11,0,7,0,4,0,12,0,6,0,16,0,7,0,19,0,8,0,17,0,9,0,18,0,9,0,4,0,10,0,39,0,11,0,38,0,11,0,95,0,12,0,15,0,6,0,19,0,9,0,5,0,10,0,37,0,11,0,14,0,6,0,20,0,9,0,36,0,11,0,13,0,6,0,6,0,10,0,94,0,12,0,17,0,7,0,7,0,10,0,19,0,7,0,93,0,12,0,18,0,7,0,92,0,12,0,20,0,8,0,91,0,12,0,21,0,8,0,26,0,8,0,25,0,8,0,24,0,8,0,23,0,8,0,22,0,8,0,25,0,9,0,21,0,9,0,22,0,9,0,24,0,9,0,23,0,9,0,4,0,11,0,5,0,11,0,88,0,12,0,89,0,12,0,90,0,12,0,3,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,7,7,7,7,7,8,8,8,8,9,9,9,9,10,10,11,11,12,12,13,14,15,16,17,18,19,0,0,0,0,0,1,1,1,1,1,2,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,1,2,3,4,5,6,7,8,9,10,11,12,13,1,2,3,4,5,6,7,8,9,10,11,1,2,3,4,5,6,7,8,9,1,2,3,4,5,6,1,2,3,4,5,6,1,2,3,4,5,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,1,2,1,2,1,1,1,1,1,1,1,1,2,3,4,5,1,2,3,4,5,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,6,0,3,0,7,0,3,0,10,0,4,0,9,0,5,0,20,0,6,0,21,0,6,0,52,0,7,0,116,0,8,0,117,0,8,0,221,0,9,0,236,0,9,0,236,1,10,0,237,1,10,0,244,1,10,0,236,3,11,0,237,3,11,0,244,3,11,0,125,7,12,0,188,7,12,0,189,15,13,0,220,15,13,0,189,7,12,0,221,15,13,0,189,31,14,0,220,31,14,0,221,31,14,0,252,31,15,0,1,0,4,0,8,0,5,0,45,0,7,0,108,0,8,0,109,0,8,0,220,0,9,0,221,1,10,0,220,3,11,0,221,3,11,0,124,7,12,0,188,15,13,0,125,31,14,0,188,31,14,0,4,0,5,0,44,0,7,0,188,0,9,0,220,1,10,0,188,3,11,0,189,3,11,0,253,14,13,0,124,15,13,0,125,15,13,0,253,30,14,0,124,31,14,0,5,0,5,0,92,0,8,0,189,0,9,0,125,3,11,0,252,6,12,0,252,14,13,0,253,29,14,0,252,30,14,0,253,31,15,0,12,0,6,0,93,0,8,0,189,1,10,0,253,3,12,0,253,6,12,0,253,27,14,0,13,0,6,0,125,0,9,0,252,2,11,0,252,5,12,0,252,27,14,0,252,29,14,0,28,0,7,0,124,1,10,0,253,2,11,0,253,5,12,0,252,47,15,0,29,0,7,0,125,1,10,0,124,3,11,0,253,13,13,0,253,47,15,0,60,0,8,0,188,1,10,0,253,11,13,0,253,23,14,0,61,0,8,0,253,1,11,0,252,13,13,0,252,55,15,0,124,0,9,0,252,3,12,0,252,0,10,0,252,11,13,0,253,0,10,0,253,55,15,0,252,1,11,0,252,7,13,0,253,7,13,0,252,15,14,0,253,15,14,0,252,23,14,0,252,59,15,0,11,0,4,0,120,0,8,0,245,3,11,0,236,15,13,0,236,31,14,0,18,0,5,0,237,0,9,0,220,7,12,0,237,31,14,0,253,59,15,0,19,0,5,0,248,3,11,0,252,61,15,0,24,0,6,0,221,7,12,0,25,0,6,0,236,7,12,0,34,0,6,0,237,15,13,0,35,0,6,0,244,15,13,0,53,0,7,0,245,15,13,0,56,0,7,0,248,15,13,0,57,0,7,0,249,15,13,0,66,0,7,0,244,31,14,0,67,0,7,0,245,31,14,0,121,0,8,0,248,31,14,0,130,0,8,0,253,61,15,0,131,0,8,0,244,0,9,0,245,0,9,0,248,0,9,0,249,0,9,0,2,1,9,0,3,1,9,0,245,1,10,0,248,1,10,0,249,1,10,0,2,2,10,0,3,2,10,0,249,3,11,0,2,4,11,0,3,4,11,0,237,7,12,0,244,7,12,0,245,7,12,0,248,7,12,0,249,7,12,0,2,8,12,0,3,8,12,0,2,16,13,0,3,16,13,0,249,31,14,0,2,32,14,0,3,32,14,0,252,62,15,0,253,62,15,0,124,63,15,0,125,63,15,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,7,7,8,8,9,9,10,11,12,13,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,3,3,3,4,4,5,5,6,6,7,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,0,0,0,26,10,1,0,0,0,0,7,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,1,2,3,4,5,6,7,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,1,1,1,1,2,3,4,5,6,7,8,9,10,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,1,1,1,255,1,1,1,2,1,255,2,1,1,3,1,255,3,1,1,4,1,255,4,1,1,5,1,255,5,1,1,6,1,255,6,1,1,7,1,255,7,1,1,8,1,255,8,1,1,9,1,255,9,1,1,10,1,255,10,1,1,11,1,255,11,1,2,1,2,254,1,2,1,12,1,255,12,1,1,13,1,255,13,1,1,14,1,255,14,1,1,15,1,255,15,1,2,2,2,254,2,2,1,16,1,255,16,1,1,17,1,255,17,1,3,1,3,253,1,3,1,18,1,255,18,1,1,19,1,255,19,1,2,3,2,254,3,2,1,20,1,255,20,1,1,21,1,255,21,1,2,4,2,254,4,2,1,22,1,255,22,1,2,5,2,254,5,2,1,23,1,255,23,1,0,0,0,0,4,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,255,255,255,2,0,0,0,0,0,0,0,23,0,0,0,1,1,0,255,1,0,1,2,0,255,2,0,2,1,1,254,1,1,1,3,0,255,3,0,0,0,0,1,4,0,255,4,0,1,5,0,255,5,0,1,6,0,255,6,0,3,1,2,253,1,2,2,2,1,254,2,1,1,7,0,255,7,0,1,8,0,255,8,0,1,9,0,255,9,0,2,3,1,254,3,1,4,1,2,252,1,2,1,10,0,255,10,0,1,11,0,255,11,0,2,4,1,254,4,1,3,2,2,253,2,2,1,12,0,255,12,0,2,5,1,254,5,1,5,1,3,251,1,3,1,13,0,255,13,0,2,6,1,254,6,1,1,14,0,255,14,0,2,7,1,254,7,1,2,8,1,254,8,1,3,3,2,253,3,2,6,1,3,250,1,3,1,15,0,255,15,0,0,7,4,4,3,3,3,3,3,2,2,2,2,2,2,2,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,1,0,0,0,15,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,1,2,0,255,2,0,3,1,1,253,1,1,0,0,0,1,3,0,255,3,0,2,2,0,254,2,0,4,1,1,252,1,1,1,4,0,255,4,0,5,1,2,251,1,2,1,5,0,255,5,0,3,2,1,253,2,1,2,3,0,254,3,0,1,6,0,255,6,0,6,1,2,250,1,2,2,4,0,254,4,0,1,7,0,255,7,0,4,2,1,252,2,1,7,1,2,249,1,2,3,3,1,253,3,1,2,5,0,254,5,0,1,8,0,255,8,0,2,6,0,254,6,0,8,1,3,248,1,3,1,9,0,255,9,0,5,2,2,251,2,2,3,4,1,253,4,1,2,7,0,254,7,0,9,1,3,247,1,3,1,10,0,255,10,0,0,10,6,4,4,3,3,3,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,2,0,0,0,10,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,1,2,0,255,2,0,0,0,0,4,1,0,252,1,0,5,1,1,251,1,1,2,2,0,254,2,0,1,3,0,255,3,0,6,1,1,250,1,1,3,2,0,253,2,0,7,1,1,249,1,1,1,4,0,255,4,0,8,1,2,248,1,2,2,3,0,254,3,0,4,2,0,252,2,0,1,5,0,255,5,0,9,1,2,247,1,2,5,2,1,251,2,1,2,4,0,254,4,0,10,1,2,246,1,2,3,3,0,253,3,0,1,6,0,255,6,0,11,1,3,245,1,3,6,2,1,250,2,1,1,7,0,255,7,0,2,5,0,254,5,0,3,4,0,253,4,0,12,1,3,244,1,3,4,3,0,252,3,0,0,13,7,5,4,3,2,2,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,2,0,0,0,4,0,0,0,7,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,0,0,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,1,2,0,255,2,0,7,1,0,249,1,0,8,1,1,248,1,1,2,2,0,254,2,0,9,1,1,247,1,1,10,1,1,246,1,1,1,3,0,255,3,0,3,2,0,253,2,0,11,1,2,245,1,2,4,2,0,252,2,0,12,1,2,244,1,2,13,1,2,243,1,2,5,2,0,251,2,0,1,4,0,255,4,0,2,3,0,254,3,0,14,1,2,242,1,2,6,2,0,250,2,0,15,1,2,241,1,2,16,1,2,240,1,2,3,3,0,253,3,0,1,5,0,255,5,0,7,2,0,249,2,0,17,1,2,239,1,2,0,18,8,4,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,7,0,0,0,5,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,7,1,0,249,1,0,8,1,0,248,1,0,9,1,0,247,1,0,10,1,0,246,1,0,1,2,0,255,2,0,11,1,1,245,1,1,12,1,1,244,1,1,13,1,1,243,1,1,2,2,0,254,2,0,14,1,1,242,1,1,15,1,1,241,1,1,3,2,0,253,2,0,16,1,1,240,1,1,1,3,0,255,3,0,17,1,1,239,1,1,4,2,0,252,2,0,18,1,1,238,1,1,5,2,0,251,2,0,19,1,1,237,1,1,20,1,1,236,1,1,6,2,0,250,2,0,21,1,1,235,1,1,2,3,0,254,3,0,0,22,7,3,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,10,0,0,0,3,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,7,1,0,249,1,0,8,1,0,248,1,0,9,1,0,247,1,0,10,1,0,246,1,0,11,1,0,245,1,0,12,1,0,244,1,0,13,1,0,243,1,0,14,1,0,242,1,0,15,1,0,241,1,0,16,1,0,240,1,0,1,2,0,255,2,0,17,1,0,239,1,0,18,1,0,238,1,0,19,1,0,237,1,0,20,1,0,236,1,0,21,1,0,235,1,0,2,2,0,254,2,0,22,1,0,234,1,0,23,1,0,233,1,0,24,1,0,232,1,0,25,1,0,231,1,0,3,2,0,253,2,0,26,1,0,230,1,0,0,27,4,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,255,255,255,127,2,0,0,0,8,0,0,0,0,0,0,0,104,179,42,62,0,0,0,63,38,83,85,63,0,0,0,0,0,0,0,0,39,160,169,62,154,153,41,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,47,0,51,0,56,0,61,0,66,0,72,0,79,0,86,0,94,0,102,0,112,0,122,0,133,0,145,0,158,0,173,0,189,0,206,0,225,0,245,0,11,1,36,1,62,1,92,1,123,1,158,1,196,1,237,1,26,2,75,2,128,2,187,2,251,2,64,3,140,3,223,3,57,4,156,4,8,5,125,5,254,5,137,6,34,7,201,7,127,8,69,9,30,10,10,11,12,12,37,13,88,14,168,15,21,17,164,18,88,20,51,22,58,24,111,26,217,28,123,31,90,34,125,37,232,40,164,44,183,48,41,53,3,58,78,63,21,69,98,75,68,82,197,89,246,97,231,106,168,116,77,127,235,138,152,151,110,165,134,180,255,196,249,214,151,234,255,255,1,0,1,0,105,21,7,41,1,59,122,75,146,90,104,104,21,117,179,128,88,139,25,149,10,158,59,166,188,173,158,180,235,186,178,192,253,197,215,202,73,207,92,211,24,215,131,218,166,221,133,224,39,227,145,229,198,231,205,233,168,235,92,237,235,238,88,240,168,241,219,242,244,243,246,244,226,245,187,246,129,247,55,248,222,248,119,249,2,250,131,250,248,250,100,251,199,251,33,252,116,252,192,252,5,253,69,253,128,253,181,253,230,253,19,254,60,254,98,254,133,254,164,254,194,254,220,254,245,254,11,255,31,255,50,255,67,255,83,255,98,255,111,255,123,255,134,255,144,255,154,255,162,255,170,255,177,255,184,255,190,255,195,255,200,255,205,255,209,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,240,157,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,3,0,0,158,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,84,31,0,216,161,30,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,96,13,30,0,216,161,30,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,11,35,0,108,0,0,0,128,222,13,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,0,0,1,0,1,0,1,0,1,0,0,0,0,1,0,1,0,0,1,0,1,0,1,0,1,0,0,0,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,0,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,1,1,1,1,1,1,1,1,0,1,0,1,1,0,1,0,1,1,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,9,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,0,0,0,0,0,1,1,1,1,1,2,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,1,2,3,4,5,6,7,8,9,10,1,2,3,4,5,6,7,1,2,3,4,5,6,7,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,4,5,1,2,3,4,5,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,6,0,3,0,1,0,4,0,4,0,5,0,28,0,7,0,60,0,8,0,61,0,8,0,124,0,9,0,252,0,10,0,253,0,10,0,252,1,11,0,253,1,11,0,252,3,12,0,252,7,13,0,253,7,13,0,252,11,13,0,253,11,13,0,252,15,14,0,253,15,14,0,252,31,15,0,7,0,3,0,12,0,6,0,92,0,8,0,125,0,9,0,124,1,10,0,252,2,11,0,253,3,12,0,252,13,13,0,252,23,14,0,253,23,14,0,10,0,4,0,29,0,7,0,188,0,9,0,253,2,11,0,252,5,12,0,252,27,14,0,253,27,14,0,5,0,5,0,93,0,8,0,125,1,10,0,253,5,12,0,253,13,13,0,252,29,14,0,253,31,15,0,8,0,5,0,108,0,8,0,124,3,11,0,252,14,13,0,252,47,15,0,9,0,5,0,189,0,9,0,125,3,11,0,253,14,13,0,13,0,6,0,188,1,10,0,252,6,12,0,253,29,14,0,20,0,6,0,189,1,10,0,253,6,12,0,253,47,15,0,21,0,6,0,220,1,10,0,124,15,13,0,44,0,7,0,221,1,10,0,252,30,14,0,45,0,7,0,188,3,11,0,52,0,7,0,124,7,12,0,109,0,8,0,125,15,13,0,116,0,8,0,253,30,14,0,117,0,8,0,124,31,14,0,220,0,9,0,125,31,14,0,221,0,9,0,188,31,14,0,236,0,9,0,252,55,15,0,236,1,10,0,237,1,10,0,244,1,10,0,189,3,11,0,220,3,11,0,221,3,11,0,236,3,11,0,237,3,11,0,244,3,11,0,125,7,12,0,188,7,12,0,189,7,12,0,188,15,13,0,189,15,13,0,220,15,13,0,221,15,13,0,189,31,14,0,220,31,14,0,221,31,14,0,253,55,15,0,252,59,15,0,11,0,4,0,120,0,8,0,245,3,11,0,236,15,13,0,236,31,14,0,18,0,5,0,237,0,9,0,220,7,12,0,237,31,14,0,253,59,15,0,19,0,5,0,248,3,11,0,252,61,15,0,24,0,6,0,221,7,12,0,25,0,6,0,236,7,12,0,34,0,6,0,237,15,13,0,35,0,6,0,244,15,13,0,53,0,7,0,245,15,13,0,56,0,7,0,248,15,13,0,57,0,7,0,249,15,13,0,66,0,7,0,244,31,14,0,67,0,7,0,245,31,14,0,121,0,8,0,248,31,14,0,130,0,8,0,253,61,15,0,131,0,8,0,244,0,9,0,245,0,9,0,248,0,9,0,249,0,9,0,2,1,9,0,3,1,9,0,245,1,10,0,248,1,10,0,249,1,10,0,2,2,10,0,3,2,10,0,249,3,11,0,2,4,11,0,3,4,11,0,237,7,12,0,244,7,12,0,245,7,12,0,248,7,12,0,249,7,12,0,2,8,12,0,3,8,12,0,2,16,13,0,3,16,13,0,249,31,14,0,2,32,14,0,3,32,14,0,252,62,15,0,253,62,15,0,124,63,15,0,125,63,15,0,0,0,4,0,0,0,1,1,1,2,2,2,3,3,3,4,4,1,1,2,2,2,3,3,3,4,4,4,4,4,0,0,0,0,0,0,1,1,1,255,1,1,1,2,1,255,2,1,1,3,1,255,3,1,1,4,1,255,4,1,1,5,1,255,5,1,1,6,1,255,6,1,1,7,1,255,7,1,1,8,1,255,8,1,1,9,1,255,9,1,1,10,1,255,10,1,1,11,1,255,11,1,1,12,1,255,12,1,1,13,1,255,13,1,2,1,2,254,1,2,1,14,1,255,14,1,1,15,1,255,15,1,1,16,1,255,16,1,1,17,1,255,17,1,1,18,1,255,18,1,1,19,1,255,19,1,3,1,3,253,1,3,1,20,1,255,20,1,1,21,1,255,21,1,2,2,2,254,2,2,1,22,1,255,22,1,1,23,1,255,23,1,1,24,1,255,24,1,1,25,1,255,25,1,1,26,1,255,26,1,0,0,0,0,4,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,0,0,0,0,0,0,0,26,0,0,0,1,1,0,255,1,0,0,0,0,1,2,0,255,2,0,1,3,0,255,3,0,1,4,0,255,4,0,1,5,0,255,5,0,1,6,0,255,6,0,2,1,1,254,1,1,1,7,0,255,7,0,1,8,0,255,8,0,1,9,0,255,9,0,1,10,0,255,10,0,2,2,1,254,2,1,1,11,0,255,11,0,1,12,0,255,12,0,3,1,2,253,1,2,1,13,0,255,13,0,1,14,0,255,14,0,2,3,1,254,3,1,1,15,0,255,15,0,2,4,1,254,4,1,1,16,0,255,16,0,2,5,1,254,5,1,1,17,0,255,17,0,4,1,3,252,1,3,2,6,1,254,6,1,1,18,0,255,18,0,1,19,0,255,19,0,2,7,1,254,7,1,3,2,2,253,2,2,0,5,4,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,255,255,255,255,255,255,255,2,0,0,0,1,0,0,0,19,0,0,0,1,1,0,255,1,0,0,0,0,1,2,0,255,2,0,2,1,0,254,1,0,1,3,0,255,3,0,1,4,0,255,4,0,3,1,1,253,1,1,2,2,0,254,2,0,1,5,0,255,5,0,1,6,0,255,6,0,1,7,0,255,7,0,2,3,0,254,3,0,4,1,2,252,1,2,1,8,0,255,8,0,3,2,1,253,2,1,2,4,0,254,4,0,1,9,0,255,9,0,1,10,0,255,10,0,5,1,2,251,1,2,2,5,0,254,5,0,1,11,0,255,11,0,2,6,0,254,6,0,1,12,0,255,12,0,3,3,1,253,3,1,6,1,2,250,1,2,4,2,2,252,2,2,1,13,0,255,13,0,2,7,0,254,7,0,3,4,1,253,4,1,1,14,0,255,14,0,0,7,5,4,4,3,3,3,2,2,2,2,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,2,0,0,0,14,0,0,0,1,1,0,255,1,0,0,0,0,2,1,0,254,1,0,1,2,0,255,2,0,3,1,0,253,1,0,1,3,0,255,3,0,2,2,0,254,2,0,4,1,1,252,1,1,1,4,0,255,4,0,5,1,1,251,1,1,1,5,0,255,5,0,3,2,0,253,2,0,2,3,0,254,3,0,1,6,0,255,6,0,6,1,1,250,1,1,2,4,0,254,4,0,1,7,0,255,7,0,4,2,1,252,2,1,7,1,2,249,1,2,3,3,0,253,3,0,1,8,0,255,8,0,2,5,0,254,5,0,8,1,2,248,1,2,1,9,0,255,9,0,3,4,0,253,4,0,2,6,0,254,6,0,5,2,1,251,2,1,1,10,0,255,10,0,9,1,2,247,1,2,4,3,1,252,3,1,0,10,6,5,4,3,3,2,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,3,0,0,0,10,0,0,0,1,1,0,255,1,0,0,0,0,2,1,0,254,1,0,3,1,0,253,1,0,1,2,0,255,2,0,4,1,0,252,1,0,5,1,0,251,1,0,2,2,0,254,2,0,1,3,0,255,3,0,6,1,0,250,1,0,3,2,0,253,2,0,7,1,1,249,1,1,1,4,0,255,4,0,8,1,1,248,1,1,2,3,0,254,3,0,4,2,0,252,2,0,1,5,0,255,5,0,9,1,1,247,1,1,5,2,0,251,2,0,2,4,0,254,4,0,1,6,0,255,6,0,10,1,2,246,1,2,3,3,0,253,3,0,11,1,2,245,1,2,1,7,0,255,7,0,6,2,0,250,2,0,3,4,0,253,4,0,2,5,0,254,5,0,12,1,2,244,1,2,4,3,0,252,3,0,0,13,7,5,4,3,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,6,0,0,0,7,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,1,2,0,255,2,0,6,1,0,250,1,0,7,1,0,249,1,0,8,1,0,248,1,0,2,2,0,254,2,0,9,1,0,247,1,0,1,3,0,255,3,0,10,1,1,246,1,1,3,2,0,253,2,0,11,1,1,245,1,1,4,2,0,252,2,0,12,1,1,244,1,1,1,4,0,255,4,0,2,3,0,254,3,0,13,1,1,243,1,1,5,2,0,251,2,0,14,1,1,242,1,1,6,2,0,250,2,0,1,5,0,255,5,0,15,1,1,241,1,1,3,3,0,253,3,0,16,1,1,240,1,1,2,4,0,254,4,0,7,2,0,249,2,0,0,17,8,4,3,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,9,0,0,0,5,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,7,1,0,249,1,0,1,2,0,255,2,0,8,1,0,248,1,0,9,1,0,247,1,0,10,1,0,246,1,0,11,1,0,245,1,0,12,1,0,244,1,0,2,2,0,254,2,0,13,1,0,243,1,0,1,3,0,255,3,0,14,1,0,242,1,0,15,1,0,241,1,0,3,2,0,253,2,0,16,1,0,240,1,0,17,1,0,239,1,0,18,1,0,238,1,0,4,2,0,252,2,0,19,1,0,237,1,0,20,1,0,236,1,0,2,3,0,254,3,0,1,4,0,255,4,0,5,2,0,251,2,0,21,1,0,235,1,0,0,22,6,3,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,255,255,255,127,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,30,5,62,191,237,18,61,36,27,33,62,28,203,208,188,154,153,153,62,31,46,62,62,90,127,53,62,30,243,50,62,154,153,25,63,158,78,144,62,56,33,35,190,244,80,241,62,72,225,58,63,194,134,40,63,73,67,190,190,76,95,121,62,20,174,71,63,30,96,67,63,215,138,220,190,130,182,44,62,195,245,104,63,164,15,116,63,93,116,81,190,255,185,7,61,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,222,8,0,0,0,0,0,0,56,108,30,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,166,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,240,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,215,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,1,0,0,0,0,0,0,0,0,0,0,136,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,204,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,1,0,0,0,0,0,0,0,0,0,0,206,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,215,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,0,0,0,0,0,0,0,0,0,0,0,188,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,115,0,0,0,64,0,0,0,0,0,0,0,104,1,0,0,61,1,0,0,147,255,255,255,98,0,0,0,0,0,0,0,0,0,0,0,153,200,139,141,157,154,154,154,154,154,154,154,154,184,154,154,154,184,63,139,154,154,154,154,154,154,154,154,154,154,154,154,154,154,154,154,154,153,138,138,111,141,94,138,182,154,139,139,110,110,124,125,140,153,125,127,140,109,111,143,127,111,79,108,123,63,110,110,124,125,140,153,125,127,140,109,111,143,127,111,79,108,123,63,91,171,134,141,111,111,125,110,110,94,124,108,124,107,125,141,179,153,125,107,125,141,179,153,125,107,125,141,179,153,125,140,139,182,182,152,136,152,136,153,136,139,111,136,139,111,140,92,137,138,140,152,138,139,153,74,149,92,139,107,122,152,140,179,166,182,140,227,122,197,138,153,136,167,152,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,153,185,107,139,126,154,197,185,201,154,154,154,149,154,139,154,154,154,152,139,110,122,95,79,63,31,31,153,153,153,153,140,198,140,198,168,79,124,138,94,153,111,149,107,167,154,139,139,125,110,94,110,95,79,125,111,110,78,110,111,111,95,94,108,123,108,125,110,94,110,95,79,125,111,110,78,110,111,111,95,94,108,123,108,121,140,61,154,155,154,139,153,139,123,123,63,153,166,183,140,136,153,154,166,183,140,136,153,154,166,183,140,136,153,154,170,153,123,123,107,121,107,121,167,151,183,140,151,183,140,154,196,196,167,154,152,167,182,182,134,149,136,153,121,136,137,169,194,166,167,154,167,137,182,107,167,91,122,107,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,153,160,107,139,126,154,197,185,201,154,154,154,134,154,139,154,154,183,152,139,154,137,95,79,63,31,31,153,153,153,153,169,198,169,198,168,79,224,167,122,153,111,149,92,167,154,139,139,125,110,124,110,95,94,125,111,111,79,125,126,111,111,79,108,123,93,125,110,124,110,95,94,125,111,111,79,125,126,111,111,79,108,123,93,121,140,61,154,170,154,139,153,139,123,123,63,124,166,183,140,136,153,154,166,183,140,136,153,154,166,183,140,136,153,154,170,153,138,138,122,121,122,121,167,151,183,140,151,183,140,154,196,167,167,154,152,167,182,182,134,149,136,153,121,136,122,169,208,166,167,154,152,167,182,107,167,91,107,107,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,153,33,0,0,0,0,0,0,0,0,0,0,0,0,0,40,243,30,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,2,1,1,16,1,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,4,4,4,4,4,4,5,5,5,5,6,6,6,6,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,4,4,4,4,4,4,5,5,5,5,6,6,6,6,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,1,1,1,1,2,2,2,2,4,4,4,5,5,6,6,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,1,1,1,1,2,2,2,2,4,4,4,5,5,6,6,255,255,255,255,255,255,255,255,1,1,1,2,2,4,5,6,255,255,255,255,255,255,255,255,1,1,1,2,2,4,5,6,255,255,255,255,1,2,4,6,255,255,255,255,1,2,4,6,255,255,2,6,255,255,2,6,255,4,255,4,0,0,0,0,248,235,29,0,108,0,0,0,0,0,0,0,100,66,52,0,4,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,96,27,30,0,8,0,0,0,104,67,34,0,8,0,0,0,160,190,32,0,8,0,0,0,96,184,31,0,10,0,0,0,72,246,30,0,12,0,0,0,216,70,30,0,62,0,0,0,184,205,29,0,62,0,0,0,232,101,29,0,62,0,0,0,136,16,29,0,63,0,0,0,216,191,28,0,63,0,0,0,64,189,35,0,65,0,0,0,24,101,35,0,66,0,0,0,16,14,35,0,64,0,0,0,192,203,34,0,67,0,0,0,192,143,34,0,1,0,0,0,120,85,34,0,2,0,0,0,88,32,34,0,13,0,0,0,104,238,33,0,34,0,0,0,232,200,33,0,14,0,0,0,8,164,33,0,14,0,0,0,40,134,33,0,79,0,0,0,64,86,33,0,94,0,0,0,48,27,33,0,97,0,0,0,192,251,32,0,97,0,0,0,112,225,32,0,102,0,0,0,16,198,32,0,105], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+903660);
/* memory initializer */ allocate([16,173,32,0,110,0,0,0,224,149,32,0,88,73,80,66,8,126,32,0,111,0,0,0,32,101,32,0,111,0,0,0,208,80,32,0,111,0,0,0,56,41,32,0,111,0,0,0,168,252,31,0,111,0,0,0,48,231,31,0,111,0,0,0,112,211,31,0,111,0,0,0,176,191,31,0,111,0,0,0,216,170,31,0,89,0,0,0,16,153,31,0,89,0,0,0,88,135,31,0,89,0,0,0,88,119,31,0,89,0,0,0,112,105,31,0,129,0,0,0,56,72,31,0,82,88,69,48,240,37,31,0,142,0,0,0,144,24,31,0,126,0,0,0,16,12,31,0,80,66,69,87,200,251,30,0,161,0,0,0,40,236,30,0,67,65,70,88,144,222,30,0,159,0,0,0,208,209,30,0,0,0,0,0,0,0,0,0,48,246,30,0,108,0,0,0,208,81,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,143,34,0,108,0,0,0,248,209,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,71,31,0,108,0,0,0,208,81,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,151,252,83,59,33,77,101,59,78,141,130,59,89,214,1,59,43,167,152,58,100,253,234,58,7,253,183,58,85,175,174,58,35,75,197,58,158,172,255,58,20,216,53,59,168,229,135,59,83,180,205,59,129,107,25,60,142,104,140,60,28,139,183,60,9,161,232,60,184,160,40,61,242,206,65,61,141,193,89,61,198,133,136,61,62,2,164,61,41,79,170,61,3,106,176,61,23,152,202,61,138,199,229,61,34,252,235,61,169,247,244,61,50,113,11,62,36,40,30,62,230,150,38,62,0,0,0,0,57,238,244,61,112,40,252,61,232,74,4,62,71,67,204,61,63,199,167,61,25,216,196,61,117,202,179,61,82,94,176,61,42,128,184,61,112,23,203,61,211,103,231,61,229,69,6,62,38,142,28,62,9,140,53,62,210,26,99,62,134,203,122,62,209,230,136,62,253,22,157,62,73,102,165,62,70,177,172,62,172,201,187,62,59,253,200,62,158,208,203,62,154,125,206,62,96,89,217,62,208,185,227,62,248,251,229,62,22,48,233,62,38,169,244,62,216,43,0,63,63,169,2,63,0,0,0,0,226,147,14,62,7,123,179,62,80,113,24,63,205,147,91,63,201,142,143,63,117,177,177,63,169,18,217,63,24,34,8,64,155,232,147,61,10,159,61,62,175,38,151,62,29,60,211,62,102,106,10,63,112,66,45,63,51,221,79,63,82,153,114,63,231,251,137,63,129,9,154,63,128,43,171,63,243,173,189,63,238,234,209,63,65,74,232,63,44,125,4,64,138,202,28,64,64,189,25,61,233,95,210,61,36,15,36,62,96,58,93,62,1,109,139,62,13,23,169,62,180,203,199,62,211,219,231,62,78,152,4,63,229,213,21,63,169,105,39,63,235,30,57,63,69,160,74,63,135,225,91,63,166,154,109,63,117,63,127,63,161,244,135,63,249,20,144,63,123,76,152,63,155,200,160,63,51,136,169,63,195,160,178,63,29,5,188,63,80,197,197,63,68,48,208,63,56,19,219,63,10,191,230,63,107,130,244,63,228,106,3,64,10,75,14,64,129,233,30,64,139,54,80,64,218,170,228,61,246,124,181,62,38,111,36,63,248,22,118,63,76,196,165,63,22,19,207,63,11,179,254,63,95,181,32,64,231,109,108,61,195,244,45,62,150,93,152,62,155,142,224,62,100,36,23,63,69,213,63,63,100,145,106,63,140,44,139,63,211,161,161,63,248,227,182,63,193,82,205,63,173,52,229,63,242,10,0,64,109,83,15,64,168,142,41,64,13,213,168,64,141,123,243,60,65,211,178,61,58,235,19,62,32,38,81,62,128,159,137,62,73,161,172,62,173,79,209,62,243,84,247,62,137,124,15,63,224,185,35,63,38,111,56,63,75,229,77,63,134,171,99,63,62,178,121,63,185,254,135,63,97,85,147,63,14,192,158,63,204,209,169,63,58,205,180,63,115,16,192,63,110,190,203,63,98,220,215,63,182,130,228,63,236,19,242,63,9,84,0,64,237,43,8,64,168,86,17,64,239,115,30,64,59,52,46,64,236,134,70,64,117,245,149,64,40,82,199,64,213,36,88,63,121,121,242,62,170,99,185,63,77,158,138,62,230,150,62,63,144,249,158,63,210,56,236,63,0,0,0,0,132,103,94,63,155,3,244,62,114,54,189,63,218,113,131,62,154,122,65,63,147,87,169,63,72,51,2,64,0,0,0,0,65,72,66,63,26,107,31,63,174,186,162,63,121,32,178,62,53,208,64,63,85,76,147,63,231,113,208,63,0,0,0,0,226,231,67,63,150,7,37,63,252,196,161,63,227,226,176,62,156,139,67,63,159,115,155,63,201,198,225,63,0,0,0,0,17,17,18,18,0,0,0,0,16,15,13,11,8,5,3,1,2,4,6,9,10,12,14,16,7,0,10,8,7,6,4,4,3,2,2,3,4,6,7,9,11,11,7,0,15,15,14,11,8,6,4,2,1,4,5,7,9,10,12,13,4,0,13,11,10,8,6,4,2,2,2,3,5,7,9,12,15,15,14,0,14,12,10,8,7,4,2,2,2,3,5,7,9,11,13,14,7,0,14,13,11,8,6,4,3,2,2,3,5,7,9,10,12,14,3,0,13,12,10,7,5,4,3,2,2,3,4,6,8,9,11,13,4,0,13,12,10,7,5,4,3,2,2,3,4,6,8,9,11,13,4,0,16,14,12,10,8,5,3,1,2,4,7,9,11,13,15,17,6,17,15,13,11,8,6,4,2,2,2,3,5,7,10,12,14,16,9,16,14,12,11,9,8,6,3,1,2,5,7,10,13,15,16,17,4,17,16,14,12,9,7,5,2,2,2,3,4,6,8,11,13,15,10,16,13,11,10,8,7,5,2,2,2,4,6,9,12,14,15,16,3,16,11,11,10,9,8,7,5,4,3,3,3,3,3,3,4,5,6,5,9,9,7,6,5,4,3,3,2,3,4,5,4,5,5,6,8,6,13,12,10,8,5,3,3,2,2,3,4,7,9,11,14,15,6,15,50,204,24,102,135,25,96,6,205,0,24,0,7,0,0,0,2,0,13,0,50,0,153,1,49,3,194,12,13,51,51,204,103,0,0,0,254,2,190,0,94,0,45,0,10,0,9,0,3,0,3,0,0,0,2,0,8,0,44,0,93,0,126,1,254,5,255,5,92,0,0,0,105,81,104,81,181,40,23,5,163,0,41,0,8,0,3,0,0,0,9,0,21,0,80,0,68,1,138,2,44,10,91,20,11,0,0,0,49,18,141,4,71,2,144,0,37,0,8,0,1,0,3,0,0,0,5,0,19,0,73,0,34,1,25,9,195,72,194,72,96,36,0,0,29,45,70,11,208,2,181,0,89,0,10,0,3,0,1,0,0,0,4,0,23,0,91,0,105,1,162,5,143,22,28,45,88,0,0,0,0,24,1,12,1,3,97,0,25,0,7,0,4,0,3,0,0,0,5,0,13,0,49,0,193,0,129,1,1,6,1,24,2,0,0,0,86,21,170,10,171,2,84,0,20,0,11,0,2,0,3,0,0,0,3,0,8,0,43,0,171,0,84,1,84,5,87,21,9,0,0,0,86,21,170,10,171,2,84,0,20,0,11,0,2,0,3,0,0,0,3,0,8,0,43,0,171,0,84,1,84,5,87,21,9,0,0,0,147,41,101,10,152,2,167,0,40,0,4,0,0,0,1,0,1,0,3,0,21,0,82,0,77,1,51,5,200,20,36,83,11,0,37,83,184,9,111,2,154,0,18,0,5,0,0,0,1,0,2,0,3,0,1,0,3,0,8,0,76,0,54,1,221,4,115,19,39,0,114,19,135,7,224,1,241,0,61,0,31,0,6,0,1,0,1,0,1,0,2,0,14,0,121,0,194,3,13,15,25,30,48,60,0,0,49,60,6,75,192,18,177,4,151,0,36,0,8,0,2,0,3,0,0,0,3,0,5,0,19,0,74,0,89,2,97,9,130,37,45,1,7,75,90,10,151,2,74,1,83,0,40,0,11,0,3,0,0,0,2,0,4,0,21,0,164,0,44,5,183,20,108,41,219,82,3,0,218,82,147,1,146,1,200,0,101,0,51,0,24,0,7,0,4,0,0,0,4,0,5,0,7,0,6,0,3,0,5,0,5,0,13,0,4,0,18,0,19,0,5,0,3,0,0,0,3,0,5,0,4,0,3,0,3,0,5,0,5,0,4,0,4,0,3,0,5,0,8,0,4,0,102,13,178,6,173,1,106,0,12,0,5,0,4,0,0,0,3,0,2,0,7,0,52,0,215,0,88,3,207,26,156,53,27,0,157,53,87,119,58,57,96,203,165,57,22,106,19,58,111,18,131,58,45,21,233,58,57,62,79,59,155,68,184,59,10,215,35,60,60,173,145,60,227,134,1,61,194,85,102,61,205,204,204,61,139,24,54,62,156,232,161,62,153,245,15,63,0,0,128,63,174,158,227,63,195,98,74,64,0,243,179,64,0,0,32,65,45,67,142,65,116,251,252,65,192,239,96,66,0,0,200,66,248,211,49,67,41,29,158,67,216,149,12,68,0,0,122,68,246,72,222,68,115,164,69,69,78,187,175,69,0,64,28,70,1,1,1,1,1,1,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,2,0,3,2,3,3,0,0,0,0,0,0,0,0,0,0,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,2,2,2,2,0,1,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,160,23,33,0,224,250,31,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,160,23,33,0,16,37,31,0,224,250,31,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,160,23,33,0,232,117,30,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,160,23,33,0,88,233,29,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,160,23,33,0,160,124,29,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,160,23,33,0,184,35,29,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,160,23,33,0,120,212,28,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,160,23,33,0,248,206,35,0,72,125,35,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,248,206,35,0,120,33,35,0,72,125,35,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,248,206,35,0,232,117,30,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,206,35,0,88,233,29,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,206,35,0,160,124,29,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,206,35,0,184,35,29,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,206,35,0,120,212,28,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,248,206,35,0,208,219,34,0,176,159,34,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,208,219,34,0,0,99,34,0,176,159,34,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,208,219,34,0,232,117,30,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,219,34,0,88,233,29,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,219,34,0,160,124,29,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,219,34,0,184,35,29,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,219,34,0,120,212,28,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,219,34,0,176,43,34,0,224,252,33,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,200,208,33,0,224,252,33,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,24,170,33,0,248,139,33,0,20,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,102,33,0,248,139,33,0,20,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,176,38,33,0,88,2,33,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,136,231,32,0,88,2,33,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,167,32,0,108,0,0,0,232,250,13,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,135,37,136,5,160,0,0,45,178,157,239,167,198,6,64,61,10,215,163,112,189,18,192,66,96,229,208,34,219,24,64,35,219,249,126,106,188,28,192,117,147,24,4,86,142,26,64,84,227,165,155,196,32,20,192,180,200,118,190,159,26,10,64,233,38,49,8,172,28,250,191,251,58,112,206,136,210,218,63,73,110,100,101,120,32,118,97,108,117,101,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,32,40,48,32,45,32,37,100,41,32,102,111,114,32,37,115,32,97,116,32,37,115,58,37,105,10,0,0,0,4,49,46,52,0,0,0,0,79,0,21,0,0,0,0,0,224,35,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,37,31,0,72,118,30,0,4,0,0,0,4,0,0,0,164,112,61,10,215,163,240,63,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,112,233,29,0,184,124,29,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,248,63,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,35,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,32,0,108,0,0,0,104,1,14,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,5,2,6,3,7,104,234,29,0,16,227,29,0,4,0,0,0,28,1,0,0,232,217,29,0,200,26,30,0,236,0,0,0,4,1,0,0,40,209,29,0,40,209,29,0,38,1,0,0,0,0,0,0,96,200,29,0,96,200,29,0,140,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,213,28,0,168,74,34,0,56,118,29,0,144,75,30,0,248,205,28,0,208,101,35,0,152,200,28,0,128,192,28,0,216,193,28,0,8,86,34,0,248,188,28,0,24,239,33,0,200,184,28,0,24,164,33,0,176,179,28,0,136,198,32,0,0,0,0,0,0,0,0,0,43,125,128,62,238,131,132,62,125,59,141,62,87,66,156,62,243,4,181,62,68,41,223,62,217,111,151,62,234,70,247,62,0,0,0,0,0,0,0,0,143,149,62,64,6,247,65,66,107,190,157,70,190,43,33,78,154,121,130,90,222,161,148,111,98,236,183,75,29,117,163,123,0,0,0,0,0,0,0,0,43,125,0,63,238,131,4,63,125,59,13,63,87,66,28,63,243,4,53,63,68,41,95,63,217,111,151,63,234,70,247,63,84,148,183,64,0,0,0,0,150,62,64,0,247,65,66,0,190,157,70,0,44,33,78,0,122,130,90,0,162,148,111,0,217,111,151,0,234,70,247,0,81,81,222,2,0,0,0,0,61,153,99,255,0,0,0,0,1,0,255,255,2,0,2,0,2,0,1,0,2,0,0,0,2,0,3,0,2,0,2,16,2,0,1,16,2,0,0,16,2,0,3,16,2,0,2,32,2,0,1,32,2,0,0,32,2,0,3,32,2,0,2,15,2,0,1,15,2,0,0,15,2,0,3,15,2,0,2,31,2,0,1,31,2,0,0,31,2,0,3,31,2,0,2,47,2,0,1,47,2,0,0,47,2,0,3,47,4,0,255,255,1,0,255,255,2,0,2,0,2,0,1,0,2,0,0,0,2,0,3,0,2,0,2,16,2,0,1,16,2,0,0,16,2,0,3,16,2,0,2,32,2,0,1,32,2,0,0,32,2,0,3,32,2,0,2,15,2,0,1,15,2,0,0,15,2,0,3,15,2,0,2,31,2,0,1,31,2,0,0,31,2,0,3,31,2,0,2,47,2,0,1,47,2,0,0,47,2,0,3,47,4,0,255,255,1,0,255,255,2,0,2,0,2,0,1,0,2,0,0,0,2,0,3,0,2,0,2,16,2,0,1,16,2,0,0,16,2,0,3,16,2,0,2,32,2,0,1,32,2,0,0,32,2,0,3,32,2,0,2,15,2,0,1,15,2,0,0,15,2,0,3,15,2,0,2,31,2,0,1,31,2,0,0,31,2,0,3,31,2,0,2,47,2,0,1,47,2,0,0,47,2,0,3,47,4,0,255,255,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,27,0,0,0,56,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,249,0,0,0,250,0,0,0,251,3,0,0,248,7,0,0,249,7,0,0,250,7,0,0,251,7,0,0,248,15,0,0,249,15,0,0,1,0,0,0,57,0,0,0,123,0,0,0,251,0,0,0,248,1,0,0,249,1,0,0,250,15,0,0,251,15,0,0,248,31,0,0,249,31,0,0,250,31,0,0,251,31,0,0,248,63,0,0,249,63,0,0,250,63,0,0,0,0,0,0,4,0,0,0,58,0,0,0,250,1,0,0,251,63,0,0,248,127,0,0,249,127,0,0,250,127,0,0,251,127,0,0,248,255,0,0,249,255,0,0,250,255,0,0,251,255,0,0,248,255,1,0,249,255,1,0,250,255,1,0,0,0,0,0,12,0,0,0,248,0,0,0,251,1,0,0,251,255,1,0,248,255,3,0,249,255,3,0,250,255,3,0,251,255,3,0,248,255,7,0,249,255,7,0,250,255,7,0,251,255,7,0,248,255,15,0,249,255,15,0,250,255,15,0,0,0,0,0,26,0,0,0,248,3,0,0,251,255,15,0,248,255,31,0,249,255,31,0,250,255,31,0,251,255,31,0,248,255,63,0,249,255,63,0,250,255,63,0,251,255,63,0,248,255,127,0,249,255,127,0,250,255,127,0,251,255,127,0,0,0,0,0,59,0,0,0,249,3,0,0,248,255,255,0,249,255,255,0,250,255,255,0,251,255,255,0,248,255,255,1,249,255,255,1,250,255,255,1,251,255,255,1,248,255,255,3,249,255,255,3,250,255,255,3,251,255,255,3,248,255,255,7,0,0,0,0,250,3,0,0,249,255,255,7,250,255,255,7,251,255,255,7,248,255,255,15,249,255,255,15,250,255,255,15,251,255,255,15,248,255,255,31,249,255,255,31,250,255,255,31,251,255,255,31,248,255,255,63,249,255,255,63,250,255,255,63,0,0,0,0,0,8,9,10,11,12,13,14,15,16,17,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,104,105,106,107,108,109,110,111,112,113,114,115,116,117,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,2,3,0,0,2,3,4,5,6,7,20,21,22,23,24,25,52,53,54,55,56,57,58,59,120,121,122,123,124,125,126,127,8,9,0,0,2,3,8,9,10,11,28,29,60,61,62,63,12,13,0,0,4,5,12,13,28,29,30,31,0,0,0,0,0,0,0,0,4,5,12,13,14,15,0,0,4,5,6,7,0,0,0,0,4,5,12,13,28,29,30,31,0,0,0,0,0,0,0,3,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,4,4,0,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,4,4,0,2,3,3,4,4,4,4,5,5,6,6,6,6,4,4,0,1,3,3,4,4,5,5,5,5,0,0,0,0,0,0,0,1,3,3,4,4,4,4,0,1,3,3,3,3,0,0,0,1,3,3,4,4,5,5,5,5,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,5,6,7,7,7,8,8,10,11,11,11,11,12,12,2,6,7,8,9,9,12,12,13,13,13,13,14,14,14,0,3,6,9,14,15,15,15,15,16,16,16,16,17,17,17,0,4,8,9,17,18,18,18,18,19,19,19,19,20,20,20,0,5,10,20,21,21,21,21,22,22,22,22,23,23,23,23,0,6,10,24,24,24,24,25,25,25,25,26,26,26,26,27,0,10,27,27,27,28,28,28,28,29,29,29,29,30,30,30,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,130,0,0,0,128,0,0,0,154,0,0,0,166,0,0,0,142,0,0,0,204,0,0,0,190,0,0,0,170,0,0,0,30,2,0,0,204,1,0,0,150,2,0,0,158,1,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,130,0,0,0,128,0,0,0,154,0,0,0,166,0,0,0,142,0,0,0,204,0,0,0,190,0,0,0,170,0,0,0,30,2,0,0,204,1,0,0,150,2,0,0,158,1,0,0,9,5,7,9,15,31,63,0,1,2,1,7,6,0,2,3,1,3,4,5,5,4,4,3,1,1,6,4,15,14,5,0,1,3,4,4,5,5,4,3,30,30,14,14,7,7,0,0,0,0,0,0,0,0,0,0,1,2,2,3,2,0,3,3,1,3,4,5,5,4,4,3,1,0,6,4,2,3,5,7,1,3,4,4,4,4,4,4,212,78,213,78,206,78,207,78,204,78,214,78,216,78,70,79,96,79,24,39,25,39,100,39,101,39,109,39,177,39,183,19,214,19,199,9,233,9,237,9,238,4,247,4,120,2,57,1,154,0,159,0,32,0,17,0,10,0,3,0,1,0,0,0,11,0,18,0,33,0,76,0,155,0,58,1,121,2,112,2,239,4,226,4,234,9,216,9,215,19,208,19,178,39,162,39,26,39,27,39,102,79,103,79,97,79,71,79,217,78,215,78,205,78,210,78,211,78,208,78,209,78,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,15,15,15,15,15,15,14,14,13,13,13,12,12,11,10,9,9,7,6,5,3,1,2,5,6,7,8,9,10,11,11,12,12,13,13,14,14,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,0,0,0,249,255,7,0,250,255,7,0,251,255,7,0,248,255,15,0,249,255,15,0,250,255,15,0,253,255,1,0,254,127,0,0,254,15,0,0,254,3,0,0,254,0,0,0,62,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,30,0,0,0,126,0,0,0,254,1,0,0,254,7,0,0,254,31,0,0,254,63,0,0,252,255,1,0,248,255,7,0,251,255,15,0,252,255,15,0,253,255,15,0,254,255,15,0,255,255,15,0,0,0,0,0,19,19,19,20,20,20,17,15,12,10,8,6,4,2,1,3,5,7,9,11,13,14,17,19,20,20,20,20,20,0,0,0,180,254,1,0,181,254,1,0,118,253,1,0,119,253,1,0,116,253,1,0,117,253,1,0,138,254,1,0,139,254,1,0,136,254,1,0,128,254,0,0,182,254,1,0,130,254,0,0,184,254,0,0,66,127,0,0,174,127,0,0,175,63,0,0,209,31,0,0,233,31,0,0,233,15,0,0,234,7,0,0,251,7,0,0,251,3,0,0,251,1,0,0,255,1,0,0,124,0,0,0,60,0,0,0,28,0,0,0,12,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,13,0,0,0,29,0,0,0,61,0,0,0,125,0,0,0,252,0,0,0,252,1,0,0,252,3,0,0,244,3,0,0,235,7,0,0,234,15,0,0,234,31,0,0,214,31,0,0,208,63,0,0,175,127,0,0,67,127,0,0,185,254,0,0,131,254,0,0,183,254,1,0,129,254,0,0,137,254,1,0,142,254,1,0,143,254,1,0,140,254,1,0,141,254,1,0,178,254,1,0,179,254,1,0,176,254,1,0,177,254,1,0,0,0,0,0,18,18,18,18,18,18,18,18,18,17,18,17,17,16,16,15,14,14,13,12,12,11,10,10,8,7,6,5,4,3,1,3,4,5,6,7,8,9,10,11,11,12,13,14,14,15,16,16,17,17,18,17,18,18,18,18,18,18,18,18,18,0,0,0,251,255,1,0,252,255,1,0,253,255,1,0,250,255,1,0,252,255,0,0,252,127,0,0,253,31,0,0,254,3,0,0,254,1,0,0,126,0,0,0,60,0,0,0,29,0,0,0,13,0,0,0,5,0,0,0,0,0,0,0,4,0,0,0,12,0,0,0,28,0,0,0,61,0,0,0,62,0,0,0,254,0,0,0,254,7,0,0,252,31,0,0,252,63,0,0,253,63,0,0,253,127,0,0,254,255,1,0,254,255,3,0,255,255,3,0,0,0,0,0,17,17,17,17,16,15,13,10,9,7,6,5,4,3,1,3,4,5,6,6,8,11,13,14,14,15,17,18,18,0,0,0,2,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,254,63,254,31,254,7,254,1,126,0,30,0,6,0,0,0,2,0,14,0,62,0,254,0,254,3,254,15,255,63,0,0,14,13,11,9,7,5,3,1,2,4,6,8,10,12,14,0,255,63,254,63,254,15,254,3,126,0,30,0,6,0,0,0,2,0,14,0,62,0,254,0,254,1,254,7,254,31,0,0,14,14,12,10,7,5,3,1,2,4,6,8,9,11,13,0,48,8,14,0,40,8,14,0,32,8,14,0,16,8,14,0,0,8,14,0,224,7,14,0,160,7,14,0,0,0,0,0,208,8,14,0,200,8,14,0,192,8,14,0,176,8,14,0,160,8,14,0,128,8,14,0,64,8,14,0,0,0,0,0,0,1,2,62,63,3,4,5,59,60,61,6,7,8,9,10,54,55,56,57,58,11,12,13,14,15,16,47,49,50,51,52,53,17,18,19,20,45,46,48,21,22,23,24,25,26,27,37,38,39,40,41,42,43,44,28,29,30,35,31,33,34,36,0,2,11,1,0,4,6,10,12,7,15,4,4,0,0,0,0,0,16,240,1,15,32,224,17,241,2,14,31,255,208,33,225,18,242,3,13,30,254,47,239,48,64,96,112,144,160,192,49,209,34,226,19,243,4,6,7,9,12,29,253,46,238,63,223,80,176,65,97,113,145,161,193,50,98,114,146,162,210,35,211,227,20,244,5,22,38,230,246,23,39,231,247,25,41,249,10,26,42,250,11,28,44,252,45,61,237,62,78,126,158,222,79,111,127,159,175,207,81,177,66,82,178,194,51,99,115,147,163,179,195,36,52,116,164,212,228,21,37,101,149,229,245,54,214,55,71,199,215,57,89,185,201,217,233,58,106,218,234,27,43,155,171,235,251,108,124,156,172,236,77,109,125,157,173,189,221,94,110,174,206,95,67,83,68,84,100,148,180,196,53,69,85,117,165,181,197,213,70,86,102,118,150,166,182,198,87,103,119,151,167,183,73,105,121,153,169,74,90,122,154,170,186,202,59,75,91,107,123,187,203,219,60,76,92,188,204,220,93,205,190,191,0,0,0,0,0,0,0,2,12,1,4,0,0,0,8,11,24,53,64,60,0,0,0,0,1,15,2,14,5,13,3,4,11,12,0,0,0,0,0,1,6,1,0,2,2,2,4,0,64,16,4,1,5,80,20,84,65,17,81,69,21,85,68,149,106,3,128,192,144,208,148,212,36,100,88,145,161,133,213,37,101,165,229,117,181,245,25,89,153,217,105,169,233,121,185,249,77,93,157,221,109,173,237,125,189,253,2,66,82,6,70,22,86,150,214,38,102,166,230,118,182,246,26,90,154,218,170,234,122,186,250,94,158,222,110,174,238,126,190,254,7,71,87,151,215,103,167,231,119,183,247,91,155,219,107,171,235,123,187,251,95,159,223,111,175,239,127,191,255,32,96,112,176,240,132,196,164,228,116,180,244,8,136,24,152,216,104,168,232,120,184,248,28,92,156,220,108,172,236,60,124,188,252,129,209,33,97,225,113,177,241,197,53,9,73,137,201,41,57,13,141,205,29,45,61,146,210,34,98,162,226,114,178,242,134,198,54,10,74,138,202,42,58,14,78,142,206,30,46,62,19,83,147,211,99,163,227,115,179,243,135,199,23,39,55,11,75,139,203,27,43,59,15,79,143,207,31,47,63,160,224,48,52,72,200,40,56,12,76,140,204,44,193,49,130,194,18,50,67,131,195,35,51,1,11,1,0,0,0,1,4,9,4,103,110,24,0,0,0,0,3,64,192,16,48,4,12,1,80,208,112,240,196,20,52,76,28,60,193,17,49,5,13,19,51,7,15,68,204,65,67,195,84,116,220,252,241,197,21,29,83,199,55,79,63,212,244,92,124,81,209,113,69,85,53,77,205,221,61,211,115,243,71,23,119,207,31,255,213,117,245,93,125,253,87,215,247,95,223,127,0,0,0,0,0,0,0,1,12,1,0,0,1,7,0,19,5,13,23,0,12,0,0,0,1,63,62,2,3,60,61,4,5,6,7,57,58,59,8,9,10,11,12,52,53,54,55,56,13,14,15,16,17,18,25,26,27,28,29,30,31,33,34,35,36,37,38,39,46,47,48,49,50,51,19,20,21,22,23,24,40,41,42,43,44,45,0,2,9,1,2,1,4,7,10,26,12,0,0,0,0,0,0,0,16,1,17,33,2,18,32,34,19,48,49,65,209,225,50,82,3,35,45,64,80,96,128,208,224,81,97,241,66,98,210,226,242,51,67,195,211,227,4,20,212,244,37,53,22,23,247,216,28,60,13,29,61,93,14,30,46,126,47,192,240,113,129,145,193,114,130,146,178,194,83,99,115,147,163,243,36,68,100,132,164,180,5,21,149,213,6,38,54,70,150,214,230,246,7,39,55,215,231,8,24,40,56,232,248,9,25,41,233,249,10,26,202,218,234,11,27,219,235,251,44,76,92,124,140,77,109,141,157,253,62,94,110,142,158,238,15,31,63,79,95,111,127,207,112,161,162,131,179,52,116,196,228,85,101,133,165,197,229,245,86,102,118,134,166,198,87,103,119,151,167,72,136,152,73,89,121,153,58,74,138,186,250,43,123,12,172,188,204,236,125,173,189,221,78,190,206,254,143,159,175,191,223,239,255,144,160,176,177,84,148,69,117,181,182,71,135,183,199,88,104,120,168,184,200,57,105,137,169,185,201,217,42,90,106,122,154,170,59,75,91,107,139,155,171,187,203,108,156,220,252,205,237,174,222,1,12,1,0,0,3,0,3,3,10,40,85,61,50,0,0,0,240,1,16,15,17,241,32,224,2,14,31,255,208,33,225,18,242,7,10,13,30,254,47,239,48,112,144,160,192,113,145,193,209,50,146,226,3,19,99,4,6,230,231,247,9,25,57,250,12,28,221,237,253,46,126,158,63,159,64,80,96,176,49,65,97,161,177,34,66,114,162,178,194,210,35,51,115,163,195,211,227,243,20,36,52,68,116,212,228,5,37,69,101,149,165,22,38,70,118,166,182,198,214,246,23,39,55,71,103,167,215,41,105,185,217,233,249,26,42,58,154,202,218,234,11,27,59,107,235,251,44,108,236,252,29,45,77,109,157,173,62,78,110,174,206,238,79,95,111,223,81,82,98,67,147,179,84,148,164,244,21,117,181,229,245,54,86,102,150,87,119,73,89,169,201,74,90,106,122,170,186,43,75,123,155,171,219,60,76,124,156,172,188,204,61,93,125,189,205,94,190,222,191,207,83,100,180,196,53,85,197,213,151,183,199,121,153,91,187,203,92,220,127,175,0,0,0,0,0,0,0,1,12,1,0,0,2,2,2,6,12,34,92,54,20,0,0,1,0,2,5,3,4,0,0,1,5,1,1,1,1,2,0,0,1,7,2,3,5,6,0,1,5,1,1,1,0,4,0,0,64,1,16,4,2,128,80,144,5,6,32,96,68,20,84,36,8,24,65,17,21,9,160,132,148,100,164,40,81,69,85,25,18,22,10,26,72,88,104,129,145,33,97,133,149,37,101,73,89,41,105,66,70,86,136,152,168,161,165,153,169,82,34,38,102,74,90,42,106,137,130,146,98,134,150,166,138,170,162,154,0,0,0,0,0,0,0,1,12,1,0,0,2,3,5,12,14,18,15,9,2,0,0,0,1,31,2,30,3,4,13,29,5,6,7,14,15,17,18,19,26,27,28,8,9,12,20,21,22,23,24,25,10,11,0,1,9,1,0,2,0,2,4,11,9,2,0,0,0,0,0,0,7,1,2,3,5,6,0,1,5,1,1,1,0,4,0,0,1,8,56,7,57,15,48,9,63,16,49,2,58,6,14,23,17,10,62,55,18,50,22,54,0,0,0,0,0,0,0,1,9,1,0,1,3,2,3,7,4,4,0,0,0,0,0,0,1,2,62,63,3,4,60,61,5,6,7,57,58,59,8,9,10,11,12,26,27,37,38,52,53,54,55,56,13,14,15,16,17,18,25,28,29,30,31,33,34,35,36,39,46,47,48,49,50,51,19,20,21,22,23,24,40,41,42,43,44,45,0,2,9,1,1,3,4,6,14,22,12,0,0,0,0,0,0,0,7,8,56,1,9,57,15,63,16,48,49,2,58,6,14,23,55,24,40,17,25,41,10,3,11,59,5,13,61,62,31,47,18,26,42,50,19,51,21,53,22,30,46,54,27,43,29,45,0,0,0,0,0,0,0,2,9,1,1,3,4,9,15,12,4,0,0,0,0,0,0,0,7,8,56,1,57,15,16,9,63,48,49,2,58,6,14,23,17,10,62,55,18,50,22,54,0,0,0,0,0,0,0,1,9,1,0,1,3,2,3,7,4,4,0,0,0,0,0,0,1,64,192,16,48,4,12,3,80,208,112,240,196,20,52,76,28,60,193,17,49,5,13,195,19,51,7,15,68,204,65,67,84,116,220,252,113,21,77,29,55,63,212,244,92,124,81,209,241,69,197,53,205,221,61,83,211,115,243,71,199,23,119,79,207,31,85,255,213,117,245,93,125,253,87,215,247,95,223,127,0,0,0,0,0,0,0,1,12,1,0,0,1,7,0,20,4,10,24,2,12,0,0,0,1,63,2,62,3,61,4,5,6,58,59,60,7,8,9,10,25,26,27,28,29,34,35,37,38,39,55,56,57,11,13,14,15,30,31,33,36,49,50,51,52,53,54,12,16,17,18,19,21,41,43,44,45,46,47,48,20,22,23,24,40,42,0,1,11,1,0,2,0,2,2,6,17,14,13,6,0,0,0,0,16,240,1,15,17,241,2,14,31,255,32,224,33,242,254,239,48,208,225,18,34,226,3,13,29,30,46,238,47,223,64,96,112,144,160,176,192,49,113,145,193,209,50,210,19,227,243,4,5,6,7,23,247,9,25,10,26,250,12,28,45,237,253,62,126,222,63,111,127,159,175,207,80,65,81,97,161,177,98,114,146,162,194,35,51,99,115,147,163,211,20,36,52,212,228,244,21,245,22,38,214,230,246,39,55,71,231,41,57,201,217,233,249,42,234,11,27,251,44,124,236,252,61,77,109,125,221,78,94,110,158,174,206,79,95,66,82,178,67,179,195,68,100,116,148,164,37,53,101,117,149,165,229,54,70,102,118,150,166,182,198,87,167,183,199,215,89,169,185,58,74,106,202,218,43,59,107,155,171,219,235,60,108,156,172,204,220,93,157,173,189,205,190,191,83,84,180,196,69,85,181,197,213,86,103,119,151,73,105,121,153,90,122,154,170,186,75,91,123,187,203,76,92,188,0,0,0,0,0,0,0,1,12,1,0,0,0,4,6,6,14,42,63,59,30,0,0,0,64,16,4,1,80,68,20,84,65,17,81,5,69,21,85,32,149,101,73,89,82,70,22,128,144,96,132,148,36,100,164,8,72,24,88,129,145,33,97,133,37,9,25,105,2,66,18,6,86,90,87,208,116,104,92,193,213,165,229,117,181,245,153,217,169,233,121,185,249,29,93,157,221,109,173,237,125,189,253,130,146,210,98,150,214,38,102,166,230,118,182,246,10,74,26,154,218,42,106,170,234,122,186,250,94,158,222,110,174,238,126,190,254,3,19,83,23,151,215,103,167,231,119,183,247,91,155,219,107,171,235,123,187,251,95,159,223,111,175,239,127,191,255,192,160,224,48,196,212,228,52,180,244,136,200,152,216,40,168,232,56,120,184,248,12,76,28,156,220,108,172,236,124,188,252,209,161,225,49,113,177,241,197,53,137,201,41,57,13,77,141,205,45,61,34,162,226,114,178,242,134,198,54,138,202,58,14,78,142,206,30,46,62,67,131,147,211,35,99,163,227,115,179,243,7,71,135,199,39,55,75,139,203,27,43,59,79,143,207,31,112,176,240,140,204,44,60,194,50,195,15,47,63,51,11,2,12,1,0,0,4,11,8,28,92,97,13,2,0,0,0,0,64,16,4,1,80,68,20,65,17,5,128,84,81,69,21,85,2,144,32,96,132,36,8,24,9,18,6,160,148,100,72,88,129,145,33,97,133,149,37,101,73,25,89,66,82,70,22,86,10,164,40,104,161,165,41,105,38,74,26,90,136,152,168,137,153,169,130,146,34,98,134,150,102,154,42,106,162,166,138,170,0,0,0,0,0,0,0,2,11,1,0,4,6,7,10,22,11,16,4,0,0,0,0,0,1,16,17,32,33,2,18,48,49,34,3,19,64,65,81,50,66,35,51,4,20,36,21,80,97,113,209,225,82,98,210,67,83,211,52,68,5,37,53,6,22,38,23,24,29,45,61,30,46,96,112,128,208,224,240,129,145,161,193,241,114,130,146,194,226,242,99,115,227,243,84,100,116,212,228,244,69,85,101,213,229,245,54,70,86,214,230,7,39,55,71,215,8,40,56,25,41,26,27,28,44,13,77,93,109,125,14,62,78,94,110,15,31,47,63,79,144,160,192,177,162,178,131,147,163,179,195,132,148,164,196,117,133,149,197,102,118,134,150,198,246,87,103,119,231,247,72,88,104,120,216,232,248,9,57,73,89,217,233,249,10,42,58,74,218,234,11,43,59,219,235,12,60,76,92,108,220,141,157,173,189,205,126,142,158,174,190,206,95,111,127,143,159,175,176,180,165,181,166,182,135,151,167,183,199,136,152,168,200,105,121,137,153,169,201,90,106,122,154,202,250,75,91,107,123,203,251,124,140,156,172,188,204,236,252,221,237,253,222,238,254,191,207,223,239,184,185,138,170,186,139,155,171,187,255,3,12,2,2,4,5,11,26,67,78,51,10,0,0,0,0,0,16,1,17,32,33,2,18,48,49,65,34,50,3,19,35,20,64,81,97,66,82,51,67,4,36,52,21,37,22,80,96,112,113,129,209,225,98,114,130,210,83,99,115,211,68,84,5,53,69,85,6,38,54,7,23,39,55,24,40,25,29,45,61,30,46,31,128,144,208,224,240,145,161,177,193,241,146,162,178,194,226,242,131,147,163,195,227,243,100,116,132,148,212,228,244,101,117,133,213,229,70,86,102,118,214,230,71,87,103,215,8,56,72,88,9,41,57,73,10,26,42,58,27,43,12,28,44,60,13,77,93,109,125,14,62,78,94,110,15,47,63,79,160,176,192,179,164,180,196,149,165,181,197,245,134,150,166,182,198,246,119,135,151,167,199,231,247,104,120,136,152,216,232,248,89,105,121,137,217,233,249,74,90,106,122,218,234], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+913900);
/* memory initializer */ allocate([11,59,75,91,219,235,76,92,108,124,140,220,141,157,173,189,205,126,142,158,174,190,95,111,127,143,159,183,168,184,200,153,169,185,201,138,154,170,186,202,250,107,123,139,155,171,187,203,251,156,172,188,204,236,252,221,237,253,206,222,238,254,175,191,207,223,239,255,4,12,4,4,9,13,37,76,72,39,2,0,0,0,0,0,0,16,240,1,15,241,31,255,32,224,17,2,14,48,80,176,208,33,225,18,242,3,5,11,13,30,254,47,239,64,192,49,81,177,193,209,34,82,226,19,243,4,21,245,27,235,251,12,29,253,46,94,238,63,95,191,223,65,50,66,178,210,35,83,179,227,20,36,228,244,37,53,213,229,43,59,219,28,44,188,236,252,45,189,237,62,78,190,222,79,207,194,51,67,195,211,52,68,84,180,212,69,85,197,75,203,60,76,92,204,220,61,77,93,205,221,206,196,181,91,187,0,0,0,0,0,0,0,1,12,1,0,0,4,0,3,5,16,28,34,26,4,0,0,0,64,4,1,16,80,68,20,84,65,17,81,5,69,21,85,128,144,32,96,132,148,36,100,8,72,24,129,145,97,133,149,37,101,9,73,25,89,2,66,18,82,6,70,22,86,164,88,104,33,165,41,105,26,90,160,136,152,40,161,137,153,169,146,34,98,134,150,38,102,10,74,106,168,130,162,166,138,154,42,170,0,0,0,0,0,0,0,3,10,1,3,12,0,30,9,18,8,0,0,0,0,0,0,0,1,63,2,62,3,4,60,61,5,6,7,8,56,57,58,59,9,10,11,12,25,26,27,28,29,30,31,33,34,35,36,37,38,39,51,52,53,54,55,13,14,15,16,17,18,19,45,46,47,48,49,50,20,21,22,23,24,40,41,42,43,44,0,3,9,3,2,4,8,23,13,10,0,0,0,0,0,0,0,0,16,240,1,15,17,241,31,255,32,224,2,14,48,208,33,225,18,242,3,13,30,254,47,239,64,96,112,144,160,192,49,209,34,50,210,226,19,35,227,243,4,6,7,9,10,12,29,45,253,46,62,238,63,223,80,176,65,81,97,113,145,161,177,193,66,98,114,146,162,194,51,147,163,211,20,36,228,244,5,21,245,22,38,214,230,246,23,39,215,231,247,25,41,57,233,249,26,42,234,250,11,27,251,28,44,236,252,61,125,157,221,237,78,110,126,158,174,206,222,79,95,111,127,159,175,191,207,82,178,67,83,99,115,179,195,52,68,100,116,148,164,180,196,212,37,53,101,117,149,165,213,229,54,70,86,102,166,182,198,55,71,87,183,199,73,89,105,185,201,217,58,74,90,106,170,186,202,218,43,59,107,123,155,171,219,235,60,76,108,124,156,172,204,220,77,93,109,173,189,205,94,190,84,69,85,181,197,118,150,103,119,151,167,121,153,169,122,154,75,91,187,203,92,188,0,0,0,0,0,0,0,3,11,1,4,4,4,12,30,73,75,22,0,0,0,0,0,0,16,240,1,15,17,241,31,255,32,224,2,242,14,33,225,18,226,30,46,254,47,239,48,80,176,192,208,49,177,209,34,210,3,19,227,243,244,5,229,245,11,27,12,13,29,45,253,62,238,63,95,223,64,65,81,193,50,66,82,178,194,35,51,179,195,211,4,20,36,212,228,21,37,197,213,43,59,235,251,28,44,60,92,236,252,61,93,221,237,78,94,190,206,222,79,191,207,67,83,52,84,180,196,53,69,85,181,75,91,203,219,76,188,204,220,77,189,205,68,187,0,0,0,0,0,0,0,2,11,1,0,4,4,5,9,30,45,21,2,0,0,0,0,0,8,56,1,7,48,9,57,15,63,16,24,40,49,2,58,3,5,6,14,23,55,17,25,41,10,50,11,59,13,21,61,62,31,47,18,26,42,19,27,43,51,29,45,53,22,30,46,54,0,0,0,0,0,0,0,1,9,1,0,0,4,0,5,12,13,14,0,0,0,0,0,0,64,16,4,1,80,68,20,84,65,17,5,21,128,81,69,85,144,32,96,36,8,24,9,2,6,132,148,100,72,88,129,145,33,97,149,37,101,25,89,66,18,70,22,86,160,164,40,104,133,165,73,41,105,82,10,26,90,136,152,161,137,153,169,34,98,150,38,102,74,106,168,130,146,162,134,166,138,154,42,170,0,0,0,0,0,0,0,1,12,1,0,0,4,0,8,4,9,19,13,13,10,0,0,0,1,3,64,192,16,48,4,12,80,208,112,240,52,28,5,13,19,7,15,68,196,20,76,204,60,65,193,17,49,67,195,51,84,116,220,252,113,21,77,29,211,199,55,63,212,244,92,124,81,209,241,69,197,85,53,205,221,61,83,115,243,71,23,119,79,207,31,255,245,125,215,95,213,117,93,253,87,247,223,127,0,0,0,0,0,0,0,1,12,1,0,0,2,6,0,11,13,12,24,4,8,0,0,0,16,1,17,32,33,2,18,48,49,65,34,3,19,35,20,64,81,97,50,66,51,4,36,21,22,80,96,208,113,129,209,225,241,82,98,114,210,67,83,99,211,52,68,84,5,37,53,69,6,38,54,23,39,24,13,29,45,61,30,46,31,112,128,224,240,145,161,193,130,146,194,226,242,115,131,147,227,243,100,116,132,212,228,244,85,101,213,229,245,70,86,102,214,7,55,71,87,8,40,56,72,25,41,57,26,42,27,28,44,60,77,93,109,14,62,78,94,15,47,63,79,144,160,176,192,177,162,178,163,179,195,148,164,180,196,117,133,149,165,197,118,134,150,230,246,103,119,135,215,231,247,88,104,120,136,216,232,248,9,73,89,105,217,233,249,10,58,74,90,218,234,11,43,59,75,219,12,76,92,108,220,125,141,157,173,189,205,110,126,142,158,174,190,95,111,127,143,159,175,181,166,182,198,151,167,199,152,168,184,200,121,137,153,169,185,201,106,122,138,154,170,202,250,91,107,123,139,203,235,251,124,140,156,172,188,236,252,221,237,253,206,222,238,254,191,207,223,183,186,155,171,187,204,239,255,3,12,1,3,4,8,10,36,60,78,48,8,0,0,0,0,0,1,14,15,2,3,13,4,6,10,12,5,7,9,11,0,2,6,1,3,3,4,4,0,0,16,240,1,15,17,241,31,255,32,224,2,242,14,33,225,18,226,30,46,254,47,239,48,80,176,192,208,49,177,209,34,210,3,19,227,243,244,5,229,245,11,27,12,13,29,45,253,62,238,63,95,223,64,65,81,193,50,66,82,178,194,35,51,179,195,211,4,20,36,212,228,21,37,197,213,43,59,235,251,28,44,60,92,236,252,61,93,221,237,78,94,190,206,222,79,191,207,67,83,52,84,180,196,53,69,85,181,75,91,203,219,76,188,204,220,77,189,205,68,187,0,0,0,0,0,0,0,1,12,1,0,0,4,0,4,5,9,30,45,21,2,0,0,0,8,56,1,57,7,15,9,63,16,48,49,2,58,6,14,23,17,10,50,13,22,62,55,24,40,25,41,18,42,3,59,5,21,30,31,47,26,11,43,51,53,61,46,54,19,27,29,45,0,0,0,0,0,0,0,2,10,1,1,5,2,8,7,13,8,4,0,0,0,0,0,0,64,16,4,1,80,68,20,84,65,17,5,21,81,69,85,128,144,32,100,8,25,2,6,96,132,148,36,72,24,88,129,145,33,97,133,149,37,101,9,73,89,66,18,82,70,22,86,160,164,152,40,104,161,165,153,41,105,150,38,102,10,74,26,90,136,168,137,169,130,146,34,98,134,166,42,106,162,138,154,170,0,0,0,0,0,0,0,2,11,1,0,4,8,3,8,24,17,12,4,0,0,0,0,1,3,1,1,2,0,0,0,0,1,2,62,63,3,4,60,61,5,6,7,57,58,59,8,9,10,11,12,13,26,38,52,53,54,55,56,14,15,16,17,18,19,25,27,28,29,30,31,33,34,35,36,37,39,45,46,47,48,49,50,51,20,21,22,23,24,40,41,42,43,44,0,2,9,1,1,3,4,6,13,25,10,0,0,0,0,0,0,0,1,31,2,30,3,4,15,17,28,29,5,6,7,8,24,25,26,27,9,10,11,21,22,23,12,19,20,13,14,18,0,2,10,1,2,2,6,8,6,3,1,2,0,0,0,0,0,0,1,15,14,2,3,13,4,6,10,12,5,7,9,11,0,2,7,3,0,1,3,4,4,0,16,32,224,240,2,14,239,48,1,17,33,49,241,18,242,30,238,223,255,64,192,208,209,225,34,50,66,210,226,3,19,35,179,195,227,243,228,5,245,43,12,252,29,45,189,221,253,46,78,222,254,15,31,47,63,80,176,65,81,177,193,82,178,194,51,67,83,211,4,20,36,52,68,84,180,196,212,244,21,37,53,69,85,181,197,213,229,11,27,59,75,91,187,203,219,235,251,28,44,60,76,92,188,204,220,236,13,61,77,93,205,237,62,94,190,206,79,207,95,191,0,0,0,0,0,0,0,4,9,1,7,12,36,63,2,0,64,16,80,4,68,20,1,65,5,69,85,84,17,81,21,128,144,96,36,100,164,72,97,149,37,165,2,66,82,22,86,32,132,148,24,88,129,145,133,101,9,73,25,89,153,41,105,121,93,18,98,6,70,134,102,26,90,106,71,23,192,160,224,196,212,116,8,120,12,76,28,92,209,33,225,113,197,229,117,181,137,189,146,34,150,166,54,10,74,138,154,42,122,222,110,67,19,83,35,7,119,75,27,155,107,47,208,48,112,228,52,244,200,152,40,104,168,232,56,184,248,156,44,108,124,161,177,213,53,201,217,169,233,57,185,249,205,29,45,173,125,194,210,162,178,242,198,38,118,182,218,170,234,58,250,14,78,46,126,190,254,3,131,99,163,179,135,87,151,215,39,11,139,91,43,171,207,31,159,127,191,176,240,180,136,216,140,204,220,172,236,60,188,252,193,49,241,245,13,77,141,157,221,109,237,61,253,130,226,50,114,214,230,246,202,186,142,206,30,94,158,174,238,62,195,147,211,227,51,115,243,199,103,167,231,55,183,247,203,219,235,59,123,187,251,15,79,143,95,223,111,175,239,63,255,3,11,1,1,10,4,16,29,46,75,74,0,0,0,0,0,0,8,56,1,7,57,15,9,63,16,48,49,2,58,6,14,23,55,17,10,50,22,62,18,54,0,0,0,0,0,0,0,3,8,5,2,2,9,5,2,0,64,192,16,48,4,12,1,3,112,80,208,240,68,196,20,52,76,28,60,49,5,13,19,7,15,116,204,220,252,65,193,17,67,195,51,84,212,244,92,124,81,209,113,241,69,197,21,53,77,205,29,61,83,211,115,243,71,199,23,55,79,207,31,63,85,213,117,245,93,221,253,87,215,119,247,255,125,95,223,127,0,0,0,0,0,0,0,2,11,1,0,8,0,1,16,10,29,12,4,0,0,0,0,0,1,2,61,62,63,3,4,5,6,58,59,60,7,8,9,10,54,55,56,57,11,12,13,14,15,26,27,28,36,37,38,49,50,51,52,53,16,17,18,19,20,21,23,24,25,29,30,31,33,34,35,39,43,44,45,46,47,48,22,40,41,42,0,3,9,1,5,7,8,16,22,4,0,0,0,0,0,0,0,4,0,1,2,3,28,29,30,31,5,6,7,24,25,27,8,9,14,19,21,22,23,26,10,11,12,13,15,17,18,20,0,3,7,1,8,6,8,8,0,0,1,2,3,6,7,4,5,1,6,1,1,1,0,3,2,0,1,15,31,16,224,240,17,241,47,255,32,33,225,2,18,242,3,243,14,46,254,63,48,64,208,193,209,34,194,51,227,12,204,13,29,45,253,30,62,94,239,192,82,178,210,67,195,211,36,69,245,75,91,251,28,61,189,221,238,191,207,223,80,176,49,65,81,177,50,66,226,19,35,83,179,4,20,52,68,84,180,196,212,228,244,5,21,37,53,85,181,197,213,229,11,27,43,59,187,203,219,235,44,60,76,92,188,220,236,252,77,93,205,237,78,190,206,222,79,95,0,0,0,0,0,0,0,4,9,4,7,12,19,21,58,0,1,2,6,7,3,5,0,0,8,56,1,7,9,57,15,63,16,2,6,48,17,49,10,58,14,23,55,50,22,62,18,54,0,0,0,0,0,0,0,1,10,1,0,2,2,0,4,3,8,3,2,0,0,0,0,0,64,192,48,4,1,3,16,12,208,112,52,28,13,7,80,240,68,196,20,76,204,60,65,193,17,49,5,67,195,19,51,15,116,220,29,55,84,212,244,92,124,252,209,113,241,197,21,53,77,205,221,61,83,211,115,71,199,23,119,79,31,63,81,69,85,243,207,255,213,117,245,93,125,253,87,215,247,95,223,127,0,0,0,0,0,0,0,2,11,1,0,6,2,6,18,4,26,6,12,0,0,0,0,0,1,2,62,63,3,4,5,6,8,54,56,57,58,59,60,61,7,9,10,11,12,13,14,53,55,15,16,17,18,19,20,21,36,37,39,42,52,22,25,28,35,38,40,41,43,45,46,47,48,49,50,51,23,24,26,27,29,30,31,33,34,44,0,4,9,5,12,9,12,15,10,2,0,48,33,49,65,97,18,34,66,98,67,83,36,69,38,39,16,64,176,1,17,129,50,82,114,146,3,19,51,99,20,52,84,100,116,5,21,37,53,85,101,6,70,86,87,103,136,32,81,145,209,242,35,131,147,4,68,132,148,117,133,197,54,102,150,182,7,55,151,8,40,56,72,104,9,105,121,10,42,27,155,44,77,80,96,112,128,144,160,192,208,224,240,113,161,177,193,225,241,130,162,178,194,210,226,115,163,179,195,211,227,243,164,180,196,212,228,244,149,165,181,213,229,245,22,118,134,166,198,214,230,246,23,71,119,135,167,183,199,215,231,247,24,88,120,152,168,184,200,216,232,248,25,41,57,73,89,137,153,169,185,201,217,233,249,26,58,74,90,106,122,138,154,170,186,202,218,234,250,11,43,59,75,91,107,123,139,171,187,203,219,235,251,12,28,60,76,92,108,124,140,156,172,188,204,220,236,252,13,29,45,61,93,109,125,141,157,173,189,205,221,237,253,14,30,46,62,78,94,110,126,142,158,174,190,206,222,238,254,15,31,47,63,79,95,111,127,143,159,175,191,207,223,239,255,5,9,1,16,31,36,172,0,1,2,0,3,4,5,6,7,2,4,2,2,4,0,0,0,0,16,240,1,15,17,241,31,255,32,224,33,225,2,18,242,14,30,254,47,239,48,80,208,209,34,226,3,19,243,13,29,45,253,46,238,63,223,64,176,192,49,65,81,177,193,50,178,194,210,35,179,211,227,4,20,228,244,5,21,213,229,245,11,27,43,59,235,251,12,28,44,252,61,93,237,62,78,94,190,222,79,95,191,207,66,82,51,83,195,36,180,212,37,53,197,75,203,219,60,76,92,220,236,77,189,205,221,206,67,52,68,84,196,69,85,181,91,187,188,204,0,0,0,0,0,0,0,4,10,5,4,12,17,47,24,12,0,0,0,0,0,0,0,0,7,1,2,6,3,5,0,2,4,2,3,2,0,0,0,0,64,1,16,80,4,68,20,84,65,17,81,5,69,21,85,89,128,144,32,96,132,148,36,100,8,72,24,88,129,145,33,97,133,149,37,101,9,73,25,2,66,18,82,6,70,22,86,160,164,104,161,165,153,41,105,150,102,74,26,90,136,152,40,137,169,130,146,34,98,134,38,166,10,154,42,106,168,162,138,170,0,0,0,0,0,0,0,3,10,1,2,13,1,31,13,16,4,0,0,0,0,0,0,0,64,192,16,48,4,12,1,3,80,208,112,240,196,52,76,204,28,65,193,49,5,13,67,195,19,7,15,68,20,116,220,60,17,29,51,55,84,212,244,92,124,252,209,113,241,197,21,53,77,205,221,61,211,115,71,199,23,119,31,63,81,69,85,213,117,245,93,125,253,83,243,87,215,247,79,207,95,223,127,255,0,0,0,0,0,0,0,1,12,1,0,0,6,2,0,0,0,19,9,24,20,0,0,0,1,2,3,61,62,63,4,5,6,58,59,60,7,8,9,10,54,55,56,57,11,12,13,14,15,16,25,26,27,28,29,30,35,36,37,38,48,49,50,51,52,53,17,18,19,20,21,22,23,24,31,33,34,39,40,41,42,43,44,45,46,47,0,4,8,7,6,8,22,20,0,0,16,1,17,32,33,2,18,34,49,65,50,19,35,48,64,81,66,3,51,67,4,20,36,52,21,37,80,97,113,209,82,98,114,210,83,99,211,68,84,100,5,53,69,85,22,38,54,70,23,39,29,45,61,96,112,208,129,145,161,193,225,241,130,146,194,226,242,115,131,227,243,116,132,196,212,228,244,101,117,133,213,229,6,86,102,214,230,7,55,71,87,103,215,231,24,40,56,72,88,216,25,41,42,28,44,13,77,93,109,125,141,157,30,46,62,78,94,110,126,31,47,63,128,144,160,192,224,240,177,162,178,147,163,179,195,148,164,180,149,165,181,197,245,118,134,150,166,198,246,119,135,151,167,199,247,8,104,120,136,152,200,232,248,9,57,73,89,105,121,137,217,233,249,10,26,58,74,90,106,218,234,250,27,43,59,75,91,219,235,251,12,60,76,92,108,124,140,156,220,236,173,189,205,221,237,14,142,158,174,190,15,79,95,111,127,143,159,175,176,182,183,168,184,153,169,185,201,122,138,154,170,186,202,11,107,123,139,155,203,172,188,204,252,253,206,222,238,254,191,207,223,239,255,171,187,3,12,1,3,5,5,13,27,69,96,35,2,0,0,0,0,0,240,15,16,1,255,32,224,17,241,14,31,48,64,208,33,225,2,18,34,226,242,3,19,30,46,62,238,254,47,239,210,67,243,4,13,45,61,63,223,80,96,112,144,176,49,65,145,161,193,209,66,162,194,35,51,227,36,52,180,212,244,5,21,69,229,22,54,86,166,198,214,246,87,199,247,9,41,73,89,105,249,10,42,58,74,218,234,250,11,43,171,235,251,12,28,44,60,76,92,204,220,252,29,77,109,189,205,237,253,78,110,206,222,127,160,192,81,97,113,177,50,82,98,114,146,178,83,99,115,147,163,179,195,211,20,68,84,100,116,148,164,196,228,37,53,85,101,117,149,165,181,197,213,245,6,38,70,102,118,150,182,230,7,23,39,55,71,103,119,151,167,183,215,231,25,57,121,153,169,185,201,217,233,26,90,106,122,154,170,186,202,27,59,75,91,107,123,155,187,203,219,108,124,156,172,188,236,93,125,157,173,221,94,126,158,174,190,79,95,111,159,175,191,207,0,0,0,0,0,0,0,2,10,1,0,2,3,6,19,9,75,110,0,0,0,0,0,1,0,2,3,4,5,0,0,1,5,1,1,1,1,2,0,0,16,64,80,4,68,20,84,1,65,17,81,5,69,21,85,144,32,148,100,24,33,149,25,105,2,82,6,70,22,128,96,132,212,36,8,72,88,104,129,145,97,133,37,101,165,9,73,89,41,66,18,86,150,166,10,23,27,208,196,116,244,136,200,40,161,113,197,213,117,153,185,77,29,45,109,34,98,102,74,26,154,106,142,94,67,35,7,71,87,107,192,160,224,112,176,164,228,52,180,152,216,168,56,120,12,76,28,92,156,108,124,193,209,225,49,229,53,181,245,137,169,121,249,13,205,157,221,173,61,125,130,194,146,210,226,114,242,134,214,230,118,182,138,90,218,234,250,78,30,158,238,3,19,83,151,183,11,75,139,91,155,235,123,15,79,31,95,159,47,63,191,232,184,248,140,44,60,252,177,201,217,233,57,93,237,189,162,50,38,54,42,170,186,14,46,110,131,195,147,99,179,167,55,48,240,204,220,172,236,188,241,141,253,178,198,246,202,58,122,206,222,174,62,126,190,254,211,163,227,51,115,243,135,199,215,39,103,231,119,247,203,219,43,171,59,187,251,143,207,223,111,175,239,127,255,3,12,1,1,13,1,14,28,33,81,32,52,0,0,0,0,0,64,1,16,4,128,80,32,20,5,2,144,96,68,84,36,8,24,65,17,21,9,6,160,132,148,100,164,72,88,40,81,33,69,85,37,25,18,22,10,26,104,168,129,145,97,161,133,149,101,165,73,89,41,105,66,82,70,86,42,136,152,137,153,169,130,146,34,98,134,38,102,74,90,106,162,150,166,138,154,170,0,0,0,0,0,0,0,1,11,1,0,0,2,2,6,12,18,19,15,6,0,0,0,0,4,12,1,3,5,13,7,15,0,0,0,0,0,0,0,1,6,1,0,3,1,0,4,0,2,3,1,5,6,7,9,54,55,56,58,59,60,61,62,63,4,8,10,11,12,14,49,52,53,57,13,15,16,17,18,19,22,23,25,26,30,39,43,44,45,46,47,48,50,51,20,21,24,27,28,29,31,33,34,35,36,37,38,40,41,42,0,4,8,3,14,10,20,16,0,0,1,17,16,33,18,34,32,48,49,65,2,50,3,19,35,51,20,36,64,81,97,66,82,67,83,4,52,68,21,37,53,22,38,80,96,113,129,209,98,114,130,210,99,115,211,84,100,5,69,85,101,6,54,70,86,23,39,55,71,24,40,56,25,29,45,61,30,112,128,144,208,224,145,161,177,193,225,241,146,162,194,226,242,131,147,163,195,227,243,116,132,148,164,196,212,228,244,117,133,149,213,229,102,118,134,214,230,7,87,103,119,215,8,72,88,104,216,9,41,57,73,89,105,26,42,58,74,27,43,28,44,60,76,13,77,93,109,125,141,14,46,62,78,94,110,31,47,63,79,95,160,176,192,240,178,179,180,165,181,197,245,150,166,182,198,246,135,151,167,183,199,231,247,120,136,152,168,200,232,248,121,137,153,201,217,233,249,10,90,106,122,138,218,234,250,11,59,75,91,107,123,139,219,12,92,108,124,140,156,220,157,173,189,205,126,142,158,174,190,15,111,127,143,159,175,184,169,185,154,170,186,202,155,171,187,203,235,251,172,188,204,236,252,221,237,253,206,222,238,254,191,207,223,239,255,4,11,3,4,12,15,34,83,75,30,0,0,0,0,0,0,1,0,2,3,4,5,6,7,2,4,1,5,2,0,0,0,2,4,3,1,2,0,0,0,0,8,56,1,7,9,57,15,63,16,48,2,58,6,14,24,40,17,49,10,3,5,62,23,55,25,41,18,42,50,11,51,59,13,21,61,22,30,54,31,47,26,19,27,43,29,45,53,46,0,0,0,0,0,0,0,3,9,5,0,4,6,10,16,8,0,0,0,0,0,0,0,0,8,56,1,7,9,57,15,63,16,2,6,48,17,49,10,58,14,23,55,50,22,62,18,54,0,0,0,0,0,0,0,2,9,1,4,0,4,3,8,3,2,0,0,0,0,0,0,0,64,192,16,48,4,12,1,3,208,112,52,28,13,19,7,80,240,68,196,20,116,76,204,220,60,65,193,17,49,5,29,67,195,51,55,15,84,244,252,209,113,21,77,205,221,211,115,71,199,119,63,212,92,124,81,241,69,197,85,53,61,83,243,23,79,207,31,255,117,245,93,125,215,247,95,223,213,253,87,127,0,0,0,0,0,0,0,1,12,1,0,0,2,6,0,7,21,15,17,8,4,0,0,0,1,63,2,62,3,4,59,60,61,5,6,7,8,56,57,58,9,10,11,12,13,14,26,27,36,37,38,50,51,52,53,54,55,15,16,17,18,19,20,21,25,28,29,30,31,33,34,35,39,43,44,45,46,47,48,49,22,23,24,40,41,42,0,3,9,3,2,5,7,17,23,6,0,0,0,0,0,0,0,0,1,16,17,33,18,32,49,2,34,19,48,65,50,3,35,20,36,64,81,97,209,225,66,82,210,51,67,211,4,52,5,21,37,22,29,45,30,46,80,96,208,224,240,113,129,241,98,114,226,242,83,99,227,243,68,84,212,228,244,53,69,85,213,229,245,6,38,54,214,7,23,39,55,215,24,40,28,13,61,77,93,109,141,14,62,78,94,15,31,47,63,95,112,128,144,192,145,161,177,193,130,146,162,194,115,131,147,163,195,100,116,132,148,164,196,101,117,133,70,86,102,198,230,246,71,87,231,247,8,56,72,88,104,216,232,248,9,25,41,57,89,217,233,249,26,42,58,218,234,250,27,43,219,235,251,12,44,60,220,236,125,157,173,189,205,110,126,142,158,174,190,206,79,111,127,143,175,160,178,179,180,149,165,181,197,118,134,150,166,182,103,119,135,151,199,120,136,152,200,73,105,121,137,153,201,10,74,90,106,122,202,11,59,75,91,107,203,76,92,108,124,140,156,172,188,204,252,221,237,253,222,238,254,159,191,207,223,239,255,176,167,183,168,184,169,185,138,154,170,186,123,139,155,171,187,2,12,1,1,2,2,5,7,21,54,85,62,16,0,0,0,0,16,240,1,17,241,15,31,255,32,224,33,225,2,18,242,14,30,254,47,239,48,208,49,209,34,226,3,19,243,13,29,253,46,238,63,223,64,96,112,144,160,192,65,193,50,66,194,210,35,51,211,227,4,20,36,228,244,6,22,246,7,9,10,26,250,12,28,44,236,252,45,61,221,237,62,78,206,222,79,207,80,176,81,97,113,145,161,177,82,98,114,146,162,178,67,83,99,115,147,163,195,52,68,100,164,196,212,5,21,37,53,213,229,245,38,54,70,198,214,230,23,39,55,199,215,231,247,25,41,57,201,217,233,249,42,58,74,90,202,218,234,11,27,43,59,203,219,235,251,60,76,108,124,156,172,188,204,220,77,93,109,125,157,173,189,205,94,110,126,158,174,190,95,111,127,159,175,191,179,84,116,148,180,69,85,101,117,149,165,181,197,86,102,118,150,166,182,71,87,103,167,183,73,89,105,169,185,106,122,154,170,186,75,91,107,123,155,171,187,92,119,151,121,153,0,0,0,0,0,0,0,5,11,9,12,16,44,98,42,4,0,0,0,0,0,0,0,0,16,240,1,15,241,31,255,32,224,17,2,14,48,80,176,208,33,225,18,242,3,5,11,13,30,254,47,239,64,192,49,81,177,193,209,34,82,226,19,243,4,21,245,27,235,251,12,29,253,46,94,238,63,95,191,223,65,50,66,178,210,35,83,179,227,20,36,228,244,37,53,213,229,43,59,219,28,44,188,236,252,45,189,237,62,78,190,222,79,207,194,51,67,195,211,52,68,84,180,212,69,85,197,75,203,60,76,92,204,220,61,77,93,205,221,206,196,181,91,187,0,0,0,0,0,0,0,2,11,1,0,4,3,5,16,28,34,26,4,0,0,0,0,0,8,56,1,7,57,15,9,63,16,48,49,2,58,6,14,62,23,24,40,17,41,10,50,3,11,59,5,13,61,22,31,55,25,18,26,42,19,51,21,53,30,46,54,47,27,43,29,45,0,0,0,0,0,0,0,1,10,1,0,0,4,2,2,9,15,12,4,0,0,0,0,0,64,16,80,4,68,20,84,1,65,17,81,5,69,21,85,144,148,88,145,149,25,89,6,70,22,86,128,96,132,36,100,164,8,72,24,104,129,33,97,161,133,37,101,165,9,73,153,105,169,2,66,18,82,150,38,102,26,90,32,160,136,152,40,168,137,41,130,146,34,98,134,166,10,74,154,106,170,162,138,42,0,0,0,0,0,0,0,5,10,16,11,32,19,1,2,0,64,192,16,48,4,12,1,3,208,80,112,240,196,52,76,204,28,65,193,49,5,13,67,195,19,7,15,68,20,116,220,60,17,29,51,55,84,212,244,92,124,252,209,113,241,21,53,77,205,221,61,211,115,71,199,23,119,63,81,69,197,85,83,243,79,207,31,255,213,117,245,93,125,253,87,215,247,95,223,127,0,0,0,0,0,0,0,1,11,1,0,0,0,8,1,18,9,22,10,12,0,0,0,0,1,63,2,62,3,61,4,5,6,58,59,60,7,8,9,10,26,27,28,36,37,38,54,55,56,57,11,12,13,14,15,16,25,29,30,31,33,34,35,39,47,48,49,50,51,52,53,17,18,19,20,21,22,23,41,42,43,44,45,46,24,40,0,2,10,1,2,2,2,6,14,21,13,2,0,0,0,0,0,1,0,2,3,4,5,6,7,8,9,13,14,10,11,12,15,2,6,1,3,2,6,4,0,0,16,240,1,17,241,15,31,255,32,224,225,2,242,14,30,47,48,208,33,18,34,226,3,13,46,238,254,239,64,192,49,193,209,50,210,19,35,227,243,4,244,12,28,29,45,237,253,62,222,63,223,80,96,112,144,160,176,65,81,97,113,145,161,177,66,98,146,162,194,51,195,211,20,36,52,212,228,5,21,245,6,22,38,230,246,7,23,231,247,9,25,41,249,10,26,42,234,250,11,27,251,44,60,220,236,252,61,77,205,221,78,110,126,174,206,79,95,111,127,159,175,191,207,82,114,178,67,83,99,115,147,163,179,68,100,116,148,164,180,196,37,53,165,197,213,229,54,70,182,198,214,39,55,71,183,199,215,57,73,89,201,217,233,58,74,90,202,218,43,59,75,107,123,219,235,76,92,108,124,156,172,204,93,109,125,157,173,189,94,158,190,84,69,85,101,117,149,181,86,102,118,150,166,87,103,151,167,105,121,169,185,106,122,154,170,186,91,155,171,187,203,188,119,153,0,0,0,0,0,0,0,3,12,1,3,5,8,12,23,72,68,31,2,0,0,0,0,1,2,0,3,4,5,0,0,2,3,2,4,0,0,0,0,0,8,56,1,9,57,7,15,63,16,48,17,49,2,10,58,5,6,14,62,23,55,24,40,25,41,42,50,3,11,51,59,13,21,61,22,30,54,31,47,18,26,19,43,29,53,46,27,45,0,0,0,0,0,0,0,3,9,1,8,0,13,18,7,2,0,0,0,0,0,0,0,0,64,16,4,1,80,68,20,84,65,17,81,5,69,21,85,144,128,32,96,132,148,36,100,8,72,24,88,129,145,33,133,149,101,9,73,25,89,2,66,18,82,6,70,22,86,136,97,37,41,105,90,160,164,152,40,104,161,165,137,153,169,130,146,34,98,150,38,102,10,74,26,168,134,166,138,154,42,106,162,170,0,0,0,0,0,0,0,2,12,1,0,4,11,0,1,29,6,20,7,2,0,0,0,0,3,64,192,16,48,4,12,1,80,208,112,240,196,20,52,76,28,60,65,193,49,5,13,195,19,7,15,68,204,17,67,51,84,116,220,252,113,21,77,205,29,211,199,55,63,212,244,92,124,81,209,241,69,197,53,221,61,83,115,243,71,23,119,79,207,31,85,245,125,215,95,255,213,117,93,253,87,247,223,127,0,0,0,0,0,0,0,1,12,1,0,0,1,7,0,19,5,13,21,6,8,0,0,16,140,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,24,33,0,240,159,34,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,72,37,31,0,64,99,34,0,32,0,0,0,5,0,0,0,248,43,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,251,31,0,80,253,33,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,184,118,30,0,216,208,33,0,44,0,0,0,5,0,0,0,80,170,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,140,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,1,0,0,0,0,0,0,0,0,0,0,8,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,175,32,0,108,0,0,0,24,53,14,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,128,63,0,192,228,191,0,64,93,63,0,76,253,191,0,168,122,63,0,1,2,3,16,17,18,19,4,5,6,7,20,21,22,23,8,9,10,11,24,25,26,27,12,13,14,15,28,29,30,31,32,33,34,35,48,49,50,51,36,37,38,39,52,53,54,55,40,41,42,43,56,57,58,59,44,45,46,47,60,61,62,63,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,0,1,2,3,0,1,2,3,0,1,2,3,0,1,2,3,0,0,1,1,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,32,34,0,108,0,0,0,64,84,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,80,32,48,96,112,128,144,192,208,160,176,224,240,240,67,50,76,3,70,166,69,120,69,103,114,119,77,179,69,177,124,226,76,197,124,149,59,54,71,68,71,71,76,64,76,191,66,23,54,82,115,139,110,210,112,87,76,81,163,79,71,218,69,133,76,108,124,7,77,164,74,161,70,35,107,37,114,84,90,99,26,6,62,97,63,77,102,251,86,0,0,149,125,29,89,185,139,244,61,52,151,239,123,219,91,94,29,164,90,37,54,176,158,209,90,183,91,252,92,110,103,147,133,69,153,97,116,157,116,117,56,83,29,158,54,33,96,236,62,222,88,245,58,252,122,151,159,97,65,13,137,234,49,138,10,94,50,10,67,132,132,150,159,47,148,48,73,19,134,150,88,74,151,24,146,208,121,50,122,96,102,41,106,157,136,76,116,197,123,130,103,44,122,79,82,70,144,230,52,196,115,185,93,198,116,199,159,179,87,47,73,76,84,49,65,142,54,24,88,114,122,101,123,143,139,174,70,136,110,129,65,153,93,174,123,188,36,200,159,193,36,201,36,204,36,201,159,4,133,187,53,180,64,202,159,225,68,255,173,193,98,110,112,203,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,49,193,49,194,49,195,49,196,49,12,1,197,49,209,0,205,0,198,49,199,49,203,0,232,31,200,49,202,0,201,49,202,49,203,49,204,49,14,1,205,49,206,49,0,1,193,0,205,1,192,0,18,1,201,0,26,1,200,0,76,1,211,0,209,1,210,0,0,220,190,30,4,220,192,30,202,0,1,1,225,0,206,1,224,0,81,2,19,1,233,0,27,1,232,0,43,1,237,0,208,1,236,0,77,1,243,0,210,1,242,0,107,1,250,0,212,1,249,0,214,1,216,1,218,1,220,1,252,0,8,220,191,30,12,220,193,30,234,0,97,2,218,35,219,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,163,69,17,0,0,10,101,0,0,0,0,61,78,221,110,78,157,223,145,0,0,0,0,53,119,145,100,26,79,40,79,168,79,86,81,116,81,156,81,228,81,161,82,168,82,59,83,78,83,209,83,216,83,226,86,240,88,4,89,7,89,50,89,52,89,102,91,158,91,159,91,154,92,134,94,59,96,137,101,254,103,4,104,101,104,78,109,188,112,53,117,164,126,172,126,186,126,199,126,207,126,223,126,6,127,55,127,122,130,207,130,111,131,198,137,190,139,226,139,102,143,103,143,110,143,17,116,252,124,205,125,70,105,201,122,39,82,0,0,0,0,0,0,0,0,140,145,184,120,94,145,188,128,0,0,11,141,246,128,231,9,0,0,0,0,159,128,199,158,205,76,201,157,12,158,62,76,246,157,14,112,10,158,51,161,193,53,0,0,154,110,62,130,25,117,0,0,17,73,108,154,143,154,153,159,135,121,108,132,202,29,208,5,230,42,36,78,129,78,128,78,135,78,191,78,235,78,55,79,76,52,189,79,72,62,3,80,136,80,125,52,147,52,165,52,134,81,5,89,219,81,252,81,5,82,137,78,121,82,144,82,39,83,199,53,169,83,81,53,176,83,83,53,194,83,35,84,109,53,114,53,129,54,147,84,163,84,180,84,185,84,208,84,239,84,24,85,35,85,40,85,152,53,63,85,165,53,191,53,215,85,197,53,132,125,37,85,0,0,66,12,21,13,43,81,144,85,198,44,236,57,65,3,70,142,184,77,229,148,83,64,190,128,122,119,56,44,52,58,213,71,93,129,242,105,234,77,221,100,124,13,180,15,213,12,244,16,141,100,126,142,150,14,11,12,100,15,169,44,86,130,211,68,0,0,70,13,77,154,233,128,244,71,167,78,194,44,178,154,103,58,244,149,237,63,6,53,199,82,212,151,200,120,68,45,110,157,21,152,0,0,217,67,165,96,180,100,227,84,76,45,202,43,119,16,251,57,111,16,218,102,22,103,160,121,234,100,82,80,67,12,104,142,161,33,76,139,49,7,0,0,11,72,169,1,250,63,115,88,141,45,0,0,200,69,252,4,151,96,76,15,150,13,121,85,187,64,186,67,0,0,180,74,102,42,157,16,170,129,245,152,156,13,121,99,254,57,117,39,192,141,161,86,124,100,67,62,0,0,1,166,9,14,207,42,201,44,0,0,200,16,194,57,146,57,6,58,155,130,120,53,73,94,199,32,82,86,49,15,178,44,32,151,188,52,61,108,59,78,0,0,0,0,116,117,139,46,8,34,91,166,205,140,122,14,52,12,28,104,147,127,207,16,3,40,57,41,251,53,227,81,140,14,141,15,170,14,147,63,48,15,71,13,79,17,76,14,0,0,171,14,169,11,72,13,192,16,61,17,249,63,150,38,50,100,173,15,244,51,57,118,206,43,126,13,127,13,81,44,85,44,24,58,152,14,199,16,46,15,50,166,80,107,210,140,153,141,202,140,170,149,204,84,196,130,185,85,0,0,195,158,38,156,182,154,94,119,238,45,64,113,109,129,236,128,28,92,114,101,52,129,151,55,95,83,189,128,182,145,250,14,15,14,119,14,251,14,221,53,235,77,9,54,214,12,175,86,181,39,201,16,16,14,120,14,120,16,72,17,7,130,85,20,121,14,80,78,164,45,84,90,29,16,30,16,245,16,246,16,156,87,17,14,148,118,205,130,181,15,123,14,126,81,3,55,182,15,128,17,216,82,189,162,218,73,58,24,119,65,124,130,153,88,104,82,26,54,61,87,178,123,104,91,0,72,44,75,39,159,231,73,31,156,141,155,116,91,61,49,251,85,242,53,137,86,40,78,2,89,193,27,120,248,81,151,134,0,91,78,187,78,62,53,35,92,81,95,196,95,250,56,76,98,53,101,122,107,53,108,58,108,108,112,43,114,44,78,173,114,233,72,82,127,59,121,249,124,83,127,106,98,193,52,0,0,75,99,2,128,128,128,18,102,81,105,93,83,100,136,193,137,178,120,160,139,29,141,133,148,120,149,127,149,232,149,15,142,230,151,117,152,206,152,222,152,99,153,16,152,124,156,31,158,196,158,111,107,7,249,55,78,135,0,29,150,55,98,162,148,0,0,59,80,254,109,115,156,166,159,201,61,143,136,78,65,119,112,245,92,32,75,205,81,89,53,48,93,34,97,50,138,167,143,246,145,145,113,25,103,186,115,129,50,7,161,139,60,128,25,16,75,228,120,2,116,174,81,15,135,9,64,99,106,186,162,35,66,15,134,111,10,42,122,71,153,234,138,85,151,77,112,36,83,126,32,244,147,217,118,227,137,167,159,221,119,163,78,240,79,188,80,47,78,23,79,168,159,52,84,139,125,146,88,208,88,182,29,146,94,153,94,194,95,18,39,139,101,249,51,25,105,67,106,99,60,255,108,0,0,0,114,5,69,140,115,219,62,19,74,21,91,185,116,131,139,164,92,149,86,147,122,236,123,195,124,108,126,248,130,151,133,169,159,144,136,170,159,185,142,171,159,207,143,95,133,224,153,33,146,172,159,185,141,63,20,113,64,162,66,26,90,0,0,0,0,0,0,104,152,107,103,118,66,61,87,0,0,214,133,123,73,191,130,13,113,129,76,116,109,123,93,21,107,190,111,173,159,174,159,150,91,175,159,231,102,91,126,87,110,202,121,136,61,195,68,86,50,150,39,154,67,54,69,0,0,213,92,26,59,249,138,120,92,18,61,81,53,120,93,178,159,87,113,88,69,236,64,35,30,119,76,120,57,74,52,164,1,65,108,204,138,180,79,57,2,191,89,108,129,86,152,250,152,59,95,159,11,0,0,193,33,109,137,2,65,187,70,121,144,7,63,179,159,181,161,248,64,214,55,247,70,70,108,124,65,178,134,255,115,109,69,212,56,154,84,97,69,27,69,137,77,123,76,118,77,234,69,200,63,15,75,97,54,222,68,189,68,237,65,62,93,72,93,86,93,252,61,15,56,164,93,185,93,32,56,56,56,66,94,189,94,37,95,131,95,8,57,20,57,63,57,77,57,215,96,61,97,229,92,137,57,183,97,185,97,207,97,184,57,44,98,144,98,229,98,24,99,248,57,177,86,3,58,226,99,251,99,7,100,90,100,75,58,192,100,21,93,33,86,159,159,151,58,134,101,189,58,255,101,83,102,242,58,146,102,34,59,22,103,66,59,164,103,0,104,88,59,74,104,132,104,114,59,113,59,123,59,9,105,67,105,92,114,100,105,159,105,133,105,188,59,214,105,221,59,101,106,116,106,113,106,130,106,236,59,153,106,242,59,171,106,181,106,212,106,246,106,129,107,193,107,234,107,117,108,170,108,203,60,2,109,6,109,38,109,129,109,239,60,164,109,177,109,21,110,24,110,41,110,134,110,192,137,187,110,226,110,218,110,127,159,232,110,233,110,36,111,52,111,70,61,65,63,129,111,190,111,106,61,117,61,183,113,153,92,138,61,44,112,145,61,80,112,84,112,111,112,127,112,137,112,37,3,193,67,241,53,216,14,215,62,190,87,211,110,62,113,224,87,78,54,162,105,233,139,116,91,73,122,225,88,217,148,101,122,125,122,172,89,187,122,176,122,194,122,195,122,209,113,141,100,202,65,218,122,221,122,234,122,239,65,178,84,1,92,11,123,85,123,41,123,14,83,254,92,162,123,111,123,156,131,180,91,127,108,208,123,33,132,146,123,0,0,32,93,173,61,101,92,146,132,250,123,0,0,53,124,193,92,68,124,131,124,130,72,166,124,125,102,120,69,201,124,199,124,230,124,116,124,243,124,245,124,0,0,103,126,29,69,68,110,93,125,214,110,141,116,137,125,171,125,53,113,179,125,0,0,87,64,41,96,228,125,19,61,245,125,249,23,229,125,109,131,0,0,33,97,90,97,110,126,146,126,43,67,108,148,39,126,64,127,65,127,71,127,54,121,208,98,225,153,151,127,81,99,163,127,97,22,104,0,92,69,102,55,3,69,58,131,250,127,137,100,0,0,8,128,29,128,0,0,47,128,135,160,195,108,59,128,60,128,97,128,20,39,137,73,38,102,227,61,232,102,37,103,167,128,72,138,7,129,26,129,176,88,246,38,127,108,152,100,184,79,231,100,138,20,24,130,94,24,83,106,101,74,149,74,122,68,41,130,13,11,82,106,126,61,249,79,253,20,226,132,98,131,10,107,167,73,48,53,115,23,248,61,170,130,27,105,148,249,219,65,75,133,208,130,26,131,22,14,180,23,193,54,125,49,90,53,123,130,226,130,24,131,139,62,163,109,5,107,151,107,206,53,191,61,29,131,236,85,133,131,11,69,165,109,172,131,0,0,211,131,126,52,212,110,87,106,90,133,150,52,66,110,239,46,88,132,228,91,113,132,211,61,228,68,167,106,74,132,181,60,88,121,0,0,150,107,119,110,67,110,222,132,0,0,145,131,160,68,147,132,228,132,145,92,64,66,192,92,67,69,52,133,242,90,153,110,39,69,115,133,22,69,191,103,22,134,37,134,59,134,193,133,136,112,2,134,130,21,205,112,178,249,106,69,40,134,72,54,162,24,247,83,154,115,126,134], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+924140);
/* memory initializer */ allocate([113,135,248,160,238,135,39,44,177,135,218,135,15,136,97,86,108,134,86,104,15,70,69,136,70,136,224,117,185,61,228,117,94,136,156,136,91,70,180,136,181,136,193,99,197,136,119,119,15,119,135,137,138,137,0,0,0,0,167,137,188,137,37,138,231,137,36,121,189,122,156,138,147,119,254,145,144,138,89,122,233,122,58,123,143,63,19,71,56,123,124,113,12,139,31,139,48,84,101,85,63,139,76,139,77,139,169,138,122,74,144,139,155,139,175,138,223,22,21,70,79,136,155,140,84,125,143,125,212,249,37,55,83,125,214,140,152,125,189,125,18,141,3,141,16,25,219,140,92,112,17,141,201,76,208,62,0,0,169,141,2,128,20,16,138,73,124,59,188,129,12,113,231,122,173,142,182,142,195,142,212,146,25,143,45,143,101,131,18,132,165,143,3,147,159,162,80,10,179,143,42,73,222,137,61,133,187,61,248,94,98,50,249,143,20,160,188,134,1,133,37,35,128,57,215,110,55,144,60,133,190,122,97,144,108,133,11,134,168,144,19,135,196,144,230,134,174,144,0,0,103,145,240,58,169,145,196,145,172,124,51,137,137,30,14,146,159,108,65,146,98,146,185,85,0,0,198,138,155,60,12,139,219,85,49,13,44,147,107,147,225,138,235,139,143,112,195,90,226,138,229,138,101,73,68,146,236,139,57,140,255,139,115,147,91,148,188,142,133,149,166,149,38,148,160,149,246,111,185,66,122,38,216,134,124,18,46,62,223,73,28,108,123,150,150,150,108,65,163,150,213,110,218,97,182,150,245,120,224,138,189,150,204,83,161,73,184,108,116,2,16,100,175,144,229,144,209,74,21,25,10,51,49,151,66,134,54,151,15,74,61,69,133,69,233,74,117,112,65,91,27,151,0,0,213,145,87,151,74,91,235,145,95,151,37,148,208,80,183,48,188,48,137,151,159,151,177,151,190,151,192,151,210,151,224,151,108,84,238,151,28,116,51,148,0,0,245,151,29,148,122,121,209,74,52,152,51,152,75,152,102,152,14,59,117,113,81,61,48,6,92,65,6,87,202,152,183,152,200,152,199,152,255,74,39,109,211,22,176,85,225,152,230,152,236,152,120,147,57,153,41,74,114,75,87,152,5,153,245,153,12,154,59,154,16,154,88,154,37,87,196,54,177,144,213,155,224,154,226,154,5,155,244,154,14,76,20,155,45,155,0,134,52,80,52,155,168,105,195,56,125,48,80,155,64,155,62,157,69,90,99,24,142,155,75,66,2,156,255,155,12,156,104,158,212,157,183,159,146,161,171,161,225,160,35,161,223,161,126,157,131,157,52,161,14,158,136,104,196,157,91,33,147,161,32,162,59,25,51,162,57,157,185,160,180,162,144,158,149,158,158,158,162,158,52,77,170,158,175,158,100,67,193,158,96,59,229,57,29,61,50,79,190,55,43,140,2,159,8,159,150,75,36,148,162,109,23,159,0,0,57,159,159,86,138,86,69,159,184,153,139,144,242,151,127,132,98,159,105,159,220,122,142,159,22,114,190,75,117,73,187,73,119,113,248,73,72,67,81,74,158,115,218,139,250,24,159,121,126,137,54,142,105,147,243,147,68,138,236,146,129,147,203,147,108,137,185,68,23,114,235,62,114,119,67,122,208,112,115,68,248,67,126,113,239,23,163,112,190,24,153,53,199,62,133,24,47,84,248,23,34,55,251,22,57,24,225,54,116,23,209,24,75,95,35,55,192,22,91,87,37,74,254,19,168,18,198,19,182,20,3,133,166,54,0,0,85,132,148,73,101,113,49,62,92,85,251,62,82,112,244,68,238,54,157,153,38,111,249,103,51,55,21,60,231,61,108,88,34,25,16,104,87,64,63,55,225,64,139,64,15,65,33,108,203,84,158,86,177,102,146,86,223,15,168,11,13,14,198,147,19,139,156,147,248,78,43,81,25,56,54,68,188,78,101,4,127,3,75,79,138,79,81,86,104,90,171,1,203,3,153,57,10,3,20,4,53,52,41,79,192,2,179,142,117,2,218,138,12,2,152,78,205,80,13,81,162,79,3,79,14,74,138,62,66,79,46,80,108,80,129,80,204,79,229,79,88,80,252,80,0,0,0,0,0,0,0,0,118,110,149,53,57,62,191,62,114,109,132,24,137,62,168,81,195,81,224,5,221,68,163,4,146,4,145,4,122,141,156,138,14,7,89,82,164,82,115,8,225,82,0,0,122,70,140,113,140,67,32,12,172,73,228,16,209,105,29,14,0,0,222,62,153,116,20,116,86,116,152,115,142,75,188,74,141,64,208,83,132,53,15,114,201,64,180,85,69,3,205,84,198,11,29,87,93,146,244,150,102,147,221,87,141,87,127,87,62,54,203,88,153,90,70,138,250,22,111,23,16,23,44,90,184,89,143,146,126,90,207,90,18,90,70,89,243,25,97,24,149,66,245,54,5,109,67,116,33,90,131,94,129,90,215,139,19,4,224,147,140,116,3,19,5,113,114,73,8,148,251,137,189,147,160,55,30,92,158,92,94,94,72,94,150,25,124,25,238,58,205,94,79,91,3,25,4,25,1,55,160,24,221,54,254,22,211,54,42,129,71,138,186,29,114,52,168,137,12,95,14,95,39,25,171,23,107,90,59,23,68,91,20,134,253,117,96,136,126,96,96,40,43,38,219,95,184,62,175,37,190,37,136,144,115,111,192,97,62,0,70,0,27,38,153,97,152,97,117,96,155,44,7,45,212,70,77,145,113,100,101,70,106,43,41,58,34,43,80,52,234,152,120,46,55,99,91,164,182,100,49,99,209,99,227,73,103,45,164,98,161,44,59,100,107,101,114,105,244,59,142,48,173,50,137,73,171,50,13,85,224,50,217,24,63,148,206,102,137,50,179,49,224,58,144,65,132,85,34,139,143,85,252,22,91,85,37,84,238,120,3,49,42,24,52,50,100,52,15,50,130,49,201,66,142,102,36,109,107,102,147,75,48,102,112,120,235,29,99,102,210,50,225,50,30,102,114,88,209,56,58,56,188,55,153,59,162,55,254,51,208,116,150,59,143,103,42,70,182,104,30,104,196,59,190,106,99,56,213,55,135,68,51,106,82,106,201,106,5,107,18,25,17,101,152,104,76,106,215,59,122,106,87,107,192,63,154,60,160,147,242,146,234,139,203,138,137,146,30,128,220,137,103,148,165,109,11,111,236,73,0,0,127,63,143,61,4,110,60,64,61,90,10,110,71,88,36,109,66,120,59,113,26,67,118,66,241,112,80,114,135,114,148,114,143,71,37,71,121,81,164,74,235,5,122,116,248,62,95,54,74,74,23,73,225,95,6,63,177,62,223,74,35,140,53,63,167,96,243,62,204,116,60,116,135,147,55,116,159,68,234,109,81,69,131,117,99,63,217,76,6,77,88,63,85,117,115,118,198,165,25,59,104,116,204,138,171,73,142,73,251,58,205,61,78,74,255,62,197,73,243,72,250,145,50,87,66,147,227,138,100,24,223,80,33,82,231,81,120,119,50,50,14,119,15,119,123,119,151,70,129,55,94,58,240,72,56,116,155,116,191,62,186,74,199,74,200,64,150,74,174,97,7,147,129,85,30,120,141,120,136,120,210,120,208,115,89,121,65,119,227,86,14,65,0,0,150,132,165,121,45,106,250,62,58,122,244,121,110,65,230,22,50,65,53,146,241,121,76,13,140,73,153,2,186,61,110,23,151,53,107,85,112,53,170,54,212,1,13,12,226,122,89,90,245,38,175,90,156,90,13,90,91,2,240,120,42,90,198,91,254,122,249,65,93,124,109,124,17,66,179,91,188,94,166,94,205,124,249,73,176,23,142,124,124,124,174,124,178,106,220,125,7,126,211,125,78,127,97,98,92,97,72,123,151,125,130,94,106,66,117,107,22,9,214,103,78,0,207,53,196,87,18,100,248,99,98,73,221,127,39,123,44,8,233,90,67,93,12,123,14,94,230,153,69,134,99,154,28,106,63,52,226,57,247,73,173,101,31,154,160,101,128,132,39,113,209,108,234,68,55,129,2,68,198,128,9,129,66,129,180,103,195,152,66,106,98,130,101,130,81,106,83,132,167,109,16,134,27,114,134,90,127,65,64,24,43,91,161,24,228,90,216,24,160,134,188,249,143,61,45,136,34,116,2,90,110,136,69,79,135,136,191,136,230,136,101,137,77,137,131,86,84,137,133,119,132,119,245,139,217,139,156,139,249,137,173,62,163,132,245,70,207,70,242,55,61,138,28,138,72,148,77,95,43,146,132,66,212,101,41,113,196,112,69,24,109,157,159,140,233,140,220,125,154,89,195,119,240,89,110,67,212,54,42,142,167,142,9,76,48,143,74,143,244,66,88,108,187,111,33,35,155,72,121,111,139,110,218,23,233,155,181,54,47,73,187,144,0,0,113,85,6,73,187,145,4,148,75,138,98,64,252,138,39,148,29,140,59,140,229,132,43,138,153,149,167,149,151,149,150,149,52,141,69,116,194,62,255,72,66,74,234,67,231,62,37,50,143,150,231,142,102,142,101,142,204,62,237,73,120,74,238,63,18,116,107,116,252,62,65,151,176,144,71,104,29,74,147,144,223,87,0,0,104,147,137,137,38,140,47,139,190,99,186,146,17,91,105,139,60,73,249,115,27,66,155,151,113,151,56,153,38,15,193,93,197,139,178,74,31,152,218,148,246,146,215,149,229,145,192,68,80,139,103,74,100,139,220,152,69,138,0,63,42,146,37,73,20,132,59,153,77,153,6,123,253,61,155,153,111,75,170,153,92,154,101,139,200,88,143,106,33,154,254,90,47,154,241,152,144,75,72,153,188,153,189,75,151,75,125,147,114,88,2,19,34,88,184,73,232,20,68,120,31,39,184,61,197,104,125,61,88,148,39,57,80,97,129,39,107,41,7,97,79,156,83,156,123,156,53,156,16,156,127,155,207,155,45,158,159,155,245,161,254,160,33,157,174,76,4,65,24,158,176,76,12,157,180,161,237,160,243,160,47,153,165,157,189,132,18,110,223,111,130,107,252,133,51,69,164,109,132,110,240,109,32,132,238,133,0,110,215,55,100,96,226,121,156,53,64,54,45,73,222,73,98,61,219,147,190,146,72,147,191,2,185,120,119,146,77,148,228,79,64,52,100,144,93,85,61,120,84,120,182,120,75,120,87,23,201,49,65,73,154,54,114,79,218,111,217,111,0,0,30,112,20,84,181,65,187,87,243,88,138,87,22,157,215,87,52,113,175,52,172,65,235,113,64,108,151,79,0,0,181,23,73,138,12,97,206,90,11,90,188,66,136,68,44,55,123,75,252,137,187,147,184,147,214,24,29,15,114,132,192,108,19,20,250,66,38,44,193,67,148,89,183,61,65,103,168,125,91,97,164,96,185,73,139,73,250,137,229,146,226,115,233,62,180,116,99,139,159,24,225,62,179,74,216,106,243,115,251,115,214,62,62,74,148,74,217,23,102,74,167,3,36,20,229,73,72,116,22,73,165,112,118,73,132,146,230,115,95,147,254,4,49,147,206,138,22,138,134,147,231,139,213,85,53,73,130,138,107,113,67,73,255,12,164,86,26,6,235,11,184,12,2,85,196,121,250,23,254,125,194,22,80,74,82,24,46,69,1,148,10,55,192,138,173,73,176,89,191,24,131,24,132,116,161,90,226,54,91,61,176,54,95,146,121,90,129,138,98,24,116,147,205,60,180,10,150,74,138,57,244,80,105,61,76,61,156,19,117,113,251,66,24,130,15,110,228,144,235,68,87,109,79,126,103,112,175,108,214,60,237,63,45,62,2,110,12,111,111,61,245,3,81,117,188,54,200,52,128,70,218,62,113,72,196,89,110,146,62,73,65,143,28,140,192,107,18,88,200,87,214,54,82,20,254,112,98,67,113,74,227,47,176,18,189,35,185,104,103,105,152,19,229,52,244,123,223,54,131,138,214,55,250,51,159,76,26,106,173,54,183,108,62,132,223,68,206,68,38,109,81,109,130,108,222,111,23,111,9,113,61,131,58,23,237,131,128,108,83,112,219,23,137,89,130,90,179,23,97,90,113,90,5,25,252,65,45,55,239,89,60,23,199,54,142,113,144,147,154,102,165,66,110,90,43,90,147,66,43,106,249,62,54,119,91,68,202,66,29,113,89,66,225,137,176,79,40,109,194,92,206,68,77,126,189,67,12,106,86,66,4,19,166,112,51,113,233,67,165,61,223,108,37,248,79,74,101,126,235,89,47,93,243,61,92,95,93,74,223,23,164,125,38,132,133,84,250,58,0,51,20,2,126,87,213,8,25,6,229,63,158,31,182,162,3,112,91,145,112,93,143,115,211,124,89,138,32,148,200,79,231,127,205,114,16,115,244,122,56,115,57,115,246,86,65,115,72,115,169,62,24,123,108,144,245,113,242,72,225,115,246,129,202,62,12,119,209,62,162,108,253,86,25,116,30,116,31,116,226,62,240,62,244,62,250,62,211,116,14,63,83,63,66,117,109,117,114,117,141,117,124,63,200,117,220,117,192,63,77,118,215,63,116,118,220,63,122,118,92,79,136,113,35,86,128,137,105,88,29,64,67,119,57,64,97,103,69,64,219,53,152,119,106,64,111,64,94,92,190,119,203,119,242,88,24,120,185,112,28,120,168,64,57,120,71,120,81,120,102,120,72,132,53,85,51,121,3,104,50,121,3,65,9,65,145,121,153,121,187,143,6,122,188,143,103,65,145,122,178,65,188,122,121,130,196,65,207,122,219,122,207,65,33,78,98,123,108,123,123,123,18,124,27,124,96,66,122,66,123,124,156,124,140,66,184,124,148,66,237,124,147,143,192,112,207,12,207,125,212,125,208,125,253,125,174,127,180,127,159,114,151,67,32,128,37,128,57,123,46,128,49,128,84,128,204,61,180,87,160,112,183,128,233,128,237,67,12,129,42,115,14,129,18,129,96,117,20,129,1,68,57,59,86,129,89,129,90,129,19,68,58,88,124,129,132,129,37,68,147,129,45,68,165,129,239,87,193,129,228,129,84,130,143,68,166,130,118,130,202,130,216,130,255,130,176,68,87,131,105,150,138,105,5,132,245,112,100,132,227,96,136,132,4,69,190,132,225,132,248,132,16,133,56,133,82,133,59,69,111,133,112,133,224,133,119,69,114,134,146,134,178,134,239,134,69,150,139,135,6,70,23,70,174,136,255,136,36,137,71,137,145,137,103,121,41,138,56,138,148,138,180,138,81,140,212,140,242,140,28,141,152,71,95,88,195,141,237,71,238,78,58,142,216,85,84,87,113,142,245,85,176,142,55,72,206,142,226,142,228,142,237,142,242,142,183,143,193,143,202,143,204,143,51,144,196,153,173,72,224,152,19,146,30,73,40,146,88,146,107,146,177,146,174,146,191,146,227,146,235,146,243,146,244,146,253,146,67,147,132,147,173,147,69,73,81,73,191,158,23,148,1,83,29,148,45,148,62,148,106,73,84,148,121,148,45,149,162,149,167,73,244,149,51,150,229,73,160,103,36,74,64,151,53,74,178,151,194,151,84,86,228,74,232,96,185,152,25,75,241,152,68,88,14,153,25,153,180,81,28,153,55,153,66,153,93,153,98,153,112,75,197,153,157,75,60,154,15,155,131,122,105,155,129,155,221,155,241,155,244,155,109,76,32,156,111,55,194,27,73,157,58,156,254,158,80,86,147,157,189,157,192,157,252,157,246,148,182,143,123,158,172,158,177,158,189,158,198,158,220,148,226,158,241,158,248,158,200,122,68,159,148,0,183,2,160,3,26,105,195,148,172,89,215,4,64,88,193,148,185,55,213,5,21,6,118,6,186,22,87,87,115,113,194,10,205,10,191,11,106,84,59,248,203,11,158,84,251,11,59,12,83,12,101,12,124,12,231,96,141,12,122,86,181,12,221,12,237,12,111,13,178,13,200,13,85,105,47,156,165,135,4,14,14,14,215,14,144,15,45,15,115,14,32,92,188,15,11,94,92,16,79,16,118,16,30,103,123,16,136,16,150,16,71,54,191,16,211,16,47,17,59,17,100,83,173,132,227,18,117,19,54,19,129,139,119,21,25,22,195,23,199,23,120,78,187,112,45,24,106,25,45,26,69,26,42,28,112,28,172,28,200,30,195,98,213,30,21,31,152,113,85,104,69,32,233,105,200,54,124,34,215,35,250,35,42,39,113,40,79,41,253,130,103,41,147,41,213,42,165,137,232,42,160,143,14,43,184,151,63,43,71,152,189,154,76,44,0,0,136,44,183,44,232,91,8,45,18,45,183,45,149,45,66,46,116,47,204,47,51,48,102,48,31,51,222,51,177,95,72,102,191,102,121,122,103,53,243,53,0,0,186,73,0,0,26,54,22,55,0,0,70,3,181,88,14,103,24,105,167,58,87,118,226,95,17,62,185,62,254,117,154,32,208,72,184,74,25,65,154,138,238,66,13,67,59,64,52,67,150,67,69,74,202,5,210,81,17,6,159,89,168,30,190,59,255,60,4,68,214,68,136,87,116,70,155,57,47,71,232,133,201,153,98,55,195,33,94,139,78,139,0,0,18,72,251,72,21,74,9,114,192,74,120,12,101,89,165,78,134,79,121,7,218,142,44,80,143,82,63,87,113,113,153,82,25,84,74,63,167,74,188,85,70,84,110,84,82,107,0,0,115,52,63,85,50,118,94,85,24,71,98,85,102,85,199,87,63,73,93,88,102,80,251,52,204,51,0,0,3,89,124,71,72,137,174,90,137,91,6,92,144,29,161,87,81,113,0,0,2,97,18,124,86,144,178,97,154,79,98,139,2,100,74,100,91,93,247,107,0,0,132,100,28,25,234,138,246,73,136,100,239,63,18,101,192,75,191,101,181,102,27,39,101,148,225,87,149,97,39,90,205,248,0,0,185,86,33,69,252,102,106,78,52,73,86,150,143,109,189,108,24,54,119,137,153,103,110,104,17,100,94,104,0,0,199,104,66,123,192,144,17,10,38,105,0,0,57,105,69,122,0,0,250,105,38,154,45,106,95,54,105,100,33,0,131,121,52,106,91,107,44,93,25,53,0,0,157,107,208,70,164,108,59,117,101,136,174,109,182,88,28,55,141,37,75,112,205,113,84,60,128,114,133,114,129,146,122,33,139,114,48,147,230,114,208,73,57,108,159,148,80,116,248,14,39,136,245,136,38,41,115,132,177,23,184,110,42,74,32,24,164,57,185,54,0,0,0,0,63,69,182,102,173,156,164,152,67,137,204,119,88,120,214,86,223,64,10,22,161,57,47,55,232,128,197,19,173,113,102,131,221,121,168,145,0,0,183,76,175,112,171,137,253,121,10,122,11,123,102,125,122,65,67,123,126,121,9,128,181,111,223,162,3,106,24,131,162,83,7,110,191,147,54,104,93,151,111,129,35,128,181,105,237,19,47,50,72,128,133,93,48,140,131,128,21,87,35,152,73,137,171,93,136,73,190,101,213,105,210,83,165,74,129,63,17,60,54,103,144,128,244,128,46,129,161,31,79,129,137,129,175,129,26,130,6,131,47,131,138,131,202,53,104,132,170,134,250,72,230,99,86,137,8,120,85,146,184,137,242,67,231,137,223,67,232,137,70,139,212,139,248,89,9,140,0,0,197,143,236,144,0,0,16,145,60,145,247,61,94,145,202,74,208,143,143,114,139,86,231,148,233,149,176,149,184,149,50,151,209,152,73,153,106,153,195,153,40,154,14,155,90,157,155,157,159,126,248,158,35,159,164,76,71,149,147,162,162,113,255,162,145,77,18,144,203,165,156,77,156,12,190,143,193,85,186,143,176,36,185,143,147,74,9,69,127,126,86,111,177,106,234,78,228,52,44,139,157,120,58,55,128,142,245,23,36,128,108,139,153,139,62,122,175,102,235,61,85,118,183,60,53,86,86,89,154,78,129,94,88,98,191,86,109,14,14,142,109,91,136,62,158,76,222,99,0,0,246,23,123,24,48,101,45,86,74,92,26,84,17,83,198,61,152,157,125,76,34,86,30,86,73,127,216,94,117,89,64,61,112,135,28,78,234,15,73,13,186,54,23,129,94,157,24,141,59,118,69,156,78,118,185,119,69,147,50,84,72,129,247,130,37,86,50,129,24,132,189,128,234,85,98,121,67,86,22,84,157,14,206,53,5,86,241,85,241,102,226,130,45,54,52,117,240,85,186,85,151,84,114,85,65,12,150,12,208,94,72,81,118,14,98,44,162,14,171,158,90,125,222,85,117,16,157,98,109,151,148,84,205,140,246,113,118,145,252,99,185,99,254,99,105,85,67,43,114,156,179,46,154,81,223,52,167,13,167,81,77,84,30,85,19,85,102,118,45,142,138,104,177,117,182,128,4,136,134,135,199,136,182,129,28,132,193,16,236,68,4,115,6,71,144,91,11,131,147,104,123,86,244,38,47,125,163,65,115,125,208,110,182,114,112,145,217,17,8,146,252,60,169,166,172,14,249,14,102,114,162,28,78,71,194,79,249,127,235,15,250,64,93,156,31,101,160,45,243,72,224,71,124,157,236,15,10,14,0,0,163,117,237,15,0,0,72,96,135,17,163,113,142,126,80,157,26,78,4,78,119,53,13,91,178,108,103,83,172,54,220,57,125,83,165,54,24,70,154,88,110,75,45,130,75,84,170,87,149,90,121,9,0,0,82,58,101,36,116,115,172,158,9,77,237,155,254,60,48,159,91,76,169,79,158,149,222,159,92,132,182,61,178,114,179,103,32,55,46,99,37,125,247,62,44,62,42,58,8,144,204,82,116,62,122,54,233,69,142,4,64,118,240,90,182,14,122,120,46,127,167,88,191,64,124,86,139,155,116,93,84,118,52,164,133,158,225,76,0,0,251,55,25,97,218,48,242,67,0,0,93,86,169,18,167,87,99,73,6,158,52,82,174,112,173,53,0,0,124,157,86,124,57,155,222,87,108,23,83,92,211,100,208,148,53,99,100,113,173,134,40,13,34,109,226,74,113,13,0,0,254,81,15,31,142,93,3,151,209,29,129,158,76,144,31,123,2,155,209,92,163,123,104,98,53,99,255,154,207,123,42,155,126,124,0,0,66,124,134,124,21,156,252,123,9,155,0,0,27,156,62,73,90,159,115,85,195,91,253,79,152,158,242,79,96,82,6,62,209,82,103,87,86,80,183,89,18,94,200,151,171,157,92,143,105,84,180,151,64,153,186,151,44,83,48,97,44,105,218,83,10,156,2,157,59,76,65,150,128,105,166,80,70,117,109,23,218,153,115,82,0,0,89,145,129,150,92,145,0,0,81,145,151,142,127,99,35,109,202,106,17,86,142,145,122,117,133,98,252,3,79,115,112,124,33,92,253,60,0,0,25,73,214,118,157,155,42,78,212,12,190,131,66,136,0,0,74,92,192,105,0,0,122,87,31,82,245,93,206,78,49,108,242,1,57,79,156,84,218,84,154,82,130,141,254,53,0,0,243,53,0,0,82,107,124,145,165,159,151,155,46,152,180,152,186,154,168,158,132,158,122,113,20,123,0,0,250,107,24,136,120,127,0,0,32,86,74,166,119,142,83,159,0,0,212,141,79,142,28,158,1,142,130,98,125,131,40,142,117,142,211,122,119,74,62,122,216,120,234,108,103,138,7,118,90,138,38,159,206,108,214,135,195,117,178,162,83,120,64,248,12,141,226,114,113,115,45,139,2,115,241,116,235,140,187,74,47,134,186,95,160,136,183,68,0,0,59,24,5,110,0,0,126,138,27,37,0,0,253,96,103,118,215,154,68,157,110,147,143,155,245,135,0,0,0,0,247,140,44,115,33,151,176,155,214,53,178,114,7,76,81,124,74,153,89,97,89,97,4,76,150,158,125,97,0,0,95,87,111,97,166,98,57,98,0,0,92,58,226,97,170,83,245,51,100,99,2,104,210,53,87,93,194,139,218,143,57,142,0,0,217,80,70,29,6,121,50,83,56,150,59,15,101,64,0,0,254,119,0,0,194,124,26,95,218,124,45,122,102,128,99,128,77,125,5,117,242,116,148,137,26,130,12,103,98,128,134,116,91,128,240,116,3,129,36,119,137,137,204,103,83,117,209,110,169,135,206,135,200,129,140,135,73,138,173,140,67,139,43,119,248,116,218,132,53,54,178,105,166,141,0,0,169,137,0,0,185,109,193,135,17,64,231,116,219,61,118,113,164,96,156,97,209,60,0,0,119,96,0,0,113,127,45,139,0,0,233,96,126,75,32,82,24,60,199,60,215,94,86,118,49,85,68,25,254,18,3,153,220,109,173,112,193,92,173,97,15,138,119,54,238,0,70,104,14,79,98,69,31,91,76,99,80,159,166,158,107,98,71,5,219,146,223,5,197,63,76,133,181,66,239,115,181,81,73,54,66,73,228,137,68,147,219,25,238,130,200,60,60,120,68,103,223,98,51,73,170,137,160,2,179,107,5,19,171,79,237,36,8,80,41,109,132,122,0,54,177,74,19,37,0,0,126,3,164,95,128,3,71,3,219,110,31,4,0,0,1,81,122,52,14,81,108,152,67,55,22,132,164,73,135,4,96,81,180,51,106,81,255,11,252,32,229,2,48,37,142,5,51,50,131,25,130,91,125,135,179,5,153,60,178,81,184,81,52,157,201,81,207,81,209,81,220,60,211,81,166,74,179,81,226,81,66,83,237,81,205,131,62,105,45,55,123,95,11,82,38,82,60,82,181,82,87,82,148,82,185,82,197,82,21,124,66,133,224,82,13,134,19,107,0,0,222,138,73,85,217,110,128,63,84,9,236,63,51,83,0,0,226,11,203,108,38,23,27,104,213,115,74,96,170,62,204,56,232,22,221,113,162,68,109,83,116,83,171,134,126,83,0,0,150,21,19,22,230,119,147,83,155,138,160,83,171,83,174,83,167,115,114,87,89,63,156,115,193,83,197,83,73,108,73,78,254,87,217,83,171,58,143,11,224,83,235,63,163,45,246,83,119,12,19,84,121,112,43,85,87,102,91,109,109,84,83,107,116,13,93,85,143,84,164,84,166,71,13,23,221,14,180,61,77,13,188,137,152,38,71,85,237,76,47,84,23,116,134,85,169,85,0,0,215,24,58,64,82,69,53,68,179,102,180,16,55,86,205,102,138,50,164,102,173,102,77,86,79,86,241,120,241,86,135,151,254,83,0,87,239,86,237,86,102,139,35,54,79,18,70,87,165,65,110,108,139,112,66,87,177,54,126,108,230,87,22,20,3,88,84,20,99,67,38,88,245,75,92,88,170,88,97,53,224,88,220,88,60,18,251,88,255,91,67,87,80,161,120,66,211,147,161,53,31,89,166,104,195,54,89,110,62,22,36,90,83,85,146,22,5,133,201,89,78,13,129,108,42,109,220,23,217,89,251,23,178,23,166,109,113,109,40,24,213,22,249,89,69,110,171,90,99,90,230,54,169,73,0,0,8,55,150,90,101,116,211,90,161,111,84,37,133,61,17,25,50,55,184,22,131,94,208,82,118,91,136,101,124,91,14,122,4,64,93,72,4,2,213,91,96,97,52,26,204,89,165,5,243,91,157,91,16,77,5,92,68,27,19,92,206,115,20,92,165,28,40,107,73,92,221,72,133,92,233,92,239,92,139,93,249,29,55,30,16,93,24,93,70,93,164,30,186,92,215,93,252,130,45,56,1,73,73,32,115,33,135,130,54,56,194,59,46,94,138,106,0,0,122,94,188,68,211,12,166,83,183,78,0,0,168,83,113,23,9,94,244,94,130,132,249,94,251,94,160,56,252,94,62,104,27,148,13,95,193,1,148,248,222,58,174,72,58,19,58,95,136,104,208,35,0,0,113,36,99,95,189,151,110,110,114,95,64,147,54,138,167,95,182,93,95,61,80,82,106,31,248,112,104,38,214,145,158,2,41,138,49,96,133,102,119,24,99,57,199,61,57,54,144,87,180,39,113,121,64,62,158,96,0,0,179,96,130,73,143,73,83,122,164,116,225,80,160,90,100,97,36,132,66,97,166,248,210,110,129,97,244,81,86,6,135,97,170,91,183,63,95,40,211,97,157,139,93,153,208,97,50,57,128,41,193,40,35,96,92,97,30,101,139,99,24,1,197,98,112,23,213,98,13,46,108,99,223,73,23,58,56,100,248,99,142,19,252,23,0,0,138,111,54,46,20,152,140,64,29,87,225,100,229,100,123,148,102,58,58,100,87,58,77,101,22,111,40,74,35,74,133,101,109,101,95,101,126,48,181,101,64,73,55,75,209,101,216,64,41,24,224,101,227,101,223,95,0,52,24,102,247,49,248,49,68,102,164,49,165,49,75,102,117,14,103,102,230,81,115,102,0,0,61,30,49,50,244,133,200,49,19,83,197,119,247,40,164,153,2,103,156,67,33,74,43,59,250,105,194,55,0,0,103,103,98,103,205,65,237,144,215,103,233,68,34,104,80,110,60,146,1,104,230,51,160,109,93,104,111,52,225,105,11,106,223,138,115,105,195,104,205,53,1,105,0,105,50,61,1,58,60,54,128,59,172,103,97,105,74,138,252,66,54,105,152,105,161,59,201,3,99,131,144,80,249,105,89,54,42,33,69,106,3,55,157,106,243,59,177,103,200,106,156,145,13,60,29,107,35,9,222,96,53,107,116,107,205,39,181,110,219,58,181,3,88,25,64,55,33,84,90,59,225,107,252,62,220,107,55,108,139,36,241,72,81,107,90,108,38,130,121,108,188,61,197,68,189,61,164,65,12,73,0,73,201,60,229,54,235,60,50,13,131,155,249,49,145,36,143,127,55,104,37,109,161,109,235,109,150,109,92,109,124,110,4,111,127,73,133,64,114,110,51,133,116,111,199,81,0,0,0,0,46,132,33,139,0,0,47,62,83,116,130,63,204,121,79,110,145,90,75,48,248,111,13,55,157,111,48,62,250,110,151,20,61,64,85,69,240,147,68,111,92,111,78,61,116,111,112,145,59,61,159,111,68,65,211,111,145,64,85,65,57,64,240,63,180,63,63,65,223,81,86,65,87,65,64,65,221,97,75,112,126,112,167,112,129,112,204,112,213,112,214,112,223,112,4,65,232,61,180,113,150,113,119,66,43,113,69,113,136,90,74,113,0,0,156,92,101,67,79,113,98,147,193,66,44,113,90,68,39,74,34,74,186,113,232,139,189,112,14,114,66,148,21,114,17,89,67,148,36,114,65,147,5,86,46,114,64,114,116,73,189,104,85,114,87,114,85,62,68,48,13,104,61,111,130,114,0,0,43,115,35,72,43,136,237,72,4,136,40,115,46,115,207,115,170,115,58,12,46,106,201,115,73,116,226,65,231,22,36,74,35,102,197,54,183,73,141,73,251,73,247,115,21,116,3,105,38,74,57,116,195,5,215,62,0,0,173,40,96,116,178,142,71,116,228,115,118,116,185,131,108,116,48,55,116,116,241,147,44,106,130,116,83,73,140,74,95,65,121,74,143,139,70,91,3,140,158,24,200,116,136,25,14,117,0,0,30,117,217,142,75,26,215,91,172,142,133,147,77,117,74,117,103,117,110,117,130,79,4,63,19,77,142,117,93,116,158,117,180,117,2,118,44,118,81,118,79,118,111,118,118,118,245,99,144,118,239,129,248,55,17,105,14,105,161,118,165,118,183,118,204,118,159,111,98,132,157,80,125,81,28,30,30,119,38,119,64,119,175,100,32,82,88,119,172,50,175,119,100,137,104,137,193,22,244,119,0,0,118,19,18,74,202,104,175,120,199,120,211,120,165,150,46,121,224,85,215,120,52,121,177,120,12,118,184,143,132,136,43,139,131,96,28,38,134,121,0,137,2,105,128,121,87,88,157,121,57,123,60,121,169,121,42,110,38,113,168,62,198,121,13,145,212,121,32,5,95,68,15,82,130,184,248,0,0,64,32,169,78,4,0,0,0,0,52,11,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,64,0,0,0,0,0,0,0,0,4,88,0,60,0,0,0,0,0,128,92,173,220,243,187,201,67,238,237,164,15,38,193,155,118,242,239,222,251,250,247,15,50,68,175,254,239,253,254,17,96,176,0,0,33,25,129,32,16,136,168,96,33,105,36,0,68,137,196,0,0,3,64,53,0,67,132,49,81,147,104,2,2,0,0,0,0,0,0,0,0,0,0,0,64,0,1,128,172,100,130,64,140,161,144,4,80,96,212,0,210,42,24,157,104,53,151,79,216,248,32,196,130,28,40,130,117,148,2,56,64,160,161,197,16,113,77,196,13,152,185,94,91,1,67,159,153,3,120,32,226,31,8,137,1,201,64,7,3,13,154,144,82,209,79,124,3,2,33,32,192,110,19,131,181,219,245,229,119,144,79,23,154,54,23,12,0,110,186,9,47,96,84,0,30,120,104,34,112,86,158,37,243,142,183,23,11,239,230,119,23,91,27,193,16,152,141,18,24,182,207,1,49,114,26,91,44,182,192,32,226,195,92,130,27,224,218,206,133,214,64,169,84,11,208,15,72,68,64,16,9,212,64,174,59,100,30,68,43,23,8,134,130,54,24,160,137,231,156,91,8,132,3,2,218,144,236,219,135,133,191,162,173,157,142,157,152,32,37,70,0,70,159,127,227,213,201,132,244,214,77,6,227,182,24,18,9,0,0,0,4,0,0,32,0,0,0,0,2,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,142,120,110,95,63,126,221,61,247,252,155,252,174,210,255,143,107,241,231,191,186,174,110,23,239,220,167,62,182,181,119,201,146,215,165,182,74,110,155,185,129,77,103,254,84,241,155,98,254,111,82,215,54,254,191,41,69,129,249,189,101,166,66,57,0,0,66,96,143,0,148,64,64,210,175,215,209,219,0,160,152,178,123,6,82,32,152,22,200,61,9,0,0,1,0,0,0,1,10,178,8,128,0,0,0,4,136,32,20,16,76,0,0,4,0,161,68,16,0,65,1,0,8,64,240,223,79,54,88,241,245,181,128,245,103,128,64,0,80,78,65,200,132,0,90,96,216,1,43,1,80,161,22,196,64,242,110,17,172,32,57,196,192,8,7,12,9,152,150,196,155,16,28,152,108,134,42,166,1,70,17,109,229,203,196,192,146,16,33,22,18,157,114,244,105,14,23,42,162,129,244,123,0,8,164,11,144,16,44,204,57,74,1,240,22,11,10,64,12,29,234,12,68,14,69,2,0,128,119,30,0,48,234,29,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,128,119,30,0,96,125,29,0,96,36,29,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,128,119,30,0,24,213,28,0,120,207,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,128,119,30,0,128,126,35,0,88,34,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,128,119,30,0,96,220,34,0,88,34,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,128,119,30,0,24,160,34,0,104,99,34,0,20,4,0,0,1,0,0,0,200,0,0,0,0,0,0,0,0,0,0,0,0,0,73,64,0,0,0,0,0,0,160,64,16,0,1,0,0,0,0,0,0,44,34,0,144,253,33,0,24,4,0,0,1,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,64,16,0,1,0,0,0,0,0,248,208,33,0,88,170,33,0,28,4,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,24,140,33,0,168,103,33,0,32,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,24,140,33,0,8,39,33,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,24,140,33,0,160,2,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,24,140,33,0,160,231,32,0,192,204,32,0,36,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,160,231,32,0,72,178,32,0,240,156,32,0,40,4,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,72,178,32,0,32,131,32,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,178,32,0,104,106,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,178,32,0,200,84,32,0,248,57,32,0,44,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,200,84,32,0,232,3,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,84,32,0,152,236,31,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,84,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,190,32,0,108,0,0,0,240,95,14,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,0,2,0,3,1,3,1,2,2,2,2,3,3,3,3,2,3,1,2,1,2,0,3,0,0,0,0,192,0,0,128,63,0,112,247,191,0,152,111,63,96,201,32,0,32,77,31,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,56,153,32,0,32,77,31,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,32,129,32,0,136,102,32,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,32,129,32,0,112,82,32,0,40,48,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,8,255,31,0,72,233,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,152,213,31,0,120,194,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,144,172,31,0,168,154,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,88,137,31,0,200,39,31,0,40,0,0,0,3,0,0,0,57,180,200,118,190,159,230,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,72,106,31,0,200,39,31,0,40,0,0,0,3,0,0,0,57,180,200,118,190,159,230,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,232,25,31,0,152,13,31,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,208,253,30,0,152,13,31,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,23,35,0,108,0,0,0,224,99,14,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,18,254,2,3,5,255,17,4,0,0,0,0,0,0,0,0,1,18,17,254,2,18,3,7,2,5,4,0,0,0,0,0,0,0,1,2,1,18,3,6,254,18,2,3,4,5,0,0,0,0,0,0,0,0,2,18,18,254,2,18,3,6,2,17,4,0,0,0,0,0,0,0,1,2,18,18,2,18,3,2,255,4,18,5,0,0,0,0,0,0,0,1,1,7,6,5,3,4,2,5,4,3,7,0,0,0,0,0,0,0,1,1,17,3,18,7,2,6,1,4,3,5,0,0,0,0,0,0,0,1,1,254,18,18,18,3,254,6,5,2,1,0,0,0,0,0,0,0,1,2,18,18,255,18,2,3,6,254,17,5,0,0,0,0,0,0,0,0,1,17,17,18,3,6,4,5,2,18,254,0,0,0,0,0,0,0,1,2,1,18,254,3,5,2,4,255,6,1,0,0,0,0,0,0,0,0,2,18,18,3,6,18,2,4,8,5,3,0,0,0,0,0,0,0,0,1,254,1,18,2,254,7,18,2,255,5,0,0,0,0,0,0,0,1,1,4,3,8,1,5,2,5,6,2,8,0,0,0,0,0,0,0,1,1,17,18,2,6,3,4,255,1,8,6,0,0,0,0,0,0,0,0,1,18,18,3,6,3,254,2,5,255,1,0,0,0,0,0,0,0,0,1,18,18,17,255,2,254,18,3,4,5,0,0,0,0,0,0,0,1,2,18,17,2,254,18,3,5,7,2,4,0,0,0,0,0,0,0,1,2,18,18,3,6,254,18,2,5,8,3,0,0,0,0,0,0,0,0,1,18,17,2,18,18,2,6,5,17,7,0,0,0,0,0,0,0,1,2,18,17,2,18,3,2,6,18,255,4,0,0,0,0,0,0,0,1,1,5,3,6,5,3,4,1,2,4,7,0,0,0,0,0,0,0,1,1,5,3,6,5,3,4,1,2,4,7,0,0,0,0,0,0,0,0,1,254,18,18,18,254,3,2,4,6,5,0,0,0,0,0,0,0,1,2,18,17,253,3,255,18,2,3,6,5,0,0,0,0,0,0,0,0,1,17,18,7,3,254,7,1,2,4,5,0,0,0,0,0,0,0,1,1,2,18,18,254,2,4,255,18,3,6,0,0,0,0,0,0,0,0,3,1,18,4,3,5,2,4,18,2,3,0,0,0,0,0,0,0,0,1,254,18,2,18,3,7,18,2,6,254,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,18,5,4,6,4,5,1,4,3,0,0,0,0,0,0,0,1,1,18,3,6,5,7,8,2,3,1,255,0,0,0,0,0,0,0,1,1,18,18,18,2,254,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,17,254,2,3,18,253,5,2,7,0,0,0,0,0,0,0,1,1,1,1,255,8,17,3,254,2,6,17,0,0,0,0,0,0,0,0,2,18,18,17,2,254,3,2,4,18,5,0,0,0,0,0,0,0,1,1,17,18,2,255,5,7,18,3,4,6,0,0,0,0,0,0,0,1,1,5,4,5,17,3,6,3,4,7,2,0,0,0,0,0,0,0,0,1,17,3,1,7,4,2,5,254,18,6,0,0,0,0,0,0,0,0,1,17,18,2,18,4,3,5,7,253,6,0,0,0,0,0,0,0,1,2,17,17,253,254,2,8,18,255,3,5,0,0,0,0,0,0,0,0,1,17,17,18,2,3,6,254,8,1,7,0,0,0,0,0,0,0,1,1,1,2,6,254,18,2,5,253,7,254,0,0,0,0,0,0,0,0,1,18,18,3,18,6,8,254,2,3,5,0,0,0,0,0,0,0,0,1,18,17,2,18,254,3,7,6,2,4,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,18,2,255,3,6,1,3,4,8,0,0,0,0,0,0,0,0,1,18,18,3,6,5,3,254,2,18,255,0,0,0,0,0,0,0,0,1,18,17,253,18,2,4,254,3,6,17,0,0,0,0,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+934380);
/* memory initializer */ allocate([3,1,2,17,3,18,7,255,5,2,4,0,0,0,0,0,0,0,1,1,18,3,18,6,8,18,254,5,7,2,0,0,0,0,0,0,0,0,1,17,2,18,6,3,2,5,4,8,1,0,0,0,0,0,0,0,0,1,18,17,255,2,3,18,18,2,3,17,0,0,0,0,0,0,0,1,1,18,7,6,5,5,3,1,4,2,4,0,0,0,0,0,0,0,1,1,6,17,3,8,1,5,7,255,2,1,0,0,0,0,0,0,0,1,1,18,254,18,3,254,2,7,4,6,18,0,0,0,0,0,0,0,1,3,18,253,18,2,3,18,255,7,2,5,0,0,0,0,0,0,0,0,2,18,254,7,1,3,2,4,6,253,7,0,0,0,0,0,0,0,1,1,18,254,2,253,18,254,17,255,4,2,0,0,0,0,0,0,0,0,3,17,17,2,5,3,7,18,6,4,2,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,17,4,6,6,4,5,3,4,1,0,0,0,0,0,0,0,0,1,18,5,3,6,2,3,8,1,3,7,0,0,0,0,0,0,0,1,2,18,17,254,2,18,3,5,7,255,2,0,0,0,0,0,0,0,0,1,1,18,18,3,6,255,4,8,5,2,0,0,0,0,0,0,0,1,1,1,5,3,4,1,1,3,5,7,3,0,0,0,0,0,0,0,0,1,3,18,18,2,18,18,255,2,3,18,0,0,0,0,0,0,0,1,2,18,18,255,18,2,3,4,6,18,5,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,3,1,4,5,2,7,1,3,6,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,18,255,18,2,3,5,254,6,8,0,0,0,0,0,0,0,1,1,17,18,4,8,3,2,5,2,7,6,0,0,0,0,0,0,0,1,4,1,2,5,18,254,2,3,7,255,4,0,0,0,0,0,0,0,0,2,18,17,255,3,6,18,2,3,7,5,0,0,0,0,0,0,0,0,1,254,18,2,253,6,18,4,3,254,5,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,17,6,2,4,8,3,5,255,17,0,0,0,0,0,0,0,1,1,18,3,18,6,8,18,254,5,7,2,0,0,0,0,0,0,0,1,2,17,17,253,2,18,254,8,3,6,255,0,0,0,0,0,0,0,1,1,18,254,17,18,2,3,254,6,5,4,0,0,0,0,0,0,0,1,2,18,17,255,3,18,2,5,3,6,253,0,0,0,0,0,0,0,0,1,18,17,2,18,7,18,2,4,3,17,0,0,0,0,0,0,0,1,3,18,18,5,6,4,3,4,18,6,5,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,7,6,5,3,4,2,5,4,3,7,0,0,0,0,0,0,0,0,1,254,18,18,18,3,6,4,2,5,2,0,0,0,0,0,0,0,0,3,18,17,253,18,3,2,5,255,17,3,0,0,0,0,0,0,0,1,1,17,18,7,3,1,7,4,2,6,5,0,0,0,0,0,0,0,1,1,18,2,254,255,18,5,3,254,1,2,0,0,0,0,0,0,0,0,3,18,18,255,3,2,7,5,18,4,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,18,2,254,4,8,18,3,6,5,0,0,0,0,0,0,0,0,2,18,17,3,5,254,7,2,18,3,255,0,0,0,0,0,0,0,1,1,18,2,254,255,18,5,3,254,1,2,0,0,0,0,0,0,0,0,2,3,17,18,18,2,5,7,6,18,3,0,0,0,0,0,0,0,1,1,17,18,18,4,3,2,18,7,8,255,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,1,2,3,5,6,1,4,8,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,17,255,18,253,2,8,3,6,17,0,0,0,0,0,0,0,1,1,17,17,1,2,4,5,255,2,1,6,0,0,0,0,0,0,0,1,1,1,2,6,254,18,2,253,3,254,5,0,0,0,0,0,0,0,0,1,18,3,18,6,18,5,2,4,255,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,18,255,2,18,3,6,4,254,7,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,255,18,18,18,2,254,4,7,2,3,0,0,0,0,0,0,0,0,3,3,17,254,5,2,7,18,6,4,5,0,0,0,0,0,0,0,0,1,17,6,18,3,8,4,5,3,8,18,0,0,0,0,0,0,0,0,2,18,2,6,2,18,3,2,4,5,8,0,0,0,0,0,0,0,0,1,3,18,18,2,18,255,2,18,2,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,3,6,17,254,5,1,2,7,4,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,3,3,18,17,5,6,2,7,254,8,18,0,0,0,0,0,0,0,1,1,18,255,3,1,7,2,255,4,6,17,0,0,0,0,0,0,0,1,1,18,2,254,255,18,5,3,254,1,2,0,0,0,0,0,0,0,0,2,18,1,2,18,3,6,5,2,4,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,254,2,18,18,8,5,3,2,6,0,0,0,0,0,0,0,0,1,18,17,2,18,3,2,7,254,18,4,0,0,0,0,0,0,0,1,2,1,18,2,3,255,5,6,4,7,17,0,0,0,0,0,0,0,0,2,18,17,3,6,254,2,3,8,5,17,0,0,0,0,0,0,0,0,2,18,18,3,2,18,255,2,4,3,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,17,255,18,2,3,254,5,18,2,7,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,253,18,2,3,254,18,5,6,253,0,0,0,0,0,0,0,0,2,18,17,3,5,254,7,2,18,3,255,0,0,0,0,0,0,0,1,1,1,18,255,2,3,1,254,8,2,5,0,0,0,0,0,0,0,0,1,18,18,3,6,18,2,3,4,8,5,0,0,0,0,0,0,0,0,1,254,1,18,2,254,5,7,18,2,255,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,18,255,2,8,3,4,5,1,7,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,18,255,2,18,3,254,5,4,2,0,0,0,0,0,0,0,1,1,18,17,2,18,3,8,5,2,7,17,0,0,0,0,0,0,0,0,1,18,18,3,18,6,8,254,2,3,5,0,0,0,0,0,0,0,0,1,18,18,2,18,2,6,18,2,17,7,0,0,0,0,0,0,0,1,3,18,17,18,2,8,18,5,255,3,6,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,7,6,5,5,3,1,4,2,4,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,17,255,3,6,18,2,5,8,3,0,0,0,0,0,0,0,0,1,17,18,18,4,7,2,3,254,18,5,0,0,0,0,0,0,0,1,2,18,1,2,6,2,5,18,2,4,8,0,0,0,0,0,0,0,0,4,18,4,1,2,3,5,4,1,2,6,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,17,2,255,18,3,253,5,2,4,0,0,0,0,0,0,0,0,1,17,17,3,6,3,5,254,2,18,255,0,0,0,0,0,0,0,0,2,18,18,3,254,18,2,253,5,3,6,0,0,0,0,0,0,0,1,1,17,17,2,4,1,3,5,2,6,253,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,1,3,2,7,1,6,3,4,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,255,18,2,1,5,3,8,255,254,0,0,0,0,0,0,0,1,1,17,18,255,8,2,5,3,4,1,6,0,0,0,0,0,0,0,1,2,1,18,3,255,5,1,2,4,7,6,0,0,0,0,0,0,0,0,1,18,18,3,6,5,3,254,2,18,255,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,1,18,255,3,8,5,6,1,2,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,18,2,3,6,18,255,4,2,3,0,0,0,0,0,0,0,1,1,1,3,5,18,2,6,7,2,3,1,0,0,0,0,0,0,0,1,1,1,3,8,18,5,2,7,1,3,254,0,0,0,0,0,0,0,0,2,17,2,18,3,6,2,4,5,8,3,0,0,0,0,0,0,0,0,1,18,17,2,18,3,2,7,254,18,4,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,253,18,255,3,254,5,7,1,2,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,3,18,18,2,6,18,5,18,2,3,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,3,1,255,1,3,254,2,5,7,253,18,0,0,0,0,0,0,0,1,2,18,7,3,253,2,8,2,5,4,17,0,0,0,0,0,0,0,1,1,1,4,5,1,3,4,6,7,8,3,0,0,0,0,0,0,0,0,1,18,17,2,18,255,2,3,18,2,4,0,0,0,0,0,0,0,0,2,18,18,254,18,2,3,4,7,5,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,18,2,1,3,2,5,1,2,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,18,255,2,3,5,8,6,1,254,0,0,0,0,0,0,0,0,1,17,18,8,3,4,6,5,2,8,7,0,0,0,0,0,0,0,1,2,1,3,254,18,2,5,1,7,255,254,0,0,0,0,0,0,0,0,3,18,17,255,3,18,2,3,6,4,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,18,4,18,6,7,8,3,18,2,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,17,253,17,2,254,8,3,18,4,253,0,0,0,0,0,0,0,1,1,18,17,3,5,6,2,8,1,3,7,0,0,0,0,0,0,0,0,1,18,18,3,6,5,3,254,2,18,255,0,0,0,0,0,0,0,0,3,18,18,2,6,18,5,18,2,3,17,0,0,0,0,0,0,0,1,1,18,18,5,4,6,4,5,1,4,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,3,17,18,253,2,5,18,6,255,7,0,0,0,0,0,0,0,1,1,17,18,3,2,5,255,6,8,4,7,0,0,0,0,0,0,0,1,1,18,1,254,3,2,1,7,6,3,4,0,0,0,0,0,0,0,0,3,1,2,17,3,18,2,7,5,4,255,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,254,2,18,18,8,5,3,2,6,0,0,0,0,0,0,0,0,2,18,5,18,2,3,7,254,1,6,8,0,0,0,0,0,0,0,0,1,2,255,18,255,2,4,253,5,18,3,0,0,0,0,0,0,0,0,1,3,17,18,5,2,18,7,3,6,5,0,0,0,0,0,0,0,1,4,1,2,5,18,254,2,3,7,255,4,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,1,18,2,1,3,4,1,5,2,7,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,17,18,2,4,5,18,254,6,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,18,255,3,5,6,8,18,2,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,18,18,4,6,8,18,7,3,2,5,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,255,18,18,18,2,4,254,2,3,6,0,0,0,0,0,0,0,0,2,18,254,7,1,3,2,4,6,253,7,0,0,0,0,0,0,0,1,1,17,18,8,3,4,6,254,5,3,8,0,0,0,0,0,0,0,0,2,18,1,2,6,2,8,3,18,5,4,0,0,0,0,0,0,0,1,1,3,18,18,2,18,2,18,3,2,18,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,3,17,18,5,2,6,7,1,4,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,30,3,42,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,254,2,1,240,246,1,3,1,0,6,1,253,7,1,234,2,252,253,11,14,6,255,1,243,29,228,10,10,248,0,247,248,8,249,10,253,244,251,248,1,254,9,254,251,238,1,9,248,248,3,41,7,247,247,22,214,227,14,238,242,224,1,241,240,8,15,16,240,5,2,7,250,240,249,1,1,253,254,0,8,20,230,245,2,239,0,253,222,219,10,44,254,22,2,252,7,14,5,6,15,255,3,253,247,233,251,242,8,255,242,250,251,248,54,31,250,18,2,237,254,245,226,250,237,2,254,242,1,2,254,255,253,253,1,251,1,253,252,248,5,252,0,1,3,7,251,252,253,244,3,254,253,12,203,205,6,255,6,8,0,255,5,1,250,248,7,5,238,252,255,1,0,253,253,242,255,250,0,242,255,255,5,253,245,1,236,10,2,19,254,254,2,4,3,0,5,0,3,1,254,0,250,253,252,251,253,253,249,0,222,4,213,17,0,203,243,249,24,14,5,238,9,236,1,0,253,2,3,251,254,7,235,5,231,23,11,228,2,1,245,9,13,250,244,5,7,2,4,245,250,255,8,0,1,254,2,252,250,252,0,251,227,13,250,234,253,213,12,215,5,24,18,247,220,250,4,249,252,13,4,241,255,251,1,2,251,4,0,255,13,250,251,1,0,253,1,251,19,234,31,229,4,241,250,15,9,243,1,247,10,239,4,255,255,4,2,0,253,251,249,3,248,13,19,244,8,237,253,254,232,31,14,0,7,243,238,0,3,6,13,254,1,244,235,9,254,30,21,242,2,242,253,249,8,255,254,247,6,1,249,7,13,3,255,246,30,4,246,12,5,6,243,249,252,254,254,7,253,250,3,4,1,2,248,9,2,253,251,2,0,9,3,7,252,240,243,3,23,229,18,46,218,6,4,43,255,0,8,249,252,255,11,249,6,253,1,1,18,248,250,0,3,4,22,253,252,254,252,245,40,249,253,243,242,249,246,14,7,5,242,11,251,7,21,254,9,253,0,0,254,4,254,0,2,0,255,2,255,0,0,2,2,2,255,1,253,255,241,254,193,229,235,209,242,1,242,10,0,2,1,0,252,0,253,247,4,2,6,250,0,251,11,249,241,6,249,250,3,7,241,251,23,243,250,12,248,9,2,253,3,4,6,0,3,0,254,252,2,1,1,255,1,254,255,252,234,241,210,190,10,20,2,239,12,250,1,254,254,0,1,251,1,2,255,0,0,1,0,252,0,1,246,253,248,5,7,245,2,245,29,231,11,10,0,255,5,249,254,251,254,4,4,253,5,254,1,255,255,253,254,1,248,253,2,254,4,251,255,249,254,1,242,249,3,226,241,242,3,252,255,3,243,255,253,1,2,3,255,254,253,2,2,253,3,1,253,2,0,252,6,5,251,10,199,3,22,206,1,254,251,250,255,5,1,2,2,1,254,2,2,0,255,249,2,1,3,2,0,4,3,254,3,253,4,252,24,221,253,38,250,251,15,20,3,16,249,251,0,252,251,0,0,1,0,0,0,255,255,1,1,255,1,254,0,0,0,0,0,255,254,255,251,254,213,253,46,204,246,7,248,11,254,255,0,0,255,0,255,2,215,33,212,208,241,230,247,6,3,3,253,2,2,2,2,255,255,254,1,3,0,0,5,2,3,1,252,1,6,1,250,255,254,1,242,252,0,251,254,2,254,0,250,1,0,8,235,32,253,220,250,254,255,249,3,0,1,250,253,254,3,0,2,2,8,252,252,6,2,1,3,250,4,3,13,0,244,255,25,236,254,233,241,7,253,245,253,6,255,0,0,0,253,255,0,0,254,255,254,254,1,255,0,0,10,3,254,3,3,249,250,251,0,252,196,240,250,38,5,6,251,0,0,1,0,0,0,0,0,0,1,255,255,0,1,0,0,1,0,0,255,0,248,2,247,10,40,31,200,235,4,20,252,7,254,254,0,4,253,255,7,3,1,3,248,0,3,1,2,5,1,254,14,5,4,5,5,5,251,9,190,0,236,254,248,4,254,255,4,255,248,254,252,255,253,253,2,249,253,5,7,254,45,31,239,240,254,254,255,234,1,255,253,3,5,253,5,255,252,0,7,5,8,7,2,9,247,247,249,245,253,248,17,252,34,32,18,22,1,2,1,249,251,6,255,6,4,10,254,249,6,0,14,9,6,255,254,253,4,250,248,4,7,255,28,38,15,255,16,245,5,8,4,246,3,246,239,5,3,3,3,1,1,1,2,255,2,1,0,0,255,0,0,254,1,253,0,1,2,254,252,254,0,255,1,253,1,1,1,255,8,8,66,33,251,2,253,249,2,248,252,10,17,238,249,4,252,249,250,250,251,5,244,2,0,6,8,254,1,4,245,2,1,8,31,19,6,9,16,250,250,255,254,253,245,254,7,7,17,3,4,10,2,5,243,8,7,1,4,5,7,6,7,248,9,248,33,6,3,255,1,0,249,251,0,14,249,1,249,1,2,252,7,10,240,12,1,250,3,8,255,10,243,250,244,233,12,253,30,14,254,241,0,8,3,237,5,253,2,3,13,7,14,253,246,0,8,5,250,240,248,248,14,2,255,1,247,245,11,251,27,9,248,6,252,4,252,255,5,4,1,249,251,252,241,1,9,0,8,4,1,239,11,254,237,255,250,248,3,244,3,239,33,246,253,255,2,7,7,254,9,8,238,255,243,246,253,253,11,8,254,244,248,1,4,9,14,10,253,0,2,1,254,3,31,10,253,246,8,255,251,245,7,251,3,6,1,4,240,10,5,252,254,246,255,13,6,251,249,12,7,253,239,1,12,252,29,8,1,2,5,2,250,249,0,255,6,255,10,6,252,5,2,2,254,248,250,245,14,243,27,3,254,244,5,240,2,230,20,15,255,253,251,253,253,6,255,3,251,1,7,2,1,0,255,255,0,255,9,7,250,253,4,251,252,8,248,231,248,252,34,23,255,254,1,1,255,254,255,1,255,0,0,0,0,254,255,1,0,2,1,255,4,0,0,1,255,0,5,3,12,247,68,240,10,0,248,14,250,1,244,0,0,253,251,245,250,12,9,246,253,5,0,7,11,2,4,253,248,253,7,4,3,253,34,4,244,13,251,7,245,254,255,1,252,242,235,3,253,253,252,249,247,252,3,239,254,243,10,254,12,252,0,247,1,251,31,10,246,6,5,6,4,249,10,0,228,253,0,245,255,251,16,246,240,7,20,2,252,2,251,0,15,6,5,246,7,247,20,4,1,249,254,249,4,253,254,249,255,242,6,240,4,251,252,250,251,0,254,2,250,9,251,4,238,8,246,8,15,0,32,1,251,7,253,7,15,252,0,240,9,5,251,5,4,253,244,247,238,10,2,2,253,7,3,255,6,247,246,3,15,252,35,249,255,246,2,2,252,254,10,2,255,2,254,1,255,242,245,3,248,5,248,254,6,255,249,1,7,5,7,8,30,252,30,14,2,254,1,2,3,248,3,0,254,0,247,2,1,4,250,255,254,5,0,1,254,12,6,253,9,253,4,244,21,217,24,254,3,5,1,254,254,254,253,6,248,254,245,248,255,4,2,2,252,246,12,251,245,1,241,222,245,249,245,255,7,242,38,255,252,4,8,9,8,1,251,247,4,254,15,252,11,241,20,255,255,253,4,247,254,254,254,8,6,12,251,0,11,244,27,252,0,8,252,3,245,6,245,2,3,0,5,248,249,250,247,235,4,245,255,240,249,16,253,7,249,4,251,0,11,249,31,3,1,3,4,11,245,254,253,250,6,5,0,3,247,250,4,252,0,4,248,13,250,243,255,251,255,4,0,0,9,234,24,18,249,3,10,243,250,6,250,6,22,1,0,242,2,3,7,255,8,20,255,5,252,13,9,247,247,6,0,252,0,248,31,252,253,252,0,1,7,3,249,0,5,254,1,3,3,1,251,254,5,2,245,4,0,255,12,0,253,243,15,8,250,229,34,0,253,253,10,252,2,255,253,0,255,255,252,2,6,254,12,1,3,250,249,250,251,4,237,250,248,222,252,248,10,249,23,10,249,0,255,250,8,4,252,2,251,248,249,247,248,5,9,7,250,1,244,244,255,240,5,0,16,3,249,248,27,252,23,15,248,4,8,5,6,11,253,5,3,255,245,6,251,0,2,250,253,250,4,255,5,251,244,250,7,251,9,3,6,249,29,1,1,3,254,254,250,254,1,6,250,253,1,2,3,4,1,5,255,0,4,2,11,6,2,253,13,247,237,18,241,246,36,21,253,253,2,255,249,6,252,1,253,255,254,2,3,249,253,0,254,0,254,6,237,3,248,2,250,7,255,0,29,250,28,246,251,1,253,249,244,252,1,1,255,13,246,255,247,251,243,6,13,3,252,2,3,11,2,6,231,240,250,0,14,255,27,16,250,255,249,251,254,251,251,255,9,1,0,3,248,244,250,5,250,5,3,247,1,4,249,246,247,249,239,251,241,233,25,3,248,254,9,253,252,3,255,8,249,249,251,252,254,9,4,255,249,252,251,240,3,250,18,243,247,16,241,8,15,246,24,5,1,218,2,34,9,10,11,2,2,250,3,2,254,5,4,249,255,1,4,0,3,1,248,255,250,5,4,2,252,5,2,255,1,234,15,18,254,10,240,247,248,245,8,4,0,7,242,251,255,249,12,17,9,5,249,252,244,250,7,0,7,2,254,1,245,227,7,10,19,255,248,247,7,1,9,6,8,249,242,8,253,245,243,0,249,233,254,248,12,9,2,14,19,1,255,5,232,229,245,36,2,6,253,4,250,8,0,12,255,252,250,3,4,255,2,253,254,3,2,255,254,252,0,255,254,7,2,3,247,232,11,13,246,244,12,254,7,4,8,13,253,253,2,9,253,252,4,13,5,13,250,253,1,15,7,253,0,19,254,247,248,241,7,14,252,251,2,238,237,254,2,17,16,6,246,10,247,14,255,251,255,250,249,2,9,11,13,6,251,244,3,2,246,219,13,1,3,242,0,236,4,253,8,2,254,253,247,251,253,239,255,13,245,2,250,4,4,0,3,1,247,252,251,252,254,234,251,46,248,5,9,245,8,7,7,255,255,254,249,2,253,3,255,254,7,0,2,255,1,254,254,253,6,0,252,250,240,229,15,16,252,14,249,230,2,254,6,5,253,11,0,2,3,9,249,255,2,252,252,255,6,10,1,1,253,254,3,0,253,234,10,26,1,2,253,3,17,253,249,9,1,235,252,5,3,0,249,250,3,3,248,249,247,3,7,1,248,12,6,249,247,231,3,18,9,250,245,0,251,244,9,248,249,250,250,22,2,250,253,15,3,2,254,9,14,246,249,15,13,6,254,11,5,236,251,28,11,10,252,252,0,249,3,5,2,251,248,2,6,10,9,247,238,3,14,1,3,253,255,250,7,7,2,255,248,226,7,12,10,8,7,243,240,0,1,255,250,245,241,4,1,254,10,241,1,11,254,8,9,249,249,9,251,2,7,238,246,224,10,11,3,255,3,251,5,2,14,250,3,1,5,241,245,6,20,4,0,244,249,3,1,255,10,6,255,247,252,255,1,231,242,12,245,9,9,240,232,239,22,247,11,226,253,252,6,249,9,2,255,251,250,2,255,255,10,1,253,3,4,8,242,230,250,9,8,17,245,232,249,252,248,254,10,2,2,255,2,13,12,249,4,250,246,6,6,243,245,249,240,0,254,5,252,226,243,12,16,250,12,240,243,5,15,254,254,246,249,7,11,255,252,254,252,7,4,248,1,3,0,11,3,254,251,4,252,235,20,22,2,20,248,1,244,251,247,4,246,239,253,248,253,3,244,1,253,0,7,4,7,7,253,7,5,3,1,251,244,236,2,29,11,250,9,249,250,252,0,6,17,243,254,246,239,255,238,2,0,14,250,1,0,3,2,246,1,251,254,5,16,219,255,26,254,242,1,251,242,2,2,3,6,1,1,4,0,255,0,254,254,4,9,250,0,254,10,249,254,4,1,0,247,232,244,5,5,3,239,242,4,3,2,252,10,234,248,253,6,1,12,248,4,1,9,255,18,253,6,5,3,251,9,251,242,223,254,20,243,246,2,249,255,11,247,248,18,253,1,8,0,254,10,7,254,243,9,253,252,5,254,254,255,251,1,249,246,233,8,14,1,7,1,253,249,4,1,1,8,249,15,242,13,14,2,5,243,251,248,255,6,3,6,9,6,15,14,5,243,231,246,13,239,232,249,243,250,246,248,2,0,243,246,252,248,4,247,9,252,4,253,253,3,3,251,247,1,254,11,2,244,233,1,18,245,254,5,9,251,5,14,247,253,254,250,2,254,11,243,1,253,11,247,252,254,250,8,10,1,4,2,1,251,238,16,22,2,0,8,250,247,249,10,240,23,10,245,255,7,2,7,2,1,251,6,1,0,252,9,2,253,1,0,252,253,230,14,11,2,247,17,254,255,251,240,247,251,10,243,1,6,12,10,11,0,0,253,242,6,254,0,4,251,255,249,255,246,223,1,8,11,251,1,250,7,4,5,6,1,254,246,251,250,12,245,5,246,4,12,255,255,253,4,255,9,0,16,239,242,219,7,7,254,5,248,245,2,243,4,237,1,8,8,4,247,2,252,3,12,2,4,252,248,8,1,4,8,255,6,254,250,226,18,17,1,234,253,4,249,246,7,0,248,8,255,4,2,8,6,254,2,7,4,4,3,250,2,1,253,1,255,251,239,238,253,22,248,1,9,254,239,20,251,251,244,251,4,251,247,8,254,16,253,0,19,248,8,1,2,252,0,11,0,253,247,233,3,10,4,4,253,254,254,254,1,234,11,0,254,5,254,14,247,245,252,7,5,32,1,253,249,0,21,247,7,250,0,0,0,2,255,1,0,1,3,0,0,1,0,1,0,1,253,0,255,254,0,255,255,253,255,1,252,1,255,251,187,237,253,251,248,244,4,253,237,245,251,0,242,7,18,250,7,22,8,14,15,10,3,255,253,5,255,7,249,1,250,3,230,245,255,250,4,252,251,240,0,250,253,11,1,0,9,5,16,3,252,223,252,4,249,0,1,6,245,254,243,254,238,20,231,240,4,0,255,0,251,1,0,2,0,11,246,4,246,7,16,2,16,15,2,255,2,9,2,8,253,251,254,0,253,0,223,254,253,241,10,10,247,255,7,3,5,251,248,248,253,15,247,4,12,13,243,242,10,250,9,22,229,23,255,5,232,2,226,5,0,254,7,251,251,3,5,3,253,251,2,1,252,3,253,255,1,254,10,22,253,252,254,254,249,3,8,1,14,4,219,9,253,252,255,1,252,0,6,2,6,249,246,246,255,252,11,253,7,250,4,244,255,5,1,249,10,250,17,252,8,3,216,13,2,12,4,249,14,253,16,254,18,2,13,5,5,1,11,255,0,9,2,250,255,2,250,2,251,3,5,1,255,1,224,249,240,11,7,252,2,251,247,9,11,11,15,243,245,11,9,4,3,248,246,12,12,0,0,240,247,13,2,9,4,243,223,3,6,4,5,4,3,255,5,6,4,2,245,255,241,245,255,1,11,253,254,24,252,250,231,246,241,248,0,0,251,4,226,2,10,253,250,1,247,251,6,9,246,253,8,255,4,255,11,245,3,9,11,253,6,239,5,248,223,9,243,19,254,9,231,2,0,0,255,253,0,254,1,0,0,2,1,0,254,0,255,2,0,255,4,255,2,253,4,254,3,3,1,0,241,12,193,27,254,14,9,255,3,0,1,1,237,15,3,4,0,246,1,251,3,0,251,246,2,240,252,8,244,250,7,251,246,255,223,252,0,3,1,3,1,2,4,4,9,250,248,251,1,244,3,8,246,6,255,1,13,251,251,2,252,13,238,246,249,247,223,10,250,253,244,5,255,11,250,0,254,1,2,249,3,1,3,254,1,8,246,7,255,253,3,0,13,1,6,7,240,249,217,8,250,255,11,6,253,8,3,251,3,0,251,254,250,253,252,2,253,13,245,1,7,5,19,251,253,241,255,7,255,6,223,8,249,3,252,253,252,1,6,251,251,6,248,255,249,4,255,250,254,1,7,0,1,1,251,2,254,0,243,254,225,242,217,244,246,9,0,253,1,255,255,0,1,251,255,252,254,5,2,249,18,248,254,237,249,249,244,242,245,255,247,243,249,244,225,247,253,240,10,9,1,246,244,2,254,2,7,253,253,1,252,251,247,5,7,3,255,4,245,248,4,13,246,13,10,252,220,1,249,244,4,236,249,249,2,11,255,254,3,244,1,0,250,249,6,4,13,3,253,4,3,250,244,5,251,234,243,248,219,250,249,5,3,5,7,9,242,253,10,17,255,1,244,5,250,0,252,247,0,245,242,3,13,6,231,248,244,4,246,18,226,255,246,6,246,6,6,1,246,0,249,5,254,17,238,252,0,253,240,250,253,248,5,1,252,6,249,16,6,10,255,0,224,245,255,9,9,251,4,9,6,9,252,254,7,11,4,2,251,252,250,0,2,253,255,5,10,0,12,246,238,253,255,14,223,2,4,248,238,252,251,245,4,246,252,9,13,244,1,250,1,2,4,247,8,3,250,21,13,255,254,1,254,6,249,0,226,1,6,255,2,253,255,252,6,252,0,4,2,2,247,2,6,3,254,4,255,9,250,0,7,248,5,19,254,9,251,2,223,248,2,1,12,251,248,8,3,254,252,1,254,5,252,247,248,248,7,245,252,6,246,7,255,255,254,255,16,32,249,20,223,250,238,2,6,13,9,9,255,3,239,24,254,250,28,8,254,6,3,246,222,240,243,252,241,245,244,253,246,4,248,4,225,252,245,0,18,2,240,247,243,254,254,244,253,234,30,0,8,3,9,252,240,1,0,245,15,254,252,6,251,6,1,2,231,244,14,255,5,7,3,241,248,1,5,254,12,13,11,231,3,1,0,254,252,240,233,0,251,239,7,5,247,6,251,2,224,249,3,255,6,14,2,244,247,247,4,7,4,6,5,248,4,2,4,5,254,8,8,250,0,10,236,255,3,255,8,23,223,251,253,11,250,3,252,5,7,3,4,5,254,3,255,30,6,1,8,250,0,0,247,6,247,4,2,9,250,1,244,0,222,18,239,13,0,1,9,252,245,0,7,0,246,252,255,6,250,4,1,6,247,3,251,250,245,2,252,14,23,253,2,5,226,12,242,5,229,2,0,7,1,4,30,8,7,5,1,255,0,5,8,246,48,245,12,33,6,8,241,20,254,251,32,5,237,10,240,252,244,249,254,0,8,250,236,238,16,253,0,31,254,11,2,247,49,237,244,233,10,26,16,254,4,235,242,13,245,247,251,247,255,3,251,235,2,10,0,0,10,235,249,7,230,247,22,32,58,11,253,11,251,248,243,6,251,247,1,10,14,248,7,7,10,3,254,255,245,245,250,213,253,14,237,238,19,18,224,10,45,250,6,21,236,244,2,4,6,6,252,3,3,1,21,22,253,254,245,250,255,254,8,8,32,235,7,28,252,250,253,254,50,2,2,27,251,248,12,7,251,255,252,239,27,6,13,7,2,250,244,2,246,251,239,11,4,17,244,254,5,239,37,240,48,242,238,29,8,24,11,251,247,11,255,1,243,253,1,1,255,2,0,0,0,255,1,255,7,2,253,3,0,6,2,10,54,231,7,54,251,250,255,241,9,13,232,241,244,3,21,5,8,3,253,252,254,252,3,245,251,248,9,16,8,247,246,253,46,210,2,1,246,10,17,11,236,220,10,14,0,251,7,243,250,247,232,45,2,8,8,0,17,20,12,232,1,249,241,253,46,243,254,20,1,243,245,243,2,15,1,10,255,3,0,0,0,0,0,0,0,0,0,0,0,0,255,0,254,255,240,247,31,187,222,26,7,17,255,250,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,251,236,18,174,22,3,249,9,4,6,2,252,255,0,254,2,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,255,15,251,62,220,4,52,249,5,0,6,1,2,1,1,255,0,3,237,19,236,13,252,245,8,8,240,10,1,242,30,1,223,10,245,45,226,3,252,253,243,7,12,3,234,3,254,252,254,255,0,0,0,0,0,0,0,0,0,0,1,0,0,2,1,11,8,70,48,246,21,4,9,247,247,252,250,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,255,80,2,241,220,246,251,254,8,254,2,0,0,0,0,10,8,248,248,232,12,255,0,20,9,255,254,2,254,12,246,254,243,35,213,44,15,246,231,4,10,253,251,251,7,255,3,1,1,1,1,0,0,1,0,0,0,0,0,0,0,254,255,238,9,49,184,7,248,7,251,2,3,2,254,1,254,253,1,255,4,253,10,19,4,3,20,6,232,6,9,8,15,18,18,220,19,57,245,4,253,8,7,2,253,254,247,241,254,12,252,20,3,11,247,252,22,42,231,1,5,246,237,0,9,240,5,2,10,44,227,17,253,247,254,255,8,14,249,255,16,251,1,249,16,245,12,6,33,241,14,233,2,230,8,2,10,0,251,8,248,38,218,252,5,5,5,1,22,241,7,6,0,4,28,255,244,2,10,254,0,7,17,12,22,252,10,25,29,5,18,4,1,27,217,31,17,2,2,22,233,13,16,1,249,252,251,0,1,0,0,0,0,0,0,0,0,255,0,254,0,242,0,249,245,49,234,252,19,17,217,4,227,10,2,36,252,23,255,254,254,254,254,1,15,251,249,240,248,237,16,253,236,36,247,253,20,39,236,0,2,27,240,10,10,242,234,240,253,13,248,5,247,6,231,7,37,13,246,251,3,251,7,18,234,249,9,251,252,50,245,252,251,251,8,252,254,252,229,14,20,7,247,0,242,246,229,242,239,250,26,10,2,14,244,251,0,8,9,0,228,55,249,244,249,4,246,10,7,244,11,3,5,9,248,2,23,4,254,255,236,254,14,10,247,247,232,10,0,11,244,12,11,49,231,254,29,7,243,21,246,11,239,3,1,248,5,3,0,242,250,18,254,17,247,237,9,251,9,14,6,19,253,27,1,41,235,20,241,33,0,26,14,7,10,3,20,253,244,255,16,15,248,3,248,248,21,251,240,227,4,1,250,252,228,2,31,37,230,254,13,24,8,247,250,227,10,7,2,7,8,246,246,11,13,224,2,16,9,14,23,241,243,24,13,4,229,14,12,31,238,17,23,254,249,242,9,239,250,246,20,9,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,1,89,8,10,250,2,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,255,4,249,64,206,7,37,2,5,0,0,0,0,0,0,0,0,254,5,3,252,252,253,2,253,3,253,5,4,1,250,255,1,6,254,50,221,249,43,7,249,251,230,24,21,3,241,5,6,248,21,237,33,248,22,245,17,3,0,0,254,1,253,6,255,10,248,4,245,252,251,0,8,252,3,1,252,4,2,8,4,249,5,236,9,234,3,242,1,6,13,23,254,252,249,2,0,11,4,6,3,249,245,249,4,5,5,244,8,2,4,7,253,249,6,252,20,236,16,254,7,6,16,11,12,249,249,5,3,247,252,1,2,5,2,1,247,254,239,252,6,246,7,249,250,247,18,239,12,232,1,255,4,14,9,4,3,2,8,244,242,4,248,252,7,7,6,255,13,247,252,255,1,0,252,15,8,231,2,245,6,251,24,228,251,8,12,254,6,8,253,8,247,255,251,255,251,6,255,255,255,252,8,244,254,243,7,2,1,242,14,238,20,246,12,254,9,1,0,12,254,15,246,26,239,16,245,10,246,9,254,4,248,2,253,4,4,2,253,251,1,238,12,238,21,250,12,250,13,231,18,1,11,247,251,0,10,251,3,253,8,247,7,4,2,247,0,5,0,2,253,9,248,252,16,1,18,226,9,1,6,248,13,13,244,250,255,13,7,6,2,241,253,5,5,1,250,1,251,0,2,240,0,3,252,235,1,254,6,213,18,255,5,255,4,6,254,255,253,255,253,0,1,2,247,0,255,0,254,0,255,255,254,6,0,1,254,233,10,4,7,224,245,238,2,254,249,250,253,253,244,19,3,251,250,16,250,16,2,16,16,8,254,13,8,241,245,2,10,248,2,243,2,227,24,236,19,1,10,252,10,1,2,247,11,255,254,9,251,19,249,16,247,254,238,11,1,1,0,7,253,250,3,4,13,230,10,246,28,249,28,1,7,0,242,5,7,4,252,3,254,3,3,245,7,6,4,0,255,2,255,253,2,250,16,225,13,246,17,250,4,242,4,4,255,246,12,251,1,242,15,0,248,1,251,3,3,9,251,7,236,7,4,11,251,237,3,239,14,244,16,234,18,14,8,254,4,10,12,242,4,253,2,3,7,249,7,250,2,254,252,251,0,251,254,2,1,247,249,245,24,220,247,245,5,7,244,243,18,254,20,1,252,255,246,15,250,14,1,0,2,1,2,247,240,245,7,13,0,232,24,238,18,234,14,245,13,244,11,246,11,249,11,251,252,255,1,5,2,3,255,1,251,7,252,5,250,8,249,8,250,250,18,234,22,5,11,255,6,19,22,8,4,248,20,254,15,250,238,0,223,247,244,255,6,5,2,5,5,251,239,253,253,1,11,240,9,238,11,252,18,20,26,246,8,1,245,8,252,0,7,3,5,2,2,10,254,252,4,252,254,1,252,251,255,246,6,255,18,239,27,253,10,254,12,249,247,1,1,255,7,244,255,249,250,255,8,3,241,8,9,3,249,4,255,1,255,242,6,240,22,2,5,0,5,238,11,6,253,22,236,247,253,6,250,249,241,1,15,248,11,8,253,248,1,248,2,6,254,235,5,237,19,249,4,249,0,248,6,12,5,253,234,243,250,255,253,254,242,6,253,1,248,249,251,250,11,253,246,251,2,255,9,244,15,250,6,237,14,247,11,3,12,239,253,8,252,253,252,1,251,4,5,249,241,249,15,250,251,1,251,253,1,244,20,241,20,242,3,242,9,250,33,243,6,254,8,250,7,251,250,253,253,0,8,253,253,1,254,2,2,6,251,251,254,249,12,238,12,238,10,252,8,2,4,8,9,0,3,248,3,6,244,252,1,25,251,247,6,249,0,247,249,3,251,252,252,238,12,246,11,234,0,241,5,254,2,253,6,252,252,253,241,254,253,21,6,244,245,19,3,3,242,7,0,245,234,246,0,241,2,226,15,239,13,240,8,249,10,248,2,11,3,10,249,7,234,12,246,3,244,6,246,12,246,7,248,5,2,9,1,247,11,242,6,246,21,5,12,251,5,7,21,6,2,254,255,255,4,2,236,238,255,242,3,255,4,249,10,1,11,4,252,234,8,226,13,235,252,4,255,12,9,254,253,2,250,4,243,254,8,8,1,249,3,252,251,255,249,254,8,8,7,8,0,250,252,221,16,243,15,245,14,249,9,255,11,7,0,13,10,255,8,1,1,254,8,255,2,2,3,246,255,7,243,253,249,241,7,240,14,238,17,250,14,3,4,7,253,10,234,5,241,4,252,245,15,241,11,245,20,1,0,2,1,11,253,11,249,244,3,5,16,219,255,15,15,241,10,3,246,1,15,7,241,243,8,9,253,2,12,248,2,251,0,253,4,5,247,252,5,240,26,252,14,234,26,6,253,248,4,21,6,16,252,245,7,246,3,3,7,252,2,247,8,254,2,5,254,252,254,7,255,249,246,4,3,2,252,244,246,252,251,16,19,240,1,2,247,246,0,9,7,248,3,12,8,250,245,243,255,253,236,6,251,242,239,3,251,14,244,244,8,250,231,21,21,10,248,244,4,10,252,3,247,11,9,0,4,2,241,1,242,4,1,0,252,252,247,253,255,6,3,250,6,246,252,14,8,2,253,244,237,0,11,236,1,6,254,229,250,10,239,242,239,247,8,248,3,244,243,16,252,254,12,249,245,2,243,3,7,240,238,255,244,254,1,244,247,254,250,2,9,234,253,252,242,249,7,255,2,249,248,248,15,15,18,15,16,252,219,11,15,244,255,253,3,6,6,0,251,253,251,9,1,1,245,255,248], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+944620);
/* memory initializer */ allocate([250,2,3,0,250,7,251,244,13,10,238,252,253,235,6,16,241,249,244,247,1,244,255,10,254,255,253,4,252,1,240,255,12,247,5,9,242,251,9,3,4,26,228,3,250,232,4,5,3,13,5,255,3,255,3,1,1,251,3,0,249,248,249,253,3,251,4,0,252,2,246,250,25,26,250,10,250,248,15,11,250,253,2,249,5,14,9,255,0,244,4,252,246,1,253,3,254,254,250,255,246,8,241,246,19,17,248,0,253,249,7,5,243,255,7,249,1,13,244,243,17,244,1,26,238,253,251,250,4,5,8,1,2,251,3,0,0,0,2,253,254,251,7,13,252,9,0,251,4,255,245,248,252,0,243,2,209,233,248,245,252,4,254,253,238,252,4,5,255,17,244,248,1,244,7,20,244,3,254,245,16,12,250,1,243,240,250,253,253,251,4,244,251,247,10,1,245,0,4,7,7,8,3,255,3,237,32,8,237,248,2,4,244,15,240,3,1,9,254,1,254,8,5,6,252,255,11,248,3,255,4,254,14,32,247,233,246,244,22,15,255,254,10,0,4,6,248,4,241,254,255,252,0,248,4,1,248,3,4,1,239,244,6,248,16,13,236,248,255,240,10,21,237,11,247,251,7,18,250,7,249,238,13,2,254,8,244,247,2,4,251,16,4,0,17,245,12,7,244,5,255,231,30,248,249,250,252,249,9,8,7,3,3,240,8,0,254,254,238,253,252,251,1,4,253,250,6,240,17,6,253,2,247,239,12,11,11,2,236,8,1,1,0,2,254,250,235,243,247,241,255,248,250,248,0,254,245,249,6,247,3,6,8,16,4,251,23,26,246,253,4,0,2,2,252,4,254,244,12,10,245,0,246,240,3,0,0,246,251,240,10,250,27,13,253,4,254,243,15,5,2,5,3,252,13,12,245,249,0,1,11,12,2,13,241,248,9,254,3,8,251,248,4,3,9,3,245,10,14,231,14,8,254,5,244,235,2,10,249,2,253,2,0,2,255,253,251,250,255,240,2,8,255,5,1,245,5,9,249,8,243,244,4,12,252,1,255,255,27,29,10,15,2,250,253,4,235,10,247,245,250,255,247,253,250,253,255,250,11,251,0,254,251,225,11,3,255,5,253,4,5,7,246,5,246,243,4,12,241,254,2,249,1,247,253,246,253,249,17,248,251,36,8,249,248,236,12,8,1,255,3,0,1,4,246,3,1,4,254,253,254,253,246,4,255,249,3,2,243,253,251,9,22,6,233,3,246,249,17,17,18,242,248,248,2,4,248,2,253,248,6,4,255,7,0,0,253,0,244,253,253,246,241,253,9,3,233,247,243,238,12,13,254,0,1,8,255,2,249,244,251,14,2,1,234,6,246,248,247,28,249,242,253,1,2,255,13,7,254,249,1,253,6,9,253,254,4,254,2,1,246,254,254,234,254,249,246,251,245,229,244,240,4,249,2,250,253,1,8,0,254,12,253,252,58,15,246,252,254,2,254,0,254,250,2,4,255,1,252,1,255,251,252,253,3,1,10,255,0,5,21,7,242,6,253,240,15,17,240,13,3,250,252,6,244,251,1,252,249,248,2,3,250,6,255,248,5,4,250,254,248,245,15,10,0,8,250,241,33,8,254,18,241,245,5,255,0,15,241,252,252,255,10,7,243,4,252,0,8,3,249,254,0,254,0,254,252,251,242,240,12,38,7,12,6,252,0,255,0,3,254,250,0,2,247,1,0,255,0,254,4,1,248,252,18,1,14,5,244,253,20,239,5,19,245,248,11,253,3,9,249,248,9,239,2,15,246,245,5,251,7,15,250,254,249,2,38,5,19,16,251,4,243,236,0,4,252,6,4,2,249,6,248,254,251,249,6,3,252,253,254,253,7,250,252,0,245,244,8,241,253,14,249,234,245,2,22,14,237,2,237,250,1,3,238,14,2,250,254,248,253,250,5,249,248,252,1,1,8,7,25,235,12,250,251,252,246,6,0,10,1,244,18,251,241,4,1,14,255,5,8,249,1,249,253,9,10,1,255,0,9,10,32,241,8,2,11,249,238,248,2,250,247,240,253,3,255,3,1,251,4,254,1,248,0,250,253,245,1,5,0,0,14,0,23,231,22,3,7,10,0,254,7,8,0,10,0,0,3,2,3,246,0,10,0,249,0,10,255,251,249,1,255,2,12,0,25,238,251,252,13,246,3,250,7,21,0,240,3,246,250,5,249,253,2,5,3,250,4,9,248,12,254,3,2,4,31,15,27,236,10,249,15,246,9,248,4,251,3,253,5,6,11,254,244,254,6,254,1,2,255,255,1,1,3,1,1,2,12,252,13,233,12,250,2,4,253,13,6,249,5,237,249,18,1,249,7,1,16,249,3,0,3,0,244,8,245,9,4,7,29,1,3,234,251,6,0,12,242,11,1,6,253,4,6,254,4,243,12,1,1,3,245,9,246,255,249,16,245,255,3,9,4,4,36,233,251,248,241,1,250,3,13,255,251,249,4,9,2,245,253,5,1,3,250,255,252,252,254,2,3,255,251,254,19,10,6,239,2,252,254,252,253,13,2,2,243,249,253,245,9,250,1,247,251,4,251,247,238,249,245,9,4,245,8,4,16,253,9,240,18,254,244,240,245,11,238,16,243,6,2,8,3,8,252,240,10,245,255,253,248,5,247,252,9,252,0,253,14,15,3,233,251,7,248,250,2,17,2,12,248,244,13,255,247,3,1,1,19,15,4,255,1,2,253,2,253,1,5,3,32,5,246,209,251,255,4,11,249,0,2,254,1,249,6,252,6,2,252,254,2,254,0,252,1,250,251,2,254,255,253,252,20,8,10,235,249,247,240,12,1,4,6,251,9,245,249,4,245,28,253,2,4,250,10,248,251,251,247,9,254,255,6,251,38,3,23,231,250,238,3,246,248,6,246,1,246,2,2,0,249,2,252,5,255,8,253,0,3,3,255,1,0,252,252,0,20,5,16,234,24,238,2,244,242,249,253,10,2,7,246,2,248,1,8,255,4,1,4,254,5,247,238,248,243,5,245,10,14,8,244,240,9,245,253,250,231,249,6,5,249,240,10,2,249,255,247,253,16,4,3,3,253,253,241,13,253,4,13,249,16,247,19,233,7,237,253,251,241,11,235,21,240,18,255,6,10,246,18,242,16,241,6,251,247,5,239,13,246,13,0,10,8,252,4,232,8,235,238,9,245,4,250,17,5,247,254,254,2,15,254,253,254,1,7,243,15,246,248,245,3,3,255,255,14,17,6,224,5,239,254,0,15,255,251,16,1,251,254,9,253,8,4,254,254,252,253,1,0,7,253,4,251,0,249,2,24,6,22,244,8,3,242,4,249,8,6,5,6,1,6,244,15,10,4,11,9,6,249,252,10,247,2,255,251,11,15,3,17,12,3,233,5,255,254,1,247,255,253,1,8,1,251,17,11,0,254,245,7,4,0,229,249,1,2,248,9,7,5,3,12,10,12,246,252,5,255,2,232,5,248,2,6,239,19,5,12,254,16,249,250,242,4,1,253,13,240,5,255,4,1,1,31,9,11,239,10,253,249,7,1,2,2,4,253,255,11,4,251,248,1,4,15,250,228,1,8,3,250,5,17,254,2,252,11,19,16,230,0,249,249,2,243,241,244,9,253,27,8,4,250,1,4,250,11,255,250,249,253,0,250,4,250,249,253,255,10,18,16,224,19,247,252,253,249,8,8,253,245,254,250,240,13,13,250,255,10,254,254,247,0,253,9,4,11,254,250,6,9,4,19,223,4,7,244,36,253,255,8,254,2,248,247,252,248,0,1,255,0,252,252,3,0,3,6,0,250,2,0,254,25,7,15,244,2,232,255,24,252,4,9,0,254,247,4,6,3,13,253,1,5,255,253,251,255,7,254,3,4,4,1,0,19,6,8,236,9,247,5,252,243,7,11,253,5,243,247,6,245,255,0,4,11,26,3,6,249,12,6,253,1,247,7,1,15,6,19,233,253,247,3,16,250,252,6,251,246,1,16,242,2,0,2,243,253,8,250,3,1,1,2,251,12,252,248,253,14,4,16,236,1,12,0,6,253,9,4,16,10,240,5,7,5,252,252,238,253,245,252,4,249,3,13,7,3,3,2,249,22,3,255,226,18,253,247,9,254,11,240,254,242,12,0,4,251,4,255,3,236,12,4,246,254,254,244,244,10,6,11,253,15,7,2,235,5,4,9,247,223,7,7,3,250,242,248,10,12,0,2,255,5,4,254,0,249,0,2,4,0,1,253,8,249,0,12,3,0,250,8,252,0,2,14,241,2,249,225,253,14,0,14,241,255,252,241,10,1,253,1,2,5,2,248,1,254,5,1,0,253,3,3,250,255,2,252,1,237,0,245,18,11,10,21,5,6,2,10,3,250,0,254,13,5,255,254,9,247,1,251,0,0,241,8,4,8,3,8,12,243,254,217,254,4,252,5,253,252,3,253,3,10,5,3,2,253,5,254,8,247,6,6,248,12,244,23,238,4,241,251,2,236,13,249,7,7,244,14,244,6,1,1,253,248,9,0,1,249,3,7,250,238,13,4,3,246,226,246,250,242,1,249,252,221,5,231,11,9,8,19,252,249,253,238,248,1,5,10,252,242,247,3,252,250,255,4,247,247,4,20,0,0,3,11,7,240,239,236,11,250,242,1,4,19,2,248,6,241,3,6,251,242,3,7,2,1,6,254,248,251,253,3,248,21,1,3,16,242,254,247,252,13,254,18,14,14,19,243,5,246,2,253,3,5,5,1,255,255,251,250,254,245,249,5,252,5,255,0,3,253,2,237,18,16,4,14,234,254,245,234,1,255,11,1,2,11,246,7,244,1,4,5,255,247,251,1,12,5,6,12,9,232,23,1,20,14,245,13,5,254,254,5,6,2,1,247,6,10,5,252,11,255,255,1,7,253,252,8,240,15,255,249,9,234,245,245,10,16,9,254,4,13,10,6,16,4,7,1,248,249,242,249,4,1,3,250,0,15,247,252,0,4,6,12,9,250,251,234,17,7,245,15,251,1,3,237,0,241,253,16,5,5,249,245,12,254,255,13,2,4,232,37,251,254,250,12,7,254,233,252,9,2,253,3,2,3,3,242,11,0,252,254,254,3,10,246,4,2,9,8,250,228,14,28,245,18,245,0,2,254,4,244,3,6,0,7,249,250,2,5,255,255,255,5,2,3,0,253,9,249,14,5,246,253,7,4,251,7,248,249,4,244,14,240,25,3,0,1,251,12,246,0,246,0,12,12,17,12,10,255,0,252,254,5,254,239,253,5,251,7,239,1,5,252,4,236,0,11,241,13,248,10,1,1,5,244,9,248,0,6,255,245,4,253,12,13,241,249,249,0,5,33,3,3,250,243,249,241,10,3,3,3,251,2,7,255,0,244,2,11,250,247,0,5,11,248,5,10,249,242,252,13,0,18,253,250,7,1,250,0,21,8,249,10,248,253,17,247,0,251,1,4,8,253,11,251,0,248,8,253,248,8,245,16,240,17,0,8,16,239,10,240,10,248,6,11,0,10,7,4,5,7,251,251,250,249,251,255,16,250,0,6,1,248,248,8,249,251,246,245,8,237,6,249,13,5,253,4,248,7,255,238,9,0,251,6,26,3,8,2,4,254,254,23,254,236,2,7,249,250,241,3,9,237,254,246,7,254,7,9,11,0,4,252,6,9,254,4,253,4,3,2,8,250,12,10,246,249,4,17,11,250,1,12,11,238,8,244,4,1,13,6,243,23,9,251,8,254,251,1,3,0,254,252,4,7,1,7,239,248,8,255,249,5,250,4,253,240,9,232,18,253,10,13,245,250,245,252,10,0,11,8,2,6,251,245,4,252,1,251,246,0,253,9,254,4,255,1,5,215,246,249,4,253,3,1,0,244,4,253,0,2,255,254,251,3,2,249,5,254,1,4,4,253,250,1,0,12,251,11,0,239,253,255,11,4,1,27,244,0,242,2,241,253,247,0,249,253,15,248,6,250,4,9,2,4,3,7,246,28,1,254,48,7,0,246,10,1,247,2,255,0,3,251,5,252,254,7,7,1,3,2,5,253,3,255,3,247,0,255,3,2,250,39,242,244,5,237,21,7,250,4,255,252,0,252,1,0,247,1,10,0,254,0,7,4,2,227,12,5,253,16,250,15,243,252,255,243,22,240,17,16,4,9,252,4,250,252,11,248,7,8,4,3,253,249,243,0,3,3,250,252,0,9,0,5,0,10,10,4,243,244,16,23,252,244,250,252,20,2,0,252,23,1,8,11,252,251,15,250,4,241,247,255,237,12,226,239,252,1,243,243,4,253,26,5,231,11,242,250,243,0,249,9,2,8,255,248,1,248,13,1,6,1,252,252,1,2,0,253,2,10,6,250,254,245,4,32,15,15,209,248,3,244,4,251,4,255,0,251,5,1,249,2,255,0,0,255,250,0,250,4,252,5,9,251,1,253,51,4,251,4,242,255,252,253,1,252,255,0,2,248,0,1,2,0,4,254,249,254,247,6,248,11,253,250,3,245,248,244,8,11,5,19,3,232,19,242,11,251,238,248,244,251,252,255,4,16,9,10,14,238,254,238,229,10,251,12,14,4,0,254,250,244,249,255,3,4,7,11,10,5,251,249,240,253,250,6,9,7,15,247,10,237,4,251,219,254,252,8,2,4,255,1,9,251,251,244,1,255,248,3,253,4,6,9,3,3,255,2,4,13,17,3,9,249,249,241,239,248,243,252,248,19,2,16,25,7,15,2,16,251,250,246,247,249,250,254,249,7,2,4,5,24,7,9,8,243,254,0,252,1,243,3,6,7,10,252,15,5,7,252,5,251,3,13,249,5,15,245,254,7,5,8,6,17,6,241,23,254,255,250,254,0,252,11,253,12,15,6,248,241,10,247,7,255,245,2,248,252,3,4,246,4,4,11,1,21,12,253,6,248,8,245,248,251,251,3,7,255,251,12,15,246,245,3,15,8,4,2,241,0,14,1,248,255,3,10,249,16,12,5,13,250,15,233,0,239,247,0,4,247,13,6,18,0,0,252,255,0,14,5,255,8,252,248,250,5,254,254,0,14,16,255,12,241,247,250,236,4,6,8,9,3,1,247,252,255,245,9,11,244,1,242,249,2,248,11,9,252,10,4,240,13,10,3,7,0,248,223,250,4,252,19,254,14,6,5,7,6,253,255,246,246,247,4,253,5,9,2,2,10,9,254,253,11,10,25,18,255,250,235,235,245,240,6,5,14,4,8,7,0,246,249,247,251,252,3,255,1,6,255,6,254,2,253,247,15,9,5,22,239,15,247,7,7,247,13,9,10,255,8,253,254,6,1,17,8,242,7,253,12,9,1,0,1,251,17,238,25,19,239,12,252,246,1,243,237,249,253,9,6,254,3,1,4,254,245,242,255,249,251,247,7,255,253,4,251,1,0,255,20,8,253,246,232,3,250,254,0,244,14,6,7,11,4,7,244,251,248,246,5,255,252,4,16,7,242,6,255,254,249,245,16,18,17,1,241,250,251,253,255,237,8,254,2,8,12,237,244,8,0,253,255,255,4,242,9,255,244,255,249,10,253,5,18,12,249,7,0,253,243,0,255,252,9,254,6,255,0,1,15,235,1,248,25,237,13,247,2,12,5,249,253,255,253,1,13,16,252,9,254,2,255,237,249,252,18,250,14,18,251,4,250,253,237,242,255,244,10,6,7,17,244,243,246,252,5,4,27,17,4,14,247,254,252,248,0,250,14,245,249,2,253,253,254,253,243,12,16,1,251,247,246,245,254,3,249,5,11,249,7,17,240,254,242,228,249,248,15,246,7,15,8,17,13,255,4,249,244,245,0,0,2,3,253,7,250,6,1,240,1,254,23,11,247,15,233,252,250,252,2,247,249,9,248,3,243,252,8,18,250,254,1,251,6,242,251,254,250,251,253,254,4,251,12,13,18,18,221,2,7,239,3,245,6,9,253,254,10,252,3,3,254,249,0,2,252,0,252,0,250,5,10,4,253,255,19,11,1,20,242,4,247,243,254,11,0,17,255,255,255,255,251,248,0,5,255,248,5,255,3,2,244,21,254,232,5,7,15,15,241,17,242,234,3,252,245,253,249,1,18,10,1,10,250,253,8,2,249,0,254,1,1,2,247,254,1,2,253,4,45,13,8,17,251,2,240,2,8,254,8,241,4,5,255,7,250,254,250,2,253,0,0,247,255,7,2,3,253,253,255,5,1,18,248,18,244,246,3,4,234,244,20,8,253,9,2,10,246,253,9,3,6,253,10,255,253,2,254,4,2,3,253,238,9,10,251,9,221,235,238,240,255,244,250,249,241,237,12,4,4,9,249,2,14,1,4,0,255,6,249,2,1,1,252,4,31,8,239,35,248,1,251,250,249,250,10,254,253,6,9,3,250,254,3,3,5,253,0,6,0,1,251,253,254,252,255,0,18,4,248,7,248,241,255,240,12,18,3,19,2,4,8,8,0,251,248,244,10,251,0,1,0,4,253,16,11,11,254,250,27,15,239,246,233,234,255,242,252,249,20,254,249,6,15,251,32,4,9,245,253,248,11,252,255,252,248,250,252,251,254,249,22,4,249,2,241,245,239,246,2,0,15,11,7,12,248,6,246,238,250,244,7,3,22,3,249,14,251,254,243,249,255,249,18,13,9,24,252,237,247,245,13,8,2,4,255,8,14,10,244,0,0,5,10,5,4,255,5,1,255,11,2,252,0,247,15,19,251,1,252,246,248,229,6,8,5,10,4,11,5,251,245,0,245,242,252,247,248,248,6,247,4,251,255,1,5,252,18,1,243,14,242,9,241,249,12,1,13,252,236,12,10,12,244,7,1,243,10,250,5,253,4,8,10,243,253,250,9,253,19,242,5,248,250,2,251,5,253,255,228,11,18,250,252,254,11,14,213,214,9,2,20,233,6,32,0,5,0,6,9,5,8,11,242,255,7,12,249,2,240,2,10,253,255,249,249,255,1,246,196,233,238,42,243,9,18,245,0,1,0,2,251,1,251,255,2,0,3,253,3,254,250,0,253,253,7,2,0,254,254,3,222,241,37,47,10,20,9,1,3,235,231,223,242,8,5,6,2,254,254,254,6,5,251,7,253,1,251,243,9,3,239,237,254,177,244,249,248,250,254,254,255,255,249,243,6,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,0,3,4,169,6,245,16,247,255,8,0,5,0,1,2,1,251,6,2,232,5,247,249,0,7,3,253,16,242,240,0,18,15,247,242,228,239,53,14,250,228,255,253,246,249,242,19,241,0,0,0,0,0,0,0,0,0,0,0,0,0,0,253,0,243,0,203,3,234,63,19,16,1,245,0,253,0,253,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,250,213,213,254,65,243,252,9,1,1,2,1,0,0,1,0,1,0,0,255,0,1,1,0,0,1,2,255,255,253,255,233,1,195,201,3,228,250,252,252,8,2,1,1,255,0,0,0,1,255,1,255,0,255,0,1,255,0,1,255,0,247,252,208,237,204,210,11,244,5,242,0,246,0,0,255,254,255,0,0,253,255,252,2,255,249,3,1,3,255,1,253,0,249,0,3,249,195,205,252,235,240,235,245,14,249,8,3,251,1,2,0,0,0,1,0,0,255,0,0,0,0,0,1,255,9,253,56,245,250,189,255,13,0,7,1,247,255,255,0,0,1,0,14,9,254,14,246,246,9,251,1,248,233,30,8,249,23,8,2,10,255,229,239,57,22,4,251,2,244,250,2,249,252,247,1,5,12,254,254,253,2,253,6,0,4,254,248,250,0,16,241,29,201,227,232,29,3,10,6,13,10,251,21,11,242,5,4,2,26,250,10,11,233,246,229,236,3,232,245,246,243,25,246,5,247,220,249,43,3,243,6,13,254,0,1,3,253,252,255,0,255,0,0,0,0,255,1,0,255,0,0,0,255,1,244,12,230,192,241,29,37,249,253,244,251,14,8,248,246,254,19,252,245,240,8,14,5,19,3,22,245,235,255,250,245,11,10,232,233,216,248,20,17,5,13,250,3,14,236,248,3,28,2,244,10,242,238,26,234,4,254,5,235,8,3,1,19,0,244,24,242,216,15,29,241,6,15,1,237,2,4,7,244,253,0,17,13,7,251,245,2,237,3,38,235,253,250,252,7,1,1,251,216,246,254,35,8,8,246,248,247,33,4,4,0,254,254,244,7,29,232,2,16,255,249,16,10,254,254,254,13,254,219,15,234,216,245,33,10,255,8,10,6,8,9,0,244,2,15,248,247,254,7,239,7,19,14,4,12,27,11,10,4,11,241,14,243,208,5,18,0,247,220,245,2,4,5,5,241,244,244,0,3,4,7,251,5,242,232,238,250,241,248,236,1,249,223,228,216,218,238,246,251,17,244,4,3,251,5,243,4,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,253,247,207,196,251,45,255,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,253,247,207,196,251,45,255,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,255,0,0,0,3,254,9,227,245,55,8,32,220,243,249,37,4,11,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,255,217,252,226,63,28,239,250,10,7,242,247,11,9,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,13,254,206,224,22,51,4,7,6,11,236,243,9,251,21,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,253,247,207,196,251,45,255,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,253,247,207,196,251,45,255,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,255,0,0,0,3,254,9,227,245,55,8,32,220,243,249,37,4,11,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,255,217,252,226,63,28,239,250,10,7,242,247,11,9,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,13,254,206,224,22,51,4,7,6,11,236,243,9,251,21,252,248,2,1,22,225,250,231,253,253,1,241,245,254,253,4,243,247,15,238,37,249,219,12,243,245,231,246,245,234,7,16,7,14,10,4,246,255,251,249,253,16,13,251,241,5,11,255,8,229,7,244,49,17,234,9,254,247,255,2,241,255,41,238,239,252,247,241,253,3,4,4,2,7,253,249,248,251,17,237,249,36,247,218,17,1,208,11,238,243,254,248,4,246,251,21,11,15,243,4,2,1,251,254,1,246,7,255,3,250,0,11,245,8,20,239,51,239,215,2,15,4,8,254,16,224,255,17,6,248,8,238,251,4,6,253,8,0,252,2,0,255,252,5,8,30,30,248,70,2,8,2,0,7,1,13,255,250,249,245,2,248,249,9,246,243,6,245,242,13,25,230,5,2,251,251,5,248,4,0,33,12,218,252,6,13,6,25,34,255,25,237,251,18,3,239,4,248,7,20,1,255,5,251,254,248,8,221,15,24,43,251,51,5,244,253,1,254,3,253,253,247,8,247,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,10,24,76,254,234,11,255,4,33,4,1,255,1,2,0,0,255,0,1,0,1,0,1,0,0,0,0,0,1,2,0,24,13,32,70,26,5,235,247,250,241,2,254,2,4,1,1,5,252,245,4,252,22,10,254,13,245,252,235,239,0,249,4,10,222,11,52,2,210,251,0,0,255,2,4,247,1,1,249,0,1,1,0,255,0,1,0,1,1,0,1,0,0,253,1,248,9,255,64,243,195,253,3,251,10,1,3,255,255,255,255,0,1,0,255,0,255,0,0,1,0,0,0,1,1,2,1,10,254,225,79,246,27,0,255,3,8,1,1,0,255,0,255,3,12,10,26,237,10,247,6,252,241,10,3,240,6,11,237,3,10,18,44,5,226,5,247,21,4,20,10,14,231,8,239,0,0,0,1,255,0,255,0,1,0,1,1,0,0,250,254,8,248,13,69,26,237,231,239,16,6,244,22,2,250,9,5,0,255,0,1,0,255,255,0,0,1,254,1,0,0,252,255,222,241,223,56,9,214,9,10,6,9,248,245,0,250,15,5,10,2,242,253,241,221,255,7,238,14,8,255,241,230,6,241,238,22,9,33,0,224,247,3,245,7,4,255,5,30,9,1,4,15,0,6,251,245,9,6,6,6,14,2,255,10,232,231,254,252,255,37,2,227,14,247,22,17,254,33,10,231,11,245,0,5,2,18,244,21,22,33,249,21,247,249,7,241,249,16,7,0,242,44,10,231,5,252,15,248,10,252,5,9,255,16,3,13,12,12,8,25,233,8,234,253,238,248,15,12,9,19,0,0,247,49,229,241,247,241,12,248,240,249,13,5,13,2,12,250,7,254,20,247,242,12,13,251,239,22,248,252,2,7,243,254,241,43,251,226,27,4,10,229,5,27,246,246,238,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,10,238,70,254,204,255,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,10,238,70,254,204,255,249,0,0,0,0,0,0,0,0,15,243,236,16,2,13,5,245,248,251,253,2,24,233,30,249,11,30,241,43,5,241,15,253,242,1,233,8,3,9,4,245,0,255,0,1,0,255,255,0,0,1,254,1,0,0,252,255,222,241,223,56,9,214,9,10,6,9,248,245,0,250,15,5,10,2,242,253,241,221,255,7,238,14,8,255,241,230,6,241,238,22,9,33,0,224,247,3,245,7,4,255,5,30,9,1,4,15,0,6,251,245,9,6,6,6,14,2,255,10,232,231,254,252,255,37,2,227,14,247,22,17,254,33,10,231,11,245,0,5,2,18,244,21,22,33,249,21,247,249,7,241,249,16,7,0,242,44,10,231,5,252,15,248,10,252,5,9,255,16,3,13,12,12,8,25,233,8,234,253,238,248,15,12,9,19,0,0,247,49,229,241,247,241,12,248,240,249,13,5,13,2,12,250,7,254,20,247,242,12,13,251,239,22,248,252,2,7,243,254,241,43,251,226,27,4,10,229,5,27,246,246,238,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,10,238,70,254,204,255,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,10,238,70,254,204,255,249,0,0,0,0,0,0,0,0,15,243,236,16,2,13,5,245,248,251,253,2,24,233,30,249,11,30,241,43,5,241,15,253,242,1,233,8,3,9,4,245,16,238,7,252,31,241,247,243,20,244,250,0,12,250,254,4,3,253,255,0,1,3,3,254,1,6,4,0,253,2,251,1,38,251,243,252,8,241,11,1,2,252,255,9,13,4,244,249,0,254,7,2,250,254,253,254,3,252,6,15,1,1,245,254,47,234,9,230,3,251,2,249,4,254,2,254,3,0,3,252,3,253,2,253,7,253,255,1,1,251,5,0,2,251,253,254,14,240,2,250,7,254,249,252,252,249,14,253,7,237,242,239,227,6,26,16,251,13,252,255,21,14,1,3,250,0,249,255,29,245,5,253,4,11,4,246,1,234,253,246,5,4,2,8,254,249,244,244,248,253,238,254,247,251,255,253,2,242,242,7,28,244,5,3,9,249,0,254,2,1,4,0,249,253,254,4,4,14,8,255,252,14,249,17,254,254,247,2,19,249,9,248,31,238,234,8,15,251,246,241,1,10,6,7,6,248,2,255,12,253,3,255,1,5,250,252,0,1,7,246,254,4,253,252,53,226,252,12,2,3,253,253,0,1,6,5,251,252,249,1,0,2,1,3,1,5,0,2,2,255,0,4,2,0,254,0,27,238,253,254,4,248,3,254,245,2,10,248,248,252,0,254,8,0,9,0,240,11,1,250,13,253,246,243,241,25,1,0,35,251,255,248,23,11,242,253,2,254,8,250,17,254,7,0,254,10,239,13,254,254,11,11,242,2,254,253,248,255,244,251,29,247,7,3,2,246,0,3,9,0,253,5,1,246,10,251,3,6,236,247,250,252,1,0,12,17,248,9,3,255,247,0,15,240,18,237,16,241,17,238,13,240,17,242,15,247,13,239,9,249,4,251,3,252,253,0,250,7,247,7,254,7,247,9,21,246,7,254,12,249,13,239,11,254,20,3,5,245,250,250,241,0,247,5,245,7,255,7,8,246,247,3,251,9,248,254,23,234,15,251,16,252,253,244,9,3,255,254,248,2,254,240,3,4,254,250,249,12,248,2,242,2,249,11,254,6,252,255,34,239,252,8,4,250,1,8,4,16,3,6,12,255,255,241,6,4,249,250,6,0,2,1,254,2,3,3,253,254,8,250,18,238,2,254,10,1,18,233,253,246,0,4,20,237,253,252,2,8,6,1,253,1,1,3,5,255,245,3,249,5,255,1,15,242,2,3,10,248,12,243,13,241,6,248,252,246,14,247,24,2,249,238,13,245,8,14,250,254,3,255,252,7,249,252,20,244,13,5,255,246,15,250,8,255,253,246,17,0,250,237,2,255,8,253,240,0,253,2,254,0,8,247,0,1,246,247,32,0,247,251,255,5,13,245,8,3,11,245,0,248,254,242,7,10,6,251,1,10,2,12,246,4,4,6,4,0,249,246,16,242,10,249,11,245,11,245,18,243,8,241,16,245,13,247,8,249,12,245,7,250,3,251,9,251,4,255,7,252,8,253,24,229,255,5,8,251,12,7,4,253,3,255,247,245,243,251,10,0,243,7,1,251,4,247,7,253,13,2,251,253,239,254,23,237,15,1,246,238,244,250,8,253,12,0,244,246,252,252,8,246,4,2,254,248,13,253,254,250,2,253,5,254,2,11,25,244,4,2,24,253,3,250,14,11,0,235,253,253,1,248,7,0,0,3,3,250,249,6,2,1,252,5,255,10,254,9,24,248,250,7,16,244,13,255,11,235,2,250,3,244,0,9,4,11,249,1,4,1,248,3,3,250,3,3,0,248,8,4,25,235,13,14,13,238,4,253,0,251,252,5,253,0,4,12,7,3,5,251,2,254,3,246,2,247,241,6,1,7,251,1,23,240,254,10,4,255,3,1,32,3,251,254,9,10,255,252,250,2,9,255,14,12,250,255,239,254,252,247,249,250,248,3,50,248,5,2,245,10,0,0,6,253,7,0,253,254,253,0,6,252,2,251,247,0,3,10,1,249,254,253,250,247,1,254,28,239,0,254,2,247,1,5,252,255,0,0,19,229,5,244,7,242,253,250,10,254,252,254,4,251,254,249,1,7,247,4,22,237,250,250,3,234,3,5,20,248,242,251,1,1,20,2,16,6,3,14,4,3,5,1,5,249,246,250,3,250,1,242,29,242,248,13,8,246,250,4,4,250,5,249,1,12,14,11,249,1,2,247,245,247,0,4,255,7,10,4,4,20,255,245,18,247,4,1,7,227,12,1,255,247,254,255,254,2,9,248,243,5,4,243,252,2,251,249,250,14,246,222,253,1,253,243,38,247,24,8,11,4,250,245,254,244,1,1,245,248,251,254,241,248,8,0,1,249,5,4,255,8,254,11,253,255,251,251,236,11,252,24,245,1,15,4,0,228,246,255,10,10,250,5,250,2,7,254,1,254,250,253,249,1,2,12,255,7,0,254,247,10,233,27,252,239,20,250,14,239,5,255,5,247,249,5,250,4,254,9,0,8,0,1,253,253,251,248,5,254,254,12,246,19,4,9,1,240,17,254,9,227,240,245,252,7,251,4,255,253,3,2,3,252,5,244,254,6,5,252,4,1,4,10,236,10,232,14,251,11,9,0,16,236,10,251,250,250,255,2,252,5,240,8,254,5,5,245,9,245,4,245,255,255,4,3,247,11,3,19,24,4,5,242,30,239,252,254,239,7,2,3,1,3,249,252,2,253,1,4,255,255,3,244,254,3,253,10,237,18,11,19,19,19,10,4,13,6,5,4,8,3,254,12,250,254,7,250,15,12,16,16,18,253,252,236,0,10,247,253,235,9,20,12,0,253,5,247,15,243,5,251,250,24,2,9,251,2,249,2,5,7,251,2,15,3,1,255,252,254,7,0,238,16,13,15,2,246,14,245,4,245,5,12,12,20,8,30,2,11,247,7,0,253,240,251,250,5,252,235,0,5,6,1,230,8,243,9,6,246,2,245,7,252,6,237,245,250,244,16,0,5,249,8,5,6,17,247,10,246,5,253,245,2,4,10,245,17,253,22,251,18,3,1,4,251,14,229,5,249,252,251,246,11,1,15,1,1,250,251,10,234,249,249,241,13,252,5,239,14,249,13,3,0,13,250,9,242,234,255,1,19,14,253,4,243,243,2,252,8,254,254,13,244,13,244,249,251,253,6,239,17,255,33,6,3,9,240,3,242,248,6,239,8,3,13,8,250,3,1,254,0,254,8,4,9,13,246,4,239,0,250,236,7,7,21,1,253,7,253,254,244,9,249,2,253,14,1,255,249,12,246,5,236,11,254,0,232,239,6,6,252,3,255,248,10,6,7,255,250,28,250,10,223,1,236,0,244,10,1,250,8,253,255,246,8,5,0,10,254,8,16,251,253,249,4,239,13,3,15,1,251,27,251,6,250,12,2,252,8,255,253,254,12,241,3,4,1,2,247,0,240,235,2,252,16,249,4,241,20,8,17,5,242,15,245,21,245,13,243,2,241,243,1,251,5,2,10,247,4,255,3,2,252,13,251,1,252,5,253,235,8,2,16,255,2,15,240,13,244,244,249,248,2,249,11,248,5,2,249,16,252,1,249,3,241,6,251,248,2,248,5,241,17,250,3,253,3,9,249,14,233,11,1,255,4,7,6,255,242,7,6,248,5,1,241,10,247,2,253,255,4,246,252,246,18,3,11,1,4,14,242,7,252,15,246,10,245,10,252,5,242,10,4,15,244,15,243,20,241,14,241,8,245,4,250,249,23,2,20,7,8,19,251,9,240,248,239,251,1,5,250,248,1,250,252,10,6,6,2,245,252,0,2,4,7,9,252,241,20,251,22,11,248,9,251,10,243,248,8,2,254,253,7,6,10,1,2,251,247,1,10,16,234,249,0,7,7,6,1,230,19,251,3,5,25,18,251,9,242,248,250,254,250,2,3,248,254,249,7,253,7,3,4,248,0,1,248,252,254,254,1,236,14,246,6,253,7,8,224,254,249,254,246,16,244,247,15,254,251,250,2,249,5,9,1,6,249,255,0,254,252,249,3,242,16,4,11,248,1,23,252,17,243,246,1,12,9,12,252,7,255,255,5,248,250,3,3,250,253,238,0,18,20,4,254,223,19,246,30,15,2,253,255,252,242,7,249,255,7,248,9,255,253,251,2,2,4,0,5,0,0,2,3,3,253,253,4,250,20,0,5,17,246,18,239,9,240,4,243,250,2,242,14,228,9,244,25,252,7,7,248,6,250,254,246,2,245,255,2,244,14,12,52,253,5,251,4,8,243,2,251,252,2,254,255,254,3,3,5,2,3,0,1,251,2,252,253,1,251,254,0,243,6,9,24,0,8,14,241,18,247,245,248,3,15,254,252,247,4,253,12,14,243,11,252,2,252,0,250,250,250,242,255,246,28,3,12,9,3,11,228,6,245,249,4,0,7,8,247,0,250,0,240,4,7,4,4,7,3,4,249,0,253,246,6,245,14,254,19,255,255,7,9,254,229,10,242,15,252,12,252,2,254,250,12,250,0,251,252,251,1,3,245,5,247,3,248,238,7,13,16,252,3,9,246,10,246,253,234,252,244,3,240,0,253,240,8,245,1,10,249,15,3,0,255,243,8,1,6,236,10,246,10,8,255,6,0,16,244,9,246,255,251,252,243,13,16,248,12,254,14,18,13,0,240,2,251,251,251,252,3,242,5,249,239,5,243,23,20,252,255,1,250,13,5,255,4,242,254,249,8,3,2,2,249,2,255,4,7,3,247,255,251,237,3,232,228,247,249,19,3,2,19,7,5,243,8,241,239,3,245,4,13,3,2,255,253,252,252,2,0,251,250,6,2,239,18,226,236,254,253,1,15,255,245,6,252,11,11,252,251,246,0,0,1,3,249,8,2,5,1,5,251,1,6,4,1,250,1,226,231,255,248,254,247,239,16,3,255,254,247,250,249,253,12,6,252,246,0,10,248,250,251,253,245,252,0,255,253,255,255,222,228,1,246,2,9,4,16,2,6,14,17,0,7,252,4,4,4,0,1,255,251,8,1,252,1,247,254,5,6,245,14,1,225,249,232,9,7,6,5,243,1,255,3,4,255,254,248,250,3,5,252,250,7,254,5,3,3,0,0,251,2,231,8,245,238,1,252,8,253,252,15,6,251,8,2,3,4,252,5,6,8,249,6,1,245,241,243,9,252,242,10,12,7,236,11,241,231,3,4,18,13,252,251,247,255,251,254,254,249,16,5,252,251,249,254,253,247,11,254,0,249,239,250,245,6,245,18,251,236,241,253,9,11,236,12,5,5,11,253,7,1,10,250,253,253,3,3,14,249,10,239,9,245,254,250,7,244,236,8,242,239,247,243,253,0,229,242,253,242,4,3,6,250,7,4,23,9,11,9,3,252,9,2,4,255,250,1,248,245,247,14,2,219,249,13,6,245,250,9,18,245,250,2,12,4,255,3,1,254,254,1,247,252,254,253,3,5,250,0,254,248,227,8,255,243,254,8,23,2,246,7,13,250,251,11,13,0,246,243,11,244,246,6,4,6,4,3,6,251,247,254,255,3,238,6,246,201,252,245,254,0,1,253,247,250,3,254,255,6,3,255,3,1,252,249,254,6,3,254,255,253,254,0,4,1,242,5,3,235,248,240,252,254,245,27,15,236,3,0,1,1,2,251,251,4,1,247,5,253,3,0,252,254,245,252,253,7,239,255,247,239,248,238,12,243,247,13,253,3,3,253,1,254,0,16,247,6,12,9,5,11,2,241,1,252,240,7,252,244,238,8,250,245,248,249,13,7,1,6,8,255,21,252,14,15,18,252,253,15,0,9,4,7,3,255,9,254,0,7,248,2,246,7,238,227,3,12,12,9,11,4,255,241,1,255,8,254,254,10,241,255,0,6,12,250,255,10,250,253,245,252,9,250,242,14,247,235,244,254,255,249,251,246,5,248,0,6,9,245,11,253,251,3,8,15,254,252,234,4,250,12,2,13,6,249,244,11,251,227,231,4,12,243,245,249,4,2,2,251,5,8,7,251,251,6,3,246,1,250,6,250,251,255,254,252,7,6,241,11,251,240,0,243,26,233,250,253,5,254,254,21,250,253,251,255,6,255,0,243,2,253,247,255,252,253,5,252,12,240,247,9,255,239,253,250,12,6,238,254,11,242,250,3,14,244,245,251,14,2,5,248,252,245,2,251,16,6,249,252,8,13,243,5,3,228,242,0,6,23,5,4,255,239,1,253,0,0,5,4,0,238,14,10,4,2,5,254,4,253,2,0,2,0,241,4,243,240,253,244,254,2,7,10,9,3,11,4,23,14,9,16,4,1,244,253,4,249,241,249,246,242,250,248,255,250,249,10,251,246,253,243,16,255,244,7,253,244,2,13,13,2,17,15,243,1,251,254,3,255,1,253,6,253,244,240,7,249,245,251,244,226,250,234,1,4,250,253,12,6,7,0,16,6,254,0,234,254,247,2,243,8,6,248,4,249,255,250,4,6,242,5,1,229,252,2,1,14,245,249,248,252,1,8,0,250,243,11,244,249,251,1,10,7,3,254,0,6,248,2,10,255,246,10,231,243,236,252,19,3,13,5,5,7,248,2,4,2,3,255,255,247,14,10,9,14,3,3,250,0,251,4,1,255,247,15,238,239,4,245,6,7,244,8,255,245,2,3,7,16,253,247,7,244,23,0,6,7,242,247,8,1,254,6,254,255,250,9,240,230,242,245,9,250,5,254,13,17,21,7,18,237,6,233,254,241,254,2,246,248,2,1,254,4,253,252,251,252,0,6,251,228,239,224,2,246,11,3,251,9,10,3,11,11,253,12,254,2,4,250,9,252,252,252,252,247,2,0,2,4,0,248,238,222,247,249,252,245,10,15,11,255,248,15,6,243,9,2,252,244,0,255,19,12,6,5,0,253,246,244,3,251,246,6,247,239,244,245,9,250,11,11,18,249,0,16,4,2,250,3,244,255,0,1,251,234,254,244,0,6,17,5,5,6,12,251,7,1,251,254,255,2,2,252,253,253,253,254,227,11,5,243,183,24,12,4,242,246,5,1,0,245,249,249,7,3,10,253,255,253,4,245,251,254,248,7,9,2,248,250,6,7,21,17,202,47,242,246,14,19,13,21,252,3,1,2,252,2,244,4,240,244,5,247,252,19,249,234,234,239,3,0,250,8,23,252,201,228,2,230,2,1,4,0,243,6,0,10,249,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,255,35,255,189,221,232,232,250,2,2,254,1,3,2,0,255,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,0,41,252,183,241,18,4,17,8,255,240,255,254,1,0,0,0,252,252,4,6,255,2,240,246,241,246,21,254,250,254,14,249,10,251,201,34,244,11,243,254,2,28,230,0,7,4,21,249,2,1,15,234,10,253,14,250,254,15,254,249,20,6,241,249,23,10,196,8,252,29,234,2,243,9,246,12,255,253,4,7,0,0,0,0,0,0,0,0,0,0,255,0,255,254,11,251,235,245,196,229,239,217,6,36,0,248,2,2,0,0,254,3,2,251,9,239,255,2,253,250,8,12,7,250,223,245,242,216,10,36,210,0,237,5,0,246,3,12,250,248,6,244,249,1,1,1,0,0,0,0,1,0,0,0,255,0,1,0,254,0,4,254,169,253,254,2,254,20,2,6,255,6,0,0,2,255,1,0,0,0,0,255,0,0,0,0,0,0,255,0,0,1,1,7,180,41,249,232,0,250,3,6,0,254,255,1,0,0,0,253,4,2,3,2,2,0,3,255,4,0,255,4,254,252,224,245,192,227,247,213,2,245,255,249,0,252,254,254,254,2,10,236,3,253,13,13,0,252,2,7,248,7,254,2,236,236,237,3,209,238,240,250,241,214,239,14,250,8,12,246,11,244,253,254,254,255,255,4,253,255,250,254,3,2,253,6,255,247,10,13,188,247,26,3,5,3,235,10,241,21,234,19,11,242,1,5,18,237,227,243,254,18,246,20,2,10,246,11,1,8,240,239,215,10,242,231,0,242,237,17,7,244,14,245,14,5,0,0,0,0,0,0,0,0,0,0,0,0,3,255,213,5,6,244,208,19,8,218,248,253,22,235,246,15,20,247,251,8,0,0,0,0,255,1,255,0,0,0,0,0,0,0,6,253,22,242,185,232,254,223,23,7,248,7,253,2,252,1,248,254,1,0,255,2,0,254,0,0,255,0,4,0,26,255,10,245,239,224,198,14,242,245,254,15,2,248,12,10,247,13,223,242,15,239,237,7,248,241,224,234,7,12,18,0,0,241,252,16,37,254,210,11,2,248,246,248,14,9,252,5,7,239,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,251,3,171,23,247,239,254,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,251,3,171,23,247,239,254,254,0,0,0,0,0,0,0,0,1,0,0,0,0,255,0,0,0,0,0,0,255,0,0,1,1,7,180,41,249,232,0,250,3,6,0,254,255,1,0,0,0,253,4,2,3,2,2,0,3,255,4,0,255,4,254,252,224,245,192,227,247,213,2,245,255,249,0,252,254,254,254,2,10,236,3,253,13,13,0,252,2,7,248,7,254,2,236,236,237,3,209,238,240,250,241,214,239,14,250,8,12,246,11,244,253,254,254,255,255,4,253,255,250,254,3,2,253,6,255,247,10,13,188,247,26,3,5,3,235,10,241,21,234,19,11,242,1,5,18,237,227,243,254,18,246,20,2,10,246,11,1,8,240,239,215,10,242,231,0,242,237,17,7,244,14,245,14,5,0,0,0,0,0,0,0,0,0,0,0,0,3,255,213,5,6,244,208,19,8,218,248,253,22,235,246,15,20,247,251,8,0,0,0,0,255,1,255,0,0,0,0,0,0,0,6,253,22,242,185,232,254,223,23,7,248,7,253,2,252,1,248,254,1,0,255,2,0,254,0,0,255,0,4,0,26,255,10,245,239,224,198,14,242,245,254,15,2,248,12,10,247,13,223,242,15,239,237,7,248,241,224,234,7,12,18,0,0,241,252,16,37,254,210,11,2,248,246,248,14,9,252,5,7,239,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,251,3,171,23,247,239,254,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,251,3,171,23,247,239,254,254,0,0,0,0,0,0,0,0,16,65,254,254,4,3,0,249,3,1,3,1,0,5,1,251,0,2,255,3,0,0,255,254,6,0,254,0,0,255,1,1,5,37,252,8,252,255,9,17,6,249,5,255,11,6,252,7,254,4,1,253,11,3,3,247,6,0,254,252,251,4,244,245,15,24,242,2,6,17,26,5,8,11,247,249,250,248,3,251,9,10,253,10,0,1,4,247,4,9,3,0,4,0,251,3,9,36,247,248,7,7,4,3,255,240,254,7,251,250,6,12,245,244,9,255,253,247,12,6,250,2,2,5,0,5,6,250,25,39,251,24,3,10,3,250,13,248,3,249,2,246,251,2,254,3,5,254,1,5,254,3,252,1,251,252], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+954860);
/* memory initializer */ allocate([0,1,254,0,16,27,255,0,242,6,4,251,7,254,250,0,253,251,2,255,255,237,5,248,0,11,12,5,0,3,10,6,242,14,243,241,12,23,242,2,1,4,253,16,7,248,2,248,8,6,248,249,253,0,2,8,243,7,13,250,252,6,243,240,14,11,249,5,16,28,249,255,6,253,9,0,249,3,0,3,244,20,8,9,8,23,8,243,254,4,9,3,251,13,5,254,12,14,5,255,19,37,19,5,7,5,10,5,19,10,14,0,2,5,1,252,252,2,2,251,254,255,2,250,252,252,251,253,2,254,254,254,24,21,1,245,246,17,242,14,6,255,250,255,0,243,255,244,254,251,6,252,244,14,5,254,248,248,15,249,226,244,4,0,11,26,253,3,5,255,254,3,254,10,15,252,10,228,10,239,248,1,2,249,255,250,241,255,4,5,249,9,0,251,252,4,18,32,1,2,249,4,15,2,247,254,12,245,7,11,13,2,0,5,9,246,16,3,253,5,247,233,2,254,255,5,2,11,35,24,236,2,4,255,5,14,246,247,8,249,0,5,249,249,11,1,5,3,2,0,254,3,0,1,4,0,254,248,0,252,9,35,255,2,255,237,253,12,255,8,8,243,255,254,2,5,248,255,13,254,11,1,0,246,0,253,249,2,1,244,3,12,20,27,244,244,7,4,255,243,255,247,2,13,245,5,7,247,9,1,1,8,247,0,250,7,4,2,254,7,3,254,1,247,8,37,236,251,0,235,10,248,3,19,247,7,253,248,10,254,0,5,6,252,254,255,0,249,6,1,0,4,251,6,248,2,8,27,1,253,251,1,6,0,15,2,17,255,3,239,10,5,5,250,250,6,246,18,251,0,0,13,7,10,251,250,254,252,14,29,236,252,253,1,251,255,2,12,246,253,4,238,4,14,252,255,247,15,254,2,251,253,2,9,254,242,253,4,252,249,23,23,233,245,27,4,4,255,7,0,251,9,2,245,3,7,254,251,2,249,249,13,253,250,2,3,3,252,255,248,5,254,16,26,250,8,247,255,254,255,248,4,254,0,244,9,255,0,239,247,30,251,241,240,243,0,10,245,249,253,255,0,245,254,12,32,252,251,10,19,246,4,244,5,250,9,244,250,250,248,4,1,3,0,8,0,253,252,249,252,10,8,6,5,255,4,46,42,253,242,254,250,6,254,251,255,253,253,1,255,3,1,1,4,255,2,3,1,254,6,0,255,254,4,254,255,2,2,9,33,243,4,245,3,248,22,12,254,4,0,240,5,4,255,7,250,247,1,7,5,0,251,5,255,10,3,254,255,3,254,9,30,6,253,6,1,249,5,11,14,7,1,0,2,2,255,8,7,250,243,246,254,1,250,10,7,6,5,254,251,255,240,9,28,245,246,9,246,15,8,4,9,252,249,0,251,9,8,249,2,241,233,4,252,4,16,248,253,0,248,14,5,253,15,17,26,251,251,255,248,20,18,249,254,4,249,248,251,252,16,0,0,249,254,243,251,254,3,12,1,3,251,2,2,0,255,11,37,7,233,6,255,15,13,4,247,7,5,3,253,251,248,254,3,251,255,248,7,2,13,1,3,0,253,255,2,0,254,21,33,7,20,21,246,6,251,251,250,247,2,10,0,8,252,10,2,254,254,0,246,250,254,0,251,3,245,3,247,253,1,6,30,241,248,16,1,4,6,4,5,8,253,8,247,255,250,8,2,254,4,254,5,11,235,3,246,16,245,24,10,14,250,15,36,253,247,236,12,0,249,238,252,248,247,9,249,253,255,2,7,251,248,6,2,2,255,7,1,1,253,3,252,248,1,16,34,21,3,247,10,7,9,249,1,252,247,252,251,251,3,3,237,1,5,4,254,250,251,246,245,248,254,2,251,248,249,28,29,253,18,254,0,250,12,254,10,245,252,243,244,250,252,0,4,255,248,6,4,12,11,10,10,253,250,1,2,1,7,3,8,22,248,3,36,248,255,9,6,243,242,8,255,1,2,254,248,0,3,1,2,255,5,255,248,0,254,2,2,255,1,0,6,0,0,4,13,249,240,250,15,242,235,247,246,246,250,235,5,4,2,12,4,12,11,252,250,250,246,249,238,1,4,255,3,10,1,255,15,4,249,240,3,0,234,10,2,253,254,13,5,248,16,251,4,0,245,246,234,0,252,239,5,2,1,12,8,252,247,14,40,235,0,1,241,246,244,12,6,246,2,8,6,244,246,245,1,0,245,2,1,13,0,6,3,8,4,246,3,5,252,253,3,0,247,2,8,234,233,17,8,239,253,14,248,252,1,248,3,0,5,255,253,254,252,1,246,0,254,0,255,5,249,4,12,254,0,249,2,240,241,12,21,249,252,7,249,245,241,249,247,251,248,0,250,8,253,248,22,249,247,7,19,4,247,24,22,2,250,8,13,242,236,252,11,8,252,255,2,0,249,5,239,253,3,250,5,3,4,251,249,253,14,254,6,2,8,254,5,252,254,246,3,211,226,253,253,244,252,253,253,255,9,250,250,5,252,0,5,255,254,255,0,250,255,253,14,240,246,10,0,254,216,247,12,2,237,15,252,4,3,3,252,7,1,252,251,0,4,255,0,247,254,252,255,254,0,7,16,2,249,8,2,0,1,5,21,246,230,7,2,247,249,253,240,8,5,5,250,10,4,242,250,5,3,254,254,252,1,247,14,255,3,3,11,1,251,253,13,240,238,20,6,251,0,253,2,8,4,237,247,12,0,248,2,2,1,6,13,249,245,2,5,16,252,19,15,4,0,245,7,246,246,240,18,245,244,247,252,7,252,252,239,1,1,248,253,253,5,254,250,245,251,2,12,0,247,246,14,6,2,253,2,244,228,12,1,255,2,0,253,252,7,16,5,249,8,252,253,255,3,244,4,239,251,252,7,11,6,1,14,252,250,5,5,250,232,23,247,241,13,249,247,241,10,255,8,251,1,12,6,2,0,4,254,9,246,1,5,11,3,6,12,253,8,235,5,249,236,12,254,247,253,17,249,248,247,242,3,243,18,248,9,2,248,4,248,251,254,253,253,255,5,254,15,3,2,1,248,1,217,250,13,243,0,254,251,250,253,0,251,254,15,247,5,253,250,254,7,0,243,2,8,5,244,243,22,8,240,11,5,254,224,254,252,11,5,5,250,1,3,1,5,3,6,251,4,4,248,8,4,1,3,13,9,5,252,9,18,245,2,255,15,246,237,254,14,0,246,1,1,238,3,2,250,248,20,7,248,16,9,9,243,253,254,243,11,11,247,246,13,253,238,2,10,5,235,6,15,245,235,3,14,0,244,9,255,254,252,3,253,247,248,251,254,248,2,3,3,11,4,0,13,1,248,10,13,250,230,2,12,253,251,12,254,1,8,249,239,237,5,10,7,253,2,253,0,5,0,5,0,3,253,247,5,241,251,251,17,251,225,0,13,13,5,255,250,242,7,248,9,242,254,240,252,252,250,6,250,246,6,13,3,1,7,253,4,255,254,255,4,248,224,255,252,0,3,246,7,10,246,4,255,6,2,240,247,4,3,13,233,253,252,4,11,252,247,4,11,244,244,244,6,1,228,253,14,18,254,244,7,15,253,251,249,253,2,250,4,4,254,251,253,2,243,8,7,249,0,13,7,248,249,8,36,246,234,3,23,253,246,253,11,1,249,3,3,255,249,252,2,3,2,5,3,252,255,255,1,13,1,250,255,250,247,238,17,251,219,255,255,250,252,1,250,241,2,17,247,0,253,0,4,0,251,0,4,1,251,0,14,5,0,249,2,250,17,250,247,7,240,251,23,242,243,8,241,11,10,245,243,223,251,254,1,6,8,0,243,247,5,11,7,254,248,9,11,25,242,7,3,255,223,14,8,250,237,3,3,2,255,253,255,254,246,253,1,2,1,4,2,253,4,254,8,4,254,9,13,252,254,241,253,19,219,9,25,247,2,251,254,254,252,4,2,2,0,3,3,3,5,254,253,252,253,10,13,255,241,4,6,238,252,25,1,233,239,15,13,248,248,7,4,251,3,6,9,249,6,0,251,8,0,250,255,254,254,1,3,9,251,27,15,247,225,255,23,254,247,1,8,255,249,254,248,252,252,254,255,3,5,0,0,255,1,249,7,253,253,248,7,3,250,8,3,245,254,36,14,1,226,6,10,244,250,250,254,252,253,251,0,9,4,251,251,248,12,4,253,1,248,254,9,33,0,12,253,249,252,252,255,6,231,11,250,247,245,254,252,254,6,255,253,250,15,250,3,10,252,1,0,5,8,234,235,247,237,251,249,244,241,248,9,237,14,249,252,5,248,254,7,1,253,4,252,6,11,2,6,253,251,2,254,0,253,224,243,3,232,3,248,4,1,246,14,241,0,4,6,255,6,7,255,6,4,253,239,1,4,250,255,1,0,3,3,249,252,224,245,7,248,244,13,251,234,252,12,240,2,0,4,0,1,0,6,251,248,2,6,5,0,253,250,5,6,5,5,13,252,212,223,6,252,2,0,247,10,3,4,7,0,255,7,5,1,1,253,1,6,255,0,2,3,252,0,0,1,0,255,254,255,226,238,232,248,5,0,254,14,7,0,1,12,6,4,247,7,5,7,245,251,1,248,255,2,2,247,7,255,7,5,6,6,234,236,243,247,20,253,10,248,6,252,2,249,10,8,0,255,2,253,6,237,2,4,3,3,249,2,255,250,1,1,6,254,229,248,255,3,255,245,24,4,255,1,248,8,5,245,15,253,241,255,255,243,255,1,251,5,2,3,247,0,4,3,249,6,223,240,255,248,10,233,6,13,255,253,247,0,5,249,251,244,254,3,3,6,254,253,2,253,9,250,253,254,0,5,253,252,234,239,11,253,3,1,255,251,17,2,241,254,10,247,6,14,240,244,20,255,249,6,253,244,1,10,246,255,7,253,255,10,228,243,1,253,255,255,0,3,3,5,1,10,246,253,7,2,4,19,255,255,10,5,248,1,11,241,252,253,251,4,243,3,234,243,42,236,5,243,7,245,1,1,255,1,6,3,6,245,3,3,254,0,252,4,253,255,251,2,0,0,247,255,4,4,230,241,254,250,252,254,16,8,21,8,1,253,246,7,248,244,251,12,247,3,254,253,18,1,244,241,252,5,253,0,12,7,230,240,5,6,14,253,15,6,1,249,243,16,241,5,11,254,9,249,252,254,0,0,254,7,248,250,251,2,7,253,2,12,225,239,248,226,4,14,6,250,6,245,0,3,252,0,0,252,0,252,1,4,3,4,0,251,3,2,2,0,2,1,3,5,195,246,4,10,4,7,0,253,0,1,0,253,0,1,0,254,255,1,2,254,4,253,1,1,255,1,254,252,252,4,0,0,228,243,248,252,3,253,2,1,11,14,3,9,1,13,3,5,253,254,254,244,242,247,245,241,244,251,252,244,3,253,0,251,215,0,12,232,13,4,5,16,251,252,0,0,13,252,1,247,9,250,255,6,254,5,2,9,6,247,248,8,254,253,250,252,230,237,254,241,4,242,6,0,26,20,8,9,9,3,252,251,248,1,0,255,5,9,3,4,4,7,1,3,254,254,246,0,227,238,9,252,1,251,242,244,5,246,251,4,251,0,255,255,4,251,7,240,245,2,7,241,2,252,6,252,250,7,253,7,229,240,9,242,3,248,9,0,7,252,253,249,0,246,255,2,1,254,15,246,14,7,6,17,3,252,3,246,8,248,3,11,235,236,248,248,4,5,253,254,0,251,14,246,11,252,13,0,5,245,19,238,18,3,251,253,252,248,11,246,10,3,4,247,221,241,13,244,4,0,254,252,244,253,248,232,249,1,7,8,253,0,254,255,3,254,254,250,8,1,0,1,250,255,2,250,237,242,13,246,9,255,1,3,244,5,240,7,13,9,4,252,6,251,4,9,253,17,252,12,245,250,251,250,13,2,7,247,222,248,252,1,2,255,3,6,236,245,8,255,4,2,247,4,252,251,16,10,252,14,243,1,250,0,2,246,0,253,253,7,220,246,248,253,2,254,14,252,255,249,252,10,255,253,15,245,0,2,3,255,4,0,8,255,0,18,245,251,15,251,13,244,234,243,14,236,15,25,16,10,8,254,246,251,255,248,11,8,255,254,252,1,2,255,249,0,0,0,253,0,2,255,0,2,225,234,7,6,254,5,236,14,250,7,0,14,3,249,3,250,254,1,253,251,1,246,1,232,6,254,3,249,1,249,8,7,231,236,253,247,10,6,12,7,5,4,253,6,255,251,250,248,3,5,6,5,246,10,252,241,241,254,247,2,18,1,8,12,232,237,254,252,249,11,6,9,16,2,249,18,6,249,6,6,254,247,3,12,254,3,255,6,7,8,0,8,245,8,4,2,230,236,244,244,254,253,1,251,255,254,0,3,7,9,254,2,9,22,13,4,252,255,254,242,5,15,248,251,249,245,242,250,235,238,255,252,0,3,7,254,10,8,248,255,15,1,247,3,1,3,251,254,2,4,0,255,10,2,237,248,8,30,249,8,231,250,26,4,248,4,254,21,5,252,240,5,13,4,246,255,250,254,2,246,243,1,3,253,250,248,2,11,1,249,0,5,0,255,254,19,244,208,250,11,8,254,252,254,249,5,253,2,254,255,255,249,0,253,253,252,252,4,1,3,253,255,254,251,245,248,228,18,16,232,248,19,4,8,244,9,252,254,4,249,6,2,3,3,252,0,1,250,252,254,2,6,0,253,1,240,247,251,230,7,253,219,240,254,2,249,4,243,0,252,250,251,250,252,0,3,4,253,252,252,4,253,9,252,254,2,7,252,2,9,238,7,29,232,255,7,14,10,3,253,254,251,6,246,250,253,248,0,5,1,4,3,244,2,6,1,3,4,1,253,236,2,8,20,247,232,252,18,3,11,255,245,6,9,255,253,1,255,241,3,15,9,3,2,243,2,248,8,1,255,1,248,244,5,245,6,19,230,239,250,4,14,6,248,9,5,250,251,2,255,20,1,245,246,238,20,249,0,253,4,2,0,10,4,241,1,254,13,248,235,234,4,4,3,3,249,225,4,246,242,0,8,4,5,8,11,2,248,6,7,0,254,6,8,8,7,243,246,247,12,19,240,253,254,9,2,11,227,255,9,4,253,1,246,246,16,1,7,249,250,252,255,251,3,6,0,3,1,239,255,251,19,12,247,235,251,2,12,249,249,253,8,7,254,6,247,247,1,252,1,1,3,242,2,248,0,10,1,244,250,243,251,8,15,0,236,254,20,8,248,8,237,12,10,2,245,0,12,1,245,0,245,241,5,245,2,4,252,245,5,252,251,3,245,249,8,0,239,230,15,19,249,10,247,251,251,14,231,0,248,2,247,253,9,1,250,4,252,3,247,255,6,2,2,244,5,5,9,14,238,237,4,2,16,14,235,241,247,255,16,12,245,246,251,249,4,15,248,251,255,1,14,13,249,255,252,246,251,255,8,7,233,246,14,6,11,10,240,253,16,6,0,0,9,6,254,249,1,22,5,3,248,0,3,254,246,3,0,254,242,2,16,15,239,239,6,19,4,246,241,255,15,11,242,248,5,8,8,254,248,245,10,10,248,242,2,13,4,254,244,246,3,6,4,19,233,237,1,4,247,226,3,250,18,0,2,0,245,0,3,7,254,8,5,2,253,6,247,1,252,7,250,9,5,254,21,20,223,243,7,246,8,8,241,250,252,1,5,3,7,254,247,255,4,250,1,0,9,255,251,2,1,253,3,247,253,3,15,253,226,249,249,231,6,2,250,1,19,1,244,1,248,243,9,13,1,8,2,5,15,254,3,247,0,252,4,250,244,239,25,22,243,246,9,2,11,249,240,4,6,1,0,0,18,252,251,4,254,255,251,0,252,6,1,6,255,7,0,255,0,246,8,8,229,0,254,29,16,254,252,9,255,2,0,6,10,6,4,2,249,9,238,3,3,3,246,17,10,9,250,253,244,250,11,20,224,5,21,3,252,247,2,246,1,7,252,5,0,0,255,248,247,249,4,246,5,0,2,251,4,9,1,251,255,251,1,2,237,243,1,6,12,2,240,239,11,10,13,16,244,245,3,250,0,6,4,253,1,8,2,5,245,3,242,237,5,10,11,2,233,247,16,254,7,0,245,249,10,6,249,26,241,252,8,6,252,7,247,241,1,8,252,4,2,244,16,245,1,11,252,1,225,243,255,8,5,4,254,0,13,7,239,7,246,250,1,4,255,2,247,252,9,3,3,252,251,3,4,253,1,10,255,0,241,234,4,40,245,252,253,242,9,11,255,9,255,250,6,3,250,0,0,244,7,254,0,9,3,1,3,255,255,255,14,8,232,242,248,5,8,5,244,239,8,2,7,10,248,0,4,250,250,246,8,4,244,3,247,244,5,4,253,251,1,245,8,9,232,0,2,2,14,244,243,1,6,7,0,7,250,9,26,11,242,8,10,1,9,0,11,254,6,2,246,243,1,4,34,19,239,241,0,3,254,249,255,0,253,253,255,1,255,246,8,5,0,248,4,239,9,254,0,0,6,2,253,250,252,1,2,2,242,227,0,9,34,253,251,242,6,246,247,251,255,0,3,3,0,1,255,254,255,255,253,253,252,3,253,252,6,3,14,14,248,227,31,11,14,252,251,250,10,6,247,255,245,249,1,7,4,1,250,4,0,10,249,251,255,2,4,252,252,254,14,6,224,250,242,14,251,245,10,238,252,6,248,9,5,252,1,252,5,254,247,3,5,2,246,250,239,3,17,240,9,21,19,4,236,239,14,9,15,250,239,255,1,6,253,1,1,8,253,250,6,9,4,9,247,251,1,255,0,255,2,249,251,3,19,1,236,247,14,21,249,238,247,26,249,239,249,12,6,0,247,250,14,9,247,248,4,15,249,247,255,9,1,236,30,250,11,24,252,0,250,254,8,252,12,248,239,0,5,252,1,255,3,253,5,3,3,7,254,253,254,4,0,0,255,221,17,6,1,247,255,240,3,236,243,8,7,252,249,252,236,7,12,251,5,251,245,12,255,15,247,250,16,252,247,243,4,235,36,237,9,0,249,248,9,252,253,3,0,7,248,254,254,245,13,255,5,253,7,2,3,255,254,251,1,255,254,251,253,244,33,252,1,244,247,0,243,255,2,248,4,246,6,240,249,255,252,246,15,255,0,251,248,5,5,253,0,2,249,1,249,242,32,5,249,241,3,251,8,14,5,9,13,3,18,253,7,4,246,246,10,255,2,0,254,245,5,253,252,2,2,7,4,242,34,1,20,255,244,0,253,249,252,7,18,9,253,14,249,247,236,249,252,243,12,1,12,5,250,2,252,0,241,1,3,235,23,7,248,3,243,253,0,250,254,249,6,244,9,250,254,254,252,255,6,9,5,247,15,0,8,248,7,6,241,3,251,229,32,255,252,254,4,246,12,253,8,13,7,0,241,4,254,3,5,7,252,9,244,255,254,255,252,0,252,2,251,6,250,239,29,15,0,255,252,246,13,12,255,248,246,246,4,7,254,6,251,243,19,6,1,249,2,247,254,12,252,248,253,2,4,218,27,16,241,250,3,249,252,0,255,6,254,253,250,6,250,253,0,2,0,252,6,1,255,0,4,255,3,4,1,254,5,223,40,252,2,1,0,0,246,242,0,249,4,255,3,254,5,7,6,255,4,1,3,1,249,1,252,5,7,0,4,3,252,236,25,12,252,16,252,2,2,242,254,253,29,255,1,3,1,9,251,2,248,253,1,249,254,249,1,0,4,16,254,255,255,246,30,17,3,251,254,0,251,234,4,5,5,253,238,250,10,251,249,2,8,7,249,245,254,0,253,3,2,11,252,4,252,245,30,11,4,253,248,1,254,4,18,3,1,255,0,248,252,253,10,13,14,5,251,1,1,246,2,15,4,9,255,251,253,239,32,18,238,253,251,6,10,1,241,251,9,8,244,246,250,11,9,251,248,249,10,5,246,242,252,253,1,9,245,2,1,243,28,245,255,2,240,254,7,232,0,3,6,3,255,248,249,244,2,2,236,10,4,0,243,254,254,1,8,242,0,4,1,242,23,12,8,8,230,2,252,242,13,242,15,3,247,255,243,246,254,246,6,240,12,8,0,9,246,249,252,252,7,248,8,236,45,10,242,4,16,8,247,1,248,10,5,249,254,2,251,255,0,251,4,250,254,4,1,3,4,252,2,254,254,5,1,236,26,252,1,7,4,248,1,251,243,2,13,249,253,6,250,22,0,5,11,252,245,8,247,2,254,252,254,2,243,252,248,228,18,17,3,248,233,240,250,5,246,14,10,5,255,248,4,254,13,253,254,3,4,3,254,253,252,0,1,3,4,0,4,244,32,250,240,18,12,240,0,7,13,252,5,248,255,253,4,6,254,255,243,4,255,3,12,253,246,1,6,8,245,254,4,238,26,2,5,0,247,239,14,5,1,7,253,248,253,11,7,251,244,248,7,0,249,2,244,247,13,245,9,6,245,251,11,232,22,241,247,8,1,249,244,247,3,11,15,14,245,12,241,251,7,254,0,248,3,3,255,2,11,245,14,250,13,1,250,236,28,18,252,250,251,12,14,2,10,243,250,248,250,243,255,230,22,253,242,6,0,10,241,243,247,6,249,1,251,252,255,237,26,248,253,242,250,247,252,248,15,248,3,244,252,254,249,251,3,13,253,252,231,4,255,5,244,255,243,5,2,0,6,238,43,14,248,1,233,254,254,1,3,249,0,0,8,255,253,251,1,5,2,0,254,254,254,1,255,255,249,0,3,253,9,245,30,10,242,3,1,10,245,1,249,252,14,2,1,247,1,245,254,249,5,245,1,3,14,1,240,248,3,251,7,252,4,238,24,6,3,8,7,234,249,249,3,248,4,23,9,3,255,3,6,7,255,249,6,4,1,253,1,250,255,2,249,3,3,241,38,249,255,245,2,239,232,24,8,7,252,251,2,2,249,1,4,0,247,5,0,255,1,255,251,250,3,0,7,8,253,242,22,1,251,9,244,247,251,250,5,7,8,255,252,247,253,223,240,247,255,12,245,17,249,253,255,249,3,2,253,16,252,242,20,6,4,246,252,252,252,1,249,2,6,8,244,4,1,255,12,10,3,242,246,253,18,254,33,251,239,17,251,9,7,244,23,13,0,245,248,245,12,251,247,240,11,6,4,12,251,5,243,7,244,253,1,2,12,1,252,255,5,4,11,244,253,15,2,14,7,1,2,1,12,10,23,4,6,236,246,4,26,250,13,4,3,2,245,5,249,246,4,9,1,10,252,11,4,17,15,31,17,18,16,11,24,2,4,2,3,248,253,7,253,251,249,254,250,252,251,252,255,252,254,251,250,2,255,4,254,16,8,15,14,3,7,21,9,8,15,21,6,8,12,5,251,7,253,10,2,253,8,6,0,5,5,6,253,2,4,0,251,5,252,6,12,6,13,24,17,251,17,255,250,249,246,248,238,3,254,2,7,241,245,12,253,254,254,252,249,2,0,5,5,10,250,8,11,12,20,22,245,253,15,253,15,254,254,0,2,5,248,4,251,247,252,255,2,255,253,1,3,13,255,9,7,251,8,5,11,14,251,14,247,2,35,8,15,1,254,2,254,4,247,253,242,244,254,254,252,254,248,253,1,250,3,10,0,16,0,250,15,253,4,4,3,3,20,5,252,10,9,247,253,246,254,249,11,245,246,17,255,3,241,2,9,241,246,16,10,14,4,249,19,3,0,19,8,16,34,247,6,243,255,6,5,255,254,4,3,2,1,1,255,0,249,2,255,1,0,6,255,1,6,9,13,9,10,15,16,10,18,13,17,3,255,249,2,241,245,246,252,243,250,239,243,250,242,1,246,6,4,255,255,13,1,7,10,14,13,249,5,5,28,14,14,254,2,3,253,243,252,10,247,19,252,253,4,251,251,0,5,251,0,3,252,1,0,6,22,9,18,18,253,5,10,12,254,1,253,248,244,9,246,249,1,255,19,0,2,248,245,246,9,6,11,0,3,10,11,19,44,0,14,1,249,6,22,2,255,9,2,0,252,4,0,250,250,3,0,0,254,2,251,1,254,0,1,1,1,5,7,0,32,30,26,5,4,249,253,15,250,3,246,7,6,248,249,2,243,251,255,253,7,3,254,248,0,6,4,5,0,9,8,254,4,2,11,4,29,251,14,8,251,242,8,0,9,8,246,5,241,250,247,9,255,18,240,9,235,253,243,254,8,25,7,247,23,20,18,6,16,247,8,8,251,11,13,248,7,4,10,254,255,249,247,249,247,252,1,1,251,246,8,4,251,9,2,16,14,251,14,1,0,235,17,255,9,12,253,253,4,252,14,10,3,0,246,7,4,4,245,2,4,255,253,9,255,17,8,11,26,15,253,14,255,12,9,10,248,8,238,245,253,242,249,7,253,253,252,1,249,253,2,253,16,10,0,9,6,9,8,3,8,18,14,11,1,10,6,1,252,240,254,14,254,1,8,12,14,3,253,8,8,12,241,3,253,3,254,14,10,22,253,245,13,249,11,4,11,3,14,0,250,254,247,4,2,254,0,251,229,246,3,255,5,8,232,253,245,253,2,11,255,19,2,8,36,5,250,3,15,253,252,251,14,246,1,244,246,253,252,3,254,1,248,4,3,5,253,0,4,8,254,8,4,8,14,15,9,252,10,5,11,9,10,8,9,241,15,6,248,246,243,5,248,236,243,250,245,255,253,250,252,255,0,13,15,254,255,9,12,2,2,13,3,233,33,15,2,252,255,3,8,8,6,6,249,8,6,9,255,3,248,0,252,1,248,11,255,6,5,250,16,2,253,31,21,247,12,0,255,252,1,244,3,243,238,2,245,247,2,248,250,11,253,255,0,255,0,13,5,5,255,2,0,25,5,10,16,251,21,14,12,13,2,251,5,5,253,254,242,0,244,7,11,255,249,19,255,255,255,8,255,10,7,3,11,0,8,22,3,3,19,252,12,15,9,5,15,2,1,2,246,246,0,2,255,0,1,244,255,21,16,9,249,11,252,251,24,249,11,20,11,241,18,5,243,241,0,251,9,1,0,255,247,4,248,6,248,1,254,249,20,9,3,9,3,20,0,244,250,9,31,9,12,8,27,15,7,240,5,253,249,255,247,254,249,253,4,248,253,3,250,254,254,253,250,255,2,6,250,48,8,253,19,12,11,249,2,3,0,255,1,8,252,4,250,0,252,252,253,3,6,3,243,248,5,253,249,8,5,7,254,6,11,12,2,14,4,251,12,2,9,4,2,0,255,2,0,241,247,240,254,8,239,251,234,237,251,255,246,1,254,11,247,3,12,6,6,1,17,250,19,14,7,249,255,255,247,9,245,239,0,250,16,0,1,9,232,3,3,247,253,3,254,9,0,1,8,1,7,2,251,253,8,255,7,2,6,253,250,5,254,6,254,252,253,0,253,13,206,1,254,2,4,4,3,7,0,26,21,252,2,17,8,7,11,249,1,255,241,255,241,245,252,239,252,1,249,3,6,3,247,2,3,6,10,6,12,1,254,2,255,246,252,6,253,251,254,248,2,2,2,8,0,1,1,6,0,11,13,3,4,0,244,11,251,19,20,2,5,5,3,243,254,1,244,11,249,244,7,10,0,7,0,254,4,250,247,245,244,233,12,10,253,0,6,19,255,24,18,9,12,6,253,2,5,2,2,254,251,248,245,252,3,248,252,5,253,240,252,3,244,252,3,32,7,2,8,32,238,255,12,1,7,0,248,255,0,248,7,248,255,255,4,244,255,3,0,1,238,8,8,242,246,245,19,9,5,249,6,8,252,26,12,255,6,3,5,242,7,14,8,20,243,240,246,254,17,249,4,248,247,14,251,3,252,244,7,14,246,237,236,35,8,13,14,254,9,254,252,255,1,253,0,255,1,2,2,6,0,0,4,5,254,3,3,3,254,249,253,253,255,6,254,29,22,13,34,0,14,253,247,3,1,5,252,2,0,7,247,0,2,251,253,0,6,255,255,255,2,2,4,8,7,20,250,7,16,33,20,6,255,245,1,253,253,245,3,247,231,255,240,4,248,15,1,254,7,8,23,2,18,243,16,3,249,6,3,16,248,12,16,3,4,0,5,5,251,1,255,2,253,254,1,243,2,2,10,6,7,18,18,7,9,8,9,21,14,7,12,15,14,15,12,11,5,1,251,11,254,17,8,3,0,255,6,11,249,6,6,7,5,241,14,1,11,4,10,12,1,2,4,30,1,11,1,6,13,2,4,3,249,5,8,245,7,251,9,246,6,8,246,253,10,1,227,252,230,5,248,13,4,3,6,35,1,3,6,3,0,254,1,0,0,255,253,249,253,247,253,255,250,3,4,4,0,5,255,254,254,255,252,246,8,0,250,10,252,46,12,2,28,4,255,4,1,0,4,254,254,254,255,2,252,1,5,0,253,1,1,254,0,1,254,255,255,3,250,35,245,13,53,253,255,251,254,0,243,240,5,244,245,1,226,3,238,232,248,251,237,1,253,248,7,249,248,15,237,4,10,30,24,6,1,247,10,252,8,249,252,250,12,255,247,252,2,247,3,2,254,4,2,22,9,4,251,0,5,254,247,253,1,18,244,18,16,4,16,251,248,253,251,253,6,249,253,254,251,253,1,2,2,4,250,10,3,12,253,20,0,27,252,16,5,18,253,23,4,12,11,0,1,0,1,254,1,2,1,255,0,254,2,254,252,1,254,254,255,251,254,0,0,254,2,9,7,63,5,12,255,1,0,4,253,249,251,245,251,244,246,246,244,241,244,242,242,1,1,10,246,16,6,2,9,11,9,9,8,12,255,13,12,6,3,7,253,254,4,6,248,2,253,244,251,247,248,246,15,254,252,8,9,7,243,238,34,251,7,12,22,16,245,13,25,241,245,253,254,0,252,1,0,253,243,249,13,12,249,246,13,19,6,16,15,244,241,253,34,1,5,1,247,11,21,8,17,251,250,3,251,0,252,0,4,245,4,249,253,255,248,3,254,2,1,11,5,6,14,253,2,252,249,0,31,15,254,24,11,5,4,255,252,247,5,248,238,252,247,236,238,7,242,240,3,8,253,29,11,243,243,7,1,17,6,6,21,11,1,14,248,2,5,253,8,246,250,12,2,1,3,3,3,3,250,248,242,15,251,16,4,16,0,7,255,0,16,2,1,22,4,19,13,245,1,2,253,10,20,252,255,248,5,248,247,250,254,252,249,8,246,0,8,250,1,248,14,13,5,17,250,26,255,7,255,0,12,252,249,225,254,249,255,5,251,251,244,4,249,250,3,15,254,5,254,7,255,10,7,8,255,14,20,14,9,16,16,8,24,249,0,253,250,1,3,243,250,252,252,251,247,255,246,252,248,2,0,255,1,24,24,21,31,5,2,11,12,7,4,3,6,253,251,6,252,253,255,2,255,254,1,0,248,255,2,0,252,6,22,255,251,8,12,255,254,28,27,20,229,14,1,2,253,1,251,254,254,6,254,9,1,254,251,3,4,11,5,2,8,253,255,1,254,253,251,5,8,49,12,8,253,9,20,12,17,250,0,1,7,0,9,254,252,8,0,254,246,0,7,21,255,0,1,17,249,251,2,4,16,254,17,14,236,15,14,4,15,0,3,252,9,252,0,6,4,250,250,251,249,2,247,246,254,251,0,253,235,9,14,245,13,29,2,25,4,22,255,2,253,2,12,245,2,16,9,252,7,1,246,241,11,252,3,254,4,4,251,246,1,4,19,241,6,252,254,30,249,11,21,244,5,254,253,254,4,255,251,253,249,251,1,0,250,1,250,7,0,8,249,253,254,2,14,2,253,230,255,26,22,32,1,254,6,1,218,255,236,254,253,250,252,2,2,7,0,3,5,3,10,6,1,253,251,7,5,251,252,8,3,1,242,255,247,251,252,251,230,249,237,246,251,245,5,245,231,248,242,247,240,248,250,239,242,255,255,6,2,2,2,3,0,2,8,248,3,0,253,17,207,253,233,255,11,7,3,4,252,0,0,255,4,2,4,254,252,2,254,255,254,2,0,0,255,0,0,1,2,0,0,4,222,250,247,1,21,249,3,254,255,253,18,2,240,7,253,8,7,251,7,2,4,8,250,249,254,251,255,4,1,2,252,5,227,13,254,242,3,1,18,241,4,248,8,246,8,2,1,248,15,3,246,252,252,254,0,253,252,2,253,252,253,12,250,13,236,3,238,239,4,242,13,28,11,248,250,16,6,0,10,3,4,247,13,5,249,12,251,0,249,5,1,3,3,2,1,3,229,251,245,235,245,244,0,251,7,234,1,3,5,0,251,8,7,1,251,249,2,251,4,1,3,248,254,0,4,254,6,31,211,0,255,244,1,2,250,4,3,255,3,3,0,5,3,251,12,4,6,2,1,254,1,3,2,5,2,2,2,3,255,9,211,6,5,255,239,254,18,253,2,0,1,0,255,10,8,249,254,251,248,6,255,0,4,6,253,12,255,254,0,5,249,3,230,254,244,244,2,246,16,253,12,4,5,11,8,240,239,254,253,253,2,5,247,13,1,10,11,3,5,254,2,2,249,8,230,32,249,251,22,2,14,246,248,249,3,3,7,0,251,0,255,253,0,8,4,251,249,6,255,4,8,1,1,7,250,4,225,2,242,2,0,1,8,250,255,17,253,13,250,5,246,254,246,254,246,253,7,1,5,248,8,242,253,241,7,246,250,16,229,13,252,233,7,247,6,249,5,4,2,255,253,23,238,7,0,253,4,253,9,250,254,255,8,250,2,6,253,2,254,255,221,254,248,11,255,249,253,254,11,7,6,250,246,9,6,253,251,250,253,9,16,240,247,236,12,3,5,253,1,247,4,2,232,1,244,240,5,252,3,252,255,245,245,248,242,14,10,248,20,8,253,245,1,1,252,252,249,253,15,2,250,254,7,9,235,2,237,249,251,248,25,3,17,5,253,9,244,8,2,252,3,3,1,11,247,252,253,4,3,234,6,4,6,11,251,16,233,13,239,235,244,5,9,236,7,6,250,0,2,247,6,250,243,249,255,5,253,5,249,246,1,0,8,247,11,0,248,10,230,247,249,237,252,6,16,249,5,252,4,8,0,4,255,6,249,1,248,245,10,242,0,240,6,253,5,255,14,12,1,8,229,12,242,255,255,237,10,245,21,242,9,248,253,8,255,12,243,3,252,254,0,247,0,249,2,253,12,1,253,3,1,18,236,242,242,240,253,232,6,239,2,253,245,2,253,12,10,10,1,10,7,8,5,5,4,255,7,2,2,0,4,7,0,0,226,9,240,238,15,12,253,4,252,251,245,252,244,246,0,2,254,252,255,2,0,255,250,2,253,4,251,7,3,5,7,25,232,255,250,247,6,243,254,3,15,253,11,4,248,245,2,0,247,254,7,4,8,5,248,5,6,255,245,241,251,0,11,0,222,249,245,249,9,253,19,4,248,3,245,11,253,247,12,9,9,2,1,249,1,253,0,250,254,255,3,0,249,254,251,6,222,252,251,253,247,2,9,255,9,251,253,230,244,8,250,249,11,248,4,4,1,255,0,8,9,252,7,255,1,253,255,3,226,5,6,246,3,249,6,3,3,230,237,253,1,7,5,252,251,6,10,13,246,4,249,252,5,253,9,250,3,9,5,4,232,9,237,2,252,251,8,253,2,0,241,255,9,252,22,6,9,3,7,11,247,0,253,4,5,251,10,248,5,249,253,8,229,7,253,255,2,247,13,7,12,252,250,250,5,0,7,5,1,15,253,252,0,251,254,7,251,249,1,254,13,248,13,17,234,241,245,248,16,242,18,2,255,14,249,14,250,250,249,248,17,6,4,4,249,251,247,242,250,255,9,253,1,6,251,25,226,2,244,243,18,238,16,8,253,10,248,253,255,250,3,251,249,4,6,7,1,1,245,251,6,2,252,9,255,251,254,7,233,7,241,255,253,255,0,246,12,2,5,252,0,4,6,255,5,247,255,255,249,1,17,9,239,240,8,4,242,11,14,0,225,7,243,3,245,249,6,1,245,8,249,15,253,16,245,255,241,16,253,5,0,254,254,250,11,5,6,5,251,6,3,13,232,254,236,246,7,253,255,15,2,6,251,249,246,236,1,252,14,8,254,3,243,253,1,252,1,253,2,8,249,16,252,1,254,254,253,252,249,0,3,6,7,3,2,1,254,255,0,250,4,2,252,253,252,5,9,5,0,253,253,252,249,225,206,255,253,7,2,255,2,4,6,0,10,254,0,236,250,253,9,236,234,255,255,15,9,244,10,243,236,12,3,5,6,249,230,0,4,254,242,244,6,243,11,246,3,22,6,16,254,251,1,253,245,0,249,5,251,0,1,255,250,8,8,10,9,251,229,251,10,254,7,9,247,5,247,5,4,241,14,1,3,246,5,0,254,7,3,243,6,9,250,5,242,239,255,11,14,254,230,0,6,253,0,248,6,0,1,4,248,2,251,4,7,15,11,9,19,254,14,248,7,255,3,253,253,246,254,12,254,244,227,244,251,0,253,254,6,3,253,2,254,1,11,2,249,5,1,2,254,242,0,255,251,3,8,228,230,6,250,3,8,246,229,255,253,6,2,4,15,1,0,2,254,254,13,3,6,0,6,255,252,255,251,8,255,5,251,241,11,248,251,14,250,242,227,251,250,0,1,0,6,253,2,251,255,5,253,2,246,3,4,3,0,13,253,255,4,252,250,2,9,8,2,253,28,245,225,1,252,246,247,252,253,241,250,1,5,253,250,5,250,234,27,243,5,3,249,252,20,249,244,255,232,252,243,248,245,241,235,250,252,19,250,2,11,250,1,253,246,9,247,12,246,2,1,247,1,15,7,251,5,227,221,4,226,9,9,19,17,2,239,253,3,253,1,2,5,255,5,254,253,1,253,248,3,252,254,252,255,12,0,2,248,250,252,16,255,242,254,25,250,241,220,0,255,3,252,252,255,7,252,8,0,10,9,252,1,10,255,253,243,251,252,255,252,8,11,14,249,251,16,12,13,255,228,1,254,2,253,248,10,4,9,12,3,5,0,8,253,250,2,16,245,11,0,1,6,1,18,246,240,255,252,5,242,241,236,1,244,5,4,249,8,255,239,254,247,242,245,6,247,5,252,3,254,7,18,251,5,6,255,245,254,246,253,8,253,254,224,244,5,20,251,250,245,250,250,243,4,250,19,248,2,3,247,252,252,255,9,255,21,255,7,15,246,255,253,9,253,2,232,0,253,2,250,4,255,247,254,255,253,6,255,251,250,251,248,0,254,250,9,252,3,2,243,1,249,23,243,4,253,241,223,249,2,241,11,246,14,0,245,3,255,12,252,252,9,11,243,243,253,242,1,3,6,251,8,0,5,5,246,4,5,250,226,250,4,0,251,4,1,255,255,3,6,5,254,251,0,254,5,252,254,252,254,4,7,249,255,1,252,253,237,37,12,10,216,249,2,249,244,17,11,249,2,2,3,1,255,3,4,254,251,9,247,6,4,9,12,11,251,2,255,0,9,5,249,254,232,249,6,1,3,1,0,6,0,4,244,254,254,1,247,10,254,11,255,21,244,15,251,10,251,5,251,14,250,5,249,253,227,254,0,251,254,253,1,253,0,4,2,3,0,2,254,7,254,3,251,2,255,6,252,0,253,8,245,19,248,22,222,13,221,255,253,255,9,11,253,253,255,7,18,11,251,2,244,245,18,9,251,1,250,247,12,1,253,253,247,242,9,9,8,250,230,0,5,251,255,255,254,4,6,8,2,255,254,5,1,251,252,1,1,18,1,7,246,3,254,12,255,241,9,12,242,13,218,3,0,248,255,0,8,247,253,248,16,3,16,251,247,0,255,249,255,252,13,7,0,1,2,255,240,0,254,1,8,248,228,7,9,251,253,254,2,0,3,11,250,252,254,254,251,28,238,250,2,15,246,241,246,254,0,254,254,4,253,7,11,5,226,9,0,249,255,252,249,2,2,9,254,2,3,248,250,250,3,246,4,10,5,21,252,14,238,1,3,246,254,6,14,248,230,242,255,2,3,253,7,1,234,255,255,0,1,12,242,3,251,0,10,253,1,251,12,253,10,248,234,245,243,249,246,243,231,254,251,252,252,247,238,9,253,251,17,13,5,6,11,3,8,20,4,2,9,8,5,6,1,7,249,250,254,249,0,239,233,251,251,2,0,6,2,254,2,253,4,4,0,251,254,252,6,8,10,255,1,251,5,242,254,245,8,6,25,7,255,0,213,252,0,4,254,7,0,3,17,5,2,251,1,21,3,254,246,240,247,7,244,9,248,2,5,251,246,254,245,251,255,247,226,254,3,1,252,255,0,8,1,12,4,255,255,3,239,13,9,0,7,250,251,9,1,5,4,246,238,0,14,11,252,240,228,255,0,2,255,4,1,255,1,255,254,255,254,3,0,0,255,255,1,2,254,3,3,254,4,254,255,250,1,255,255,6,186,7,3,245,255,12,252,242,4,4,252,4,254,2,244,252,15,239,252,253,6,8,251,22,234,5,245,15,252,4,255,235,255,10,254,243,11,4,14,4,9,8,8,19,15,14,15,5,10,8,15,251,4,14,248,1,1,2,1,255,253,21,8,227,13,250,0,250,6,255,2,8,252,251,4,252,251,0,254,252,0,9,254,1,254,26,237,21,246,4,1,248,5,22,246,243,15,11,251,1,0,6,3,7,254,254,253,251,255,254,250,1,1,248,251,243,13,254,253,255,247,228,4,2,245,18,236,232,9,7,4,253,6,6,250,249,251,249,252,252,0,249,251,250,251,2,243,244,2,0,5,18,15,243,249,13,236,16,246,237,6,5,248,255,5,10,2,255,246,245,23,8,251,248,4,251,252,251,251,245,248,5,1,7,247,247,250,12,14,17,244,234,3,251,248,253,3,12,255,0,252,251,1,1,6,1,5,251,7,254,7,1,6,6,2,0,251,17,252,251,232,13,236,229,14,255,2,253,1,253,1,253,0,254,3,254,1,2,255,254,255,254,251,5,254,0,249,1,250,8,8,11,251,24,213,243,2,254,4,7,253,252,4,13,252,0,0,254,9,0,253,250,1,249,1,255,10,0,5,255,232,25,241,7,2,22,246,235,0,251,2,6,254,13,3,5,244,245,16,6,10,251,0,253,6,5,251,251,10,12,10,11,249,8,242,2,241,13,242,248,253,5,6,249,251,5,2,9,5,0,255,252,2,8,0,3,5,244,3,253,250,2,255,251,14,11,236,235,231,24,255,246,6,251,5,254,9,4,252,255,250,11,250,5,0,2,253,6,255,239,238,252,243,9,255,9,249,252,248,2,253,12,225,238,5,249,245,6,248,4,253,244,0,255,250,253,0,5,9,7,2,1,248,250,8,2,251,7,255,16,246,16,244,18,255,231,244,3,244,1,2,254,238,248,241,246,247,2,249,11,245,2,255,255,255,247,250,3,242,254,255,2,243,249,247,19,251,239,2,7,1,248,7,17,243,246,5,7,1,250,4,9,252,0,3,8,1,242,247,4,7,247,0,6,251,244,254,25,254,237,1,7,253,6,253,1,6,249,0,10,0,4,251,239,252,4,255,0,253,249,19,24,255,21,8,10,9,8,255,23,254,238,254,3,253,0,5,8,254,247,2,9,6,19,8,2,6,247,254,252,253,248,7,249,248,5,4,26,250,7,18,24,0,243,4,0,243,245,255,3,247,5,4,249,3,0,2,255,4,251,2,9,254,245,15,1,235,1,255,0,4,242,252,24,240,243,1,1,247,248,0,0,252,11,255,14,16,0,17,254,247,244,0,255,242,247,242,0,254,19,4,6,4,4,245,8,239,237,251,253,1,2,12,252,238,255,252,249,14,253,2,0,249,248,12,251,247,14,12,247,254,4,250,4,18,255,231,22,2,233,251,254,0,0,0,1,3,5,255,5,254,254,2,253,0,1,2,0,255,2,255,247,250,249,252,254,4,249,251,64,253,231,4,12,254,253,0,8,247,13,249,6,253,244,12,15,247,252,2,9,252,244,3,14,1,7,241,15,0,250,244,0,253,236,6,2,255,252,5,9,6,249,2,254,249,254,0,255,238,252,250,241,251,11,5,246,255,2,7,12,237,249,8,21,252,241,4,4,2,5,5,251,1,3,2,248,13,0,251,254,242,245,6,2,17,8,243,26,254,5,241,252,242,12,247,13,235,233,252,2,253,254,253,3,254,6,9,247,13,4,2,12,253,253,1,239,234,253,4,3,254,1,247,1,250,11,243,14,0,241,6,240,252,17,254,236,245,11,10,5,248,16,2,239,242,11,11,250,245,249,12,12,246,250,5,8,252,254,251,28,3,243,4,0,253,3,249,6,8,244,20,237,18,245,10,251,0,247,11,3,0,254,9,249,251,18,3,254,240,1,6,12,249,240,1,4,1,5,251,15,2,248,3,5,245,15,253,8,248,255,7,4,7,254,6,247,5,12,2,33,254,250,238,4,0,238,11,3,255,1,255,0,1,4,255,251,0,1,0,4,2,255,4,253,2,0,254,4,6,255,6,42,19,252,219,19,1,241,252,2,0,251,0,10,0,0,251,3,0,0,253,253,0,2,252,246,2,250,4,4,1,27,249,17,222,5,247,15,240,249,251,254,7,7,254,9,254,241,11,11,7,5,1,15,1,247,31,2,241,2,4,3,4,255,248,2,249,6,239,11,242,245,2,1,1,245,9,9,250,242,245,246,8,253,11,16,247,248,243,248,9,0,6,6,254,13,248,254,3,13,253,10,250,239,4,14,5,4,250,244,10,249,8,21,248,226,15,254,1,11,247,251,1,0,255,255,250,254,3,251,7,9,5,251,2,0,1,255,2,20,239,241,3,3,7,11,239,243,250,253,18,17,241,252,252,251,22,14,242,254,246,249,11,8,249,253,0,249,11,7,245,249,248,242,22,5,2,6,13,244,254,10,3,0,235,252,20,3,10,21,246,244,8,11,2,251,2,1,3,255,15,255,254,255,254,243,8,252,0,7,254,239,8,18,5,3,8,248,254,3,252,14,238,243,14,15,243,255,254,4,11,1,12,13,250,252,240,239,16,21,254,5,245,247,19,21,239,253,239,3,12,8,244,250,1,249,9,9,249,251,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+965100);
/* memory initializer */ allocate([253,5,250,252,11,5,12,236,250,10,4,12,8,251,246,15,13,14,10,241,243,1,6,14,15,239,243,4,251,10,7,250,248,253,252,12,25,255,7,251,249,11,1,17,13,241,242,252,5,3,8,253,254,2,0,6,16,244,250,252,4,253,7,246,253,249,243,7,248,10,253,243,5,2,4,9,9,239,243,2,11,1,6,252,8,246,4,1,19,241,252,12,31,7,251,239,252,9,254,7,14,250,250,250,242,13,17,251,4,242,247,7,7,247,3,240,241,11,11,6,4,245,237,3,5,8,13,242,242,3,252,12,254,252,10,252,249,255,27,5,2,240,238,4,12,254,253,254,255,1,248,244,3,252,8,15,2,4,9,243,242,9,249,5,4,2,246,251,249,2,1,4,255,250,241,6,1,10,5,246,247,255,13,253,5,235,245,8,8,5,27,235,238,251,255,15,11,1,240,248,245,0,5,248,244,243,239,22,4,250,255,238,246,0,19,2,254,248,249,253,2,254,247,239,251,4,4,10,8,250,237,251,252,12,14,15,10,247,255,247,19,12,0,255,2,4,7,9,16,240,242,9,252,3,1,0,254,10,255,255,12,248,12,247,0,25,7,9,2,225,247,252,15,4,251,1,246,11,8,10,0,250,5,11,255,250,4,246,247,6,4,5,14,6,239,254,17,12,247,2,0,231,242,5,20,14,8,236,5,2,254,253,9,243,253,255,250,3,7,250,0,2,3,1,8,4,241,253,10,18,252,13,8,234,246,9,19,241,7,251,243,12,252,9,2,247,250,0,2,1,247,250,6,1,255,11,4,1,4,251,246,18,7,2,252,247,245,0,32,249,4,240,255,0,6,3,6,253,242,16,9,254,7,255,0,251,5,253,253,2,3,248,250,4,6,2,4,244,241,2,8,8,9,253,238,6,34,11,12,241,255,2,9,2,252,252,2,4,2,253,18,250,244,248,255,15,20,252,255,245,251,6,6,245,241,249,3,7,10,2,8,246,251,8,15,251,5,239,243,13,11,7,8,252,250,255,242,253,6,254,1,251,255,10,10,241,5,0,246,252,253,7,252,237,241,27,11,18,3,237,254,6,0,12,12,0,251,0,4,251,1,5,10,249,245,21,29,1,254,1,252,245,255,13,11,236,255,4,4,4,251,6,243,254,11,9,2,249,249,253,246,255,20,12,1,237,237,255,5,4,249,231,14,1,253,2,12,252,253,253,254,6,1,0,3,2,5,255,12,248,3,244,246,10,13,0,23,242,238,10,0,15,3,244,253,251,5,252,2,242,246,8,2,9,255,245,253,5,13,2,9,250,7,249,226,17,6,13,1,242,0,255,6,247,8,3,252,0,255,249,251,243,237,253,252,4,250,254,243,1,254,3,10,1,3,238,230,17,4,240,4,253,243,252,250,245,252,235,7,8,2,5,13,250,1,5,8,7,9,250,250,1,255,2,253,255,0,254,254,0,255,3,4,242,248,247,13,2,50,233,248,8,7,11,16,3,249,0,254,6,5,255,1,254,4,3,1,3,1,1,250,3,6,6,2,254,253,10,2,248,251,251,5,4,4,254,10,248,216,255,21,8,3,252,255,13,4,7,2,0,252,248,5,2,7,251,5,248,252,255,12,2,12,243,247,0,1,244,9,213,1,251,12,1,3,6,1,255,3,254,6,254,255,1,0,4,8,14,4,249,233,251,23,239,250,241,248,7,10,255,7,240,4,250,2,3,253,253,255,8,255,4,10,4,252,1,7,253,2,11,4,250,253,8,5,4,1,211,250,252,4,2,1,242,246,1,1,6,2,248,255,253,3,3,1,255,2,253,248,9,3,3,254,251,248,8,7,249,252,250,5,247,11,254,46,251,255,9,254,0,3,251,253,251,7,0,252,1,254,255,245,11,8,253,254,246,0,4,9,9,239,239,222,252,251,249,253,244,253,11,18,3,254,251,238,251,253,6,7,251,253,1,252,253,251,255,2,5,254,3,246,12,238,251,246,12,247,4,250,2,0,16,239,15,14,244,246,254,247,255,4,251,253,251,253,255,7,18,249,12,3,5,248,252,236,1,231,1,248,13,246,8,237,255,248,10,6,247,255,0,12,4,252,5,0,255,2,5,248,254,250,4,248,9,3,2,249,4,231,13,233,10,14,15,245,3,238,4,16,252,1,246,246,3,5,253,255,253,4,1,253,252,251,1,244,14,249,11,241,6,250,24,252,13,255,15,243,8,3,7,251,2,2,0,3,249,253,1,0,8,6,255,6,5,251,254,244,4,0,254,253,5,250,0,248,9,246,4,228,12,236,11,243,7,238,1,245,1,1,252,241,5,0,243,251,13,245,4,252,251,5,242,240,0,242,5,236,12,10,249,251,6,6,22,6,252,254,3,8,11,13,245,254,16,16,249,0,20,249,255,0,5,247,12,254,251,234,5,246,12,250,11,9,21,248,15,4,0,248,252,252,10,18,252,243,0,1,241,255,253,2,10,255,6,1,252,236,251,248,6,248,17,251,5,246,8,234,6,251,254,8,239,8,2,1,254,247,6,225,248,248,8,0,5,247,252,2,3,244,11,238,10,251,3,245,13,250,11,253,12,249,3,247,255,2,11,247,250,21,248,241,4,245,12,245,17,255,2,250,0,241,13,244,19,0,2,250,253,247,10,3,17,254,5,246,253,0,1,4,250,5,246,1,251,1,0,0,0,2,7,254,2,254,0,252,3,252,1,244,6,207,16,246,13,0,254,8,6,1,8,5,248,249,9,13,251,7,0,10,11,252,253,255,13,242,6,241,250,242,16,15,1,238,252,236,20,249,255,247,254,246,10,244,4,0,10,0,3,8,4,229,255,254,19,252,2,243,3,1,9,244,1,234,19,251,4,247,12,2,247,248,11,253,7,4,251,11,250,17,239,5,252,254,250,1,251,2,4,242,6,236,19,236,12,235,5,242,13,254,11,4,253,0,246,252,254,254,255,253,8,247,249,234,253,232,13,254,10,241,5,247,4,249,0,251,15,248,11,243,6,252,19,248,12,252,6,9,7,2,253,2,255,0,3,1,2,1,252,254,253,1,5,244,6,240,14,233,10,242,17,241,16,254,9,231,9,246,16,4,9,253,7,248,253,2,2,252,248,247,10,3,245,25,246,228,27,247,7,243,9,254,4,244,248,242,6,7,246,3,3,253,5,248,253,1,246,8,253,247,252,13,7,2,4,246,4,3,7,238,2,234,15,4,20,249,5,250,13,255,4,249,250,6,13,254,3,0,2,252,254,0,0,1,2,254,251,0,1,252,0,254,253,1,2,255,2,248,255,232,68,253,8,3,3,255,255,241,254,247,249,255,8,242,8,3,6,0,255,248,8,233,2,242,17,241,8,252,7,238,0,248,253,255,252,246,4,255,4,8,0,2,249,0,5,1,3,245,4,248,14,3,20,1,26,245,13,243,20,254,0,248,2,250,6,255,9,3,250,253,10,5,0,255,249,10,1,253,5,4,7,251,255,253,255,12,253,241,7,247,22,237,8,247,4,233,13,242,6,250,242,252,7,14,251,248,246,25,3,233,249,228,0,255,247,4,1,243,20,248,10,240,8,12,243,235,5,243,11,254,1,12,249,2,246,251,252,9,5,250,35,249,8,15,2,255,247,250,2,238,7,241,6,253,2,8,12,226,7,252,20,2,6,13,250,252,0,1,8,247,9,251,12,247,16,247,16,239,14,243,15,238,14,241,17,244,14,243,7,240,13,247,5,245,10,247,6,244,13,246,252,5,3,1,6,8,242,251,15,7,4,8,7,234,8,249,248,241,26,1,13,253,17,251,9,254,4,250,3,248,9,8,253,2,3,3,1,254,255,245,8,252,0,250,251,255,13,219,9,1,250,246,254,246,11,8,13,253,254,250,8,252,13,3,2,253,252,252,7,248,9,248,9,236,12,237,15,238,17,241,7,255,20,245,6,250,3,1,9,2,242,254,254,2,1,249,1,255,253,250,4,4,253,3,255,5,252,3,2,255,9,197,5,252,30,3,3,254,253,255,2,2,1,255,255,254,1,0,253,2,0,255,248,0,2,253,4,252,1,10,6,250,8,249,4,10,11,215,27,236,3,253,8,1,11,251,248,0,4,5,1,4,254,1,2,255,6,249,2,11,4,0,0,248,7,246,0,0,8,2,10,255,1,254,44,254,235,244,253,255,2,252,4,254,254,6,248,2,1,246,14,8,6,5,1,254,4,243,4,2,5,10,254,235,32,253,18,9,250,247,247,10,2,9,240,250,254,1,4,22,2,254,1,253,254,247,3,16,19,232,250,250,251,248,249,8,249,255,244,5,253,0,4,2,253,10,3,240,252,255,13,4,4,1,253,1,250,242,18,3,8,248,228,240,4,4,2,12,7,9,252,252,5,255,255,2,2,251,243,234,253,248,21,254,247,21,252,247,5,248,15,5,1,251,247,249,254,251,251,255,251,251,251,3,10,252,0,249,254,5,246,238,2,20,4,13,246,8,241,245,253,255,16,10,9,248,6,7,251,6,11,5,17,252,7,245,5,253,250,2,1,3,251,237,1,1,253,254,231,245,239,0,243,252,10,10,2,251,4,0,3,253,251,246,254,13,234,0,3,245,251,7,255,12,242,227,6,255,10,7,239,244,14,3,9,247,9,7,6,253,243,0,5,3,255,250,255,0,2,4,244,251,255,2,11,12,241,249,254,244,17,20,240,254,244,250,15,250,12,11,9,7,250,7,252,237,6,2,2,3,245,246,252,251,253,3,2,11,234,250,0,8,18,3,245,252,249,241,239,244,6,16,4,247,4,251,3,6,240,10,249,249,253,5,0,1,241,252,5,12,234,240,5,250,8,12,252,247,239,245,3,5,8,239,0,11,252,243,250,2,255,255,3,3,245,244,255,1,1,12,254,8,246,223,251,253,250,1,249,248,252,250,255,5,252,250,244,240,248,11,8,242,7,12,11,4,242,253,6,249,251,253,3,0,248,249,2,252,24,2,247,245,253,249,11,244,17,1,255,3,251,249,12,4,11,0,3,2,238,253,4,7,250,3,15,10,241,240,254,252,247,7,241,250,2,240,13,248,7,19,235,252,244,247,253,253,6,11,253,255,237,3,249,247,252,3,250,251,246,235,0,253,249,18,235,15,251,244,252,243,2,6,247,247,245,252,13,253,6,4,255,7,247,252,9,5,2,6,3,15,255,229,254,10,3,7,248,9,254,7,1,254,251,18,9,245,239,254,7,247,11,10,0,248,6,240,253,2,249,3,11,4,247,217,19,6,243,13,251,251,241,254,9,0,4,14,6,246,252,251,2,252,254,5,245,3,3,254,254,249,9,7,246,5,245,248,10,254,12,16,0,12,254,250,8,14,8,7,1,18,226,4,10,252,250,2,245,9,246,248,5,0,0,249,6,255,240,246,11,0,13,12,252,252,251,235,12,4,13,14,249,6,240,243,8,2,9,15,244,1,247,234,10,247,9,9,249,4,244,229,1,254,11,15,3,14,242,247,0,247,16,22,10,16,246,5,251,247,1,1,6,6,252,2,239,251,250,241,255,7,244,239,1,247,5,20,249,3,23,248,248,248,255,13,17,249,243,4,252,7,14,8,11,253,253,4,0,4,6,255,247,7,241,241,252,10,12,3,243,6,14,9,248,241,14,23,251,246,251,1,15,246,249,1,9,4,243,246,10,7,253,2,3,4,246,242,0,3,4,0,247,253,252,245,2,239,8,2,15,6,244,244,15,251,17,18,3,253,253,252,250,248,13,4,10,254,238,230,10,252,10,13,4,252,240,249,239,253,5,252,2,241,246,255,248,249,253,2,2,8,246,249,2,2,252,4,255,4,237,251,255,255,250,2,248,10,240,228,250,8,255,11,28,2,246,252,6,250,6,11,15,252,254,7,3,7,249,4,1,253,250,246,251,13,18,10,241,251,253,243,5,1,2,18,251,246,246,249,4,2,1,5,4,2,5,4,8,247,239,7,7,20,244,254,252,5,14,7,245,255,240,250,252,245,17,14,0,248,246,248,10,3,5,10,240,3,248,242,10,3,9,0,3,12,246,220,0,7,15,2,240,2,255,0,255,5,4,5,253,1,246,5,255,241,253,244,12,2,5,255,5,6,253,254,2,17,241,225,23,252,15,254,253,6,249,251,1,244,4,6,8,246,8,3,5,252,1,5,3,255,252,253,1,10,252,254,254,6,238,251,12,10,12,14,245,15,2,247,250,251,254,247,4,251,228,252,14,0,240,9,14,255,3,252,252,2,1,0,4,251,242,225,8,16,7,13,243,5,6,240,10,251,2,254,2,14,251,8,251,7,240,6,243,251,0,251,8,253,255,4,3,1,254,255,0,6,5,2,252,253,255,0,1,4,2,43,28,244,221,254,254,249,255,0,2,255,254,254,1,252,0,254,3,2,247,234,12,3,3,249,252,237,234,242,252,255,21,9,253,241,240,243,1,245,4,247,1,249,255,255,0,254,9,243,253,255,253,233,0,2,12,3,247,252,7,3,9,246,1,27,28,0,9,241,254,254,1,6,8,248,7,253,20,0,0,255,250,255,11,8,254,1,5,250,255,4,2,252,0,255,251,4,250,246,244,19,1,249,9,248,247,240,245,254,12,14,4,4,34,17,7,250,1,4,246,251,4,245,3,238,4,14,243,253,1,0,0,245,0,7,239,252,4,245,250,248,18,0,0,0,26,250,249,255,255,11,248,1,3,2,11,250,250,10,253,1,253,7,4,244,248,0,247,8,234,251,0,250,22,254,11,243,24,253,4,0,3,9,10,255,3,247,244,1,251,18,0,253,8,25,15,248,2,2,254,4,8,9,255,251,10,253,1,255,23,251,2,247,255,253,0,3,255,246,252,0,243,16,9,255,242,2,6,254,250,251,254,249,7,5,3,11,254,242,0,247,30,4,6,6,5,253,255,4,5,10,0,5,252,7,245,14,14,7,34,247,0,246,22,249,255,7,247,2,248,0,249,251,29,252,3,255,252,253,5,1,252,0,2,4,2,1,255,246,1,6,250,252,1,4,253,253,251,0,3,7,244,0,254,246,55,5,9,255,0,4,9,235,247,4,2,6,249,11,249,1,251,0,252,2,253,243,248,0,247,252,2,16,254,241,249,245,31,8,2,255,0,3,251,251,5,1,255,247,1,0,250,254,255,5,2,0,0,12,20,237,1,8,244,245,0,6,251,2,31,255,255,254,1,255,3,247,251,8,254,5,255,0,254,4,254,253,244,0,254,3,0,9,4,255,21,248,3,252,9,250,30,252,0,249,17,10,244,254,246,244,253,10,0,11,252,243,253,5,6,10,7,248,0,249,243,1,0,254,7,244,4,253,24,243,9,4,254,2,252,242,255,253,251,246,4,13,254,5,13,8,3,254,1,5,250,7,238,246,1,255,5,4,1,0,25,251,255,18,12,8,8,240,255,1,1,1,252,251,3,3,4,4,245,244,240,250,2,12,243,0,9,7,9,247,0,246,24,252,1,253,0,2,252,4,1,5,0,253,2,253,254,2,255,1,4,255,254,254,1,255,255,252,255,252,254,250,6,12,69,8,5,11,0,241,252,13,6,0,252,9,1,251,253,15,0,1,6,251,0,1,6,5,8,0,7,1,255,252,245,247,41,252,247,32,250,0,7,252,6,250,1,250,254,4,248,251,253,240,255,254,250,1,15,0,21,3,253,252,3,244,16,2,27,250,251,1,247,251,3,7,253,5,5,14,13,20,249,255,12,255,10,245,245,249,252,242,7,242,13,22,18,255,0,14,28,248,3,254,0,5,6,255,252,1,3,249,3,1,241,4,247,22,246,247,252,1,8,252,9,241,2,250,252,240,12,246,23,0,0,2,0,255,3,253,255,3,251,7,1,5,251,248,1,13,241,251,249,12,250,254,3,10,251,248,17,251,245,242,23,249,252,6,252,5,250,251,2,252,11,9,252,2,254,252,6,15,3,253,18,241,254,250,3,3,236,17,11,252,2,3,29,6,1,250,2,3,0,0,253,3,3,255,3,252,250,250,249,253,254,249,254,252,5,3,251,236,243,252,10,242,227,14,37,3,4,3,250,252,5,0,3,2,3,0,254,4,0,253,251,252,4,252,4,4,3,1,252,252,247,242,20,226,3,238,33,0,2,5,254,252,254,255,2,250,253,254,254,2,251,255,4,3,2,253,0,255,255,246,249,2,252,238,2,219,255,12,40,249,2,255,0,254,4,248,1,252,12,7,4,15,249,1,247,18,0,12,239,253,255,0,0,0,2,250,0,252,253,255,26,250,4,8,251,250,254,2,255,1,255,241,8,7,255,239,252,1,5,6,245,250,14,17,251,241,11,8,0,253,241,250,28,255,0,0,0,1,0,255,0,1,3,2,254,3,255,255,2,2,255,255,249,1,2,247,0,255,252,238,7,246,49,243,32,255,253,4,1,2,251,1,249,255,5,247,4,4,25,1,255,2,251,2,249,17,254,10,251,0,2,241,3,247,7,247,30,251,255,0,2,1,255,2,5,223,3,251,14,11,7,5,253,2,248,252,254,249,250,4,248,255,248,2,254,248,255,252,27,255,0,255,254,1,255,254,255,2,0,1,2,2,4,1,3,4,2,1,249,252,1,253,252,221,231,17,10,253,230,249,32,251,1,6,254,6,6,247,3,255,252,5,252,254,254,247,2,251,2,2,4,3,5,251,240,225,244,245,2,237,20,254,21,251,2,7,249,249,5,249,2,0,0,252,3,255,0,255,254,0,253,5,245,248,253,249,249,28,245,249,0,240,245,252,29,2,1,253,254,255,3,4,0,1,0,255,251,4,251,244,2,254,251,234,254,255,11,8,249,244,0,222,6,251,11,248,19,255,253,5,11,18,254,254,251,254,4,255,8,5,250,1,255,2,8,4,251,248,254,5,238,7,12,7,19,238,2,250,243,9,0,0,5,4,3,250,4,1,252,5,255,252,8,8,6,248,250,0,6,253,3,5,253,17,31,16,10,243,0,247,237,12,246,2,254,254,255,253,6,244,251,254,14,240,4,12,12,17,4,7,240,7,250,11,7,7,2,231,23,232,5,249,247,10,4,13,10,10,3,250,3,3,2,255,250,8,4,10,0,1,2,252,2,253,248,0,255,9,9,246,253,227,1,255,229,2,2,0,7,9,254,246,255,255,1,247,251,8,4,1,2,246,1,13,12,253,15,247,2,249,1,246,23,236,238,247,241,253,251,255,8,0,251,255,4,7,255,249,2,248,251,11,7,250,3,253,247,7,9,234,1,6,252,14,27,231,242,3,251,1,3,8,4,7,6,12,239,241,1,248,246,7,242,248,6,254,254,245,245,249,13,254,254,4,5,251,13,233,250,239,248,251,4,242,251,252,251,6,5,248,251,254,245,249,244,3,245,2,250,4,246,251,249,14,5,23,11,7,12,240,250,252,240,5,6,2,5,254,251,251,250,251,237,243,255,253,243,5,0,6,254,254,250,249,249,255,247,4,14,17,244,229,3,0,255,7,255,9,246,8,2,249,254,5,2,253,249,3,0,6,4,12,5,11,14,243,255,8,1,13,9,12,12,238,242,245,240,249,251,250,251,0,255,253,2,2,1,4,9,2,3,5,254,2,1,8,0,3,0,254,2,1,7,29,0,220,251,247,235,14,250,247,0,255,248,248,245,2,2,247,244,12,252,5,3,251,247,11,255,253,12,235,253,12,5,3,11,238,241,1,254,255,3,247,253,7,249,238,2,4,12,246,2,8,253,242,13,17,251,5,247,13,253,249,238,17,254,5,7,236,253,250,245,253,3,3,255,1,250,251,1,5,253,242,250,251,248,14,250,7,255,5,1,15,255,249,252,6,245,9,254,219,16,249,253,255,0,6,1,253,247,0,11,248,2,254,0,5,2,12,246,10,13,2,7,250,2,246,246,21,251,5,5,244,233,3,242,6,0,254,1,0,1,0,252,1,1,8,254,2,251,254,1,8,252,255,255,4,255,2,6,32,1,251,236,216,252,238,242,2,2,249,254,4,4,255,2,0,254,252,249,3,5,0,251,1,2,250,4,255,254,255,241,8,3,9,46,249,238,6,245,5,5,16,21,3,245,252,11,244,2,4,244,255,11,8,1,252,11,245,235,1,1,245,3,13,1,5,12,231,1,253,254,1,6,249,4,2,3,1,251,8,9,241,3,253,242,17,4,248,14,254,248,252,5,8,249,8,9,7,6,227,239,8,4,249,249,4,0,13,1,0,4,4,240,246,249,5,9,241,246,246,8,252,255,245,255,246,241,3,3,14,10,237,2,238,244,252,0,2,0,5,254,247,0,4,252,2,255,254,2,252,9,2,250,252,254,255,253,253,255,2,5,255,11,232,212,247,241,255,246,6,21,11,15,249,10,242,247,248,248,4,6,19,1,250,1,251,239,248,246,9,5,11,18,255,10,240,249,247,248,3,251,0,0,254,254,250,4,252,1,255,0,7,253,4,252,249,7,17,236,6,4,1,250,244,31,13,19,242,246,249,254,254,6,246,3,9,6,242,15,2,251,2,245,9,248,4,6,20,241,253,253,255,32,235,6,1,9,11,17,237,6,255,253,8,10,254,0,248,240,7,7,6,10,4,242,7,250,21,249,10,5,5,0,249,2,250,0,249,11,247,15,236,249,245,2,0,249,5,2,0,253,250,252,254,255,252,251,243,255,27,247,250,245,249,1,11,252,252,242,254,11,6,10,237,250,241,2,0,7,255,2,249,241,254,253,13,251,251,12,3,0,5,251,234,2,7,22,13,0,255,2,3,2,249,7,229,252,252,244,11,1,240,6,241,1,3,2,0,2,253,2,5,254,251,9,5,253,3,254,245,3,9,6,9,3,255,12,215,8,250,9,3,249,3,2,5,5,0,255,1,3,251,254,243,7,255,254,254,250,4,250,0,2,254,2,4,1,252,1,209,235,7,250,3,16,249,13,252,254,10,253,255,18,243,7,243,252,8,4,8,9,251,13,8,251,3,250,7,18,248,10,231,253,244,244,1,255,255,0,2,5,251,253,0,251,255,0,252,248,254,3,2,254,239,250,252,1,33,250,236,250,8,31,230,248,255,252,3,253,253,5,253,254,1,7,0,3,6,3,6,254,9,15,246,253,241,251,253,252,250,226,17,248,254,2,236,0,248,254,254,255,255,255,3,251,254,253,4,254,0,5,8,253,1,252,1,1,253,4,4,242,3,11,251,3,253,7,253,13,23,240,2,250,1,253,5,0,250,245,249,252,255,2,249,255,255,7,1,254,6,12,250,8,243,17,25,233,237,249,244,9,16,239,9,4,4,4,253,255,6,254,253,0,13,252,249,14,1,249,0,251,3,237,253,5,3,9,255,9,243,13,239,4,21,230,0,251,0,0,252,251,2,250,252,5,249,10,0,2,0,254,254,0,4,250,7,254,6,5,251,2,244,1,227,29,27,12,9,246,234,6,255,255,9,242,244,254,1,255,10,245,240,0,3,11,13,242,247,254,255,6,4,242,0,246,254,16,17,245,2,0,255,254,4,3,250,254,1,255,1,3,252,1,3,252,255,255,4,255,1,0,1,6,251,249,2,1,209,253,50,239,8,252,245,249,11,11,14,249,12,249,6,2,13,250,253,254,242,6,6,6,0,2,255,5,236,2,255,4,251,6,21,245,254,247,3,0,250,7,8,248,1,253,4,1,5,254,253,249,4,7,244,247,254,10,250,13,6,5,20,2,241,9,28,249,0,251,250,250,250,1,250,6,254,4,8,253,12,255,252,254,6,16,242,9,242,254,248,229,253,18,255,249,253,8,23,233,1,4,247,255,251,10,254,1,245,1,247,4,7,14,247,254,253,2,251,255,250,246,249,11,20,2,3,237,3,15,30,247,7,2,242,252,0,254,5,2,5,254,8,253,249,6,6,245,242,1,10,255,249,248,1,10,3,250,241,244,239,4,30,250,4,2,1,254,3,0,1,0,2,0,1,6,249,0,3,4,4,252,254,251,254,2,255,254,0,254,245,249,253,42,24,242,4,1,3,2,0,254,253,254,2,255,4,11,254,2,3,252,251,9,2,252,247,5,8,255,249,1,24,243,228,20,15,234,253,7,6,3,254,251,246,254,254,255,250,250,254,242,240,250,251,0,18,0,9,1,7,243,251,250,247,11,241,9,22,245,9,254,6,5,2,9,246,1,1,5,252,12,2,2,246,249,252,250,7,9,6,15,6,6,246,10,5,243,251,6,24,244,1,3,253,253,8,1,250,2,251,253,7,2,14,6,9,250,251,252,27,7,253,8,250,3,248,8,22,251,250,254,22,239,254,254,3,10,9,9,12,241,255,245,243,3,254,1,253,245,7,9,16,253,246,251,251,1,8,253,9,9,251,3,31,244,7,251,10,252,248,2,16,254,10,10,253,254,3,248,253,3,243,250,15,20,247,253,244,1,254,240,8,8,255,16,22,251,5,253,241,254,12,248,8,251,2,248,20,238,14,252,3,3,7,243,240,1,246,7,16,7,4,242,252,251,247,8,23,250,5,252,251,252,1,8,4,249,251,8,10,6,250,246,254,6,9,239,242,11,12,253,243,249,2,18,3,231,240,18,22,251,5,6,249,236,252,2,8,4,232,252,1,4,251,254,1,246,254,9,3,252,253,252,252,252,10,10,3,0,250,25,21,245,0,7,255,14,250,252,246,5,4,4,4,251,3,4,255,249,8,237,0,6,2,3,238,253,250,2,8,14,230,22,27,243,254,250,7,251,12,249,8,255,3,254,4,1,8,254,0,14,6,251,6,252,249,7,235,8,1,8,247,252,253,11,25,243,4,4,255,250,4,9,248,1,253,246,254,0,15,247,240,11,1,1,6,3,247,251,16,26,1,242,1,253,242,7,15,247,244,254,247,243,2,6,14,0,1,0,255,243,0,10,255,6,9,249,8,8,19,6,255,9,10,252,1,249,234,254,29,249,2,4,13,244,248,252,251,13,12,251,253,253,252,1,255,10,15,250,255,245,226,4,15,255,9,249,0,254,249,10,25,240,7,241,249,249,255,251,251,245,236,10,3,246,253,5,20,252,0,254,254,17,2,0,253,3,6,5,255,244,253,15,22,240,4,255,3,4,251,0,255,251,232,227,4,247,1,253,0,0,0,252,7,252,252,252,3,1,250,5,253,251,246,3,25,246,254,255,255,4,4,255,2,0,252,252,2,255,253,255,254,254,1,253,251,255,2,253,252,252,253,5,247,1,245,7,46,210,0,247,3,4,4,3,251,250,5,252,4,254,1,7,252,246,13,1,3,250,4,252,7,2,237,231,253,240,244,16,20,255,18,6,4,244,0,242,9,250,255,252,251,2,1,12,4,2,7,0,2,5,245,251,254,2,252,10,0,247,249,9,25,248,5,0,250,5,6,3,3,246,251,1,255,4,3,245,248,5,4,251,5,251,249,251,11,5,20,248,240,21,252,27,23,251,96,188,31,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,230,30,0,108,0,0,0,224,125,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,1,0,6,14,43,52,2,83,1,1,13,1,1,1,1,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,4,0,0,0,0,1,103,66,0,30,166,128,176,126,64,0,0,0,1,104,206,56,128,0,0,0,80,101,32,0,108,0,0,0,48,85,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,253,32,0,16,0,0,0,152,28,35,0,16,0,0,0,40,35,33,0,16,0,0,0,64,1,32,0,20,0,0,0,104,41,31,0,32,0,0,0,88,122,30,0,40,0,0,0,8,236,29,0,20,0,0,0,72,127,29,0,28,0,0,0,176,37,29,0,32,0,0,0,120,214,28,0,28,0,0,0,216,208,35,0,32,0,0,0,32,129,35,0,48,0,0,0,208,35,35,0,64,0,0,0,128,221,34,0,4,0,0,0,88,161,34,0,4,0,0,0,192,141,34,0,240,82,34,0,8,0,0,0,5,0,0,0,120,216,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,61,10,71,10,99,10,145,10,210,10,37,11,139,11,2,12,140,12,39,13,213,13,147,14,99,15,68,16,53,17,55,18,73,19,106,20,155,21,219,22,42,24,134,25,241,26,105,28,237,29,126,31,27,33,195,34,118,36,52,38,251,39,203,41,164,43,133,45,109,47,92,49,82,51,77,53,77,55,81,57,89,59,100,61,114,63,129,65,146,67,163,69,180,71,196,73,211,75,223,77,233,79,239,81,241,83,239,85,231,87,218,89,198,91,170,93,135,95,92,97,40,99,234,100,162,102,80,104,242,105,137,107,20,109,146,110,3,112,103,113,189,114,4,116,60,117,102,118,128,119,137,120,131,121,108,122,69,123,12,124,194,124,102,125,249,125,121,126,232,126,68,127,142,127,198,127,235,127,254,127,254,127,235,127,198,127,142,127,68,127,232,126,121,126,249,125,102,125,194,124,12,124,69,123,108,122,131,121,137,120,128,119,102,118,60,117,4,116,189,114,103,113,3,112,146,110,20,109,137,107,242,105,80,104,162,102,234,100,40,99,92,97,135,95,170,93,198,91,218,89,231,87,239,85,241,83,239,81,233,79,223,77,211,75,196,73,180,71,163,69,146,67,129,65,114,63,100,61,89,59,81,57,77,55,77,53,82,51,92,49,109,47,133,45,164,43,203,41,251,39,52,38,118,36,195,34,27,33,126,31,237,29,105,28,241,26,134,25,42,24,219,22,155,21,106,20,73,19,55,18,53,17,68,16,99,15,147,14,213,13,39,13,140,12,2,12,139,11,37,11,210,10,145,10,99,10,71,10,61,10,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,39,1,0,0,41,1,0,0,40,1,0,0,42,1,0,0,42,0,0,0,68,0,0,0,36,1,0,0,38,1,0,0,255,255,255,255,0,0,0,0,208,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,190,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,155,31,0,16,138,31,0,148,0,0,0,1,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,32,64,16,0,1,0,0,0,0,0,176,255,32,0,120,229,32,0,24,0,0,0,84,65,82,86,40,202,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,176,32,0,120,229,32,0,24,0,0,0,84,65,82,86,40,202,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,154,32,0,200,129,32,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,96,103,32,0,200,129,32,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,240,82,32,0,160,50,32,0,48,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,249,32,0,108,0,0,0,40,253,14,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,252,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,2,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,36,31,0,88,116,30,0,220,1,48,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,192,232,29,0,176,123,29,0,224,1,48,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,48,35,29,0,32,212,28,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,200,206,35,0,112,124,35,0,104,32,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,200,206,35,0,80,219,34,0,24,159,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,200,206,35,0,160,98,34,0,16,43,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,200,206,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,208,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,52,2,0,0,0,0,0,0,0,0,0,0,208,169,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,204,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,21,33,0,108,0,0,0,32,255,14,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,112,31,0,32,94,31,0,192,133,6,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,24,52,31,0,24,52,31,0,196,133,6,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,4,0,4,0,4,0,4,0,3,0,3,0,3,0,3,0,48,189,31,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,128,31,0,108,0,0,0,88,1,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,254,28,0,80,250,28,0,248,53,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,144,242,28,0,72,217,28,0,4,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,216,209,28,0,176,202,28,0,220,53,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,80,196,28,0,192,190,28,0,0,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,168,75,34,0,216,101,35,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,168,75,34,0,144,86,33,0,104,41,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,232,72,31,0,160,150,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,144,4,30,0,56,150,29,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,64,55,29,0,16,231,28,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,24,225,35,0,176,146,35,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,160,51,35,0,8,236,34,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,120,172,34,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,112,34,0,136,56,34,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,29,0,108,0,0,0,104,2,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,209,28,0,176,202,28,0,220,53,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,80,196,28,0,192,190,28,0,0,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,176,181,28,0,8,176,28,0,224,53,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,75,34,0,216,101,35,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,168,75,34,0,144,86,33,0,104,41,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,232,72,31,0,160,150,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,144,4,30,0,56,150,29,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,64,55,29,0,16,231,28,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,24,225,35,0,176,146,35,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,160,51,35,0,8,236,34,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,120,172,34,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,112,34,0,136,56,34,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,255,255,255,255,0,241,0,0,0,241,2,0,0,241,3,0,8,48,0,0,8,48,2,0,8,48,3,0,8,192,0,0,8,192,2,0,8,192,3,0,8,240,0,0,8,240,2,0,8,240,3,0,0,0,0,0,1,0,2,0,1,0,3,0,0,0,0,0,32,196,32,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,254,1,2,0,0,0,0,144,186,28,0,108,0,0,0,56,5,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,3,0,2,0,4,0,4,0,5,0,5,0,6,0,7,0,38,0,8,0,33,0,8,0,10,0,10,0,29,0,12,0,24,0,12,0,19,0,12,0,16,0,12,0,26,0,13,0,25,0,13,0,24,0,13,0,23,0,13,0,3,0,3,0,6,0,6,0,37,0,8,0,12,0,10,0,27,0,12,0,22,0,13,0,21,0,13,0,5,0,4,0,4,0,7,0,11,0,10,0,20,0,12,0,20,0,13,0,7,0,5,0,36,0,8,0,28,0,12,0,19,0,13,0,6,0,5,0,15,0,10,0,18,0,12,0,7,0,6,0,9,0,10,0,18,0,13,0,5,0,6,0,30,0,12,0,4,0,6,0,21,0,12,0,7,0,7,0,17,0,12,0,5,0,7,0,17,0,13,0,39,0,8,0,16,0,13,0,35,0,8,0,34,0,8,0,32,0,8,0,14,0,10,0,13,0,10,0,8,0,10,0,31,0,12,0,26,0,12,0,25,0,12,0,23,0,12,0,22,0,12,0,31,0,13,0,30,0,13,0,29,0,13,0,28,0,13,0,27,0,13,0,1,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,7,7,8,8,9,9,10,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,1,2,3,4,5,6,7,1,2,3,4,5,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,3,0,0,0,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+975340);
/* memory initializer */ allocate([5,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,200,189,31,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,98,33,0,108,0,0,0,168,235,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,188,0,0,0,0,0,0,225,226,0,0,8,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,12,0,1,0,9,0,0,0,0,0,1,0,10,0,0,0,2,0,0,0,11,0,0,0,2,0,0,0,12,0,0,0,25,0,0,0,13,0,0,0,25,0,0,0,14,0,0,0,25,0,0,0,15,0,0,0,25,0,0,0,16,0,0,0,3,80,1,0,17,0,0,0,2,0,0,0,20,0,0,0,1,0,0,0,22,0,0,0,1,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,224,1,0,0,1,0,0,0,0,2,0,0,1,0,0,0,64,2,0,0,2,0,0,0,96,2,0,0,2,0,0,0,56,4,0,0,4,0,0,0,208,2,0,0,6,0,0,0,117,43,124,141,151,167,73,237,152,94,213,60,140,199,95,132,109,127,94,21,177,208,17,186,145,0,128,95,180,185,126,0,141,212,137,230,118,144,181,70,145,239,115,106,81,0,206,180,255,0,0,0,0,255,0,0,0,128,255,0,0,85,170,255,24,197,32,0,108,0,0,0,32,86,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,42,30,0,0,0,0,0,0,0,8,0,160,41,30,0,24,41,30,0,0,0,4,0,8,0,0,0,66,0,0,0,32,0,0,0,0,0,0,0,0,5,15,10,25,30,20,35,104,128,128,255,0,0,0,0,49,128,128,255,0,0,0,0,200,252,31,0,16,38,31,0,4,0,0,0,4,0,0,0,51,51,51,51,51,51,243,63,82,184,30,133,235,81,224,63,0,0,0,0,0,0,80,64,16,0,1,0,0,0,0,0,176,119,30,0,112,234,29,0,12,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,64,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,194,32,0,108,0,0,0,56,12,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,1,6,5,0,0,0,2,3,1,6,5,0,0,0,15,0,7,11,13,14,3,5,10,12,1,2,4,8,6,9,47,31,15,0,23,27,29,30,7,11,13,14,39,43,45,46,16,3,5,10,12,19,21,26,28,35,37,42,44,1,2,4,8,17,18,20,24,6,9,22,25,32,33,34,36,40,38,41,47,31,15,0,23,27,29,30,7,11,13,14,39,43,45,46,16,3,5,10,12,19,21,26,28,35,37,42,44,1,2,4,8,17,18,20,24,6,9,22,25,32,33,34,36,40,38,41,0,1,2,4,8,3,5,10,12,15,7,11,13,14,6,9,0,16,1,2,4,8,32,3,5,10,12,15,47,7,11,13,14,6,9,31,35,37,42,44,33,34,36,40,39,43,45,46,17,18,20,24,19,21,26,28,23,27,29,30,22,25,38,41,0,16,1,2,4,8,32,3,5,10,12,15,47,7,11,13,14,6,9,31,35,37,42,44,33,34,36,40,39,43,45,46,17,18,20,24,19,21,26,28,23,27,29,30,22,25,38,41,0,0,0,0,1,3,4,6,7,7,7,7,6,4,3,1,0,2,5,7,7,7,7,7,7,5,2,0,0,0,0,0,0,0,0,0,1,2,3,3,3,3,2,1,1,1,2,2,0,1,2,3,3,3,3,2,1,0,0,0,1,2,2,1,16,237,28,0,56,231,35,0,16,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,208,152,35,0,120,57,35,0,208,240,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,152,35,0,152,178,34,0,80,117,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,152,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,103,35,0,108,0,0,0,64,87,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,61,29,0,108,0,0,0,40,14,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,73,70,56,57,97,0,0,71,73,70,56,57,97,0,0,71,73,70,56,55,97,0,0,71,73,70,56,55,97,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,255,255,255,255,2,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,2,78,4,78,5,78,6,78,15,78,18,78,23,78,31,78,32,78,33,78,35,78,38,78,41,78,46,78,47,78,49,78,51,78,53,78,55,78,60,78,64,78,65,78,66,78,68,78,70,78,74,78,81,78,85,78,87,78,90,78,91,78,98,78,99,78,100,78,101,78,103,78,104,78,106,78,107,78,108,78,109,78,110,78,111,78,114,78,116,78,117,78,118,78,119,78,120,78,121,78,122,78,123,78,124,78,125,78,127,78,128,78,129,78,130,78,131,78,132,78,133,78,135,78,138,78,144,78,150,78,151,78,153,78,156,78,157,78,158,78,163,78,170,78,175,78,176,78,177,78,180,78,182,78,183,78,184,78,185,78,188,78,189,78,190,78,200,78,204,78,207,78,208,78,210,78,218,78,219,78,220,78,224,78,226,78,230,78,231,78,233,78,237,78,238,78,239,78,241,78,244,78,248,78,249,78,250,78,252,78,254,78,0,79,2,79,3,79,4,79,5,79,6,79,7,79,8,79,11,79,12,79,18,79,19,79,20,79,21,79,22,79,28,79,29,79,33,79,35,79,40,79,41,79,44,79,45,79,46,79,49,79,51,79,53,79,55,79,57,79,59,79,62,79,63,79,64,79,65,79,66,79,68,79,69,79,71,79,72,79,73,79,74,79,75,79,76,79,82,79,84,79,86,79,97,79,98,79,102,79,104,79,106,79,107,79,109,79,110,79,113,79,114,79,117,79,119,79,120,79,121,79,122,79,125,79,128,79,129,79,130,79,133,79,134,79,135,79,138,79,140,79,142,79,144,79,146,79,147,79,149,79,150,79,152,79,153,79,154,79,156,79,158,79,159,79,161,79,162,79,164,79,171,79,173,79,176,79,177,79,178,79,179,79,180,79,182,79,183,79,184,79,185,79,186,79,187,79,188,79,189,79,190,79,192,79,193,79,194,79,198,79,199,79,200,79,201,79,203,79,204,79,205,79,210,79,211,79,212,79,213,79,214,79,217,79,219,79,224,79,226,79,228,79,229,79,231,79,235,79,236,79,240,79,242,79,244,79,245,79,246,79,247,79,249,79,251,79,252,79,253,79,255,79,0,80,1,80,2,80,3,80,4,80,5,80,6,80,7,80,8,80,9,80,10,80,11,80,14,80,16,80,17,80,19,80,21,80,22,80,23,80,27,80,29,80,30,80,32,80,34,80,35,80,36,80,39,80,43,80,47,80,48,80,49,80,50,80,51,80,52,80,53,80,54,80,55,80,56,80,57,80,59,80,61,80,63,80,64,80,65,80,66,80,68,80,69,80,70,80,73,80,74,80,75,80,77,80,80,80,81,80,82,80,83,80,84,80,86,80,87,80,88,80,89,80,91,80,93,80,94,80,95,80,96,80,97,80,98,80,99,80,100,80,102,80,103,80,104,80,105,80,106,80,107,80,109,80,110,80,111,80,112,80,113,80,114,80,115,80,116,80,117,80,120,80,121,80,122,80,124,80,125,80,129,80,130,80,131,80,132,80,134,80,135,80,137,80,138,80,139,80,140,80,142,80,143,80,144,80,145,80,146,80,147,80,148,80,149,80,150,80,151,80,152,80,153,80,154,80,155,80,156,80,157,80,158,80,159,80,160,80,161,80,162,80,164,80,166,80,170,80,171,80,173,80,174,80,175,80,176,80,177,80,179,80,180,80,181,80,182,80,183,80,184,80,185,80,188,80,189,80,190,80,191,80,192,80,193,80,194,80,195,80,196,80,197,80,198,80,199,80,200,80,201,80,202,80,203,80,204,80,205,80,206,80,208,80,209,80,210,80,211,80,212,80,213,80,215,80,216,80,217,80,219,80,220,80,221,80,222,80,223,80,224,80,225,80,226,80,227,80,228,80,229,80,232,80,233,80,234,80,235,80,239,80,240,80,241,80,242,80,244,80,246,80,247,80,248,80,249,80,250,80,252,80,253,80,254,80,255,80,0,81,1,81,2,81,3,81,4,81,5,81,8,81,9,81,10,81,12,81,13,81,14,81,15,81,16,81,17,81,19,81,20,81,21,81,22,81,23,81,24,81,25,81,26,81,27,81,28,81,29,81,30,81,31,81,32,81,34,81,35,81,36,81,37,81,38,81,39,81,40,81,41,81,42,81,43,81,44,81,45,81,46,81,47,81,48,81,49,81,50,81,51,81,52,81,53,81,54,81,55,81,56,81,57,81,58,81,59,81,60,81,61,81,62,81,66,81,71,81,74,81,76,81,78,81,79,81,80,81,82,81,83,81,87,81,88,81,89,81,91,81,93,81,94,81,95,81,96,81,97,81,99,81,100,81,102,81,103,81,105,81,106,81,111,81,114,81,122,81,126,81,127,81,131,81,132,81,134,81,135,81,138,81,139,81,142,81,143,81,144,81,145,81,147,81,148,81,152,81,154,81,157,81,158,81,159,81,161,81,163,81,166,81,167,81,168,81,169,81,170,81,173,81,174,81,180,81,184,81,185,81,186,81,190,81,191,81,193,81,194,81,195,81,197,81,200,81,202,81,205,81,206,81,208,81,210,81,211,81,212,81,213,81,214,81,215,81,216,81,217,81,218,81,220,81,222,81,223,81,226,81,227,81,229,81,230,81,231,81,232,81,233,81,234,81,236,81,238,81,241,81,242,81,244,81,247,81,254,81,4,82,5,82,9,82,11,82,12,82,15,82,16,82,19,82,20,82,21,82,28,82,30,82,31,82,33,82,34,82,35,82,37,82,38,82,39,82,42,82,44,82,47,82,49,82,50,82,52,82,53,82,60,82,62,82,68,82,69,82,70,82,71,82,72,82,73,82,75,82,78,82,79,82,82,82,83,82,85,82,87,82,88,82,89,82,90,82,91,82,93,82,95,82,96,82,98,82,99,82,100,82,102,82,104,82,107,82,108,82,109,82,110,82,112,82,113,82,115,82,116,82,117,82,118,82,119,82,120,82,121,82,122,82,123,82,124,82,126,82,128,82,131,82,132,82,133,82,134,82,135,82,137,82,138,82,139,82,140,82,141,82,142,82,143,82,145,82,146,82,148,82,149,82,150,82,151,82,152,82,153,82,154,82,156,82,164,82,165,82,166,82,167,82,174,82,175,82,176,82,180,82,181,82,182,82,183,82,184,82,185,82,186,82,187,82,188,82,189,82,192,82,193,82,194,82,196,82,197,82,198,82,200,82,202,82,204,82,205,82,206,82,207,82,209,82,211,82,212,82,213,82,215,82,217,82,218,82,219,82,220,82,221,82,222,82,224,82,225,82,226,82,227,82,229,82,230,82,231,82,232,82,233,82,234,82,235,82,236,82,237,82,238,82,239,82,241,82,242,82,243,82,244,82,245,82,246,82,247,82,248,82,251,82,252,82,253,82,1,83,2,83,3,83,4,83,7,83,9,83,10,83,11,83,12,83,14,83,17,83,18,83,19,83,20,83,24,83,27,83,28,83,30,83,31,83,34,83,36,83,37,83,39,83,40,83,41,83,43,83,44,83,45,83,47,83,48,83,49,83,50,83,51,83,52,83,53,83,54,83,55,83,56,83,60,83,61,83,64,83,66,83,68,83,70,83,75,83,76,83,77,83,80,83,84,83,88,83,89,83,91,83,93,83,101,83,104,83,106,83,108,83,109,83,114,83,118,83,121,83,123,83,124,83,125,83,126,83,128,83,129,83,131,83,135,83,136,83,138,83,142,83,143,83,144,83,145,83,146,83,147,83,148,83,150,83,151,83,153,83,155,83,156,83,158,83,160,83,161,83,164,83,167,83,170,83,171,83,172,83,173,83,175,83,176,83,177,83,178,83,179,83,180,83,181,83,183,83,184,83,185,83,186,83,188,83,189,83,190,83,192,83,195,83,196,83,197,83,198,83,199,83,206,83,207,83,208,83,210,83,211,83,213,83,218,83,220,83,221,83,222,83,225,83,226,83,231,83,244,83,250,83,254,83,255,83,0,84,2,84,5,84,7,84,11,84,20,84,24,84,25,84,26,84,28,84,34,84,36,84,37,84,42,84,48,84,51,84,54,84,55,84,58,84,61,84,63,84,65,84,66,84,68,84,69,84,71,84,73,84,76,84,77,84,78,84,79,84,81,84,90,84,93,84,94,84,95,84,96,84,97,84,99,84,101,84,103,84,105,84,106,84,107,84,108,84,109,84,110,84,111,84,112,84,116,84,121,84,122,84,126,84,127,84,129,84,131,84,133,84,135,84,136,84,137,84,138,84,141,84,145,84,147,84,151,84,152,84,156,84,158,84,159,84,160,84,161,84,162,84,165,84,174,84,176,84,178,84,181,84,182,84,183,84,185,84,186,84,188,84,190,84,195,84,197,84,202,84,203,84,214,84,216,84,219,84,224,84,225,84,226,84,227,84,228,84,235,84,236,84,239,84,240,84,241,84,244,84,245,84,246,84,247,84,248,84,249,84,251,84,254,84,0,85,2,85,3,85,4,85,5,85,8,85,10,85,11,85,12,85,13,85,14,85,18,85,19,85,21,85,22,85,23,85,24,85,25,85,26,85,28,85,29,85,30,85,31,85,33,85,37,85,38,85,40,85,41,85,43,85,45,85,50,85,52,85,53,85,54,85,56,85,57,85,58,85,59,85,61,85,64,85,66,85,69,85,71,85,72,85,75,85,76,85,77,85,78,85,79,85,81,85,82,85,83,85,84,85,87,85,88,85,89,85,90,85,91,85,93,85,94,85,95,85,96,85,98,85,99,85,104,85,105,85,107,85,111,85,112,85,113,85,114,85,115,85,116,85,121,85,122,85,125,85,127,85,133,85,134,85,140,85,141,85,142,85,144,85,146,85,147,85,149,85,150,85,151,85,154,85,155,85,158,85,160,85,161,85,162,85,163,85,164,85,165,85,166,85,168,85,169,85,170,85,171,85,172,85,173,85,174,85,175,85,176,85,178,85,180,85,182,85,184,85,186,85,188,85,191,85,192,85,193,85,194,85,195,85,198,85,199,85,200,85,202,85,203,85,206,85,207,85,208,85,213,85,215,85,216,85,217,85,218,85,219,85,222,85,224,85,226,85,231,85,233,85,237,85,238,85,240,85,241,85,244,85,246,85,248,85,249,85,250,85,251,85,252,85,255,85,2,86,3,86,4,86,5,86,6,86,7,86,10,86,11,86,13,86,16,86,17,86,18,86,19,86,20,86,21,86,22,86,23,86,25,86,26,86,28,86,29,86,32,86,33,86,34,86,37,86,38,86,40,86,41,86,42,86,43,86,46,86,47,86,48,86,51,86,53,86,55,86,56,86,58,86,60,86,61,86,62,86,64,86,65,86,66,86,67,86,68,86,69,86,70,86,71,86,72,86,73,86,74,86,75,86,79,86,80,86,81,86,82,86,83,86,85,86,86,86,90,86,91,86,93,86,94,86,95,86,96,86,97,86,99,86,101,86,102,86,103,86,109,86,110,86,111,86,112,86,114,86,115,86,116,86,117,86,119,86,120,86,121,86,122,86,125,86,126,86,127,86,128,86,129,86,130,86,131,86,132,86,135,86,136,86,137,86,138,86,139,86,140,86,141,86,144,86,145,86,146,86,148,86,149,86,150,86,151,86,152,86,153,86,154,86,155,86,156,86,157,86,158,86,159,86,160,86,161,86,162,86,164,86,165,86,166,86,167,86,168,86,169,86,170,86,171,86,172,86,173,86,174,86,176,86,177,86,178,86,179,86,180,86,181,86,182,86,184,86,185,86,186,86,187,86,189,86,190,86,191,86,192,86,193,86,194,86,195,86,196,86,197,86,198,86,199,86,200,86,201,86,203,86,204,86,205,86,206,86,207,86,208,86,209,86,210,86,211,86,213,86,214,86,216,86,217,86,220,86,227,86,229,86,230,86,231,86,232,86,233,86,234,86,236,86,238,86,239,86,242,86,243,86,246,86,247,86,248,86,251,86,252,86,0,87,1,87,2,87,5,87,7,87,11,87,12,87,13,87,14,87,15,87,16,87,17,87,18,87,19,87,20,87,21,87,22,87,23,87,24,87,25,87,26,87,27,87,29,87,30,87,32,87,33,87,34,87,36,87,37,87,38,87,39,87,43,87,49,87,50,87,52,87,53,87,54,87,55,87,56,87,60,87,61,87,63,87,65,87,67,87,68,87,69,87,70,87,72,87,73,87,75,87,82,87,83,87,84,87,85,87,86,87,88,87,89,87,98,87,99,87,101,87,103,87,108,87,110,87,112,87,113,87,114,87,116,87,117,87,120,87,121,87,122,87,125,87,126,87,127,87,128,87,129,87,135,87,136,87,137,87,138,87,141,87,142,87,143,87,144,87,145,87,148,87,149,87,150,87,151,87,152,87,153,87,154,87,156,87,157,87,158,87,159,87,165,87,168,87,170,87,172,87,175,87,176,87,177,87,179,87,181,87,182,87,183,87,185,87,186,87,187,87,188,87,189,87,190,87,191,87,192,87,193,87,196,87,197,87,198,87,199,87,200,87,201,87,202,87,204,87,205,87,208,87,209,87,211,87,214,87,215,87,219,87,220,87,222,87,225,87,226,87,227,87,229,87,230,87,231,87,232,87,233,87,234,87,235,87,236,87,238,87,240,87,241,87,242,87,243,87,245,87,246,87,247,87,251,87,252,87,254,87,255,87,1,88,3,88,4,88,5,88,8,88,9,88,10,88,12,88,14,88,15,88,16,88,18,88,19,88,20,88,22,88,23,88,24,88,26,88,27,88,28,88,29,88,31,88,34,88,35,88,37,88,38,88,39,88,40,88,41,88,43,88,44,88,45,88,46,88,47,88,49,88,50,88,51,88,52,88,54,88,55,88,56,88,57,88,58,88,59,88,60,88,61,88,62,88,63,88,64,88,65,88,66,88,67,88,69,88,70,88,71,88,72,88,73,88,74,88,75,88,78,88,79,88,80,88,82,88,83,88,85,88,86,88,87,88,89,88,90,88,91,88,92,88,93,88,95,88,96,88,97,88,98,88,99,88,100,88,102,88,103,88,104,88,105,88,106,88,109,88,110,88,111,88,112,88,113,88,114,88,115,88,116,88,117,88,118,88,119,88,120,88,121,88,122,88,123,88,124,88,125,88,127,88,130,88,132,88,134,88,135,88,136,88,138,88,139,88,140,88,141,88,142,88,143,88,144,88,145,88,148,88,149,88,150,88,151,88,152,88,155,88,156,88,157,88,160,88,161,88,162,88,163,88,164,88,165,88,166,88,167,88,170,88,171,88,172,88,173,88,174,88,175,88,176,88,177,88,178,88,179,88,180,88,181,88,182,88,183,88,184,88,185,88,186,88,187,88,189,88,190,88,191,88,192,88,194,88,195,88,196,88,198,88,199,88,200,88,201,88,202,88,203,88,204,88,205,88,206,88,207,88,208,88,210,88,211,88,212,88,214,88,215,88,216,88,217,88,218,88,219,88,220,88,221,88,222,88,223,88,224,88,225,88,226,88,227,88,229,88,230,88,231,88,232,88,233,88,234,88,237,88,239,88,241,88,242,88,244,88,245,88,247,88,248,88,250,88,251,88,252,88,253,88,254,88,255,88,0,89,1,89,3,89,5,89,6,89,8,89,9,89,10,89,11,89,12,89,14,89,16,89,17,89,18,89,19,89,23,89,24,89,27,89,29,89,30,89,32,89,33,89,34,89,35,89,38,89,40,89,44,89,48,89,50,89,51,89,53,89,54,89,59,89,61,89,62,89,63,89,64,89,67,89,69,89,70,89,74,89,76,89,77,89,80,89,82,89,83,89,89,89,91,89,92,89,93,89,94,89,95,89,97,89,99,89,100,89,102,89,103,89,104,89,105,89,106,89,107,89,108,89,109,89,110,89,111,89,112,89,113,89,114,89,117,89,119,89,122,89,123,89,124,89,126,89,127,89,128,89,133,89,137,89,139,89,140,89,142,89,143,89,144,89,145,89,148,89,149,89,152,89,154,89,155,89,156,89,157,89,159,89,160,89,161,89,162,89,166,89,167,89,172,89,173,89,176,89,177,89,179,89,180,89,181,89,182,89,183,89,184,89,186,89,188,89,189,89,191,89,192,89,193,89,194,89,195,89,196,89,197,89,199,89,200,89,201,89,204,89,205,89,206,89,207,89,213,89,214,89,217,89,219,89,222,89,223,89,224,89,225,89,226,89,228,89,230,89,231,89,233,89,234,89,235,89,237,89,238,89,239,89,240,89,241,89,242,89,243,89,244,89,245,89,246,89,247,89,248,89,250,89,252,89,253,89,254,89,0,90,2,90,10,90,11,90,13,90,14,90,15,90,16,90,18,90,20,90,21,90,22,90,23,90,25,90,26,90,27,90,29,90,30,90,33,90,34,90,36,90,38,90,39,90,40,90,42,90,43,90,44,90,45,90,46,90,47,90,48,90,51,90,53,90,55,90,56,90,57,90,58,90,59,90,61,90,62,90,63,90,65,90,66,90,67,90,68,90,69,90,71,90,72,90,75,90,76,90,77,90,78,90,79,90,80,90,81,90,82,90,83,90,84,90,86,90,87,90,88,90,89,90,91,90,92,90,93,90,94,90,95,90,96,90,97,90,99,90,100,90,101,90,102,90,104,90,105,90,107,90,108,90,109,90,110,90,111,90,112,90,113,90,114,90,115,90,120,90,121,90,123,90,124,90,125,90,126,90,128,90,129,90,130,90,131,90,132,90,133,90,134,90,135,90,136,90,137,90,138,90,139,90,140,90,141,90,142,90,143,90,144,90,145,90,147,90,148,90,149,90,150,90,151,90,152,90,153,90,156,90,157,90,158,90,159,90,160,90,161,90,162,90,163,90,164,90,165,90,166,90,167,90,168,90,169,90,171,90,172,90,173,90,174,90,175,90,176,90,177,90,180,90,182,90,183,90,185,90,186,90,187,90,188,90,189,90,191,90,192,90,195,90,196,90,197,90,198,90,199,90,200,90,202,90,203,90,205,90,206,90,207,90,208,90,209,90,211,90,213,90,215,90,217,90,218,90,219,90,221,90,222,90,223,90,226,90,228,90,229,90,231,90,232,90,234,90,236,90,237,90,238,90,239,90,240,90,242,90,243,90,244,90,245,90,246,90,247,90,248,90,249,90,250,90,251,90,252,90,253,90,254,90,255,90,0,91,1,91,2,91,3,91,4,91,5,91,6,91,7,91,8,91,10,91,11,91,12,91,13,91,14,91,15,91,16,91,17,91,18,91,19,91,20,91,21,91,24,91,25,91,26,91,27,91,28,91,29,91,30,91,31,91,32,91,33,91,34,91,35,91,36,91,37,91,38,91,39,91,40,91,41,91,42,91,43,91,44,91,45,91,46,91,47,91,48,91,49,91,51,91,53,91,54,91,56,91,57,91,58,91,59,91,60,91,61,91,62,91,63,91,65,91,66,91,67,91,68,91,69,91,70,91,71,91,72,91,73,91,74,91,75,91,76,91,77,91,78,91,79,91,82,91,86,91,94,91,96,91,97,91,103,91,104,91,107,91,109,91,110,91,111,91,114,91,116,91,118,91,119,91,120,91,121,91,123,91,124,91,126,91,127,91,130,91,134,91,138,91,141,91,142,91,144,91,145,91,146,91,148,91,150,91,159,91,167,91,168,91,169,91,172,91,173,91,174,91,175,91,177,91,178,91,183,91,186,91,187,91,188,91,192,91,193,91,195,91,200,91,201,91,202,91,203,91,205,91,206,91,207,91,209,91,212,91,213,91,214,91,215,91,216,91,217,91,218,91,219,91,220,91,224,91,226,91,227,91,230,91,231,91,233,91,234,91,235,91,236,91,237,91,239,91,241,91,242,91,243,91,244,91,245,91,246,91,247,91,253,91,254,91,0,92,2,92,3,92,5,92,7,92,8,92,11,92,12,92,13,92,14,92,16,92,18,92,19,92,23,92,25,92,27,92,30,92,31,92,32,92,33,92,35,92,38,92,40,92,41,92,42,92,43,92,45,92,46,92,47,92,48,92,50,92,51,92,53,92,54,92,55,92,67,92,68,92,70,92,71,92,76,92,77,92,82,92,83,92,84,92,86,92,87,92,88,92,90,92,91,92,92,92,93,92,95,92,98,92,100,92,103,92,104,92,105,92,106,92,107,92,108,92,109,92,112,92,114,92,115,92,116,92,117,92,118,92,119,92,120,92,123,92,124,92,125,92,126,92,128,92,131,92,132,92,133,92,134,92,135,92,137,92,138,92,139,92,142,92,143,92,146,92,147,92,149,92,157,92,158,92,159,92,160,92,161,92,164,92,165,92,166,92,167,92,168,92,170,92,174,92,175,92,176,92,178,92,180,92,182,92,185,92,186,92,187,92,188,92,190,92,192,92,194,92,195,92,197,92,198,92,199,92,200,92,201,92,202,92,204,92,205,92,206,92,207,92,208,92,209,92,211,92,212,92,213,92,214,92,215,92,216,92,218,92,219,92,220,92,221,92,222,92,223,92,224,92,226,92,227,92,231,92,233,92,235,92,236,92,238,92,239,92,241,92,242,92,243,92,244,92,245,92,246,92,247,92,248,92,249,92,250,92,252,92,253,92,254,92,255,92,0,93,1,93,4,93,5,93,8,93,9,93,10,93,11,93,12,93,13,93,15,93,16,93,17,93,18,93,19,93,21,93,23,93,24,93,25,93,26,93,28,93,29,93,31,93,32,93,33,93,34,93,35,93,37,93,40,93,42,93,43,93,44,93,47,93,48,93,49,93,50,93,51,93,53,93,54,93,55,93,56,93,57,93,58,93,59,93,60,93,63,93,64,93,65,93,66,93,67,93,68,93,69,93,70,93,72,93,73,93,77,93,78,93,79,93,80,93,81,93,82,93,83,93,84,93,85,93,86,93,87,93,89,93,90,93,92,93,94,93,95,93,96,93,97,93,98,93,99,93,100,93,101,93,102,93,103,93,104,93,106,93,109,93,110,93,112,93,113,93,114,93,115,93,117,93,118,93,119,93,120,93,121,93,122,93,123,93,124,93,125,93,126,93,127,93,128,93,129,93,131,93,132,93,133,93,134,93,135,93,136,93,137,93,138,93,139,93,140,93,141,93,142,93,143,93,144,93,145,93,146,93,147,93,148,93,149,93,150,93,151,93,152,93,154,93,155,93,156,93,158,93,159,93,160,93,161,93,162,93,163,93,164,93,165,93,166,93,167,93,168,93,169,93,170,93,171,93,172,93,173,93,174,93,175,93,176,93,177,93,178,93,179,93,180,93,181,93,182,93,184,93,185,93,186,93,187,93,188,93,189,93,190,93,191,93,192,93,193,93,194,93,195,93,196,93,198,93,199,93,200,93,201,93,202,93,203,93,204,93,206,93,207,93,208,93,209,93,210,93,211,93,212,93,213,93,214,93,215,93,216,93,217,93,218,93,220,93,223,93,224,93,227,93,228,93,234,93,236,93,237,93,240,93,245,93,246,93,248,93,249,93,250,93,251,93,252,93,255,93,0,94,4,94,7,94,9,94,10,94,11,94,13,94,14,94,18,94,19,94,23,94,30,94,31,94,32,94,33,94,34,94,35,94,36,94,37,94,40,94,41,94,42,94,43,94,44,94,47,94,48,94,50,94,51,94,52,94,53,94,54,94,57,94,58,94,62,94,63,94,64,94,65,94,67,94,70,94,71,94,72,94,73,94,74,94,75,94,77,94,78,94,79,94,80,94,81,94,82,94,83,94,86,94,87,94,88,94,89,94,90,94,92,94,93,94,95,94,96,94,99,94,100,94,101,94,102,94,103,94,104,94,105,94,106,94,107,94,108,94,109,94,110,94,111,94,112,94,113,94,117,94,119,94,121,94,126,94,129,94,130,94,131,94,133,94,136,94,137,94,140,94,141,94,142,94,146,94,152,94,155,94,157,94,161,94,162,94,163,94,164,94,168,94,169,94,170,94,171,94,172,94,174,94,175,94,176,94,177,94,178,94,180,94,186,94,187,94,188,94,189,94,191,94,192,94,193,94,194,94,195,94,196,94,197,94,198,94,199,94,200,94,203,94,204,94,205,94,206,94,207,94,208,94,212,94,213,94,215,94,216,94,217,94,218,94,220,94,221,94,222,94,223,94,224,94,225,94,226,94,227,94,228,94,229,94,230,94,231,94,233,94,235,94,236,94,237,94,238,94,239,94,240,94,241,94,242,94,243,94,245,94,248,94,249,94,251,94,252,94,253,94,5,95,6,95,7,95,9,95,12,95,13,95,14,95,16,95,18,95,20,95,22,95,25,95,26,95,28,95,29,95,30,95,33,95,34,95,35,95,36,95,40,95,43,95,44,95,46,95,48,95,50,95,51,95,52,95,53,95,54,95,55,95,56,95,59,95,61,95,62,95,63,95,65,95,66,95,67,95,68,95,69,95,70,95,71,95,72,95,73,95,74,95,75,95,76,95,77,95,78,95,79,95,81,95,84,95,89,95,90,95,91,95,92,95,94,95,95,95,96,95,99,95,101,95,103,95,104,95,107,95,110,95,111,95,114,95,116,95,117,95,118,95,120,95,122,95,125,95,126,95,127,95,131,95,134,95,141,95,142,95,143,95,145,95,147,95,148,95,150,95,154,95,155,95,157,95,158,95,159,95,160,95,162,95,163,95,164,95,165,95,166,95,167,95,169,95,171,95,172,95,175,95,176,95,177,95,178,95,179,95,180,95,182,95,184,95,185,95,186,95,187,95,190,95,191,95,192,95,193,95,194,95,199,95,200,95,202,95,203,95,206,95,211,95,212,95,213,95,218,95,219,95,220,95,222,95,223,95,226,95,227,95,229,95,230,95,232,95,233,95,236,95,239,95,240,95,242,95,243,95,244,95,246,95,247,95,249,95,250,95,252,95,7,96,8,96,9,96,11,96,12,96,16,96,17,96,19,96,23,96,24,96,26,96,30,96,31,96,34,96,35,96,36,96,44,96,45,96,46,96,48,96,49,96,50,96,51,96,52,96,54,96,55,96,56,96,57,96,58,96,61,96,62,96,64,96,68,96,69,96,70,96,71,96,72,96,73,96,74,96,76,96,78,96,79,96,81,96,83,96,84,96,86,96,87,96,88,96,91,96,92,96,94,96,95,96,96,96,97,96,101,96,102,96,110,96,113,96,114,96,116,96,117,96,119,96,126,96,128,96,129,96,130,96,133,96,134,96,135,96,136,96,138,96,139,96,142,96,143,96,144,96,145,96,147,96,149,96,151,96,152,96,153,96,156,96,158,96,161,96,162,96,164,96,165,96,167,96,169,96,170,96,174,96,176,96,179,96,181,96,182,96,183,96,185,96,186,96,189,96,190,96,191,96,192,96,193,96,194,96,195,96,196,96,199,96,200,96,201,96,204,96,205,96,206,96,207,96,208,96,210,96,211,96,212,96,214,96,215,96,217,96,219,96,222,96,225,96,226,96,227,96,228,96,229,96,234,96,241,96,242,96,245,96,247,96,248,96,251,96,252,96,253,96,254,96,255,96,2,97,3,97,4,97,5,97,7,97,10,97,11,97,12,97,16,97,17,97,18,97,19,97,20,97,22,97,23,97,24,97,25,97,27,97,28,97,29,97,30,97,33,97,34,97,37,97,40,97,41,97,42,97,44,97,45,97,46,97,47,97,48,97,49,97,50,97,51,97,52,97,53,97,54,97,55,97,56,97,57,97,58,97,59,97,60,97,61,97,62,97,64,97,65,97,66,97,67,97,68,97,69,97,70,97,71,97,73,97,75,97,77,97,79,97,80,97,82,97,83,97,84,97,86,97,87,97,88,97,89,97,90,97,91,97,92,97,94,97,95,97,96,97,97,97,99,97,100,97,101,97,102,97,105,97,106,97,107,97,108,97,109,97,110,97,111,97,113,97,114,97,115,97,116,97,118,97,120,97,121,97,122,97,123,97,124,97,125,97,126,97,127,97,128,97,129,97,130,97,131,97,132,97,133,97,134,97,135,97,136,97,137,97,138,97,140,97,141,97,143,97,144,97,145,97,146,97,147,97,149,97,150,97,151,97,152,97,153,97,154,97,155,97,156,97,158,97,159,97,160,97,161,97,162,97,163,97,164,97,165,97,166,97,170,97,171,97,173,97,174,97,175,97,176,97,177,97,178,97,179,97,180,97,181,97,182,97,184,97,185,97,186,97,187,97,188,97,189,97,191,97,192,97,193,97,195,97,196,97,197,97,198,97,199,97,201,97,204,97,205,97,206,97,207,97,208,97,211,97,213,97,214,97,215,97,216,97,217,97,218,97,219,97,220,97,221,97,222,97,223,97,224,97,225,97,226,97,227,97,228,97,229,97,231,97,232,97,233,97,234,97,235,97,236,97,237,97,238,97,239,97,240,97,241,97,242,97,243,97,244,97,246,97,247,97,248,97,249,97,250,97,251,97,252,97,253,97,254,97,0,98,1,98,2,98,3,98,4,98,5,98,7,98,9,98,19,98,20,98,25,98,28,98,29,98,30,98,32,98,35,98,38,98,39,98,40,98,41,98,43,98,45,98,47,98,48,98,49,98,50,98,53,98,54,98,56,98,57,98,58,98,59,98,60,98,66,98,68,98,69,98,70,98,74,98,79,98,80,98,85,98,86,98,87,98,89,98,90,98,92,98,93,98,94,98,95,98,96,98,97,98,98,98,100,98,101,98,104,98,113,98,114,98,116,98,117,98,119,98,120,98,122,98,123,98,125,98,129,98,130,98,131,98,133,98,134,98,135,98,136,98,139,98,140,98,141,98,142,98,143,98,144,98,148,98,153,98,156,98,157,98,158,98,163,98,166,98,167,98,169,98,170,98,173,98,174,98,175,98,176,98,178,98,179,98,180,98,182,98,183,98,184,98,186,98,190,98,192,98,193,98,195,98,203,98,207,98,209,98,213,98,221,98,222,98,224,98,225,98,228,98,234,98,235,98,240,98,242,98,245,98,248,98,249,98,250,98,251,98,0,99,3,99,4,99,5,99,6,99,10,99,11,99,12,99,13,99,15,99,16,99,18,99,19,99,20,99,21,99,23,99,24,99,25,99,28,99,38,99,39,99,41,99,44,99,45,99,46,99,48,99,49,99,51,99,52,99,53,99,54,99,55,99,56,99,59,99,60,99,62,99,63,99,64,99,65,99,68,99,71,99,72,99,74,99,81,99,82,99,83,99,84,99,86,99,87,99,88,99,89,99,90,99,91,99,92,99,93,99,96,99,100,99,101,99,102,99,104,99,106,99,107,99,108,99,111,99,112,99,114,99,115,99,116,99,117,99,120,99,121,99,124,99,125,99,126,99,127,99,129,99,131,99,132,99,133,99,134,99,139,99,141,99,145,99,147,99,148,99,149,99,151,99,153,99,154,99,155,99,156,99,157,99,158,99,159,99,161,99,164,99,166,99,171,99,175,99,177,99,178,99,181,99,182,99,185,99,187,99,189,99,191,99,192,99,193,99,194,99,195,99,197,99,199,99,200,99,202,99,203,99,204,99,209,99,211,99,212,99,213,99,215,99,216,99,217,99,218,99,219,99,220,99,221,99,223,99,226,99,228,99,229,99,230,99,231,99,232,99,235,99,236,99,238,99,239,99,240,99,241,99,243,99,245,99,247,99,249,99,250,99,251,99,252,99,254,99,3,100,4,100,6,100,7,100,8,100,9,100,10,100,13,100,14,100,17,100,18,100,21,100,22,100,23,100,24,100,25,100,26,100,29,100,31,100,34,100,35,100,36,100,37,100,39,100,40,100,41,100,43,100,46,100,47,100,48,100,49,100,50,100,51,100,53,100,54,100,55,100,56,100,57,100,59,100,60,100,62,100,64,100,66,100,67,100,73,100,75,100,76,100,77,100,78,100,79,100,80,100,81,100,83,100,85,100,86,100,87,100,89,100,90,100,91,100,92,100,93,100,95,100,96,100,97,100,98,100,99,100,100,100,101,100,102,100,104,100,106,100,107,100,108,100,110,100,111,100,112,100,113,100,114,100,115,100,116,100,117,100,118,100,119,100,123,100,124,100,125,100,126,100,127,100,128,100,129,100,131,100,134,100,136,100,137,100,138,100,139,100,140,100,141,100,142,100,143,100,144,100,147,100,148,100,151,100,152,100,154,100,155,100,156,100,157,100,159,100,160,100,161,100,162,100,163,100,165,100,166,100,167,100,168,100,170,100,171,100,175,100,177,100,178,100,179,100,180,100,182,100,185,100,187,100,189,100,190,100,191,100,193,100,195,100,196,100,198,100,199,100,200,100,201,100,202,100,203,100,204,100,207,100,209,100,211,100,212,100,213,100,214,100,217,100,218,100,219,100,220,100,221,100,223,100,224,100,225,100,227,100,229,100,231,100,232,100,233,100,234,100,235,100,236,100,237,100,238,100,239,100,240,100,241,100,242,100,243,100,244,100,245,100,246,100,247,100,248,100,249,100,250,100,251,100,252,100,253,100,254,100,255,100,1,101,2,101,3,101,4,101,5,101,6,101,7,101,8,101,10,101,11,101,12,101,13,101,14,101,15,101,16,101,17,101,19,101,20,101,21,101,22,101,23,101,25,101,26,101,27,101,28,101,29,101,30,101,31,101,32,101,33,101,34,101,35,101,36,101,38,101,39,101,40,101,41,101,42,101,44,101,45,101,48,101,49,101,50,101,51,101,55,101,58,101,60,101,61,101,64,101,65,101,66,101,67,101,68,101,70,101,71,101,74,101,75,101,77,101,78,101,80,101,82,101,83,101,84,101,87,101,88,101,90,101,92,101,95,101,96,101,97,101,100,101,101,101,103,101,104,101,105,101,106,101,109,101,110,101,111,101,113,101,115,101,117,101,118,101,120,101,121,101,122,101,123,101,124,101,125,101,126,101,127,101,128,101,129,101,130,101,131,101,132,101,133,101,134,101,136,101,137,101,138,101,141,101,142,101,143,101,146,101,148,101,149,101,150,101,152,101,154,101,157,101,158,101,160,101,162,101,163,101,166,101,168,101,170,101,172,101,174,101,177,101,178,101,179,101,180,101,181,101,182,101,183,101,184,101,186,101,187,101,190,101,191,101,192,101,194,101,199,101,200,101,201,101,202,101,205,101,208,101,209,101,211,101,212,101,213,101,216,101,217,101,218,101,219,101,220,101,221,101,222,101,223,101,225,101,227,101,228,101,234,101,235,101,242,101,243,101,244,101,245,101,248,101,249,101,251,101,252,101,253,101,254,101,255,101,1,102,4,102,5,102,7,102,8,102,9,102,11,102,13,102,16,102,17,102,18,102,22,102,23,102,24,102,26,102,27,102,28,102,30,102,33,102,34,102,35,102,36,102,38,102,41,102,42,102,43,102,44,102,46,102,48,102,50,102,51,102,55,102,56,102,57,102,58,102,59,102,61,102,63,102,64,102,66,102,68,102,69,102,70,102,71,102,72,102,73,102,74,102,77,102,78,102,80,102,81,102,88,102,89,102,91,102,92,102,93,102,94,102,96,102,98,102,99,102,101,102,103,102,105,102,106,102,107,102,108,102,109,102,113,102,114,102,115,102,117,102,120,102,121,102,123,102,124,102,125,102,127,102,128,102,129,102,131,102,133,102,134,102,136,102,137,102,138,102,139,102,141,102,142,102,143,102,144,102,146,102,147,102,148,102,149,102,152,102,153,102,154,102,155,102,156,102,158,102,159,102,160,102,161,102,162,102,163,102,164,102,165,102,166,102,169,102,170,102,171,102,172,102,173,102,175,102,176,102,177,102,178,102,179,102,181,102,182,102,183,102,184,102,186,102,187,102,188,102,189,102,191,102,192,102,193,102,194,102,195,102,196,102,197,102,198,102,199,102,200,102,201,102,202,102,203,102,204,102,205,102,206,102,207,102,208,102,209,102,210,102,211,102,212,102,213,102,214,102,215,102,216,102,218,102,222,102,223,102,224,102,225,102,226,102,227,102,228,102,229,102,231,102,232,102,234,102,235,102,236,102,237,102,238,102,239,102,241,102,245,102,246,102,248,102,250,102,251,102,253,102,1,103,2,103,3,103,4,103,5,103,6,103,7,103,12,103,14,103,15,103,17,103,18,103,19,103,22,103,24,103,25,103,26,103,28,103,30,103,32,103,33,103,34,103,35,103,36,103,37,103,39,103,41,103,46,103,48,103,50,103,51,103,54,103,55,103,56,103,57,103,59,103,60,103,62,103,63,103,65,103,68,103,69,103,71,103,74,103,75,103,77,103,82,103,84,103,85,103,87,103,88,103,89,103,90,103,91,103,93,103,98,103,99,103,100,103,102,103,103,103,107,103,108,103,110,103,113,103,116,103,118,103,120,103,121,103,122,103,123,103,125,103,128,103,130,103,131,103,133,103,134,103,136,103,138,103,140,103,141,103,142,103,143,103,145,103,146,103,147,103,148,103,150,103,153,103,155,103,159,103,160,103,161,103,164,103,166,103,169,103,172,103,174,103,177,103,178,103,180,103,185,103,186,103,187,103,188,103,189,103,190,103,191,103,192,103,194,103,197,103,198,103,199,103,200,103,201,103,202,103,203,103,204,103,205,103,206,103,213,103,214,103,215,103,219,103,223,103,225,103,227,103,228,103,230,103,231,103,232,103,234,103,235,103,237,103,238,103,242,103,245,103,246,103,247,103,248,103,249,103,250,103,251,103,252,103,254,103,1,104,2,104,3,104,4,104,6,104,13,104,16,104,18,104,20,104,21,104,24,104,25,104,26,104,27,104,28,104,30,104,31,104,32,104,34,104,35,104,36,104,37,104,38,104,39,104,40,104,43,104,44,104,45,104,46,104,47,104,48,104,49,104,52,104,53,104,54,104,58,104,59,104,63,104,71,104,75,104,77,104,79,104,82,104,86,104,87,104,88,104,89,104,90,104,91,104,92,104,93,104,94,104,95,104,106,104,108,104,109,104,110,104,111,104,112,104,113,104,114,104,115,104,117,104,120,104,121,104,122,104,123,104,124,104,125,104,126,104,127,104,128,104,130,104,132,104,135,104,136,104,137,104,138,104,139,104,140,104,141,104,142,104,144,104,145,104,146,104,148,104,149,104,150,104,152,104,153,104,154,104,155,104,156,104,157,104,158,104,159,104,160,104,161,104,163,104,164,104,165,104,169,104,170,104,171,104,172,104,174,104,177,104,178,104,180,104,182,104,183,104,184,104,185,104,186,104,187,104,188,104,189,104,190,104,191,104,193,104,195,104,196,104,197,104,198,104,199,104,200,104,202,104,204,104,206,104,207,104,208,104,209,104,211,104,212,104,214,104,215,104,217,104,219,104,220,104,221,104,222,104,223,104,225,104,226,104,228,104,229,104,230,104,231,104,232,104,233,104,234,104,235,104,236,104,237,104,239,104,242,104,243,104,244,104,246,104,247,104,248,104,251,104,253,104,254,104,255,104,0,105,2,105,3,105,4,105,6,105,7,105,8,105,9,105,10,105,12,105,15,105,17,105,19,105,20,105,21,105,22,105,23,105,24,105,25,105,26,105,27,105,28,105,29,105,30,105,33,105,34,105,35,105,37,105,38,105,39,105,40,105,41,105,42,105,43,105,44,105,46,105,47,105,49,105,50,105,51,105,53,105,54,105,55,105,56,105,58,105,59,105,60,105,62,105,64,105,65,105,67,105,68,105,69,105,70,105,71,105,72,105,73,105,74,105,75,105,76,105,77,105,78,105,79,105,80,105,81,105,82,105,83,105,85,105,86,105,88,105,89,105,91,105,92,105,95,105,97,105,98,105,100,105,101,105,103,105,104,105,105,105,106,105,108,105,109,105,111,105,112,105,114,105,115,105,116,105,117,105], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+985580);
/* memory initializer */ allocate([118,105,122,105,123,105,125,105,126,105,127,105,129,105,131,105,133,105,138,105,139,105,140,105,142,105,143,105,144,105,145,105,146,105,147,105,150,105,151,105,153,105,154,105,157,105,158,105,159,105,160,105,161,105,162,105,163,105,164,105,165,105,166,105,169,105,170,105,172,105,174,105,175,105,176,105,178,105,179,105,181,105,182,105,184,105,185,105,186,105,188,105,189,105,190,105,191,105,192,105,194,105,195,105,196,105,197,105,198,105,199,105,200,105,201,105,203,105,205,105,207,105,209,105,210,105,211,105,213,105,214,105,215,105,216,105,217,105,218,105,220,105,221,105,222,105,225,105,226,105,227,105,228,105,229,105,230,105,231,105,232,105,233,105,234,105,235,105,236,105,238,105,239,105,240,105,241,105,243,105,244,105,245,105,246,105,247,105,248,105,249,105,250,105,251,105,252,105,254,105,0,106,1,106,2,106,3,106,4,106,5,106,6,106,7,106,8,106,9,106,11,106,12,106,13,106,14,106,15,106,16,106,17,106,18,106,19,106,20,106,21,106,22,106,25,106,26,106,27,106,28,106,29,106,30,106,32,106,34,106,35,106,36,106,37,106,38,106,39,106,41,106,43,106,44,106,45,106,46,106,48,106,50,106,51,106,52,106,54,106,55,106,56,106,57,106,58,106,59,106,60,106,63,106,64,106,65,106,66,106,67,106,69,106,70,106,72,106,73,106,74,106,75,106,76,106,77,106,78,106,79,106,81,106,82,106,83,106,84,106,85,106,86,106,87,106,90,106,92,106,93,106,94,106,95,106,96,106,98,106,99,106,100,106,102,106,103,106,104,106,105,106,106,106,107,106,108,106,109,106,110,106,111,106,112,106,114,106,115,106,116,106,117,106,118,106,119,106,120,106,122,106,123,106,125,106,126,106,127,106,129,106,130,106,131,106,133,106,134,106,135,106,136,106,137,106,138,106,139,106,140,106,141,106,143,106,146,106,147,106,148,106,149,106,150,106,152,106,153,106,154,106,155,106,156,106,157,106,158,106,159,106,161,106,162,106,163,106,164,106,165,106,166,106,167,106,168,106,170,106,173,106,174,106,175,106,176,106,177,106,178,106,179,106,180,106,181,106,182,106,183,106,184,106,185,106,186,106,187,106,188,106,189,106,190,106,191,106,192,106,193,106,194,106,195,106,196,106,197,106,198,106,199,106,200,106,201,106,202,106,203,106,204,106,205,106,206,106,207,106,208,106,209,106,210,106,211,106,212,106,213,106,214,106,215,106,216,106,217,106,218,106,219,106,220,106,221,106,222,106,223,106,224,106,225,106,226,106,227,106,228,106,229,106,230,106,231,106,232,106,233,106,234,106,235,106,236,106,237,106,238,106,239,106,240,106,241,106,242,106,243,106,244,106,245,106,246,106,247,106,248,106,249,106,250,106,251,106,252,106,253,106,254,106,255,106,0,107,1,107,2,107,3,107,4,107,5,107,6,107,7,107,8,107,9,107,10,107,11,107,12,107,13,107,14,107,15,107,16,107,17,107,18,107,19,107,20,107,21,107,22,107,23,107,24,107,25,107,26,107,27,107,28,107,29,107,30,107,31,107,37,107,38,107,40,107,41,107,42,107,43,107,44,107,45,107,46,107,47,107,48,107,49,107,51,107,52,107,53,107,54,107,56,107,59,107,60,107,61,107,63,107,64,107,65,107,66,107,68,107,69,107,72,107,74,107,75,107,77,107,78,107,79,107,80,107,81,107,82,107,83,107,84,107,85,107,86,107,87,107,88,107,90,107,91,107,92,107,93,107,94,107,95,107,96,107,97,107,104,107,105,107,107,107,108,107,109,107,110,107,111,107,112,107,113,107,114,107,115,107,116,107,117,107,118,107,119,107,120,107,122,107,125,107,126,107,127,107,128,107,133,107,136,107,140,107,142,107,143,107,144,107,145,107,148,107,149,107,151,107,152,107,153,107,156,107,157,107,158,107,159,107,160,107,162,107,163,107,164,107,165,107,166,107,167,107,168,107,169,107,171,107,172,107,173,107,174,107,175,107,176,107,177,107,178,107,182,107,184,107,185,107,186,107,187,107,188,107,189,107,190,107,192,107,195,107,196,107,198,107,199,107,200,107,201,107,202,107,204,107,206,107,208,107,209,107,216,107,218,107,220,107,221,107,222,107,223,107,224,107,226,107,227,107,228,107,229,107,230,107,231,107,232,107,233,107,236,107,237,107,238,107,240,107,241,107,242,107,244,107,246,107,247,107,248,107,250,107,251,107,252,107,254,107,255,107,0,108,1,108,2,108,3,108,4,108,8,108,9,108,10,108,11,108,12,108,14,108,18,108,23,108,28,108,29,108,30,108,32,108,35,108,37,108,43,108,44,108,45,108,49,108,51,108,54,108,55,108,57,108,58,108,59,108,60,108,62,108,63,108,67,108,68,108,69,108,72,108,75,108,76,108,77,108,78,108,79,108,81,108,82,108,83,108,86,108,88,108,89,108,90,108,98,108,99,108,101,108,102,108,103,108,107,108,108,108,109,108,110,108,111,108,113,108,115,108,117,108,119,108,120,108,122,108,123,108,124,108,127,108,128,108,132,108,135,108,138,108,139,108,141,108,142,108,145,108,146,108,149,108,150,108,151,108,152,108,154,108,156,108,157,108,158,108,160,108,162,108,168,108,172,108,175,108,176,108,180,108,181,108,182,108,183,108,186,108,192,108,193,108,194,108,195,108,198,108,199,108,200,108,203,108,205,108,206,108,207,108,209,108,210,108,216,108,217,108,218,108,220,108,221,108,223,108,228,108,230,108,231,108,233,108,236,108,237,108,242,108,244,108,249,108,255,108,0,109,2,109,3,109,5,109,6,109,8,109,9,109,10,109,13,109,15,109,16,109,17,109,19,109,20,109,21,109,22,109,24,109,28,109,29,109,31,109,32,109,33,109,34,109,35,109,36,109,38,109,40,109,41,109,44,109,45,109,47,109,48,109,52,109,54,109,55,109,56,109,58,109,63,109,64,109,66,109,68,109,73,109,76,109,80,109,85,109,86,109,87,109,88,109,91,109,93,109,95,109,97,109,98,109,100,109,101,109,103,109,104,109,107,109,108,109,109,109,112,109,113,109,114,109,115,109,117,109,118,109,121,109,122,109,123,109,125,109,126,109,127,109,128,109,129,109,131,109,132,109,134,109,135,109,138,109,139,109,141,109,143,109,144,109,146,109,150,109,151,109,152,109,153,109,154,109,156,109,162,109,165,109,172,109,173,109,176,109,177,109,179,109,180,109,182,109,183,109,185,109,186,109,187,109,188,109,189,109,190,109,193,109,194,109,195,109,200,109,201,109,202,109,205,109,206,109,207,109,208,109,210,109,211,109,212,109,213,109,215,109,218,109,219,109,220,109,223,109,226,109,227,109,229,109,231,109,232,109,233,109,234,109,237,109,239,109,240,109,242,109,244,109,245,109,246,109,248,109,250,109,253,109,254,109,255,109,0,110,1,110,2,110,3,110,4,110,6,110,7,110,8,110,9,110,11,110,15,110,18,110,19,110,21,110,24,110,25,110,27,110,28,110,30,110,31,110,34,110,38,110,39,110,40,110,42,110,44,110,46,110,48,110,49,110,51,110,53,110,54,110,55,110,57,110,59,110,60,110,61,110,62,110,63,110,64,110,65,110,66,110,69,110,70,110,71,110,72,110,73,110,74,110,75,110,76,110,79,110,80,110,81,110,82,110,85,110,87,110,89,110,90,110,92,110,93,110,94,110,96,110,97,110,98,110,99,110,100,110,101,110,102,110,103,110,104,110,105,110,106,110,108,110,109,110,111,110,112,110,113,110,114,110,115,110,116,110,117,110,118,110,119,110,120,110,121,110,122,110,123,110,124,110,125,110,128,110,129,110,130,110,132,110,135,110,136,110,138,110,139,110,140,110,141,110,142,110,145,110,146,110,147,110,148,110,149,110,150,110,151,110,153,110,154,110,155,110,157,110,158,110,160,110,161,110,163,110,164,110,166,110,168,110,169,110,171,110,172,110,173,110,174,110,176,110,179,110,181,110,184,110,185,110,188,110,190,110,191,110,192,110,195,110,196,110,197,110,198,110,200,110,201,110,202,110,204,110,205,110,206,110,208,110,210,110,214,110,216,110,217,110,219,110,220,110,221,110,227,110,231,110,234,110,235,110,236,110,237,110,238,110,239,110,240,110,241,110,242,110,243,110,245,110,246,110,247,110,248,110,250,110,251,110,252,110,253,110,254,110,255,110,0,111,1,111,3,111,4,111,5,111,7,111,8,111,10,111,11,111,12,111,13,111,14,111,16,111,17,111,18,111,22,111,23,111,24,111,25,111,26,111,27,111,28,111,29,111,30,111,31,111,33,111,34,111,35,111,37,111,38,111,39,111,40,111,44,111,46,111,48,111,50,111,52,111,53,111,55,111,56,111,57,111,58,111,59,111,60,111,61,111,63,111,64,111,65,111,66,111,67,111,68,111,69,111,72,111,73,111,74,111,76,111,78,111,79,111,80,111,81,111,82,111,83,111,84,111,85,111,86,111,87,111,89,111,90,111,91,111,93,111,95,111,96,111,97,111,99,111,100,111,101,111,103,111,104,111,105,111,106,111,107,111,108,111,111,111,112,111,113,111,115,111,117,111,118,111,119,111,121,111,123,111,125,111,126,111,127,111,128,111,129,111,130,111,131,111,133,111,134,111,135,111,138,111,139,111,143,111,144,111,145,111,146,111,147,111,148,111,149,111,150,111,151,111,152,111,153,111,154,111,155,111,157,111,158,111,159,111,160,111,162,111,163,111,164,111,165,111,166,111,168,111,169,111,170,111,171,111,172,111,173,111,174,111,175,111,176,111,177,111,178,111,180,111,181,111,183,111,184,111,186,111,187,111,188,111,189,111,190,111,191,111,193,111,195,111,196,111,197,111,198,111,199,111,200,111,202,111,203,111,204,111,205,111,206,111,207,111,208,111,211,111,212,111,213,111,214,111,215,111,216,111,217,111,218,111,219,111,220,111,221,111,223,111,226,111,227,111,228,111,229,111,230,111,231,111,232,111,233,111,234,111,235,111,236,111,237,111,240,111,241,111,242,111,243,111,244,111,245,111,246,111,247,111,248,111,249,111,250,111,251,111,252,111,253,111,254,111,255,111,0,112,1,112,2,112,3,112,4,112,5,112,6,112,7,112,8,112,9,112,10,112,11,112,12,112,13,112,14,112,15,112,16,112,18,112,19,112,20,112,21,112,22,112,23,112,24,112,25,112,28,112,29,112,30,112,31,112,32,112,33,112,34,112,36,112,37,112,38,112,39,112,40,112,41,112,42,112,43,112,44,112,45,112,46,112,47,112,48,112,49,112,50,112,51,112,52,112,54,112,55,112,56,112,58,112,59,112,60,112,61,112,62,112,63,112,64,112,65,112,66,112,67,112,68,112,69,112,70,112,71,112,72,112,73,112,74,112,75,112,77,112,78,112,80,112,81,112,82,112,83,112,84,112,85,112,86,112,87,112,88,112,89,112,90,112,91,112,92,112,93,112,95,112,96,112,97,112,98,112,99,112,100,112,101,112,102,112,103,112,104,112,105,112,106,112,110,112,113,112,114,112,115,112,116,112,119,112,121,112,122,112,123,112,125,112,129,112,130,112,131,112,132,112,134,112,135,112,136,112,139,112,140,112,141,112,143,112,144,112,145,112,147,112,151,112,152,112,154,112,155,112,158,112,159,112,160,112,161,112,162,112,163,112,164,112,165,112,166,112,167,112,168,112,169,112,170,112,176,112,178,112,180,112,181,112,182,112,186,112,190,112,191,112,196,112,197,112,198,112,199,112,201,112,203,112,204,112,205,112,206,112,207,112,208,112,209,112,210,112,211,112,212,112,213,112,214,112,215,112,218,112,220,112,221,112,222,112,224,112,225,112,226,112,227,112,229,112,234,112,238,112,240,112,241,112,242,112,243,112,244,112,245,112,246,112,248,112,250,112,251,112,252,112,254,112,255,112,0,113,1,113,2,113,3,113,4,113,5,113,6,113,7,113,8,113,11,113,12,113,13,113,14,113,15,113,17,113,18,113,20,113,23,113,27,113,28,113,29,113,30,113,31,113,32,113,33,113,34,113,35,113,36,113,37,113,39,113,40,113,41,113,42,113,43,113,44,113,45,113,46,113,50,113,51,113,52,113,53,113,55,113,56,113,57,113,58,113,59,113,60,113,61,113,62,113,63,113,64,113,65,113,66,113,67,113,68,113,70,113,71,113,72,113,73,113,75,113,77,113,79,113,80,113,81,113,82,113,83,113,84,113,85,113,86,113,87,113,88,113,89,113,90,113,91,113,93,113,95,113,96,113,97,113,98,113,99,113,101,113,105,113,106,113,107,113,108,113,109,113,111,113,112,113,113,113,116,113,117,113,118,113,119,113,121,113,123,113,124,113,126,113,127,113,128,113,129,113,130,113,131,113,133,113,134,113,135,113,136,113,137,113,139,113,140,113,141,113,142,113,144,113,145,113,146,113,147,113,149,113,150,113,151,113,154,113,155,113,156,113,157,113,158,113,161,113,162,113,163,113,164,113,165,113,166,113,167,113,169,113,170,113,171,113,173,113,174,113,175,113,176,113,177,113,178,113,180,113,182,113,183,113,184,113,186,113,187,113,188,113,189,113,190,113,191,113,192,113,193,113,194,113,196,113,197,113,198,113,199,113,200,113,201,113,202,113,203,113,204,113,205,113,207,113,208,113,209,113,210,113,211,113,214,113,215,113,216,113,217,113,218,113,219,113,220,113,221,113,222,113,223,113,225,113,226,113,227,113,228,113,230,113,232,113,233,113,234,113,235,113,236,113,237,113,239,113,240,113,241,113,242,113,243,113,244,113,245,113,246,113,247,113,248,113,250,113,251,113,252,113,253,113,254,113,255,113,0,114,1,114,2,114,3,114,4,114,5,114,7,114,8,114,9,114,10,114,11,114,12,114,13,114,14,114,15,114,16,114,17,114,18,114,19,114,20,114,21,114,22,114,23,114,24,114,25,114,26,114,27,114,28,114,30,114,31,114,32,114,33,114,34,114,35,114,36,114,37,114,38,114,39,114,41,114,43,114,45,114,46,114,47,114,50,114,51,114,52,114,58,114,60,114,62,114,64,114,65,114,66,114,67,114,68,114,69,114,70,114,73,114,74,114,75,114,78,114,79,114,80,114,81,114,83,114,84,114,85,114,87,114,88,114,90,114,92,114,94,114,96,114,99,114,100,114,101,114,104,114,106,114,107,114,108,114,109,114,112,114,113,114,115,114,116,114,118,114,119,114,120,114,123,114,124,114,125,114,130,114,131,114,133,114,134,114,135,114,136,114,137,114,140,114,142,114,144,114,145,114,147,114,148,114,149,114,150,114,151,114,152,114,153,114,154,114,155,114,156,114,157,114,158,114,160,114,161,114,162,114,163,114,164,114,165,114,166,114,167,114,168,114,169,114,170,114,171,114,174,114,177,114,178,114,179,114,181,114,186,114,187,114,188,114,189,114,190,114,191,114,192,114,197,114,198,114,199,114,201,114,202,114,203,114,204,114,207,114,209,114,211,114,212,114,213,114,214,114,216,114,218,114,219,114,198,228,199,228,200,228,201,228,202,228,203,228,204,228,205,228,206,228,207,228,208,228,209,228,210,228,211,228,212,228,213,228,214,228,215,228,216,228,217,228,218,228,219,228,220,228,221,228,222,228,223,228,224,228,225,228,226,228,227,228,228,228,229,228,230,228,231,228,232,228,233,228,234,228,235,228,236,228,237,228,238,228,239,228,240,228,241,228,242,228,243,228,244,228,245,228,246,228,247,228,248,228,249,228,250,228,251,228,252,228,253,228,254,228,255,228,0,229,1,229,2,229,3,229,4,229,5,229,6,229,7,229,8,229,9,229,10,229,11,229,12,229,13,229,14,229,15,229,16,229,17,229,18,229,19,229,20,229,21,229,22,229,23,229,24,229,25,229,26,229,27,229,28,229,29,229,30,229,31,229,32,229,33,229,34,229,35,229,36,229,37,229,0,48,1,48,2,48,183,0,201,2,199,2,168,0,3,48,5,48,20,32,94,255,22,32,38,32,24,32,25,32,28,32,29,32,20,48,21,48,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,22,48,23,48,16,48,17,48,177,0,215,0,247,0,54,34,39,34,40,34,17,34,15,34,42,34,41,34,8,34,55,34,26,34,165,34,37,34,32,34,18,35,153,34,43,34,46,34,97,34,76,34,72,34,61,34,29,34,96,34,110,34,111,34,100,34,101,34,30,34,53,34,52,34,66,38,64,38,176,0,50,32,51,32,3,33,4,255,164,0,224,255,225,255,48,32,167,0,22,33,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,59,32,146,33,144,33,145,33,147,33,19,48,38,229,39,229,40,229,41,229,42,229,43,229,44,229,45,229,46,229,47,229,48,229,49,229,50,229,51,229,52,229,53,229,54,229,55,229,56,229,57,229,58,229,59,229,60,229,61,229,62,229,63,229,64,229,65,229,66,229,67,229,68,229,69,229,70,229,71,229,72,229,73,229,74,229,75,229,76,229,77,229,78,229,79,229,80,229,81,229,82,229,83,229,84,229,85,229,86,229,87,229,88,229,89,229,90,229,91,229,92,229,93,229,94,229,95,229,96,229,97,229,98,229,99,229,100,229,101,229,102,229,103,229,104,229,105,229,106,229,107,229,108,229,109,229,110,229,111,229,112,229,113,229,114,229,115,229,116,229,117,229,118,229,119,229,120,229,121,229,122,229,123,229,124,229,125,229,126,229,127,229,128,229,129,229,130,229,131,229,132,229,133,229,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,102,231,103,231,104,231,105,231,106,231,107,231,136,36,137,36,138,36,139,36,140,36,141,36,142,36,143,36,144,36,145,36,146,36,147,36,148,36,149,36,150,36,151,36,152,36,153,36,154,36,155,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,126,36,127,36,128,36,129,36,130,36,131,36,132,36,133,36,134,36,135,36,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,172,32,109,231,32,50,33,50,34,50,35,50,36,50,37,50,38,50,39,50,40,50,41,50,110,231,111,231,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,106,33,107,33,112,231,113,231,134,229,135,229,136,229,137,229,138,229,139,229,140,229,141,229,142,229,143,229,144,229,145,229,146,229,147,229,148,229,149,229,150,229,151,229,152,229,153,229,154,229,155,229,156,229,157,229,158,229,159,229,160,229,161,229,162,229,163,229,164,229,165,229,166,229,167,229,168,229,169,229,170,229,171,229,172,229,173,229,174,229,175,229,176,229,177,229,178,229,179,229,180,229,181,229,182,229,183,229,184,229,185,229,186,229,187,229,188,229,189,229,190,229,191,229,192,229,193,229,194,229,195,229,196,229,197,229,198,229,199,229,200,229,201,229,202,229,203,229,204,229,205,229,206,229,207,229,208,229,209,229,210,229,211,229,212,229,213,229,214,229,215,229,216,229,217,229,218,229,219,229,220,229,221,229,222,229,223,229,224,229,225,229,226,229,227,229,228,229,229,229,1,255,2,255,3,255,229,255,5,255,6,255,7,255,8,255,9,255,10,255,11,255,12,255,13,255,14,255,15,255,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,26,255,27,255,28,255,29,255,30,255,31,255,32,255,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,59,255,60,255,61,255,62,255,63,255,64,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,91,255,92,255,93,255,227,255,230,229,231,229,232,229,233,229,234,229,235,229,236,229,237,229,238,229,239,229,240,229,241,229,242,229,243,229,244,229,245,229,246,229,247,229,248,229,249,229,250,229,251,229,252,229,253,229,254,229,255,229,0,230,1,230,2,230,3,230,4,230,5,230,6,230,7,230,8,230,9,230,10,230,11,230,12,230,13,230,14,230,15,230,16,230,17,230,18,230,19,230,20,230,21,230,22,230,23,230,24,230,25,230,26,230,27,230,28,230,29,230,30,230,31,230,32,230,33,230,34,230,35,230,36,230,37,230,38,230,39,230,40,230,41,230,42,230,43,230,44,230,45,230,46,230,47,230,48,230,49,230,50,230,51,230,52,230,53,230,54,230,55,230,56,230,57,230,58,230,59,230,60,230,61,230,62,230,63,230,64,230,65,230,66,230,67,230,68,230,69,230,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,114,231,115,231,116,231,117,231,118,231,119,231,120,231,121,231,122,231,123,231,124,231,70,230,71,230,72,230,73,230,74,230,75,230,76,230,77,230,78,230,79,230,80,230,81,230,82,230,83,230,84,230,85,230,86,230,87,230,88,230,89,230,90,230,91,230,92,230,93,230,94,230,95,230,96,230,97,230,98,230,99,230,100,230,101,230,102,230,103,230,104,230,105,230,106,230,107,230,108,230,109,230,110,230,111,230,112,230,113,230,114,230,115,230,116,230,117,230,118,230,119,230,120,230,121,230,122,230,123,230,124,230,125,230,126,230,127,230,128,230,129,230,130,230,131,230,132,230,133,230,134,230,135,230,136,230,137,230,138,230,139,230,140,230,141,230,142,230,143,230,144,230,145,230,146,230,147,230,148,230,149,230,150,230,151,230,152,230,153,230,154,230,155,230,156,230,157,230,158,230,159,230,160,230,161,230,162,230,163,230,164,230,165,230,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,125,231,126,231,127,231,128,231,129,231,130,231,131,231,132,231,166,230,167,230,168,230,169,230,170,230,171,230,172,230,173,230,174,230,175,230,176,230,177,230,178,230,179,230,180,230,181,230,182,230,183,230,184,230,185,230,186,230,187,230,188,230,189,230,190,230,191,230,192,230,193,230,194,230,195,230,196,230,197,230,198,230,199,230,200,230,201,230,202,230,203,230,204,230,205,230,206,230,207,230,208,230,209,230,210,230,211,230,212,230,213,230,214,230,215,230,216,230,217,230,218,230,219,230,220,230,221,230,222,230,223,230,224,230,225,230,226,230,227,230,228,230,229,230,230,230,231,230,232,230,233,230,234,230,235,230,236,230,237,230,238,230,239,230,240,230,241,230,242,230,243,230,244,230,245,230,246,230,247,230,248,230,249,230,250,230,251,230,252,230,253,230,254,230,255,230,0,231,1,231,2,231,3,231,4,231,5,231,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,133,231,134,231,135,231,136,231,137,231,138,231,139,231,140,231,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,141,231,142,231,143,231,144,231,145,231,146,231,147,231,53,254,54,254,57,254,58,254,63,254,64,254,61,254,62,254,65,254,66,254,67,254,68,254,148,231,149,231,59,254,60,254,55,254,56,254,49,254,150,231,51,254,52,254,151,231,152,231,153,231,154,231,155,231,156,231,157,231,158,231,159,231,6,231,7,231,8,231,9,231,10,231,11,231,12,231,13,231,14,231,15,231,16,231,17,231,18,231,19,231,20,231,21,231,22,231,23,231,24,231,25,231,26,231,27,231,28,231,29,231,30,231,31,231,32,231,33,231,34,231,35,231,36,231,37,231,38,231,39,231,40,231,41,231,42,231,43,231,44,231,45,231,46,231,47,231,48,231,49,231,50,231,51,231,52,231,53,231,54,231,55,231,56,231,57,231,58,231,59,231,60,231,61,231,62,231,63,231,64,231,65,231,66,231,67,231,68,231,69,231,70,231,71,231,72,231,73,231,74,231,75,231,76,231,77,231,78,231,79,231,80,231,81,231,82,231,83,231,84,231,85,231,86,231,87,231,88,231,89,231,90,231,91,231,92,231,93,231,94,231,95,231,96,231,97,231,98,231,99,231,100,231,101,231,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,160,231,161,231,162,231,163,231,164,231,165,231,166,231,167,231,168,231,169,231,170,231,171,231,172,231,173,231,174,231,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,175,231,176,231,177,231,178,231,179,231,180,231,181,231,182,231,183,231,184,231,185,231,186,231,187,231,202,2,203,2,217,2,19,32,21,32,37,32,53,32,5,33,9,33,150,33,151,33,152,33,153,33,21,34,31,34,35,34,82,34,102,34,103,34,191,34,80,37,81,37,82,37,83,37,84,37,85,37,86,37,87,37,88,37,89,37,90,37,91,37,92,37,93,37,94,37,95,37,96,37,97,37,98,37,99,37,100,37,101,37,102,37,103,37,104,37,105,37,106,37,107,37,108,37,109,37,110,37,111,37,112,37,113,37,114,37,115,37,129,37,130,37,131,37,132,37,133,37,134,37,135,37,136,37,137,37,138,37,139,37,140,37,141,37,142,37,143,37,147,37,148,37,149,37,188,37,189,37,226,37,227,37,228,37,229,37,9,38,149,34,18,48,29,48,30,48,188,231,189,231,190,231,191,231,192,231,193,231,194,231,195,231,196,231,197,231,198,231,1,1,225,0,206,1,224,0,19,1,233,0,27,1,232,0,43,1,237,0,208,1,236,0,77,1,243,0,210,1,242,0,107,1,250,0,212,1,249,0,214,1,216,1,218,1,220,1,252,0,234,0,81,2,199,231,68,1,72,1,249,1,97,2,201,231,202,231,203,231,204,231,5,49,6,49,7,49,8,49,9,49,10,49,11,49,12,49,13,49,14,49,15,49,16,49,17,49,18,49,19,49,20,49,21,49,22,49,23,49,24,49,25,49,26,49,27,49,28,49,29,49,30,49,31,49,32,49,33,49,34,49,35,49,36,49,37,49,38,49,39,49,40,49,41,49,205,231,206,231,207,231,208,231,209,231,210,231,211,231,212,231,213,231,214,231,215,231,216,231,217,231,218,231,219,231,220,231,221,231,222,231,223,231,224,231,225,231,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,163,50,142,51,143,51,156,51,157,51,158,51,161,51,196,51,206,51,209,51,210,51,213,51,48,254,226,255,228,255,226,231,33,33,49,50,227,231,16,32,228,231,229,231,230,231,252,48,155,48,156,48,253,48,254,48,6,48,157,48,158,48,73,254,74,254,75,254,76,254,77,254,78,254,79,254,80,254,81,254,82,254,84,254,85,254,86,254,87,254,89,254,90,254,91,254,92,254,93,254,94,254,95,254,96,254,97,254,98,254,99,254,100,254,101,254,102,254,104,254,105,254,106,254,107,254,62,48,240,47,241,47,242,47,243,47,244,47,245,47,246,47,247,47,248,47,249,47,250,47,251,47,7,48,244,231,245,231,246,231,247,231,248,231,249,231,250,231,251,231,252,231,253,231,254,231,255,231,0,232,0,37,1,37,2,37,3,37,4,37,5,37,6,37,7,37,8,37,9,37,10,37,11,37,12,37,13,37,14,37,15,37,16,37,17,37,18,37,19,37,20,37,21,37,22,37,23,37,24,37,25,37,26,37,27,37,28,37,29,37,30,37,31,37,32,37,33,37,34,37,35,37,36,37,37,37,38,37,39,37,40,37,41,37,42,37,43,37,44,37,45,37,46,37,47,37,48,37,49,37,50,37,51,37,52,37,53,37,54,37,55,37,56,37,57,37,58,37,59,37,60,37,61,37,62,37,63,37,64,37,65,37,66,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,75,37,1,232,2,232,3,232,4,232,5,232,6,232,7,232,8,232,9,232,10,232,11,232,12,232,13,232,14,232,15,232,220,114,221,114,223,114,226,114,227,114,228,114,229,114,230,114,231,114,234,114,235,114,245,114,246,114,249,114,253,114,254,114,255,114,0,115,2,115,4,115,5,115,6,115,7,115,8,115,9,115,11,115,12,115,13,115,15,115,16,115,17,115,18,115,20,115,24,115,25,115,26,115,31,115,32,115,35,115,36,115,38,115,39,115,40,115,45,115,47,115,48,115,50,115,51,115,53,115,54,115,58,115,59,115,60,115,61,115,64,115,65,115,66,115,67,115,68,115,69,115,70,115,71,115,72,115,73,115,74,115,75,115,76,115,78,115,79,115,81,115,83,115,84,115,85,115,86,115,88,115,89,115,90,115,91,115,92,115,93,115,94,115,95,115,97,115,98,115,99,115,100,115,101,115,102,115,103,115,104,115,105,115,106,115,107,115,110,115,112,115,113,115,0,224,1,224,2,224,3,224,4,224,5,224,6,224,7,224,8,224,9,224,10,224,11,224,12,224,13,224,14,224,15,224,16,224,17,224,18,224,19,224,20,224,21,224,22,224,23,224,24,224,25,224,26,224,27,224,28,224,29,224,30,224,31,224,32,224,33,224,34,224,35,224,36,224,37,224,38,224,39,224,40,224,41,224,42,224,43,224,44,224,45,224,46,224,47,224,48,224,49,224,50,224,51,224,52,224,53,224,54,224,55,224,56,224,57,224,58,224,59,224,60,224,61,224,62,224,63,224,64,224,65,224,66,224,67,224,68,224,69,224,70,224,71,224,72,224,73,224,74,224,75,224,76,224,77,224,78,224,79,224,80,224,81,224,82,224,83,224,84,224,85,224,86,224,87,224,88,224,89,224,90,224,91,224,92,224,93,224,114,115,115,115,116,115,117,115,118,115,119,115,120,115,121,115,122,115,123,115,124,115,125,115,127,115,128,115,129,115,130,115,131,115,133,115,134,115,136,115,138,115,140,115,141,115,143,115,144,115,146,115,147,115,148,115,149,115,151,115,152,115,153,115,154,115,156,115,157,115,158,115,160,115,161,115,163,115,164,115,165,115,166,115,167,115,168,115,170,115,172,115,173,115,177,115,180,115,181,115,182,115,184,115,185,115,188,115,189,115,190,115,191,115,193,115,195,115,196,115,197,115,198,115,199,115,203,115,204,115,206,115,210,115,211,115,212,115,213,115,214,115,215,115,216,115,218,115,219,115,220,115,221,115,223,115,225,115,226,115,227,115,228,115,230,115,232,115,234,115,235,115,236,115,238,115,239,115,240,115,241,115,243,115,244,115,245,115,246,115,247,115,94,224,95,224,96,224,97,224,98,224,99,224,100,224,101,224,102,224,103,224,104,224,105,224,106,224,107,224,108,224,109,224,110,224,111,224,112,224,113,224,114,224,115,224,116,224,117,224,118,224,119,224,120,224,121,224,122,224,123,224,124,224,125,224,126,224,127,224,128,224,129,224,130,224,131,224,132,224,133,224,134,224,135,224,136,224,137,224,138,224,139,224,140,224,141,224,142,224,143,224,144,224,145,224,146,224,147,224,148,224,149,224,150,224,151,224,152,224,153,224,154,224,155,224,156,224,157,224,158,224,159,224,160,224,161,224,162,224,163,224,164,224,165,224,166,224,167,224,168,224,169,224,170,224,171,224,172,224,173,224,174,224,175,224,176,224,177,224,178,224,179,224,180,224,181,224,182,224,183,224,184,224,185,224,186,224,187,224,248,115,249,115,250,115,251,115,252,115,253,115,254,115,255,115,0,116,1,116,2,116,4,116,7,116,8,116,11,116,12,116,13,116,14,116,17,116,18,116,19,116,20,116,21,116,22,116,23,116,24,116,25,116,28,116,29,116,30,116,31,116,32,116,33,116,35,116,36,116,39,116,41,116,43,116,45,116,47,116,49,116,50,116,55,116,56,116,57,116,58,116,59,116,61,116,62,116,63,116,64,116,66,116,67,116,68,116,69,116,70,116,71,116,72,116,73,116,74,116,75,116,76,116,77,116,78,116,79,116,80,116,81,116,82,116,83,116,84,116,86,116,88,116,93,116,96,116,97,116,98,116,99,116,100,116,101,116,102,116,103,116,104,116,105,116,106,116,107,116,108,116,110,116,111,116,113,116,114,116,115,116,116,116,117,116,120,116,121,116,122,116,188,224,189,224,190,224,191,224,192,224,193,224,194,224,195,224,196,224,197,224,198,224,199,224,200,224,201,224,202,224,203,224,204,224,205,224,206,224,207,224,208,224,209,224,210,224,211,224,212,224,213,224,214,224,215,224,216,224,217,224,218,224,219,224,220,224,221,224,222,224,223,224,224,224,225,224,226,224,227,224,228,224,229,224,230,224,231,224,232,224,233,224,234,224,235,224,236,224,237,224,238,224,239,224,240,224,241,224,242,224,243,224,244,224,245,224,246,224,247,224,248,224,249,224,250,224,251,224,252,224,253,224,254,224,255,224,0,225,1,225,2,225,3,225,4,225,5,225,6,225,7,225,8,225,9,225,10,225,11,225,12,225,13,225,14,225,15,225,16,225,17,225,18,225,19,225,20,225,21,225,22,225,23,225,24,225,25,225,123,116,124,116,125,116,127,116,130,116,132,116,133,116,134,116,136,116,137,116,138,116,140,116,141,116,143,116,145,116,146,116,147,116,148,116,149,116,150,116,151,116,152,116,153,116,154,116,155,116,157,116,159,116,160,116,161,116,162,116,163,116,164,116,165,116,166,116,170,116,171,116,172,116,173,116,174,116,175,116,176,116,177,116,178,116,179,116,180,116,181,116,182,116,183,116,184,116,185,116,187,116,188,116,189,116,190,116,191,116,192,116,193,116,194,116,195,116,196,116,197,116,198,116,199,116,200,116,201,116,202,116,203,116,204,116,205,116,206,116,207,116,208,116,209,116,211,116,212,116,213,116,214,116,215,116,216,116,217,116,218,116,219,116,221,116,223,116,225,116,229,116,231,116,232,116,233,116,234,116,235,116,236,116,237,116,240,116,241,116,242,116,26,225,27,225,28,225,29,225,30,225,31,225,32,225,33,225,34,225,35,225,36,225,37,225,38,225,39,225,40,225,41,225,42,225,43,225,44,225,45,225,46,225,47,225,48,225,49,225,50,225,51,225,52,225,53,225,54,225,55,225,56,225,57,225,58,225,59,225,60,225,61,225,62,225,63,225,64,225,65,225,66,225,67,225,68,225,69,225,70,225,71,225,72,225,73,225,74,225,75,225,76,225,77,225,78,225,79,225,80,225,81,225,82,225,83,225,84,225,85,225,86,225,87,225,88,225,89,225,90,225,91,225,92,225,93,225,94,225,95,225,96,225,97,225,98,225,99,225,100,225,101,225,102,225,103,225,104,225,105,225,106,225,107,225,108,225,109,225,110,225,111,225,112,225,113,225,114,225,115,225,116,225,117,225,118,225,119,225,243,116,245,116,248,116,249,116,250,116,251,116,252,116,253,116,254,116,0,117,1,117,2,117,3,117,5,117,6,117,7,117,8,117,9,117,10,117,11,117,12,117,14,117,16,117,18,117,20,117,21,117,22,117,23,117,27,117,29,117,30,117,32,117,33,117,34,117,35,117,36,117,38,117,39,117,42,117,46,117,52,117,54,117,57,117,60,117,61,117,63,117,65,117,66,117,67,117,68,117,70,117,71,117,73,117,74,117,77,117,80,117,81,117,82,117,83,117,85,117,86,117,87,117,88,117,93,117,94,117,95,117,96,117,97,117,98,117,99,117,100,117,103,117,104,117,105,117,107,117,108,117,109,117,110,117,111,117,112,117,113,117,115,117,117,117,118,117,119,117,122,117,123,117,124,117,125,117,126,117,128,117,129,117,130,117,132,117,133,117,135,117,120,225,121,225,122,225,123,225,124,225,125,225,126,225,127,225,128,225,129,225,130,225,131,225,132,225,133,225,134,225,135,225,136,225,137,225,138,225,139,225,140,225,141,225,142,225,143,225,144,225,145,225,146,225,147,225,148,225,149,225,150,225,151,225,152,225,153,225,154,225,155,225,156,225,157,225,158,225,159,225,160,225,161,225,162,225,163,225,164,225,165,225,166,225,167,225,168,225,169,225,170,225,171,225,172,225,173,225,174,225,175,225,176,225,177,225,178,225,179,225,180,225,181,225,182,225,183,225,184,225,185,225,186,225,187,225,188,225,189,225,190,225,191,225,192,225,193,225,194,225,195,225,196,225,197,225,198,225,199,225,200,225,201,225,202,225,203,225,204,225,205,225,206,225,207,225,208,225,209,225,210,225,211,225,212,225,213,225,136,117,137,117,138,117,140,117,141,117,142,117,144,117,147,117,149,117,152,117,155,117,156,117,158,117,162,117,166,117,167,117,168,117,169,117,170,117,173,117,182,117,183,117,186,117,187,117,191,117,192,117,193,117,198,117,203,117,204,117,206,117,207,117,208,117,209,117,211,117,215,117,217,117,218,117,220,117,221,117,223,117,224,117,225,117,229,117,233,117,236,117,237,117,238,117,239,117,242,117,243,117,245,117,246,117,247,117,248,117,250,117,251,117,253,117,254,117,2,118,4,118,6,118,7,118,8,118,9,118,11,118,13,118,14,118,15,118,17,118,18,118,19,118,20,118,22,118,26,118,28,118,29,118,30,118,33,118,35,118,39,118,40,118,44,118,46,118,47,118,49,118,50,118,54,118,55,118,57,118,58,118,59,118,61,118,65,118,66,118,68,118,214,225,215,225,216,225,217,225,218,225,219,225,220,225,221,225,222,225,223,225,224,225,225,225,226,225,227,225,228,225,229,225,230,225,231,225,232,225,233,225,234,225,235,225,236,225,237,225,238,225,239,225,240,225,241,225,242,225,243,225,244,225,245,225,246,225,247,225,248,225,249,225,250,225,251,225,252,225,253,225,254,225,255,225,0,226,1,226,2,226,3,226,4,226,5,226,6,226,7,226,8,226,9,226,10,226,11,226,12,226,13,226,14,226,15,226,16,226,17,226,18,226,19,226,20,226,21,226,22,226,23,226,24,226,25,226,26,226,27,226,28,226,29,226,30,226,31,226,32,226,33,226,34,226,35,226,36,226,37,226,38,226,39,226,40,226,41,226,42,226,43,226,44,226,45,226,46,226,47,226,48,226,49,226,50,226,51,226,69,118,70,118,71,118,72,118,73,118,74,118,75,118,78,118,79,118,80,118,81,118,82,118,83,118,85,118,87,118,88,118,89,118,90,118,91,118,93,118,95,118,96,118,97,118,98,118,100,118,101,118,102,118,103,118,104,118,105,118,106,118,108,118,109,118,110,118,112,118,113,118,114,118,115,118,116,118,117,118,118,118,119,118,121,118,122,118,124,118,127,118,128,118,129,118,131,118,133,118,137,118,138,118,140,118,141,118,143,118,144,118,146,118,148,118,149,118,151,118,152,118,154,118,155,118,156,118,157,118,158,118,159,118,160,118,161,118,162,118,163,118,165,118,166,118,167,118,168,118,169,118,170,118,171,118,172,118,173,118,175,118,176,118,179,118,181,118,182,118,183,118,184,118,185,118,186,118,187,118,188,118,189,118,190,118,192,118,193,118,195,118,74,85,63,150,195,87,40,99,206,84,9,85,192,84,145,118,76,118,60,133,238,119,126,130,141,120,49,114,152,150,141,151,40,108,137,91,250,79,9,99,151,102,184,92,250,128,72,104,174,128,2,102,206,118,249,81,86,101,172,113,241,127,132,136,178,80,101,89,202,97,179,111,173,130,76,99,82,98,237,83,39,84,6,123,107,81,164,117,244,93,212,98,203,141,118,151,138,98,25,128,93,87,56,151,98,127,56,114,125,118,207,103,126,118,70,100,112,79,37,141,220,98,23,122,145,101,237,115,44,100,115,98,44,130,129,152,127,103,72,114,110,98,204,98,52,79,227,116,74,83,158,82,202,126,166,144,46,94,134,104,156,105,128,129,209,126,210,104,197,120,140,134,81,149,141,80,36,140,222,130,222,128,5,83,18,137,101,82,196,118,199,118,201,118,203,118,204,118,211,118,213,118,217,118,218,118,220,118,221,118,222,118,224,118,225,118,226,118,227,118,228,118,230,118,231,118,232,118,233,118,234,118,235,118,236,118,237,118,240,118,243,118,245,118,246,118,247,118,250,118,251,118,253,118,255,118,0,119,2,119,3,119,5,119,6,119,10,119,12,119,14,119,15,119,16,119,17,119,18,119,19,119,20,119,21,119,22,119,23,119,24,119,27,119,28,119,29,119,30,119,33,119,35,119,36,119,37,119,39,119,42,119,43,119,44,119,46,119,48,119,49,119,50,119,51,119,52,119,57,119,59,119,61,119,62,119,63,119,66,119,68,119,69,119,70,119,72,119,73,119,74,119,75,119,76,119,77,119,78,119,79,119,82,119,83,119,84,119,85,119,86,119,87,119,88,119,89,119,92,119,132,133,249,150,221,79,33,88,113,153,157,91,177,98,165,98,180,102,121,140,141,156,6,114,111,103,145,120,178,96,81,83,23,83,136,143,204,128,29,141,161,148,13,80,200,114,7,89,235,96,25,113,171,136,84,89,239,130,44,103,40,123,41,93,247,126,45,117,245,108,102,142,248,143,60,144,59,159,212,107,25,145,20,123,124,95,167,120,214,132,61,133,213,107,217,107,214,107,1,94,135,94,249,117,237,149,93,101,10,95,197,95,159,143,193,88,194,129,127,144,91,150,173,151,185,143,22,127,44,141,65,98,191,79,216,83,94,83,168,143,169,143,171,143,77,144,7,104,106,95,152,129,104,136,214,156,139,97,43,82,42,118,108,95,140,101,210,111,232,110,190,91,72,100,117,81,176,81,196,103,25,78,201,121,124,153,179,112,93,119,94,119,95,119,96,119,100,119,103,119,105,119,106,119,109,119,110,119,111,119,112,119,113,119,114,119,115,119,116,119,117,119,118,119,119,119,120,119,122,119,123,119,124,119,129,119,130,119,131,119,134,119,135,119,136,119,137,119,138,119,139,119,143,119,144,119,147,119,148,119,149,119,150,119,151,119,152,119,153,119,154,119,155,119,156,119,157,119,158,119,161,119,163,119,164,119,166,119,168,119,171,119,173,119,174,119,175,119,177,119,178,119,180,119,182,119,183,119,184,119,185,119,186,119,188,119,190,119,192,119,193,119,194,119,195,119,196,119,197,119,198,119,199,119,200,119,201,119,202,119,203,119,204,119,206,119,207,119,208,119,209,119,210,119,211,119,212,119,213,119,214,119,216,119,217,119,218,119,221,119,222,119,223,119,224,119,225,119,228,119,197,117,118,94,187,115,224,131,173,100,232,98,181,148,226,108,90,83,195,82,15,100,194,148,148,123,47,79,27,94,54,130,22,129,138,129,36,110,202,108,115,154,85,99,92,83,250,84,101,136,224,87,13,78,3,94,101,107,63,124,232,144,22,96,230,100,28,115,193,136,80,103,77,98,34,141,108,119,41,142,199,145,105,95,220,131,33,133,16,153,194,83,149,134,139,107,237,96,232,96,127,112,205,130,49,130,211,78,167,108,207,133,205,100,217,124,253,105,249,102,73,131,149,83,86,123,167,79,140,81,75,109,66,92,109,142,210,99,201,83,44,131,54,131,229,103,180,120,61,100,223,91,148,92,238,93,231,139,198,98,244,103,122,140,0,100,186,99,73,135,139,153,23,140,32,127,242,148,167,78,16,150,164,152,12,102,22,115,230,119,232,119,234,119,239,119,240,119,241,119], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+995820);
/* memory initializer */ allocate([242,119,244,119,245,119,247,119,249,119,250,119,251,119,252,119,3,120,4,120,5,120,6,120,7,120,8,120,10,120,11,120,14,120,15,120,16,120,19,120,21,120,25,120,27,120,30,120,32,120,33,120,34,120,36,120,40,120,42,120,43,120,46,120,47,120,49,120,50,120,51,120,53,120,54,120,61,120,63,120,65,120,66,120,67,120,68,120,70,120,72,120,73,120,74,120,75,120,77,120,79,120,81,120,83,120,84,120,88,120,89,120,90,120,91,120,92,120,94,120,95,120,96,120,97,120,98,120,99,120,100,120,101,120,102,120,103,120,104,120,105,120,111,120,112,120,113,120,114,120,115,120,116,120,117,120,118,120,120,120,121,120,122,120,123,120,125,120,126,120,127,120,128,120,129,120,130,120,131,120,58,87,29,92,56,94,127,149,127,80,160,128,130,83,94,101,69,117,49,85,33,80,133,141,132,98,158,148,29,103,50,86,110,111,226,93,53,84,146,112,102,143,111,98,164,100,163,99,123,95,136,111,244,144,227,129,176,143,24,92,104,102,241,95,137,108,72,150,129,141,108,136,145,100,240,121,206,87,89,106,16,98,72,84,88,78,11,122,233,96,132,111,218,139,127,98,30,144,139,154,228,121,3,84,244,117,1,99,25,83,96,108,223,143,27,95,112,154,59,128,127,159,136,79,58,92,100,141,197,127,165,101,189,112,69,81,178,81,107,134,7,93,160,91,189,98,108,145,116,117,12,142,32,122,1,97,121,123,199,78,248,126,133,119,17,78,237,129,29,82,250,81,113,106,168,83,135,142,4,149,207,150,193,110,100,150,90,105,132,120,133,120,134,120,136,120,138,120,139,120,143,120,144,120,146,120,148,120,149,120,150,120,153,120,157,120,158,120,160,120,162,120,164,120,166,120,168,120,169,120,170,120,171,120,172,120,173,120,174,120,175,120,181,120,182,120,183,120,184,120,186,120,187,120,188,120,189,120,191,120,192,120,194,120,195,120,196,120,198,120,199,120,200,120,204,120,205,120,206,120,207,120,209,120,210,120,211,120,214,120,215,120,216,120,218,120,219,120,220,120,221,120,222,120,223,120,224,120,225,120,226,120,227,120,228,120,229,120,230,120,231,120,233,120,234,120,235,120,237,120,238,120,239,120,240,120,241,120,243,120,245,120,246,120,248,120,249,120,251,120,252,120,253,120,254,120,255,120,0,121,2,121,3,121,4,121,6,121,7,121,8,121,9,121,10,121,11,121,12,121,64,120,168,80,215,119,16,100,230,137,4,89,227,99,221,93,127,122,61,105,32,79,57,130,152,85,50,78,174,117,151,122,98,94,138,94,239,149,27,82,57,84,138,112,118,99,36,149,130,87,37,102,63,105,135,145,7,85,243,109,175,126,34,136,51,98,240,126,181,117,40,131,193,120,204,150,158,143,72,97,247,116,205,139,100,107,58,82,80,141,33,107,106,128,113,132,241,86,6,83,206,78,27,78,209,81,151,124,139,145,7,124,195,79,127,142,225,123,156,122,103,100,20,93,172,80,6,129,1,118,185,124,236,109,224,127,81,103,88,91,248,91,203,120,174,100,19,100,170,99,43,99,25,149,45,100,190,143,84,123,41,118,83,98,39,89,70,84,121,107,163,80,52,98,38,94,134,107,227,78,55,141,139,136,133,95,46,144,13,121,14,121,15,121,16,121,17,121,18,121,20,121,21,121,22,121,23,121,24,121,25,121,26,121,27,121,28,121,29,121,31,121,32,121,33,121,34,121,35,121,37,121,38,121,39,121,40,121,41,121,42,121,43,121,44,121,45,121,46,121,47,121,48,121,49,121,50,121,51,121,53,121,54,121,55,121,56,121,57,121,61,121,63,121,66,121,67,121,68,121,69,121,71,121,74,121,75,121,76,121,77,121,78,121,79,121,80,121,81,121,82,121,84,121,85,121,88,121,89,121,97,121,99,121,100,121,102,121,105,121,106,121,107,121,108,121,110,121,112,121,113,121,114,121,115,121,116,121,117,121,118,121,121,121,123,121,124,121,125,121,126,121,127,121,130,121,131,121,134,121,135,121,136,121,137,121,139,121,140,121,141,121,142,121,144,121,145,121,146,121,32,96,61,128,197,98,57,78,85,83,248,144,184,99,198,128,230,101,46,108,70,79,238,96,225,109,222,139,57,95,203,134,83,95,33,99,90,81,97,131,99,104,0,82,99,99,72,142,18,80,155,92,119,121,252,91,48,82,59,122,188,96,83,144,215,118,183,95,151,95,132,118,108,142,111,112,123,118,73,123,170,119,243,81,147,144,36,88,78,79,244,110,234,143,76,101,27,123,196,114,164,109,223,127,225,90,181,98,149,94,48,87,130,132,44,123,29,94,31,95,18,144,20,127,160,152,130,99,199,110,152,120,185,112,120,81,91,151,171,87,53,117,67,79,56,117,151,94,230,96,96,89,192,109,191,107,137,120,252,83,213,150,203,81,1,82,137,99,10,84,147,148,3,140,204,141,57,114,159,120,118,135,237,143,13,140,224,83,147,121,148,121,149,121,150,121,151,121,152,121,153,121,155,121,156,121,157,121,158,121,159,121,160,121,161,121,162,121,163,121,164,121,165,121,166,121,168,121,169,121,170,121,171,121,172,121,173,121,174,121,175,121,176,121,177,121,178,121,180,121,181,121,182,121,183,121,184,121,188,121,191,121,194,121,196,121,197,121,199,121,200,121,202,121,204,121,206,121,207,121,208,121,211,121,212,121,214,121,215,121,217,121,218,121,219,121,220,121,221,121,222,121,224,121,225,121,226,121,229,121,232,121,234,121,236,121,238,121,241,121,242,121,243,121,244,121,245,121,246,121,247,121,249,121,250,121,252,121,254,121,255,121,1,122,4,122,5,122,7,122,8,122,9,122,10,122,12,122,15,122,16,122,17,122,18,122,19,122,21,122,22,122,24,122,25,122,27,122,28,122,1,78,239,118,238,83,137,148,118,152,14,159,45,149,154,91,162,139,34,78,28,78,172,81,99,132,194,97,168,82,11,104,151,79,107,96,187,81,30,109,92,81,150,98,151,101,97,150,70,140,23,144,216,117,253,144,99,119,210,107,138,114,236,114,251,139,53,88,121,119,76,141,92,103,64,149,154,128,166,94,33,110,146,89,239,122,237,119,59,149,181,107,173,101,14,127,6,88,81,81,31,150,249,91,169,88,40,84,114,142,102,101,127,152,228,86,157,148,254,118,65,144,135,99,198,84,26,89,58,89,155,87,178,142,53,103,250,141,53,130,65,82,240,96,21,88,254,134,232,92,69,158,196,79,157,152,185,139,37,90,118,96,132,83,124,98,79,144,2,145,127,153,105,96,12,128,63,81,51,128,20,92,117,153,49,109,140,78,29,122,31,122,33,122,34,122,36,122,37,122,38,122,39,122,40,122,41,122,42,122,43,122,44,122,45,122,46,122,47,122,48,122,49,122,50,122,52,122,53,122,54,122,56,122,58,122,62,122,64,122,65,122,66,122,67,122,68,122,69,122,71,122,72,122,73,122,74,122,75,122,76,122,77,122,78,122,79,122,80,122,82,122,83,122,84,122,85,122,86,122,88,122,89,122,90,122,91,122,92,122,93,122,94,122,95,122,96,122,97,122,98,122,99,122,100,122,101,122,102,122,103,122,104,122,105,122,106,122,107,122,108,122,109,122,110,122,111,122,113,122,114,122,115,122,117,122,123,122,124,122,125,122,126,122,130,122,133,122,135,122,137,122,138,122,139,122,140,122,142,122,143,122,144,122,147,122,148,122,153,122,154,122,155,122,158,122,161,122,162,122,48,141,209,83,90,127,79,123,16,79,79,78,0,150,213,108,208,115,233,133,6,94,106,117,251,127,10,106,254,119,146,148,65,126,225,81,230,112,205,83,212,143,3,131,41,141,175,114,109,153,219,108,74,87,179,130,185,101,170,128,63,98,50,150,168,89,255,78,191,139,186,126,62,101,242,131,94,151,97,85,222,152,165,128,42,83,253,139,32,84,186,128,159,94,184,108,57,141,172,130,90,145,41,84,27,108,6,82,183,126,95,87,26,113,126,108,137,124,75,89,253,78,255,95,36,97,170,124,48,78,1,92,171,103,2,135,240,92,11,149,206,152,175,117,253,112,34,144,175,81,29,127,189,139,73,89,228,81,91,79,38,84,43,89,119,101,164,128,117,91,118,98,194,98,144,143,69,94,31,108,38,123,15,79,216,79,13,103,163,122,164,122,167,122,169,122,170,122,171,122,174,122,175,122,176,122,177,122,178,122,180,122,181,122,182,122,183,122,184,122,185,122,186,122,187,122,188,122,189,122,190,122,192,122,193,122,194,122,195,122,196,122,197,122,198,122,199,122,200,122,201,122,202,122,204,122,205,122,206,122,207,122,208,122,209,122,210,122,211,122,212,122,213,122,215,122,216,122,218,122,219,122,220,122,221,122,225,122,226,122,228,122,231,122,232,122,233,122,234,122,235,122,236,122,238,122,240,122,241,122,242,122,243,122,244,122,245,122,246,122,247,122,248,122,251,122,252,122,254,122,0,123,1,123,2,123,5,123,7,123,9,123,12,123,13,123,14,123,16,123,18,123,19,123,22,123,23,123,24,123,26,123,28,123,29,123,31,123,33,123,34,123,35,123,39,123,41,123,45,123,110,109,170,109,143,121,177,136,23,95,43,117,154,98,133,143,239,79,220,145,167,101,47,129,81,129,156,94,80,129,116,141,111,82,134,137,75,141,13,89,133,80,216,78,28,150,54,114,121,129,31,141,204,91,163,139,68,150,135,89,26,127,144,84,118,86,14,86,229,139,57,101,130,105,153,148,214,118,137,110,114,94,24,117,70,103,209,103,255,122,157,128,118,141,31,97,198,121,98,101,99,141,136,81,26,82,162,148,56,127,155,128,178,126,151,92,47,110,96,103,217,123,139,118,216,154,143,129,148,127,213,124,30,100,80,149,63,122,74,84,229,84,76,107,1,100,8,98,61,158,243,128,153,117,114,82,105,151,91,132,60,104,228,134,1,150,148,150,236,148,42,78,4,84,217,126,57,104,223,141,21,128,244,102,154,94,185,127,47,123,48,123,50,123,52,123,53,123,54,123,55,123,57,123,59,123,61,123,63,123,64,123,65,123,66,123,67,123,68,123,70,123,72,123,74,123,77,123,78,123,83,123,85,123,87,123,89,123,92,123,94,123,95,123,97,123,99,123,100,123,101,123,102,123,103,123,104,123,105,123,106,123,107,123,108,123,109,123,111,123,112,123,115,123,116,123,118,123,120,123,122,123,124,123,125,123,127,123,129,123,130,123,131,123,132,123,134,123,135,123,136,123,137,123,138,123,139,123,140,123,142,123,143,123,145,123,146,123,147,123,150,123,152,123,153,123,154,123,155,123,158,123,159,123,160,123,163,123,164,123,165,123,174,123,175,123,176,123,178,123,179,123,181,123,182,123,183,123,185,123,186,123,187,123,188,123,189,123,190,123,191,123,192,123,194,123,195,123,196,123,194,87,63,128,151,104,229,93,59,101,159,82,109,96,154,159,155,79,172,142,108,81,171,91,19,95,233,93,94,108,241,98,33,141,113,81,169,148,254,82,159,108,223,130,215,114,162,87,132,103,45,141,31,89,156,143,199,131,149,84,141,123,48,79,189,108,100,91,209,89,19,159,228,83,202,134,168,154,55,140,161,128,69,101,126,152,250,86,199,150,46,82,220,116,80,82,225,91,2,99,2,137,86,78,208,98,42,96,250,104,115,81,152,91,160,81,194,137,161,123,134,153,80,127,239,96,76,112,47,141,73,81,127,94,27,144,112,116,196,137,45,87,69,120,82,95,159,159,250,149,104,143,60,155,225,139,120,118,66,104,220,103,234,141,53,141,61,82,138,143,218,110,205,104,5,149,237,144,253,86,156,103,249,136,199,143,200,84,197,123,200,123,201,123,202,123,203,123,205,123,206,123,207,123,208,123,210,123,212,123,213,123,214,123,215,123,216,123,219,123,220,123,222,123,223,123,224,123,226,123,227,123,228,123,231,123,232,123,233,123,235,123,236,123,237,123,239,123,240,123,242,123,243,123,244,123,245,123,246,123,248,123,249,123,250,123,251,123,253,123,255,123,0,124,1,124,2,124,3,124,4,124,5,124,6,124,8,124,9,124,10,124,13,124,14,124,16,124,17,124,18,124,19,124,20,124,21,124,23,124,24,124,25,124,26,124,27,124,28,124,29,124,30,124,32,124,33,124,34,124,35,124,36,124,37,124,40,124,41,124,43,124,44,124,45,124,46,124,47,124,48,124,49,124,50,124,51,124,52,124,53,124,54,124,55,124,57,124,58,124,59,124,60,124,61,124,62,124,66,124,184,154,105,91,119,109,38,108,165,78,179,91,135,154,99,145,168,97,175,144,233,151,43,84,181,109,210,91,253,81,138,85,85,127,240,127,188,100,77,99,241,101,190,97,141,96,10,113,87,108,73,108,47,89,109,103,42,130,213,88,142,86,106,140,235,107,221,144,125,89,23,128,247,83,105,109,117,84,157,85,119,131,207,131,56,104,190,121,140,84,85,79,8,84,210,118,137,140,2,150,179,108,184,109,107,141,16,137,100,158,58,141,63,86,209,158,213,117,136,95,224,114,104,96,252,84,168,78,42,106,97,136,82,96,112,143,196,84,216,112,121,134,63,158,42,109,143,91,24,95,162,126,137,85,175,79,52,115,60,84,154,83,25,80,14,84,124,84,78,78,253,95,90,116,246,88,107,132,225,128,116,135,208,114,202,124,86,110,67,124,68,124,69,124,70,124,71,124,72,124,73,124,74,124,75,124,76,124,78,124,79,124,80,124,81,124,82,124,83,124,84,124,85,124,86,124,87,124,88,124,89,124,90,124,91,124,92,124,93,124,94,124,95,124,96,124,97,124,98,124,99,124,100,124,101,124,102,124,103,124,104,124,105,124,106,124,107,124,108,124,109,124,110,124,111,124,112,124,113,124,114,124,117,124,118,124,119,124,120,124,121,124,122,124,126,124,127,124,128,124,129,124,130,124,131,124,132,124,133,124,134,124,135,124,136,124,138,124,139,124,140,124,141,124,142,124,143,124,144,124,147,124,148,124,150,124,153,124,154,124,155,124,160,124,161,124,163,124,166,124,167,124,168,124,169,124,171,124,172,124,173,124,175,124,176,124,180,124,181,124,182,124,183,124,184,124,186,124,187,124,39,95,78,134,44,85,164,98,146,78,170,108,55,98,177,130,215,84,78,83,62,115,209,110,59,117,18,82,22,83,221,139,208,105,138,95,0,96,238,109,79,87,34,107,175,115,83,104,216,143,19,127,98,99,163,96,36,85,234,117,98,140,21,113,163,109,166,91,123,94,82,131,76,97,196,158,250,120,87,135,39,124,135,118,240,81,246,96,76,113,67,102,76,94,77,96,14,140,112,112,37,99,137,143,189,95,98,96,212,134,222,86,193,107,148,96,103,97,73,83,224,96,102,102,63,141,253,121,26,79,233,112,71,108,179,139,242,139,216,126,100,131,15,102,90,90,66,155,81,109,247,109,65,140,59,109,25,79,107,112,183,131,22,98,209,96,13,151,39,141,120,121,251,81,62,87,250,87,58,103,120,117,61,122,239,121,149,123,191,124,192,124,194,124,195,124,196,124,198,124,201,124,203,124,206,124,207,124,208,124,209,124,210,124,211,124,212,124,216,124,218,124,219,124,221,124,222,124,225,124,226,124,227,124,228,124,229,124,230,124,231,124,233,124,234,124,235,124,236,124,237,124,238,124,240,124,241,124,242,124,243,124,244,124,245,124,246,124,247,124,249,124,250,124,252,124,253,124,254,124,255,124,0,125,1,125,2,125,3,125,4,125,5,125,6,125,7,125,8,125,9,125,11,125,12,125,13,125,14,125,15,125,16,125,17,125,18,125,19,125,20,125,21,125,22,125,23,125,24,125,25,125,26,125,27,125,28,125,29,125,30,125,31,125,33,125,35,125,36,125,37,125,38,125,40,125,41,125,42,125,44,125,45,125,46,125,48,125,49,125,50,125,51,125,52,125,53,125,54,125,140,128,101,153,249,143,192,111,165,139,33,158,236,89,233,126,9,127,9,84,129,103,216,104,145,143,77,124,198,150,202,83,37,96,190,117,114,108,115,83,201,90,167,126,36,99,224,81,10,129,241,93,223,132,128,98,128,81,99,91,14,79,109,121,66,82,184,96,78,109,196,91,194,91,161,139,176,139,226,101,204,95,69,150,147,89,231,126,170,126,9,86,183,103,57,89,115,79,182,91,160,82,90,131,138,152,62,141,50,117,190,148,71,80,60,122,247,78,182,103,126,154,193,90,124,107,209,118,90,87,22,92,58,123,244,149,78,113,124,81,169,128,112,130,120,89,4,127,39,131,192,104,236,103,177,120,119,120,227,98,97,99,128,123,237,79,106,82,207,81,80,131,219,105,116,146,245,141,49,141,193,137,46,149,173,123,246,78,55,125,56,125,57,125,58,125,59,125,60,125,61,125,62,125,63,125,64,125,65,125,66,125,67,125,68,125,69,125,70,125,71,125,72,125,73,125,74,125,75,125,76,125,77,125,78,125,79,125,80,125,81,125,82,125,83,125,84,125,85,125,86,125,87,125,88,125,89,125,90,125,91,125,92,125,93,125,94,125,95,125,96,125,97,125,98,125,99,125,100,125,101,125,102,125,103,125,104,125,105,125,106,125,107,125,108,125,109,125,111,125,112,125,113,125,114,125,115,125,116,125,117,125,118,125,120,125,121,125,122,125,123,125,124,125,125,125,126,125,127,125,128,125,129,125,130,125,131,125,132,125,133,125,134,125,135,125,136,125,137,125,138,125,139,125,140,125,141,125,142,125,143,125,144,125,145,125,146,125,147,125,148,125,149,125,150,125,151,125,152,125,101,80,48,130,81,82,111,153,16,110,133,110,167,109,250,94,245,80,220,89,6,92,70,109,95,108,134,117,139,132,104,104,86,89,178,139,32,83,113,145,77,150,73,133,18,105,1,121,38,113,246,128,164,78,202,144,71,109,132,154,7,90,188,86,5,100,240,148,235,119,165,79,26,129,225,114,210,137,122,153,52,127,222,126,127,82,89,101,117,145,127,143,131,143,235,83,150,122,237,99,165,99,134,118,248,121,87,136,54,150,42,98,171,82,130,130,84,104,112,103,119,99,107,119,237,122,1,109,211,126,227,137,208,89,18,98,201,133,165,130,76,117,31,80,203,78,165,117,235,139,74,92,254,93,75,123,164,101,209,145,202,78,37,109,95,137,39,125,38,149,197,78,40,140,219,143,115,151,75,102,129,121,209,143,236,112,120,109,153,125,154,125,155,125,156,125,157,125,158,125,159,125,160,125,161,125,162,125,163,125,164,125,165,125,167,125,168,125,169,125,170,125,171,125,172,125,173,125,175,125,176,125,177,125,178,125,179,125,180,125,181,125,182,125,183,125,184,125,185,125,186,125,187,125,188,125,189,125,190,125,191,125,192,125,193,125,194,125,195,125,196,125,197,125,198,125,199,125,200,125,201,125,202,125,203,125,204,125,205,125,206,125,207,125,208,125,209,125,210,125,211,125,212,125,213,125,214,125,215,125,216,125,217,125,218,125,219,125,220,125,221,125,222,125,223,125,224,125,225,125,226,125,227,125,228,125,229,125,230,125,231,125,232,125,233,125,234,125,235,125,236,125,237,125,238,125,239,125,240,125,241,125,242,125,243,125,244,125,245,125,246,125,247,125,248,125,249,125,250,125,61,92,178,82,70,131,98,81,14,131,91,119,118,102,184,156,172,78,202,96,190,124,179,124,207,126,149,78,102,139,111,102,136,152,89,151,131,88,108,101,92,149,132,95,201,117,86,151,223,122,222,122,192,81,175,112,152,122,234,99,118,122,160,126,150,115,237,151,69,78,120,112,93,78,82,145,169,83,81,101,231,101,252,129,5,130,142,84,49,92,154,117,160,151,216,98,217,114,189,117,69,92,121,154,202,131,64,92,128,84,233,119,62,78,174,108,90,128,210,98,110,99,232,93,119,81,221,141,30,142,47,149,241,79,229,83,231,96,172,112,103,82,80,99,67,158,31,90,38,80,55,119,119,83,226,126,133,100,43,101,137,98,152,99,20,80,53,114,201,137,179,81,192,139,221,126,71,87,204,131,167,148,155,81,27,84,251,92,251,125,252,125,253,125,254,125,255,125,0,126,1,126,2,126,3,126,4,126,5,126,6,126,7,126,8,126,9,126,10,126,11,126,12,126,13,126,14,126,15,126,16,126,17,126,18,126,19,126,20,126,21,126,22,126,23,126,24,126,25,126,26,126,27,126,28,126,29,126,30,126,31,126,32,126,33,126,34,126,35,126,36,126,37,126,38,126,39,126,40,126,41,126,42,126,43,126,44,126,45,126,46,126,47,126,48,126,49,126,50,126,51,126,52,126,53,126,54,126,55,126,56,126,57,126,58,126,60,126,61,126,62,126,63,126,64,126,66,126,67,126,68,126,69,126,70,126,72,126,73,126,74,126,75,126,76,126,77,126,78,126,79,126,80,126,81,126,82,126,83,126,84,126,85,126,86,126,87,126,88,126,89,126,90,126,91,126,92,126,93,126,202,79,227,122,90,109,225,144,143,154,128,85,150,84,97,83,175,84,0,95,233,99,119,105,239,81,104,97,10,82,42,88,216,82,78,87,13,120,11,119,183,94,119,97,224,124,91,98,151,98,162,78,149,112,3,128,247,98,228,112,96,151,119,87,219,130,239,103,245,104,213,120,151,152,209,121,243,88,179,84,239,83,52,110,75,81,59,82,162,91,254,139,175,128,67,85,166,87,115,96,81,87,45,84,122,122,80,96,84,91,167,99,160,98,227,83,99,98,199,91,175,103,237,84,159,122,230,130,119,145,147,94,228,136,56,89,174,87,14,99,232,141,239,128,87,87,119,123,169,79,235,95,189,91,62,107,33,83,80,123,194,114,70,104,255,119,54,119,247,101,181,81,143,78,212,118,191,92,165,122,117,132,78,89,65,155,128,80,94,126,95,126,96,126,97,126,98,126,99,126,100,126,101,126,102,126,103,126,104,126,105,126,106,126,107,126,108,126,109,126,110,126,111,126,112,126,113,126,114,126,115,126,116,126,117,126,118,126,119,126,120,126,121,126,122,126,123,126,124,126,125,126,126,126,127,126,128,126,129,126,131,126,132,126,133,126,134,126,135,126,136,126,137,126,138,126,139,126,140,126,141,126,142,126,143,126,144,126,145,126,146,126,147,126,148,126,149,126,150,126,151,126,152,126,153,126,154,126,156,126,157,126,158,126,174,126,180,126,187,126,188,126,214,126,228,126,236,126,249,126,10,127,16,127,30,127,55,127,57,127,59,127,60,127,61,127,62,127,63,127,64,127,65,127,67,127,70,127,71,127,72,127,73,127,74,127,75,127,76,127,77,127,78,127,79,127,82,127,83,127,136,153,39,97,131,110,100,87,6,102,70,99,240,86,236,98,105,98,211,94,20,150,131,87,201,98,135,85,33,135,74,129,163,143,102,85,177,131,101,103,86,141,221,132,106,90,15,104,230,98,238,123,17,150,112,81,156,111,48,140,253,99,200,137,210,97,6,127,194,112,229,110,5,116,148,105,252,114,202,94,206,144,23,103,106,109,94,99,179,82,98,114,1,128,108,79,229,89,106,145,217,112,157,109,210,82,80,78,247,150,109,149,126,133,202,120,47,125,33,81,146,87,194,100,139,128,123,124,234,108,241,104,94,105,183,81,152,83,168,104,129,114,206,158,241,123,248,114,187,121,19,111,6,116,78,103,204,145,164,156,60,121,137,131,84,131,15,84,23,104,61,78,137,83,177,82,62,120,134,83,41,82,136,80,139,79,208,79,86,127,89,127,91,127,92,127,93,127,94,127,96,127,99,127,100,127,101,127,102,127,103,127,107,127,108,127,109,127,111,127,112,127,115,127,117,127,118,127,119,127,120,127,122,127,123,127,124,127,125,127,127,127,128,127,130,127,131,127,132,127,133,127,134,127,135,127,136,127,137,127,139,127,141,127,143,127,144,127,145,127,146,127,147,127,149,127,150,127,151,127,152,127,153,127,155,127,156,127,160,127,162,127,163,127,165,127,166,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,177,127,179,127,180,127,181,127,182,127,183,127,186,127,187,127,190,127,192,127,194,127,195,127,196,127,198,127,199,127,200,127,201,127,203,127,205,127,207,127,208,127,209,127,210,127,211,127,214,127,215,127,217,127,218,127,219,127,220,127,221,127,222,127,226,127,227,127,226,117,203,122,146,124,165,108,182,150,155,82,131,116,233,84,233,79,84,128,178,131,222,143,112,149,201,94,28,96,159,109,24,94,91,101,56,129,254,148,75,96,188,112,195,126,174,124,201,81,129,104,177,124,111,130,36,78,134,143,207,145,126,102,174,78,5,140,169,100,74,128,218,80,151,117,206,113,229,91,189,143,102,111,134,78,130,100,99,149,214,94,153,101,23,82,194,136,200,112,163,82,14,115,51,116,151,103,247,120,22,151,52,78,187,144,222,156,203,109,219,81,65,141,29,84,206,98,178,115,241,131,246,150,132,159,195,148,54,79,154,127,204,81,117,112,117,150,173,92,134,152,230,83,228,78,156,110,9,116,180,105,107,120,143,153,89,117,24,82,36,118,65,109,243,103,109,81,153,159,75,128,153,84,60,123,191,122,228,127,231,127,232,127,234,127,235,127,236,127,237,127,239,127,242,127,244,127,245,127,246,127,247,127,248,127,249,127,250,127,253,127,254,127,255,127,2,128,7,128,8,128,9,128,10,128,14,128,15,128,17,128,19,128,26,128,27,128,29,128,30,128,31,128,33,128,35,128,36,128,43,128,44,128,45,128,46,128,47,128,48,128,50,128,52,128,57,128,58,128,60,128,62,128,64,128,65,128,68,128,69,128,71,128,72,128,73,128,78,128,79,128,80,128,81,128,83,128,85,128,86,128,87,128,89,128,91,128,92,128,93,128,94,128,95,128,96,128,97,128,98,128,99,128,100,128,101,128,102,128,103,128,104,128,107,128,108,128,109,128,110,128,111,128,112,128,114,128,115,128,116,128,117,128,118,128,119,128,120,128,121,128,122,128,123,128,124,128,125,128,134,150,132,87,226,98,71,150,124,105,4,90,2,100,211,123,15,111,75,150,166,130,98,83,133,152,144,94,137,112,179,99,100,83,79,134,129,156,147,158,140,120,50,151,239,141,66,141,127,158,94,111,132,121,85,95,70,150,46,98,116,154,21,84,221,148,163,79,197,101,101,92,97,92,21,127,81,134,47,108,139,95,135,115,228,110,255,126,230,92,27,99,106,91,230,110,117,83,113,78,160,99,101,117,161,98,110,143,38,79,209,78,166,108,182,126,186,139,29,132,186,135,87,127,59,144,35,149,169,123,161,154,248,136,61,132,27,109,134,154,220,126,136,89,187,158,155,115,1,120,130,134,108,154,130,154,27,86,23,84,203,87,112,78,166,158,86,83,200,143,9,129,146,119,146,153,238,134,225,110,19,133,252,102,98,97,43,111,126,128,129,128,130,128,133,128,136,128,138,128,141,128,142,128,143,128,144,128,145,128,146,128,148,128,149,128,151,128,153,128,158,128,163,128,166,128,167,128,168,128,172,128,176,128,179,128,181,128,182,128,184,128,185,128,187,128,197,128,199,128,200,128,201,128,202,128,203,128,207,128,208,128,209,128,210,128,211,128,212,128,213,128,216,128,223,128,224,128,226,128,227,128,230,128,238,128,245,128,247,128,249,128,251,128,254,128,255,128,0,129,1,129,3,129,4,129,5,129,7,129,8,129,11,129,12,129,21,129,23,129,25,129,27,129,28,129,29,129,31,129,32,129,33,129,34,129,35,129,36,129,37,129,38,129,39,129,40,129,41,129,42,129,43,129,45,129,46,129,48,129,51,129,52,129,53,129,55,129,57,129,58,129,59,129,60,129,61,129,63,129,41,140,146,130,43,131,242,118,19,108,217,95,189,131,43,115,5,131,26,149,219,107,219,119,198,148,111,83,2,131,146,81,61,94,140,140,56,141,72,78,171,115,154,103,133,104,118,145,9,151,100,113,161,108,9,119,146,90,65,149,207,107,142,127,39,102,208,91,185,89,154,90,232,149,247,149,236,78,12,132,153,132,172,106,223,118,48,149,27,115,166,104,95,91,47,119,154,145,97,151,220,124,247,143,28,140,37,95,115,124,216,121,197,137,204,108,28,135,198,91,66,94,201,104,32,119,245,126,149,81,77,81,201,82,41,90,5,127,98,151,215,130,207,99,132,119,208,133,210,121,58,110,153,94,153,89,17,133,109,112,17,108,191,98,191,118,79,101,175,96,253,149,14,102,159,135,35,158,237,148,13,84,125,84,44,140,120,100,64,129,65,129,66,129,67,129,68,129,69,129,71,129,73,129,77,129,78,129,79,129,82,129,86,129,87,129,88,129,91,129,92,129,93,129,94,129,95,129,97,129,98,129,99,129,100,129,102,129,104,129,106,129,107,129,108,129,111,129,114,129,115,129,117,129,118,129,119,129,120,129,129,129,131,129,132,129,133,129,134,129,135,129,137,129,139,129,140,129,141,129,142,129,144,129,146,129,147,129,148,129,149,129,150,129,151,129,153,129,154,129,158,129,159,129,160,129,161,129,162,129,164,129,165,129,167,129,169,129,171,129,172,129,173,129,174,129,175,129,176,129,177,129,178,129,180,129,181,129,182,129,183,129,184,129,185,129,188,129,189,129,190,129,191,129,196,129,197,129,199,129,200,129,201,129,203,129,205,129,206,129,207,129,208,129,209,129,210,129,211,129,121,100,17,134,33,106,156,129,232,120,105,100,84,155,185,98,43,103,171,131,168,88,216,158,171,108,32,111,222,91,76,150,11,140,95,114,208,103,199,98,97,114,169,78,198,89,205,107,147,88,174,102,85,94,223,82,85,97,40,103,238,118,102,119,103,114,70,122,255,98,234,84,80,84,160,148,163,144,28,90,179,126,22,108,67,78,118,89,16,128,72,89,87,83,55,117,190,150,202,86,32,99,17,129,124,96,249,149,214,109,98,84,129,153,133,81,233,90,253,128,174,89,19,151,42,80,229,108,60,92,223,98,96,79,63,83,123,129,6,144,186,110,43,133,200,98,116,94,190,120,181,100,123,99,245,95,24,90,127,145,31,158,63,92,79,99,66,128,125,91,110,85,74,149,77,149,133,109,168,96,224,103,222,114,221,81,129,91,212,129,213,129,214,129,215,129,216,129,217,129,218,129,219,129,220,129,221,129,222,129,223,129,224,129,225,129,226,129,228,129,229,129,230,129,232,129,233,129,235,129,238,129,239,129,240,129,241,129,242,129,245,129,246,129,247,129,248,129,249,129,250,129,253,129,255,129,3,130,7,130,8,130,9,130,10,130,11,130,14,130,15,130,17,130,19,130,21,130,22,130,23,130,24,130,25,130,26,130,29,130,32,130,36,130,37,130,38,130,39,130,41,130,46,130,50,130,58,130,60,130,61,130,63,130,64,130,65,130,66,130,67,130,69,130,70,130,72,130,74,130,76,130,77,130,78,130,80,130,81,130,82,130,83,130,84,130,85,130,86,130,87,130,89,130,91,130,92,130,93,130,94,130,96,130,97,130,98,130,99,130,100,130,101,130,102,130,103,130,105,130,231,98,222,108,91,114,109,98,174,148,189,126,19,129,83,109,156,81,4,95,116,89,170,82,18,96,115,89,150,102,80,134,159,117,42,99,230,97,239,124,250,139,230,84,39,107,37,158,180,107,213,133,85,84,118,80,164,108,106,85,180,141,44,114,21,94,21,96,54,116,205,98,146,99,76,114,152,95,67,110,62,109,0,101,88,111,216,118,208,120,252,118,84,117,36,82,219,83,83,78,158,94,193,101,42,128,214,128,155,98,134,84,40,82,174,112,141,136,209,141,225,108,120,84,218,128,249,87,244,136,84,141,106,150,77,145,105,79,155,108,183,85,198,118,48,120,168,98,249,112,142,111,109,95,236,132,218,104,124,120,247,123,168,129,11,103,79,158,103,99,176,120,111,87,18,120,57,151,121,98,171,98,136,82,53,116,215,107,106,130,107,130,108,130,109,130,113,130,117,130,118,130,119,130,120,130,123,130,124,130,128,130,129,130,131,130,133,130,134,130,135,130,137,130,140,130,144,130,147,130,148,130,149,130,150,130,154,130,155,130,158,130,160,130,162,130,163,130,167,130,178,130,181,130,182,130,186,130,187,130,188,130,191,130,192,130,194,130,195,130,197,130,198,130,201,130,208,130,214,130,217,130,218,130,221,130,226,130,231,130,232,130,233,130,234,130,236,130,237,130,238,130,240,130,242,130,243,130,245,130,246,130,248,130,250,130,252,130,253,130,254,130,255,130,0,131,10,131,11,131,13,131,16,131,18,131,19,131,22,131,24,131,25,131,29,131,30,131,31,131,32,131,33,131,34,131,35,131,36,131,37,131,38,131,41,131,42,131,46,131,48,131,50,131,55,131,59,131,61,131,100,85,62,129,178,117,174,118,57,83,222,117,251,80,65,92,108,139,199,123,79,80,71,114,151,154,216,152,2,111,226,116,104,121,135,100,165,119,252,98,145,152,43,141,193,84,88,128,82,78,106,87,249,130,13,132,115,94,237,81,246,116,196,139,79,92,97,87,252,108,135,152,70,90,52,120,68,155,235,143,149,124,86,82,81,98,250,148,198,78,134,131,97,132,233,131,178,132,212,87,52,103,3,87,110,102,102,109,49,140,221,102,17,112,31,103,58,107,22,104,26,98,187,89,3,78,196,81,6,111,210,103,143,108,118,81,203,104,71,89,103,107,102,117,14,93,16,129,80,159,215,101,72,121,65,121,145,154,119,141,130,92,94,78,1,79,47,84,81,89,12,120,104,86,20,108,196,143,3,95,125,108,227,108,171,139,144,99,62,131,63,131,65,131,66,131,68,131,69,131,72,131,74,131,75,131,76,131,77,131,78,131,83,131,85,131,86,131,87,131,88,131,89,131,93,131,98,131,112,131,113,131,114,131,115,131,116,131,117,131,118,131,121,131,122,131,126,131,127,131,128,131,129,131,130,131,131,131,132,131,135,131,136,131,138,131,139,131,140,131,141,131,143,131,144,131,145,131,148,131,149,131,150,131,151,131,153,131,154,131,157,131,159,131,161,131,162,131,163,131,164,131,165,131,166,131,167,131,172,131,173,131,174,131,175,131,181,131,187,131,190,131,191,131,194,131,195,131,196,131,198,131,200,131,201,131,203,131,205,131,206,131,208,131,209,131,210,131,211,131,213,131,215,131,217,131,218,131,219,131,222,131,226,131,227,131,228,131,230,131,231,131,232,131,235,131,236,131,237,131,112,96,61,109,117,114,102,98,142,148,197,148,67,83,193,143,126,123,223,78,38,140,126,78,212,158,177,148,179,148,77,82,92,111,99,144,69,109,52,140,17,88,76,93,32,107,73,107,170,103,91,84,84,129,140,127,153,88,55,133,58,95,162,98,71,106,57,149,114,101,132,96,101,104,167,119,84,78,168,79,231,93,152,151,172,100,216,127,237,92,207,79,141,122,7,82,4,131,20,78,47,96,131,122,166,148,181,79,178,78,230,121,52,116,228,82,185,130,210,100,189,121,221,91,129,108,82,151,123,143,34,108,62,80,127,83,5,110,206,100,116,102,48,108,197,96,119,152,247,139,134,94,60,116,119,122,203,121,24,78,177,144,3,116,66,108,218,86,75,145,197,108,139,141,58,83,198,134,242,102,175,142,72,92,113,154,32,110,238,131,239,131,243,131,244,131,245,131,246,131,247,131,250,131,251,131,252,131,254,131,255,131,0,132,2,132,5,132,7,132,8,132,9,132,10,132,16,132,18,132,19,132,20,132,21,132,22,132,23,132,25,132,26,132,27,132,30,132,31,132,32,132,33,132,34,132,35,132,41,132,42,132,43,132,44,132,45,132,46,132,47,132,48,132,50,132,51,132,52,132,53,132,54,132,55,132,57,132,58,132,59,132,62,132,63,132,64,132,65,132,66,132,67,132,68,132,69,132,71,132,72,132,73,132,74,132,75,132,76,132,77,132,78,132,79,132,80,132,82,132,83,132,84,132,85,132,86,132,88,132,93,132,94,132,95,132,96,132,98,132,100,132,101,132,102,132,103,132,104,132,106,132,110,132,111,132,112,132,114,132,116,132,119,132,121,132,123,132,124,132,214,83,54,90,139,159,163,141,187,83,8,87,167,152,67,103,155,145,201,108,104,81,202,117,243,98,172,114,56,82,157,82,58,127,148,112,56,118,116,83,74,158,183,105,110,120,192,150,217,136,164,127,54,113,195,113,137,81,211,103,228,116,228,88,24,101,183,86,169,139,118,153,112,98,213,126,249,96,237,112,236,88,193,78,186,78,205,95,231,151,251,78,164,139,3,82,138,89,171,126,84,98,205,78,229,101,14,98,56,131,201,132,99,131,141,135,148,113,182,110,185,91,210,126,151,81,201,99,212,103,137,128,57,131,21,136,18,81,122,91,130,89,177,143,115,78,93,108,101,81,37,137,111,143,46,150,74,133,94,116,16,149,240,149,166,109,229,130,49,95,146,100,18,109,40,132,110,129,195,156,94,88,91,141,9,78,193,83,125,132,126,132,127,132,128,132,129,132,131,132,132,132,133,132,134,132,138,132,141,132,143,132,144,132,145,132,146,132,147,132,148,132,149,132,150,132,152,132,154,132,155,132,157,132,158,132,159,132,160,132,162,132,163,132,164,132,165,132,166,132,167,132,168,132,169,132,170,132,171,132,172,132,173,132,174,132,176,132,177,132,179,132,181,132,182,132,183,132,187,132,188,132,190,132,192,132,194,132,195,132,197,132,198,132,199,132,200,132,203,132,204,132,206,132,207,132,210,132,212,132,213,132,215,132,216,132,217,132,218,132,219,132,220,132,222,132,225,132,226,132,228,132,231,132,232,132,233,132,234,132,235,132,237,132,238,132,239,132,241,132,242,132,243,132,244,132,245,132,246,132,247,132,248,132,249,132,250,132,251,132,253,132,254,132,0,133,1,133,2,133,30,79,99,101,81,104,211,85,39,78,20,100,154,154,107,98,194,90,95,116,114,130,169,109,238,104,231,80,142,131,2,120,64,103,57,82,153,108,177,126,187,80,101,85,94,113,91,123,82,102,202,115,235,130,73,103,113,92,32,82,125,113,107,136,234,149,85,150,197,100,97,141,179,129,132,85,85,108,71,98,46,127,146,88,36,79,70,85,79,141,76,102,10,78,26,92,243,136,162,104,78,99,13,122,231,112,141,130,250,82,246,151,17,92,232,84,181,144,205,126,98,89,74,141,199,134,12,130,13,130,102,141,68,100,4,92,81,97,137,109,62,121,190,139,55,120,51,117,123,84,56,79,171,142,241,109,32,90,197,126,94,121,136,108,161,91,118,90,26,117,190,128,78,97,23,110,240,88,31,117,37,117,114,114,71,83,243,126,3,133,4,133,5,133,6,133,7,133,8,133,9,133,10,133,11,133,13,133,14,133,15,133,16,133,18,133,20,133,21,133,22,133,24,133,25,133,27,133,28,133,29,133,30,133,32,133,34,133,35,133,36,133,37,133,38,133,39,133,40,133,41,133,42,133,45,133,46,133,47,133,48,133,49,133,50,133,51,133,52,133,53,133,54,133,62,133,63,133,64,133,65,133,66,133,68,133,69,133,70,133,71,133,75,133,76,133,77,133,78,133,79,133,80,133,81,133,82,133,83,133,84,133,85,133,87,133,88,133,90,133,91,133,92,133,93,133,95,133,96,133,97,133,98,133,99,133,101,133,102,133,103,133,105,133,106,133,107,133,108,133,109,133,110,133,111,133,112,133,113,133,115,133,117,133,118,133,119,133,120,133,124,133,125,133,127,133,128,133,129,133,1,119,219,118,105,82,220,128,35,87,8,94,49,89,238,114,189,101,127,110,215,139,56,92,113,134,65,83,243,119,254,98,246,101,192,78,223,152,128,134,158,91,198,139,242,83,226,119,127,79,78,92,118,154,203,89,15,95,58,121,235,88,22,78,255,103,139,78,237,98,147,138,29,144,191,82,47,102,220,85,108,86,2,144,213,78,141,79,202,145,112,153,15,108,2,94,67,96,164,91,198,137,213,139,54,101,75,98,150,153,136,91,255,91,136,99,46,85,215,83,38,118,125,81,44,133,162,103,179,104,138,107,146,98,147,143,212,83,18,130,209,109,143,117,102,78,78,141,112,91,159,113,175,133,145,102,217,102,114,127,0,135,205,158,32,159,94,92,47,103,240,143,17,104,95,103,13,98,214,122,133,88,182,94,112,101,49,111,130,133,131,133,134,133,136,133,137,133,138,133,139,133,140,133,141,133,142,133,144,133,145,133,146,133,147,133,148,133,149,133,150,133,151,133,152,133,153,133,154,133,157,133,158,133,159,133,160,133,161,133,162,133,163,133,165,133,166,133,167,133,169,133,171,133,172,133,173,133,177,133,178,133,179,133,180,133,181,133,182,133,184,133,186,133,187,133,188,133,189,133,190,133,191,133,192,133,194,133,195,133,196,133,197,133,198,133,199,133,200,133,202,133,203,133,204,133,205,133,206,133,209,133,210,133,212,133,214,133,215,133,216,133,217,133,218,133,219,133,221,133,222,133,223,133,224,133,225,133,226,133,227,133,229,133,230,133,231,133,232,133,234,133,235,133,236,133,237,133,238,133,239,133,240,133,241,133,242,133,243,133,244,133,245,133,246,133,247,133,248,133,85,96,55,82,13,128,84,100,112,136,41,117,5,94,19,104,244,98,28,151,204,83,61,114,1,140,52,108,97,119,14,122,46,84,172,119,122,152,28,130,244,139,85,120,20,103,193,112,175,101,149,100,54,86,29,96,193,121,248,83,29,78,123,107,134,128,250,91,227,85,219,86,58,79,60,79,114,153,243,93,126,103,56,128,2,96,130,152,1,144,139,91,188,139,245,139,28,100,88,130,222,100,253,85,207,130,101,145,215,79,32,125,31,144,159,124,243,80,81,88,175,110,191,91,201,139,131,128,120,145,156,132,151,123,125,134,139,150,143,150,229,126,211,154,142,120,129,92,87,122,66,144,167,150,95,121,89,91,95,99,11,123,209,132,173,104,6,85,41,127,16,116,34,125,1,149,64,98,76,88,214,78,131,91,121,89,84,88,249,133,250,133,252,133,253,133,254,133,0,134,1,134,2,134,3,134,4,134,6,134,7,134,8,134,9,134,10,134,11,134,12,134,13,134,14,134,15,134,16,134,18,134,19,134,20,134,21,134,23,134,24,134,25,134,26,134,27,134,28,134,29,134,30,134,31,134,32,134,33,134,34,134,35,134,36,134,37,134,38,134,40,134,42,134,43,134,44,134,45,134,46,134,47,134,48,134,49,134,50,134,51,134,52,134,53,134,54,134,55,134,57,134,58,134,59,134,61,134,62,134,63,134,64,134,65,134,66,134,67,134,68,134,69,134,70,134,71,134,72,134,73,134,74,134,75,134,76,134,82,134,83,134,85,134,86,134,87,134,88,134,89,134,91,134,92,134,93,134,95,134,96,134,97,134,99,134,100,134,101,134,102,134,103,134,104,134,105,134,106,134,109,115,30,99,75,142,15,142,206,128,212,130,172,98,240,83,240,108,94,145,42,89,1,96,112,108,77,87,74,100,42,141,43,118,233,110,91,87,128,106,240,117,109,111,45,140,8,140,102,87,239,107,146,136,179,120,162,99,249,83,173,112,100,108,88,88,42,100,2,88,224,104,155,129,16,85,214,124,24,80,186,142,204,109,159,141,235,112,143,99,155,109,212,110,230,126,4,132,67,104,3,144,216,109,118,150,168,139,87,89,121,114,228,133,126,129,188,117,138,138,175,104,84,82,34,142,17,149,208,99,152,152,68,142,124,85,83,79,255,102,143,86,213,96,149,109,67,82,73,92,41,89,251,109,107,88,48,117,28,117,108,96,20,130,70,129,17,99,97,103,226,143,58,119,243,141,52,141,193,148,22,94,133,83,44,84,195,112,109,134,111,134,112,134,114,134,115,134,116,134,117,134,118,134,119,134,120,134,131,134,132,134,133,134,134,134,135,134,136,134,137,134,142,134,143,134,144,134,145,134,146,134,148,134,150,134,151,134,152,134,153,134,154,134,155,134,158,134,159,134,160,134,161,134,162,134,165,134,166,134,171,134,173,134,174,134,178,134,179,134,183,134,184,134,185,134,187,134,188,134,189,134,190,134,191,134,193,134,194,134,195,134,197,134,200,134,204,134,205,134,210,134,211,134,213,134,214,134,215,134,218,134,220,134,221,134,224,134,225,134,226,134,227,134,229,134,230,134,231,134,232,134,234,134,235,134,236,134,239,134,245,134,246,134,247,134,250,134,251,134,252,134,253,134,255,134,1,135,4,135,5,135,6,135,11,135,12,135,14,135,15,135,16,135,17,135,20,135,22,135,64,108,247,94,92,80,173,78,173,94,58,99,71,130,26,144,80,104,110,145,179,119,12,84,220,148,100,95,229,122,118,104,69,99,82,123,223,126,219,117,119,80,149,98,52,89,15,144,248,81,195,121,129,122,254,86,146,95,20,144,130,109,96,92,31,87,16,84,84,81,77,110,226,86,168,99,147,152,127,129,21,135,42,137,0,144,30,84,111,92,192,129,214,98,88,98,49,129,53,158,64,150,110,154,124,154,45,105,165,89,211,98,62,85,22,99,199,84,217,134,60,109,3,90,230,116,156,136,106,107,22,89,76,140,47,95,126,110,169,115,125,152,56,78,247,112,140,91,151,120,61,99,90,102,150,118,203,96,155,91,73,90,7,78,85,129,106,108,139,115,161,78,137,103,81,127,128,95,250,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1006060);
/* memory initializer */ allocate([27,103,216,95,132,89,1,90,25,135,27,135,29,135,31,135,32,135,36,135,38,135,39,135,40,135,42,135,43,135,44,135,45,135,47,135,48,135,50,135,51,135,53,135,54,135,56,135,57,135,58,135,60,135,61,135,64,135,65,135,66,135,67,135,68,135,69,135,70,135,74,135,75,135,77,135,79,135,80,135,81,135,82,135,84,135,85,135,86,135,88,135,90,135,91,135,92,135,93,135,94,135,95,135,97,135,98,135,102,135,103,135,104,135,105,135,106,135,107,135,108,135,109,135,111,135,113,135,114,135,115,135,117,135,119,135,120,135,121,135,122,135,127,135,128,135,129,135,132,135,134,135,135,135,137,135,138,135,140,135,142,135,143,135,144,135,145,135,146,135,148,135,149,135,150,135,152,135,153,135,154,135,155,135,156,135,157,135,158,135,160,135,161,135,162,135,163,135,164,135,205,93,174,95,113,83,230,151,221,143,69,104,244,86,47,85,223,96,58,78,77,111,244,126,199,130,14,132,212,89,31,79,42,79,62,92,172,126,42,103,26,133,115,84,79,117,195,128,130,85,79,155,77,79,45,110,19,140,9,92,112,97,107,83,31,118,41,110,138,134,135,101,251,149,185,126,59,84,51,122,10,125,238,149,225,85,193,127,238,116,29,99,23,135,161,109,157,122,17,98,161,101,103,83,225,99,131,108,235,93,92,84,168,148,76,78,97,108,236,139,75,92,224,101,156,130,167,104,62,84,52,84,203,107,102,107,148,78,66,99,72,83,30,130,13,79,174,79,94,87,10,98,254,150,100,102,105,114,255,82,161,82,159,96,239,139,20,102,153,113,144,103,127,137,82,120,253,119,112,102,59,86,56,84,33,149,122,114,165,135,166,135,167,135,169,135,170,135,174,135,176,135,177,135,178,135,180,135,182,135,183,135,184,135,185,135,187,135,188,135,190,135,191,135,193,135,194,135,195,135,196,135,197,135,199,135,200,135,201,135,204,135,205,135,206,135,207,135,208,135,212,135,213,135,214,135,215,135,216,135,217,135,218,135,220,135,221,135,222,135,223,135,225,135,226,135,227,135,228,135,230,135,231,135,232,135,233,135,235,135,236,135,237,135,239,135,240,135,241,135,242,135,243,135,244,135,245,135,246,135,247,135,248,135,250,135,251,135,252,135,253,135,255,135,0,136,1,136,2,136,4,136,5,136,6,136,7,136,8,136,9,136,11,136,12,136,13,136,14,136,15,136,16,136,17,136,18,136,20,136,23,136,24,136,25,136,26,136,28,136,29,136,30,136,31,136,32,136,35,136,0,122,111,96,12,94,137,96,157,129,21,89,220,96,132,113,239,112,170,110,80,108,128,114,132,106,173,136,45,94,96,78,179,90,156,85,227,148,23,109,251,124,153,150,15,98,198,126,142,119,126,134,35,83,30,151,150,143,135,102,225,92,160,79,237,114,11,78,166,83,15,89,19,84,128,99,40,149,72,81,217,78,156,156,164,126,184,84,36,141,84,136,55,130,242,149,142,109,38,95,204,90,62,102,105,150,176,115,46,115,191,83,122,129,133,153,161,127,170,91,119,150,80,150,191,126,248,118,162,83,118,149,153,153,177,123,68,137,88,110,97,78,212,127,101,121,230,139,243,96,205,84,171,78,121,152,247,93,97,106,207,80,17,84,97,140,39,132,93,120,4,151,74,82,238,84,163,86,0,149,136,109,181,91,198,109,83,102,36,136,37,136,38,136,39,136,40,136,41,136,42,136,43,136,44,136,45,136,46,136,47,136,48,136,49,136,51,136,52,136,53,136,54,136,55,136,56,136,58,136,59,136,61,136,62,136,63,136,65,136,66,136,67,136,70,136,71,136,72,136,73,136,74,136,75,136,78,136,79,136,80,136,81,136,82,136,83,136,85,136,86,136,88,136,90,136,91,136,92,136,93,136,94,136,95,136,96,136,102,136,103,136,106,136,109,136,111,136,113,136,115,136,116,136,117,136,118,136,120,136,121,136,122,136,123,136,124,136,128,136,131,136,134,136,135,136,137,136,138,136,140,136,142,136,143,136,144,136,145,136,147,136,148,136,149,136,151,136,152,136,153,136,154,136,155,136,157,136,158,136,159,136,160,136,161,136,163,136,165,136,166,136,167,136,168,136,169,136,170,136,15,92,93,91,33,104,150,128,120,85,17,123,72,101,84,105,155,78,71,107,78,135,139,151,79,83,31,99,58,100,170,144,156,101,193,128,16,140,153,81,176,104,120,83,249,135,200,97,196,108,251,108,34,140,81,92,170,133,175,130,12,149,35,107,155,143,176,101,251,95,195,95,225,79,69,136,31,102,101,129,41,115,250,96,116,81,17,82,139,87,98,95,162,144,76,136,146,145,120,94,79,103,39,96,211,89,68,81,246,81,248,128,8,83,121,108,196,150,138,113,17,79,238,79,158,127,61,103,197,85,8,149,192,121,150,136,227,126,159,88,12,98,0,151,90,134,24,86,123,152,144,95,184,139,196,132,87,145,217,83,237,101,143,94,92,117,100,96,110,125,127,90,234,126,237,126,105,143,167,85,163,91,172,96,203,101,132,115,172,136,174,136,175,136,176,136,178,136,179,136,180,136,181,136,182,136,184,136,185,136,186,136,187,136,189,136,190,136,191,136,192,136,195,136,196,136,199,136,200,136,202,136,203,136,204,136,205,136,207,136,208,136,209,136,211,136,214,136,215,136,218,136,219,136,220,136,221,136,222,136,224,136,225,136,230,136,231,136,233,136,234,136,235,136,236,136,237,136,238,136,239,136,242,136,245,136,246,136,247,136,250,136,251,136,253,136,255,136,0,137,1,137,3,137,4,137,5,137,6,137,7,137,8,137,9,137,11,137,12,137,13,137,14,137,15,137,17,137,20,137,21,137,22,137,23,137,24,137,28,137,29,137,30,137,31,137,32,137,34,137,35,137,36,137,38,137,39,137,40,137,41,137,44,137,45,137,46,137,47,137,49,137,50,137,51,137,53,137,55,137,9,144,99,118,41,119,218,126,116,151,155,133,102,91,116,122,234,150,64,136,203,82,143,113,170,95,236,101,226,139,251,91,111,154,225,93,137,107,91,108,173,139,175,139,10,144,197,143,139,83,188,98,38,158,45,158,64,84,43,78,189,130,89,114,156,134,22,93,89,136,175,109,197,150,209,84,154,78,182,139,9,113,189,84,9,150,223,112,249,109,208,118,37,78,20,120,18,135,169,92,246,94,0,138,156,152,14,150,142,112,191,108,68,89,169,99,60,119,77,136,20,111,115,130,48,88,213,113,140,83,26,120,193,150,1,85,102,95,48,113,180,91,26,140,140,154,131,107,46,89,47,158,231,121,104,103,108,98,111,79,161,117,138,127,11,109,51,150,39,108,240,78,210,117,123,81,55,104,62,111,128,144,112,129,150,89,118,116,56,137,57,137,58,137,59,137,60,137,61,137,62,137,63,137,64,137,66,137,67,137,69,137,70,137,71,137,72,137,73,137,74,137,75,137,76,137,77,137,78,137,79,137,80,137,81,137,82,137,83,137,84,137,85,137,86,137,87,137,88,137,89,137,90,137,91,137,92,137,93,137,96,137,97,137,98,137,99,137,100,137,101,137,103,137,104,137,105,137,106,137,107,137,108,137,109,137,110,137,111,137,112,137,113,137,114,137,115,137,116,137,117,137,118,137,119,137,120,137,121,137,122,137,124,137,125,137,126,137,128,137,130,137,132,137,133,137,135,137,136,137,137,137,138,137,139,137,140,137,141,137,142,137,143,137,144,137,145,137,146,137,147,137,148,137,149,137,150,137,151,137,152,137,153,137,154,137,155,137,156,137,157,137,158,137,159,137,160,137,161,137,71,100,39,92,101,144,145,122,35,140,218,89,172,84,0,130,111,131,129,137,0,128,48,105,78,86,54,128,55,114,206,145,182,81,95,78,117,152,150,99,26,78,246,83,243,102,75,129,28,89,178,109,0,78,249,88,59,83,214,99,241,148,157,79,10,79,99,136,144,152,55,89,87,144,251,121,234,78,240,128,145,117,130,108,156,91,232,89,93,95,5,105,129,134,26,80,242,93,89,78,227,119,229,78,122,130,145,98,19,102,145,144,121,92,191,78,121,95,198,129,56,144,132,128,171,117,166,78,212,136,15,97,197,107,198,95,73,78,202,118,162,110,227,139,174,139,10,140,209,139,2,95,252,127,204,127,206,126,53,131,107,131,224,86,183,107,243,151,52,150,251,89,31,84,246,148,235,109,197,91,110,153,57,92,21,95,144,150,162,137,163,137,164,137,165,137,166,137,167,137,168,137,169,137,170,137,171,137,172,137,173,137,174,137,175,137,176,137,177,137,178,137,179,137,180,137,181,137,182,137,183,137,184,137,185,137,186,137,187,137,188,137,189,137,190,137,191,137,192,137,195,137,205,137,211,137,212,137,213,137,215,137,216,137,217,137,219,137,221,137,223,137,224,137,225,137,226,137,228,137,231,137,232,137,233,137,234,137,236,137,237,137,238,137,240,137,241,137,242,137,244,137,245,137,246,137,247,137,248,137,249,137,250,137,251,137,252,137,253,137,254,137,255,137,1,138,2,138,3,138,4,138,5,138,6,138,8,138,9,138,10,138,11,138,12,138,13,138,14,138,15,138,16,138,17,138,18,138,19,138,20,138,21,138,22,138,23,138,24,138,25,138,26,138,27,138,28,138,29,138,112,83,241,130,49,106,116,90,112,158,148,94,40,127,185,131,36,132,37,132,103,131,71,135,206,143,98,141,200,118,113,95,150,152,108,120,32,102,223,84,229,98,99,79,195,129,200,117,184,94,205,150,10,142,249,134,143,84,243,108,140,109,56,108,127,96,199,82,40,117,125,94,24,79,160,96,231,95,36,92,49,117,174,144,192,148,185,114,185,108,56,110,73,145,9,103,203,83,243,83,81,79,201,145,241,139,200,83,124,94,194,143,228,109,142,78,194,118,134,105,94,134,26,97,6,130,89,79,222,79,62,144,124,156,9,97,29,110,20,110,133,150,136,78,49,90,232,150,14,78,127,92,185,121,135,91,237,139,189,127,137,115,223,87,139,130,193,144,1,84,71,144,187,85,234,92,161,95,8,97,50,107,241,114,178,128,137,138,30,138,31,138,32,138,33,138,34,138,35,138,36,138,37,138,38,138,39,138,40,138,41,138,42,138,43,138,44,138,45,138,46,138,47,138,48,138,49,138,50,138,51,138,52,138,53,138,54,138,55,138,56,138,57,138,58,138,59,138,60,138,61,138,63,138,64,138,65,138,66,138,67,138,68,138,69,138,70,138,71,138,73,138,74,138,75,138,76,138,77,138,78,138,79,138,80,138,81,138,82,138,83,138,84,138,85,138,86,138,87,138,88,138,89,138,90,138,91,138,92,138,93,138,94,138,95,138,96,138,97,138,98,138,99,138,100,138,101,138,102,138,103,138,104,138,105,138,106,138,107,138,108,138,109,138,110,138,111,138,112,138,113,138,114,138,115,138,116,138,117,138,118,138,119,138,120,138,122,138,123,138,124,138,125,138,126,138,127,138,128,138,116,109,211,91,213,136,132,152,107,140,109,154,51,158,10,110,164,81,67,81,163,87,129,136,159,83,244,99,149,143,237,86,88,84,6,87,63,115,144,110,24,127,220,143,209,130,63,97,40,96,98,150,240,102,166,126,138,141,195,141,165,148,179,92,164,124,8,103,166,96,5,150,24,128,145,78,231,144,0,83,104,150,65,81,208,143,116,133,93,145,85,102,245,151,85,91,29,83,56,120,66,103,61,104,201,84,126,112,176,91,125,143,141,81,40,87,177,84,18,101,130,102,94,141,67,141,15,129,108,132,109,144,223,124,255,81,251,133,163,103,233,101,161,111,164,134,129,142,106,86,32,144,130,118,118,112,229,113,35,141,233,98,25,82,253,108,60,141,14,96,158,88,142,97,254,102,96,141,78,98,179,85,35,110,45,103,103,143,129,138,130,138,131,138,132,138,133,138,134,138,135,138,136,138,139,138,140,138,141,138,142,138,143,138,144,138,145,138,146,138,148,138,149,138,150,138,151,138,152,138,153,138,154,138,155,138,156,138,157,138,158,138,159,138,160,138,161,138,162,138,163,138,164,138,165,138,166,138,167,138,168,138,169,138,170,138,171,138,172,138,173,138,174,138,175,138,176,138,177,138,178,138,179,138,180,138,181,138,182,138,183,138,184,138,185,138,186,138,187,138,188,138,189,138,190,138,191,138,192,138,193,138,194,138,195,138,196,138,197,138,198,138,199,138,200,138,201,138,202,138,203,138,204,138,205,138,206,138,207,138,208,138,209,138,210,138,211,138,212,138,213,138,214,138,215,138,216,138,217,138,218,138,219,138,220,138,221,138,222,138,223,138,224,138,225,138,226,138,227,138,225,148,248,149,40,119,5,104,168,105,139,84,77,78,184,112,200,139,88,100,139,101,133,91,132,122,58,80,232,91,187,119,225,107,121,138,152,124,190,108,207,118,169,101,151,143,45,93,85,92,56,134,8,104,96,83,24,98,217,122,91,110,253,126,31,106,224,122,112,95,51,111,32,95,140,99,168,109,86,103,8,78,16,94,38,141,215,78,192,128,52,118,156,150,219,98,45,102,126,98,188,108,117,141,103,113,105,127,70,81,135,128,236,83,110,144,152,98,242,84,240,134,153,143,5,128,23,149,23,133,217,143,89,109,205,115,159,101,31,119,4,117,39,120,251,129,30,141,136,148,166,79,149,103,185,117,202,139,7,151,47,99,71,149,53,150,184,132,35,99,65,119,129,95,240,114,137,78,20,96,116,101,239,98,99,107,63,101,228,138,229,138,230,138,231,138,232,138,233,138,234,138,235,138,236,138,237,138,238,138,239,138,240,138,241,138,242,138,243,138,244,138,245,138,246,138,247,138,248,138,249,138,250,138,251,138,252,138,253,138,254,138,255,138,0,139,1,139,2,139,3,139,4,139,5,139,6,139,8,139,9,139,10,139,11,139,12,139,13,139,14,139,15,139,16,139,17,139,18,139,19,139,20,139,21,139,22,139,23,139,24,139,25,139,26,139,27,139,28,139,29,139,30,139,31,139,32,139,33,139,34,139,35,139,36,139,37,139,39,139,40,139,41,139,42,139,43,139,44,139,45,139,46,139,47,139,48,139,49,139,50,139,51,139,52,139,53,139,54,139,55,139,56,139,57,139,58,139,59,139,60,139,61,139,62,139,63,139,64,139,65,139,66,139,67,139,68,139,69,139,39,94,199,117,209,144,193,139,157,130,157,103,47,101,49,84,24,135,229,119,162,128,2,129,65,108,75,78,199,126,76,128,244,118,13,105,150,107,103,98,60,80,132,79,64,87,7,99,98,107,190,141,234,83,232,101,184,126,215,95,26,99,183,99,243,129,244,129,110,127,28,94,217,92,54,82,122,102,233,121,26,122,40,141,153,112,212,117,222,110,187,108,146,122,45,78,197,118,224,95,159,148,119,136,200,126,205,121,191,128,205,145,242,78,23,79,31,130,104,84,222,93,50,109,204,139,165,124,116,143,152,128,26,94,146,84,177,118,153,91,60,102,164,154,224,115,42,104,219,134,49,103,42,115,248,139,219,139,16,144,249,122,219,112,110,113,196,98,169,119,49,86,59,78,87,132,241,103,169,82,192,134,46,141,248,148,81,123,70,139,71,139,72,139,73,139,74,139,75,139,76,139,77,139,78,139,79,139,80,139,81,139,82,139,83,139,84,139,85,139,86,139,87,139,88,139,89,139,90,139,91,139,92,139,93,139,94,139,95,139,96,139,97,139,98,139,99,139,100,139,101,139,103,139,104,139,105,139,106,139,107,139,109,139,110,139,111,139,112,139,113,139,114,139,115,139,116,139,117,139,118,139,119,139,120,139,121,139,122,139,123,139,124,139,125,139,126,139,127,139,128,139,129,139,130,139,131,139,132,139,133,139,134,139,135,139,136,139,137,139,138,139,139,139,140,139,141,139,142,139,143,139,144,139,145,139,146,139,147,139,148,139,149,139,150,139,151,139,152,139,153,139,154,139,155,139,156,139,157,139,158,139,159,139,172,139,177,139,187,139,199,139,208,139,234,139,9,140,30,140,79,79,232,108,93,121,123,154,147,98,42,114,253,98,19,78,22,120,108,143,176,100,90,141,198,123,105,104,132,94,197,136,134,89,158,100,238,88,182,114,14,105,37,149,253,143,88,141,96,87,0,127,6,140,198,81,73,99,217,98,83,83,76,104,34,116,1,131,76,145,68,85,64,119,124,112,74,109,121,81,168,84,68,141,255,89,203,110,196,109,92,91,43,125,212,78,125,124,211,110,80,91,234,129,13,110,87,91,3,155,213,104,42,142,151,91,252,126,59,96,181,126,185,144,112,141,79,89,205,99,223,121,179,141,82,83,207,101,86,121,197,139,59,150,196,126,187,148,130,126,52,86,137,145,0,103,106,127,10,92,117,144,40,102,230,93,80,79,222,103,90,80,92,79,80,87,167,94,16,232,17,232,18,232,19,232,20,232,56,140,57,140,58,140,59,140,60,140,61,140,62,140,63,140,64,140,66,140,67,140,68,140,69,140,72,140,74,140,75,140,77,140,78,140,79,140,80,140,81,140,82,140,83,140,84,140,86,140,87,140,88,140,89,140,91,140,92,140,93,140,94,140,95,140,96,140,99,140,100,140,101,140,102,140,103,140,104,140,105,140,108,140,109,140,110,140,111,140,112,140,113,140,114,140,116,140,117,140,118,140,119,140,123,140,124,140,125,140,126,140,127,140,128,140,129,140,131,140,132,140,134,140,135,140,136,140,139,140,141,140,142,140,143,140,144,140,145,140,146,140,147,140,149,140,150,140,151,140,153,140,154,140,155,140,156,140,157,140,158,140,159,140,160,140,161,140,162,140,163,140,164,140,165,140,166,140,167,140,168,140,169,140,170,140,171,140,172,140,173,140,141,78,12,78,64,81,16,78,255,94,69,83,21,78,152,78,30,78,50,155,108,91,105,86,40,78,186,121,63,78,21,83,71,78,45,89,59,114,110,83,16,108,223,86,228,128,151,153,211,107,126,119,23,159,54,78,159,78,16,159,92,78,105,78,147,78,136,130,91,91,108,85,15,86,196,78,141,83,157,83,163,83,165,83,174,83,101,151,93,141,26,83,245,83,38,83,46,83,62,83,92,141,102,83,99,83,2,82,8,82,14,82,45,82,51,82,63,82,64,82,76,82,94,82,97,82,92,82,175,132,125,82,130,82,129,82,144,82,147,82,130,81,84,127,187,78,195,78,201,78,194,78,232,78,225,78,235,78,222,78,27,79,243,78,34,79,100,79,245,78,37,79,39,79,9,79,43,79,94,79,103,79,56,101,90,79,93,79,174,140,175,140,176,140,177,140,178,140,179,140,180,140,181,140,182,140,183,140,184,140,185,140,186,140,187,140,188,140,189,140,190,140,191,140,192,140,193,140,194,140,195,140,196,140,197,140,198,140,199,140,200,140,201,140,202,140,203,140,204,140,205,140,206,140,207,140,208,140,209,140,210,140,211,140,212,140,213,140,214,140,215,140,216,140,217,140,218,140,219,140,220,140,221,140,222,140,223,140,224,140,225,140,226,140,227,140,228,140,229,140,230,140,231,140,232,140,233,140,234,140,235,140,236,140,237,140,238,140,239,140,240,140,241,140,242,140,243,140,244,140,245,140,246,140,247,140,248,140,249,140,250,140,251,140,252,140,253,140,254,140,255,140,0,141,1,141,2,141,3,141,4,141,5,141,6,141,7,141,8,141,9,141,10,141,11,141,12,141,13,141,95,79,87,79,50,79,61,79,118,79,116,79,145,79,137,79,131,79,143,79,126,79,123,79,170,79,124,79,172,79,148,79,230,79,232,79,234,79,197,79,218,79,227,79,220,79,209,79,223,79,248,79,41,80,76,80,243,79,44,80,15,80,46,80,45,80,254,79,28,80,12,80,37,80,40,80,126,80,67,80,85,80,72,80,78,80,108,80,123,80,165,80,167,80,169,80,186,80,214,80,6,81,237,80,236,80,230,80,238,80,7,81,11,81,221,78,61,108,88,79,101,79,206,79,160,159,70,108,116,124,110,81,253,93,201,158,152,153,129,81,20,89,249,82,13,83,7,138,16,83,235,81,25,89,85,81,160,78,86,81,179,78,110,136,164,136,181,78,20,129,210,136,128,121,52,91,3,136,184,127,171,81,177,81,189,81,188,81,14,141,15,141,16,141,17,141,18,141,19,141,20,141,21,141,22,141,23,141,24,141,25,141,26,141,27,141,28,141,32,141,81,141,82,141,87,141,95,141,101,141,104,141,105,141,106,141,108,141,110,141,111,141,113,141,114,141,120,141,121,141,122,141,123,141,124,141,125,141,126,141,127,141,128,141,130,141,131,141,134,141,135,141,136,141,137,141,140,141,141,141,142,141,143,141,144,141,146,141,147,141,149,141,150,141,151,141,152,141,153,141,154,141,155,141,156,141,157,141,158,141,160,141,161,141,162,141,164,141,165,141,166,141,167,141,168,141,169,141,170,141,171,141,172,141,173,141,174,141,175,141,176,141,178,141,182,141,183,141,185,141,187,141,189,141,192,141,193,141,194,141,197,141,199,141,200,141,201,141,202,141,205,141,208,141,210,141,211,141,212,141,199,81,150,81,162,81,165,81,160,139,166,139,167,139,170,139,180,139,181,139,183,139,194,139,195,139,203,139,207,139,206,139,210,139,211,139,212,139,214,139,216,139,217,139,220,139,223,139,224,139,228,139,232,139,233,139,238,139,240,139,243,139,246,139,249,139,252,139,255,139,0,140,2,140,4,140,7,140,12,140,15,140,17,140,18,140,20,140,21,140,22,140,25,140,27,140,24,140,29,140,31,140,32,140,33,140,37,140,39,140,42,140,43,140,46,140,47,140,50,140,51,140,53,140,54,140,105,83,122,83,29,150,34,150,33,150,49,150,42,150,61,150,60,150,66,150,73,150,84,150,95,150,103,150,108,150,114,150,116,150,136,150,141,150,151,150,176,150,151,144,155,144,157,144,153,144,172,144,161,144,180,144,179,144,182,144,186,144,213,141,216,141,217,141,220,141,224,141,225,141,226,141,229,141,230,141,231,141,233,141,237,141,238,141,240,141,241,141,242,141,244,141,246,141,252,141,254,141,255,141,0,142,1,142,2,142,3,142,4,142,6,142,7,142,8,142,11,142,13,142,14,142,16,142,17,142,18,142,19,142,21,142,22,142,23,142,24,142,25,142,26,142,27,142,28,142,32,142,33,142,36,142,37,142,38,142,39,142,40,142,43,142,45,142,48,142,50,142,51,142,52,142,54,142,55,142,56,142,59,142,60,142,62,142,63,142,67,142,69,142,70,142,76,142,77,142,78,142,79,142,80,142,83,142,84,142,85,142,86,142,87,142,88,142,90,142,91,142,92,142,93,142,94,142,95,142,96,142,97,142,98,142,99,142,100,142,101,142,103,142,104,142,106,142,107,142,110,142,113,142,184,144,176,144,207,144,197,144,190,144,208,144,196,144,199,144,211,144,230,144,226,144,220,144,215,144,219,144,235,144,239,144,254,144,4,145,34,145,30,145,35,145,49,145,47,145,57,145,67,145,70,145,13,82,66,89,162,82,172,82,173,82,190,82,255,84,208,82,214,82,240,82,223,83,238,113,205,119,244,94,245,81,252,81,47,155,182,83,1,95,90,117,239,93,76,87,169,87,161,87,126,88,188,88,197,88,209,88,41,87,44,87,42,87,51,87,57,87,46,87,47,87,92,87,59,87,66,87,105,87,133,87,107,87,134,87,124,87,123,87,104,87,109,87,118,87,115,87,173,87,164,87,140,87,178,87,207,87,167,87,180,87,147,87,160,87,213,87,216,87,218,87,217,87,210,87,184,87,244,87,239,87,248,87,228,87,221,87,115,142,117,142,119,142,120,142,121,142,122,142,123,142,125,142,126,142,128,142,130,142,131,142,132,142,134,142,136,142,137,142,138,142,139,142,140,142,141,142,142,142,145,142,146,142,147,142,149,142,150,142,151,142,152,142,153,142,154,142,155,142,157,142,159,142,160,142,161,142,162,142,163,142,164,142,165,142,166,142,167,142,168,142,169,142,170,142,173,142,174,142,176,142,177,142,179,142,180,142,181,142,182,142,183,142,184,142,185,142,187,142,188,142,189,142,190,142,191,142,192,142,193,142,194,142,195,142,196,142,197,142,198,142,199,142,200,142,201,142,202,142,203,142,204,142,205,142,207,142,208,142,209,142,210,142,211,142,212,142,213,142,214,142,215,142,216,142,217,142,218,142,219,142,220,142,221,142,222,142,223,142,224,142,225,142,226,142,227,142,228,142,11,88,13,88,253,87,237,87,0,88,30,88,25,88,68,88,32,88,101,88,108,88,129,88,137,88,154,88,128,88,168,153,25,159,255,97,121,130,125,130,127,130,143,130,138,130,168,130,132,130,142,130,145,130,151,130,153,130,171,130,184,130,190,130,176,130,200,130,202,130,227,130,152,130,183,130,174,130,203,130,204,130,193,130,169,130,180,130,161,130,170,130,159,130,196,130,206,130,164,130,225,130,9,131,247,130,228,130,15,131,7,131,220,130,244,130,210,130,216,130,12,131,251,130,211,130,17,131,26,131,6,131,20,131,21,131,224,130,213,130,28,131,81,131,91,131,92,131,8,131,146,131,60,131,52,131,49,131,155,131,94,131,47,131,79,131,71,131,67,131,95,131,64,131,23,131,96,131,45,131,58,131,51,131,102,131,101,131,229,142,230,142,231,142,232,142,233,142,234,142,235,142,236,142,237,142,238,142,239,142,240,142,241,142,242,142,243,142,244,142,245,142,246,142,247,142,248,142,249,142,250,142,251,142,252,142,253,142,254,142,255,142,0,143,1,143,2,143,3,143,4,143,5,143,6,143,7,143,8,143,9,143,10,143,11,143,12,143,13,143,14,143,15,143,16,143,17,143,18,143,19,143,20,143,21,143,22,143,23,143,24,143,25,143,26,143,27,143,28,143,29,143,30,143,31,143,32,143,33,143,34,143,35,143,36,143,37,143,38,143,39,143,40,143,41,143,42,143,43,143,44,143,45,143,46,143,47,143,48,143,49,143,50,143,51,143,52,143,53,143,54,143,55,143,56,143,57,143,58,143,59,143,60,143,61,143,62,143,63,143,64,143,65,143,66,143,67,143,68,143,104,131,27,131,105,131,108,131,106,131,109,131,110,131,176,131,120,131,179,131,180,131,160,131,170,131,147,131,156,131,133,131,124,131,182,131,169,131,125,131,184,131,123,131,152,131,158,131,168,131,186,131,188,131,193,131,1,132,229,131,216,131,7,88,24,132,11,132,221,131,253,131,214,131,28,132,56,132,17,132,6,132,212,131,223,131,15,132,3,132,248,131,249,131,234,131,197,131,192,131,38,132,240,131,225,131,92,132,81,132,90,132,89,132,115,132,135,132,136,132,122,132,137,132,120,132,60,132,70,132,105,132,118,132,140,132,142,132,49,132,109,132,193,132,205,132,208,132,230,132,189,132,211,132,202,132,191,132,186,132,224,132,161,132,185,132,180,132,151,132,229,132,227,132,12,133,13,117,56,133,240,132,57,133,31,133,58,133,69,143,70,143,71,143,72,143,73,143,74,143,75,143,76,143,77,143,78,143,79,143,80,143,81,143,82,143,83,143,84,143,85,143,86,143,87,143,88,143,89,143,90,143,91,143,92,143,93,143,94,143,95,143,96,143,97,143,98,143,99,143,100,143,101,143,106,143,128,143,140,143,146,143,157,143,160,143,161,143,162,143,164,143,165,143,166,143,167,143,170,143,172,143,173,143,174,143,175,143,178,143,179,143,180,143,181,143,183,143,184,143,186,143,187,143,188,143,191,143,192,143,195,143,198,143,201,143,202,143,203,143,204,143,205,143,207,143,210,143,214,143,215,143,218,143,224,143,225,143,227,143,231,143,236,143,239,143,241,143,242,143,244,143,245,143,246,143,250,143,251,143,252,143,254,143,255,143,7,144,8,144,12,144,14,144,19,144,21,144,24,144,86,133,59,133,255,132,252,132,89,133,72,133,104,133,100,133,94,133,122,133,162,119,67,133,114,133,123,133,164,133,168,133,135,133,143,133,121,133,174,133,156,133,133,133,185,133,183,133,176,133,211,133,193,133,220,133,255,133,39,134,5,134,41,134,22,134,60,134,254,94,8,95,60,89,65,89,55,128,85,89,90,89,88,89,15,83,34,92,37,92,44,92,52,92,76,98,106,98,159,98,187,98,202,98,218,98,215,98,238,98,34,99,246,98,57,99,75,99,67,99,173,99,246,99,113,99,122,99,142,99,180,99,109,99,172,99,138,99,105,99,174,99,188,99,242,99,248,99,224,99,255,99,196,99,222,99,206,99,82,100,198,99,190,99,69,100,65,100,11,100,27,100,32,100,12,100,38,100,33,100,94,100,132,100,109,100,150,100,25,144,28,144,35,144,36,144,37,144,39,144,40,144,41,144,42,144,43,144,44,144,48,144,49,144,50,144,51,144,52,144,55,144,57,144,58,144,61,144,63,144,64,144,67,144,69,144,70,144,72,144,73,144,74,144,75,144,76,144,78,144,84,144,85,144,86,144,89,144,90,144,92,144,93,144,94,144,95,144,96,144,97,144,100,144,102,144,103,144,105,144,106,144,107,144,108,144,111,144,112,144,113,144,114,144,115,144,118,144,119,144,120,144,121,144,122,144,123,144,124,144,126,144,129,144,132,144,133,144,134,144,135,144,137,144,138,144,140,144,141,144,142,144,143,144,144,144,146,144,148,144,150,144,152,144,154,144,156,144,158,144,159,144,160,144,164,144,165,144,167,144,168,144,169,144,171,144,173,144,178,144,183,144,188,144,189,144,191,144,192,144,122,100,183,100,184,100,153,100,186,100,192,100,208,100,215,100,228,100,226,100,9,101,37,101,46,101,11,95,210,95,25,117,17,95,95,83,241,83,253,83,233,83,232,83,251,83,18,84,22,84,6,84,75,84,82,84,83,84,84,84,86,84,67,84,33,84,87,84,89,84,35,84,50,84,130,84,148,84,119,84,113,84,100,84,154,84,155,84,132,84,118,84,102,84,157,84,208,84,173,84,194,84,180,84,210,84,167,84,166,84,211,84,212,84,114,84,163,84,213,84,187,84,191,84,204,84,217,84,218,84,220,84,169,84,170,84,164,84,221,84,207,84,222,84,27,85,231,84,32,85,253,84,20,85,243,84,34,85,35,85,15,85,17,85,39,85,42,85,103,85,143,85,181,85,73,85,109,85,65,85,85,85,63,85,80,85,60,85,194,144,195,144,198,144,200,144,201,144,203,144,204,144,205,144,210,144,212,144,213,144,214,144,216,144,217,144,218,144,222,144,223,144,224,144,227,144,228,144,229,144,233,144,234,144,236,144,238,144,240,144,241,144,242,144,243,144,245,144,246,144,247,144,249,144,250,144,251,144,252,144,255,144,0,145,1,145,3,145,5,145,6,145,7,145,8,145,9,145,10,145,11,145,12,145,13,145,14,145,15,145,16,145,17,145,18,145,19,145,20,145,21,145,22,145,23,145,24,145,26,145,27,145,28,145,29,145,31,145,32,145,33,145,36,145,37,145,38,145,39,145,40,145,41,145,42,145,43,145,44,145,45,145,46,145,48,145,50,145,51,145,52,145,53,145,54,145,55,145,56,145,58,145,59,145,60,145,61,145,62,145,63,145,64,145,65,145,66,145,68,145,55,85,86,85,117,85,118,85,119,85,51,85,48,85,92,85,139,85,210,85,131,85,177,85,185,85,136,85,129,85,159,85,126,85,214,85,145,85,123,85,223,85,189,85,190,85,148,85,153,85,234,85,247,85,201,85,31,86,209,85,235,85,236,85,212,85,230,85,221,85,196,85,239,85,229,85,242,85,243,85,204,85,205,85,232,85,245,85,228,85,148,143,30,86,8,86,12,86,1,86,36,86,35,86,254,85,0,86,39,86,45,86,88,86,57,86,87,86,44,86,77,86,98,86,89,86,92,86,76,86,84,86,134,86,100,86,113,86,107,86,123,86,124,86,133,86,147,86,175,86,212,86,215,86,221,86,225,86,245,86,235,86,249,86,255,86,4,87,10,87,9,87,28,87,15,94,25,94,20,94,17,94,49,94,59,94,60,94,69,145,71,145,72,145,81,145,83,145,84,145,85,145,86,145,88,145,89,145,91,145,92,145,95,145,96,145,102,145,103,145,104,145,107,145,109,145,115,145,122,145,123,145,124,145,128,145,129,145,130,145,131,145,132,145,134,145,136,145,138,145,142,145,143,145,147,145,148,145,149,145,150,145,151,145,152,145,153,145,156,145,157,145,158,145,159,145,160,145,161,145,164,145,165,145,166,145,167,145,168,145,169,145,171,145,172,145,176,145,177,145,178,145,179,145,182,145,183,145,184,145,185,145,187,145,188,145,189,145,190,145,191,145,192,145,193,145,194,145,195,145,196,145,197,145,198,145,200,145,203,145,208,145,210,145,211,145,212,145,213,145,214,145,215,145,216,145,217,145,218,145,219,145,221,145,222,145,223,145,224,145,225,145,226,145,227,145,228,145,229,145,55,94,68,94,84,94,91,94,94,94,97,94,140,92,122,92,141,92,144,92,150,92,136,92,152,92,153,92,145,92,154,92,156,92,181,92,162,92,189,92,172,92,171,92,177,92,163,92,193,92,183,92,196,92,210,92,228,92,203,92,229,92,2,93,3,93,39,93,38,93,46,93,36,93,30,93,6,93,27,93,88,93,62,93,52,93,61,93,108,93,91,93,111,93,93,93,107,93,75,93,74,93,105,93,116,93,130,93,153,93,157,93,115,140,183,93,197,93,115,95,119,95,130,95,135,95,137,95,140,95,149,95,153,95,156,95,168,95,173,95,181,95,188,95,98,136,97,95,173,114,176,114,180,114,183,114,184,114,195,114,193,114,206,114,205,114,210,114,232,114,239,114,233,114,242,114,244,114,247,114,1,115,243,114,3,115,250,114,230,145,231,145,232,145,233,145,234,145,235,145,236,145,237,145,238,145,239,145,240,145,241,145,242,145,243,145,244,145,245,145,246,145,247,145,248,145,249,145,250,145,251,145,252,145,253,145,254,145,255,145,0,146,1,146,2,146,3,146,4,146,5,146,6,146,7,146,8,146,9,146,10,146,11,146,12,146,13,146,14,146,15,146,16,146,17,146,18,146,19,146,20,146,21,146,22,146,23,146,24,146,25,146,26,146,27,146,28,146,29,146,30,146,31,146,32,146,33,146,34,146,35,146,36,146,37,146,38,146,39,146,40,146,41,146,42,146,43,146,44,146,45,146,46,146,47,146,48,146,49,146,50,146,51,146,52,146,53,146,54,146,55,146,56,146,57,146,58,146,59,146,60,146,61,146,62,146,63,146,64,146,65,146,66,146,67,146,68,146,69,146,251,114,23,115,19,115,33,115,10,115,30,115,29,115,21,115,34,115,57,115,37,115,44,115,56,115,49,115,80,115,77,115,87,115,96,115,108,115,111,115,126,115,27,130,37,89,231,152,36,89,2,89,99,153,103,153,104,153,105,153,106,153,107,153,108,153,116,153,119,153,125,153,128,153,132,153,135,153,138,153,141,153,144,153,145,153,147,153,148,153,149,153,128,94,145,94,139,94,150,94,165,94,160,94,185,94,181,94,190,94,179,94,83,141,210,94,209,94,219,94,232,94,234,94,186,129,196,95,201,95,214,95,207,95,3,96,238,95,4,96,225,95,228,95,254,95,5,96,6,96,234,95,237,95,248,95,25,96,53,96,38,96,27,96,15,96,13,96,41,96,43,96,10,96,63,96,33,96,120,96,121,96,123,96,122,96,66,96,70,146,71,146,72,146,73,146,74,146,75,146,76,146,77,146,78,146,79,146,80,146,81,146,82,146,83,146,84,146,85,146,86,146,87,146,88,146,89,146,90,146,91,146,92,146,93,146,94,146,95,146,96,146,97,146,98,146,99,146,100,146,101,146,102,146,103,146,104,146,105,146,106,146,107,146,108,146,109,146,110,146,111,146,112,146,113,146,114,146,115,146,117,146,118,146,119,146,120,146,121,146,122,146,123,146,124,146,125,146,126,146,127,146,128,146,129,146,130,146,131,146,132,146,133,146,134,146,135,146,136,146,137,146,138,146,139,146,140,146,141,146,143,146,144,146,145,146,146,146,147,146,148,146,149,146,150,146,151,146,152,146,153,146,154,146,155,146,156,146,157,146,158,146,159,146,160,146,161,146,162,146,163,146,164,146,165,146,166,146,167,146,106,96,125,96,150,96,154,96,173,96,157,96,131,96,146,96,140,96,155,96,236,96,187,96,177,96,221,96,216,96,198,96,218,96,180,96,32,97,38,97,21,97,35,97,244,96,0,97,14,97,43,97,74,97,117,97,172,97,148,97,167,97,183,97,212,97,245,97,221,95,179,150,233,149,235,149,241,149,243,149,245,149,246,149,252,149,254,149,3,150,4,150,6,150,8,150,10,150,11,150,12,150,13,150,15,150,18,150,21,150,22,150,23,150,25,150,26,150,44,78,63,114,21,98,53,108,84,108,92,108,74,108,163,108,133,108,144,108,148,108,140,108,104,108,105,108,116,108,118,108,134,108,169,108,208,108,212,108,173,108,247,108,248,108,241,108,215,108,178,108,224,108,214,108,250,108,235,108,238,108,177,108,211,108,239,108,254,108,168,146,169,146,170,146,171,146,172,146,173,146,175,146,176,146,177,146,178,146,179,146,180,146,181,146,182,146,183,146,184,146,185,146,186,146,187,146,188,146,189,146,190,146,191,146,192,146,193,146,194,146,195,146,196,146,197,146,198,146,199,146,201,146,202,146,203,146,204,146,205,146,206,146,207,146,208,146,209,146,210,146,211,146,212,146,213,146,214,146,215,146,216,146,217,146,218,146,219,146,220,146,221,146,222,146,223,146,224,146,225,146,226,146,227,146,228,146,229,146,230,146,231,146,232,146,233,146,234,146,235,146,236,146,237,146,238,146,239,146,240,146,241,146,242,146,243,146,244,146,245,146,246,146,247,146,248,146,249,146,250,146,251,146,252,146,253,146,254,146,255,146,0,147,1,147,2,147,3,147,4,147,5,147,6,147,7,147,8,147,9,147,57,109,39,109,12,109,67,109,72,109,7,109,4,109,25,109,14,109,43,109,77,109,46,109,53,109,26,109,79,109,82,109,84,109,51,109,145,109,111,109,158,109,160,109,94,109,147,109,148,109,92,109,96,109,124,109,99,109,26,110,199,109,197,109,222,109,14,110,191,109,224,109,17,110,230,109,221,109,217,109,22,110,171,109,12,110,174,109,43,110,110,110,78,110,107,110,178,110,95,110,134,110,83,110,84,110,50,110,37,110,68,110,223,110,177,110,152,110,224,110,45,111,226,110,165,110,167,110,189,110,187,110,183,110,215,110,180,110,207,110,143,110,194,110,159,110,98,111,70,111,71,111,36,111,21,111,249,110,47,111,54,111,75,111,116,111,42,111,9,111,41,111,137,111,141,111,140,111,120,111,114,111,124,111,122,111,209,111,10,147,11,147,12,147,13,147,14,147,15,147,16,147,17,147,18,147,19,147,20,147,21,147,22,147,23,147,24,147,25,147,26,147,27,147,28,147,29,147,30,147,31,147,32,147,33,147,34,147,35,147,36,147,37,147,38,147,39,147,40,147,41,147,42,147,43,147,44,147,45,147,46,147,47,147,48,147,49,147,50,147,51,147,52,147,53,147,54,147,55,147,56,147,57,147,58,147,59,147,60,147,61,147,63,147,64,147,65,147,66,147,67,147,68,147,69,147,70,147,71,147,72,147,73,147,74,147,75,147,76,147,77,147,78,147,79,147,80,147,81,147,82,147,83,147,84,147,85,147,86,147,87,147,88,147,89,147,90,147,91,147,92,147,93,147,94,147,95,147,96,147,97,147,98,147,99,147,100,147,101,147,102,147,103,147,104,147,105,147,107,147,201,111,167,111,185,111,182,111,194,111,225,111,238,111,222,111,224,111,239,111,26,112,35,112,27,112,57,112,53,112,79,112,94,112,128,91,132,91,149,91,147,91,165,91,184,91,47,117,158,154,52,100,228,91,238,91,48,137,240,91,71,142,7,139,182,143,211,143,213,143,229,143,238,143,228,143,233,143,230,143,243,143,232,143,5,144,4,144,11,144,38,144,17,144,13,144,22,144,33,144,53,144,54,144,45,144,47,144,68,144,81,144,82,144,80,144,104,144,88,144,98,144,91,144,185,102,116,144,125,144,130,144,136,144,131,144,139,144,80,95,87,95,86,95,88,95,59,92,171,84,80,92,89,92,113,91,99,92,102,92,188,127,42,95,41,95,45,95,116,130,60,95,59,155,110,92,129,89,131,89,141,89,169,89,170,89,163,89,108,147,109,147,110,147,111,147,112,147,113,147,114,147,115,147,116,147,117,147,118,147,119,147,120,147,121,147,122,147,123,147,124,147,125,147,126,147,127,147,128,147,129,147,130,147,131,147,132,147,133,147,134,147,135,147,136,147,137,147,138,147,139,147,140,147,141,147,142,147,144,147,145,147,146,147,147,147,148,147,149,147,150,147,151,147,152,147,153,147,154,147,155,147,156,147,157,147,158,147,159,147,160,147,161,147,162,147,163,147,164,147,165,147,166,147,167,147,168,147,169,147,170,147,171,147,172,147,173,147,174,147,175,147,176,147,177,147,178,147,179,147,180,147,181,147,182,147,183,147,184,147,185,147,186,147,187,147,188,147,189,147,190,147,191,147,192,147,193,147,194,147,195,147,196,147,197,147,198,147,199,147,200,147,201,147,203,147,204,147,205,147,151,89,202,89,171,89,158,89,164,89,210,89,178,89,175,89,215,89,190,89,5,90,6,90,221,89,8,90,227,89,216,89,249,89,12,90,9,90,50,90,52,90,17,90,35,90,19,90,64,90,103,90,74,90,85,90,60,90,98,90,117,90,236,128,170,90,155,90,119,90,122,90,190,90,235,90,178,90,210,90,212,90,184,90,224,90,227,90,241,90,214,90,230,90,216,90,220,90,9,91,23,91,22,91,50,91,55,91,64,91,21,92,28,92,90,91,101,91,115,91,81,91,83,91,98,91,117,154,119,154,120,154,122,154,127,154,125,154,128,154,129,154,133,154,136,154,138,154,144,154,146,154,147,154,150,154,152,154,155,154,156,154,157,154,159,154,160,154,162,154,163,154,165,154,167,154,159,126,161,126,163,126,165,126,168,126,169,126,206,147,207,147,208,147,209,147,210,147,211,147,212,147,213,147,215,147,216,147,217,147,218,147,219,147,220,147,221,147,222,147,223,147,224,147,225,147,226,147,227,147,228,147,229,147,230,147,231,147,232,147,233,147,234,147,235,147,236,147,237,147,238,147,239,147,240,147,241,147,242,147,243,147,244,147,245,147,246,147,247,147,248,147,249,147,250,147,251,147,252,147,253,147,254,147,255,147,0,148,1,148,2,148,3,148,4,148,5,148,6,148,7,148,8,148,9,148,10,148,11,148,12,148,13,148,14,148,15,148,16,148,17,148,18,148,19,148,20,148,21,148,22,148,23,148,24,148,25,148,26,148,27,148,28,148,29,148,30,148,31,148,32,148,33,148,34,148,35,148,36,148,37,148,38,148,39,148,40,148,41,148,42,148,43,148,44,148,45,148,46,148,173,126,176,126,190,126,192,126,193,126,194,126,201,126,203,126,204,126,208,126,212,126,215,126,219,126,224,126,225,126,232,126,235,126,238,126,239,126,241,126,242,126,13,127,246,126,250,126,251,126,254,126,1,127,2,127,3,127,7,127,8,127,11,127,12,127,15,127,17,127,18,127,23,127,25,127,28,127,27,127,31,127,33,127,34,127,35,127,36,127,37,127,38,127,39,127,42,127,43,127,44,127,45,127,47,127,48,127,49,127,50,127,51,127,53,127,122,94,127,117,219,93,62,117,149,144,142,115,145,115,174,115,162,115,159,115,207,115,194,115,209,115,183,115,179,115,192,115,201,115,200,115,229,115,217,115,124,152,10,116,233,115,231,115,222,115,186,115,242,115,15,116,42,116,91,116,38,116,37,116,40,116,48,116,46,116,44,116,47,148,48,148,49,148,50,148,51,148,52,148,53,148,54,148,55,148,56,148,57,148,58,148,59,148,60,148,61,148,63,148,64,148,65,148,66,148,67,148,68,148,69,148,70,148,71,148,72,148,73,148,74,148,75,148,76,148,77,148,78,148,79,148,80,148,81,148,82,148,83,148,84,148,85,148,86,148,87,148,88,148,89,148,90,148,91,148,92,148,93,148,94,148,95,148,96,148,97,148,98,148,99,148,100,148,101,148,102,148,103,148,104,148,105,148,106,148,108,148,109,148,110,148,111,148,112,148,113,148,114,148,115,148,116,148,117,148,118,148,119,148,120,148,121,148,122,148,123,148,124,148,125,148,126,148,127,148,128,148,129,148,130,148,131,148,132,148,145,148,150,148,152,148,199,148,207,148,211,148,212,148,218,148,230,148,251,148,28,149,32,149,27,116,26,116,65,116,92,116,87,116,85,116,89,116,119,116,109,116,126,116,156,116,142,116,128,116,129,116,135,116,139,116,158,116,168,116,169,116,144,116,167,116,210,116,186,116,234,151,235,151,236,151,76,103,83,103,94,103,72,103,105,103,165,103,135,103,106,103,115,103,152,103,167,103,117,103,168,103,158,103,173,103,139,103,119,103,124,103,240,103,9,104,216,103,10,104,233,103,176,103,12,104,217,103,181,103,218,103,179,103,221,103,0,104,195,103,184,103,226,103,14,104,193,103,253,103,50,104,51,104,96,104,97,104,78,104,98,104,68,104,100,104,131,104,29,104,85,104,102,104,65,104,103,104,64,104,62,104,74,104], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1016300);
/* memory initializer */ allocate([73,104,41,104,181,104,143,104,116,104,119,104,147,104,107,104,194,104,110,105,252,104,31,105,32,105,249,104,39,149,51,149,61,149,67,149,72,149,75,149,85,149,90,149,96,149,110,149,116,149,117,149,119,149,120,149,121,149,122,149,123,149,124,149,125,149,126,149,128,149,129,149,130,149,131,149,132,149,133,149,134,149,135,149,136,149,137,149,138,149,139,149,140,149,141,149,142,149,143,149,144,149,145,149,146,149,147,149,148,149,149,149,150,149,151,149,152,149,153,149,154,149,155,149,156,149,157,149,158,149,159,149,160,149,161,149,162,149,163,149,164,149,165,149,166,149,167,149,168,149,169,149,170,149,171,149,172,149,173,149,174,149,175,149,176,149,177,149,178,149,179,149,180,149,181,149,182,149,183,149,184,149,185,149,186,149,187,149,188,149,189,149,190,149,191,149,192,149,193,149,194,149,195,149,196,149,197,149,198,149,199,149,200,149,201,149,202,149,203,149,36,105,240,104,11,105,1,105,87,105,227,104,16,105,113,105,57,105,96,105,66,105,93,105,132,105,107,105,128,105,152,105,120,105,52,105,204,105,135,105,136,105,206,105,137,105,102,105,99,105,121,105,155,105,167,105,187,105,171,105,173,105,212,105,177,105,193,105,202,105,223,105,149,105,224,105,141,105,255,105,47,106,237,105,23,106,24,106,101,106,242,105,68,106,62,106,160,106,80,106,91,106,53,106,142,106,121,106,61,106,40,106,88,106,124,106,145,106,144,106,169,106,151,106,171,106,55,115,82,115,129,107,130,107,135,107,132,107,146,107,147,107,141,107,154,107,155,107,161,107,170,107,107,143,109,143,113,143,114,143,115,143,117,143,118,143,120,143,119,143,121,143,122,143,124,143,126,143,129,143,130,143,132,143,135,143,139,143,204,149,205,149,206,149,207,149,208,149,209,149,210,149,211,149,212,149,213,149,214,149,215,149,216,149,217,149,218,149,219,149,220,149,221,149,222,149,223,149,224,149,225,149,226,149,227,149,228,149,229,149,230,149,231,149,236,149,255,149,7,150,19,150,24,150,27,150,30,150,32,150,35,150,36,150,37,150,38,150,39,150,40,150,41,150,43,150,44,150,45,150,47,150,48,150,55,150,56,150,57,150,58,150,62,150,65,150,67,150,74,150,78,150,79,150,81,150,82,150,83,150,86,150,87,150,88,150,89,150,90,150,92,150,93,150,94,150,96,150,99,150,101,150,102,150,107,150,109,150,110,150,111,150,112,150,113,150,115,150,120,150,121,150,122,150,123,150,124,150,125,150,126,150,127,150,128,150,129,150,130,150,131,150,132,150,135,150,137,150,138,150,141,143,142,143,143,143,152,143,154,143,206,142,11,98,23,98,27,98,31,98,34,98,33,98,37,98,36,98,44,98,231,129,239,116,244,116,255,116,15,117,17,117,19,117,52,101,238,101,239,101,240,101,10,102,25,102,114,103,3,102,21,102,0,102,133,112,247,102,29,102,52,102,49,102,54,102,53,102,6,128,95,102,84,102,65,102,79,102,86,102,97,102,87,102,119,102,132,102,140,102,167,102,157,102,190,102,219,102,220,102,230,102,233,102,50,141,51,141,54,141,59,141,61,141,64,141,69,141,70,141,72,141,73,141,71,141,77,141,85,141,89,141,199,137,202,137,203,137,204,137,206,137,207,137,208,137,209,137,110,114,159,114,93,114,102,114,111,114,126,114,127,114,132,114,139,114,141,114,143,114,146,114,8,99,50,99,176,99,140,150,142,150,145,150,146,150,147,150,149,150,150,150,154,150,155,150,157,150,158,150,159,150,160,150,161,150,162,150,163,150,164,150,165,150,166,150,168,150,169,150,170,150,171,150,172,150,173,150,174,150,175,150,177,150,178,150,180,150,181,150,183,150,184,150,186,150,187,150,191,150,194,150,195,150,200,150,202,150,203,150,208,150,209,150,211,150,212,150,214,150,215,150,216,150,217,150,218,150,219,150,220,150,221,150,222,150,223,150,225,150,226,150,227,150,228,150,229,150,230,150,231,150,235,150,236,150,237,150,238,150,240,150,241,150,242,150,244,150,245,150,248,150,250,150,251,150,252,150,253,150,255,150,2,151,3,151,5,151,10,151,11,151,12,151,16,151,17,151,18,151,20,151,21,151,23,151,24,151,25,151,26,151,27,151,29,151,31,151,32,151,63,100,216,100,4,128,234,107,243,107,253,107,245,107,249,107,5,108,7,108,6,108,13,108,21,108,24,108,25,108,26,108,33,108,41,108,36,108,42,108,50,108,53,101,85,101,107,101,77,114,82,114,86,114,48,114,98,134,22,82,159,128,156,128,147,128,188,128,10,103,189,128,177,128,171,128,173,128,180,128,183,128,231,128,232,128,233,128,234,128,219,128,194,128,196,128,217,128,205,128,215,128,16,103,221,128,235,128,241,128,244,128,237,128,13,129,14,129,242,128,252,128,21,103,18,129,90,140,54,129,30,129,44,129,24,129,50,129,72,129,76,129,83,129,116,129,89,129,90,129,113,129,96,129,105,129,124,129,125,129,109,129,103,129,77,88,181,90,136,129,130,129,145,129,213,110,163,129,170,129,204,129,38,103,202,129,187,129,33,151,34,151,35,151,36,151,37,151,38,151,39,151,40,151,41,151,43,151,44,151,46,151,47,151,49,151,51,151,52,151,53,151,54,151,55,151,58,151,59,151,60,151,61,151,63,151,64,151,65,151,66,151,67,151,68,151,69,151,70,151,71,151,72,151,73,151,74,151,75,151,76,151,77,151,78,151,79,151,80,151,81,151,84,151,85,151,87,151,88,151,90,151,92,151,93,151,95,151,99,151,100,151,102,151,103,151,104,151,106,151,107,151,108,151,109,151,110,151,111,151,112,151,113,151,114,151,117,151,119,151,120,151,121,151,122,151,123,151,125,151,126,151,127,151,128,151,129,151,130,151,131,151,132,151,134,151,135,151,136,151,137,151,138,151,140,151,142,151,143,151,144,151,147,151,149,151,150,151,151,151,153,151,154,151,155,151,156,151,157,151,193,129,166,129,36,107,55,107,57,107,67,107,70,107,89,107,209,152,210,152,211,152,213,152,217,152,218,152,179,107,64,95,194,107,243,137,144,101,81,159,147,101,188,101,198,101,196,101,195,101,204,101,206,101,210,101,214,101,128,112,156,112,150,112,157,112,187,112,192,112,183,112,171,112,177,112,232,112,202,112,16,113,19,113,22,113,47,113,49,113,115,113,92,113,104,113,69,113,114,113,74,113,120,113,122,113,152,113,179,113,181,113,168,113,160,113,224,113,212,113,231,113,249,113,29,114,40,114,108,112,24,113,102,113,185,113,62,98,61,98,67,98,72,98,73,98,59,121,64,121,70,121,73,121,91,121,92,121,83,121,90,121,98,121,87,121,96,121,111,121,103,121,122,121,133,121,138,121,154,121,167,121,179,121,209,95,208,95,158,151,159,151,161,151,162,151,164,151,165,151,166,151,167,151,168,151,169,151,170,151,172,151,174,151,176,151,177,151,179,151,181,151,182,151,183,151,184,151,185,151,186,151,187,151,188,151,189,151,190,151,191,151,192,151,193,151,194,151,195,151,196,151,197,151,198,151,199,151,200,151,201,151,202,151,203,151,204,151,205,151,206,151,207,151,208,151,209,151,210,151,211,151,212,151,213,151,214,151,215,151,216,151,217,151,218,151,219,151,220,151,221,151,222,151,223,151,224,151,225,151,226,151,227,151,228,151,229,151,232,151,238,151,239,151,240,151,241,151,242,151,244,151,247,151,248,151,249,151,250,151,251,151,252,151,253,151,254,151,255,151,0,152,1,152,2,152,3,152,4,152,5,152,6,152,7,152,8,152,9,152,10,152,11,152,12,152,13,152,14,152,60,96,93,96,90,96,103,96,65,96,89,96,99,96,171,96,6,97,13,97,93,97,169,97,157,97,203,97,209,97,6,98,128,128,127,128,147,108,246,108,252,109,246,119,248,119,0,120,9,120,23,120,24,120,17,120,171,101,45,120,28,120,29,120,57,120,58,120,59,120,31,120,60,120,37,120,44,120,35,120,41,120,78,120,109,120,86,120,87,120,38,120,80,120,71,120,76,120,106,120,155,120,147,120,154,120,135,120,156,120,161,120,163,120,178,120,185,120,165,120,212,120,217,120,201,120,236,120,242,120,5,121,244,120,19,121,36,121,30,121,52,121,155,159,249,158,251,158,252,158,241,118,4,119,13,119,249,118,7,119,8,119,26,119,34,119,25,119,45,119,38,119,53,119,56,119,80,119,81,119,71,119,67,119,90,119,104,119,15,152,16,152,17,152,18,152,19,152,20,152,21,152,22,152,23,152,24,152,25,152,26,152,27,152,28,152,29,152,30,152,31,152,32,152,33,152,34,152,35,152,36,152,37,152,38,152,39,152,40,152,41,152,42,152,43,152,44,152,45,152,46,152,47,152,48,152,49,152,50,152,51,152,52,152,53,152,54,152,55,152,56,152,57,152,58,152,59,152,60,152,61,152,62,152,63,152,64,152,65,152,66,152,67,152,68,152,69,152,70,152,71,152,72,152,73,152,74,152,75,152,76,152,77,152,78,152,79,152,80,152,81,152,82,152,83,152,84,152,85,152,86,152,87,152,88,152,89,152,90,152,91,152,92,152,93,152,94,152,95,152,96,152,97,152,98,152,99,152,100,152,101,152,102,152,103,152,104,152,105,152,106,152,107,152,108,152,109,152,110,152,98,119,101,119,127,119,141,119,125,119,128,119,140,119,145,119,159,119,160,119,176,119,181,119,189,119,58,117,64,117,78,117,75,117,72,117,91,117,114,117,121,117,131,117,88,127,97,127,95,127,72,138,104,127,116,127,113,127,121,127,129,127,126,127,205,118,229,118,50,136,133,148,134,148,135,148,139,148,138,148,140,148,141,148,143,148,144,148,148,148,151,148,149,148,154,148,155,148,156,148,163,148,164,148,171,148,170,148,173,148,172,148,175,148,176,148,178,148,180,148,182,148,183,148,184,148,185,148,186,148,188,148,189,148,191,148,196,148,200,148,201,148,202,148,203,148,204,148,205,148,206,148,208,148,209,148,210,148,213,148,214,148,215,148,217,148,216,148,219,148,222,148,223,148,224,148,226,148,228,148,229,148,231,148,232,148,234,148,111,152,112,152,113,152,114,152,115,152,116,152,139,152,142,152,146,152,149,152,153,152,163,152,168,152,169,152,170,152,171,152,172,152,173,152,174,152,175,152,176,152,177,152,178,152,179,152,180,152,181,152,182,152,183,152,184,152,185,152,186,152,187,152,188,152,189,152,190,152,191,152,192,152,193,152,194,152,195,152,196,152,197,152,198,152,199,152,200,152,201,152,202,152,203,152,204,152,205,152,207,152,208,152,212,152,214,152,215,152,219,152,220,152,221,152,224,152,225,152,226,152,227,152,228,152,229,152,230,152,233,152,234,152,235,152,236,152,237,152,238,152,239,152,240,152,241,152,242,152,243,152,244,152,245,152,246,152,247,152,248,152,249,152,250,152,251,152,252,152,253,152,254,152,255,152,0,153,1,153,2,153,3,153,4,153,5,153,6,153,7,153,233,148,235,148,238,148,239,148,243,148,244,148,245,148,247,148,249,148,252,148,253,148,255,148,3,149,2,149,6,149,7,149,9,149,10,149,13,149,14,149,15,149,18,149,19,149,20,149,21,149,22,149,24,149,27,149,29,149,30,149,31,149,34,149,42,149,43,149,41,149,44,149,49,149,50,149,52,149,54,149,55,149,56,149,60,149,62,149,63,149,66,149,53,149,68,149,69,149,70,149,73,149,76,149,78,149,79,149,82,149,83,149,84,149,86,149,87,149,88,149,89,149,91,149,94,149,95,149,93,149,97,149,98,149,100,149,101,149,102,149,103,149,104,149,105,149,106,149,107,149,108,149,111,149,113,149,114,149,115,149,58,149,231,119,236,119,201,150,213,121,237,121,227,121,235,121,6,122,71,93,3,122,2,122,30,122,20,122,8,153,9,153,10,153,11,153,12,153,14,153,15,153,17,153,18,153,19,153,20,153,21,153,22,153,23,153,24,153,25,153,26,153,27,153,28,153,29,153,30,153,31,153,32,153,33,153,34,153,35,153,36,153,37,153,38,153,39,153,40,153,41,153,42,153,43,153,44,153,45,153,47,153,48,153,49,153,50,153,51,153,52,153,53,153,54,153,55,153,56,153,57,153,58,153,59,153,60,153,61,153,62,153,63,153,64,153,65,153,66,153,67,153,68,153,69,153,70,153,71,153,72,153,73,153,74,153,75,153,76,153,77,153,78,153,79,153,80,153,81,153,82,153,83,153,86,153,87,153,88,153,89,153,90,153,91,153,92,153,93,153,94,153,95,153,96,153,97,153,98,153,100,153,102,153,115,153,120,153,121,153,123,153,126,153,130,153,131,153,137,153,57,122,55,122,81,122,207,158,165,153,112,122,136,118,142,118,147,118,153,118,164,118,222,116,224,116,44,117,32,158,34,158,40,158,41,158,42,158,43,158,44,158,50,158,49,158,54,158,56,158,55,158,57,158,58,158,62,158,65,158,66,158,68,158,70,158,71,158,72,158,73,158,75,158,76,158,78,158,81,158,85,158,87,158,90,158,91,158,92,158,94,158,99,158,102,158,103,158,104,158,105,158,106,158,107,158,108,158,113,158,109,158,115,158,146,117,148,117,150,117,160,117,157,117,172,117,163,117,179,117,180,117,184,117,196,117,177,117,176,117,195,117,194,117,214,117,205,117,227,117,232,117,230,117,228,117,235,117,231,117,3,118,241,117,252,117,255,117,16,118,0,118,5,118,12,118,23,118,10,118,37,118,24,118,21,118,25,118,140,153,142,153,154,153,155,153,156,153,157,153,158,153,159,153,160,153,161,153,162,153,163,153,164,153,166,153,167,153,169,153,170,153,171,153,172,153,173,153,174,153,175,153,176,153,177,153,178,153,179,153,180,153,181,153,182,153,183,153,184,153,185,153,186,153,187,153,188,153,189,153,190,153,191,153,192,153,193,153,194,153,195,153,196,153,197,153,198,153,199,153,200,153,201,153,202,153,203,153,204,153,205,153,206,153,207,153,208,153,209,153,210,153,211,153,212,153,213,153,214,153,215,153,216,153,217,153,218,153,219,153,220,153,221,153,222,153,223,153,224,153,225,153,226,153,227,153,228,153,229,153,230,153,231,153,232,153,233,153,234,153,235,153,236,153,237,153,238,153,239,153,240,153,241,153,242,153,243,153,244,153,245,153,246,153,247,153,248,153,249,153,27,118,60,118,34,118,32,118,64,118,45,118,48,118,63,118,53,118,67,118,62,118,51,118,77,118,94,118,84,118,92,118,86,118,107,118,111,118,202,127,230,122,120,122,121,122,128,122,134,122,136,122,149,122,166,122,160,122,172,122,168,122,173,122,179,122,100,136,105,136,114,136,125,136,127,136,130,136,162,136,198,136,183,136,188,136,201,136,226,136,206,136,227,136,229,136,241,136,26,137,252,136,232,136,254,136,240,136,33,137,25,137,19,137,27,137,10,137,52,137,43,137,54,137,65,137,102,137,123,137,139,117,229,128,178,118,180,118,220,119,18,128,20,128,22,128,28,128,32,128,34,128,37,128,38,128,39,128,41,128,40,128,49,128,11,128,53,128,67,128,70,128,77,128,82,128,105,128,113,128,131,137,120,152,128,152,131,152,250,153,251,153,252,153,253,153,254,153,255,153,0,154,1,154,2,154,3,154,4,154,5,154,6,154,7,154,8,154,9,154,10,154,11,154,12,154,13,154,14,154,15,154,16,154,17,154,18,154,19,154,20,154,21,154,22,154,23,154,24,154,25,154,26,154,27,154,28,154,29,154,30,154,31,154,32,154,33,154,34,154,35,154,36,154,37,154,38,154,39,154,40,154,41,154,42,154,43,154,44,154,45,154,46,154,47,154,48,154,49,154,50,154,51,154,52,154,53,154,54,154,55,154,56,154,57,154,58,154,59,154,60,154,61,154,62,154,63,154,64,154,65,154,66,154,67,154,68,154,69,154,70,154,71,154,72,154,73,154,74,154,75,154,76,154,77,154,78,154,79,154,80,154,81,154,82,154,83,154,84,154,85,154,86,154,87,154,88,154,89,154,137,152,140,152,141,152,143,152,148,152,154,152,155,152,158,152,159,152,161,152,162,152,165,152,166,152,77,134,84,134,108,134,110,134,127,134,122,134,124,134,123,134,168,134,141,134,139,134,172,134,157,134,167,134,163,134,170,134,147,134,169,134,182,134,196,134,181,134,206,134,176,134,186,134,177,134,175,134,201,134,207,134,180,134,233,134,241,134,242,134,237,134,243,134,208,134,19,135,222,134,244,134,223,134,216,134,209,134,3,135,7,135,248,134,8,135,10,135,13,135,9,135,35,135,59,135,30,135,37,135,46,135,26,135,62,135,72,135,52,135,49,135,41,135,55,135,63,135,130,135,34,135,125,135,126,135,123,135,96,135,112,135,76,135,110,135,139,135,83,135,99,135,124,135,100,135,89,135,101,135,147,135,175,135,168,135,210,135,90,154,91,154,92,154,93,154,94,154,95,154,96,154,97,154,98,154,99,154,100,154,101,154,102,154,103,154,104,154,105,154,106,154,107,154,114,154,131,154,137,154,141,154,142,154,148,154,149,154,153,154,166,154,169,154,170,154,171,154,172,154,173,154,174,154,175,154,178,154,179,154,180,154,181,154,185,154,187,154,189,154,190,154,191,154,195,154,196,154,198,154,199,154,200,154,201,154,202,154,205,154,206,154,207,154,208,154,210,154,212,154,213,154,214,154,215,154,217,154,218,154,219,154,220,154,221,154,222,154,224,154,226,154,227,154,228,154,229,154,231,154,232,154,233,154,234,154,236,154,238,154,240,154,241,154,242,154,243,154,244,154,245,154,246,154,247,154,248,154,250,154,252,154,253,154,254,154,255,154,0,155,1,155,2,155,4,155,5,155,6,155,198,135,136,135,133,135,173,135,151,135,131,135,171,135,229,135,172,135,181,135,179,135,203,135,211,135,189,135,209,135,192,135,202,135,219,135,234,135,224,135,238,135,22,136,19,136,254,135,10,136,27,136,33,136,57,136,60,136,54,127,66,127,68,127,69,127,16,130,250,122,253,122,8,123,3,123,4,123,21,123,10,123,43,123,15,123,71,123,56,123,42,123,25,123,46,123,49,123,32,123,37,123,36,123,51,123,62,123,30,123,88,123,90,123,69,123,117,123,76,123,93,123,96,123,110,123,123,123,98,123,114,123,113,123,144,123,166,123,167,123,184,123,172,123,157,123,168,123,133,123,170,123,156,123,162,123,171,123,180,123,209,123,193,123,204,123,221,123,218,123,229,123,230,123,234,123,12,124,254,123,252,123,15,124,22,124,11,124,7,155,9,155,10,155,11,155,12,155,13,155,14,155,16,155,17,155,18,155,20,155,21,155,22,155,23,155,24,155,25,155,26,155,27,155,28,155,29,155,30,155,32,155,33,155,34,155,36,155,37,155,38,155,39,155,40,155,41,155,42,155,43,155,44,155,45,155,46,155,48,155,49,155,51,155,52,155,53,155,54,155,55,155,56,155,57,155,58,155,61,155,62,155,63,155,64,155,70,155,74,155,75,155,76,155,78,155,80,155,82,155,83,155,85,155,86,155,87,155,88,155,89,155,90,155,91,155,92,155,93,155,94,155,95,155,96,155,97,155,98,155,99,155,100,155,101,155,102,155,103,155,104,155,105,155,106,155,107,155,108,155,109,155,110,155,111,155,112,155,113,155,114,155,115,155,116,155,117,155,118,155,119,155,120,155,121,155,122,155,123,155,31,124,42,124,38,124,56,124,65,124,64,124,254,129,1,130,2,130,4,130,236,129,68,136,33,130,34,130,35,130,45,130,47,130,40,130,43,130,56,130,59,130,51,130,52,130,62,130,68,130,73,130,75,130,79,130,90,130,95,130,104,130,126,136,133,136,136,136,216,136,223,136,94,137,157,127,159,127,167,127,175,127,176,127,178,127,124,124,73,101,145,124,157,124,156,124,158,124,162,124,178,124,188,124,189,124,193,124,199,124,204,124,205,124,200,124,197,124,215,124,232,124,110,130,168,102,191,127,206,127,213,127,229,127,225,127,230,127,233,127,238,127,243,127,248,124,119,125,166,125,174,125,71,126,155,126,184,158,180,158,115,141,132,141,148,141,145,141,177,141,103,141,109,141,71,140,73,140,74,145,80,145,78,145,79,145,100,145,124,155,125,155,126,155,127,155,128,155,129,155,130,155,131,155,132,155,133,155,134,155,135,155,136,155,137,155,138,155,139,155,140,155,141,155,142,155,143,155,144,155,145,155,146,155,147,155,148,155,149,155,150,155,151,155,152,155,153,155,154,155,155,155,156,155,157,155,158,155,159,155,160,155,161,155,162,155,163,155,164,155,165,155,166,155,167,155,168,155,169,155,170,155,171,155,172,155,173,155,174,155,175,155,176,155,177,155,178,155,179,155,180,155,181,155,182,155,183,155,184,155,185,155,186,155,187,155,188,155,189,155,190,155,191,155,192,155,193,155,194,155,195,155,196,155,197,155,198,155,199,155,200,155,201,155,202,155,203,155,204,155,205,155,206,155,207,155,208,155,209,155,210,155,211,155,212,155,213,155,214,155,215,155,216,155,217,155,218,155,219,155,98,145,97,145,112,145,105,145,111,145,125,145,126,145,114,145,116,145,121,145,140,145,133,145,144,145,141,145,145,145,162,145,163,145,170,145,173,145,174,145,175,145,181,145,180,145,186,145,85,140,126,158,184,141,235,141,5,142,89,142,105,142,181,141,191,141,188,141,186,141,196,141,214,141,215,141,218,141,222,141,206,141,207,141,219,141,198,141,236,141,247,141,248,141,227,141,249,141,251,141,228,141,9,142,253,141,20,142,29,142,31,142,44,142,46,142,35,142,47,142,58,142,64,142,57,142,53,142,61,142,49,142,73,142,65,142,66,142,81,142,82,142,74,142,112,142,118,142,124,142,111,142,116,142,133,142,143,142,148,142,144,142,156,142,158,142,120,140,130,140,138,140,133,140,152,140,148,140,155,101,214,137,222,137,218,137,220,137,220,155,221,155,222,155,223,155,224,155,225,155,226,155,227,155,228,155,229,155,230,155,231,155,232,155,233,155,234,155,235,155,236,155,237,155,238,155,239,155,240,155,241,155,242,155,243,155,244,155,245,155,246,155,247,155,248,155,249,155,250,155,251,155,252,155,253,155,254,155,255,155,0,156,1,156,2,156,3,156,4,156,5,156,6,156,7,156,8,156,9,156,10,156,11,156,12,156,13,156,14,156,15,156,16,156,17,156,18,156,19,156,20,156,21,156,22,156,23,156,24,156,25,156,26,156,27,156,28,156,29,156,30,156,31,156,32,156,33,156,34,156,35,156,36,156,37,156,38,156,39,156,40,156,41,156,42,156,43,156,44,156,45,156,46,156,47,156,48,156,49,156,50,156,51,156,52,156,53,156,54,156,55,156,56,156,57,156,58,156,59,156,229,137,235,137,239,137,62,138,38,139,83,151,233,150,243,150,239,150,6,151,1,151,8,151,15,151,14,151,42,151,45,151,48,151,62,151,128,159,131,159,133,159,134,159,135,159,136,159,137,159,138,159,140,159,254,158,11,159,13,159,185,150,188,150,189,150,206,150,210,150,191,119,224,150,142,146,174,146,200,146,62,147,106,147,202,147,143,147,62,148,107,148,127,156,130,156,133,156,134,156,135,156,136,156,35,122,139,156,142,156,144,156,145,156,146,156,148,156,149,156,154,156,155,156,158,156,159,156,160,156,161,156,162,156,163,156,165,156,166,156,167,156,168,156,169,156,171,156,173,156,174,156,176,156,177,156,178,156,179,156,180,156,181,156,182,156,183,156,186,156,187,156,188,156,189,156,196,156,197,156,198,156,199,156,202,156,203,156,60,156,61,156,62,156,63,156,64,156,65,156,66,156,67,156,68,156,69,156,70,156,71,156,72,156,73,156,74,156,75,156,76,156,77,156,78,156,79,156,80,156,81,156,82,156,83,156,84,156,85,156,86,156,87,156,88,156,89,156,90,156,91,156,92,156,93,156,94,156,95,156,96,156,97,156,98,156,99,156,100,156,101,156,102,156,103,156,104,156,105,156,106,156,107,156,108,156,109,156,110,156,111,156,112,156,113,156,114,156,115,156,116,156,117,156,118,156,119,156,120,156,121,156,122,156,123,156,125,156,126,156,128,156,131,156,132,156,137,156,138,156,140,156,143,156,147,156,150,156,151,156,152,156,153,156,157,156,170,156,172,156,175,156,185,156,190,156,191,156,192,156,193,156,194,156,200,156,201,156,209,156,210,156,218,156,219,156,224,156,225,156,204,156,205,156,206,156,207,156,208,156,211,156,212,156,213,156,215,156,216,156,217,156,220,156,221,156,223,156,226,156,124,151,133,151,145,151,146,151,148,151,175,151,171,151,163,151,178,151,180,151,177,154,176,154,183,154,88,158,182,154,186,154,188,154,193,154,192,154,197,154,194,154,203,154,204,154,209,154,69,155,67,155,71,155,73,155,72,155,77,155,81,155,232,152,13,153,46,153,85,153,84,153,223,154,225,154,230,154,239,154,235,154,251,154,237,154,249,154,8,155,15,155,19,155,31,155,35,155,189,158,190,158,59,126,130,158,135,158,136,158,139,158,146,158,214,147,157,158,159,158,219,158,220,158,221,158,224,158,223,158,226,158,233,158,231,158,229,158,234,158,239,158,34,159,44,159,47,159,57,159,55,159,61,159,62,159,68,159,227,156,228,156,229,156,230,156,231,156,232,156,233,156,234,156,235,156,236,156,237,156,238,156,239,156,240,156,241,156,242,156,243,156,244,156,245,156,246,156,247,156,248,156,249,156,250,156,251,156,252,156,253,156,254,156,255,156,0,157,1,157,2,157,3,157,4,157,5,157,6,157,7,157,8,157,9,157,10,157,11,157,12,157,13,157,14,157,15,157,16,157,17,157,18,157,19,157,20,157,21,157,22,157,23,157,24,157,25,157,26,157,27,157,28,157,29,157,30,157,31,157,32,157,33,157,34,157,35,157,36,157,37,157,38,157,39,157,40,157,41,157,42,157,43,157,44,157,45,157,46,157,47,157,48,157,49,157,50,157,51,157,52,157,53,157,54,157,55,157,56,157,57,157,58,157,59,157,60,157,61,157,62,157,63,157,64,157,65,157,66,157,52,226,53,226,54,226,55,226,56,226,57,226,58,226,59,226,60,226,61,226,62,226,63,226,64,226,65,226,66,226,67,226,68,226,69,226,70,226,71,226,72,226,73,226,74,226,75,226,76,226,77,226,78,226,79,226,80,226,81,226,82,226,83,226,84,226,85,226,86,226,87,226,88,226,89,226,90,226,91,226,92,226,93,226,94,226,95,226,96,226,97,226,98,226,99,226,100,226,101,226,102,226,103,226,104,226,105,226,106,226,107,226,108,226,109,226,110,226,111,226,112,226,113,226,114,226,115,226,116,226,117,226,118,226,119,226,120,226,121,226,122,226,123,226,124,226,125,226,126,226,127,226,128,226,129,226,130,226,131,226,132,226,133,226,134,226,135,226,136,226,137,226,138,226,139,226,140,226,141,226,142,226,143,226,144,226,145,226,67,157,68,157,69,157,70,157,71,157,72,157,73,157,74,157,75,157,76,157,77,157,78,157,79,157,80,157,81,157,82,157,83,157,84,157,85,157,86,157,87,157,88,157,89,157,90,157,91,157,92,157,93,157,94,157,95,157,96,157,97,157,98,157,99,157,100,157,101,157,102,157,103,157,104,157,105,157,106,157,107,157,108,157,109,157,110,157,111,157,112,157,113,157,114,157,115,157,116,157,117,157,118,157,119,157,120,157,121,157,122,157,123,157,124,157,125,157,126,157,127,157,128,157,129,157,130,157,131,157,132,157,133,157,134,157,135,157,136,157,137,157,138,157,139,157,140,157,141,157,142,157,143,157,144,157,145,157,146,157,147,157,148,157,149,157,150,157,151,157,152,157,153,157,154,157,155,157,156,157,157,157,158,157,159,157,160,157,161,157,162,157,146,226,147,226,148,226,149,226,150,226,151,226,152,226,153,226,154,226,155,226,156,226,157,226,158,226,159,226,160,226,161,226,162,226,163,226,164,226,165,226,166,226,167,226,168,226,169,226,170,226,171,226,172,226,173,226,174,226,175,226,176,226,177,226,178,226,179,226,180,226,181,226,182,226,183,226,184,226,185,226,186,226,187,226,188,226,189,226,190,226,191,226,192,226,193,226,194,226,195,226,196,226,197,226,198,226,199,226,200,226,201,226,202,226,203,226,204,226,205,226,206,226,207,226,208,226,209,226,210,226,211,226,212,226,213,226,214,226,215,226,216,226,217,226,218,226,219,226,220,226,221,226,222,226,223,226,224,226,225,226,226,226,227,226,228,226,229,226,230,226,231,226,232,226,233,226,234,226,235,226,236,226,237,226,238,226,239,226,163,157,164,157,165,157,166,157,167,157,168,157,169,157,170,157,171,157,172,157,173,157,174,157,175,157,176,157,177,157,178,157,179,157,180,157,181,157,182,157,183,157,184,157,185,157,186,157,187,157,188,157,189,157,190,157,191,157,192,157,193,157,194,157,195,157,196,157,197,157,198,157,199,157,200,157,201,157,202,157,203,157,204,157,205,157,206,157,207,157,208,157,209,157,210,157,211,157,212,157,213,157,214,157,215,157,216,157,217,157,218,157,219,157,220,157,221,157,222,157,223,157,224,157,225,157,226,157,227,157,228,157,229,157,230,157,231,157,232,157,233,157,234,157,235,157,236,157,237,157,238,157,239,157,240,157,241,157,242,157,243,157,244,157,245,157,246,157,247,157,248,157,249,157,250,157,251,157,252,157,253,157,254,157,255,157,0,158,1,158,2,158,240,226,241,226,242,226,243,226,244,226,245,226,246,226,247,226,248,226,249,226,250,226,251,226,252,226,253,226,254,226,255,226,0,227,1,227,2,227,3,227,4,227,5,227,6,227,7,227,8,227,9,227,10,227,11,227,12,227,13,227,14,227,15,227,16,227,17,227,18,227,19,227,20,227,21,227,22,227,23,227,24,227,25,227,26,227,27,227,28,227,29,227,30,227,31,227,32,227,33,227,34,227,35,227,36,227,37,227,38,227,39,227,40,227,41,227,42,227,43,227,44,227,45,227,46,227,47,227,48,227,49,227,50,227,51,227,52,227,53,227,54,227,55,227,56,227,57,227,58,227,59,227,60,227,61,227,62,227,63,227,64,227,65,227,66,227,67,227,68,227,69,227,70,227,71,227,72,227,73,227,74,227,75,227,76,227,77,227,3,158,4,158,5,158,6,158,7,158,8,158,9,158,10,158,11,158,12,158,13,158,14,158,15,158,16,158,17,158,18,158,19,158,20,158,21,158,22,158,23,158,24,158,25,158,26,158,27,158,28,158,29,158,30,158,36,158,39,158,46,158,48,158,52,158,59,158,60,158,64,158,77,158,80,158,82,158,83,158,84,158,86,158,89,158,93,158,95,158,96,158,97,158,98,158,101,158,110,158,111,158,114,158,116,158,117,158,118,158,119,158,120,158,121,158,122,158,123,158,124,158,125,158,128,158,129,158,131,158,132,158,133,158,134,158,137,158,138,158,140,158,141,158,142,158,143,158,144,158,145,158,148,158,149,158,150,158,151,158,152,158,153,158,154,158,155,158,156,158,158,158,160,158,161,158,162,158,163,158,164,158,165,158,167,158,168,158,169,158,170,158,78,227,79,227,80,227,81,227,82,227,83,227,84,227,85,227,86,227,87,227,88,227,89,227,90,227,91,227,92,227,93,227,94,227,95,227,96,227,97,227,98,227,99,227,100,227,101,227,102,227,103,227,104,227,105,227,106,227,107,227,108,227,109,227,110,227,111,227,112,227,113,227,114,227,115,227,116,227,117,227,118,227,119,227,120,227,121,227,122,227,123,227,124,227,125,227,126,227,127,227,128,227,129,227,130,227,131,227,132,227,133,227,134,227,135,227,136,227,137,227,138,227,139,227,140,227,141,227,142,227,143,227,144,227,145,227,146,227,147,227,148,227,149,227,150,227,151,227,152,227,153,227,154,227,155,227,156,227,157,227,158,227,159,227,160,227,161,227,162,227,163,227,164,227,165,227,166,227,167,227,168,227,169,227,170,227,171,227,171,158,172,158,173,158,174,158,175,158,176,158,177,158,178,158,179,158,181,158,182,158,183,158,185,158,186,158,188,158,191,158,192,158,193,158,194,158,195,158,197,158,198,158,199,158,200,158,202,158,203,158,204,158,208,158,210,158,211,158,213,158,214,158,215,158,217,158,218,158,222,158,225,158,227,158,228,158,230,158,232,158,235,158,236,158,237,158,238,158,240,158,241,158,242,158,243,158,244,158,245,158,246,158,247,158,248,158,250,158,253,158,255,158,0,159,1,159,2,159,3,159,4,159,5,159,6,159,7,159,8,159,9,159,10,159,12,159,15,159,17,159,18,159,20,159,21,159,22,159,24,159,26,159,27,159,28,159,29,159,30,159,31,159,33,159,35,159,36,159,37,159,38,159,39,159,40,159,41,159,42,159,43,159,45,159,46,159,48,159,49,159,172,227,173,227,174,227,175,227,176,227,177,227,178,227,179,227,180,227,181,227,182,227,183,227,184,227,185,227,186,227,187,227,188,227,189,227,190,227,191,227,192,227,193,227,194,227,195,227,196,227,197,227,198,227,199,227,200,227,201,227,202,227,203,227,204,227,205,227,206,227,207,227,208,227,209,227,210,227,211,227,212,227,213,227,214,227,215,227,216,227,217,227,218,227,219,227,220,227,221,227,222,227,223,227,224,227,225,227,226,227,227,227,228,227,229,227,230,227,231,227,232,227,233,227,234,227,235,227,236,227,237,227,238,227,239,227,240,227,241,227,242,227,243,227,244,227,245,227,246,227,247,227,248,227,249,227,250,227,251,227,252,227,253,227,254,227,255,227,0,228,1,228,2,228,3,228,4,228,5,228,6,228,7,228,8,228,9,228,50,159,51,159,52,159,53,159,54,159,56,159,58,159,60,159,63,159,64,159,65,159,66,159,67,159,69,159,70,159,71,159,72,159,73,159,74,159,75,159,76,159,77,159,78,159,79,159,82,159,83,159,84,159,85,159,86,159,87,159,88,159,89,159,90,159,91,159,92,159,93,159,94,159,95,159,96,159,97,159,98,159,99,159,100,159,101,159,102,159,103,159,104,159,105,159,106,159,107,159,108,159,109,159,110,159,111,159,112,159,113,159,114,159,115,159,116,159,117,159,118,159,119,159,120,159,121,159,122,159,123,159,124,159,125,159,126,159,129,159,130,159,141,159,142,159,143,159,144,159,145,159,146,159,147,159,148,159,149,159,150,159,151,159,152,159,156,159,157,159,158,159,161,159,162,159,163,159,164,159,165,159,44,249,121,249,149,249,231,249,241,249,10,228,11,228,12,228,13,228,14,228,15,228,16,228,17,228,18,228,19,228,20,228,21,228,22,228,23,228,24,228,25,228,26,228,27,228,28,228,29,228,30,228,31,228,32,228,33,228,34,228,35,228,36,228,37,228,38,228,39,228,40,228,41,228,42,228,43,228,44,228,45,228,46,228,47,228,48,228,49,228,50,228,51,228,52,228,53,228,54,228,55,228,56,228,57,228,58,228,59,228,60,228,61,228,62,228,63,228,64,228,65,228,66,228,67,228,68,228,69,228,70,228,71,228,72,228,73,228,74,228,75,228,76,228,77,228,78,228,79,228,80,228,81,228,82,228,83,228,84,228,85,228,86,228,87,228,88,228,89,228,90,228,91,228,92,228,93,228,94,228,95,228,96,228,97,228,98,228,99,228,100,228,101,228,102,228,103,228,12,250,13,250,14,250,15,250,17,250,19,250,20,250,24,250,31,250,32,250,33,250,35,250,36,250,39,250,40,250,41,250,129,46,22,232,23,232,24,232,132,46,115,52,71,52,136,46,139,46,30,232,158,53,26,54,14,54,140,46,151,46,110,57,24,57,38,232,207,57,223,57,115,58,208,57,43,232,44,232,78,59,110,60,224,60,167,46,49,232,50,232,170,46,86,64,95,65,174,46,55,67,179,46,182,46,183,46,59,232,177,67,172,67,187,46,221,67,214,68,97,70,76,70,67,232,35,71,41,71,124,71,141,71,202,46,71,73,122,73,125,73,130,73,131,73,133,73,134,73,159,73,155,73,183,73,182,73,84,232,85,232,163,76,159,76,160,76,161,76,119,76,162,76,19,77,20,77,21,77,22,77,23,77,24,77,25,77,174,77,100,232,104,228,105,228,106,228,107,228,108,228,109,228,110,228,111,228,112,228,113,228,114,228,115,228,116,228,117,228,118,228,119,228,120,228,121,228,122,228,123,228,124,228,125,228,126,228,127,228,128,228,129,228,130,228,131,228,132,228,133,228,134,228,135,228,136,228,137,228,138,228,139,228,140,228,141,228,142,228,143,228,144,228,145,228,146,228,147,228,148,228,149,228,150,228,151,228,152,228,153,228,154,228,155,228,156,228,157,228,158,228,159,228,160,228,161,228,162,228,163,228,164,228,165,228,166,228,167,228,168,228,169,228,170,228,171,228,172,228,173,228,174,228,175,228,176,228,177,228,178,228,179,228,180,228,181,228,182,228,183,228,184,228,185,228,186,228,187,228,188,228,189,228,190,228,191,228,192,228,193,228,194,228,195,228,196,228,197,228,2,0,0,0,10,0,0,0,10,0,0,0,0,0,0,0,0,9,16,22,28,33,39,44,49,53,58,63,67,72,76,80,84,89,93,97,101,105,109,113,117,121,125,128,132,136,140,143,147,151,154,158,162,165,169,172,176,179,183,186,190,193,197,200,203,207,210,213,217,220,223,227,230,233,237,240,243,246,250,253,3,11,18,24,29,35,40,45,50,54,59,64,68,73,77,81,86,90,94,98,102,106,110,114,118,122,125,129,133,137,141,144,148,152,155,159,162,166,170,173,177,180,184,187,191,194,197,201,204,208,211,214,218,221,224,228,231,234,237,241,244,247,250,253,5,13,19,25,31,36,41,46,51,56,60,65,69,74,78,82,87,91,95,99,103,107,111,115,119,123,126,130,134,138,141,145,149,153,156,160,163,167,170,174,178,181,185,188,191,195,198,202,205,208,212,215,218,222,225,228,232,235,238,241,245,248,251,253,7,14,21,26,32,37,42,47,52,57,61,66,70,75,79,83,88,92,96,100,104,108,112,116,120,124,127,131,135,139,142,146,150,153,157,161,164,168,171,175,178,182,185,189,192,196,199,203,206,209,213,216,219,223,226,229,233,236,239,242,246,249,252,253,61,42,81,112,0,80,225,10,153,73,194,25,81,24,245,28,51,67,204,40,122,84,245,4,143,82,71,17,40,44,20,6,61,74,20,50,215,67,194,9,194,69,225,18,10,39,194,9,122,68,184,30,174,55,92,7,20,62,81,12,61,26,10,7,10,71,225,78,102,70,215,11,71,65,225,22,143,34,174,15,20,62,10,35,102,70,112,5,71,65,0,16,0,32,143,2,133,59,102,54,174,55,40,12,10,55,61,18,30,21,143,10,122,52,153,25,163,48,133,3,163,48,102,10,184,14,143,2,153,57,215,91,225,74,153,9,184,78,215,19,225,26,0,16,0,80,112,33,204,76,225,2,61,74,163,16,184,30,40,8,204,44,0,48,20,62,194,5,112,61,20,18,215,35,153,5,184,62,92,27,235,57,225,2,225,58,204,8,215,19,204,4,215,51,174,67,163,64,30,9,225,58,184,22,92,15,102,14,174,55,153,33,235,65,10,3,225,58,225,14,174,23,102,2,122,36,40,36,215,51,225,6,215,51,194,13,153,9,174,7,204,44,153,21,245,40,225,2,112,45,122,12,194,5,10,3,65,2,150,2,38,3,44,7,37,12,28,4,85,16,107,5,69,9,145,5,176,12,193,7,35,7,16,9,173,3,242,12,47,9,161,11,32,14,116,9,123,13,24,12,139,11,205,16,56,7,148,17,44,15,40,21,163,4,42,28,11,12,40,35,216,28,115,3,74,23,226,5,35,20,86,8,8,31,217,7,107,25,202,8,246,29,192,10,64,23,200,11,34,19,180,14,77,27,4,14,238,31,138,15,176,23,52,17,29,30,223,19,147,21,133,23,89,30,214,27,172,23,2,31,218,21,223,44,85,41,76,5,89,35,61,6,66,38,243,7,242,34,111,9,56,40,24,10,191,36,174,10,252,33,146,12,29,38,67,13,193,39,52,15,210,35,176,17,168,39,140,19,154,35,103,22,4,41,122,24,126,39,207,29,140,34,23,34,252,34,208,48,124,50,208,3,171,44,219,6,106,47,24,9,124,44,64,9,204,41,248,11,44,48,45,11,202,45,255,12,6,44,116,14,109,42,61,17,50,47,181,17,19,44,85,20,184,46,161,24,159,43,110,29,96,47,137,32,217,42,25,42,60,40,224,67,75,54,145,6,36,49,253,7,209,51,135,9,209,54,173,11,140,52,26,12,108,48,74,14,198,52,196,14,80,50,176,16,221,52,253,18,123,49,81,21,30,54,218,23,231,50,83,25,245,52,41,30,157,50,95,36,146,53,31,45,47,49,102,59,9,59,4,6,224,58,29,9,191,56,207,9,100,57,127,12,22,60,232,13,53,55,120,15,254,58,140,16,252,55,216,18,254,57,75,21,202,59,195,23,249,55,232,26,212,58,9,30,70,56,210,36,27,60,13,38,232,57,191,55,32,53,107,97,12,64,177,7,177,65,16,11,97,61,27,11,232,62,8,13,0,64,123,15,44,66,227,17,95,61,247,17,94,63,72,21,192,65,238,24,129,61,229,27,198,63,45,29,227,64,176,33,132,66,178,40,33,62,41,46,238,65,98,57,131,64,134,81,222,70,35,8,201,75,106,12,100,68,98,13,86,78,187,15,149,70,153,16,8,74,202,19,47,69,26,21,123,77,48,24,30,70,102,27,70,83,197,30,246,69,73,36,200,74,74,36,37,80,117,44,155,70,149,56,31,78,218,69,154,73,252,127,44,3,128,0,30,2,140,0,57,11,111,4,218,8,74,13,19,8,51,2,133,49,135,2,36,16,6,7,225,21,165,20,9,30,118,1,151,14,185,1,160,42,78,10,31,46,190,9,10,80,29,3,98,20,163,2,68,26,162,32,162,20,160,6,208,5,172,1,250,22,196,1,212,20,232,15,255,13,244,4,165,9,133,3,22,62,237,3,134,58,199,12,91,40,250,18,51,14,229,7,36,10,67,3,72,48,28,19,174,47,168,6,120,52,68,6,158,35,37,9,128,15,2,6,103,21,208,38,211,14,161,1,79,5,158,1,56,14,33,6,59,31,213,13,141,44,133,2,104,33,123,2,216,15,97,5,224,64,236,23,156,44,188,2,215,7,95,2,127,48,42,6,111,43,46,18,112,53,172,6,214,46,205,4,60,31,129,28,175,51,83,22,124,9,135,4,25,8,149,7,74,24,233,23,218,13,12,7,221,34,10,7,231,33,44,6,111,54,248,13,1,52,93,24,254,23,106,4,106,23,198,6,61,55,54,18,7,44,249,12,194,47,15,6,107,54,199,11,217,19,224,40,228,36,50,26,153,6,171,2,156,5,26,5,44,28,93,15,242,15,153,10,113,30,192,2,222,58,34,3,155,24,92,20,241,16,237,20,20,26,29,2,174,23,114,2,83,53,116,14,234,44,104,9,28,63,204,2,145,47,239,2,129,31,225,44,170,24,208,8,114,17,240,1,125,28,11,2,229,39,249,14,202,32,221,11,211,32,198,3,148,55,88,7,255,33,33,21,11,64,255,18,252,28,187,7,201,23,206,4,155,36,46,17,222,56,35,13,247,52,57,11,107,51,185,5,158,21,142,6,82,51,179,57,170,28,88,2,38,5,36,2,156,16,211,13,60,39,60,9,91,41,110,2,32,51,157,2,46,55,198,13,175,19,56,38,234,59,107,2,43,12,78,2,58,64,197,11,182,60,72,16,177,60,75,6,45,60,204,4,151,62,83,36,110,29,112,19,198,7,189,4,183,44,133,4,224,48,143,21,3,37,84,10,36,30,242,7,224,51,191,8,139,62,229,19,130,31,105,26,99,39,133,5,138,19,43,9,235,48,87,23,22,59,83,11,88,71,241,8,211,61,223,9,137,63,14,40,59,57,55,44,5,7,81,1,43,12,141,1,182,13,112,11,240,17,110,10,95,29,116,2,151,44,144,2,58,23,131,9,144,25,199,28,46,32,61,3,160,15,95,3,48,39,188,9,185,62,223,13,28,71,30,4,215,23,174,5,252,22,220,30,64,73,140,13,72,7,32,2,238,35,171,2,103,45,64,16,242,17,108,6,86,12,133,4,81,62,0,10,61,48,149,14,12,68,140,20,218,23,212,7,101,11,206,6,83,64,137,20,147,65,144,6,53,67,223,6,165,18,159,12,218,28,147,23,6,56,28,39,195,15,186,1,98,16,202,1,254,35,194,8,3,29,121,16,60,50,33,3,178,43,57,3,104,49,36,8,156,50,154,25,33,37,228,3,229,25,217,3,41,41,198,9,185,59,142,19,58,49,7,8,124,60,117,6,66,63,9,27,151,55,158,22,66,10,60,3,239,21,150,6,95,53,146,22,84,14,18,6,49,44,73,10,42,38,179,5,179,54,125,18,25,62,147,24,134,24,78,7,230,30,237,8,82,66,219,17,192,64,9,15,144,59,7,9,151,62,172,12,123,56,144,69,71,46,203,10,189,7,127,5,120,5,108,3,239,16,219,13,39,17,114,16,29,21,168,2,53,68,13,3,101,25,254,19,155,31,253,29,187,28,26,3,141,32,158,4,193,58,88,12], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1026540);
/* memory initializer */ allocate([80,58,223,11,197,79,112,3,209,56,84,3,49,48,116,57,248,26,128,7,129,16,165,3,26,32,63,4,163,41,244,15,98,39,181,17,175,10,72,3,177,80,57,4,71,65,78,23,1,62,226,17,119,42,14,10,189,14,142,4,183,56,204,15,219,80,67,10,115,59,174,10,170,59,138,8,113,24,154,12,69,51,24,76,28,28,162,3,158,9,82,6,163,17,20,12,28,54,181,16,220,40,65,3,187,67,42,3,251,65,241,8,186,60,25,32,35,53,148,6,125,12,42,7,76,62,4,11,196,61,207,20,110,66,134,9,148,65,46,5,55,61,220,31,206,45,108,33,178,14,5,8,91,37,37,5,249,52,134,26,195,47,144,7,244,31,222,13,231,51,242,6,171,63,199,25,163,63,78,30,73,33,247,9,57,28,85,10,93,71,65,29,245,65,200,8,218,69,68,11,113,67,0,13,201,36,194,78,34,43,128,32,6,5,108,2,151,5,71,2,105,23,241,8,138,15,42,14,24,20,240,2,97,52,62,3,177,21,44,11,244,45,20,23,241,41,48,2,70,21,52,2,9,52,192,11,170,46,99,14,175,77,30,3,97,38,216,2,95,53,44,34,223,28,237,11,211,9,10,3,162,23,65,3,69,25,210,19,113,32,159,9,253,23,73,7,204,59,238,4,72,56,195,17,95,53,163,17,65,12,167,11,175,9,235,4,240,58,39,18,22,60,47,10,156,56,88,9,174,48,233,9,115,29,133,11,109,50,28,47,92,21,172,2,69,12,210,2,217,19,250,4,188,49,104,16,198,59,169,2,139,30,80,2,134,25,229,7,94,64,33,34,52,52,114,3,21,21,131,3,64,57,130,8,149,57,131,16,190,55,18,5,105,54,237,7,117,60,58,29,199,61,220,17,217,9,221,7,198,19,12,7,39,20,182,25,218,27,13,14,168,42,75,6,209,45,172,6,7,66,127,13,140,63,240,25,90,36,239,3,153,36,58,8,238,74,173,19,153,48,173,16,47,62,52,5,253,59,184,13,122,46,61,55,229,62,198,26,218,7,225,2,195,14,93,3,190,44,64,11,236,13,212,13,97,35,217,4,103,48,128,3,98,33,21,18,41,45,144,22,193,31,77,2,26,32,76,2,40,73,171,14,173,50,77,12,113,61,246,2,250,64,242,2,118,59,130,43,255,61,160,8,65,18,98,2,234,39,166,2,153,59,50,16,97,22,255,12,185,32,134,6,150,77,17,9,90,60,135,21,230,54,105,21,96,22,72,11,156,29,66,5,48,56,205,20,108,63,110,15,14,59,160,14,202,59,155,5,5,57,230,15,13,48,80,61,193,29,163,6,122,8,116,3,107,17,215,17,174,70,234,12,198,49,47,3,78,58,139,3,168,58,185,16,158,60,176,32,74,70,63,4,54,9,97,3,153,63,203,14,63,61,244,17,228,63,254,5,200,64,162,8,193,65,225,37,57,62,161,17,205,12,61,4,171,37,139,8,197,46,180,23,239,35,110,17,251,34,93,6,49,40,246,11,97,64,35,20,106,60,154,27,110,53,239,9,153,20,229,8,106,65,69,24,15,65,80,13,80,79,35,13,0,73,193,7,92,55,67,50,50,59,87,61,121,17,252,3,145,6,118,3,215,16,205,16,248,34,73,14,5,23,123,4,127,45,172,5,14,62,179,8,230,17,244,25,17,27,181,4,76,24,31,3,127,48,81,13,96,62,37,15,147,77,61,8,217,37,93,8,150,57,126,34,144,56,39,10,25,7,214,4,91,30,45,3,135,74,58,17,178,21,16,8,103,14,28,11,27,68,208,8,57,65,134,17,71,63,12,21,92,31,203,10,77,13,71,8,18,68,101,21,130,53,226,10,167,77,160,10,138,35,40,15,252,70,225,18,184,67,175,47,252,19,228,3,71,19,220,3,160,38,9,12,126,23,251,20,9,62,131,6,213,32,159,4,239,58,62,9,65,77,90,27,187,46,26,6,111,28,104,4,219,65,252,5,146,61,5,21,116,57,17,8,137,78,107,8,6,67,53,32,247,69,174,24,91,21,224,5,4,16,14,10,13,68,154,26,41,22,72,11,252,64,54,13,15,35,39,7,191,78,129,18,94,76,126,28,2,26,221,10,208,44,249,12,197,75,190,19,190,73,114,18,55,64,69,9,206,79,34,17,89,44,158,103,73,45,252,11,50,11,30,6,244,19,46,4,142,37,51,19,75,19,208,13,117,29,110,3,237,80,83,3,26,27,43,17,159,65,53,30,153,39,251,3,117,38,196,3,134,60,115,15,99,60,102,13,175,73,214,3,152,78,195,3,236,65,87,50,254,55,104,16,199,25,196,4,6,36,46,3,46,66,14,20,29,22,34,19,112,21,6,7,34,79,122,15,109,66,34,24,9,70,41,23,149,36,92,13,50,29,179,7,81,76,57,20,59,74,190,11,70,64,204,14,198,62,63,9,216,33,183,10,229,36,246,102,104,42,7,5,227,13,241,3,230,21,38,14,253,75,136,21,165,48,29,3,154,80,143,3,67,60,250,11,141,66,35,40,195,73,73,10,73,15,244,4,63,76,43,13,132,70,110,20,91,75,142,6,52,76,100,12,152,70,2,42,241,64,189,26,62,12,250,8,117,42,133,9,220,60,1,27,53,49,53,13,108,43,225,12,122,65,120,9,165,73,59,26,19,67,159,38,199,49,45,10,233,34,68,12,89,74,84,30,171,71,40,15,251,79,98,14,146,76,52,13,244,50,173,75,30,41,84,90,142,117,1,63,249,49,6,63,67,28,11,63,110,52,16,63,0,126,21,63,0,248,26,63,0,164,32,63,0,134,38,63,0,160,44,63,0,242,50,63,0,126,57,63,0,74,64,63,0,84,71,63,0,160,78,63,0,48,86,63,0,8,94,63,0,42,102,63,0,152,110,63,0,36,118,63,0,150,123,63,0,226,126,63,0,0,128,63,0,238,126,63,0,176,123,63,0,74,118,63,0,202,110,63,0,64,101,63,0,192,89,63,0,100,76,63,0,72,61,63,0,144,44,63,0,94,26,63,0,218,6,63,0,92,228,62,0,20,185,62,0,52,140,62,0,72,60,62,0,32,189,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,204,76,62,205,204,204,62,0,0,0,63,154,153,25,63,51,51,51,63,0,0,64,63,205,204,76,63,154,153,89,63,102,102,102,63,51,51,115,63,0,0,128,63,102,102,134,63,205,204,140,63,51,51,147,63,154,153,153,63,183,98,74,64,95,96,52,64,189,194,32,64,44,71,15,64,182,100,255,63,157,158,227,63,198,221,202,63,251,205,180,63,108,36,161,63,73,158,143,63,0,0,128,63,7,41,100,63,20,89,75,63,243,59,53,63,102,134,33,63,148,245,15,63,203,77,0,63,162,179,228,62,174,212,203,62,13,170,181,62,129,232,161,62,18,77,144,62,183,155,128,62,180,62,101,62,139,80,76,62,139,24,54,62,241,74,34,62,160,164,16,62,213,233,0,62,163,201,229,61,205,204,204,61,43,135,182,61,243,4,181,63,240,55,152,63,0,0,128,63,253,68,87,63,243,4,53,63,240,55,24,63,0,0,0,63,0,0,0,0,243,4,181,62,0,0,0,0,91,148,153,61,212,241,216,61,215,163,16,62,114,225,64,62,212,212,114,62,85,77,144,62,28,153,167,62,26,110,192,62,16,233,215,62,184,64,242,62,192,231,7,63,44,125,24,63,85,24,43,63,203,248,63,63,254,101,87,63,235,173,113,63,129,149,135,63,197,32,152,63,201,176,170,63,203,132,191,63,235,226,214,63,113,27,241,63,108,67,7,64,135,196,23,64,102,73,42,64,207,131,67,64,144,20,99,64,107,241,134,64,4,226,169,64,240,138,226,64,189,12,23,65,5,93,85,65,85,77,16,61,190,106,37,62,14,158,73,61,80,143,229,62,90,73,107,61,113,29,79,63,71,88,148,61,181,81,225,63,101,85,228,61,197,0,17,63,44,14,231,61,111,156,140,63,212,239,18,62,60,19,58,63,240,80,20,62,215,18,178,62,80,171,56,62,186,102,134,63,230,175,64,62,216,159,12,64,84,83,66,62,143,142,131,62,171,4,75,62,183,39,248,62,75,173,87,62,191,125,65,63,156,253,97,62,226,61,23,63,98,192,114,62,79,62,169,63,76,166,130,62,102,107,173,62,232,19,153,62,237,70,107,63,202,22,161,62,179,93,5,63,40,153,172,62,121,36,188,63,221,206,174,62,175,125,51,64,210,252,185,62,12,121,60,63,156,78,186,62,79,59,188,62,251,92,189,62,57,14,248,63,119,130,189,62,48,160,137,63,130,87,203,62,34,166,12,63,174,101,218,62,133,66,96,63,81,192,230,62,26,195,92,62,230,172,239,62,59,254,43,63,184,228,240,62,248,250,158,63,185,199,242,62,62,179,222,63,137,65,248,62,52,43,251,62,13,114,255,62,14,163,120,63,91,239,7,63,229,39,73,63,60,46,10,63,53,93,8,64,8,200,11,63,91,236,22,63,19,240,11,63,16,65,67,64,228,101,13,63,151,144,199,62,207,105,14,63,147,54,179,63,182,71,15,63,111,126,141,63,215,250,18,63,34,226,42,63,197,117,24,63,156,53,84,63,133,7,25,63,122,109,254,62,228,248,29,63,62,121,238,63,215,161,30,63,23,97,156,63,33,5,31,63,57,69,115,63,135,224,32,63,225,121,33,63,195,241,32,63,207,191,135,64,245,17,36,63,254,209,195,63,0,84,37,63,122,137,169,62,174,46,39,63,240,135,63,63,103,180,41,63,125,233,137,63,174,100,43,63,44,100,40,64,95,123,46,63,30,110,235,63,139,22,48,63,57,69,103,63,6,76,48,63,143,170,162,63,28,240,49,63,175,6,20,63,71,171,50,63,125,92,219,62,254,39,55,63,127,246,79,63,9,224,58,63,166,9,197,63,122,200,60,63,122,170,141,63,111,128,61,63,205,34,2,64,185,169,61,63,152,134,17,63,58,176,64,63,87,206,50,63,176,175,65,63,195,160,100,63,88,142,68,63,44,157,255,62,119,189,68,63,133,152,109,64,91,237,69,63,198,138,170,63,125,63,73,63,229,128,133,63,70,238,73,63,252,27,116,62,222,117,74,63,149,124,17,64,69,155,75,63,28,152,202,63,82,67,79,63,193,114,24,63,39,47,82,63,93,167,65,63,85,24,83,63,208,68,108,63,251,117,83,63,213,232,151,63,49,210,83,63,44,74,241,63,31,128,84,63,90,214,194,64,120,71,86,63,196,122,52,64,176,118,88,63,188,204,190,63,178,43,89,63,171,36,210,62,7,69,91,63,66,207,58,63,183,213,92,63,115,133,119,63,59,227,95,63,163,64,215,63,174,239,95,63,148,188,150,63,21,25,97,63,128,72,19,64,223,252,98,63,6,242,28,63,8,144,101,63,249,245,71,63,119,159,103,63,173,251,94,64,10,246,103,63,171,90,170,63,131,79,107,63,48,72,240,63,162,126,107,63,121,203,17,63,64,249,107,63,62,94,132,63,246,36,108,63,18,131,192,62,28,41,111,63,126,27,190,63,243,87,112,63,162,127,94,63,47,109,112,63,248,53,24,64,162,124,117,63,91,181,143,63,199,131,117,63,104,176,49,63,197,3,118,63,183,40,223,63,237,131,120,63,39,162,56,64,23,158,123,63,119,131,80,63,225,121,125,63,41,62,170,63,39,23,127,63,140,100,233,63,109,0,128,63,243,173,119,63,89,24,128,63,207,16,246,62,205,6,129,63,23,12,163,64,235,198,129,63,114,191,6,64,82,98,131,63,211,249,48,63,145,128,131,63,21,114,199,63,18,219,131,63,164,137,101,64,92,87,132,63,206,27,143,63,70,8,133,63,105,198,34,64,193,199,136,63,0,29,86,63,246,94,138,63,100,205,168,63,87,236,139,63,87,36,17,64,218,60,140,63,94,47,219,63,19,41,141,63,92,199,132,63,172,54,141,63,156,82,98,64,169,188,141,63,152,52,2,63,51,51,147,63,207,247,255,64,195,15,148,63,139,78,158,63,12,143,149,63,74,40,17,64,146,145,151,63,98,157,70,63,60,245,154,63,249,131,193,63,175,62,156,63,173,179,139,64,142,172,156,63,158,177,123,63,69,73,160,63,132,211,49,64,239,140,166,63,254,40,246,63,0,0,104,63,0,64,82,63,0,140,62,63,0,172,44,63,0,124,28,63,0,208,13,63,0,132,0,63,0,240,232,62,0,24,211,62,0,80,191,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,31,3,31,63,255,0,15,0,9,0,13,0,13,0,15,0,78,228,13,16,15,0,15,68,79,0,30,15,15,174,175,69,127,239,255,15,255,0,9,1,17,0,1,28,221,0,21,0,255,0,16,0,253,0,15,79,95,61,255,255,255,79,255,28,255,223,255,143,255,0,13,0,0,0,21,1,7,0,1,2,31,1,17,5,127,0,31,65,87,31,255,5,119,13,95,77,255,79,255,15,255,0,0,2,5,0,17,5,125,16,21,47,255,64,80,13,253,4,15,7,31,7,127,15,191,13,127,15,255,77,125,15,255,16,0,0,0,0,0,0,0,85,87,87,127,0,0,0,0,17,17,17,17,81,17,19,17,17,17,19,17,17,17,51,17,19,17,19,19,19,19,49,49,17,1,17,17,113,17,17,117,23,0,0,0,0,0,0,0,4,0,1,1,67,46,255,63,64,0,0,0,0,0,0,0,1,19,3,127,0,0,0,0,0,0,0,0,80,0,243,95,132,4,23,159,4,35,5,255,0,0,0,2,3,3,51,215,5,3,95,63,23,51,255,255,0,128,2,4,18,0,17,87,5,37,5,3,53,191,159,255,7,111,32,64,23,6,250,232,1,7,31,159,31,255,255,255,80,0,0,0,0,0,0,0,55,115,0,25,87,127,245,251,112,51,240,249,127,255,255,255,0,0,1,1,0,0,227,223,5,23,5,15,0,27,15,223,0,4,0,0,13,15,3,127,0,0,0,1,0,29,69,47,0,0,0,13,0,10,255,255,0,4,0,5,1,63,207,255,16,1,128,201,15,15,255,255,0,0,0,0,27,31,255,255,79,84,7,31,87,71,215,61,255,255,95,31,127,255,127,127,5,15,1,15,15,95,155,223,127,255,95,29,95,255,15,31,15,95,3,31,79,95,247,127,127,255,13,15,251,255,247,191,15,79,215,63,79,127,255,255,103,191,86,37,31,127,159,255,0,0,0,5,95,127,1,223,20,0,5,15,7,162,9,15,0,0,0,0,15,95,24,215,148,113,0,5,31,183,12,7,15,15,0,15,15,31,132,143,5,21,5,15,79,255,135,223,5,1,16,0,15,15,0,8,5,4,4,1,79,255,159,143,74,64,95,95,255,254,223,255,127,247,255,127,255,255,123,255,15,253,215,95,79,127,127,223,255,255,255,255,255,119,223,127,79,239,255,255,119,255,255,255,111,255,15,79,255,255,157,255,15,239,255,223,111,255,255,255,79,255,205,15,79,255,255,223,0,0,0,11,5,2,2,15,4,0,0,12,1,6,0,15,32,3,0,0,5,15,64,8,0,0,0,1,0,1,12,15,1,0,128,0,0,0,128,0,0,20,1,5,1,21,175,15,0,1,16,0,8,0,70,12,32,0,136,0,15,21,255,223,2,0,0,15,127,95,219,255,79,62,5,15,127,247,149,79,13,15,1,15,79,95,159,223,37,14,13,13,79,127,143,15,15,250,4,79,79,255,247,119,71,237,5,15,255,255,223,255,79,111,216,95,15,127,223,95,7,15,148,13,31,255,255,255,0,2,0,3,70,87,1,13,1,8,1,15,71,108,13,15,2,0,0,0,11,79,0,8,5,0,149,1,15,127,12,15,1,14,0,0,15,65,0,0,4,36,13,15,15,127,207,223,0,0,0,0,4,64,0,0,6,38,207,5,207,127,223,223,0,0,23,95,255,253,255,255,70,9,79,95,127,253,223,255,10,136,167,127,127,255,255,255,15,4,223,127,79,255,159,255,14,230,223,255,127,255,255,255,15,236,143,79,127,255,223,255,15,207,223,255,111,127,255,255,3,12,157,15,127,255,255,255,16,79,30,0,192,109,140,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,251,30,0,108,0,0,0,96,224,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,247,34,0,108,0,0,0,208,126,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,156,29,0,108,0,0,0,48,127,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,100,33,0,108,0,0,0,16,129,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,0,0,0,0,178,157,239,167,198,75,3,64,246,40,92,143,194,245,10,192,229,208,34,219,249,126,15,64,25,4,86,14,45,178,16,192,109,231,251,169,241,210,10,64,164,112,61,10,215,163,1,192,229,208,34,219,249,126,244,63,104,145,237,124,63,53,226,191,144,160,248,49,230,174,181,63,200,138,31,0,40,122,31,0,0,0,0,0,0,0,0,0,10,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,88,53,32,0,24,2,32,0,0,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,232,61,29,0,168,237,28,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,157,29,0,108,0,0,0,56,226,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,1,0,0,0,40,1,0,0,2,0,0,0,2,0,0,0,3,0,0,0,42,1,0,0,4,0,0,0,30,0,0,0,5,0,0,0,255,255,255,255,0,0,0,0,0,238,2,0,0,0,0,0,94,46,215,245,117,67,136,63,15,254,15,192,16,182,167,191,101,249,173,250,9,219,176,63,92,182,57,219,245,44,150,191,57,210,67,45,198,245,172,191,107,120,208,202,1,9,182,63,5,93,233,186,100,72,161,191,8,51,62,114,193,150,165,191,114,131,0,140,65,109,176,63,98,225,125,74,12,163,161,191,13,118,207,170,119,143,124,63,0,0,0,0,0,0,240,63,35,237,112,46,53,253,20,192,209,212,113,17,104,55,37,64,218,176,55,157,136,123,33,192,242,90,76,237,202,108,245,191,28,50,77,55,210,40,32,64,98,8,1,227,225,216,21,192,236,6,75,129,188,97,225,63,162,248,6,192,251,251,235,63,4,215,134,127,13,46,214,191,114,143,186,175,137,19,159,63,191,226,39,102,157,227,239,63,236,226,39,102,157,227,255,191,191,226,39,102,157,227,239,63,0,0,0,0,0,0,240,63,82,227,70,207,144,227,255,191,13,197,17,250,83,199,239,63,16,177,2,0,0,0,0,0,247,196,119,73,74,0,102,63,212,40,180,76,236,116,129,191,12,38,51,49,160,118,129,63,141,84,113,239,143,240,87,63,9,254,4,23,57,121,131,191,137,123,76,66,80,158,121,63,121,178,140,202,26,9,83,63,110,149,115,234,93,177,109,191,236,63,19,72,95,181,96,63,21,123,190,189,13,154,64,191,135,127,218,92,54,176,6,63,0,0,0,0,0,0,240,63,236,196,42,79,238,76,22,192,99,40,74,44,197,226,40,64,233,242,164,61,207,191,41,192,194,199,57,9,52,175,8,64,244,14,0,219,238,127,26,64,219,125,108,123,119,78,28,192,41,165,192,58,19,24,4,64,162,17,129,27,144,59,177,63,140,208,242,143,92,114,207,191,155,13,121,170,74,72,164,63,69,95,207,252,27,225,239,63,69,95,207,252,27,225,255,191,69,95,207,252,27,225,239,63,0,0,0,0,0,0,240,63,168,145,220,19,13,225,255,191,194,89,132,203,85,194,239,63,128,50,2,0,0,0,0,0,255,192,47,66,142,51,122,63,208,31,46,123,140,45,154,191,0,44,185,41,119,169,165,63,134,254,76,12,27,15,163,191,22,167,60,199,251,152,145,63,122,234,98,18,134,2,121,63,76,161,159,200,62,101,159,191,203,207,86,13,14,64,166,63,210,235,199,9,136,227,160,191,32,180,146,242,131,13,139,63,38,20,165,199,28,12,98,191,0,0,0,0,0,0,240,63,48,109,141,165,179,151,24,192,15,116,20,210,156,153,47,64,194,146,30,160,237,200,52,192,80,152,68,198,26,250,39,64,81,54,51,248,189,234,10,64,228,176,123,43,202,114,36,192,146,219,229,174,189,159,26,64,234,239,9,113,33,190,250,191,233,32,186,138,108,189,171,191,251,157,15,188,32,225,178,63,123,253,88,204,44,218,239,63,168,253,88,204,44,218,255,191,123,253,88,204,44,218,239,63,0,0,0,0,0,0,240,63,204,124,100,113,22,218,255,191,9,253,154,78,134,180,239,63,0,244,1,0,0,0,0,0,125,229,64,195,227,167,118,63,72,241,252,165,27,162,149,191,0,106,231,95,216,43,162,63,7,39,175,53,75,55,161,191,196,95,243,159,166,51,141,63,141,147,153,62,8,138,139,63,164,22,136,247,248,94,161,191,210,30,13,80,131,188,161,63,47,131,42,158,107,225,148,191,149,159,191,13,106,86,123,63,0,155,98,122,121,185,78,191,0,0,0,0,0,0,240,63,152,22,127,20,81,149,24,192,255,177,101,125,64,12,48,64,164,13,207,64,222,48,54,192,156,8,108,205,192,126,46,64,242,115,84,63,245,163,224,191,1,106,242,120,128,2,32,192,111,74,49,227,199,111,26,64,17,93,186,149,74,7,3,192,178,59,45,11,62,48,213,63,54,193,178,37,146,213,114,63,134,189,191,139,117,213,239,63,179,189,191,139,117,213,255,191,134,189,191,139,117,213,239,63,0,0,0,0,0,0,240,63,210,36,207,68,89,213,255,191,39,173,96,165,35,171,239,63,128,181,1,0,0,0,0,0,207,102,71,144,165,168,117,63,232,225,51,119,4,99,147,191,102,73,45,90,238,79,160,63,188,226,38,11,4,247,157,191,224,228,201,19,28,81,125,63,202,109,220,206,129,85,148,63,165,16,217,27,242,127,160,191,184,229,135,7,200,69,154,63,135,230,109,115,91,203,136,191,186,249,176,191,228,168,106,63,33,211,115,95,25,243,60,191,0,0,0,0,0,0,240,63,113,154,193,6,78,255,24,192,73,215,30,198,102,108,49,64,224,99,30,42,66,222,59,192,119,86,165,174,118,202,58,64,36,7,29,253,204,223,42,192,116,95,248,132,167,32,229,191,187,111,220,119,117,37,24,64,51,219,173,134,63,255,16,192,135,22,164,233,93,136,246,63,188,255,173,92,124,239,200,191,24,233,223,99,102,207,239,63,24,233,223,99,102,207,255,191,24,233,223,99,102,207,239,63,0,0,0,0,0,0,240,63,204,192,239,123,65,207,255,191,202,34,160,151,22,159,239,63,0,119,1,0,0,0,0,0,197,238,246,183,19,23,120,63,34,92,228,154,217,133,144,191,145,136,68,194,81,95,150,63,196,93,45,132,213,215,145,191,150,114,34,207,14,8,115,63,27,47,22,223,88,228,134,63,164,37,69,58,150,191,149,191,126,128,16,125,84,16,148,63,19,68,56,132,216,28,134,191,41,22,188,196,211,217,108,63,227,193,240,232,64,175,68,191,0,0,0,0,0,0,240,63,50,27,112,246,143,233,23,192,128,169,26,34,176,54,48,64,97,141,206,75,175,186,57,192,0,81,146,218,154,103,57,64,178,126,9,122,197,82,45,192,105,225,156,209,29,135,6,64,63,14,153,27,163,29,4,64,219,152,103,129,210,226,1,192,136,190,168,185,144,64,232,63,236,132,97,14,188,204,185,191,45,90,234,249,83,199,239,63,45,90,234,249,83,199,255,191,45,90,234,249,83,199,239,63,0,0,0,0,0,0,240,63,5,250,233,202,33,199,255,191,167,116,213,81,12,143,239,63,136,88,1,0,0,0,0,0,119,180,64,230,164,80,155,63,187,50,152,72,88,32,189,191,28,72,153,191,86,133,205,63,176,116,190,228,57,170,211,191,176,206,96,115,155,61,213,63,127,195,143,192,15,172,213,191,0,165,99,12,73,91,212,63,102,248,155,135,27,96,206,191,49,31,49,215,209,107,191,63,8,232,181,55,48,169,163,191,122,88,242,67,190,131,118,63,0,0,0,0,0,0,240,63,72,141,11,89,1,70,25,192,249,205,33,101,66,80,50,64,252,35,184,80,209,225,63,192,206,59,88,156,218,68,66,64,177,210,65,220,226,59,60,192,44,107,245,227,151,126,44,64,177,209,159,177,212,47,16,192,62,161,171,108,238,37,200,63,71,167,70,17,222,68,208,63,87,120,197,93,124,200,174,191,31,22,77,203,85,194,239,63,76,22,77,203,85,194,255,191,31,22,77,203,85,194,239,63,0,0,0,0,0,0,240,63,45,208,220,96,26,194,255,191,213,184,122,107,34,133,239,63,0,250,0,0,0,0,0,0,34,192,29,148,248,193,154,63,194,215,57,17,72,207,180,191,253,72,221,15,166,30,195,63,254,97,138,52,64,197,203,191,165,138,80,116,175,1,208,63,108,53,58,45,209,165,205,191,10,123,47,145,130,77,198,63,240,184,249,1,242,93,186,191,24,35,70,106,245,205,165,63,201,86,87,54,74,7,132,191,150,75,192,147,172,65,81,63,0,0,0,0,0,0,240,63,157,133,74,197,236,241,22,192,138,65,240,26,10,39,48,64,179,114,245,174,193,175,61,192,197,7,8,203,77,199,67,64,12,249,134,165,161,233,67,192,50,86,10,184,140,129,62,64,76,5,235,104,54,110,49,192,210,99,254,103,200,52,28,64,167,47,135,244,231,236,252,191,136,202,46,198,217,82,204,63,198,83,154,164,35,171,239,63,198,83,154,164,35,171,255,191,198,83,154,164,35,171,239,63,0,0,0,0,0,0,240,63,104,221,109,30,179,170,255,191,160,148,141,85,40,87,239,63,192,218,0,0,0,0,0,0,124,207,161,70,26,26,160,63,116,179,39,203,49,127,175,191,247,44,218,144,166,166,180,63,214,232,238,54,219,237,184,191,14,125,62,203,5,229,182,63,146,130,168,211,244,228,177,191,228,73,105,192,225,57,169,63,121,102,119,29,134,47,160,191,242,48,55,47,6,214,141,63,166,40,238,49,81,227,105,191,133,142,68,159,86,194,85,63,0,0,0,0,0,0,240,63,146,92,53,98,190,126,19,192,48,163,142,218,20,20,40,64,191,168,14,163,252,25,52,192,81,170,219,58,152,26,57,64,41,113,235,103,104,74,56,192,202,137,5,147,134,69,50,64,170,32,88,126,173,231,36,192,23,221,144,186,120,54,17,64,188,140,54,22,217,49,242,191,143,171,178,141,224,146,194,63,87,163,78,150,22,159,239,63,87,163,78,150,22,159,255,191,87,163,78,150,22,159,239,63,0,0,0,0,0,0,240,63,151,198,109,213,131,158,255,191,215,255,94,174,82,63,239,63,128,187,0,0,0,0,0,0,50,23,78,148,59,192,163,63,137,21,35,224,69,31,150,191,30,25,58,32,147,55,84,191,100,127,76,30,138,91,24,191,57,67,88,105,42,243,144,191,71,48,13,28,80,34,150,63,183,143,205,46,252,60,149,191,145,39,155,184,170,87,120,63,78,249,55,236,66,26,105,63,191,132,219,151,14,134,31,63,93,40,82,156,133,161,103,63,0,0,0,0,0,0,240,63,105,9,132,109,238,197,14,192,39,38,121,177,147,66,31,64,79,178,147,196,243,174,38,192,77,9,136,125,46,28,42,64,99,181,117,43,64,147,40,192,108,219,102,168,67,247,34,64,70,223,201,63,133,125,23,192,246,69,57,117,138,9,6,64,224,81,234,151,194,213,235,191,22,209,63,188,20,209,193,63,82,90,102,79,12,143,239,63,82,90,102,79,12,143,255,191,82,90,102,79,12,143,239,63,0,0,0,0,0,0,240,63,142,99,111,244,68,142,255,191,136,162,186,84,167,31,239,63,68,172,0,0,0,0,0,0,160,218,19,97,87,190,171,63,11,103,131,69,8,207,157,191,11,230,107,114,174,97,129,191,200,135,220,48,143,110,129,191,157,37,85,210,193,25,129,191,134,135,184,203,230,253,150,63,39,181,23,72,37,150,154,191,246,69,14,107,124,163,144,63,56,93,161,143,153,187,99,191,70,250,109,80,214,161,123,63,51,47,54,53,98,195,94,191,0,0,0,0,0,0,240,63,6,126,21,145,226,211,11,192,124,102,244,223,228,115,25,64,116,244,13,236,83,24,33,192,233,177,50,247,48,244,34,64,239,9,159,243,69,161,33,192,178,24,246,3,131,106,27,64,11,23,20,217,46,148,17,192,203,6,226,181,165,145,1,64,156,177,133,97,139,8,232,191,118,42,253,188,196,212,192,63,212,16,18,104,34,133,239,63,212,16,18,104,34,133,255,191,212,16,18,104,34,133,239,63,0,0,0,0,0,0,240,63,58,43,218,132,54,132,255,191,222,236,147,150,28,12,239,63,168,147,0,0,0,0,0,0,87,243,243,141,89,81,182,63,187,124,168,70,215,124,132,191,121,175,120,139,99,10,176,191,108,237,123,175,129,236,134,191,153,15,118,108,57,185,82,191,19,36,182,146,23,80,149,63,238,162,198,210,218,106,144,191,204,81,181,170,27,213,147,63,251,170,215,141,165,33,127,63,204,193,173,110,231,230,104,191,141,16,227,135,227,154,72,191,0,0,0,0,0,0,240,63,225,65,18,98,122,6,5,192,65,82,32,185,123,76,12,64,105,34,107,92,243,122,14,192,158,86,172,24,167,77,15,64,99,42,228,160,15,72,12,192,248,114,135,124,99,181,5,64,135,27,157,213,47,224,253,191,45,237,184,143,155,238,241,63,220,215,135,222,96,22,223,191,115,95,197,243,149,1,189,63,208,132,81,48,214,112,239,63,253,132,81,48,214,112,255,191,208,132,81,48,214,112,239,63,0,0,0,0,0,0,240,63,20,108,27,235,149,111,255,191,115,59,15,235,44,228,238,63,0,125,0,0,0,0,0,0,241,119,23,71,12,201,195,63,136,170,87,65,50,227,183,191,246,216,149,178,56,253,175,191,212,141,60,98,152,39,150,63,15,64,199,163,209,156,172,191,171,78,232,86,45,123,168,63,214,62,198,171,59,54,98,63,47,107,20,185,88,64,160,63,238,33,35,135,177,122,140,191,80,155,72,10,164,174,122,63,207,141,107,9,225,12,130,191,0,0,0,0,0,0,240,63,145,69,61,11,43,8,3,192,158,18,71,136,25,202,6,64,5,109,176,90,138,42,5,192,226,192,107,249,83,229,1,64,85,26,176,107,99,190,250,191,59,4,2,10,105,24,240,63,30,237,181,186,3,105,221,191,248,74,46,12,204,246,196,63,47,41,133,24,165,195,169,191,144,190,25,71,223,10,152,63,149,236,96,73,40,87,239,63,149,236,96,73,40,87,255,191,149,236,96,73,40,87,239,63,0,0,0,0,0,0,240,63,224,62,238,205,106,85,255,191,238,52,167,137,203,177,238,63,192,93,0,0,0,0,0,0,45,33,68,101,216,99,211,63,13,242,27,221,38,242,204,191,31,155,214,217,201,251,181,191,48,106,136,146,0,207,160,63,42,241,39,172,235,192,130,191,74,23,235,77,116,53,152,191,58,82,97,60,119,240,119,191,44,162,59,19,27,17,176,63,5,119,162,194,193,93,225,190,93,236,29,149,60,221,96,63,254,79,225,18,154,53,158,191,0,0,0,0,0,0,240,63,189,230,61,180,191,205,249,191,207,180,185,17,194,70,241,63,154,139,250,113,133,107,208,191,177,214,138,41,142,213,196,191,8,250,225,13,80,250,204,191,33,145,242,79,141,9,217,63,231,77,7,178,57,86,204,191,124,115,66,108,140,10,167,63,218,187,97,92,56,138,148,63,191,156,19,136,155,198,104,63,20,206,26,0,207,53,239,63,65,206,26,0,207,53,255,191,20,206,26,0,207,53,239,63,0,0,0,0,0,0,240,63,251,142,188,33,80,51,255,191,178,26,242,188,155,112,238,63,34,86,0,0,0,0,0,0,92,65,204,137,244,135,213,63,249,69,133,139,193,93,208,191,138,220,181,196,248,71,190,191,82,82,232,220,164,132,190,63,200,31,137,62,105,14,180,191,79,101,137,91,19,64,115,191,20,188,151,157,91,37,120,191,151,43,39,61,220,78,173,63,188,121,230,134,78,10,129,63,121,1,134,222,13,191,144,191,140,202,208,127,50,6,146,191,0,0,0,0,0,0,240,63,48,118,159,74,57,250,247,191,239,27,204,246,187,243,235,63,207,9,154,244,174,62,191,63,236,2,32,94,21,217,233,191,216,69,1,144,135,160,222,63,198,185,85,146,127,225,191,191,110,73,114,241,93,211,164,191,62,39,251,31,156,85,181,63,254,211,216,15,250,177,165,191,92,75,230,2,146,124,158,63,152,52,59,107,43,36,239,63,197,52,59,107,43,36,255,191,152,52,59,107,43,36,239,63,0,0,0,0,0,0,240,63,125,31,207,50,56,33,255,191,192,147,78,71,61,78,238,63,212,73,0,0,0,0,0,0,25,106,2,242,219,167,216,63,96,2,184,32,116,183,209,191,19,143,6,155,156,140,185,191,152,234,158,109,206,121,185,63,22,233,241,219,255,222,182,191,219,125,189,41,147,104,106,191,62,124,60,151,137,19,82,191,73,54,73,200,110,96,163,63,162,111,160,84,66,62,145,63,210,163,193,215,202,125,135,191,160,110,14,112,58,226,147,191,0,0,0,0,0,0,240,63,94,133,151,150,224,192,244,191,183,210,89,143,131,237,236,63,113,241,186,193,236,243,210,191,95,17,230,51,204,22,219,191,2,187,236,127,64,71,216,63,161,225,162,132,199,68,216,191,150,193,125,229,20,247,205,63,41,210,197,143,152,238,163,191,36,91,146,135,220,129,112,63,37,178,60,60,61,163,162,63,75,115,122,137,44,228,238,63,75,115,122,137,44,228,254,191,75,115,122,137,44,228,238,63,0,0,0,0,0,0,240,63,133,93,221,115,65,223,254,191,123,18,47,62,47,210,237,63,128,62,0,0,0,0,0,0,129,213,143,103,234,190,220,63,192,115,192,172,200,94,194,191,0,184,172,136,253,41,205,191,15,236,159,153,97,16,141,191,178,156,195,234,117,225,164,63,67,252,140,166,66,189,191,191,86,74,4,181,194,250,164,63,193,175,189,46,49,211,186,63,30,94,167,239,17,22,147,191,236,38,37,198,176,89,160,191,76,164,77,137,80,50,118,63,0,0,0,0,0,0,240,63,43,99,103,223,67,26,228,191,183,80,102,97,201,251,210,63,227,81,99,138,21,216,215,191,183,212,176,113,9,131,97,63,130,37,186,109,42,230,218,191,175,240,202,169,97,106,204,63,112,186,245,115,56,32,121,63,222,3,62,232,30,70,177,63,76,198,139,158,71,158,173,63,87,85,220,210,32,128,160,63,162,74,80,205,141,221,238,63,162,74,80,205,141,221,254,191,162,74,80,205,141,221,238,63,0,0,0,0,0,0,240,63,147,20,125,71,103,216,254,191,96,1,71,166,104,197,237,63,224,46,0,0,0,0,0,0,214,175,6,93,68,30,226,63,107,180,52,94,12,38,232,191,72,155,25,68,57,202,196,63,102,6,2,243,192,110,197,63,232,114,101,123,173,49,200,191,236,21,72,1,221,203,211,63,190,128,199,106,234,163,209,191,74,124,66,94,139,131,122,63,19,84,73,99,58,35,182,63,124,52,246,62,76,102,163,191,222,155,204,206,226,23,120,191,0,0,0,0,0,0,240,63,197,102,124,41,159,196,240,191,213,161,248,91,248,168,210,63,81,61,138,44,229,39,209,191,35,114,239,228,40,203,128,63,202,138,18,136,196,213,220,63,22,215,218,105,7,36,213,191,179,50,221,97,182,64,177,63,108,42,253,84,209,126,168,191,216,212,254,132,235,202,144,63,58,215,119,170,229,129,146,63,247,168,92,169,17,185,238,63,247,168,92,169,17,185,254,191,247,168,92,169,17,185,238,63,0,0,0,0,0,0,240,63,255,251,115,239,138,178,254,191,54,172,138,198,48,127,237,63,17,43,0,0,0,0,0,0,13,214,43,177,151,151,226,63,30,204,55,171,22,4,225,191,151,183,151,57,123,74,194,191,42,112,91,63,47,109,198,63,235,71,167,5,164,89,152,63,174,158,17,79,49,234,195,63,33,128,18,139,125,56,208,191,102,94,30,159,234,172,144,63,13,56,49,211,101,183,177,63,248,239,170,144,253,13,163,191,99,105,238,162,82,180,126,191,0,0,0,0,0,0,240,63,9,162,4,98,208,84,224,191,159,53,10,182,134,100,212,191,233,26,64,31,159,237,201,191,113,221,175,29,31,218,194,63,71,180,1,35,0,238,216,63,143,150,116,253,74,215,205,191,160,159,226,226,15,220,170,191,139,80,254,113,58,169,153,191,167,98,233,63,126,2,153,63,227,96,172,195,224,159,146,63,252,4,93,62,153,172,238,63,41,5,93,62,153,172,254,191,252,4,93,62,153,172,238,63,0,0,0,0,0,0,240,63,169,23,62,147,144,165,254,191,247,228,247,210,67,103,237,63,64,31,0,0,0,0,0,0,119,157,38,168,232,42,225,63,221,69,23,214,253,251,218,191,189,171,77,172,42,155,102,191,213,51,35,55,242,217,165,63,42,16,217,211,105,38,186,191,220,17,8,177,26,173,194,63,205,75,240,92,99,48,153,191,167,104,9,158,140,173,188,191,223,19,236,99,145,201,164,191,186,21,107,134,153,132,168,63,251,195,4,49,48,182,150,191,0,0,0,0,0,0,240,63,28,220,12,200,43,8,208,191,148,99,7,64,229,164,219,191,237,37,103,67,204,136,161,191,44,170,144,166,250,243,167,191,141,223,67,100,188,230,208,63,99,214,230,70,69,88,195,63,24,234,52,104,233,120,198,191,105,39,247,117,236,23,200,191,250,169,244,249,193,11,172,63,59,51,38,243,41,22,168,63,157,193,105,65,113,69,238,63,157,193,105,65,113,69,254,191,157,193,105,65,113,69,238,63,0,0,0,0,0,0,240,63,117,252,16,192,122,57,254,191,137,13,133,133,207,162,236,63,72,22,35,0,8,10,0,0,0,0,0,0,100,66,52,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,38,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,28,33,0,248,252,31,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,38,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,196,32,0,108,0,0,0,192,245,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,160,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,209,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,152,170,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,201,32,0,108,0,0,0,192,94,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,200,34,0,108,0,0,0,168,250,14,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,13,15,17,19,20,26,31,5,0,0,0,0,0,0,0,24,20,4,1,0,0,0,0,24,20,4,1,0,0,0,0,60,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,50,0,0,0,1,0,0,0,30,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,25,0,0,0,1,0,0,0,24,0,0,0,1,0,0,0,192,93,0,0,233,3,0,0,0,0,0,0,0,0,0,0,216,171,34,0,216,109,140,0,160,1,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,0,0,0,0,0,0,0,0,64,112,34,0,216,109,140,0,168,1,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,0,0,0,0,0,0,0,0,32,56,34,0,216,109,140,0,196,1,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,0,0,0,0,0,0,0,0,136,7,34,0,216,109,140,0,124,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,248,216,33,0,216,109,140,0,68,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,128,180,33,0,216,109,140,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,16,147,33,0,216,109,140,0,80,0,0,0,1,0,0,0,255,255,255,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1036780);
/* memory initializer */ allocate([255,255,255,255,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,192,113,33,0,216,109,140,0,96,1,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,0,0,0,0,0,0,0,0,64,49,33,0,216,109,140,0,88,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,4,0,6,0,8,0,0,16,0,32,0,64,0,2,0,4,0,8,0,0,0,0,1,0,0,0,0,0,0,0,2,1,0,1,0,0,28,0,2,1,1,2,0,0,46,0,2,1,1,3,2,0,80,0,2,1,1,3,5,0,104,0,4,2,1,3,0,0,108,0,4,2,1,3,2,0,132,0,4,2,1,3,5,0,168,0,2,1,2,3,0,0,64,0,2,1,2,3,2,0,80,0,2,1,2,3,5,0,104,0,4,2,2,3,0,0,108,0,4,2,2,3,2,0,132,0,4,2,2,3,5,0,168,0,8,3,2,3,0,0,176,0,8,3,2,3,2,0,208,0,8,3,2,3,5,0,0,1,0,0,2,0,1,0,2,0,4,0,3,0,5,0,3,0,12,0,4,0,13,0,4,0,56,0,6,0,57,0,6,0,58,0,6,0,59,0,6,0,120,0,7,0,121,0,7,0,122,0,7,0,123,0,7,0,240,1,9,0,241,1,9,0,242,1,9,0,243,1,9,0,244,1,9,0,245,1,9,0,246,1,9,0,247,1,9,0,248,1,9,0,249,1,9,0,250,1,9,0,251,1,9,0,252,1,9,0,253,1,9,0,254,1,9,0,255,1,9,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,24,0,0,0,1,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,32,217,32,0,168,38,31,0,24,0,0,0,84,65,82,86,64,120,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,200,234,29,0,208,125,29,0,16,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,16,0,0,0,0,0,0,0,200,36,29,0,136,213,28,0,32,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,200,36,29,0,224,207,35,0,64,127,35,0,32,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,200,36,29,0,216,34,35,0,192,220,34,0,32,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,200,36,29,0,88,160,34,0,8,100,34,0,32,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,200,36,29,0,216,44,34,0,240,253,33,0,32,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,200,36,29,0,16,209,33,0,160,170,33,0,32,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,200,36,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,217,32,0,108,0,0,0,224,251,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,35,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,8,4,0,3,3,2,9,0,8,5,1,3,4,4,13,0,3,3,3,3,3,3,3,3,3,3,3,1,3,3,3,0,0,3,0,3,2,3,3,2,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,3,3,3,3,3,3,3,3,3,3,0,0,0,3,3,3,3,3,3,0,0,3,3,3,3,1,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,3,3,3,3,3,1,1,0,0,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,0,0,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,1,1,3,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,80,219,32,0,108,0,0,0,16,96,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,70,184,38,75,21,182,11,113,6,139,3,243,1,18,1,151,0,83,0,0,0,0,0,136,49,30,0,248,76,34,0,152,193,32,0,136,187,31,0,176,248,30,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,4,4,0,14,1,0,0,140,0,0,0,154,0,0,0,210,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,1,0,0,16,0,0,0,8,2,0,0,166,1,0,0,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,1,0,0,4,2,0,0,20,2,0,0,20,1,0,0,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,1,0,0,174,0,0,0,218,1,0,0,248,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,178,1,0,0,150,1,0,0,174,1,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,0,0,0,5,0,0,0,8,0,0,0,13,0,0,0,9,0,0,0,87,0,0,0,3,0,0,0,132,0,0,0,6,0,0,0,93,0,0,0,4,0,0,0,92,0,0,0,4,0,0,0,107,0,0,0,5,0,0,0,28,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,48,101,33,0,108,0,0,0,168,235,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,192,31,0,108,0,0,0,208,87,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,80,1,0,2,0,0,0,5,0,1,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,3,0,0,0,13,16,1,0,1,0,0,0,2,80,1,0,10,0,0,0,34,80,1,0,6,0,0,0,6,0,1,0,8,0,0,0,7,0,1,0,7,0,0,0,36,80,1,0,11,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,5,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,255,255,255,255,9,0,0,0,10,0,0,0,11,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,12,0,0,0,13,0,0,0,14,0,0,0,0,0,0,0,152,194,28,0,24,192,35,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,19,29,0,108,0,0,0,240,2,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,182,31,0,108,0,0,0,112,129,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,7,6,0,0,0,0,0,0,15,6,0,0,0,0,0,0,15,7,0,0,0,0,0,0,63,6,0,0,0,0,0,0,0,0,240,65,0,0,136,65,0,0,128,65,0,0,32,65,0,0,64,64,0,0,64,65,0,0,0,65,0,0,32,64,0,0,160,64,0,0,160,64,0,0,192,64,0,0,192,64,0,0,160,64,0,0,192,64,0,0,32,65,0,0,192,64,0,0,128,192,0,0,32,193,0,0,168,193,0,0,240,193,0,0,40,194,0,0,92,194,0,0,136,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,182,194,0,0,214,194,0,0,220,194,0,0,216,194,0,0,240,65,0,0,136,65,0,0,128,65,0,0,32,65,0,0,64,64,0,0,64,65,0,0,0,65,0,0,32,64,0,0,160,64,0,0,160,64,0,0,192,64,0,0,192,64,0,0,160,64,0,0,192,64,0,0,32,65,0,0,192,64,0,0,128,192,0,0,32,193,0,0,168,193,0,0,240,193,0,0,40,194,0,0,92,194,0,0,136,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,182,194,0,0,214,194,0,0,220,194,0,0,216,194,0,0,1,255,2,254,3,253,4,252,5,251,6,250,7,249,8,248,9,247,10,246,11,245,12,244,13,243,14,242,15,241,16,240,17,239,18,238,19,237,20,236,21,235,22,234,23,233,24,232,25,231,26,230,27,229,28,228,29,227,30,226,31,225,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,3,0,0,0,253,255,255,255,1,0,0,0,1,0,2,0,3,0,4,0,6,0,9,0,13,0,18,0,26,0,38,0,55,0,80,0,115,0,166,0,240,0,92,1,246,1,214,2,26,4,237,5,145,8,98,12,230,17,223,25,72,206,249,46,43,88,154,46,40,41,138,178,53,83,90,179,46,182,37,180,15,181,212,180,144,23,69,181,176,35,213,180,177,137,254,180,243,169,33,181,151,236,49,181,29,114,59,181,136,117,60,181,61,172,53,181,130,26,40,181,123,92,21,181,118,255,59,53,164,5,98,53,137,196,130,53,38,168,145,53,242,21,156,53,63,87,160,53,99,68,158,53,69,180,138,53,216,183,125,53,208,143,4,54,80,199,159,53,18,131,12,53,8,83,88,52,23,64,168,51,255,59,56,176,112,186,221,176,186,90,56,177,132,156,105,177,48,208,97,50,211,246,0,50,204,140,239,50,161,37,27,52,49,43,168,52,179,224,187,53,134,95,8,54,149,51,54,54,135,200,103,54,26,195,140,54,145,76,164,54,91,25,185,54,131,214,201,54,45,116,213,54,190,85,6,55,140,176,7,55,226,59,5,55,202,247,253,54,184,108,234,54,151,224,208,54,141,95,178,54,92,160,148,54,162,165,95,54,114,55,98,53,27,21,233,52,47,31,203,51,145,144,255,50,5,127,137,51,14,109,11,179,41,162,35,179,237,30,181,51,192,63,138,51,160,160,159,53,208,149,39,54,47,190,114,54,4,225,83,54,158,170,27,54,136,6,4,55,72,220,36,55,110,124,69,55,219,110,103,55,44,210,131,55,146,58,146,55,16,15,158,55,129,176,166,55,115,96,171,55,121,227,3,184,185,224,11,184,47,36,17,184,216,119,19,184,105,155,18,184,45,132,14,184,247,72,7,184,103,229,249,183,103,150,224,183,51,147,151,183,39,8,149,183,73,103,139,183,102,128,74,183,31,168,234,182,152,59,23,181,250,3,134,181,179,94,197,181,234,200,248,181,85,56,65,53,208,39,79,54,147,43,204,54,130,104,32,55,129,184,91,55,45,221,189,55,43,216,238,55,253,66,15,56,2,134,37,56,252,160,57,56,83,249,74,56,246,33,89,56,230,188,99,56,112,177,106,56,114,247,164,54,22,5,28,55,17,136,99,55,10,245,146,55,243,166,175,55,92,47,198,55,133,211,212,55,13,160,219,55,172,72,214,55,43,59,253,55,57,168,215,55,92,135,166,55,199,223,71,55,211,125,41,54,210,56,127,183,242,180,135,183,138,39,167,55,114,223,148,55,115,247,65,56,100,82,107,56,176,189,137,56,9,147,157,56,168,114,176,56,183,168,183,56,227,150,199,56,197,13,214,56,89,108,227,56,142,50,239,56,115,31,249,56,199,114,0,57,107,25,3,57,73,85,4,57,150,155,0,57,90,129,254,56,99,171,247,56,112,50,236,56,128,157,219,56,172,125,197,56,133,106,169,56,161,53,135,56,114,99,60,56,248,65,207,55,234,20,230,181,225,239,5,184,182,48,137,184,251,200,214,184,51,152,9,185,129,7,58,185,50,57,106,185,90,158,140,185,44,131,175,185,233,207,204,185,136,107,235,185,13,177,5,186,211,50,22,186,89,177,38,186,45,19,56,186,185,206,73,186,40,209,91,186,219,255,109,186,232,31,128,186,169,57,137,186,67,61,146,186,86,27,155,186,254,53,164,186,5,132,172,186,22,110,180,186,12,223,187,186,193,193,194,186,102,0,201,186,178,132,206,186,141,55,211,186,92,2,215,186,149,191,217,186,85,123,219,186,74,254,219,186,205,65,219,186,244,30,217,186,189,43,214,186,74,219,208,186,164,31,202,58,38,230,193,58,239,233,182,58,88,205,170,58,253,200,156,58,81,189,140,58,238,86,117,58,207,236,76,58,135,71,32,58,238,135,222,57,226,82,103,57,83,255,145,180,153,223,121,185,240,94,1,186,169,197,72,186,48,84,138,186,243,117,178,186,48,202,220,186,249,162,4,187,239,237,27,187,170,62,52,187,158,140,77,187,10,206,103,187,235,123,129,187,4,127,143,187,58,233,157,187,109,180,172,187,204,214,187,187,119,74,203,187,162,4,219,187,94,242,234,187,212,34,251,187,25,189,5,188,167,247,13,188,1,64,22,188,35,138,30,188,61,211,38,188,156,21,47,188,8,76,55,188,206,112,63,188,65,124,71,188,85,105,79,188,5,50,87,188,100,208,94,188,148,62,102,188,201,118,109,188,86,115,116,188,177,46,123,188,87,209,128,188,223,229,131,188,2,210,134,188,100,147,137,188,193,39,140,188,248,140,142,188,11,193,144,188,38,194,146,188,149,142,148,188,12,37,150,188,202,131,151,188,215,169,152,188,46,150,153,188,57,72,154,188,194,191,154,188,51,251,154,188,51,251,154,60,194,191,154,60,57,72,154,60,46,150,153,60,215,169,152,60,202,131,151,60,12,37,150,60,149,142,148,60,38,194,146,60,11,193,144,60,248,140,142,60,193,39,140,60,100,147,137,60,2,210,134,60,223,229,131,60,87,209,128,60,177,46,123,60,86,115,116,60,201,118,109,60,148,62,102,60,100,208,94,60,5,50,87,60,85,105,79,60,65,124,71,60,206,112,63,60,8,76,55,60,156,21,47,60,61,211,38,60,35,138,30,60,1,64,22,60,167,247,13,60,25,189,5,60,212,34,251,59,94,242,234,59,162,4,219,59,119,74,203,59,204,214,187,59,109,180,172,59,58,233,157,59,4,127,143,59,235,123,129,59,10,206,103,59,158,140,77,59,170,62,52,59,239,237,27,59,249,162,4,59,48,202,220,58,243,117,178,58,48,84,138,58,169,197,72,58,240,94,1,58,153,223,121,57,83,255,145,52,226,82,103,185,238,135,222,185,135,71,32,186,207,236,76,186,238,86,117,186,81,189,140,186,253,200,156,186,88,205,170,186,239,233,182,186,38,230,193,186,164,31,202,186,74,219,208,58,189,43,214,58,244,30,217,58,205,65,219,58,74,254,219,58,85,123,219,58,149,191,217,58,92,2,215,58,141,55,211,58,178,132,206,58,102,0,201,58,193,193,194,58,12,223,187,58,22,110,180,58,5,132,172,58,254,53,164,58,86,27,155,58,67,61,146,58,169,57,137,58,232,31,128,58,219,255,109,58,40,209,91,58,185,206,73,58,45,19,56,58,89,177,38,58,211,50,22,58,13,177,5,58,136,107,235,57,233,207,204,57,44,131,175,57,90,158,140,57,50,57,106,57,129,7,58,57,51,152,9,57,251,200,214,56,182,48,137,56,225,239,5,56,234,20,230,53,248,65,207,183,114,99,60,184,161,53,135,184,133,106,169,184,172,125,197,184,128,157,219,184,112,50,236,184,99,171,247,184,90,129,254,184,150,155,0,185,73,85,4,185,107,25,3,185,199,114,0,185,115,31,249,184,142,50,239,184,89,108,227,184,197,13,214,184,227,150,199,184,183,168,183,184,168,114,176,184,9,147,157,184,176,189,137,184,100,82,107,184,115,247,65,184,114,223,148,183,138,39,167,183,242,180,135,55,210,56,127,55,211,125,41,182,199,223,71,183,92,135,166,183,57,168,215,183,43,59,253,183,172,72,214,183,13,160,219,183,133,211,212,183,92,47,198,183,243,166,175,183,10,245,146,183,17,136,99,183,22,5,28,183,114,247,164,182,112,177,106,184,230,188,99,184,246,33,89,184,83,249,74,184,252,160,57,184,2,134,37,184,253,66,15,184,43,216,238,183,45,221,189,183,129,184,91,183,130,104,32,183,147,43,204,182,208,39,79,182,85,56,65,181,234,200,248,53,179,94,197,53,250,3,134,53,152,59,23,53,31,168,234,54,102,128,74,55,73,103,139,55,39,8,149,55,51,147,151,55,103,150,224,55,103,229,249,55,247,72,7,56,45,132,14,56,105,155,18,56,216,119,19,56,47,36,17,56,185,224,11,56,121,227,3,56,115,96,171,183,129,176,166,183,16,15,158,183,146,58,146,183,44,210,131,183,219,110,103,183,110,124,69,183,72,220,36,183,136,6,4,183,158,170,27,182,4,225,83,182,47,190,114,182,208,149,39,182,160,160,159,181,192,63,138,179,237,30,181,179,41,162,35,51,14,109,11,51,5,127,137,179,145,144,255,178,47,31,203,179,27,21,233,180,114,55,98,181,162,165,95,182,92,160,148,182,141,95,178,182,151,224,208,182,184,108,234,182,202,247,253,182,226,59,5,183,140,176,7,183,190,85,6,183,45,116,213,182,131,214,201,182,91,25,185,182,145,76,164,182,26,195,140,182,135,200,103,182,149,51,54,182,134,95,8,182,179,224,187,181,49,43,168,180,161,37,27,180,204,140,239,178,211,246,0,178,48,208,97,178,132,156,105,49,186,90,56,49,112,186,221,48,255,59,56,48,23,64,168,179,8,83,88,180,18,131,12,181,80,199,159,181,208,143,4,182,216,183,125,181,69,180,138,181,99,68,158,181,63,87,160,181,242,21,156,181,38,168,145,181,137,196,130,181,164,5,98,181,118,255,59,181,123,92,21,53,130,26,40,53,61,172,53,53,136,117,60,53,29,114,59,53,151,236,49,53,243,169,33,53,177,137,254,52,176,35,213,52,144,23,69,53,15,181,212,52,46,182,37,52,53,83,90,51,40,41,138,50,43,88,154,174,72,206,249,174,72,206,249,46,43,88,154,46,40,41,138,178,53,83,90,179,46,182,37,180,15,181,212,180,144,23,69,181,176,35,213,180,177,137,254,180,243,169,33,181,151,236,49,181,29,114,59,181,136,117,60,181,61,172,53,181,130,26,40,181,123,92,21,181,118,255,59,53,164,5,98,53,137,196,130,53,38,168,145,53,242,21,156,53,63,87,160,53,99,68,158,53,69,180,138,53,216,183,125,53,208,143,4,54,80,199,159,53,18,131,12,53,8,83,88,52,23,64,168,51,255,59,56,176,112,186,221,176,186,90,56,177,132,156,105,177,48,208,97,50,211,246,0,50,204,140,239,50,161,37,27,52,49,43,168,52,179,224,187,53,134,95,8,54,149,51,54,54,135,200,103,54,26,195,140,54,145,76,164,54,91,25,185,54,131,214,201,54,45,116,213,54,190,85,6,55,140,176,7,55,226,59,5,55,202,247,253,54,184,108,234,54,151,224,208,54,141,95,178,54,92,160,148,54,162,165,95,54,114,55,98,53,27,21,233,52,47,31,203,51,145,144,255,50,5,127,137,51,14,109,11,179,41,162,35,179,237,30,181,51,192,63,138,51,160,160,159,53,208,149,39,54,47,190,114,54,4,225,83,54,158,170,27,54,136,6,4,55,72,220,36,55,110,124,69,55,219,110,103,55,44,210,131,55,146,58,146,55,16,15,158,55,129,176,166,55,115,96,171,55,121,227,3,184,185,224,11,184,47,36,17,184,216,119,19,184,105,155,18,184,45,132,14,184,247,72,7,184,103,229,249,183,103,150,224,183,51,147,151,183,39,8,149,183,73,103,139,183,102,128,74,183,31,168,234,182,152,59,23,181,250,3,134,181,179,94,197,181,234,200,248,181,85,56,65,53,208,39,79,54,147,43,204,54,130,104,32,55,129,184,91,55,45,221,189,55,43,216,238,55,253,66,15,56,2,134,37,56,252,160,57,56,83,249,74,56,246,33,89,56,230,188,99,56,112,177,106,56,114,247,164,54,22,5,28,55,17,136,99,55,10,245,146,55,243,166,175,55,92,47,198,55,133,211,212,55,13,160,219,55,172,72,214,55,43,59,253,55,57,168,215,55,92,135,166,55,199,223,71,55,211,125,41,54,210,56,127,183,242,180,135,183,138,39,167,55,114,223,148,55,115,247,65,56,100,82,107,56,176,189,137,56,9,147,157,56,168,114,176,56,183,168,183,56,227,150,199,56,197,13,214,56,89,108,227,56,142,50,239,56,115,31,249,56,199,114,0,57,107,25,3,57,73,85,4,57,150,155,0,57,90,129,254,56,99,171,247,56,112,50,236,56,128,157,219,56,172,125,197,56,133,106,169,56,161,53,135,56,114,99,60,56,248,65,207,55,234,20,230,181,225,239,5,184,182,48,137,184,251,200,214,184,51,152,9,185,129,7,58,185,50,57,106,185,90,158,140,185,44,131,175,185,233,207,204,185,136,107,235,185,13,177,5,186,211,50,22,186,89,177,38,186,45,19,56,186,185,206,73,186,40,209,91,186,219,255,109,186,232,31,128,186,169,57,137,186,67,61,146,186,86,27,155,186,254,53,164,186,5,132,172,186,22,110,180,186,12,223,187,186,193,193,194,186,102,0,201,186,178,132,206,186,141,55,211,186,92,2,215,186,149,191,217,186,85,123,219,186,74,254,219,186,205,65,219,186,244,30,217,186,189,43,214,186,74,219,208,186,164,31,202,58,38,230,193,58,239,233,182,58,88,205,170,58,253,200,156,58,81,189,140,58,238,86,117,58,207,236,76,58,135,71,32,58,238,135,222,57,226,82,103,57,83,255,145,180,153,223,121,185,240,94,1,186,169,197,72,186,48,84,138,186,243,117,178,186,48,202,220,186,249,162,4,187,239,237,27,187,170,62,52,187,158,140,77,187,10,206,103,187,235,123,129,187,4,127,143,187,58,233,157,187,109,180,172,187,204,214,187,187,119,74,203,187,162,4,219,187,94,242,234,187,212,34,251,187,25,189,5,188,167,247,13,188,1,64,22,188,35,138,30,188,61,211,38,188,156,21,47,188,8,76,55,188,206,112,63,188,65,124,71,188,85,105,79,188,5,50,87,188,100,208,94,188,148,62,102,188,201,118,109,188,86,115,116,188,177,46,123,188,87,209,128,188,223,229,131,188,2,210,134,188,100,147,137,188,193,39,140,188,248,140,142,188,11,193,144,188,38,194,146,188,149,142,148,188,12,37,150,188,202,131,151,188,215,169,152,188,46,150,153,188,57,72,154,188,194,191,154,188,51,251,154,188,51,251,154,60,194,191,154,60,57,72,154,60,46,150,153,60,215,169,152,60,202,131,151,60,12,37,150,60,149,142,148,60,38,194,146,60,11,193,144,60,248,140,142,60,193,39,140,60,100,147,137,60,2,210,134,60,223,229,131,60,87,209,128,60,177,46,123,60,86,115,116,60,201,118,109,60,148,62,102,60,100,208,94,60,5,50,87,60,85,105,79,60,65,124,71,60,206,112,63,60,8,76,55,60,156,21,47,60,61,211,38,60,35,138,30,60,1,64,22,60,167,247,13,60,25,189,5,60,212,34,251,59,94,242,234,59,162,4,219,59,119,74,203,59,204,214,187,59,109,180,172,59,58,233,157,59,4,127,143,59,235,123,129,59,10,206,103,59,158,140,77,59,170,62,52,59,239,237,27,59,249,162,4,59,48,202,220,58,243,117,178,58,48,84,138,58,169,197,72,58,240,94,1,58,153,223,121,57,83,255,145,52,226,82,103,185,238,135,222,185,135,71,32,186,207,236,76,186,238,86,117,186,81,189,140,186,253,200,156,186,88,205,170,186,239,233,182,186,38,230,193,186,164,31,202,186,74,219,208,58,189,43,214,58,244,30,217,58,205,65,219,58,74,254,219,58,85,123,219,58,149,191,217,58,92,2,215,58,141,55,211,58,178,132,206,58,102,0,201,58,193,193,194,58,12,223,187,58,22,110,180,58,5,132,172,58,254,53,164,58,86,27,155,58,67,61,146,58,169,57,137,58,232,31,128,58,219,255,109,58,40,209,91,58,185,206,73,58,45,19,56,58,89,177,38,58,211,50,22,58,13,177,5,58,136,107,235,57,233,207,204,57,44,131,175,57,90,158,140,57,50,57,106,57,129,7,58,57,51,152,9,57,251,200,214,56,182,48,137,56,225,239,5,56,234,20,230,53,248,65,207,183,114,99,60,184,161,53,135,184,133,106,169,184,172,125,197,184,128,157,219,184,112,50,236,184,99,171,247,184,90,129,254,184,150,155,0,185,73,85,4,185,107,25,3,185,199,114,0,185,115,31,249,184,142,50,239,184,89,108,227,184,197,13,214,184,227,150,199,184,183,168,183,184,168,114,176,184,9,147,157,184,176,189,137,184,100,82,107,184,115,247,65,184,114,223,148,183,138,39,167,183,242,180,135,55,210,56,127,55,211,125,41,182,199,223,71,183,92,135,166,183,57,168,215,183,43,59,253,183,172,72,214,183,13,160,219,183,133,211,212,183,92,47,198,183,243,166,175,183,10,245,146,183,17,136,99,183,22,5,28,183,114,247,164,182,112,177,106,184,230,188,99,184,246,33,89,184,83,249,74,184,252,160,57,184,2,134,37,184,253,66,15,184,43,216,238,183,45,221,189,183,129,184,91,183,130,104,32,183,147,43,204,182,208,39,79,182,85,56,65,181,234,200,248,53,179,94,197,53,250,3,134,53,152,59,23,53,31,168,234,54,102,128,74,55,73,103,139,55,39,8,149,55,51,147,151,55,103,150,224,55,103,229,249,55,247,72,7,56,45,132,14,56,105,155,18,56,216,119,19,56,47,36,17,56,185,224,11,56,121,227,3,56,115,96,171,183,129,176,166,183,16,15,158,183,146,58,146,183,44,210,131,183,219,110,103,183,110,124,69,183,72,220,36,183,136,6,4,183,158,170,27,182,4,225,83,182,47,190,114,182,208,149,39,182,160,160,159,181,192,63,138,179,237,30,181,179,41,162,35,51,14,109,11,51,5,127,137,179,145,144,255,178,47,31,203,179,27,21,233,180,114,55,98,181,162,165,95,182,92,160,148,182,141,95,178,182,151,224,208,182,184,108,234,182,202,247,253,182,226,59,5,183,140,176,7,183,190,85,6,183,45,116,213,182,131,214,201,182,91,25,185,182,145,76,164,182,26,195,140,182,135,200,103,182,149,51,54,182,134,95,8,182,179,224,187,181,49,43,168,180,161,37,27,180,204,140,239,178,211,246,0,178,48,208,97,178,132,156,105,49,186,90,56,49,112,186,221,48,255,59,56,48,23,64,168,179,8,83,88,180,18,131,12,181,80,199,159,181,208,143,4,182,216,183,125,181,69,180,138,181,99,68,158,181,63,87,160,181,242,21,156,181,38,168,145,181,137,196,130,181,164,5,98,181,118,255,59,181,123,92,21,53,130,26,40,53,61,172,53,53,136,117,60,53,29,114,59,53,151,236,49,53,243,169,33,53,177,137,254,52,176,35,213,52,144,23,69,53,15,181,212,52,46,182,37,52,53,83,90,51,40,41,138,50,43,88,154,174,72,206,249,174,77,69,21,180,34,221,53,180,215,10,90,180,154,19,129,180,69,76,151,180,121,234,175,180,61,49,203,180,120,108,233,180,57,121,5,181,106,18,24,181,89,184,44,181,214,167,67,181,60,36,93,181,224,119,121,181,45,122,140,181,102,249,157,181,25,106,177,181,137,0,199,181,4,245,222,181,236,131,249,181,184,118,11,182,195,186,27,182,237,177,45,182,166,129,65,182,232,80,87,182,11,72,111,182,69,200,132,182,106,42,147,182,250,223,162,182,148,254,179,182,198,155,198,182,222,204,218,182,181,166,240,182,179,30,4,183,1,210,16,183,47,118,30,183,91,19,45,183,173,176,60,183,47,84,77,183,152,2,95,183,31,191,113,183,165,197,130,183,93,51,141,183,127,39,152,183,168,159,163,183,54,152,175,183,45,12,188,183,24,245,200,183,244,74,214,183,20,4,228,183,9,21,242,183,70,56,0,184,179,131,7,184,44,228,14,184,12,80,22,184,149,188,29,184,246,29,37,184,56,103,44,184,70,138,51,184,228,119,58,184,178,31,65,184,45,112,71,184,178,86,77,184,135,191,82,184,224,149,87,56,232,195,91,56,217,50,95,56,0,203,97,56,218,115,99,56,37,20,100,56,252,145,99,56,242,210,97,56,47,188,94,56,150,50,90,56,231,26,84,56,233,89,76,56,147,212,66,56,57,112,55,56,192,18,42,56,207,162,26,56,1,8,9,56,74,86,234,55,223,236,189,55,115,171,140,55,243,218,44,55,181,148,88,54,115,2,150,182,49,197,86,183,227,163,182,183,102,167,3,184,115,179,46,184,67,116,92,184,17,114,134,184,161,252,159,184,193,210,186,184,26,235,214,184,244,57,244,184,144,88,9,185,239,31,25,185,102,105,41,185,232,41,58,185,8,85,75,185,238,220,92,185,87,178,110,185,72,98,128,185,186,128,137,185,186,170,146,185,198,213,155,185,172,246,164,185,136,1,174,185,204,233,182,185,69,162,191,185,33,29,200,185,250,75,208,185,221,31,216,185,87,137,223,185,128,120,230,185,7,221,236,185,70,166,242,185,79,195,247,185,246,34,252,185,243,179,255,185,116,50,1,186,61,18,2,186,0,113,2,186,161,69,2,186,6,136,1,186,248,47,0,186,6,107,252,57,237,33,247,57,248,117,240,57,73,89,232,57,227,190,222,57,200,154,211,57,28,226,198,57,57,139,184,57,207,141,168,57,252,226,150,57,110,133,131,57,240,226,92,57,89,74,47,57,229,129,252,56,247,148,147,56,57,118,143,55,113,24,37,184,111,135,207,184,11,117,41,185,93,64,110,185,157,3,155,185,27,83,192,185,122,250,230,185,129,113,7,186,181,249,27,186,241,7,49,186,253,140,70,186,96,120,92,186,85,184,114,186,235,156,132,186,81,244,143,186,158,87,155,186,128,187,166,186,15,20,178,186,217,84,189,186,227,112,200,186,181,90,211,186,93,4,222,186,125,95,232,186,81,93,242,186,185,238,251,186,36,130,2,187,35,199,6,187,101,190,10,187,222,95,14,187,114,163,17,187,254,128,20,187,94,240,22,187,117,233,24,187,50,100,26,187,157,88,27,187,216,190,27,187,49,143,27,187,29,194,26,187,76,80,25,187,171,50,23,187,111,98,20,187,26,217,16,187,135,144,12,187,239,130,7,187,241,170,1,187,56,7,246,186,235,16,231,186,253,106,214,186,121,14,196,58,126,245,175,58,80,27,154,58,91,124,130,58,144,44,82,58,253,207,27,58,197,198,195,57,51,167,17,57,58,184,228,184,58,45,194,185,177,9,41,186,51,98,116,186,157,135,161,186,139,126,202,186,154,10,245,186,143,143,16,187,2,87,39,187,237,211,62,187,231,253,86,187,226,203,111,187,18,154,132,187,43,150,145,187,196,212,158,187,23,80,172,187,23,2,186,187,120,228,199,187,169,240,213,187,224,31,228,187,28,107,242,187,149,101,0,188,83,156,7,188,6,214,14,188,215,14,22,188,226,66,29,188,56,110,36,188,223,140,43,188,218,154,50,188,42,148,57,188,205,116,64,188,200,56,71,188,37,220,77,188,248,90,84,188,101,177,90,188,157,219,96,188,230,213,102,188,154,156,108,188,50,44,114,188,62,129,119,188,112,152,124,188,78,183,128,188,92,0,131,188,243,37,133,188,184,38,135,188,99,1,137,188,201,180,138,188,210,63,140,188,130,161,141,188,245,216,142,188,99,229,143,188,35,198,144,188,155,122,145,188,92,2,146,188,14,93,146,188,118,138,146,188,118,138,146,60,14,93,146,60,92,2,146,60,155,122,145,60,35,198,144,60,99,229,143,60,245,216,142,60,130,161,141,60,210,63,140,60,201,180,138,60,99,1,137,60,184,38,135,60,243,37,133,60,92,0,131,60,78,183,128,60,112,152,124,60,62,129,119,60,50,44,114,60,154,156,108,60,230,213,102,60,157,219,96,60,101,177,90,60,248,90,84,60,37,220,77,60,200,56,71,60,205,116,64,60,42,148,57,60,218,154,50,60,223,140,43,60,56,110,36,60,226,66,29,60,215,14,22,60,6,214,14,60,83,156,7,60,149,101,0,60,28,107,242,59,224,31,228,59,169,240,213,59,120,228,199,59,23,2,186,59,23,80,172,59,196,212,158,59,43,150,145,59,18,154,132,59,226,203,111,59,231,253,86,59,237,211,62,59,2,87,39,59,143,143,16,59,154,10,245,58,139,126,202,58,157,135,161,58,51,98,116,58,177,9,41,58,58,45,194,57,58,184,228,56,51,167,17,185,197,198,195,185,253,207,27,186,144,44,82,186,91,124,130,186,80,27,154,186,126,245,175,186,121,14,196,186,253,106,214,58,235,16,231,58,56,7,246,58,241,170,1,59,239,130,7,59,135,144,12,59,26,217,16,59,111,98,20,59,171,50,23,59,76,80,25,59,29,194,26,59,49,143,27,59,216,190,27,59,157,88,27,59,50,100,26,59,117,233,24,59,94,240,22,59,254,128,20,59,114,163,17,59,222,95,14,59,101,190,10,59,35,199,6,59,36,130,2,59,185,238,251,58,81,93,242,58,125,95,232,58,93,4,222,58,181,90,211,58,227,112,200,58,217,84,189,58,15,20,178,58,128,187,166,58,158,87,155,58,81,244,143,58,235,156,132,58,85,184,114,58,96,120,92,58,253,140,70,58,241,7,49,58,181,249,27,58,129,113,7,58,122,250,230,57,27,83,192,57,157,3,155,57,93,64,110,57,11,117,41,57,111,135,207,56,113,24,37,56,57,118,143,183,247,148,147,184,229,129,252,184,89,74,47,185,240,226,92,185,110,133,131,185,252,226,150,185,207,141,168,185,57,139,184,185,28,226,198,185,200,154,211,185,227,190,222,185,73,89,232,185,248,117,240,185,237,33,247,185,6,107,252,185,248,47,0,58,6,136,1,58,161,69,2,58,0,113,2,58,61,18,2,58,116,50,1,58,243,179,255,57,246,34,252,57,79,195,247,57,70,166,242,57,7,221,236,57,128,120,230,57,87,137,223,57,221,31,216,57,250,75,208,57,33,29,200,57,69,162,191,57,204,233,182,57,136,1,174,57,172,246,164,57,198,213,155,57,186,170,146,57,186,128,137,57,72,98,128,57,87,178,110,57,238,220,92,57,8,85,75,57,232,41,58,57,102,105,41,57,239,31,25,57,144,88,9,57,244,57,244,56,26,235,214,56,193,210,186,56,161,252,159,56,17,114,134,56,67,116,92,56,115,179,46,56,102,167,3,56,227,163,182,55,49,197,86,55,115,2,150,54,181,148,88,182,243,218,44,183,115,171,140,183,223,236,189,183,74,86,234,183,1,8,9,184,207,162,26,184,192,18,42,184,57,112,55,184,147,212,66,184,233,89,76,184,231,26,84,184,150,50,90,184,47,188,94,184,242,210,97,184,252,145,99,184,37,20,100,184,218,115,99,184,0,203,97,184,217,50,95,184,232,195,91,184,224,149,87,184,135,191,82,56,178,86,77,56,45,112,71,56,178,31,65,56,228,119,58,56,70,138,51,56,56,103,44,56,246,29,37,56,149,188,29,56,12,80,22,56,44,228,14,56,179,131,7,56,70,56,0,56,9,21,242,55,20,4,228,55,244,74,214,55,24,245,200,55,45,12,188,55,54,152,175,55,168,159,163,55,127,39,152,55,93,51,141,55,165,197,130,55,31,191,113,55,152,2,95,55,47,84,77,55,173,176,60,55,91,19,45,55,47,118,30,55,1,210,16,55,179,30,4,55,181,166,240,54,222,204,218,54,198,155,198,54,148,254,179,54,250,223,162,54,106,42,147,54,69,200,132,54,11,72,111,54,232,80,87,54,166,129,65,54,237,177,45,54,195,186,27,54,184,118,11,54,236,131,249,53,4,245,222,53,137,0,199,53,25,106,177,53,102,249,157,53,45,122,140,53,224,119,121,53,60,36,93,53,214,167,67,53,89,184,44,53,106,18,24,53,57,121,5,53,120,108,233,52,61,49,203,52,121,234,175,52,69,76,151,52,154,19,129,52,215,10,90,52,34,221,53,52,77,69,21,52,77,69,21,180,34,221,53,180,215,10,90,180,154,19,129,180,69,76,151,180,121,234,175,180,61,49,203,180,120,108,233,180,57,121,5,181,106,18,24,181,89,184,44,181,214,167,67,181,60,36,93,181,224,119,121,181,45,122,140,181,102,249,157,181,25,106,177,181,137,0,199,181,4,245,222,181,236,131,249,181,184,118,11,182,195,186,27,182,237,177,45,182,166,129,65,182,232,80,87,182,11,72,111,182,69,200,132,182,106,42,147,182,250,223,162,182,148,254,179,182,198,155,198,182,222,204,218,182,181,166,240,182,179,30,4,183,1,210,16,183,47,118,30,183,91,19,45,183,173,176,60,183,47,84,77,183,152,2,95,183,31,191,113,183,165,197,130,183,93,51,141,183,127,39,152,183,168,159,163,183,54,152,175,183,45,12,188,183,24,245,200,183,244,74,214,183,20,4,228,183,9,21,242,183,70,56,0,184,179,131,7,184,44,228,14,184,12,80,22,184,149,188,29,184,246,29,37,184,56,103,44,184,70,138,51,184,228,119,58,184,178,31,65,184,45,112,71,184,178,86,77,184,135,191,82,184,224,149,87,56,232,195,91,56,217,50,95,56,0,203,97,56,218,115,99,56,37,20,100,56,252,145,99,56,242,210,97,56,47,188,94,56,150,50,90,56,231,26,84,56,233,89,76,56,147,212,66,56,57,112,55,56,192,18,42,56,207,162,26,56,1,8,9,56,74,86,234,55,223,236,189,55,115,171,140,55,243,218,44,55,181,148,88,54,115,2,150,182,49,197,86,183,227,163,182,183,102,167,3,184,115,179,46,184,67,116,92,184,17,114,134,184,161,252,159,184,193,210,186,184,26,235,214,184,244,57,244,184,144,88,9,185,239,31,25,185,102,105,41,185,232,41,58,185,8,85,75,185,238,220,92,185,87,178,110,185,72,98,128,185,186,128,137,185,186,170,146,185,198,213,155,185,172,246,164,185,136,1,174,185,204,233,182,185,69,162,191,185,33,29,200,185,250,75,208,185,221,31,216,185,87,137,223,185,128,120,230,185,7,221,236,185,70,166,242,185,79,195,247,185,246,34,252,185,243,179,255,185,116,50,1,186,61,18,2,186,0,113,2,186,161,69,2,186,6,136,1,186,248,47,0,186,6,107,252,57,237,33,247,57,248,117,240,57,73,89,232,57,227,190,222,57,200,154,211,57,28,226,198,57,57,139,184,57,207,141,168,57,252,226,150,57,110,133,131,57,240,226,92,57,89,74,47,57,229,129,252,56,247,148,147,56,57,118,143,55,113,24,37,184,111,135,207,184,11,117,41,185,93,64,110,185,157,3,155,185,27,83,192,185,122,250,230,185,129,113,7,186,181,249,27,186,241,7,49,186,253,140,70,186,96,120,92,186,85,184,114,186,235,156,132,186,81,244,143,186,158,87,155,186,128,187,166,186,15,20,178,186,217,84,189,186,227,112,200,186,181,90,211,186,93,4,222,186,125,95,232,186,81,93,242,186,185,238,251,186,36,130,2,187,35,199,6,187,101,190,10,187,222,95,14,187,114,163,17,187,254,128,20,187,94,240,22,187,117,233,24,187,50,100,26,187,157,88,27,187,216,190,27,187,49,143,27,187,29,194,26,187,76,80,25,187,171,50,23,187,111,98,20,187,26,217,16,187,135,144,12,187,239,130,7,187,241,170,1,187,56,7,246,186,235,16,231,186,253,106,214,186,121,14,196,58,126,245,175,58,80,27,154,58,91,124,130,58,144,44,82,58,253,207,27,58,197,198,195,57,51,167,17,57,58,184,228,184,58,45,194,185,177,9,41,186,51,98,116,186,157,135,161,186,139,126,202,186,154,10,245,186,143,143,16,187,2,87,39,187,237,211,62,187,231,253,86,187,226,203,111,187,18,154,132,187,43,150,145,187,196,212,158,187,23,80,172,187,23,2,186,187,120,228,199,187,169,240,213,187,224,31,228,187,28,107,242,187,149,101,0,188,83,156,7,188,6,214,14,188,215,14,22,188,226,66,29,188,56,110,36,188,223,140,43,188,218,154,50,188,42,148,57,188,205,116,64,188,200,56,71,188,37,220,77,188,248,90,84,188,101,177,90,188,157,219,96,188,230,213,102,188,154,156,108,188,50,44,114,188,62,129,119,188,112,152,124,188,78,183,128,188,92,0,131,188,243,37,133,188,184,38,135,188,99,1,137,188,201,180,138,188,210,63,140,188,130,161,141,188,245,216,142,188,99,229,143,188,35,198,144,188,155,122,145,188,92,2,146,188,14,93,146,188,118,138,146,188,118,138,146,60,14,93,146,60,92,2,146,60,155,122,145,60,35,198,144,60,99,229,143,60,245,216,142,60,130,161,141,60,210,63,140,60,201,180,138,60,99,1,137,60,184,38,135,60,243,37,133,60,92,0,131,60,78,183,128,60,112,152,124,60,62,129,119,60,50,44,114,60,154,156,108,60,230,213,102,60,157,219,96,60,101,177,90,60,248,90,84,60,37,220,77,60,200,56,71,60], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1047020);
/* memory initializer */ allocate([205,116,64,60,42,148,57,60,218,154,50,60,223,140,43,60,56,110,36,60,226,66,29,60,215,14,22,60,6,214,14,60,83,156,7,60,149,101,0,60,28,107,242,59,224,31,228,59,169,240,213,59,120,228,199,59,23,2,186,59,23,80,172,59,196,212,158,59,43,150,145,59,18,154,132,59,226,203,111,59,231,253,86,59,237,211,62,59,2,87,39,59,143,143,16,59,154,10,245,58,139,126,202,58,157,135,161,58,51,98,116,58,177,9,41,58,58,45,194,57,58,184,228,56,51,167,17,185,197,198,195,185,253,207,27,186,144,44,82,186,91,124,130,186,80,27,154,186,126,245,175,186,121,14,196,186,253,106,214,58,235,16,231,58,56,7,246,58,241,170,1,59,239,130,7,59,135,144,12,59,26,217,16,59,111,98,20,59,171,50,23,59,76,80,25,59,29,194,26,59,49,143,27,59,216,190,27,59,157,88,27,59,50,100,26,59,117,233,24,59,94,240,22,59,254,128,20,59,114,163,17,59,222,95,14,59,101,190,10,59,35,199,6,59,36,130,2,59,185,238,251,58,81,93,242,58,125,95,232,58,93,4,222,58,181,90,211,58,227,112,200,58,217,84,189,58,15,20,178,58,128,187,166,58,158,87,155,58,81,244,143,58,235,156,132,58,85,184,114,58,96,120,92,58,253,140,70,58,241,7,49,58,181,249,27,58,129,113,7,58,122,250,230,57,27,83,192,57,157,3,155,57,93,64,110,57,11,117,41,57,111,135,207,56,113,24,37,56,57,118,143,183,247,148,147,184,229,129,252,184,89,74,47,185,240,226,92,185,110,133,131,185,252,226,150,185,207,141,168,185,57,139,184,185,28,226,198,185,200,154,211,185,227,190,222,185,73,89,232,185,248,117,240,185,237,33,247,185,6,107,252,185,248,47,0,58,6,136,1,58,161,69,2,58,0,113,2,58,61,18,2,58,116,50,1,58,243,179,255,57,246,34,252,57,79,195,247,57,70,166,242,57,7,221,236,57,128,120,230,57,87,137,223,57,221,31,216,57,250,75,208,57,33,29,200,57,69,162,191,57,204,233,182,57,136,1,174,57,172,246,164,57,198,213,155,57,186,170,146,57,186,128,137,57,72,98,128,57,87,178,110,57,238,220,92,57,8,85,75,57,232,41,58,57,102,105,41,57,239,31,25,57,144,88,9,57,244,57,244,56,26,235,214,56,193,210,186,56,161,252,159,56,17,114,134,56,67,116,92,56,115,179,46,56,102,167,3,56,227,163,182,55,49,197,86,55,115,2,150,54,181,148,88,182,243,218,44,183,115,171,140,183,223,236,189,183,74,86,234,183,1,8,9,184,207,162,26,184,192,18,42,184,57,112,55,184,147,212,66,184,233,89,76,184,231,26,84,184,150,50,90,184,47,188,94,184,242,210,97,184,252,145,99,184,37,20,100,184,218,115,99,184,0,203,97,184,217,50,95,184,232,195,91,184,224,149,87,184,135,191,82,56,178,86,77,56,45,112,71,56,178,31,65,56,228,119,58,56,70,138,51,56,56,103,44,56,246,29,37,56,149,188,29,56,12,80,22,56,44,228,14,56,179,131,7,56,70,56,0,56,9,21,242,55,20,4,228,55,244,74,214,55,24,245,200,55,45,12,188,55,54,152,175,55,168,159,163,55,127,39,152,55,93,51,141,55,165,197,130,55,31,191,113,55,152,2,95,55,47,84,77,55,173,176,60,55,91,19,45,55,47,118,30,55,1,210,16,55,179,30,4,55,181,166,240,54,222,204,218,54,198,155,198,54,148,254,179,54,250,223,162,54,106,42,147,54,69,200,132,54,11,72,111,54,232,80,87,54,166,129,65,54,237,177,45,54,195,186,27,54,184,118,11,54,236,131,249,53,4,245,222,53,137,0,199,53,25,106,177,53,102,249,157,53,45,122,140,53,224,119,121,53,60,36,93,53,214,167,67,53,89,184,44,53,106,18,24,53,57,121,5,53,120,108,233,52,61,49,203,52,121,234,175,52,69,76,151,52,154,19,129,52,215,10,90,52,34,221,53,52,77,69,21,52,3,255,255,3,4,255,255,4,255,255,0,255,255,0,6,255,0,255,255,0,4,255,255,2,255,255,0,253,253,0,2,255,255,0,0,255,255,4,2,255,255,255,253,0,0,253,255,2,1,255,255,1,2,255,255,2,255,255,0,253,253,0,253,253,0,255,255,0,2,255,255,255,255,1,0,253,253,0,253,253,255,0,0,255,255,2,255,255,1,255,253,0,0,253,253,253,0,255,255,0,1,255,255,1,255,255,0,253,253,0,253,253,0,255,255,0,1,255,255,255,0,254,254,0,254,255,255,254,255,0,0,255,255,1,255,255,254,0,0,254,255,254,254,255,0,255,255,0,255,255,0,254,254,0,255,254,254,255,254,254,0,255,255,0,255,255,0,254,254,0,255,254,254,255,254,254,0,255,255,0,255,255,0,254,254,0,255,254,254,255,254,254,0,255,255,0,255,255,0,254,254,0,255,254,254,255,254,254,68,172,0,0,0,0,0,0,5,0,0,0,210,0,0,0,64,252,12,0,65,0,0,0,176,179,0,0,0,0,0,0,9,0,0,0,20,1,0,0,176,225,15,0,66,0,0,0,176,179,0,0,0,0,0,0,9,0,0,0,160,0,0,0,72,90,10,0,67,0,0,0,176,179,0,0,0,0,0,0,9,0,0,0,65,1,0,0,96,0,14,0,68,0,0,0,128,187,0,0,0,0,0,0,16,0,0,0,45,1,0,0,232,198,6,0,69,0,0,0,68,172,0,0,0,0,0,0,20,0,0,0,77,1,0,0,104,199,6,0,69,0,0,0,168,147,0,0,0,0,0,0,16,0,0,0,240,0,0,0,8,200,6,0,69,0,0,0,0,125,0,0,0,0,0,0,20,0,0,0,240,0,0,0,136,200,6,0,69,0,0,0,34,86,0,0,0,0,0,0,20,0,0,0,240,0,0,0,40,201,6,0,69,0,0,0,128,62,0,0,0,0,0,0,20,0,0,0,240,0,0,0,200,201,6,0,69,0,0,0,17,43,0,0,0,0,0,0,20,0,0,0,240,0,0,0,104,202,6,0,69,0,0,0,64,31,0,0,0,0,0,0,20,0,0,0,240,0,0,0,8,203,6,0,69,0,0,0,128,187,0,0,0,0,0,0,16,0,0,0,250,0,0,0,184,197,6,0,70,0,0,0,68,172,0,0,0,0,0,0,15,0,0,0,250,0,0,0,56,198,6,0,70,0,0,0,68,172,0,0,0,0,0,0,20,0,0,0,127,1,0,0,168,203,6,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,204,31,0,152,183,31,0,24,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,240,204,31,0,152,164,31,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,204,31,0,200,146,31,0,200,128,31,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,88,113,31,0,232,95,31,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,24,53,31,0,152,33,31,0,44,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,223,31,0,108,0,0,0,224,39,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,134,102,138,187,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,180,84,69,102,136,170,171,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,101,69,85,102,119,120,153,153,170,171,187,188,203,191,255,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,134,85,85,85,102,103,119,136,136,153,153,153,153,153,154,170,155,187,203,187,204,204,207,255,204,207,252,188,204,251,185,252,168,118,102,86,102,103,103,119,120,136,136,137,136,137,153,153,154,154,154,154,170,170,170,170,154,169,171,169,169,152,134,255,202,136,119,119,119,119,119,136,136,136,136,153,153,153,152,153,153,154,153,153,153,153,153,153,153,153,153,152,136,135,101,255,251,170,169,136,136,137,153,152,153,154,169,154,169,170,169,154,170,169,170,169,153,153,169,154,153,153,153,152,136,119,100,255,255,252,187,186,185,170,171,170,170,186,171,171,171,203,186,171,187,187,170,186,170,170,170,169,170,153,153,153,136,135,100,255,255,255,255,203,187,187,187,187,187,203,187,188,187,204,251,204,207,207,204,252,252,207,203,204,187,187,203,187,170,153,134,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,184,160,0,0,251,149,103,139,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,247,85,86,119,137,186,187,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,184,101,85,85,86,119,120,137,154,170,170,188,188,203,188,207,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,134,85,85,85,85,86,103,119,119,136,137,154,153,153,170,187,187,171,191,203,250,204,252,236,239,251,188,255,188,187,169,255,152,118,102,102,101,102,102,118,119,119,119,136,136,136,137,153,153,153,153,169,153,153,154,153,153,170,170,169,153,152,118,255,249,135,119,119,119,119,119,119,119,120,136,136,136,136,153,153,137,153,153,153,153,137,153,153,153,152,153,152,119,119,101,255,202,169,153,137,136,136,152,137,153,152,153,153,153,153,154,153,153,169,154,169,153,153,153,153,169,153,153,152,136,119,100,255,203,169,169,170,170,170,154,171,170,154,187,171,171,187,171,186,187,186,170,186,186,170,170,169,169,153,153,153,136,119,100,255,255,255,188,251,203,187,187,187,186,186,171,191,203,187,187,188,191,204,203,203,204,187,187,251,203,188,202,188,170,169,134,255,255,255,255,255,207,255,252,255,255,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,240,0,0,155,101,103,171,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,181,84,86,103,136,169,171,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,168,101,68,69,86,103,120,137,153,169,170,187,187,171,188,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,118,85,84,85,85,86,103,119,119,136,137,153,152,153,138,153,187,171,188,171,186,170,187,203,204,187,204,187,172,186,151,251,151,118,102,102,102,102,103,119,119,119,136,136,136,136,153,137,153,153,153,153,153,153,154,152,153,153,169,153,136,135,101,255,202,152,135,119,119,135,136,136,136,136,136,153,153,153,153,153,153,153,153,153,153,153,153,153,153,153,153,136,135,119,100,255,252,202,170,153,153,153,153,153,170,154,170,170,170,170,170,170,170,170,170,170,170,170,170,170,153,153,153,137,136,135,100,255,255,251,255,188,252,187,203,187,202,203,188,204,191,188,187,187,190,188,203,204,187,252,188,204,171,203,171,187,170,169,151,255,255,255,255,187,207,251,204,252,207,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,3,3,3,1,1,1,1,0,3,1,1,3,3,3,3,71,136,118,82,18,53,68,67,52,69,119,103,102,135,135,125,138,137,157,221,156,192,0,0,124,204,199,101,204,34,35,70,50,34,70,123,182,187,187,188,204,204,204,204,204,192,0,0,187,187,180,67,37,91,90,171,91,34,34,43,186,170,70,91,187,187,187,187,187,176,0,0,153,137,136,137,49,136,136,137,136,56,136,19,40,136,136,40,136,136,136,136,153,144,0,0,153,137,136,137,136,136,136,57,152,136,136,136,8,136,136,129,153,136,153,153,153,32,0,0,170,217,134,205,221,221,152,118,67,101,53,99,35,68,51,36,69,68,69,89,168,144,0,0,153,137,136,137,152,136,136,137,152,8,136,136,40,136,136,131,25,152,136,153,153,144,0,0,186,170,170,170,170,170,170,165,164,1,74,170,83,74,164,170,90,170,170,170,170,176,0,0,170,170,170,170,170,170,170,154,170,163,49,49,52,52,169,165,68,74,170,170,170,160,0,0,238,222,237,222,238,237,221,222,232,238,231,100,71,67,48,67,67,54,126,238,238,144,0,0,103,135,135,102,101,85,68,69,101,84,84,50,52,102,99,85,68,84,52,69,86,96,0,0,86,102,101,84,51,52,51,51,51,52,68,69,86,102,103,119,119,119,120,137,137,96,0,0,120,137,152,101,101,50,34,50,51,51,69,119,119,139,154,239,255,255,255,255,238,240,0,0,157,216,141,87,86,85,68,69,34,34,35,52,87,120,136,221,221,221,221,221,221,208,0,0,220,204,140,204,135,101,85,84,35,68,33,35,70,86,135,124,140,140,204,204,204,208,0,0,221,205,204,205,220,199,100,88,49,37,51,34,68,86,102,109,221,221,220,220,220,208,0,0,185,153,166,103,120,118,120,136,102,85,68,67,35,51,51,51,52,69,86,102,136,176,0,0,221,205,220,205,220,204,119,197,83,18,35,51,51,70,101,117,141,221,221,220,220,208,0,0,221,205,204,205,220,204,140,133,85,51,33,35,51,68,86,86,86,141,221,204,220,208,0,0,238,222,221,222,221,221,221,135,117,85,67,34,33,37,101,85,102,119,216,141,221,144,0,0,255,255,255,255,255,255,252,170,152,119,85,67,51,51,33,51,52,102,137,175,255,192,0,0,87,119,118,102,101,85,68,68,68,68,68,68,51,68,67,68,68,69,86,102,119,80,0,0,87,118,102,101,68,68,67,51,51,51,51,52,69,86,103,119,119,137,136,137,153,96,0,0,138,153,136,119,102,68,67,50,50,34,51,69,103,137,235,239,255,255,255,255,255,240,0,0,255,251,186,167,120,102,101,84,34,33,35,68,86,138,158,175,251,255,255,255,255,240,0,0,255,175,253,223,172,152,119,102,68,49,17,53,103,136,138,170,255,255,255,255,255,240,0,0,255,239,238,239,168,142,151,102,67,34,33,35,69,103,151,127,255,238,233,238,238,240,0,0,170,169,151,101,69,69,103,102,85,84,68,68,51,51,51,51,68,69,86,104,139,176,0,0,238,222,237,222,237,221,216,119,101,67,17,34,52,102,120,135,238,238,238,157,237,224,0,0,255,255,255,220,255,174,234,152,118,84,49,17,52,86,136,153,155,255,255,191,255,240,0,0,255,255,255,207,223,255,253,154,118,101,67,33,18,53,86,103,137,153,175,175,255,240,0,0,255,255,254,239,219,186,170,153,118,85,67,34,34,51,51,68,85,103,138,250,251,160,0,0,87,119,119,102,101,85,84,68,68,68,67,51,51,52,68,68,85,85,102,119,136,96,0,0,88,119,118,102,85,84,68,51,51,35,51,51,69,86,102,119,136,136,136,136,153,96,0,0,154,169,169,136,118,85,68,51,34,34,35,69,86,153,157,191,255,255,255,255,255,240,0,0,253,187,170,186,169,135,119,84,51,33,18,69,104,138,170,203,255,207,255,255,254,240,0,0,255,255,255,239,254,169,152,135,101,65,2,69,119,136,172,175,255,255,255,255,255,240,0,0,191,252,171,251,186,171,184,136,118,82,1,53,120,153,171,170,207,187,207,252,252,240,0,0,186,202,152,117,33,53,119,119,118,101,84,68,68,52,68,68,69,86,120,136,154,192,0,0,223,207,204,255,171,201,185,152,151,117,32,19,86,137,137,170,252,188,175,204,255,208,0,0,255,255,187,251,255,251,186,168,119,84,33,17,69,103,136,138,239,187,255,187,255,240,0,0,255,255,255,255,252,251,203,185,136,101,49,18,35,53,103,136,170,172,252,255,255,240,0,0,255,255,252,239,255,187,170,169,118,85,50,34,34,51,52,86,103,104,154,170,205,224,0,0,88,119,119,102,102,85,84,68,68,67,51,51,51,52,68,85,85,102,103,120,136,96,0,0,87,119,118,102,85,85,84,67,51,34,51,52,69,85,102,103,119,119,120,136,153,80,0,0,172,153,152,135,118,102,84,67,50,33,35,69,102,137,153,153,170,191,255,255,255,240,0,0,255,255,255,185,170,152,119,101,66,33,18,69,120,138,186,170,251,255,255,255,255,240,0,0,255,255,255,253,188,187,185,152,118,50,1,70,121,171,187,190,255,255,255,255,255,240,0,0,255,255,255,255,207,170,170,153,118,66,1,54,121,154,171,191,253,255,255,255,255,240,0,0,204,220,185,117,16,71,137,153,152,135,118,102,85,85,85,86,102,103,120,153,190,224,0,0,255,255,255,252,204,255,251,171,135,100,16,35,103,153,154,173,206,255,252,255,255,240,0,0,255,255,255,251,255,253,250,185,151,101,32,19,86,120,170,155,251,252,255,255,255,240,0,0,255,255,255,207,252,201,172,152,135,84,49,18,35,69,103,120,154,170,235,255,255,224,0,0,255,255,254,202,250,153,152,136,101,68,50,34,34,51,69,86,103,120,153,187,171,160,0,0,72,119,118,102,101,85,85,68,68,67,51,51,51,52,69,85,85,102,103,119,120,96,0,0,104,135,119,119,102,85,84,67,51,34,35,52,69,85,102,120,136,152,136,136,137,96,0,0,171,186,170,186,153,135,118,84,51,33,18,70,103,137,154,223,255,255,255,255,255,240,0,0,255,255,255,253,202,152,135,118,84,33,17,69,120,138,154,255,255,255,255,255,255,240,0,0,255,255,255,255,255,188,170,153,118,50,1,70,120,154,171,239,255,255,255,255,255,240,0,0,255,255,255,255,255,202,233,137,118,82,1,53,104,152,154,175,255,255,255,255,255,240,0,0,173,203,169,116,16,70,137,154,169,152,119,118,102,85,85,86,102,102,120,136,138,208,0,0,255,255,255,255,255,253,170,170,135,99,16,36,103,137,175,223,255,255,255,255,255,240,0,0,255,255,255,255,255,255,187,154,151,100,32,19,103,137,154,207,255,255,255,255,255,240,0,0,255,255,255,255,255,255,153,135,118,67,33,18,52,86,103,136,137,174,207,253,239,240,0,0,255,255,255,255,255,253,170,135,102,84,49,18,51,68,85,103,119,137,171,171,207,192,0,0,88,135,135,119,118,102,85,85,68,67,50,34,51,68,85,86,103,119,120,136,136,112,0,0,103,118,102,118,102,85,68,68,51,34,34,52,86,103,119,137,136,153,171,154,171,112,0,0,155,169,136,136,135,119,101,84,67,33,18,69,103,154,154,239,255,255,255,255,238,240,0,0,255,255,252,203,186,170,152,135,101,49,2,86,137,171,203,188,255,255,255,255,255,240,0,0,255,255,255,255,250,170,154,152,118,66,1,54,121,175,207,255,255,255,255,255,255,240,0,0,255,255,255,255,250,120,169,152,118,82,1,53,120,142,203,191,239,255,255,255,255,240,0,0,140,186,153,116,16,54,137,154,169,153,136,135,118,102,102,102,102,86,102,120,137,192,0,0,255,255,255,255,255,249,138,169,136,99,16,36,103,139,188,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,201,153,118,84,16,36,86,120,154,170,255,255,255,255,239,240,0,0,255,255,255,255,255,255,255,217,135,84,32,34,69,103,119,137,172,171,251,255,255,240,0,0,255,255,255,255,255,255,173,171,134,84,33,18,52,69,102,119,103,119,136,153,154,144,0,0,87,119,118,102,101,85,85,85,84,67,50,35,51,68,85,85,102,103,136,119,119,80,0,0,53,68,69,85,84,68,68,67,51,51,35,68,104,153,170,170,203,171,175,254,235,224,0,0,119,102,103,102,102,102,84,68,51,34,18,69,104,170,190,175,255,255,255,255,238,240,0,0,255,234,152,136,135,119,101,85,68,50,2,70,120,137,170,191,255,255,255,255,255,240,0,0,255,255,255,255,171,171,153,118,101,66,1,69,120,170,173,172,254,255,255,255,255,240,0,0,255,255,255,255,252,235,186,169,134,66,1,54,119,138,187,255,255,255,255,255,255,240,0,0,172,187,152,116,16,54,119,137,153,153,136,119,118,102,102,85,86,103,137,170,171,192,0,0,255,255,255,255,223,201,153,153,136,100,16,36,85,104,137,187,173,191,191,255,255,240,0,0,255,255,255,255,255,255,151,101,101,84,32,35,69,86,119,119,142,203,190,223,255,240,0,0,255,255,255,255,255,255,255,186,118,83,33,19,52,85,69,85,103,121,171,250,251,160,0,0,255,255,255,255,255,255,191,254,135,84,33,35,51,68,85,85,68,69,87,138,170,128,0,0,121,153,153,151,119,118,84,68,68,68,50,51,51,51,68,69,86,103,136,119,120,96,0,0,52,84,69,85,84,68,68,51,50,67,52,68,86,119,187,182,204,204,204,200,203,112,0,0,126,103,85,101,68,85,68,51,34,35,35,87,152,221,221,222,237,221,221,221,221,224,0,0,255,239,238,151,117,84,67,51,51,50,18,88,136,238,174,239,255,255,255,254,238,240,0,0,255,255,255,255,250,136,135,102,83,34,2,87,157,255,255,239,239,255,255,255,255,240,0,0,255,255,255,255,255,250,169,120,118,66,1,54,153,154,255,223,255,253,255,255,255,240,0,0,171,170,168,117,16,38,121,136,119,119,102,102,87,120,136,137,152,154,187,187,221,192,0,0,255,255,254,239,255,254,168,120,118,84,32,34,69,110,142,239,255,249,255,255,255,240,0,0,255,255,255,239,255,255,250,231,102,100,32,35,52,86,120,136,175,252,255,255,175,240,0,0,238,222,237,222,237,141,221,217,230,99,33,35,67,52,53,85,101,71,238,237,237,224,0,0,221,205,220,205,221,204,204,205,221,118,67,68,68,67,52,51,34,51,53,216,204,208,0,0,107,119,187,182,150,85,85,84,68,68,51,67,51,51,69,52,68,104,87,120,134,80,0,0,74,170,170,154,68,68,69,35,36,34,163,58,68,153,153,154,170,170,170,170,170,160,0,0,170,69,52,148,74,74,50,35,50,36,74,170,170,169,153,154,170,170,170,170,170,160,0,0,170,170,170,170,74,164,68,33,67,50,35,90,170,170,153,170,170,170,170,170,170,160,0,0,221,221,221,221,221,125,141,116,33,17,53,125,221,221,221,221,221,221,221,221,221,208,0,0,254,238,238,238,238,238,238,233,100,50,1,87,232,238,238,238,238,238,238,238,238,240,0,0,238,222,233,85,16,39,152,101,72,174,153,136,119,135,121,137,234,238,174,238,238,224,0,0,203,187,187,187,187,187,187,187,182,69,17,19,68,59,187,187,187,187,187,187,187,192,0,0,187,171,170,170,170,170,170,170,170,90,49,18,35,52,170,170,170,170,170,170,170,176,0,0,187,187,187,171,187,187,170,171,187,187,181,85,100,34,36,85,50,20,187,187,187,176,0,0,170,170,169,154,170,169,153,154,74,170,163,51,50,52,53,68,66,36,164,170,170,160,0,0,170,154,153,154,169,84,148,149,68,83,52,83,35,52,52,69,51,74,153,153,169,160,0,0,87,171,102,82,18,68,69,67,51,69,119,166,119,167,167,101,119,187,183,187,123,176,0,0,187,91,187,91,187,33,34,69,98,38,86,187,187,186,170,187,187,187,187,187,187,176,0,0,170,58,153,147,25,153,153,153,153,36,25,51,153,147,153,153,153,153,153,153,153,160,0,0,119,103,102,103,118,102,102,103,119,102,102,102,102,102,102,16,119,118,119,119,119,112,0,0,119,103,102,103,118,102,102,103,119,102,102,102,97,102,102,103,7,118,119,119,119,112,0,0,221,221,214,205,221,217,136,201,100,118,52,66,18,84,83,52,84,86,102,121,221,208,0,0,136,120,119,120,119,119,119,120,135,7,119,119,33,119,119,120,136,135,135,136,136,128,0,0,170,154,153,154,153,153,153,154,153,1,153,153,67,153,52,153,148,153,153,153,170,160,0,0,153,137,136,137,136,136,136,137,136,130,136,33,130,130,131,136,130,136,136,136,153,144,0,0,221,221,221,205,221,221,204,205,221,221,214,116,86,100,32,84,66,56,221,221,221,208,0,0,121,135,150,118,118,85,102,68,85,68,85,50,36,136,98,85,69,67,71,102,118,96,0,0,87,102,101,84,67,52,51,51,51,51,68,69,85,102,119,119,119,119,152,136,121,96,0,0,136,152,141,101,102,50,51,34,35,51,69,103,120,104,141,205,221,221,221,221,221,208,0,0,141,205,220,197,86,70,69,84,34,34,34,69,87,108,204,205,221,221,221,220,204,208,0,0,204,204,203,188,204,199,181,84,18,51,34,37,86,182,123,183,204,204,204,204,204,192,0,0,187,171,186,171,187,165,165,85,33,43,51,35,68,85,166,91,187,187,187,187,187,176,0,0,172,171,198,102,135,135,119,152,102,84,67,67,51,50,51,51,68,69,102,104,121,160,0,0,187,187,187,171,187,187,186,75,67,34,34,50,68,52,165,166,187,187,187,187,187,176,0,0,187,171,170,171,186,170,166,101,84,67,33,35,52,52,85,86,107,187,182,186,186,176,0,0,221,205,220,205,221,204,204,198,102,68,67,50,33,37,101,70,84,141,221,220,215,192,0,0,255,239,238,239,238,238,238,154,247,102,85,67,51,34,34,51,52,120,152,238,254,144,0,0,87,103,102,118,101,85,68,84,68,67,67,52,67,68,68,68,69,69,85,103,119,96,0,0,120,136,118,102,85,84,68,51,34,35,51,68,85,103,103,120,152,152,153,154,169,144,0,0,153,170,171,151,101,85,68,50,34,34,51,69,103,137,255,239,255,255,255,255,255,240,0,0,255,252,187,168,136,119,118,84,50,17,35,70,119,138,248,207,255,255,255,255,255,240,0,0,238,222,237,222,233,221,119,101,67,33,18,52,87,125,120,222,238,238,238,238,238,224,0,0,238,238,238,222,238,231,125,150,84,34,17,36,86,135,221,222,238,238,238,238,238,224,0,0,203,170,151,101,68,69,119,118,102,85,68,51,51,51,51,51,68,85,104,153,154,192,0,0,221,221,221,125,221,220,204,102,102,67,17,34,52,86,140,205,221,221,221,221,221,208,0,0,255,239,254,239,255,238,233,136,118,84,49,17,52,87,119,143,175,255,255,254,254,240,0,0,254,238,238,234,174,238,169,233,135,101,67,17,34,53,86,102,136,154,238,234,238,240,0,0,255,255,255,234,255,251,234,152,118,85,67,34,34,51,51,68,70,120,170,255,251,176,0,0,121,153,119,119,102,85,84,68,67,67,51,51,51,52,68,85,85,102,102,121,153,128,0,0,104,135,119,102,85,85,84,67,50,34,51,52,69,102,119,120,136,137,152,136,136,96,0,0,170,171,171,169,136,102,101,67,34,33,35,70,120,169,191,239,255,255,255,239,255,240,0,0,253,255,255,188,153,152,118,101,66,33,18,70,103,153,255,239,255,255,191,255,255,240,0,0,255,255,255,255,190,250,185,135,101,49,2,86,121,154,175,234,255,255,255,207,255,240,0,0,155,174,190,155,187,171,170,152,118,82,1,53,136,153,154,172,186,187,234,186,234,176,0,0,204,188,167,101,33,70,136,135,119,101,68,68,67,51,68,69,85,86,120,154,155,192,0,0,158,158,169,171,170,169,157,153,135,101,16,35,104,136,152,154,169,170,218,173,170,144,0,0,255,255,254,239,255,252,187,169,167,101,48,18,86,120,154,154,255,255,255,255,255,240,0,0,255,255,255,255,255,255,204,186,152,118,65,17,36,71,119,137,187,237,207,255,255,240,0,0,255,207,255,239,207,206,155,169,135,101,66,17,35,68,85,102,103,154,171,207,204,208,0,0,104,120,119,118,102,85,85,84,68,51,51,50,51,52,85,85,102,102,119,119,136,96,0,0,104,119,118,102,85,85,84,68,50,34,51,52,85,86,102,102,103,120,136,153,153,80,0,0,203,202,170,169,151,119,102,84,50,33,19,70,121,170,171,191,205,253,207,255,255,240,0,0,255,255,252,255,187,169,168,135,101,49,2,86,137,171,187,187,188,255,255,255,255,240,0,0,255,255,251,255,205,207,153,135,101,66,1,69,103,154,187,175,189,191,252,255,255,240,0,0,255,255,255,255,255,207,249,168,134,66,1,54,120,138,191,159,255,255,255,255,255,176,0,0,207,219,186,133,16,71,137,153,153,135,102,101,85,85,85,86,102,119,137,172,206,240,0,0,255,255,255,207,255,191,187,255,152,99,16,36,89,153,191,251,191,255,255,255,255,240,0,0,255,255,255,255,255,203,187,175,151,101,32,19,86,120,153,171,253,175,255,255,255,240,0,0,255,255,255,255,255,204,187,170,151,101,48,19,68,86,136,137,169,191,255,207,252,240,0,0,255,255,253,255,250,186,186,185,135,101,50,17,35,69,86,103,119,154,186,191,255,240,0,0,87,120,119,102,102,85,85,68,68,67,51,35,51,68,69,85,86,102,102,119,120,96,0,0,104,135,135,119,102,85,84,68,50,34,35,68,69,86,102,120,136,136,136,136,136,80,0,0,154,185,169,168,135,118,101,84,67,33,18,69,104,136,170,223,255,255,255,255,255,240,0,0,255,255,255,252,207,186,152,119,101,49,2,86,137,172,239,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,185,135,118,66,1,54,137,170,189,255,223,255,255,255,255,240,0,0,255,255,191,255,239,191,172,153,135,66,1,53,121,170,187,255,255,255,255,255,255,240,0,0,205,204,185,116,16,70,138,169,153,152,119,102,102,85,85,85,102,103,137,154,171,208,0,0,255,255,255,255,255,255,187,218,168,83,16,36,104,154,174,255,254,255,255,255,255,240,0,0,255,255,255,255,255,255,252,251,152,116,16,35,87,137,171,188,255,255,207,255,255,240,0,0,255,255,255,255,255,255,187,186,152,101,32,19,86,120,137,154,172,239,251,255,223,240,0,0,255,255,255,255,255,255,187,153,134,84,33,18,52,69,86,103,103,153,171,235,255,176,0,0,87,135,119,119,102,102,101,85,68,67,50,34,51,68,85,86,103,119,119,136,153,112,0,0,120,136,136,119,118,101,84,68,51,50,18,52,70,120,153,154,186,172,171,203,170,144,0,0,154,152,136,152,135,119,101,84,67,33,18,69,103,139,255,239,255,255,255,255,255,240,0,0,255,255,255,189,169,153,135,119,85,65,2,70,121,171,252,255,255,255,255,255,255,240,0,0,255,254,255,255,219,154,186,152,118,66,1,54,121,187,203,252,255,252,255,255,255,240,0,0,255,255,255,254,255,250,154,170,135,66,1,53,120,218,255,254,255,255,255,255,255,240,0,0,188,204,169,116,16,54,138,170,169,153,136,119,118,102,101,102,85,102,120,136,171,192,0,0,255,255,255,255,255,255,191,170,151,99,16,36,103,136,155,253,253,255,255,255,255,240,0,0,255,255,255,255,251,255,252,187,151,100,16,35,103,136,170,171,255,255,239,255,255,240,0,0,255,255,255,255,255,207,255,189,167,100,32,20,85,119,120,138,170,171,253,204,191,240,0,0,255,255,255,255,255,255,255,234,118,84,33,18,52,69,86,103,119,138,170,153,186,144,0,0,104,136,119,102,102,85,85,85,84,67,34,35,52,68,68,86,119,119,120,153,153,96,0,0,69,86,102,101,85,84,68,68,68,66,18,53,104,142,154,188,235,187,235,187,190,176,0,0,135,119,118,118,102,102,85,84,67,49,18,69,86,169,238,222,238,238,238,238,238,224,0,0,255,255,175,152,151,120,117,85,68,50,2,69,104,142,156,239,223,255,255,255,255,240,0,0,255,255,255,255,251,186,152,119,101,66,1,69,105,156,155,223,191,255,255,255,255,240,0,0,255,255,251,255,255,202,170,168,118,82,1,53,103,138,234,191,255,255,254,255,255,240,0,0,169,171,152,116,16,54,137,153,153,136,135,135,118,102,102,85,86,103,121,155,155,176,0,0,255,255,255,255,255,255,184,136,135,84,16,36,86,119,137,191,255,236,255,255,255,240,0,0,255,255,255,220,255,251,219,185,134,83,32,35,68,86,136,120,170,255,171,255,255,240,0,0,255,255,255,255,255,175,191,250,151,100,32,35,68,85,86,103,119,137,155,185,255,240,0,0,238,238,238,238,238,238,238,217,117,67,33,35,52,68,68,85,85,102,102,120,138,128,0,0,121,137,152,136,119,119,84,68,68,67,34,51,51,68,69,69,102,104,119,152,136,96,0,0,37,69,87,69,69,85,67,51,51,51,52,68,85,187,187,107,187,187,187,187,187,176,0,0,134,118,117,85,85,101,116,68,51,50,18,53,108,204,204,205,221,204,204,204,204,208,0,0,238,222,221,142,118,85,67,68,50,50,18,70,135,153,157,222,238,238,221,221,221,224,0,0,255,255,254,239,255,169,150,85,67,50,2,69,136,238,233,239,255,255,255,255,255,240,0,0,255,255,255,255,255,250,175,137,102,66,1,54,217,138,255,239,255,255,255,255,255,240,0,0,170,234,249,116,16,53,121,152,135,102,102,85,86,103,119,119,136,153,170,252,238,176,0,0,255,255,255,239,255,255,233,151,247,101,32,19,86,121,234,239,255,255,255,255,255,240,0,0,238,238,237,222,238,237,221,222,117,99,17,34,52,69,103,120,158,238,238,238,238,224,0,0,238,222,221,222,237,216,221,222,135,84,32,35,70,70,86,103,118,121,142,237,237,224,0,0,238,222,221,222,221,221,221,217,152,84,50,35,69,68,52,67,35,102,54,216,221,144,0,0,123,123,167,119,106,87,86,85,69,67,51,51,51,51,68,67,53,187,186,170,183,80,0,0,36,163,68,68,170,73,52,67,36,66,53,169,153,73,153,154,170,170,170,170,170,160,0,0,153,57,148,148,57,67,146,51,41,34,57,153,153,153,136,153,153,153,153,153,153,144,0,0,153,153,153,153,73,73,51,52,51,33,35,153,153,153,152,153,153,153,153,153,153,144,0,0,220,204,204,204,204,204,204,198,50,33,18,69,199,204,204,204,204,204,204,204,204,208,0,0,237,221,221,221,221,221,215,221,117,66,1,56,221,125,221,221,221,221,221,221,221,224,0,0,204,140,135,100,16,55,134,102,103,105,120,119,118,102,102,103,104,119,136,204,204,192,0,0,187,171,170,171,170,170,170,170,170,164,32,34,68,165,170,170,170,170,170,170,186,176,0,0,187,187,187,187,187,187,187,187,187,75,51,3,35,70,75,91,187,187,187,187,187,176,0,0,187,187,187,171,187,187,170,171,187,187,178,67,68,50,19,70,52,53,187,187,187,176,0,0,170,170,170,170,170,170,169,154,170,170,164,35,50,165,50,162,36,163,170,74,170,160,0,0,169,89,153,153,153,84,73,69,85,69,67,57,82,51,67,68,37,89,89,153,89,160,0,0,88,118,91,83,33,37,84,67,51,72,136,86,103,107,135,188,124,140,204,204,140,176,0,0,204,204,108,76,204,18,18,69,83,53,124,204,204,204,187,204,204,204,204,204,204,192,0,0,170,170,164,161,68,85,169,154,170,162,34,36,165,164,73,170,170,170,170,170,170,160,0,0,153,136,51,136,136,136,136,40,136,136,136,33,51,136,131,130,136,136,136,136,137,144,0,0,102,86,85,86,101,85,85,86,6,101,85,85,85,85,85,86,102,102,102,102,102,96,0,0,238,157,166,157,218,217,151,85,66,100,67,50,36,68,51,68,102,85,88,125,221,160,0,0,136,120,119,120,119,119,119,120,130,7,119,119,114,39,119,120,135,119,135,136,136,128,0,0,187,171,170,170,170,170,170,170,68,1,58,170,74,74,69,170,170,170,170,170,170,176,0,0,153,153,153,153,153,153,153,137,153,146,57,33,73,67,51,153,52,57,153,153,153,144,0,0,238,238,237,222,238,237,221,222,238,238,151,117,85,117,32,52,99,38,142,238,238,224,0,0,105,184,119,139,133,86,85,68,101,68,51,50,35,103,164,116,69,68,69,104,134,112,0,0,103,118,102,84,67,67,51,51,51,51,68,68,85,102,103,103,119,119,137,137,153,96,0,0,169,153,153,102,102,67,51,34,34,51,52,87,120,255,191,255,255,255,255,255,255,240,0,0,254,233,233,135,101,85,68,68,50,34,34,52,86,121,142,234,238,238,238,238,238,240,0,0,238,222,221,216,221,117,84,84,51,68,49,19,69,102,136,137,142,221,221,221,237,224,0,0,204,188,187,188,203,117,101,69,50,36,67,18,70,84,119,188,204,204,203,203,203,192,0,0,169,139,151,86,136,118,119,102,85,68,51,51,51,51,51,51,69,86,103,138,202,192,0,0,221,205,204,205,220,204,104,85,83,33,35,51,51,69,119,103,221,221,221,220,220,208,0,0,238,222,221,222,233,141,216,103,68,50,34,34,51,68,70,135,238,238,238,221,221,224,0,0,255,239,238,239,254,238,233,120,103,84,67,34,18,53,83,85,86,122,254,238,254,240,0,0,255,255,255,255,255,255,186,251,135,102,84,51,51,34,34,51,70,103,122,207,207,240,0,0,103,119,119,102,102,85,85,68,67,68,51,52,67,68,67,68,68,85,102,118,136,112,0,0,120,119,118,102,85,68,68,51,51,34,51,52,69,103,120,136,136,153,137,169,169,112,0,0,169,155,153,135,119,84,68,51,34,34,35,69,103,159,255,255,255,255,255,255,255,240,0,0,255,255,253,170,152,135,119,101,50,17,35,68,87,154,206,255,255,255,255,255,255,240,0,0,255,255,255,255,250,136,119,101,84,49,17,53,87,136,143,223,252,159,255,255,255,240,0,0,255,239,238,239,254,153,135,119,84,34,17,36,102,119,120,234,249,255,238,238,254,240,0,0,171,170,151,101,68,69,102,101,84,68,67,51,51,51,51,68,85,102,120,139,171,176,0,0,238,222,237,222,152,141,221,103,102,67,17,34,52,87,119,142,238,238,238,237,221,224,0,0,255,255,255,239,251,255,187,152,102,84,49,17,52,86,152,191,220,191,191,255,255,240,0,0,255,255,255,255,255,255,203,170,136,102,50,17,35,53,102,119,153,206,254,205,255,240,0,0,255,255,255,255,255,254,202,169,118,84,66,34,34,51,52,85,86,119,155,191,255,192,0,0,105,136,119,119,118,101,85,68,67,67,51,51,51,52,68,68,85,103,119,136,137,112,0,0,121,152,135,119,102,85,68,67,51,34,35,51,69,102,119,136,137,153,154,169,153,112,0,0,187,251,186,169,152,118,101,68,50,33,34,53,121,174,204,255,255,255,255,255,255,240,0,0,255,207,250,170,153,136,119,101,51,33,18,68,87,137,171,190,207,255,255,255,255,240,0,0,255,255,255,191,219,169,153,134,101,65,2,69,120,137,202,255,255,255,255,255,255,240,0,0,255,255,255,255,255,171,169,152,118,82,1,53,104,137,158,239,191,255,255,255,255,192,0,0,219,202,152,117,33,70,119,118,102,84,68,68,51,52,68,69,102,119,137,172,203,208,0,0,255,255,255,255,255,255,187,152,119,101,16,35,86,137,170,255,252,255,255,255,255,240,0,0,255,255,255,255,255,252,187,202,135,101,48,18,86,120,169,186,253,207,255,255,255,240,0,0,255,255,255,255,254,237,170,169,151,100,49,18,35,69,86,120,169,172,255,255,255,240,0,0,255,255,255,255,254,252,203,168,101,84,50,18,35,52,69,86,119,136,172,223,223,224,0,0,104,152,136,119,119,102,85,84,68,67,50,34,51,68,85,86,102,119,120,137,153,112,0,0,138,169,136,135,102,101,84,67,51,34,35,51,69,85,103,120,136,136,136,153,153,96,0,0,207,191,202,170,152,135,118,84,51,33,18,69,120,138,191,255,255,255,255,255,255,240,0,0,255,255,255,239,190,186,153,119,101,49,2,86,137,155,188,255,255,255,255,255,255,240,0,0,255,255,255,255,255,252,187,151,118,50,1,70,136,155,171,255,255,255,255,255,255,240,0,0,255,255,255,255,255,253,252,168,151,66,1,53,120,154,188,223,255,255,255,255,255,240,0,0,220,203,185,117,16,71,137,137,136,118,102,85,85,85,85,102,119,120,154,172,254,240,0,0,255,255,255,255,255,251,202,169,135,99,16,36,103,138,202,255,254,207,255,255,255,240,0,0,255,255,255,255,255,255,253,170,152,116,32,19,87,138,158,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,188,169,135,101,48,19,68,86,120,154,190,239,255,255,255,240,0,0,255,255,255,255,255,255,187,152,101,84,49,18,51,68,85,103,120,154,172,252,255,240,0,0,104,136,135,119,119,118,85,84,68,67,50,34,51,68,69,86,103,120,137,154,187,144,0,0,138,153,136,119,118,102,85,67,51,34,34,51,69,103,119,136,136,153,170,154,170,128,0,0,188,170,171,169,152,135,102,84,51,33,18,69,137,207,255,255,255,255,255,255,255,240,0,0,255,255,239,252,204,186,152,135,101,49,2,86,121,187,239,255,255,255,255,255,255,240,0,0,255,255,255,223,255,253,186,152,118,66,1,54,120,154,251,255,255,255,255,255,255,240,0,0,255,255,255,255,255,250,187,169,135,66,1,53,120,171,251,207,255,255,255,255,255,240,0,0,221,236,201,116,16,71,137,153,153,135,118,102,85,85,85,86,103,120,137,188,205,224,0,0,255,255,255,255,255,255,255,218,152,99,16,36,88,154,191,239,255,191,255,255,255,240,0,0,255,255,255,255,255,255,254,219,151,116,16,35,87,154,171,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,255,202,168,101,32,19,86,119,137,155,206,207,255,255,255,240,0,0,255,255,255,255,255,203,154,170,118,84,33,18,52,69,86,102,120,153,175,236,239,176,0,0,120,136,135,119,102,102,101,85,84,67,34,34,51,68,85,103,119,136,152,153,170,128,0,0,103,119,134,102,102,101,84,68,51,50,18,52,87,153,172,154,172,251,207,238,235,160,0,0,170,153,136,135,119,119,102,85,67,33,18,53,138,251,255,255,255,255,255,255,255,240,0,0,255,250,218,153,152,119,118,101,83,50,2,69,103,154,207,223,255,255,255,255,255,240,0,0,255,255,255,207,251,187,233,135,118,66,1,54,137,187,191,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,170,169,118,82,1,53,103,138,154,201,255,254,255,255,255,240,0,0,236,204,169,116,16,55,136,137,153,136,135,118,102,85,85,86,119,120,170,254,255,240,0,0,255,255,255,255,255,255,237,186,135,100,16,36,70,119,171,255,255,255,239,255,255,240,0,0,255,255,255,255,255,254,207,255,136,100,16,36,70,120,136,170,191,204,255,255,255,240,0,0,255,255,255,255,255,255,254,220,167,101,32,20,85,87,119,136,154,170,187,255,255,240,0,0,255,255,255,255,255,252,249,151,118,83,33,19,52,69,85,102,102,119,136,170,220,160,0,0,157,172,186,152,136,119,101,84,84,67,33,35,52,69,85,102,103,121,153,157,187,128,0,0,71,124,101,69,69,69,69,51,67,34,35,68,87,119,204,184,204,204,204,204,204,192,0,0,137,136,103,104,103,118,85,85,67,33,18,70,142,234,238,239,238,238,238,238,238,240,0,0,238,222,217,216,135,102,100,85,68,66,2,69,103,141,221,222,238,238,238,237,221,224,0,0,255,255,250,255,207,183,152,102,84,66,1,87,137,250,255,239,251,255,255,255,255,240,0,0,255,255,255,255,255,253,170,136,118,66,1,54,120,255,255,234,255,255,255,255,255,240,0,0,188,170,184,117,16,53,120,136,135,102,102,85,85,102,119,119,136,153,154,219], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1057260);
/* memory initializer */ allocate([187,208,0,0,255,255,255,239,255,255,253,153,135,101,16,35,86,120,158,175,255,255,255,255,255,240,0,0,255,239,254,239,255,238,233,232,101,84,32,35,52,103,122,153,159,249,255,254,254,240,0,0,255,239,238,239,254,238,233,239,135,83,32,35,85,85,86,104,152,138,159,254,254,240,0,0,255,255,255,255,255,255,250,138,119,84,49,35,68,52,68,68,67,69,87,250,251,240,0,0,124,183,139,118,118,102,85,84,68,67,51,50,51,68,84,68,68,87,152,135,203,80,0,0,70,171,106,107,101,84,84,50,34,50,67,68,164,106,170,171,187,187,187,170,170,176,0,0,103,102,107,108,86,181,85,52,50,33,35,100,187,187,187,188,204,204,204,204,203,192,0,0,204,204,204,188,118,87,85,84,67,33,18,70,124,187,187,188,204,204,204,204,204,192,0,0,221,221,221,221,221,221,221,119,67,34,2,87,141,221,221,221,221,221,221,221,221,208,0,0,221,205,204,205,204,204,204,204,101,66,1,60,124,204,204,204,204,204,204,204,220,208,0,0,238,142,217,117,16,53,119,102,104,119,102,101,102,101,102,104,136,238,174,237,221,224,0,0,221,221,221,221,221,221,221,216,221,85,32,20,86,77,125,221,221,221,221,221,221,208,0,0,204,204,204,188,204,204,203,188,199,99,32,35,68,85,118,124,204,204,204,204,204,192,0,0,187,187,186,171,187,186,170,171,181,182,49,34,52,67,52,84,69,75,187,187,187,176,0,0,204,188,203,188,203,187,187,183,102,85,66,34,35,52,67,53,84,85,108,203,203,192,0,0,203,187,107,183,187,107,101,85,52,51,67,50,35,52,85,68,70,187,187,182,187,192,0,0,136,120,113,120,119,119,119,120,39,113,119,23,119,119,119,120,136,119,136,135,136,128,0,0,153,137,136,137,136,130,136,131,131,18,34,56,136,136,136,136,136,136,136,136,152,144,0,0,153,137,136,137,136,136,56,137,34,17,40,136,136,136,136,137,152,136,136,152,152,144,0,0,170,154,153,154,57,153,153,51,153,66,2,153,153,153,153,154,169,153,153,153,169,160,0,0,170,154,153,154,153,153,153,154,169,146,1,52,153,153,153,154,169,153,154,169,169,160,0,0,170,170,170,170,48,74,170,154,170,164,67,67,53,74,58,170,170,170,170,170,170,160,0,0,170,154,153,154,153,153,153,154,153,147,17,19,52,153,153,154,153,153,153,153,169,160,0,0,153,137,136,137,136,136,136,137,136,136,49,18,136,24,136,137,152,136,137,153,152,144,0,0,136,120,119,120,119,119,119,120,119,119,113,17,114,119,119,120,135,119,136,136,136,128,0,0,170,154,153,153,153,153,153,153,153,57,146,33,25,57,153,148,147,153,153,153,170,160,0,0,136,120,119,120,119,119,119,120,119,114,119,114,23,39,119,120,135,113,120,135,136,128,0,0,4,250,4,245,255,251,3,3,254,5,251,0,9,1,6,3,252,255,251,253,254,251,249,1,6,249,30,227,12,253,245,4,253,7,236,23,2,0,1,250,242,251,15,238,6,7,15,246,242,22,249,254,252,9,6,244,6,250,0,245,0,251,4,0,214,51,105,231,7,248,0,0,127,240,2,30,170,0,0,0,228,0,189,252,233,16,0,0,153,6,184,5,227,2,0,0,103,3,113,11,40,1,0,0,79,0,232,1,51,15,0,0,2,1,255,2,2,1,255,2,0,255,1,0,0,255,1,0,0,1,255,0,0,1,255,0,2,255,1,2,2,255,1,2,5,4,255,5,5,4,255,5,3,255,4,3,3,255,4,3,3,4,255,3,3,4,255,3,5,255,4,5,5,255,4,5,8,7,255,8,8,7,255,8,6,255,7,6,6,255,7,6,6,7,255,6,6,7,255,6,8,255,7,8,8,255,7,8,0,2,0,2,0,2,0,2,2,0,2,0,2,0,2,0,1,255,1,255,1,255,1,255,255,1,255,1,255,1,255,1,3,5,3,5,3,5,3,5,5,3,5,3,5,3,5,3,4,255,4,255,4,255,4,255,255,4,255,4,255,4,255,4,6,8,6,8,6,8,6,8,8,6,8,6,8,6,8,6,7,255,7,255,7,255,7,255,255,7,255,7,255,7,255,7,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,1,0,255,255,255,255,255,5,4,3,255,255,255,255,255,8,7,6,255,255,255,255,255,0,1,2,3,7,10,8,11,3,7,11,15,17,33,21,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,3,3,8,11,8,11,11,11,15,15,21,37,21,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,7,10,7,10,3,3,7,7,17,33,17,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,7,10,7,10,3,11,3,11,17,33,17,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,7,10,8,11,3,7,11,15,17,33,21,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,3,3,8,11,8,11,11,11,15,15,21,37,21,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,7,10,7,10,3,3,7,7,17,33,17,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,7,10,7,10,3,11,3,11,17,33,17,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,201,32,0,224,194,31,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,32,254,30,0,32,81,30,0,12,0,0,0,1,0,0,0,255,255,255,127,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,127,29,0,108,0,0,0,0,0,0,0,100,66,52,0,4,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,101,30,0,108,0,0,0,8,79,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,30,33,0,120,254,31,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,32,30,33,0,152,39,31,0,184,120,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,32,30,33,0,240,234,29,0,64,126,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,32,30,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,222,32,0,108,0,0,0,248,79,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,32,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,0,0,32,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,170,33,0,56,140,33,0,64,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,208,170,33,0,192,104,33,0,240,39,33,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,208,170,33,0,216,2,33,0,216,231,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,208,170,33,0,24,205,32,0,136,178,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,208,170,33,0,96,157,32,0,40,131,32,0,72,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,96,157,32,0,112,106,32,0,216,84,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,157,32,0,240,58,32,0,184,4,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,157,32,0,216,236,31,0,216,215,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,157,32,0,16,198,31,0,16,175,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,157,32,0,96,157,31,0,208,138,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,157,32,0,112,122,31,0,168,107,31,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,157,32,0,24,86,31,0,32,45,31,0,68,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,192,27,31,0,48,15,31,0,76,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,192,27,31,0,192,104,33,0,24,0,31,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,27,31,0,216,239,30,0,72,226,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,27,31,0,240,212,30,0,24,198,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,27,31,0,160,182,30,0,64,163,30,0,80,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,232,124,30,0,160,109,30,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,32,97,30,0,160,109,30,0,88,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,88,83,30,0,184,66,30,0,104,0,0,0,3,0,0,0,0,0,0,0,0,0,40,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,176,55,30,0,192,44,30,0,112,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,216,34,30,0,152,27,30,0,176,14,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,34,30,0,152,237,29,0,56,228,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,34,30,0,40,220,29,0,48,211,29,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,34,30,0,128,202,29,0,240,193,29,0,116,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,72,186,29,0,152,27,30,0,216,178,29,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,72,186,29,0,96,157,31,0,24,171,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,72,186,29,0,24,159,29,0,176,128,29,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,72,186,29,0,104,120,29,0,224,112,29,0,120,0,0,0,1,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,40,106,29,0,48,99,29,0,124,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,216,93,29,0,32,87,29,0,128,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,240,80,29,0,128,73,29,0,132,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,232,63,29,0,216,38,29,0,136,0,0,0,1,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,247,32,0,108,0,0,0,96,81,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,2,56,18,26,34,27,35,28,36,29,45,7,54,39,8,24,25,33,41,11,42,12,43,13,44,14,53,15,62,47,16,32,40,10,49,4,50,5,51,6,52,22,61,38,23,55,1,17,48,3,57,19,58,20,59,21,60,37,30,46,31,63,0,0,0,0,0,0,0,0,0,8,16,1,9,24,32,17,2,25,40,48,56,33,10,3,18,41,49,57,26,11,4,19,34,42,50,58,27,12,5,20,35,43,51,59,28,13,6,21,36,44,52,60,29,14,22,37,45,53,61,30,7,15,38,46,54,62,23,31,39,47,55,63,0,0,0,0,0,0,0,0,0,4,1,8,12,5,9,13,2,6,10,14,3,7,11,15,0,0,0,0,0,0,0,0,80,214,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,34,33,0,176,255,31,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,144,40,31,0,32,122,30,0,200,235,29,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,40,31,0,40,127,29,0,128,37,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,40,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,214,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,249,32,0,108,0,0,0,16,89,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,6,2,9,2,14,2,0,0,0,0,1,5,6,7,8,9,9,11,5,5,7,8,9,9,11,12,6,7,8,9,9,11,11,12,7,7,8,9,9,11,12,13,7,8,9,9,10,11,13,16,8,9,9,10,11,13,16,19,8,9,9,11,12,15,18,23,9,9,11,12,15,18,23,27,1,2,2,2,3,3,3,4,2,2,2,3,3,3,4,4,2,2,3,3,3,4,4,4,2,2,3,3,3,4,4,5,2,3,3,3,4,4,5,6,3,3,3,4,4,5,6,7,3,3,3,4,4,5,7,7,3,3,4,4,5,7,7,7,0,0,1,70,73,67,86,0,222,235,243,248,251,253,254,255,0,1,2,3,5,8,13,21,80,165,32,0,160,140,32,0,0,0,0,0,0,0,0,0,160,115,32,0,108,0,0,0,192,133,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,197,30,0,172,9,0,0,56,6,71,0,100,66,52,0,0,0,0,0,0,0,0,0,204,1,0,0,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,215,35,60,214,185,114,187,111,18,3,187,57,142,227,187,137,98,241,186,171,170,42,61,0,0,0,0,0,0,0,0,171,170,170,188,136,69,74,188,0,0,0,62,73,146,100,61,34,115,7,61,162,188,134,188,40,176,31,188,0,0,32,62,0,0,128,61,38,180,23,61,205,204,204,187,214,185,114,187,38,100,76,62,0,0,160,61,47,161,61,61,9,242,20,59,39,135,176,58,205,204,76,62,0,0,128,61,38,180,23,61,171,170,170,60,214,185,242,59,82,223,89,62,57,142,99,61,5,217,6,61,171,170,170,60,136,69,74,60,212,155,94,62,124,240,65,61,166,218,229,60,228,56,14,61,71,143,168,60,212,155,94,62,228,56,14,61,71,143,168,60,124,240,65,61,166,218,229,60,82,223,89,62,171,170,170,60,136,69,74,60,57,142,99,61,5,217,6,61,205,204,76,62,171,170,170,60,214,185,242,59,0,0,128,61,38,180,23,61,38,100,76,62,9,242,20,59,39,135,176,58,0,0,160,61,47,161,61,61,0,0,32,62,205,204,204,187,214,185,114,187,0,0,128,61,38,180,23,61,0,0,0,62,162,188,134,188,40,176,31,188,73,146,100,61,34,115,7,61,171,170,42,61,171,170,170,188,136,69,74,188,0,0,0,0,0,0,0,0,10,215,35,60,57,142,227,187,137,98,241,186,214,185,114,187,111,18,3,187,10,215,163,59,10,215,163,188,205,204,76,60,202,38,155,190,111,18,3,59,85,85,213,61,10,215,35,61,205,204,204,188,137,136,8,61,10,215,163,188,0,0,0,62,10,215,35,60,161,14,106,60,205,204,76,189,10,215,163,188,0,0,32,62,10,215,35,186,46,116,1,186,10,215,35,186,46,116,1,186,0,0,32,62,10,215,35,186,46,116,1,186,10,215,35,186,46,116,1,186,0,0,0,62,205,204,76,189,10,215,163,188,10,215,35,60,161,14,106,60,85,85,213,61,137,136,8,61,10,215,163,188,10,215,35,61,205,204,204,188,10,215,163,59,202,38,155,190,111,18,3,59,10,215,163,188,205,204,76,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,73,18,62,0,0,0,62,161,14,234,188,37,73,18,189,171,170,170,60,140,46,58,62,241,240,112,61,137,136,8,61,65,76,174,60,10,215,35,60,140,46,58,62,65,76,174,60,10,215,35,60,241,240,112,61,137,136,8,61,37,73,18,62,37,73,18,189,171,170,170,60,0,0,0,62,161,14,234,188,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,4,53,62,115,130,218,62,123,130,26,63,123,130,90,63,122,130,154,63,0,128,215,63,0,0,24,64,0,128,87,64,0,0,152,64,0,128,215,64,0,0,24,65,0,128,87,65,0,0,152,65,0,128,215,65,0,0,24,66,0,128,87,66,0,0,152,66,0,128,215,66,0,0,24,67,0,128,87,67,0,0,152,67,0,128,215,67,0,0,24,68,0,128,87,68,0,0,152,68,0,128,215,68,0,0,24,69,0,128,87,69,0,0,152,69,0,128,215,69,0,0,24,70,0,128,87,70,0,0,152,70,0,128,215,70,0,0,24,71,0,128,87,71,0,0,152,71,0,128,215,71,0,0,24,72,0,128,87,72,0,0,152,72,0,128,215,72,0,0,24,73,0,128,87,73,0,0,152,73,0,128,215,73,0,0,24,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,63,0,128,87,63,0,0,152,63,0,128,215,63,0,0,24,64,0,128,87,64,0,0,152,64,0,128,215,64,0,0,24,65,0,128,87,65,0,0,152,65,0,128,215,65,0,0,24,66,0,128,87,66,0,0,152,66,0,128,215,66,0,0,24,67,0,128,87,67,0,0,152,67,0,128,215,67,0,0,24,68,0,128,87,68,0,0,152,68,0,128,215,68,0,0,24,69,0,128,87,69,0,0,152,69,0,128,215,69,0,0,24,70,0,128,87,70,0,0,152,70,0,128,215,70,0,0,24,71,0,128,87,71,0,0,152,71,0,128,215,71,0,0,24,72,0,128,87,72,0,0,152,72,0,128,215,72,0,0,24,73,0,128,87,73,0,0,152,73,0,128,215,73,0,0,24,74,0,128,87,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,104,29,60,16,229,27,61,60,147,172,61,28,246,21,62,78,140,99,62,118,8,158,62,145,14,206,62,1,0,0,63,185,248,24,63,198,251,48,63,238,28,71,63,122,130,90,63,153,109,106,63,176,65,118,63,96,138,125,63,0,0,128,63,95,138,125,63,175,65,118,63,152,109,106,63,120,130,90,63,236,28,71,63,196,251,48,63,183,248,24,63,0,0,0,63,144,14,206,62,117,8,158,62,76,140,99,62,26,246,21,62,56,147,172,61,8,229,27,61,32,104,29,60,16,229,27,61,28,246,21,62,118,8,158,62,1,0,0,63,198,251,48,63,122,130,90,63,176,65,118,63,0,0,128,63,175,65,118,63,120,130,90,63,196,251,48,63,0,0,0,63,117,8,158,62,26,246,21,62,8,229,27,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,246,21,62,1,0,0,63,122,130,90,63,0,0,128,63,120,130,90,63,0,0,0,63,26,246,21,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,0,0,128,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,2,0,1,13,21,5,9,3,0,0,0,0,0,0,0,6,2,2,4,4,6,5,4,2,0,0,0,0,0,0,0,62,1,0,2,6,14,30,0,6,1,2,3,4,5,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,36,15,1,0,2,0,0,0,6,0,5,0,7,0,12,0,11,0,20,0,19,0,4,0,3,0,35,0,100,0,164,0,36,0,36,1,36,3,36,7,12,3,3,3,3,3,3,4,4,5,5,6,6,6,7,8,9,10,11,12,0,0,0,0,198,30,6,0,194,0,66,1,66,2,70,2,198,0,70,0,66,0,70,1,162,0,98,0,38,0,22,0,14,0,5,0,4,0,3,0,0,0,1,0,10,0,18,0,2,0,34,0,198,1,198,2,198,6,198,14,13,7,8,9,10,10,10,10,10,9,8,7,6,5,4,3,3,2,3,3,4,5,7,8,9,11,12,13,0,0,0,0,56,0,0,0,168,0,0,0,96,1,0,0,84,0,0,0,40,1,0,0,10,0,0,0,94,0,0,0,0,1,0,0,94,1,0,0,24,1,0,0,250,0,0,0,46,0,0,0,108,0,0,0,38,1,0,0,190,0,0,0,0,0,0,0,182,0,0,0,184,0,0,0,102,0,0,0,90,0,0,0,76,1,0,0,152,0,0,0,48,1,0,0,106,0,0,0,176,0,0,0,44,1,0,0,110,1,0,0,14,0,0,0,56,1,0,0,238,0,0,0,224,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,254,255,255,255,0,0,0,0,0,0,0,0,16,195,30,0,108,0,0,0,0,45,80,0,100,66,52,0,0,0,0,0,0,0,0,0,214,2,0,0,196,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,152,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,113,33,0,108,0,0,0,104,158,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,152,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,65,32,0,108,0,0,0,80,165,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,127,33,0,120,64,35,0,0,0,0,0,82,0,0,0,0,0,0,0,0,0,0,0,208,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,0,0,0,0,0,0,0,14,1,0,0,0,0,0,0,208,9,0,0,0,0,0,0,0,0,0,0,128,127,33,0,208,64,35,0,0,0,0,0,82,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,6,0,0,0,0,0,0,0,0,0,0,240,1,0,0,112,0,0,0,0,0,0,0,0,0,0,0,200,144,34,0,200,110,35,0,0,0,0,0,55,0,0,0,0,0,0,0,0,0,0,0,136,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,208,1,0,0,0,0,0,0,110,9,0,0,0,0,0,0,0,0,0,0,168,91,33,0,184,46,32,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,5,0,0,0,0,0,0,0,0,0,0,220,2,0,0,154,2,0,0,0,0,0,0,0,0,0,0,0,1,8,16,9,2,3,10,17,24,32,25,18,11,4,5,12,19,26,33,40,48,41,34,27,20,13,6,7,14,21,28,35,42,49,56,57,50,43,36,29,22,15,23,30,37,44,51,58,59,52,45,38,31,39,46,53,60,61,54,47,55,62,63,0,8,1,9,16,24,2,10,17,25,32,40,48,56,33,41,18,26,3,11,4,12,19,27,34,42,49,57,50,58,35,43,20,28,5,13,6,14,21,29,36,44,51,59,52,60,37,45,22,30,7,15,23,31,38,46,53,61,54,62,39,47,55,63,184,127,33,0,232,64,35,0,0,0,0,0,162,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,9,0,0,0,0,0,0,0,0,0,0,70,1,0,0,148,6,0,0,0,0,0,0,0,0,0,0,96,127,33,0,88,64,35,0,0,0,0,0,86,50,49,48,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,7,0,0,0,0,0,0,0,0,0,0,164,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,241,35,0,64,169,35,0,0,0,0,0,160,126,33,0,0,0,0,0,14,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,66,4,0,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,241,35,0,64,169,35,0,0,0,0,0,160,126,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,8,0,0,186,3,0,0,182,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,128,33,0,8,65,35,0,0,0,0,0,52,86,85,89,0,0,0,0,0,0,0,0,216,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,1,0,0,0,0,0,0,42,0,0,0,0,0,0,0,100,5,0,0,0,0,0,0,0,0,0,0,64,128,33,0,40,65,35,0,0,0,0,0,52,86,85,89,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,6,0,0,0,0,0,0,0,0,0,0,132,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,1,0,213,28,2,0,130,54,0,0,87,136,0,0,0,203,1,0,213,28,2,0,130,54,0,0,87,136,0,0,149,152,1,0,105,4,2,0,75,100,0,0,31,208,0,0,149,152,1,0,105,4,2,0,75,100,0,0,31,208,0,0,0,152,1,0,190,6,2,0,183,96,0,0,117,207,0,0,149,152,1,0,105,4,2,0,75,100,0,0,31,208,0,0,149,152,1,0,105,4,2,0,75,100,0,0,31,208,0,0,75,203,1,0,38,20,2,0,11,66,0,0,231,138,0,0,88,242,35,0,80,169,35,0,0,1,0,0,88,242,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,76,4,0,0,40,8,0,0,112,0,0,0,156,2,0,0,198,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,128,33,0,72,65,35,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,9,0,0,0,0,0,0,0,0,0,0,130,2,0,0,198,0,0,0,0,0,0,0,0,0,0,0,168,128,33,0,128,65,35,0,0,0,0,0,80,49,52,89,0,0,0,0,0,0,0,0,224,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,1,0,0,0,0,0,0,40,1,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,0,0,176,128,33,0,160,65,35,0,0,0,0,0,80,49,52,89,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,7,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,243,35,0,96,169,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,136,10,0,0,212,10,0,0,158,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,129,33,0,0,66,35,0,0,0,0,0,159,0,0,0,0,0,0,0,0,0,0,0,232,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,129,33,0,32,66,35,0,0,0,0,0,159,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,129,33,0,64,66,35,0,3,0,0,0,3,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,4,0,0,180,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,129,33,0,88,66,35,0,3,0,0,0,3,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,4,0,0,0,0,0,0,0,0,0,0,98,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,172,28,0,144,154,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,116,1,0,0,160,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1067500);
/* memory initializer */ allocate([128,1,0,0,252,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,129,33,0,96,66,35,0,0,0,0,0,60,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,9,0,0,0,0,0,0,0,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,255,0,0,0,251,0,0,0,0,0,0,0,4,0,0,0,251,0,0,0,1,0,0,0,255,0,0,0,200,0,0,0,0,0,0,0,55,0,0,0,200,0,0,0,33,0,0,0,223,0,0,0,159,0,0,0,0,0,0,0,64,0,0,0,159,0,0,0,131,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,125,0,0,0,131,0,0,0,0,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,38,0,0,0,38,0,0,0,13,0,0,0,152,0,0,0,38,0,0,0,76,0,0,0,13,0,0,0,165,0,0,0,13,0,0,0,178,0,0,0,6,0,0,0,230,0,0,0,38,0,0,0,114,0,0,0,13,0,0,0,191,0,0,0,13,0,0,0,204,0,0,0,6,0,0,0,236,0,0,0,13,0,0,0,217,0,0,0,6,0,0,0,242,0,0,0,5,0,0,0,248,0,0,0,3,0,0,0,253,0,0,0,248,129,33,0,112,66,35,0,0,0,0,0,67,65,70,88,0,0,0,0,0,0,0,0,64,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,6,0,0,0,0,0,0,36,2,0,0,0,0,0,0,96,2,0,0,0,0,0,0,0,0,0,0,8,130,33,0,128,66,35,0,0,0,0,0,67,65,70,88,0,0,0,0,0,0,0,0,72,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,2,0,0,0,0,0,0,0,0,0,0,94,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,130,33,0,176,66,35,0,0,0,0,0,161,0,0,0,0,0,0,0,0,0,0,0,80,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,130,33,0,200,66,35,0,0,0,0,0,161,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,10,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,205,31,0,104,6,31,0,0,0,0,0,0,0,0,0,0,0,0,0,168,245,35,0,0,0,0,0,0,0,0,0,32,0,0,0,20,9,0,0,118,3,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,121,33,0,136,71,32,0,0,0,0,0,78,73,66,88,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,5,0,0,0,0,0,0,0,0,0,0,214,0,0,0,250,8,0,0,0,0,0,0,0,0,0,0,224,128,33,0,224,65,35,0,0,0,0,0,42,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,0,0,0,0,0,0,0,0,0,0,0,226,2,0,0,98,1,0,0,0,0,0,0,0,0,0,0,128,130,33,0,224,66,35,0,0,0,0,0,41,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,4,0,0,0,0,0,0,0,0,0,0,160,2,0,0,170,4,0,0,0,0,0,0,0,0,0,0,40,16,30,0,72,160,29,0,1,0,0,0,2,64,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,6,0,0,0,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,172,28,0,176,154,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,2,0,0,0,238,10,0,0,88,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,172,28,0,208,154,33,0,8,95,32,0,208,172,28,0,25,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,12,0,0,0,218,1,0,0,214,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,173,28,0,16,155,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,0,0,0,174,3,0,0,132,0,0,0,110,1,0,0,0,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,174,28,0,72,155,33,0,0,0,0,0,16,174,28,0,3,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,192,243,35,0,0,0,0,0,0,0,0,0,80,2,0,0,26,0,0,0,46,1,0,0,44,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,183,216,0,32,55,73,218,17,166,78,0,7,233,94,173,141,88,178,28,0,120,156,33,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,224,1,0,0,104,8,0,0,100,1,0,0,128,5,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,178,28,0,176,156,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,44,3,0,0,216,4,0,0,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,178,28,0,248,156,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,7,0,0,14,6,0,0,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,130,33,0,0,67,35,0,1,0,0,0,17,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,9,0,0,0,0,0,0,0,0,0,0,156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,130,33,0,24,67,35,0,0,0,0,0,74,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,6,0,0,0,0,0,0,0,0,0,0,242,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,58,31,0,40,136,30,0,0,0,0,0,152,0,0,0,2,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,8,0,0,0,0,0,0,0,0,0,0,224,1,0,0,122,10,0,0,126,0,0,0,0,0,0,0,112,63,33,0,160,21,32,0,0,0,0,0,72,0,0,0,34,0,0,0,0,0,0,0,72,61,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,145,8,0,168,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,8,0,0,0,0,0,0,0,0,0,0,224,1,0,0,122,10,0,0,164,0,0,0,0,0,0,0,0,2,4,8,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,19,20,20,21,21,0,8,1,16,9,24,17,2,32,10,25,40,18,48,33,26,56,41,34,3,49,57,11,42,19,50,27,58,35,43,51,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,8,3,9,10,16,4,11,17,24,18,12,5,19,25,13,20,26,27,6,21,28,14,22,29,7,30,15,23,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,1,3,0,152,253,2,0,152,249,2,0,192,42,17,0,176,244,29,0,152,134,29,0,0,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,88,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,7,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,56,44,29,0,232,219,28,0,0,0,0,0,19,0,0,0,3,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,8,0,0,0,0,0,0,0,0,0,0,68,1,0,0,128,6,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,8,8,8,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,19,20,20,21,21,0,8,1,2,9,16,24,17,10,3,4,11,18,25,32,40,48,56,41,33,26,19,12,5,6,13,20,27,34,49,57,58,50,42,35,28,21,14,7,15,22,29,36,43,51,59,60,52,44,37,30,23,31,38,45,53,61,62,54,46,39,47,55,63,0,8,1,2,9,16,24,17,10,3,4,11,18,25,32,40,33,48,26,19,12,5,6,13,20,27,34,41,56,49,57,42,35,28,21,14,7,15,22,29,36,43,50,58,51,59,44,37,30,23,31,38,45,52,60,53,61,46,39,47,54,62,55,63,0,1,8,2,3,9,16,24,17,10,4,5,11,18,25,32,40,48,33,26,19,12,6,7,13,20,27,34,41,56,49,57,42,35,28,21,14,15,22,29,36,43,50,58,51,44,37,30,23,31,38,45,52,59,60,53,46,39,47,54,61,62,55,63,0,8,16,1,24,32,40,9,2,3,10,17,25,48,56,41,33,26,18,11,4,5,12,19,27,34,49,57,50,42,35,28,20,13,6,7,14,21,29,36,43,51,58,59,52,44,37,30,22,15,23,31,38,45,60,53,46,39,47,54,61,62,55,63,80,41,29,0,64,33,29,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,136,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,66,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,48,216,30,0,200,200,30,0,0,0,0,0,18,0,0,0,3,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,0,0,0,0,0,0,0,0,0,0,68,1,0,0,164,9,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,19,20,20,21,21,22,160,132,33,0,224,67,35,0,1,0,0,0,37,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,1,0,0,74,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,92,8,0,0,36,0,0,0,0,0,0,0,40,61,33,0,64,19,32,0,1,0,0,0,8,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,3,0,0,0,0,0,0,246,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,48,61,33,0,88,19,32,0,1,0,0,0,8,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,5,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,1,0,0,130,0,0,0,0,0,0,0,128,134,33,0,112,68,35,0,1,0,0,0,7,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,3,0,0,0,0,0,0,246,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,248,134,33,0,136,68,35,0,1,0,0,0,7,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,5,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,1,0,0,130,0,0,0,0,0,0,0,40,133,33,0,8,68,35,0,1,0,0,0,38,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,35,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,8,0,0,0,0,0,0,0,0,0,0,82,0,0,0,38,5,0,0,28,0,0,0,0,0,0,0,48,134,33,0,48,68,35,0,1,0,0,0,39,80,1,0,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,123,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,4,0,0,0,0,0,0,0,0,0,0,72,1,0,0,206,1,0,0,68,0,0,0,0,0,0,0,202,96,254,63,119,94,253,63,165,99,252,63,168,54,251,63,45,166,249,63,97,120,247,63,225,30,244,63,52,83,238,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,126,252,63,136,252,250,63,229,147,249,63,103,18,248,63,216,107,246,63,57,126,244,63,166,55,242,63,64,141,239,63,51,62,236,63,105,35,232,63,139,90,227,63,144,199,221,63,12,236,214,63,18,7,206,63,220,15,193,63,223,100,170,63,244,86,243,63,144,178,238,63,245,198,234,63,153,157,230,63,182,28,226,63,116,52,221,63,247,174,215,63,192,149,209,63,204,225,202,63,63,76,194,63,8,233,183,63,237,116,171,63,15,242,158,63,152,177,143,63,221,173,119,63,69,144,61,63,247,124,226,63,17,208,214,63,58,187,204,63,187,142,196,63,59,195,188,63,191,191,180,63,22,44,172,63,156,254,162,63,121,181,152,63,218,127,140,63,214,249,124,63,62,85,95,63,149,98,62,63,173,1,25,63,253,5,221,62,175,21,56,62,154,150,183,63,84,2,169,63,142,249,154,63,50,138,141,63,19,184,128,63,141,66,103,63,131,235,77,63,74,4,53,63,179,177,26,63,69,12,255,62,57,43,197,62,109,201,138,62,45,136,19,62,199,30,16,59,244,67,43,190,222,28,189,190,163,187,127,63,142,133,87,63,44,33,53,63,171,61,20,63,171,236,240,62,87,69,189,62,57,90,137,62,197,192,47,62,188,160,147,61,108,234,250,188,116,63,179,191,10,169,128,190,13,137,190,190,239,192,2,191,174,28,38,191,172,150,77,191,28,194,135,62,49,77,129,61,64,179,181,189,175,25,88,190,166,19,159,190,203,41,203,190,192,200,241,190,249,170,10,191,109,76,29,191,182,126,48,191,155,11,68,191,17,9,90,191,164,240,115,191,189,86,136,191,243,64,154,191,149,38,176,191,81,22,10,191,132,218,60,191,32,94,98,191,83,110,129,191,86,35,145,191,174,87,162,191,81,208,181,191,70,103,207,191,215,0,141,191,214,34,149,191,28,223,157,191,49,238,166,191,132,53,176,191,17,249,187,191,210,194,201,191,181,159,213,191,105,164,197,190,74,98,15,191,5,119,43,191,5,162,66,191,91,165,86,191,79,159,104,191,226,93,121,191,196,186,132,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,151,221,199,191,138,104,212,191,245,10,221,191,109,168,227,191,72,56,233,191,152,92,238,191,65,144,243,191,198,94,249,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,231,2,1,0,205,5,93,0,201,5,94,0,3,0,22,0,11,0,1,0,6,0,1,0,6,0,4,0,5,0,4,0,7,0,3,0,7,0,4,0,10,0,10,0,2,0,3,0,0,0,5,0,2,0,95,0,4,0,3,0,2,0,200,5,184,0,202,5,203,5,204,5,0,0,0,0,0,0,10,12,10,13,9,13,9,8,7,5,5,4,4,3,3,3,4,3,4,4,5,5,6,8,7,10,8,10,9,8,9,9,13,10,13,13,13,0,0,0,100,0,200,0,44,1,144,1,254,1,118,2,2,3,152,3,56,4,246,4,200,5,184,6,208,7,16,9,140,10,78,12,116,14,48,17,180,20,0,25,20,30,28,37,224,46,140,60,180,95,0,0,0,0,0,0,112,179,28,0,32,157,33,0,0,97,32,0,56,116,31,0,0,0,0,0,0,0,0,0,84,84,86,87,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,5,0,0,186,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,180,28,0,104,157,33,0,0,0,0,0,64,97,32,0,0,0,0,0,48,226,0,0,0,0,0,0,0,0,0,0,28,0,0,0,46,0,0,0,4,6,0,0,116,0,0,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,168,135,33,0,184,68,35,0,3,0,0,0,84,84,86,87,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,5,0,0,0,0,0,0,0,0,0,0,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,136,33,0,232,68,35,0,0,0,0,0,80,66,69,87,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,2,0,0,120,3,0,0,0,0,0,0,0,0,0,0,0,238,30,0,0,66,30,0,112,201,29,0,0,238,30,0,5,80,1,0,141,0,0,0,84,84,86,87,64,4,3,0,0,0,0,0,96,226,0,0,0,0,0,0,224,0,0,0,14,9,0,0,84,2,0,0,158,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,180,28,0,160,157,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,98,6,0,0,178,1,0,0,44,3,0,0,68,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,136,33,0,248,68,35,0,1,0,0,0,25,80,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,250,35,0,0,0,0,0,0,0,0,0,144,226,0,0,0,0,0,0,232,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,3,0,0,0,0,0,0,116,0,0,0,0,0,0,0,202,3,0,0,0,0,0,0,0,0,0,0,216,136,33,0,0,69,35,0,1,0,0,0,25,80,1,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,0,0,0,0,0,0,0,0,0,0,0,244,2,0,0,44,2,0,0,202,0,0,0,0,0,0,0,144,183,28,0,240,158,33,0,48,98,32,0,144,183,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,208,243,35,0,8,227,0,0,0,0,0,0,64,0,0,0,6,8,0,0,140,1,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,185,28,0,192,159,33,0,0,1,0,0,0,0,0,0,216,243,35,0,96,227,0,0,0,0,0,0,0,0,0,0,80,0,0,0,72,7,0,0,40,6,0,0,126,1,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,116,31,0,192,190,30,0,0,0,0,0,216,116,31,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,216,245,35,0,0,0,0,0,0,0,0,0,64,0,0,0,126,10,0,0,140,1,0,0,228,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,97,118,101,243,172,211,17,140,209,0,192,79,142,219,138,188,148,95,146,90,82,210,17,134,220,0,192,79,142,219,138,114,105,102,102,46,145,207,17,165,214,40,219,4,193,0,0,102,109,116,32,243,172,211,17,140,209,0,192,79,142,219,138,102,97,99,116,243,172,211,17,140,209,0,192,79,142,219,138,100,97,116,97,243,172,211,17,140,209,0,192,79,142,219,138,136,98,32,0,248,116,31,0,0,1,0,0,0,0,0,0,16,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,0,0,118,5,0,0,248,1,0,0,126,1,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,225,29,0,240,116,29,0,0,0,0,0,128,175,26,0,16,223,2,0,0,0,0,0,118,7,0,0,0,0,0,0,102,1,0,0,234,7,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,27,35,0,248,214,34,0,0,0,0,0,88,165,6,0,8,165,6,0,0,0,0,0,180,8,0,0,0,0,0,0,102,1,0,0,138,7,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,35,0,56,117,35,0,0,0,0,0,88,165,6,0,208,165,6,0,0,0,0,0,64,5,0,0,0,0,0,0,102,1,0,0,138,7,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,30,29,0,184,204,28,0,0,0,0,0,248,175,26,0,88,91,8,0,0,0,0,0,212,8,0,0,0,0,0,0,102,1,0,0,46,8,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,23,31,0,56,105,30,0,0,0,0,0,72,157,9,0,192,157,9,0,0,0,0,0,90,9,0,0,0,0,0,0,102,1,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,170,31,0,80,200,34,0,0,0,0,0,144,116,10,0,184,121,10,0,0,0,0,0,40,3,0,0,0,0,0,0,34,1,0,0,30,1,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,179,31,0,184,202,34,0,0,0,0,0,104,252,12,0,16,0,13,0,0,0,0,0,136,3,0,0,0,0,0,0,122,1,0,0,74,5,0,0,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,249,32,0,176,228,31,0,0,0,0,0,176,252,14,0,120,254,14,0,0,0,0,0,230,8,0,0,0,0,0,0,102,1,0,0,100,8,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,157,31,0,48,198,34,0,0,0,0,0,112,192,21,0,200,194,21,0,0,0,0,0,72,4,0,0,0,0,0,0,102,1,0,0,120,7,0,0,152,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,248,188,31,0,224,204,34,0,0,0,0,0,160,228,22,0,120,232,22,0,0,0,0,0,234,5,0,0,0,0,0,0,200,0,0,0,134,9,0,0,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,133,35,0,128,107,33,0,0,0,0,0,112,176,26,0,152,161,25,0,0,0,0,0,246,3,0,0,0,0,0,0,108,1,0,0,158,1,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,190,31,0,120,205,34,0,232,176,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,113,33,0,48,67,29,0,24,104,16,0,0,0,0,0,144,104,16,0,0,0,0,0,0,0,0,0,0,0,0,0,148,0,0,0,200,8,0,0,72,0,0,0,0,0,0,0,0,0,0,0,92,2,0,0,0,97,35,0,48,67,29,0,96,177,26,0,0,0,0,0,200,158,25,0,0,0,0,0,0,0,0,0,0,0,0,0,148,0,0,0,200,8,0,0,72,0,0,0,0,0,0,0,0,0,0,0,92,2,0,0,216,187,28,0,152,161,33,0,0,0,0,0,192,99,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,72,1,0,0,52,9,0,0,220,1,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,137,33,0,8,69,35,0,0,0,0,0,45,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,7,0,0,0,0,0,0,0,0,0,0,94,1,0,0,94,2,0,0,0,0,0,0,0,0,0,0,24,188,28,0,216,161,33,0,0,0,0,0,208,99,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,82,0,0,0,144,2,0,0,52,1,0,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,48,72,33,0,248,26,32,0,3,0,0,0,114,108,80,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,149,1,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,3,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,137,33,0,96,69,35,0,0,0,0,0,169,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,164,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,3,0,0,0,0,0,0,0,0,0,0,106,0,0,0,210,4,0,0,46,1,0,0,0,0,0,0,24,62,33,0,48,20,32,0,0,0,0,0,141,0,0,0,2,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,8,0,0,0,0,0,0,0,0,0,0,52,2,0,0,184,4,0,0,110,0,0,0,0,0,0,0,240,237,1,0,232,237,1,0,224,237,1,0,208,237,1,0,160,89,29,0,5,0,0,0,0,0,0,0,6,2,0,0,134,1,0,0,148,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,32,62,33,0,56,20,32,0,0,0,0,0,93,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,4,0,0,0,0,0,0,0,0,0,0,124,0,0,0,82,4,0,0,0,0,0,0,0,0,0,0,40,57,31,0,152,134,30,0,0,0,0,0,107,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,4,0,0,0,0,0,0,0,0,0,0,124,0,0,0,82,4,0,0,0,0,0,0,0,0,0,0,40,138,33,0,168,69,35,0,0,0,0,0,92,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,4,0,0,0,0,0,0,0,0,0,0,124,0,0,0,82,4,0,0,0,0,0,0,0,0,0,0,160,139,33,0,232,69,35,0,0,0,0,0,91,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,5,0,0,0,0,0,0,0,0,0,0,124,0,0,0,176,7,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,8,0,4,1,2,2,0,0,255,0,2,3,254,0,253,0,4,4,2,5,252,0,251,0,2,6,250,0,249,0,0,0,9,15,32,25,7,19,9,21,1,12,14,12,3,18,14,23,3,10,0,4,41,22,1,0,1,31,0,0,0,0,0,1,1,7,0,1,98,25,4,10,2,3,2,3,0,2,0,2,0,0,11,4,1,4,0,2,3,2,0,4,48,39,1,2,11,27,29,44,7,27,1,4,0,3,1,6,1,2,0,0,123,37,6,4,1,27,0,0,0,0,5,8,1,7,0,1,12,10,0,2,49,46,3,4,7,31,42,41,0,0,2,6,1,7,1,4,2,4,0,1,21,32,1,2,4,10,32,43,6,23,2,3,1,19,1,6,12,21,0,7,26,14,14,12,0,24,0,0,0,0,55,17,1,9,0,36,5,7,1,3,26,25,1,1,2,10,67,39,0,0,1,1,0,14,0,2,31,26,1,6,69,83,0,0,0,2,10,29,3,12,0,1,0,3,0,3,2,2,0,0,209,5,0,0,0,27,0,0,0,0,0,1,0,1,0,1,0,0,0,0,103,46,1,2,2,10,33,42,0,0,1,4,0,3,0,1,1,3,0,0,11,20,1,4,18,36,43,48,13,35,0,2,0,5,3,12,1,2,0,0,2,5,4,5,0,121,0,0,0,0,0,3,2,4,1,4,2,2,0,1,14,31,9,13,14,54,22,29,0,0,2,6,4,18,6,13,1,5,0,1,70,44,0,1,2,10,37,46,8,26,0,2,0,2,0,2,0,1,0,0,175,5,0,1,0,48,0,0,0,0,0,2,0,1,0,2,0,1,0,0,85,39,0,0,1,9,69,40,0,0,0,1,0,3,0,1,2,3,0,0,8,15,0,1,8,21,74,53,22,42,0,1,0,2,0,3,1,2,0,0,83,5,2,3,0,102,0,0,0,0,1,3,0,2,0,1,0,0,0,0,31,28,0,0,3,14,130,34,0,0,0,1,0,3,0,1,3,3,0,1,141,42,0,0,1,4,11,24,1,11,0,1,0,1,0,2,0,0,0,0,233,6,0,0,0,8,0,0,0,0,0,1,0,1,0,0,0,1,0,0,171,25,0,0,1,5,25,21,0,0,0,1,0,1,0,0,0,0,0,0,8,19,4,10,24,45,21,37,9,29,0,3,1,7,11,25,0,2,0,1,34,16,112,21,1,28,0,0,0,0,6,8,1,7,0,3,2,5,0,2,17,21,68,29,6,15,13,22,0,0,6,12,3,14,4,10,1,7,0,3,46,42,0,1,2,10,54,51,10,30,0,2,0,2,0,1,0,1,0,0,159,35,2,2,0,25,0,0,0,0,3,6,0,5,0,1,4,4,0,1,51,39,0,1,2,12,91,44,0,0,0,2,0,3,0,1,2,3,0,1,28,32,0,0,3,10,75,51,14,33,0,1,0,2,0,1,1,2,0,0,75,39,5,7,2,48,0,0,0,0,3,11,2,16,1,4,7,10,0,2,81,25,0,0,2,9,106,26,0,0,0,1,0,1,0,1,1,1,0,0,100,46,0,1,3,9,21,37,5,20,0,1,0,2,1,2,0,1,0,0,212,21,0,1,0,9,0,0,0,0,1,2,0,2,0,0,2,2,0,0,140,37,0,1,1,8,24,33,0,0,1,2,0,2,0,1,1,2,0,0,27,29,0,1,9,25,53,51,12,34,0,1,0,3,1,5,0,2,0,0,4,2,0,0,0,172,0,0,0,0,0,1,0,2,0,0,2,0,0,0,14,23,1,3,11,53,90,31,0,0,0,3,1,5,2,6,1,2,0,0,80,38,0,0,1,4,69,33,5,16,0,1,0,1,0,0,0,1,0,0,187,22,1,1,0,17,0,0,0,0,3,6,0,4,0,1,4,4,0,1,123,29,0,0,1,7,57,30,0,0,0,1,0,1,0,1,0,1,0,0,16,20,0,0,2,8,104,49,15,33,0,1,0,1,0,1,1,1,0,0,133,6,1,2,1,70,0,0,0,0,0,2,0,4,0,3,1,1,0,0,13,14,0,0,4,20,175,20,0,0,0,1,0,1,0,1,1,1,0,0,194,16,0,0,1,1,1,9,1,3,0,0,0,1,0,1,0,0,0,0,251,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,23,0,0,1,3,2,9,0,0,0,1,0,1,0,1,0,0,0,0,4,0,2,1,248,0,252,0,8,2,6,3,4,4,2,5,232,0,236,0,240,0,244,0,0,0,0,0,0,0,0,0,8,1,4,2,2,4,0,0,254,0,2,5,253,0,252,0,4,3,2,6,255,0,249,0,4,7,2,8,251,0,250,0,2,9,248,0,247,0,0,0,4,6,2,7,0,0,255,0,4,8,2,9,254,0,253,0,2,10,252,0,251,0,0,0,8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,83,199,140,125,104,0,0,14,14,13,13,12,12,10,10,10,10,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,6,6,6,6,6,6,5,5,5,5,4,4,4,4,4,4,4,3,3,3,3,2,69,42,1,2,1,7,44,42,6,22,1,3,0,2,1,5,0,1,0,0,229,8,1,1,0,8,0,0,0,0,1,2,0,1,0,0,1,1,0,0,122,35,1,1,1,6,46,34,0,0,1,2,0,1,0,1,1,1,0,0,0,0,0,0,47,47,47,47,45,43,43,43,43,43,42,41,41,40,40,40,40,35,35,35,35,33,33,33,33,32,32,32,27,27,26,26,25,25,24,24,23,23,19,19,19,19,18,18,17,16,16,16,16,16,15,11,11,11,10,10,9,8,7,5,3,3,2,2,159,0,0,0,0,0,0,0,0,0,0,145,165,0,0,0,0,0,0,0,0,0,140,148,173,0,0,0,0,0,0,0,0,135,140,155,176,0,0,0,0,0,0,0,130,134,141,157,180,0,0,0,0,0,0,129,130,133,140,153,177,196,230,243,254,254,0,0,0,0,0,0,0,1,2,3,4,10,0,0,0,1,2,3,4,5,7,11,19,35,67,0,0,0,0,0,0,255,255,0,255,255,1,255,0,254,254,0,254,255,255,254,1,254,2,255,254,254,2,254,0,0,1,1,2,3,0,0,0,0,0,0,1,2,3,3,3,3,0,0,0,0,0,0,94,92,90,88,86,82,78,74,70,66,62,58,54,53,52,51,50,49,48,47,46,45,44,43,42,40,39,37,36,35,34,33,32,31,30,29,28,27,26,25,24,23,22,21,20,19,18,17,16,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,104,62,33,0,104,20,32,0,0,0,0,0,30,0,0,0,3,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,210,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,8,0,0,0,0,0,0,0,0,0,0,208,2,0,0,10,4,0,0,132,0,0,0,0,0,0,0,88,188,28,0,16,162,33,0,224,99,32,0,32,118,31,0,112,192,30,0,232,32,30,0,184,176,29,0,144,79,29,0,0,0,0,0,0,0,0,0,8,39,1,0,136,93,1,0,136,75,1,0,136,39,1,0,136,94,1,0,136,77,1,0,136,43,1,0,8,231,0,0,62,180,228,51,9,145,243,51,139,178,1,52,60,32,10,52,35,26,19,52,96,169,28,52,167,215,38,52,75,175,49,52,80,59,61,52,112,135,73,52,35,160,86,52,184,146,100,52,85,109,115,52,136,159,129,52,252,11,138,52,147,4,147,52,105,146,156,52,50,191,166,52,63,149,177,52,147,31,189,52,228,105,201,52,173,128,214,52,54,113,228,52,166,73,243,52,136,140,1,53,192,247,9,53,6,239,18,53,118,123,28,53,192,166,38,53,55,123,49,53,218,3,61,53,94,76,73,53,59,97,86,53,185,79,100,53,252,37,115,53,138,121,129,53,134,227,137,53,124,217,146,53,133,100,156,53,82,142,166,53,51,97,177,53,37,232,188,53,220,46,201,53,206,65,214,53,65,46,228,53,87,2,243,53,143,102,1,54,79,207,9,54,245,195,18,54,152,77,28,54,232,117,38,54,50,71,49,54,116,204,60,54,94,17,73,54,101,34,86,54,206,12,100,54,184,222,114,54,151,83,129,54,28,187,137,54,114,174,146,54,175,54,156,54,129,93,166,54,53,45,177,54,199,176,188,54,228,243,200,54,1,3,214,54,96,235,227,54,30,187,242,54,162,64,1,55,235,166,9,55,241,152,18,55,201,31,28,55,30,69,38,55,61,19,49,55,30,149,60,55,111,214,72,55,162,227,85,55,247,201,99,55,137,151,114,55,175,45,129,55,190,146,137,55,116,131,146,55,230,8,156,55,190,44,166,55,71,249,176,55,121,121,188,55,254,184,200,55,71,196,213,55,146,168,227,55,248,115,242,55,192,26,1,56,147,126,9,56,249,109,18,56,6,242,27,56,98,20,38,56,86,223,48,56,216,93,60,56,146,155,72,56,242,164,85,56,51,135,99,56,110,80,114,56,211,7,129,56,107,106,137,56,130,88,146,56,42,219,155,56,9,252,165,56,104,197,176,56,59,66,188,56,41,126,200,56,160,133,213,56,217,101,227,56,232,44,242,56,233,244,0,57,70,86,9,57,14,67,18,57,81,196,27,57,181,227,37,57], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1077740);
/* memory initializer */ allocate([127,171,48,57,162,38,60,57,197,96,72,57,83,102,85,57,131,68,99,57,104,9,114,57,1,226,128,57,36,66,137,57,157,45,146,57,123,173,155,57,99,203,165,57,153,145,176,57,13,11,188,57,102,67,200,57,11,71,213,57,50,35,227,57,237,229,241,57,29,207,0,58,5,46,9,58,48,24,18,58,169,150,27,58,21,179,37,58,183,119,48,58,124,239,59,58,10,38,72,58,199,39,85,58,230,1,99,58,120,194,113,58,59,188,128,58,233,25,137,58,198,2,146,58,219,127,155,58,203,154,165,58,216,93,176,58,239,211,187,58,179,8,200,58,136,8,213,58,159,224,226,58,7,159,241,58,92,169,0,59,208,5,9,59,94,237,17,59,15,105,27,59,132,130,37,59,253,67,48,59,103,184,59,59,97,235,71,59,77,233,84,59,93,191,98,59,156,123,113,59,127,150,128,59,186,241,136,59,249,215,145,59,71,82,155,59,65,106,165,59,39,42,176,59,226,156,187,59,18,206,199,59,23,202,212,59,32,158,226,59,53,88,241,59,166,131,0,60,167,221,8,60,152,194,17,60,130,59,27,60,1,82,37,60,84,16,48,60,97,129,59,60,200,176,71,60,229,170,84,60,232,124,98,60,212,52,113,60,207,112,128,60,150,201,136,60,58,173,145,60,192,36,155,60,197,57,165,60,133,246,175,60,229,101,187,60,130,147,199,60,185,139,212,60,180,91,226,60,121,17,241,60,251,93,0,61,137,181,8,61,223,151,17,61,2,14,27,61,141,33,37,61,185,220,47,61,109,74,59,61,64,118,71,61,145,108,84,61,133,58,98,61,34,238,112,61,42,75,128,61,127,161,136,61,136,130,145,61,72,247,154,61,88,9,165,61,242,194,175,61,248,46,187,61,3,89,199,61,109,77,212,61,92,25,226,61,209,202,240,61,91,56,0,62,119,141,8,62,51,109,17,62,144,224,26,62,39,241,36,62,46,169,47,62,135,19,59,62,202,59,71,62,77,46,84,62,55,248,97,62,132,167,112,62,143,37,128,62,115,121,136,62,226,87,145,62,220,201,154,62,249,216,164,62,109,143,175,62,27,248,186,62,149,30,199,62,51,15,212,62,23,215,225,62,61,132,240,62,198,18,0,63,114,101,8,63,147,66,17,63,43,179,26,63,206,192,36,63,177,117,47,63,178,220,58,63,101,1,71,63,29,240,83,63,251,181,97,63,251,96,112,63,0,0,128,63,88,141,33,0,40,70,35,0,1,0,0,0,5,80,1,0,32,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,6,0,0,0,0,0,0,218,1,0,0,0,0,0,0,46,4,0,0,0,0,0,0,0,0,0,0,112,147,33,0,136,70,35,0,1,0,0,0,5,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,250,35,0,24,157,16,0,0,0,0,0,0,0,0,0,0,0,0,0,52,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,8,0,0,0,0,0,0,0,0,0,0,238,2,0,0,118,6,0,0,62,1,0,0,0,0,0,0,152,190,29,0,7,0,0,0,0,0,0,0,224,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,126,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,55,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,15,7,0,0,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,1,2,3,0,0,0,0,0,2,1,3,4,0,0,0,0,2,1,5,3,4,0,0,0,2,1,6,5,3,4,0,0,2,1,7,5,6,3,4,208,188,28,0,32,162,33,0,32,100,32,0,208,188,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,232,243,35,0,0,0,0,0,0,0,0,0,4,0,0,0,144,3,0,0,80,2,0,0,236,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,114,101,97,116,105,118,101,32,86,111,105,99,101,32,70,105,108,101,26,0,0,0,0,56,100,32,0,80,118,31,0,0,0,0,0,0,0,0,0,240,243,35,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,14,0,0,0,36,10,0,0,60,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,1,0,0,0,0,0,15,16,1,0,1,0,0,0,16,16,1,0,2,0,0,0,17,16,1,0,3,0,0,0,0,0,1,0,4,0,0,0,7,0,1,0,6,0,0,0,6,0,1,0,7,0,0,0,12,16,1,0,0,2,0,0,0,0,0,0,0,0,0,0,96,167,32,0,32,165,31,0,8,0,0,0,248,231,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,3,0,0,28,4,0,0,208,0,0,0,210,2,0,0,126,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,112,152,33,0,8,71,35,0,0,0,0,0,90,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,8,0,0,0,0,0,0,0,0,0,0,108,2,0,0,60,4,0,0,0,0,0,0,0,0,0,0,152,153,33,0,112,71,35,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,7,0,0,0,0,0,0,0,0,0,0,198,2,0,0,150,0,0,0,0,0,0,0,0,0,0,0,40,63,33,0,56,21,32,0,1,0,0,0,11,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,2,0,0,0,0,0,0,0,0,0,0,24,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,255,28,0,0,192,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,3,0,0,220,6,0,0,24,8,0,0,10,3,0,0,34,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,28,0,240,162,33,0,0,0,0,0,112,100,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,150,6,0,0,152,2,0,0,106,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,153,33,0,136,71,35,0,1,0,0,0,65,77,73,86,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,10,0,0,0,0,0,0,0,0,0,0,54,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,38,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,203,31,0,80,207,34,0,80,178,26,0,216,177,26,0,80,6,0,0,4,0,2,0,0,0,0,0,0,0,0,0,112,0,0,0,226,2,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,206,31,0,96,208,34,0,96,230,0,0,152,228,0,0,216,230,0,0,0,0,2,0,0,0,0,0,0,0,0,0,82,1,0,0,148,7,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,213,31,0,0,210,34,0,16,19,2,0,40,16,2,0,136,19,2,0,0,0,1,0,194,7,0,0,0,0,0,0,118,1,0,0,144,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,214,31,0,120,210,34,0,64,179,26,0,200,178,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,225,31,0,176,213,34,0,48,180,26,0,184,179,26,0,248,124,2,0,0,0,1,0,38,1,0,0,0,0,0,0,220,0,0,0,224,3,0,0,84,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,29,34,0,112,96,35,0,176,202,2,0,40,200,2,0,40,203,2,0,0,0,0,0,170,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,230,31,0,96,215,34,0,32,181,26,0,168,180,26,0,168,207,2,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,4,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,233,31,0,80,216,34,0,152,217,2,0,0,216,2,0,16,218,2,0,0,0,0,0,200,9,0,0,0,0,0,0,0,0,0,0,198,8,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,238,31,0,56,217,34,0,72,219,2,0,112,218,2,0,192,219,2,0,0,0,0,0,62,9,0,0,0,0,0,0,92,1,0,0,162,2,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,246,31,0,152,218,34,0,16,225,2,0,72,223,2,0,136,225,2,0,0,0,0,0,220,8,0,0,0,0,0,0,106,1,0,0,18,3,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,248,31,0,48,219,34,0,48,45,6,0,184,44,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,65,34,0,40,100,35,0,152,181,26,0,0,0,0,0,8,150,6,0,2,0,0,0,78,0,0,0,0,0,0,0,26,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,249,31,0,160,219,34,0,136,182,26,0,16,182,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,151,34,0,0,112,35,0,120,183,26,0,0,183,26,0,136,46,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,80,33,0,120,35,32,0,104,184,26,0,240,183,26,0,216,47,7,0,0,0,0,0,206,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,83,34,0,64,103,35,0,88,185,26,0,224,184,26,0,8,48,7,0,0,0,0,0,34,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,184,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,253,31,0,112,220,34,0,208,49,7,0,56,48,7,0,72,50,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,254,33,0,72,92,35,0,72,186,26,0,208,185,26,0,152,51,7,0,0,0,0,0,206,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,254,31,0,240,220,34,0,200,52,7,0,80,52,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,188,34,0,216,115,35,0,184,53,7,0,64,53,7,0,48,54,7,0,0,0,0,0,92,4,0,0,0,0,0,0,6,1,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,98,33,0,40,52,32,0,192,186,26,0,0,0,0,0,120,55,7,0,2,0,0,0,254,2,0,0,0,0,0,0,214,0,0,0,140,7,0,0,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,42,32,0,168,236,34,0,176,187,26,0,56,187,26,0,72,82,7,0,0,0,0,0,0,0,0,0,246,0,0,0,140,0,0,0,60,10,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,73,32,0,16,245,34,0,224,89,8,0,136,87,8,0,88,90,8,0,4,0,1,0,132,5,0,0,0,0,0,0,18,0,0,0,222,5,0,0,240,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,96,76,32,0,160,246,34,0,40,96,8,0,32,95,8,0,160,96,8,0,0,0,1,0,186,4,0,0,0,0,0,0,114,1,0,0,168,6,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,80,32,0,88,247,34,0,8,141,8,0,0,140,8,0,192,141,8,0,0,0,0,0,160,0,0,0,0,0,0,0,114,0,0,0,182,7,0,0,48,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,81,32,0,160,247,34,0,160,188,26,0,40,188,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,1,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,100,33,0,96,55,32,0,208,255,8,0,88,255,8,0,72,0,9,0,0,0,0,0,62,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,94,32,0,40,249,34,0,144,189,26,0,24,189,26,0,248,15,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,8,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,102,32,0,40,253,34,0,128,190,26,0,8,190,26,0,32,20,9,0,0,0,2,0,34,2,0,0,0,0,0,0,74,0,0,0,30,9,0,0,152,2,0,0,0,0,0,0,28,0,0,0,0,0,0,0,88,103,32,0,136,253,34,0,176,191,26,0,56,191,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,121,32,0,144,0,35,0,248,184,9,0,224,175,9,0,112,185,9,0,4,0,1,0,230,2,0,0,0,0,0,0,134,0,0,0,4,5,0,0,152,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,29,33,0,192,253,31,0,160,192,26,0,40,192,26,0,160,185,9,0,0,0,0,0,114,10,0,0,0,0,0,0,0,0,0,0,146,10,0,0,60,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,233,29,0,56,124,29,0,232,235,13,0,64,21,9,0,160,186,9,0,0,0,1,0,84,3,0,0,0,0,0,0,8,1,0,0,96,8,0,0,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,126,32,0,104,1,35,0,0,0,0,0,144,90,10,0,152,91,10,0,1,0,0,0,184,6,0,0,0,0,0,0,64,0,0,0,156,7,0,0,120,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,22,33,0,120,249,31,0,232,235,13,0,64,21,9,0,112,125,10,0,0,0,1,0,12,10,0,0,0,0,0,0,8,1,0,0,96,8,0,0,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,36,31,0,40,117,30,0,232,235,13,0,64,21,9,0,160,125,10,0,0,0,1,0,154,9,0,0,0,0,0,0,8,1,0,0,96,8,0,0,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,143,32,0,120,4,35,0,160,127,10,0,8,126,10,0,24,128,10,0,4,0,1,0,240,1,0,0,0,0,0,0,0,0,0,0,4,8,0,0,232,1,48,0,0,0,0,0,0,0,0,0,0,0,0,0,56,155,32,0,200,6,35,0,232,235,13,0,64,21,9,0,216,125,10,0,0,0,1,0,154,7,0,0,0,0,0,0,8,1,0,0,96,8,0,0,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,11,35,0,32,126,35,0,0,0,0,0,8,222,13,0,16,223,13,0,1,0,0,0,180,5,0,0,0,0,0,0,52,1,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,167,32,0,80,9,35,0,96,236,13,0,184,21,9,0,40,0,14,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,9,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,32,0,48,10,35,0,248,1,14,0,240,0,14,0,112,2,14,0,0,0,0,0,248,8,0,0,0,0,0,0,180,0,0,0,82,6,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,175,32,0,80,11,35,0,8,54,14,0,160,52,14,0,128,54,14,0,0,0,1,0,76,6,0,0,0,0,0,0,124,0,0,0,132,7,0,0,112,1,2,0,0,0,0,0,16,0,0,0,0,0,0,0,144,190,32,0,240,13,35,0,216,236,13,0,48,22,9,0,128,99,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,1,0,0,52,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,32,0,112,14,35,0,144,193,26,0,24,193,26,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,2,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,21,33,0,200,248,31,0,112,0,15,0,168,254,14,0,40,1,15,0,4,0,2,0,16,0,0,0,0,0,0,0,50,0,0,0,4,8,0,0,232,1,48,0,0,0,0,0,0,0,0,0,0,0,0,0,96,194,32,0,240,14,35,0,128,194,26,0,8,194,26,0,200,12,15,0,0,0,1,0,208,8,0,0,0,0,0,0,72,1,0,0,58,2,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,196,32,0,200,15,35,0,32,246,15,0,72,245,15,0,152,246,15,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,201,32,0,72,17,35,0,64,247,15,0,200,246,15,0,248,247,15,0,0,0,0,0,0,0,0,0,0,0,0,0,244,0,0,0,18,6,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,217,32,0,80,19,35,0,112,195,26,0,248,194,26,0,144,253,15,0,0,0,0,0,30,10,0,0,0,0,0,0,30,1,0,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,219,32,0,72,20,35,0,96,196,26,0,232,195,26,0,72,255,15,0,0,0,0,0,114,10,0,0,0,0,0,0,0,0,0,0,182,1,0,0,60,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,142,34,0,200,109,35,0,80,197,26,0,216,196,26,0,0,0,0,0,0,0,0,0,228,9,0,0,0,0,0,0,230,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,222,32,0,80,21,35,0,64,198,26,0,200,197,26,0,184,80,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,247,32,0,16,26,35,0,0,0,0,0,232,80,16,0,192,87,16,0,1,0,0,0,136,9,0,0,0,0,0,0,22,1,0,0,18,10,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,249,32,0,32,27,35,0,208,89,16,0,152,88,16,0,72,90,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,33,0,104,29,35,0,48,199,26,0,184,198,26,0,40,30,20,0,4,0,0,0,238,7,0,0,0,0,0,0,0,0,0,0,52,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,16,33,0,176,31,35,0,40,38,20,0,0,0,0,0,160,38,20,0,2,0,0,0,12,5,0,0,0,0,0,0,254,0,0,0,50,5,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,21,33,0,0,33,35,0,104,128,20,0,160,126,20,0,224,128,20,0,0,0,0,0,226,1,0,0,0,0,0,0,40,0,0,0,70,10,0,0,44,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,24,33,0,16,34,35,0,24,130,20,0,16,129,20,0,144,130,20,0,0,0,1,0,218,3,0,0,0,0,0,0,104,1,0,0,2,10,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,43,33,0,32,6,32,0,120,148,20,0,240,145,20,0,240,148,20,0,0,0,1,0,62,4,0,0,0,0,0,0,0,0,0,0,20,4,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,57,33,0,160,39,35,0,168,151,20,0,32,149,20,0,32,152,20,0,0,0,1,0,62,4,0,0,0,0,0,0,0,0,0,0,20,4,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,86,33,0,88,51,35,0,24,4,21,0,16,0,21,0,144,4,21,0,0,0,0,0,58,9,0,0,0,0,0,0,170,0,0,0,238,2,0,0,104,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,90,33,0,248,52,35,0,72,78,21,0,112,77,21,0,192,78,21,0,0,0,0,0,170,3,0,0,0,0,0,0,76,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,122,33,0,48,62,35,0,0,0,0,0,0,108,21,0,248,109,21,0,1,0,0,0,192,7,0,0,0,0,0,0,124,1,0,0,92,0,0,0,136,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,128,33,0,192,65,35,0,232,111,21,0,80,110,21,0,96,112,21,0,0,0,1,0,194,0,0,0,0,0,0,0,48,0,0,0,158,10,0,0,136,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,148,33,0,104,70,35,0,208,159,21,0,8,155,21,0,72,160,21,0,4,0,1,0,198,9,0,0,0,0,0,0,0,0,0,0,188,9,0,0,40,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,160,33,0,232,74,35,0,32,200,26,0,168,199,26,0,32,162,21,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,180,2,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,162,33,0,176,75,35,0,16,201,26,0,152,200,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,170,33,0,48,78,35,0,88,184,21,0,176,180,21,0,208,184,21,0,0,0,1,0,0,0,0,0,0,0,0,0,204,0,0,0,188,10,0,0,208,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,190,33,0,120,80,35,0,88,187,21,0,0,185,21,0,208,187,21,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,16,10,0,0,88,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,224,33,0,40,85,35,0,224,173,25,0,136,165,25,0,152,174,25,0,4,0,2,0,74,2,0,0,0,0,0,0,66,0,0,0,186,8,0,0,96,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,229,33,0,192,86,35,0,144,176,25,0,200,174,25,0,8,177,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,238,33,0,16,89,35,0,120,117,26,0,160,116,26,0,240,117,26,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,208,2,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,17,34,0,64,94,35,0,232,106,27,0,112,106,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,210,0,0,0,202,4,0,0,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,37,33,0,88,2,32,0,40,38,20,0,0,0,0,0,0,0,0,0,2,0,0,0,68,8,0,0,0,0,0,0,254,0,0,0,50,5,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,153,33,0,160,71,35,0,0,0,0,0,36,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,10,0,0,0,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,190,28,0,16,163,33,0,0,0,0,0,120,100,32,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,84,4,0,0,20,0,0,0,62,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,190,28,0,56,163,33,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,1,0,0,22,0,0,0,54,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,247,29,0,160,137,29,0,0,0,0,0,153,0,0,0,2,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,8,0,0,0,0,0,0,0,0,0,0,224,1,0,0,122,10,0,0,126,0,0,0,0,0,0,0,3,0,46,0,95,0,0,0,22,0,21,0,1,0,4,0,20,0,241,2,121,1,123,1,192,11,193,11,225,5,122,1,6,0,6,0,3,0,7,0,15,0,14,0,0,0,2,0,2,0,20,0,17,0,11,0,9,0,33,0,21,0,32,0,6,0,0,0,14,0,5,0,2,0,3,0,3,0,15,0,2,0,129,0,33,0,9,0,1,1,65,0,17,0,0,1,2,6,7,2,5,5,2,3,5,10,9,9,12,12,11,9,3,4,4,4,4,4,3,3,2,7,7,6,6,8,7,8,3,3,4,5,3,3,4,4,2,10,8,6,11,9,7,11,0,0,0,0,3,0,0,0,6,0,0,0,7,0,0,0,3,0,0,0,6,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,1,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,3,0,0,0,6,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,7,0,0,0,1,0,0,0,4,0,0,0,5,0,0,0,3,0,0,0,2,0,0,0,0,1,3,5,16,17,18,19,3,0,1,2,3,5,8,9,1,0,1,4,6,7,10,11,2,2,2,3,5,5,5,5,2,3,3,3,3,3,4,4,2,3,3,3,3,3,4,4,14,12,7,11,9,26,2,10,27,8,0,6,1,15,1,14,0,8,15,10,4,23,13,5,9,25,3,24,22,1,5,6,2,2,8,0,28,3,1,3,29,1,19,18,15,0,0,0,5,5,5,5,5,6,4,5,6,5,4,5,4,5,1,4,3,4,4,4,5,5,4,5,4,5,4,5,5,2,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,0,0,0,8,16,1,9,24,17,2,10,18,25,3,11,26,19,27,0,1,2,3,4,5,6,7,8,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,27,29,31,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,0,1,1,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,29,31,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,11,0,0,0,16,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,24,0,0,0,11,0,0,0,20,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,80,0,0,0,33,0,0,0,18,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,64,0,0,0,33,0,0,0,160,0,0,0,99,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,2,0,3,0,0,0,4,0,1,0,2,0,71,0,5,0,3,0,4,0,75,0,5,0,77,0,78,0,14,3,6,0,6,0,7,0,83,0,8,0,85,0,86,0,13,3,9,0,89,0,90,0,12,3,92,0,11,3,10,3,55,0,7,0,10,0,11,0,67,0,12,0,69,0,70,0,9,3,13,0,73,0,74,0,8,3,76,0,7,3,6,3,54,0,14,0,81,0,82,0,5,3,84,0,4,3,3,3,53,0,88,0,2,3,1,3,52,0,0,3,51,0,50,0,7,0,1,4,4,8,4,8,8,10,4,8,8,10,8,10,10,13,4,8,8,10,8,10,10,13,8,10,10,13,10,13,13,9,4,8,8,10,8,10,10,13,8,10,10,13,10,13,13,9,8,10,10,13,10,13,13,9,10,13,13,9,13,9,9,6,0,4,5,3,0,0,0,0,1,3,3,2,0,0,0,0,0,1,2,3,1,3,2,0,0,1,2,4,3,1,3,2,4,0,0,0,0,0,0,0,0,0,2,0,3,0,8,0,64,2,3,0,2,0,6,0,5,0,65,2,66,2,7,0,8,0,9,0,40,0,19,0,37,0,82,0,21,0,22,0,23,0,67,2,68,2,166,0,96,0,167,0,49,0,194,0,195,0,69,2,70,2,71,2,36,1,37,1,38,1,13,0,2,0,7,0,24,0,50,0,102,0,39,1,13,0,7,0,8,0,18,0,50,0,103,0,38,0,20,0,21,0,22,0,39,0,204,0,103,0,23,0,24,0,25,0,104,0,154,1,105,0,106,0,107,0,108,0,109,0,220,0,155,1,186,1,222,0,187,1,190,1,191,1,7,0,0,0,4,0,5,0,3,0,4,0,3,0,4,0,5,0,20,0,6,0,21,0,44,0,45,0,46,0,192,11,95,0,112,0,113,0,57,0,193,11,194,11,116,0,117,0,195,11,118,0,196,11,197,11,198,11,199,11,200,11,201,11,202,11,203,11,204,11,205,11,206,11,1,0,4,0,15,0,160,0,161,0,41,0,6,0,11,0,42,0,162,0,43,0,119,0,56,0,57,0,58,0,163,0,236,0,237,0,207,11,119,0,120,0,242,0,122,0,230,1,232,5,231,1,246,0,238,1,233,5,239,1,234,5,235,5,236,5,237,5,238,5,239,5,31,0,0,0,0,2,1,2,2,2,3,2,2,0,3,0,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,1,0,5,0,31,1,32,1,33,1,34,1,6,0,7,0,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,44,1,45,1,46,1,47,1,48,1,49,1,50,1,51,1,52,1,53,1,54,1,55,1,56,1,57,1,58,1,59,1,60,1,61,1,62,1,63,1,0,0,1,0,1,0,2,0,3,0,4,0,1,0,5,0,4,0,3,0,5,0,8,0,6,0,9,0,10,0,11,0,12,0,7,0,104,0,14,0,105,0,4,0,10,0,15,0,11,0,6,0,14,0,8,0,106,0,107,0,108,0,15,0,109,0,9,0,55,0,10,0,1,0,2,0,1,0,2,0,3,0,12,0,6,0,2,0,6,0,7,0,28,0,7,0,15,0,8,0,5,0,18,0,29,0,152,0,77,0,24,0,25,0,26,0,39,0,108,0,13,0,109,0,55,0,56,0,57,0,116,0,11,0,153,0,234,0,235,0,118,0,119,0,15,0,6,7,7,8,14,6,5,6,7,14,14,6,6,6,8,9,10,9,7,7,7,14,14,10,9,10,8,10,10,14,14,14,13,13,13,6,3,5,6,8,9,13,5,4,4,5,7,9,6,5,5,5,6,9,8,5,5,5,7,10,7,7,7,7,7,8,10,9,8,9,9,9,3,5,7,7,6,6,5,5,6,7,5,7,8,8,8,14,9,9,9,8,14,14,9,9,14,9,14,14,14,14,14,14,14,14,14,14,14,2,3,6,8,8,6,3,4,6,8,6,9,6,6,6,8,8,8,14,7,7,8,7,9,13,9,8,9,13,9,13,13,13,13,13,13,5,3,12,12,12,12,3,4,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,1,5,11,11,11,11,4,4,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,15,11,15,15,15,15,12,15,12,11,12,12,15,12,12,12,12,15,15,12,15,10,11,12,11,10,11,10,15,15,15,11,15,10,14,10,4,4,5,7,8,9,5,3,4,5,6,8,5,4,3,5,6,8,7,5,5,5,6,7,9,7,6,6,6,7,10,8,8,8,7,7,4,0,0,0,0,144,31,30,0,136,25,30,0,0,0,0,0,144,31,30,0,0,0,0,0,71,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,1,0,0,1,0,0,0,0,1,0,1,0,1,1,0,0,1,1,1,0,1,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,1,0,0,1,0,0,0,0,1,0,1,0,1,1,0,0,1,1,1,0,1,1,0,0,0,4,0,0,1,4,1,0,1,4,0,0,0,3,0,0,1,3,1,0,1,3,0,0,0,5,0,0,0,9,22,0,17,16,10,1,3,23,7,0,5,2,1,1,6,3,4,1,0,10,23,44,8,3,9,45,7,97,1,2,49,13,25,0,96,0,0,0,0,4,5,2,5,5,4,2,2,5,3,4,6,2,3,2,3,5,6,2,2,4,5,6,4,2,4,6,4,8,1,3,7,5,6,2,8,0,0,0,0,22,0,17,0,0,0,47,0,32,0,10,0,1,0,3,0,67,0,133,0,132,0,92,0,19,0,93,0,18,0,3,0,45,0,0,0,7,0,23,0,6,0,1,0,2,0,10,0,39,0,44,0,8,0,18,0,77,0,76,0,15,0,6,0,28,0,9,0,41,0,6,0,2,0,15,0,14,0,8,0,40,0,29,0,0,0,21,0,11,0,7,0,198,0,1,0,2,0,193,0,13,0,25,0,0,0,97,0,63,6,98,0,142,1,30,3,192,0,62,6,5,5,2,6,6,4,2,2,7,8,8,7,5,7,5,3,6,3,3,5,3,3,3,4,6,6,4,5,7,7,4,3,5,5,7,4,2,5,5,5,7,5,2,6,5,4,9,1,3,9,5,6,2,8,12,8,10,11,9,12,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,3,1,2,3,0,4,2,3,2,4,3,3,0,16,17,3,3,0,5,9,2,8,9,3,6,7,0,5,2,16,17,5,3,0,3,9,2,56,57,15,4,5,6,29,0,52,53,27,14,15,2,12,0,56,57,29,5,6,0,15,4,16,17,6,7,0,1,9,5,56,57,0,5,6,29,4,15,6,6,2,3,2,4,5,2,5,5,3,3,3,2,4,2,6,6,4,3,2,2,5,2,6,6,4,3,3,3,5,1,6,6,5,4,4,2,4,1,6,6,5,3,3,1,4,3,5,5,3,3,2,2,4,3,6,6,1,3,3,5,3,4,0,1,1,1,1,1,0,1,1,1,1,1,16,17,3,0,9,5,20,21,3,11,0,4,4,5,2,3,3,0,4,5,3,2,0,3,0,1,1,1,1,1,16,17,9,5,3,0,5,5,1,3,2,4,5,5,1,2,3,4,5,5,2,1,4,3,5,5,2,4,1,3,4,4,2,3,2,2,4,4,3,2,2,2,5,5,3,4,1,2,5,5,4,3,2,1,26,47,27,47,140,23,144,0,168,2,169,2,199,11,145,0,170,2,171,2,224,5,74,0,150,0,151,0,189,0,146,0,172,2,173,2,225,5,152,0,50,1,51,1,121,1,52,1,106,2,107,2,252,2,78,0,64,0,65,0,43,0,147,0,174,2,175,2,226,5,54,1,110,2,111,2,253,2,158,0,62,1,63,1,127,1,80,0,66,0,67,0,44,0,81,0,164,0,165,0,190,0,83,0,68,0,69,0,45,0,84,0,70,0,71,0,46,0,3,0,0,0,1,0,1,0,65,0,66,0,0,1,67,0,136,0,137,0,1,1,69,0,140,0,141,0,2,1,16,0,34,0,35,0,36,0,71,0,16,0,17,0,3,1,37,0,88,0,89,0,90,0,91,0,90,0,91,0,92,0,12,0,48,0,49,0,25,0,9,0,20,0,21,0,44,0,92,0,93,0,94,0,95,0,38,0,93,0,94,0,95,0,13,0,52,0,53,0,27,0,20,0,39,0,42,0,43,0,14,0,56,0,57,0,29,0,15,0,60,0,61,0,31,0,5,0,9,0,0,0,3,0,50,0,51,0,26,0,38,0,228,0,229,0,230,1,39,0,230,0,231,0,231,1,14,0,99,0,108,0,119,0,40,0,232,0,233,0,232,1,123,0,218,0,219,0,236,0,245,0,184,1,185,1,218,1,33,0,75,0,84,0,43,0,41,0,234,0,235,0,233,1,74,0,186,1,187,1,219,1,32,0,222,0,223,0,242,0,34,0,85,0,88,0,45,0,15,0,112,0,113,0,120,0,35,0,89,0,92,0,47,0,36,0,93,0,98,0,48,0,2,0,31,0,6,0,0,0,40,0,41,0,157,0,0,0,234,1,235,1,236,1,1,0,237,1,238,1,239,1,5,0,240,0,241,0,59,0,2,0,240,1,241,1,242,1,63,0,92,1,93,1,153,0,16,0,208,3,209,3,48,1,15,0,158,0,159,0,251,0,3,0,243,1,244,1,245,1,17,0,210,3,211,3,49,1,9,0,94,1,95,1,156,0,16,0,168,0,169,0,56,0,6,0,242,0,243,0,77,0,17,0,170,0,171,0,57,0,18,0,172,0,173,0,58,0,6,0,22,0,23,0,14,0,60,0,61,0,31,0,10,0,97,0,98,0,2,0,11,0,99,0,100,0,3,0,7,0,3,0,4,0,11,0,12,0,101,0,102,0,4,0,18,0,10,0,11,0,20,0,27,0,24,0,25,0,52,0,44,0,103,0,104,0,53,0,13,0,105,0,108,0,5,0,96,0,26,0,27,0,53,0,19,0,14,0,15,0,21,0,45,0,109,0,110,0,56,0,8,0,8,0,9,0,12,0,46,0,111,0,114,0,58,0,47,0,115,0,0,0,59,0,7,0,20,0,21,0,4,0,56,0,57,0,157,0,10,0,145,0,146,0,147,0,11,0,148,0,149,0,150,0,3,0,238,0,239,0,54,0,12,0,151,0,152,0,153,0,8,0,228,1,229,1,106,0,24,0,204,3,205,3,214,0,14,0,158,0,159,0,245,0,13,0,154,0,155,0,156,0,25,0,206,3,207,3,215,0,9,0,232,1,233,1,144,0,15,0,232,0,233,0,246,0,5,0,240,0,241,0,55,0,16,0,234,0,235,0,247,0,17,0,236,0,237,0,52,0,0,0,62,0,63,0,2,0,60,0,61,0,207,1,0,0,191,0,224,0,252,1,1,0,225,0,226,0,253,1,9,0,241,1,242,1,243,1,2,0,227,0,228,0,254,1,17,0,238,3,239,3,240,3,33,0,226,7,227,7,228,7,24,0,247,3,254,3,255,3,3,0,229,0,230,0,128,0,46,0,229,7,230,7,231,7,22,0,244,3,245,3,246,3,25,0,2,1,3,1,4,1,10,0,244,1,245,1,246,1,26,0,5,1,6,1,7,1,27,0,120,1,121,1,206,1,29,0,189,0,190,0,240,1,3,0,4,0,182,1,4,0,46,0,47,0,14,0,5,0,48,0,49,0,15,0,3,0,10,0,11,0,20,0,6,0,50,0,51,0,16,0,5,0,48,0,49,0,50,0,9,0,102,0,103,0,104,0,29,0,183,1,184,1,185,1,7,0,52,0,53,0,17,0,22,0,105,0,106,0,107,0,10,0,54,0,55,0,216,0,30,0,186,1,187,1,188,1,4,0,21,0,22,0,23,0,31,0,189,1,190,1,191,1,0,0,16,0,17,0,18,0,28,0,217,0,218,0,19,0,15,15,14,9,11,11,13,9,11,11,12,8,9,9,9,9,11,11,12,9,10,10,10,10,11,11,11,8,8,8,7,9,11,11,12,10,11,11,11,9,10,10,10,8,8,8,7,8,9,9,9,8,8,8,7,8,8,8,7,3,3,3,1,7,7,9,7,8,8,9,7,8,8,9,6,7,7,7,7,7,7,9,7,8,8,8,8,9,9,9,6,7,7,6,6,7,7,8,8,9,9,9,7,8,8,8,6,7,7,6,6,7,7,7,6,7,7,6,6,7,7,6,3,4,3,2,6,6,5,6,8,8,9,6,8,8,9,5,7,7,7,6,8,8,9,7,8,8,8,8,9,9,9,6,7,7,6,6,8,8,9,7,9,9,9,6,8,8,8,6,7,7,6,5,7,7,7,6,7,7,6,6,7,7,6,3,5,4,2,6,6,8,4,9,9,9,4,9,9,9,4,8,8,7,4,9,9,9,6,9,9,8,6,10,10,9,5,8,8,8,4,9,9,9,6,10,10,9,5,9,9,8,5,8,8,7,4,8,8,7,5,8,8,7,5,8,8,7,3,5,5,4,6,6,5,5,7,7,7,5,7,7,7,5,6,6,6,5,7,7,7,6,7,7,7,7,8,8,8,6,7,7,6,5,7,7,7,7,8,8,8,6,7,7,7,6,7,7,6,5,6,6,6,6,7,7,6,6,7,6,6,4,5,5,3,6,6,8,4,8,8,8,4,8,8,8,4,8,8,7,4,8,8,8,5,9,9,8,6,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1087980);
/* memory initializer */ allocate([10,9,5,8,8,8,4,8,8,8,6,10,10,9,5,9,9,8,5,8,8,8,4,8,8,7,5,8,8,8,5,8,8,7,3,6,6,4,6,6,9,3,8,8,9,3,8,8,9,4,9,9,9,3,8,8,9,5,10,10,10,6,11,11,11,5,10,10,10,3,8,8,8,6,11,11,11,5,10,10,10,5,9,9,9,4,9,9,9,5,9,9,9,5,9,9,9,5,8,8,9,6,6,10,3,7,7,7,3,7,7,7,4,8,8,8,3,7,7,7,5,9,9,9,6,10,10,10,6,10,10,10,3,7,7,7,6,10,10,10,5,9,9,9,6,10,10,10,4,8,8,8,6,10,10,10,5,9,9,9,6,9,9,9,24,0,0,0,25,0,0,0,30,0,0,0,50,0,0,0,60,0,0,0,48,0,0,0,72,0,0,0,0,0,0,0,232,3,0,0,233,3,0,0,128,0,192,0,213,0,224,0,0,2,85,1,51,1,37,1,219,0,236,0,242,0,245,0,32,0,48,0,53,0,56,0,8,0,12,0,13,0,14,0,37,0,20,0,14,0,11,0,10,0,5,0,4,0,3,0,128,0,64,0,43,0,32,0,0,2,0,4,0,6,0,8,219,0,204,0,200,0,198,0,32,0,16,0,11,0,8,0,8,0,4,0,3,0,2,0,37,0,52,0,56,0,58,0,10,0,13,0,14,0,15,0,0,0,4,0,0,0,2,0,85,85,1,0,0,0,1,0,205,204,0,0,171,170,0,0,73,146,0,0,0,128,0,0,199,113,0,0,102,102,0,0,23,93,0,0,85,85,0,0,197,78,0,0,37,73,0,0,68,68,0,0,0,64,0,0,60,60,0,0,228,56,0,0,229,53,0,0,51,51,0,0,195,48,0,0,140,46,0,0,134,44,0,0,171,42,0,0,246,40,0,0,98,39,0,0,237,37,0,0,146,36,0,0,79,35,0,0,34,34,0,0,8,33,0,0,0,32,0,0,8,31,0,0,30,30,0,0,66,29,0,0,114,28,0,0,173,27,0,0,243,26,0,0,66,26,0,0,154,25,0,0,250,24,0,0,98,24,0,0,208,23,0,0,70,23,0,0,193,22,0,0,67,22,0,0,202,21,0,0,85,21,0,0,230,20,0,0,123,20,0,0,20,20,0,0,177,19,0,0,82,19,0,0,247,18,0,0,158,18,0,0,73,18,0,0,247,17,0,0,168,17,0,0,91,17,0,0,17,17,0,0,201,16,0,0,132,16,0,0,0,16,0,0,0,0,0,0,112,229,33,0,40,193,33,0,0,1,0,0,112,229,33,0,0,0,0,0,96,61,2,0,0,0,0,0,71,0,0,0,20,0,0,0,0,0,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,154,33,0,240,71,35,0,0,0,0,0,71,0,0,0,34,0,0,0,0,0,0,0,72,61,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,145,8,0,168,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,8,0,0,0,0,0,0,0,0,0,0,224,1,0,0,122,10,0,0,164,0,0,0,0,0,0,0,0,0,6,0,15,0,13,0,13,0,11,0,3,0,13,0,5,0,8,0,49,0,10,0,12,0,114,0,102,0,119,0,1,0,54,0,96,0,8,0,10,0,111,0,5,0,15,0,12,0,10,0,2,0,12,0,13,0,115,0,53,0,63,0,1,0,7,0,1,0,7,0,14,0,12,0,4,0,14,0,1,0,9,0,97,0,11,0,7,0,58,0,52,0,62,0,4,0,103,0,1,0,9,0,11,0,56,0,101,0,118,0,4,0,110,0,100,0,30,0,2,0,5,0,4,0,3,0,0,0,9,0,1,0,18,0,5,0,14,0,237,0,26,0,3,0,121,0,3,0,22,0,13,0,16,0,6,0,30,0,2,0,10,0,1,0,20,0,12,0,241,0,5,0,28,0,16,0,12,0,3,0,24,0,28,0,124,0,239,0,247,0,1,0,240,0,1,0,19,0,18,0,15,0,4,0,27,0,1,0,122,0,2,0,23,0,1,0,17,0,7,0,31,0,1,0,11,0,2,0,21,0,19,0,246,0,238,0,29,0,17,0,13,0,236,0,25,0,58,0,63,0,8,0,125,0,0,0,201,0,25,0,231,0,5,0,221,0,1,0,3,0,2,0,158,1,2,0,241,0,16,0,225,0,195,0,236,1,2,0,156,1,1,0,240,0,7,0,224,0,98,0,245,0,1,0,220,0,96,0,5,0,9,0,230,0,101,0,247,0,1,0,102,0,1,0,159,1,24,0,3,0,2,0,244,0,3,0,54,0,3,0,228,1,17,0,114,0,200,0,237,1,3,0,157,1,1,0,4,0,13,0,113,0,99,0,229,1,4,0,111,0,194,0,243,0,5,0,29,0,26,0,31,0,0,0,28,0,12,0,44,0,3,0,36,0,20,0,52,0,2,0,32,0,16,0,48,0,8,0,40,0,24,0,28,0,1,0,30,0,14,0,46,0,6,0,38,0,22,0,54,0,3,0,34,0,18,0,50,0,10,0,42,0,26,0,30,0,1,0,29,0,13,0,45,0,5,0,37,0,21,0,53,0,2,0,33,0,17,0,49,0,9,0,41,0,25,0,29,0,1,0,31,0,15,0,47,0,7,0,39,0,23,0,55,0,4,0,35,0,19,0,51,0,11,0,43,0,27,0,31,0,13,13,7,13,7,13,13,12,6,13,7,12,6,8,8,8,5,7,8,12,6,8,13,12,7,13,13,12,6,8,7,7,6,13,8,12,7,13,13,12,7,13,8,12,5,7,7,7,6,8,13,12,6,7,8,8,5,8,8,6,3,3,3,2,14,13,8,13,3,13,8,13,3,7,8,13,4,13,13,13,3,13,13,13,4,8,13,13,5,13,13,13,5,7,8,8,3,8,14,13,5,13,13,13,4,7,13,13,6,13,13,13,5,13,8,13,5,8,8,13,5,13,8,13,6,6,13,7,13,8,6,8,4,8,13,12,4,9,8,8,5,8,8,9,5,9,10,8,4,8,7,8,6,8,7,13,4,8,7,8,5,7,8,9,6,13,13,8,4,6,8,9,5,7,8,9,5,9,9,13,5,7,7,9,4,7,8,8,3,5,5,5,9,9,9,9,2,9,9,9,2,9,9,9,9,9,9,8,3,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,2,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,128,0,85,0,170,0,64,0,192,0,51,0,102,0,153,0,204,0,43,0,215,0,37,0,74,0,111,0,148,0,185,0,222,0,32,0,96,0,160,0,224,0,255,255,0,0,0,0,0,1,2,3,4,5,6,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,0,3,3,3,3,3,3,3,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,0,171,0,205,0,219,0,228,0,128,1,64,1,43,1,32,1,230,0,239,0,244,0,246,0,43,0,51,0,55,0,57,0,11,0,13,0,14,0,14,0,26,0,17,0,12,0,10,0,7,0,4,0,3,0,3,0,0,8,1,16,2,9,10,3,24,17,4,11,18,12,5,19,25,13,20,26,27,6,21,28,14,22,29,7,30,15,23,31,0,1,8,2,9,16,17,24,10,32,25,18,40,3,33,26,48,11,56,41,34,49,57,42,19,50,27,58,35,43,51,59,0,8,1,16,24,9,2,32,40,48,56,17,10,3,25,18,11,4,33,41,49,57,26,34,42,50,58,19,12,5,27,20,13,6,35,28,21,14,7,15,22,29,36,43,51,59,60,52,44,37,30,23,31,38,45,53,61,62,54,46,39,47,55,63,0,8,16,24,1,9,2,17,25,10,3,18,26,4,11,19,12,5,13,20,27,6,21,28,14,22,29,7,30,15,23,31,0,1,2,8,16,9,24,17,10,3,32,40,48,56,25,18,33,26,41,34,49,57,11,42,19,50,27,58,35,43,51,59,0,8,16,24,1,9,17,2,25,10,18,3,26,11,19,27,186,0,0,0,169,0,0,0,133,0,0,0,149,0,0,0,103,0,0,0,103,0,0,0,163,0,0,0,175,0,0,0,14,58,59,25,12,26,15,15,13,24,27,0,28,1,2,2,8,18,19,4,20,5,30,11,21,31,6,12,7,13,14,0,15,6,7,2,8,3,28,9,10,29,4,11,5,12,13,0,0,11,12,4,13,5,30,16,14,31,6,17,7,18,19,10,5,6,6,5,5,5,5,4,5,5,5,3,5,3,3,2,4,5,5,4,5,4,5,4,5,5,4,4,4,4,4,2,4,4,4,4,4,4,5,4,4,5,4,4,4,4,4,3,2,4,4,4,4,4,5,5,4,5,4,5,4,5,5,4,12,0,0,0,28,0,0,0,11,0,0,0,0,0,0,0,14,0,0,0,42,0,0,0,80,0,0,0,104,3,0,0,2,0,0,0,26,0,0,0,4,0,0,0,58,0,0,0,29,0,0,0,108,0,0,0,239,0,0,0,188,1,0,0,95,1,0,0,15,0,0,0,3,0,0,0,28,0,0,0,13,0,0,0,11,0,0,0,62,0,0,0,167,0,0,0,70,1,0,0,153,1,0,0,6,0,0,0,31,0,0,0,4,0,0,0,60,0,0,0,7,0,0,0,190,1,0,0,139,0,0,0,44,0,0,0,179,7,0,0,5,0,0,0,219,0,0,0,86,0,0,0,236,0,0,0,82,0,0,0,189,1,0,0,120,0,0,0,207,0,0,0,115,5,0,0,9,0,0,0,35,0,0,0,237,0,0,0,24,0,0,0,6,0,0,0,68,0,0,0,245,0,0,0,121,0,0,0,210,6,0,0,110,0,0,0,43,0,0,0,93,1,0,0,23,0,0,0,127,3,0,0,68,1,0,0,206,0,0,0,40,0,0,0,171,0,0,0,16,0,0,0,181,1,0,0,247,0,0,0,166,0,0,0,123,0,0,0,40,0,0,0,237,1,0,0,233,1,0,0,253,6,0,0,4,0,0,0,245,0,0,0,41,0,0,0,138,2,0,0,139,2,0,0,143,2,0,0,249,13,0,0,53,3,0,0,133,30,0,0,238,0,0,0,189,2,0,0,43,0,0,0,216,3,0,0,209,3,0,0,152,1,0,0,233,1,0,0,29,5,0,0,180,0,0,0,63,0,0,0,85,4,0,0,43,2,0,0,41,2,0,0,81,4,0,0,120,5,0,0,178,7,0,0,112,5,0,0,85,1,0,0,50,0,0,0,208,3,0,0,84,0,0,0,211,6,0,0,113,5,0,0,84,4,0,0,52,3,0,0,241,27,0,0,183,0,0,0,41,0,0,0,132,30,0,0,108,1,0,0,155,1,0,0,240,27,0,0,121,5,0,0,67,15,0,0,181,0,0,0,161,8,0,0,42,0,0,0,109,1,0,0,160,8,0,0,160,7,0,0,209,3,0,0,229,10,0,0,84,1,0,0,228,10,0,0,57,10,0,0,56,10,0,0,3,0,0,0,9,0,0,0,22,0,0,0,16,0,0,0,215,0,0,0,53,3,0,0,116,5,0,0,85,5,0,0,0,0,0,0,29,0,0,0,9,0,0,0,23,0,0,0,44,0,0,0,173,0,0,0,116,3,0,0,179,6,0,0,119,5,0,0,15,0,0,0,24,0,0,0,10,0,0,0,46,0,0,0,34,0,0,0,124,1,0,0,123,14,0,0,137,27,0,0,216,21,0,0,8,0,0,0,52,0,0,0,109,0,0,0,35,0,0,0,194,1,0,0,118,3,0,0,211,2,0,0,74,28,0,0,10,51,0,0,20,0,0,0,106,0,0,0,114,0,0,0,108,0,0,0,227,0,0,0,155,1,0,0,63,7,0,0,240,28,0,0,65,11,0,0,50,0,0,0,230,0,0,0,224,0,0,0,207,0,0,0,171,0,0,0,156,1,0,0,171,2,0,0,43,14,0,0,217,21,0,0,111,0,0,0,195,1,0,0,175,0,0,0,191,0,0,0,172,0,0,0,125,1,0,0,227,6,0,0,41,14,0,0,132,25,0,0,84,0,0,0,181,0,0,0,122,1,0,0,173,1,0,0,153,1,0,0,120,1,0,0,88,3,0,0,210,2,0,0,75,28,0,0,91,0,0,0,168,2,0,0,49,3,0,0,136,3,0,0,139,3,0,0,112,3,0,0,19,7,0,0,195,12,0,0,241,28,0,0,185,1,0,0,239,5,0,0,56,7,0,0,242,2,0,0,59,3,0,0,185,2,0,0,235,6,0,0,112,5,0,0,36,14,0,0,157,3,0,0,162,5,0,0,163,5,0,0,125,14,0,0,238,5,0,0,57,7,0,0,84,5,0,0,165,10,0,0,164,10,0,0,119,3,0,0,245,28,0,0,206,11,0,0,121,14,0,0,96,6,0,0,116,6,0,0,234,6,0,0,124,14,0,0,101,13,0,0,246,2,0,0,218,21,0,0,136,27,0,0,161,5,0,0,244,28,0,0,230,5,0,0,40,14,0,0,117,5,0,0,100,13,0,0,52,3,0,0,11,51,0,0,219,21,0,0,64,11,0,0,207,11,0,0,197,13,0,0,42,14,0,0,117,6,0,0,113,5,0,0,83,5,0,0,4,0,0,0,2,0,0,0,16,0,0,0,3,0,0,0,23,0,0,0,69,0,0,0,62,0,0,0,126,0,0,0,3,0,0,0,2,0,0,0,40,0,0,0,30,0,0,0,21,0,0,0,71,0,0,0,2,0,0,0,77,1,0,0,96,0,0,0,11,0,0,0,38,0,0,0,36,0,0,0,20,0,0,0,50,0,0,0,111,0,0,0,195,0,0,0,49,5,0,0,229,6,0,0,21,0,0,0,63,0,0,0,45,0,0,0,1,0,0,0,62,1,0,0,221,0,0,0,246,0,0,0,5,3,0,0,49,3,0,0,14,0,0,0,3,0,0,0,52,0,0,0,51,0,0,0,26,0,0,0,74,1,0,0,197,0,0,0,244,0,0,0,228,6,0,0,1,0,0,0,60,0,0,0,125,0,0,0,141,0,0,0,157,0,0,0,49,0,0,0,110,0,0,0,150,2,0,0,205,0,0,0,37,0,0,0,73,1,0,0,50,0,0,0,137,0,0,0,54,0,0,0,136,0,0,0,111,0,0,0,3,0,0,0,29,3,0,0,14,0,0,0,170,1,0,0,126,2,0,0,97,0,0,0,78,1,0,0,79,1,0,0,103,0,0,0,255,0,0,0,131,1,0,0,54,0,0,0,87,3,0,0,245,0,0,0,198,0,0,0,194,0,0,0,153,2,0,0,25,1,0,0,49,2,0,0,80,3,0,0,44,0,0,0,143,1,0,0,48,5,0,0,151,2,0,0,4,0,0,0,184,1,0,0,192,0,0,0,122,2,0,0,17,3,0,0,156,0,0,0,33,6,0,0,153,1,0,0,28,3,0,0,247,0,0,0,227,3,0,0,86,3,0,0,137,1,0,0,5,0,0,0,107,0,0,0,194,8,0,0,48,3,0,0,255,4,0,0,240,4,0,0,81,3,0,0,242,4,0,0,242,1,0,0,115,3,0,0,0,0,0,0,65,12,0,0,195,8,0,0,236,9,0,0,226,3,0,0,4,3,0,0,247,4,0,0,241,4,0,0,240,1,0,0,72,1,0,0,64,12,0,0,237,9,0,0,192,8,0,0,193,8,0,0,243,4,0,0,254,4,0,0,254,0,0,0,243,1,0,0,169,1,0,0,0,0,0,0,4,0,0,0,47,0,0,0,82,0,0,0,16,0,0,0,173,0,0,0,11,5,0,0,144,1,0,0,3,0,0,0,22,0,0,0,7,0,0,0,13,0,0,0,187,0,0,0,115,1,0,0,201,0,0,0,15,5,0,0,44,23,0,0,3,0,0,0,17,0,0,0,5,0,0,0,67,0,0,0,35,0,0,0,75,0,0,0,46,3,0,0,91,46,0,0,130,4,0,0,9,0,0,0,42,0,0,0,20,0,0,0,42,0,0,0,8,1,0,0,202,5,0,0,90,6,0,0,54,33,0,0,50,33,0,0,11,0,0,0,19,0,0,0,65,0,0,0,184,0,0,0,116,1,0,0,0,1,0,0,218,20,0,0,78,64,0,0,55,20,0,0,43,0,0,0,133,0,0,0,167,0,0,0,160,0,0,0,76,1,0,0,154,2,0,0,44,3,0,0,51,33,0,0,42,20,0,0,81,0,0,0,132,2,0,0,172,0,0,0,2,1,0,0,69,0,0,0,68,0,0,0,27,8,0,0,94,6,0,0,183,12,0,0,24,0,0,0,12,5,0,0,18,2,0,0,228,2,0,0,3,2,0,0,148,0,0,0,34,1,0,0,26,8,0,0,85,6,0,0,51,0,0,0,186,2,0,0,70,2,0,0,66,2,0,0,110,10,0,0,12,4,0,0,8,8,0,0,52,33,0,0,79,64,0,0,117,1,0,0,5,4,0,0,71,2,0,0,42,1,0,0,20,10,0,0,187,2,0,0,145,1,0,0,79,8,0,0,56,20,0,0,175,0,0,0,151,11,0,0,131,4,0,0,59,20,0,0,43,3,0,0,67,2,0,0,43,20,0,0,88,9,0,0,191,41,0,0,73,0,0,0,108,10,0,0,219,20,0,0,173,4,0,0,222,20,0,0,78,8,0,0,52,20,0,0,87,2,0,0,90,46,0,0,7,2,0,0,53,20,0,0,57,20,0,0,182,12,0,0,58,20,0,0,148,1,0,0,84,6,0,0,53,33,0,0,124,83,0,0,92,1,0,0,64,2,0,0,18,16,0,0,125,83,0,0,89,9,0,0,152,16,0,0,54,20,0,0,95,6,0,0,38,32,0,0,55,33,0,0,5,0,0,0,25,0,0,0,22,0,0,0,17,0,0,0,62,0,0,0,94,0,0,0,239,0,0,0,226,0,0,0,0,0,0,0,57,0,0,0,43,0,0,0,38,0,0,0,40,0,0,0,18,0,0,0,194,0,0,0,237,0,0,0,29,1,0,0,13,0,0,0,49,0,0,0,42,0,0,0,37,0,0,0,32,0,0,0,92,0,0,0,237,1,0,0,77,2,0,0,112,7,0,0,6,0,0,0,122,0,0,0,96,0,0,0,79,0,0,0,72,0,0,0,57,0,0,0,134,1,0,0,19,2,0,0,198,14,0,0,15,0,0,0,38,0,0,0,95,0,0,0,117,0,0,0,112,0,0,0,39,0,0,0,219,1,0,0,198,3,0,0,143,7,0,0,63,0,0,0,166,0,0,0,240,0,0,0,58,0,0,0,82,0,0,0,78,0,0,0,227,0,0,0,217,1,0,0,15,3,0,0,16,0,0,0,221,1,0,0,167,0,0,0,247,0,0,0,34,0,0,0,146,0,0,0,196,3,0,0,239,2,0,0,98,7,0,0,121,0,0,0,143,0,0,0,218,1,0,0,135,0,0,0,232,0,0,0,186,0,0,0,118,1,0,0,238,0,0,0,176,3,0,0,133,0,0,0,25,1,0,0,14,3,0,0,8,1,0,0,210,1,0,0,12,1,0,0,115,7,0,0,36,4,0,0,52,4,0,0,113,0,0,0,221,5,0,0,193,1,0,0,167,3,0,0,39,1,0,0,141,0,0,0,27,2,0,0,178,7,0,0,223,1,0,0,216,3,0,0,100,7,0,0,228,14,0,0,179,3,0,0,77,7,0,0,216,1,0,0,220,5,0,0,74,8,0,0,153,4,0,0,197,3,0,0,142,29,0,0,101,7,0,0,53,4,0,0,113,7,0,0,194,1,0,0,24,1,0,0,188,3,0,0,129,3,0,0,135,3,0,0,51,123,0,0,151,16,0,0,150,16,0,0,205,30,0,0,153,14,0,0,28,15,0,0,29,15,0,0,229,14,0,0,28,1,0,0,50,123,0,0,152,61,0,0,143,29,0,0,152,14,0,0,103,15,0,0,189,3,0,0,128,3,0,0,152,4,0,0,134,3,0,0,13,0,0,0,16,0,0,0,46,0,0,0,57,0,0,0,13,0,0,0,116,0,0,0,237,0,0,0,182,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,48,0,0,0,41,0,0,0,112,0,0,0,243,0,0,0,140,0,0,0,102,1,0,0,9,0,0,0,51,0,0,0,120,0,0,0,6,0,0,0,196,0,0,0,11,0,0,0,99,1,0,0,204,0,0,0,190,5,0,0,31,0,0,0,47,0,0,0,100,0,0,0,24,0,0,0,198,0,0,0,10,0,0,0,98,1,0,0,192,2,0,0,243,14,0,0,7,0,0,0,15,0,0,0,227,0,0,0,202,0,0,0,178,0,0,0,143,1,0,0,174,3,0,0,95,7,0,0,81,12,0,0,21,0,0,0,71,0,0,0,238,0,0,0,226,0,0,0,234,0,0,0,9,0,0,0,106,1,0,0,195,2,0,0,157,5,0,0,61,0,0,0,8,0,0,0,217,1,0,0,50,0,0,0,14,0,0,0,110,1,0,0,44,3,0,0,91,6,0,0,107,25,0,0,2,0,0,0,15,0,0,0,216,1,0,0,141,0,0,0,180,0,0,0,228,1,0,0,103,0,0,0,23,3,0,0,148,7,0,0,34,0,0,0,190,3,0,0,21,3,0,0,52,0,0,0,55,0,0,0,222,2,0,0,108,0,0,0,254,14,0,0,108,6,0,0,40,0,0,0,203,3,0,0,172,3,0,0,53,0,0,0,107,1,0,0,189,3,0,0,193,2,0,0,44,6,0,0,254,29,0,0,14,0,0,0,158,5,0,0,191,5,0,0,218,0,0,0,41,6,0,0,132,5,0,0,183,14,0,0,10,11,0,0,109,6,0,0,12,0,0,0,126,7,0,0,156,5,0,0,120,7,0,0,94,7,0,0,90,7,0,0,45,6,0,0,55,3,0,0,52,3,0,0,151,1,0,0,87,30,0,0,228,29,0,0,106,25,0,0,86,30,0,0,80,12,0,0,63,11,0,0,84,30,0,0,11,11,0,0,142,1,0,0,182,1,0,0,85,30,0,0,180,12,0,0,62,11,0,0,182,14,0,0,229,29,0,0,255,29,0,0,53,3,0,0,183,1,0,0,1,0,0,0,11,0,0,0,25,0,0,0,111,0,0,0,42,0,0,0,117,0,0,0,235,7,0,0,99,1,0,0,1,0,0,0,14,0,0,0,26,0,0,0,62,0,0,0,28,0,0,0,45,0,0,0,100,1,0,0,236,7,0,0,101,1,0,0,4,0,0,0,6,0,0,0,54,0,0,0,127,0,0,0,174,0,0,0,88,1,0,0,92,1,0,0,109,5,0,0,16,213,15,0,0,0,0,0,4,0,0,0,123,0,0,0,243,0,0,0,59,0,0,0,237,7,0,0,179,2,0,0,204,2,0,0,110,5,0,0,24,0,0,0,62,0,0,0,23,0,0,0,30,0,0,0,175,0,0,0,247,3,0,0,111,5,0,0,205,2,0,0,17,213,15,0,20,0,0,0,173,0,0,0,170,0,0,0,20,0,0,0,168,0,0,0,83,1,0,0,232,0,0,0,254,1,0,0,207,13,0,0,120,0,0,0,184,1,0,0,82,1,0,0,254,0,0,0,177,2,0,0,93,1,0,0,96,1,0,0,18,213,15,0,19,213,15,0,122,0,0,0,176,2,0,0,229,1,0,0,233,0,0,0,252,0,0,0,230,6,0,0,200,13,0,0,132,5,0,0,20,213,15,0,171,0,0,0,222,13,0,0,89,1,0,0,244,3,0,0,201,13,0,0,202,13,0,0,250,1,0,0,21,213,15,0,22,213,15,0,252,0,0,0,255,1,0,0,228,1,0,0,175,0,0,0,90,1,0,0,103,1,0,0,203,13,0,0,133,5,0,0,23,213,15,0,247,3,0,0,85,63,0,0,24,213,15,0,220,13,0,0,134,5,0,0,86,63,0,0,25,213,15,0,87,63,0,0,26,213,15,0,186,1,0,0,135,5,0,0,136,5,0,0,223,13,0,0,178,2,0,0,27,213,15,0,206,13,0,0,246,3,0,0,28,213,15,0,212,15,0,0,29,213,15,0,30,213,15,0,31,213,15,0,128,234,7,0,129,234,7,0,108,5,0,0,130,234,7,0,131,234,7,0,118,3,0,0,137,5,0,0,138,5,0,0,132,234,7,0,133,234,7,0,221,13,0,0,134,234,7,0,135,234,7,0,139,5,0,0,169,126,0,0,3,0,0,0,14,0,0,0,15,0,0,0,126,0,0,0,98,0,0,0,198,0,0,0,217,12,0,0,62,6,0,0,2,0,0,0,2,0,0,0,0,0,0,0,24,0,0,0,12,0,0,0,105,0,0,0,57,0,0,0,7,7,0,0,126,12,0,0,2,0,0,0,13,0,0,0,27,0,0,0,15,0,0,0,154,1,0,0,71,6,0,0,55,26,0,0,196,70,3,0,109,52,0,0,1,0,0,0,30,0,0,0,127,0,0,0,10,0,0,0,225,0,0,0,97,6,0,0,228,12,0,0,197,70,3,0,198,70,3,0,29,0,0,0,48,0,0,0,13,0,0,0,203,0,0,0,153,1,0,0,32,3,0,0,142,0,0,0,46,101,0,0,199,70,3,0,62,0,0,0,57,0,0,0,53,0,0,0,51,0,0,0,159,1,0,0,192,1,0,0,218,12,0,0,200,70,3,0,201,70,3,0,11,0,0,0,208,0,0,0,158,1,0,0,34,0,0,0,56,0,0,0,142,1,0,0,30,3,0,0,148,50,0,0,60,2,0,0,50,0,0,0,18,0,0,0,19,0,0,0,113,0,0,0,157,1,0,0,32,0,0,0,135,12,0,0,192,12,0,0,202,70,3,0,56,3,0,0,83,6,0,0,162,1,0,0,42,3,0,0,34,3,0,0,231,12,0,0,132,0,0,0,31,1,0,0,203,70,3,0,37,3,0,0,73,6,0,0,43,3,0,0,119,0,0,0,72,6,0,0,66,6,0,0,134,12,0,0,140,12,0,0,204,70,3,0,58,0,0,0,183,25,0,0,67,0,0,0,39,3,0,0,140,0,0,0,141,0,0,0,141,12,0,0,205,70,3,0,206,70,3,0,55,3,0,0,229,12,0,0,133,0,0,0,38,3,0,0,71,3,0,0,164,12,0,0,127,12,0,0,26,13,0,0,207,70,3,0,40,3,0,0,96,163,1,0,97,163,1,0,216,12,0,0,140,6,0,0,149,50,0,0,150,50,0,0,47,101,0,0,216,102,0,0,49,3,0,0,6,7,0,0,61,2,0,0,118,0,0,0,193,12,0,0,130,3,0,0,230,12,0,0,217,102,0,0,218,102,0,0,219,102,0,0,4,5,5,5,6,7,8,10,2,5,5,6,6,7,8,9,10,4,5,6,6,7,8,9,10,11,4,6,6,7,7,9,9,10,12,5,8,8,8,8,9,9,10,12,5,7,8,7,7,8,9,9,11,7,9,10,9,10,10,10,10,12,6,9,9,9,9,9,10,10,11,7,10,10,11,11,11,12,12,14,8,11,10,11,11,11,11,12,12,8,12,11,11,12,12,12,12,13,8,12,11,11,12,12,12,13,12,9,14,13,11,13,12,13,12,13,9,13,13,12,12,13,13,13,13,13,3,4,5,6,8,10,11,11,2,5,5,6,7,8,10,11,11,4,5,5,6,7,9,12,13,13,4,6,7,7,9,10,11,13,14,5,7,7,7,8,9,11,13,13,6,8,8,8,8,9,10,12,13,7,9,8,8,8,9,11,12,13,7,9,9,9,9,9,10,11,13,8,10,10,10,10,10,11,12,13,9,11,11,10,10,10,11,11,12,10,12,12,12,11,11,11,12,12,10,13,12,12,11,11,11,12,12,10,13,13,12,13,11,12,11,12,10,14,13,13,12,12,12,11,11,11,4,4,5,5,6,7,8,9,2,5,6,6,6,7,7,9,9,4,6,6,6,7,8,9,11,12,5,7,7,7,9,9,10,11,12,5,7,7,7,7,9,9,10,12,5,8,8,8,8,8,9,10,10,6,9,8,8,8,8,9,9,11,6,10,10,9,9,9,9,10,10,7,11,10,9,9,10,9,10,11,7,10,11,10,10,10,9,10,11,8,12,11,11,10,11,11,10,10,8,12,12,11,11,11,11,10,11,8,13,12,12,11,11,11,11,10,9,13,12,12,12,11,11,10,10,10,3,4,6,7,7,9,11,11,2,5,5,6,8,9,10,11,13,3,5,5,7,8,9,12,14,13,4,6,6,7,9,11,13,14,14,5,7,7,8,9,9,13,15,13,6,8,8,8,9,10,12,14,13,7,10,9,9,9,9,12,13,14,7,11,10,10,10,10,11,12,13,8,11,12,12,12,11,12,14,15,9,11,12,11,12,11,11,12,13,9,12,13,13,12,12,13,14,14,9,12,13,13,13,12,13,12,14,10,13,13,14,13,11,13,14,15,10,12,13,15,14,13,13,13,14,14,4,5,5,5,6,7,8,8,2,6,6,6,6,6,8,9,10,4,6,6,6,6,7,9,10,11,4,7,7,7,7,7,9,10,12,5,7,7,7,7,7,9,10,11,6,8,8,7,7,7,8,9,10,6,9,8,8,7,8,10,10,11,7,9,9,8,8,8,9,9,10,8,10,10,9,9,9,11,11,11,8,11,10,10,9,9,10,11,10,10,12,12,11,11,10,11,12,11,10,13,12,11,11,10,10,11,11,11,15,13,13,13,12,12,12,12,10,15,14,13,12,12,11,11,11,11,4,5,6,6,6,7,8,8,2,4,5,6,6,7,8,8,9,4,6,7,7,8,8,9,10,11,5,6,7,7,8,8,9,10,12,5,7,8,8,8,9,10,11,12,5,7,8,8,8,8,9,10,11,6,8,9,8,8,9,10,11,13,5,8,9,8,8,9,9,10,11,6,10,10,9,9,10,10,12,13,6,10,10,9,9,10,10,11,13,7,11,11,11,11,11,12,12,13,7,11,11,11,11,11,11,12,12,9,13,13,13,13,12,12,13,12,9,12,13,12,12,12,13,13,12,12,3,5,6,8,9,10,12,12,1,5,6,7,8,9,12,12,12,4,6,7,8,9,12,12,14,21,4,6,8,9,9,12,13,13,14,6,9,8,8,9,13,14,13,21,6,9,9,8,9,10,11,12,13,8,10,10,11,11,12,12,21,21,8,11,10,11,11,12,13,14,21,9,13,10,11,13,13,12,21,21,9,12,10,11,12,12,13,14,21,11,15,21,13,14,15,21,15,21,10,14,14,13,13,21,13,13,21,13,21,21,21,20,20,14,20,20,11,14,14,20,20,13,20,20,14,16,2,5,6,8,9,10,13,13,2,4,5,6,8,9,10,13,14,3,5,7,8,10,12,15,20,16,4,6,8,8,10,12,13,20,20,7,8,8,9,10,11,12,16,20,7,8,8,8,10,11,13,20,20,8,10,10,10,10,11,12,15,14,8,9,9,9,10,10,13,13,20,11,12,11,11,11,13,12,13,20,11,12,11,11,12,12,13,13,20,10,14,11,11,12,12,13,20,20,11,13,12,11,12,13,14,14,20,11,19,19,13,13,15,15,16,16,11,13,14,11,13,12,13,16,16,16,2,1,0,3,1,0,2,3,2,0,3,1,1,3,2,0,2,2,2,2,1,2,3,3,3,2,3,1,1,3,3,2,5,0,0,0,12,0,0,0,30,0,0,0,18,0,0,0,12,0,0,0,52,0,0,0,117,0,0,0,112,0,0,0,0,0,0,0,8,0,0,0,27,0,0,0,8,0,0,0,29,0,0,0,124,0,0,0,214,0,0,0,222,1,0,0,175,1,0,0,5,0,0,0,27,0,0,0,38,0,0,0,30,0,0,0,18,0,0,0,118,0,0,0,77,0,0,0,246,1,0,0,244,1,0,0,57,0,0,0,127,0,0,0,39,0,0,0,106,0,0,0,113,0,0,0,53,0,0,0,113,0,0,0,104,0,0,0,220,1,0,0,39,0,0,0,115,0,0,0,255,0,0,0,232,0,0,0,233,0,0,0,126,0,0,0,249,1,0,0,245,1,0,0,253,1,0,0,62,0,0,0,202,1,0,0,249,3,0,0,76,0,0,0,105,0,0,0,250,1,0,0,223,1,0,0,247,1,0,0,112,0,0,0,221,1,0,0,77,14,0,0,39,7,0,0,146,3,0,0,200,1,0,0,203,1,0,0,248,3,0,0,174,1,0,0,248,1,0,0,251,1,0,0,206,228,0,0,207,228,0,0,96,114,0,0,97,114,0,0,98,114,0,0,99,114,0,0,100,114,0,0,101,114,0,0,102,114,0,0,7,0,0,0,1,0,0,0,7,0,0,0,22,0,0,0,1,0,0,0,69,0,0,0,24,0,0,0,182,2,0,0,6,0,0,0,4,0,0,0,23,0,0,0,16,0,0,0,41,0,0,0,44,0,0,0,90,1,0,0,102,0,0,0,158,1,0,0,9,0,0,0,40,0,0,0,23,0,0,0,0,0,0,0,42,0,0,0,4,0,0,0,91,0,0,0,181,0,0,0,206,0,0,0,6,0,0,0,68,0,0,0,15,0,0,0,70,0,0,0,14,0,0,0,172,0,0,0,50,0,0,0,55,0,0,0,235,17,0,0,10,0,0,0,26,0,0,0,31,1,0,0,22,0,0,0,20,0,0,0,43,0,0,0,104,1,0,0,85,0,0,0,213,35,0,0,87,0,0,0,47,0,0,0,54,0,0,0,46,0,0,0,105,1,0,0,84,0,0,0,123,4,0,0,159,1,0,0,125,43,0,0,142,0,0,0,222,10,0,0,121,4,0,0,110,5,0,0,244,8,0,0,191,21,0,0,120,4,0,0,212,35,0,0,241,173,0,0,249,86,0,0,14,223,10,0,15,223,10,0,128,111,5,0,129,111,5,0,130,111,5,0,131,111,5,0,132,111,5,0,133,111,5,0,134,111,5,0,2,0,0,0,6,0,0,0,7,0,0,0,13,0,0,0,7,0,0,0,48,0,0,0,255,0,0,0,240,1,0,0,2,0,0,0,0,0,0,0,5,0,0,0,25,0,0,0,30,0,0,0,7,0,0,0,99,0,0,0,253,0,0,0,35,0,0,0,14,0,0,0,27,0,0,0,26,0,0,0,6,0,0,0,9,0,0,0,24,0,0,0,197,0,0,0,51,0,0,0,241,1,0,0,2,0,0,0,251,3,0,0,243,1,0,0,34,0,0,0,252,1,0,0,66,0,0,0,35,6,0,0,131,0,0,0,32,6,0,0,125,0,0,0,64,0,0,0,67,0,0,0,228,3,0,0,229,3,0,0,145,1,0,0,233,15,0,0,5,1,0,0,8,2,0,0,252,0,0,0,36,6,0,0,34,6,0,0,144,1,0,0,38,6,0,0,245,7,0,0,75,12,0,0,208,31,0,0,77,16,0,0,101,0,0,0,66,12,0,0,201,0,0,0,39,6,0,0,67,12,0,0,74,12,0,0,78,16,0,0,209,31,0,0,79,16,0,0,18,4,0,0,206,4,1,0,207,4,1,0,96,130,0,0,97,130,0,0,98,130,0,0,99,130,0,0,100,130,0,0,101,130,0,0,102,130,0,0,13,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,23,0,0,0,5,0,0,0,127,0,0,0,77,0,0,0,3,0,0,0,17,0,0,0,62,0,0,0,59,0,0,0,23,0,0,0,103,0,0,0,74,0,0,0,195,0,0,0,242,0,0,0,10,0,0,0,44,0,0,0,50,0,0,0,61,0,0,0,21,0,0,0,40,0,0,0,147,0,0,0,204,0,0,0,150,0,0,0,3,0,0,0,117,0,0,0,32,0,0,0,45,0,0,0,33,0,0,0,41,0,0,0,144,0,0,0,208,1,0,0,251,1,0,0,28,0,0,0,76,0,0,0,96,0,0,0,9,0,0,0,8,0,0,0,45,0,0,0,159,0,0,0,250,1,0,0,61,1,0,0,49,0,0,0,252,0,0,0,88,0,0,0,146,0,0,0,240,0,0,0,241,0,0,0,205,0,0,0,133,1,0,0,101,1,0,0,78,0,0,0,145,0,0,0,233,0,0,0,132,1,0,0,209,1,0,0,230,1,0,0,151,0,0,0,231,1,0,0,179,0,0,0,60,1,0,0,78,22,0,0,79,22,0,0,32,11,0,0,33,11,0,0,34,11,0,0,35,11,0,0,36,11,0,0,37,11,0,0,38,11,0,0,3,4,5,5,5,6,7,7,2,4,5,5,6,7,8,9,9,4,6,6,6,6,7,8,9,9,6,8,7,7,7,7,8,8,9,6,8,8,8,8,8,9,9,9,7,10,10,8,8,9,9,9,8,9,13,12,11,10,10,10,9,9,9,17,17,16,16,16,16,16,16,16,3,3,4,5,5,7,8,10,3,4,5,5,6,7,9,10,12,4,6,6,5,6,6,8,9,11,4,7,7,7,7,8,9,9,13,5,8,9,8,8,9,10,10,14,7,9,9,9,10,10,11,12,14,8,12,11,11,12,13,11,14,16,15,20,20,19,19,19,19,19,19,19,3,4,4,4,5,6,8,9,2,4,5,5,5,6,7,8,8,4,7,7,6,6,7,8,8,9,5,10,9,8,9,9,11,10,11,7,9,9,10,10,11,12,11,12,8,11,11,11,11,11,12,13,15,9,12,10,11,12,12,15,13,15,13,19,19,18,18,18,18,18,18,18,4,4,4,4,5,5,7,7,3,5,6,6,6,7,7,8,8,4,6,6,6,6,7,8,8,8,4,7,6,6,6,7,8,9,9,5,7,7,6,6,7,8,9,9,6,8,8,8,8,8,8,9,10,7,8,8,9,9,9,8,9,9,9,14,14,13,13,13,13,13,13,13,120,158,33,0,112,73,35,0,0,0,0,0,156,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,3,0,0,0,0,0,0,0,0,0,0,226,0,0,0,88,10,0,0,0,0,0,0,0,0,0,0,232,158,33,0,208,73,35,0,0,0,0,0,109,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,9,0,0,0,0,0,0,0,0,0,0,142,1,0,0,2,7,0,0,0,0,0,0,0,0,0,0,24,159,33,0,232,73,35,0,0,0,0,0,158,0,0,0,0,0,0,0,0,0,0,0,248,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,4,0,0,0,0,0,0,242,0,0,0,0,0,0,0,76,5,0,0,0,0,0,0,0,0,0,0,48,159,33,0,8,74,35,0,0,0,0,0,158,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,7,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,64,33,0,216,22,32,0,0,0,0,0,56,48,52,86,0,0,0,0,0,0,0,0,224,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,2,0,0,0,0,0,0,192,1,0,0,0,0,0,0,78,4,0,0,0,0,0,0,0,0,0,0,168,64,33,0,32,23,32,0,0,0,0,0,56,48,52,86,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,10,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,159,33,0,136,74,35,0,0,0,0,0,56,48,51,86,0,0,0,0,0,0,0,0,8,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,8,0,0,0,0,0,0,112,2,0,0,0,0,0,0,114,1,0,0,0,0,0,0,0,0,0,0,224,159,33,0,168,74,35,0,0,0,0,0,56,48,51,86,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,200,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,2,3,3,9,5,5,4,33,7,32,7,17,6,1,1,0,3,1,3,1,2,8,160,33,0,200,74,35,0,0,0,0,0,126,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,1,0,0,0,0,0,0,0,0,0,0,118,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,160,33,0,0,75,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,16,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,6,0,0,0,0,0,0,76,1,0,0,0,0,0,0,166,2,0,0,0,0,0,0,0,0,0,0,0,161,33,0,80,75,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,116,2,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,2,0,0,0,0,0,0,0,0,0,0,92,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,161,33,0,152,75,35,0,0,0,0,0,154,0,0,0,0,0,0,0,0,0,0,0,24,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,9,0,0,0,0,0,0,98,1,0,0,0,0,0,0,138,10,0,0,0,0,0,0,0,0,0,0,48,162,33,0,224,75,35,0,0,0,0,0,154,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,8,0,0,0,0,0,0,0,0,0,0,134,2,0,0,132,4,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,224,210,28,0,0,169,33,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,6,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,2,0,0,0,0,0,0,0,0,0,0,16,167,33,0,144,76,35,0,0,0,0,0,58,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,9,0,0,0,0,0,0,0,0,0,0,76,0,0,0,102,10,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,31,32,32,32,32,32,32,32,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,3,3,3,3,3,3,3,3,3,3,3,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1098220);
/* memory initializer */ allocate([3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,211,28,0,144,169,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,1,0,0,124,10,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,167,33,0,160,76,35,0,0,0,0,0,106,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,136,167,33,0,208,76,35,0,1,0,0,0,44,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,3,0,0,0,0,0,0,0,0,0,0,202,0,0,0,26,6,0,0,0,0,0,0,0,0,0,0,104,212,28,0,216,169,33,0,0,0,0,0,224,105,32,0,0,0,0,0,248,191,2,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,104,3,0,0,250,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,237,16,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,10,9,10,12,0,0,0,0,240,167,33,0,8,77,35,0,1,0,0,0,22,80,1,0,64,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,56,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,74,2,0,0,0,0,0,0,18,7,0,0,0,0,0,0,0,0,0,0,248,212,28,0,56,170,33,0,0,0,0,0,248,212,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,150,8,0,0,74,6,0,0,238,2,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,168,33,0,152,77,35,0,1,0,0,0,22,80,1,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,192,2,0,0,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,1,0,0,0,0,0,0,0,0,0,0,8,1,0,0,204,10,0,0,0,0,0,0,0,0,0,0,232,169,33,0,248,77,35,0,0,0,0,0,57,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,10,0,0,0,0,0,0,0,0,0,0,172,0,0,0,232,5,0,0,0,0,0,0,0,0,0,0,176,169,33,0,208,77,35,0,0,0,0,0,165,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,8,0,0,0,0,0,0,0,0,0,0,114,1,0,0,172,6,0,0,0,0,0,0,0,0,0,0,40,170,33,0,24,78,35,0,1,0,0,0,21,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,222,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,170,33,0,88,78,35,0,0,0,0,0,78,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,5,0,0,0,0,0,0,0,0,0,0,126,1,0,0,80,6,0,0,0,0,0,0,0,0,0,0,32,172,33,0,152,78,35,0,0,0,0,0,52,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,9,0,0,0,0,0,0,0,0,0,0,46,1,0,0,204,4,0,0,0,0,0,0,0,0,0,0,200,62,30,0,112,50,30,0,0,0,0,0,176,40,30,0,45,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,2,35,0,56,194,34,0,0,1,0,0,224,132,34,0,0,0,0,0,0,0,0,0,0,0,0,0,45,80,1,0,0,0,0,0,0,0,0,0,138,1,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,89,33,0,8,44,32,0,1,0,0,0,45,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,8,0,0,0,0,0,0,0,0,0,0,60,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,32,37,31,31,0,0,0,0,0,0,0,0,9,9,10,14,14,14,14,14,14,14,14,14,14,0,0,0,31,31,34,40,42,51,46,46,42,42,42,39,39,0,0,0,40,213,28,0,112,170,33,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,6,5,0,0,22,4,0,0,100,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,172,33,0,176,78,35,0,0,0,0,0,127,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,9,0,0,0,0,0,0,0,0,0,0,148,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,91,5,230,27,151,169,73,67,136,23,26,101,90,41,138,151,116,0,105,0,109,0,101,0,108,0,105,0,110,0,101,0,46,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,101,0,110,0,116,0,114,0,105,0,101,0,115,0,46,0,69,0,118,0,101,0,110,0,116,0,115,0,0,0,116,0,105,0,109,0,101,0,108,0,105,0,110,0,101,0,208,91,31,0,0,0,0,0,184,48,31,0,177,135,0,0,144,29,31,0,0,0,0,0,104,17,31,0,0,0,0,0,120,244,33,0,56,244,33,0,248,243,33,0,136,243,33,0,160,242,33,0,72,242,33,0,232,241,33,0,144,241,33,0,88,241,33,0,224,240,33,0,144,240,33,0,88,240,33,0,168,239,33,0,64,239,33,0,216,238,33,0,136,238,33,0,64,238,33,0,136,237,33,0,80,237,33,0,240,236,33,0,112,236,33,0,24,236,33,0,216,235,33,0,128,235,33,0,96,235,33,0,32,235,33,0,144,234,33,0,192,233,33,0,152,233,33,0,72,233,33,0,192,232,33,0,112,232,33,0,117,39,0,0,208,166,34,0,118,39,0,0,48,164,34,0,147,39,0,0,104,162,34,0,148,39,0,0,144,161,34,0,217,39,0,0,136,160,34,0,218,39,0,0,96,160,34,0,219,39,0,0,40,160,34,0,247,39,0,0,200,159,34,0,248,39,0,0,80,159,34,0,249,39,0,0,208,158,34,0,61,40,0,0,64,158,34,0,62,40,0,0,208,157,34,0,91,40,0,0,48,157,34,0,92,40,0,0,208,156,34,0,161,40,0,0,88,156,34,0,162,40,0,0,48,156,34,0,163,40,0,0,216,155,34,0,164,40,0,0,160,155,34,0,165,40,0,0,16,155,34,0,166,40,0,0,192,154,34,0,167,40,0,0,152,153,34,0,191,40,0,0,88,153,34,0,192,40,0,0,80,152,34,0,193,40,0,0,152,151,34,0,194,40,0,0,48,151,34,0,195,40,0,0,224,150,34,0,196,40,0,0,160,150,34,0,5,41,0,0,80,150,34,0,6,41,0,0,16,149,34,0,7,41,0,0,160,148,34,0,35,41,0,0,96,148,34,0,36,41,0,0,40,148,34,0,37,41,0,0,144,147,34,0,104,41,0,0,64,147,34,0,134,41,0,0,240,146,34,0,204,41,0,0,200,146,34,0,234,41,0,0,144,146,34,0,149,42,0,0,232,145,34,0,150,42,0,0,208,144,34,0,151,42,0,0,96,144,34,0,179,42,0,0,16,144,34,0,180,42,0,0,168,143,34,0,181,42,0,0,224,142,34,0,249,42,0,0,96,142,34,0,250,42,0,0,248,141,34,0,23,43,0,0,168,141,34,0,24,43,0,0,16,141,34,0,93,43,0,0,192,140,34,0,94,43,0,0,112,140,34,0,95,43,0,0,88,140,34,0,123,43,0,0,240,139,34,0,124,43,0,0,136,139,34,0,125,43,0,0,168,138,34,0,193,43,0,0,104,138,34,0,194,43,0,0,248,137,34,0,223,43,0,0,184,137,34,0,224,43,0,0,104,137,34,0,37,44,0,0,216,136,34,0,38,44,0,0,8,136,34,0,67,44,0,0,192,135,34,0,68,44,0,0,64,134,34,0,137,44,0,0,8,134,34,0,138,44,0,0,32,133,34,0,167,44,0,0,176,132,34,0,168,44,0,0,88,132,34,0,237,44,0,0,56,132,34,0,238,44,0,0,168,131,34,0,11,45,0,0,128,131,34,0,12,45,0,0,72,131,34,0,81,45,0,0,24,131,34,0,82,45,0,0,160,130,34,0,111,45,0,0,208,129,34,0,112,45,0,0,216,128,34,0,181,45,0,0,88,128,34,0,182,45,0,0,192,127,34,0,211,45,0,0,152,127,34,0,212,45,0,0,72,127,34,0,25,46,0,0,216,126,34,0,26,46,0,0,24,126,34,0,55,46,0,0,232,125,34,0,56,46,0,0,40,125,34,0,124,46,0,0,16,125,34,0,154,46,0,0,160,124,34,0,225,46,0,0,80,124,34,0,226,46,0,0,8,124,34,0,255,46,0,0,176,123,34,0,0,47,0,0,80,123,34,0,69,47,0,0,32,123,34,0,70,47,0,0,224,122,34,0,71,47,0,0,184,122,34,0,79,47,0,0,120,122,34,0,80,47,0,0,112,121,34,0,81,47,0,0,216,119,34,0,109,47,0,0,144,117,34,0,110,47,0,0,48,115,34,0,111,47,0,0,184,113,34,0,169,47,0,0,136,112,34,0,170,47,0,0,184,111,34,0,171,47,0,0,16,110,34,0,199,47,0,0,208,108,34,0,200,47,0,0,248,106,34,0,201,47,0,0,88,104,34,0,13,48,0,0,72,102,34,0,14,48,0,0,56,101,34,0,43,48,0,0,160,100,34,0,44,48,0,0,48,100,34,0,113,48,0,0,168,99,34,0,114,48,0,0,24,99,34,0,115,48,0,0,176,98,34,0,143,48,0,0,16,98,34,0,144,48,0,0,216,97,34,0,145,48,0,0,144,97,34,0,213,48,0,0,224,96,34,0,214,48,0,0,104,96,34,0,215,48,0,0,200,95,34,0,242,48,0,0,168,95,34,0,57,49,0,0,72,95,34,0,58,49,0,0,208,94,34,0,86,49,0,0,80,94,34,0,157,49,0,0,8,94,34,0,158,49,0,0,160,93,34,0,159,49,0,0,104,93,34,0,187,49,0,0,128,92,34,0,188,49,0,0,200,91,34,0,189,49,0,0,48,91,34,0,0,50,0,0,184,90,34,0,30,50,0,0,128,90,34,0,100,50,0,0,72,90,34,0,130,50,0,0,240,89,34,0,201,50,0,0,152,89,34,0,202,50,0,0,88,89,34,0,203,50,0,0,16,89,34,0,231,50,0,0,184,88,34,0,232,50,0,0,96,88,34,0,233,50,0,0,0,88,34,0,45,51,0,0,216,87,34,0,46,51,0,0,168,87,34,0,47,51,0,0,16,87,34,0,48,51,0,0,56,86,34,0,75,51,0,0,240,85,34,0,76,51,0,0,168,85,34,0,77,51,0,0,96,85,34,0,78,51,0,0,56,84,34,0,144,51,0,0,224,83,34,0,174,51,0,0,8,83,34,0,245,51,0,0,208,82,34,0,246,51,0,0,112,82,34,0,19,52,0,0,72,82,34,0,20,52,0,0,0,82,34,0,89,52,0,0,200,81,34,0,90,52,0,0,160,81,34,0,119,52,0,0,0,81,34,0,120,52,0,0,248,79,34,0,189,52,0,0,160,79,34,0,190,52,0,0,24,79,34,0,219,52,0,0,216,78,34,0,220,52,0,0,152,78,34,0,33,53,0,0,40,78,34,0,34,53,0,0,200,77,34,0,63,53,0,0,120,77,34,0,64,53,0,0,40,77,34,0,133,53,0,0,176,76,34,0,134,53,0,0,80,76,34,0,163,53,0,0,240,75,34,0,164,53,0,0,184,75,34,0,232,53,0,0,112,75,34,0,6,54,0,0,176,74,34,0,77,54,0,0,112,74,34,0,78,54,0,0,56,74,34,0,106,54,0,0,248,73,34,0,177,54,0,0,72,73,34,0,178,54,0,0,240,72,34,0,207,54,0,0,184,71,34,0,208,54,0,0,96,71,34,0,20,55,0,0,40,71,34,0,50,55,0,0,248,70,34,0,121,55,0,0,224,70,34,0,122,55,0,0,152,70,34,0,123,55,0,0,224,69,34,0,124,55,0,0,152,69,34,0,125,55,0,0,112,68,34,0,151,55,0,0,16,68,34,0,152,55,0,0,160,67,34,0,153,55,0,0,112,67,34,0,154,55,0,0,72,67,34,0,155,55,0,0,16,67,34,0,221,55,0,0,240,66,34,0,222,55,0,0,184,66,34,0,223,55,0,0,24,66,34,0,251,55,0,0,200,65,34,0,252,55,0,0,96,65,34,0,253,55,0,0,120,64,34,0,64,56,0,0,80,63,34,0,94,56,0,0,48,61,34,0,165,56,0,0,144,59,34,0,166,56,0,0,240,57,34,0,195,56,0,0,88,56,34,0,196,56,0,0,160,55,34,0,9,57,0,0,224,53,34,0,10,57,0,0,176,52,34,0,39,57,0,0,176,50,34,0,40,57,0,0,136,48,34,0,109,57,0,0,8,47,34,0,110,57,0,0,200,45,34,0,139,57,0,0,80,45,34,0,140,57,0,0,248,44,34,0,209,57,0,0,16,44,34,0,210,57,0,0,192,43,34,0,211,57,0,0,56,43,34,0,239,57,0,0,128,42,34,0,240,57,0,0,40,42,34,0,241,57,0,0,160,41,34,0,53,58,0,0,208,40,34,0,54,58,0,0,152,40,34,0,55,58,0,0,88,40,34,0,56,58,0,0,24,40,34,0,83,58,0,0,232,39,34,0,84,58,0,0,152,39,34,0,85,58,0,0,88,39,34,0,86,58,0,0,40,39,34,0,153,58,0,0,208,38,34,0,154,58,0,0,136,38,34,0,155,58,0,0,8,38,34,0,156,58,0,0,216,37,34,0,157,58,0,0,120,37,34,0,158,58,0,0,32,37,34,0,159,58,0,0,0,37,34,0,160,58,0,0,224,36,34,0,161,58,0,0,104,36,34,0,162,58,0,0,72,36,34,0,183,58,0,0,0,36,34,0,184,58,0,0,184,35,34,0,185,58,0,0,24,35,34,0,186,58,0,0,200,34,34,0,187,58,0,0,72,34,34,0,188,58,0,0,8,34,34,0,189,58,0,0,216,33,34,0,190,58,0,0,64,33,34,0,191,58,0,0,192,32,34,0,192,58,0,0,144,32,34,0,253,58,0,0,104,32,34,0,254,58,0,0,64,32,34,0,255,58,0,0,208,31,34,0,0,59,0,0,144,31,34,0,1,59,0,0,88,31,34,0,27,59,0,0,32,31,34,0,28,59,0,0,144,30,34,0,29,59,0,0,112,30,34,0,30,59,0,0,72,30,34,0,31,59,0,0,48,30,34,0,97,59,0,0,192,29,34,0,98,59,0,0,80,29,34,0,126,59,0,0,224,28,34,0,42,62,0,0,192,28,34,0,43,62,0,0,88,28,34,0,44,62,0,0,64,28,34,0,45,62,0,0,24,28,34,0,196,67,0,0,176,27,34,0,197,67,0,0,80,27,34,0,198,67,0,0,224,26,34,0,199,67,0,0,176,26,34,0,200,67,0,0,144,26,34,0,201,67,0,0,0,26,34,0,202,67,0,0,200,25,34,0,203,67,0,0,152,25,34,0,204,67,0,0,112,25,34,0,205,67,0,0,192,24,34,0,206,67,0,0,136,24,34,0,40,68,0,0,32,24,34,0,41,68,0,0,224,23,34,0,42,68,0,0,8,23,34,0,43,68,0,0,208,22,34,0,44,68,0,0,64,22,34,0,45,68,0,0,216,21,34,0,46,68,0,0,160,21,34,0,47,68,0,0,120,21,34,0,48,68,0,0,88,21,34,0,49,68,0,0,16,21,34,0,50,68,0,0,160,20,34,0,111,70,0,0,40,20,34,0,112,70,0,0,40,19,34,0,113,70,0,0,16,19,34,0,114,70,0,0,168,18,34,0,115,70,0,0,120,18,34,0,116,70,0,0,80,18,34,0,117,70,0,0,56,18,34,0,131,70,0,0,0,18,34,0,132,70,0,0,216,17,34,0,133,70,0,0,144,17,34,0,134,70,0,0,112,17,34,0,152,70,0,0,8,17,34,0,153,70,0,0,64,16,34,0,154,70,0,0,184,14,34,0,221,70,0,0,104,12,34,0,222,70,0,0,232,10,34,0,188,77,0,0,80,9,34,0,193,77,0,0,200,7,34,0,200,77,0,0,24,7,34,0,200,4,34,0,0,0,0,0,176,214,33,0,177,135,0,0,120,178,33,0,0,0,0,0,56,145,33,0,0,0,0,0,248,111,33,0,0,0,0,0,160,46,33,0,176,135,0,0,200,6,33,0,176,135,0,0,64,236,32,0,176,135,0,0,216,209,32,0,176,135,0,0,104,182,32,0,176,135,0,0,224,160,32,0,176,135,0,0,64,135,32,0,176,135,0,0,120,110,32,0,176,135,0,0,8,88,32,0,176,135,0,0,184,64,32,0,176,135,0,0,176,8,32,0,176,135,0,0,16,240,31,0,176,135,0,0,48,219,31,0,176,135,0,0,96,201,31,0,176,135,0,0,48,179,31,0,176,135,0,0,168,160,31,0,176,135,0,0,120,142,31,0,176,135,0,0,104,125,31,0,176,135,0,0,128,110,31,0,176,135,0,0,169,78,0,0,240,15,31,0,170,78,0,0,152,14,31,0,24,79,0,0,176,13,31,0,25,79,0,0,128,12,31,0,26,79,0,0,216,11,31,0,27,79,0,0,64,10,31,0,28,79,0,0,88,9,31,0,29,79,0,0,200,7,31,0,30,79,0,0,248,6,31,0,31,79,0,0,192,5,31,0,32,79,0,0,240,0,31,0,33,79,0,0,248,254,30,0,34,79,0,0,248,253,30,0,124,79,0,0,96,252,30,0,125,79,0,0,96,251,30,0,126,79,0,0,232,249,30,0,127,79,0,0,192,248,30,0,128,79,0,0,88,247,30,0,129,79,0,0,144,246,30,0,130,79,0,0,112,245,30,0,131,79,0,0,120,240,30,0,132,79,0,0,224,238,30,0,133,79,0,0,152,237,30,0,134,79,0,0,176,236,30,0,213,79,0,0,192,235,30,0,214,79,0,0,176,234,30,0,215,79,0,0,216,233,30,0,19,80,0,0,24,233,30,0,58,80,0,0,72,232,30,0,59,80,0,0,32,231,30,0,220,80,0,0,232,226,30,0,86,81,0,0,56,225,30,0,87,81,0,0,32,224,30,0,88,81,0,0,32,223,30,0,237,81,0,0,64,222,30,0,239,81,0,0,80,221,30,0,241,81,0,0,248,219,30,0,243,81,0,0,240,218,30,0,245,81,0,0,88,218,30,0,247,81,0,0,200,217,30,0,249,81,0,0,168,213,30,0,251,81,0,0,104,212,30,0,253,81,0,0,152,211,30,0,255,81,0,0,128,210,30,0,1,82,0,0,128,209,30,0,3,82,0,0,248,207,30,0,108,82,0,0,32,207,30,0,156,82,0,0,0,206,30,0,157,82,0,0,176,204,30,0,158,82,0,0,32,203,30,0,165,83,0,0,224,198,30,0,166,83,0,0,24,197,30,0,167,83,0,0,16,196,30,0,168,83,0,0,192,194,30,0,169,83,0,0,72,193,30,0,170,83,0,0,128,191,30,0,171,83,0,0,96,190,30,0,172,83,0,0,16,189,30,0,173,83,0,0,216,187,30,0,174,83,0,0,16,187,30,0,175,83,0,0,160,183,30,0,225,83,0,0,248,181,30,0,226,83,0,0,104,181,30,0,227,83,0,0,104,180,30,0,228,83,0,0,184,179,30,0,229,83,0,0,216,178,30,0,230,83,0,0,232,177,30,0,231,83,0,0,248,176,30,0,232,83,0,0,216,175,30,0,233,83,0,0,216,171,30,0,234,83,0,0,128,165,30,0,235,83,0,0,24,159,30,0,252,83,0,0,200,155,30,0,30,85,0,0,8,152,30,0,57,85,0,0,0,149,30,0,58,85,0,0,144,146,30,0,131,85,0,0,200,140,30,0,132,85,0,0,16,139,30,0,133,85,0,0,64,135,30,0,134,85,0,0,48,130,30,0,16,86,0,0,232,125,30,0,17,86,0,0,208,122,30,0,175,86,0,0,64,121,30,0,176,86,0,0,32,120,30,0,177,86,0,0,64,119,30,0,178,86,0,0,152,117,30,0,179,86,0,0,24,116,30,0,180,86,0,0,40,115,30,0,181,86,0,0,104,114,30,0,60,87,0,0,120,113,30,0,119,87,0,0,176,110,30,0,120,87,0,0,24,109,30,0,251,87,0,0,64,108,30,0,252,87,0,0,168,107,30,0,48,89,0,0,216,106,30,0,208,89,0,0,136,105,30,0,209,89,0,0,248,103,30,0,210,89,0,0,40,103,30,0,244,89,0,0,0,102,30,0,245,89,0,0,200,100,30,0,246,89,0,0,152,97,30,0,247,89,0,0,72,96,30,0,248,89,0,0,8,95,30,0,249,89,0,0,168,93,30,0,250,89,0,0,248,92,30,0,251,89,0,0,152,91,30,0,252,89,0,0,104,90,30,0,253,89,0,0,24,89,30,0,254,89,0,0,104,88,30,0,199,90,0,0,40,87,30,0,200,90,0,0,240,83,30,0,137,91,0,0,248,81,30,0,38,93,0,0,240,80,30,0,39,93,0,0,0,80,30,0,40,93,0,0,176,78,30,0,41,93,0,0,64,77,30,0,42,93,0,0,192,75,30,0,43,93,0,0,128,74,30,0,44,93,0,0,8,71,30,0,45,93,0,0,48,70,30,0,78,93,0,0,104,67,30,0,79,93,0,0,40,66,30,0,80,93,0,0,176,65,30,0,81,93,0,0,56,65,30,0,82,93,0,0,104,64,30,0,83,93,0,0,152,63,30,0,84,93,0,0,208,62,30,0,85,93,0,0,64,62,30,0,86,93,0,0,112,61,30,0,139,93,0,0,168,59,30,0,140,93,0,0,64,56,30,0,239,93,0,0,232,54,30,0,240,93,0,0,56,54,30,0,36,94,0,0,96,53,30,0,136,94,0,0,8,53,30,0,50,95,0,0,240,51,30,0,51,95,0,0,160,50,30,0,52,95,0,0,208,49,30,0,53,95,0,0,64,49,30,0,54,95,0,0,176,48,30,0,62,95,0,0,104,45,30,0,63,95,0,0,96,44,30,0,64,95,0,0,216,43,30,0,180,95,0,0,224,42,30,0,227,95,0,0,64,42,30,0,228,95,0,0,128,41,30,0,144,96,0,0,184,40,30,0,145,96,0,0,40,40,30,0,242,96,0,0,120,39,30,0,243,96,0,0,112,38,30,0,244,96,0,0,168,35,30,0,245,96,0,0,96,34,30,0,45,97,0,0,232,33,30,0,46,97,0,0,160,33,30,0,47,97,0,0,88,33,30,0,48,97,0,0,80,32,30,0,59,97,0,0,152,31,30,0,60,97,0,0,240,30,30,0,61,97,0,0,72,30,30,0,168,97,0,0,248,29,30,0,143,98,0,0,8,28,30,0,47,99,0,0,120,27,30,0,48,99,0,0,40,27,30,0,49,99,0,0,208,26,30,0,50,99,0,0,152,26,30,0,51,99,0,0,16,26,30,0,100,100,0,0,152,25,30,0,76,101,0,0,40,25,30,0,79,102,0,0,160,23,30,0,80,102,0,0,88,20,30,0,81,102,0,0,64,16,30,0,125,102,0,0,24,11,30,0,219,102,0,0,96,8,30,0,220,102,0,0,184,5,30,0,23,103,0,0,24,3,30,0,24,103,0,0,216,255,29,0,25,103,0,0,56,251,29,0,64,103,0,0,0,250,29,0,223,103,0,0,168,246,29,0,224,103,0,0,88,242,29,0,8,104,0,0,40,238,29,0,68,104,0,0,80,236,29,0,79,104,0,0,80,235,29,0,80,104,0,0,176,234,29,0,81,104,0,0,24,234,29,0,82,104,0,0,64,233,29,0,83,104,0,0,152,232,29,0,84,104,0,0,24,232,29,0,85,104,0,0,200,231,29,0,86,104,0,0,64,231,29,0,87,104,0,0,216,228,29,0,88,104,0,0,240,227,29,0,89,104,0,0,112,227,29,0,90,104,0,0,48,227,29,0,91,104,0,0,224,226,29,0,92,104,0,0,248,225,29,0,93,104,0,0,56,225,29,0,94,104,0,0,112,224,29,0,95,104,0,0,152,223,29,0,96,104,0,0,248,222,29,0,97,104,0,0,136,220,29,0,98,104,0,0,248,219,29,0,105,104,0,0,248,218,29,0,106,104,0,0,8,218,29,0,107,104,0,0,200,217,29,0,108,104,0,0,144,216,29,0,109,104,0,0,232,215,29,0,110,104,0,0,8,215,29,0,111,104,0,0,104,214,29,0,112,104,0,0,136,213,29,0,113,104,0,0,160,211,29,0,114,104,0,0,184,210,29,0,115,104,0,0,176,209,29,0,116,104,0,0,64,209,29,0,117,104,0,0,208,208,29,0,118,104,0,0,216,207,29,0,119,104,0,0,224,206,29,0,120,104,0,0,112,206,29,0,121,104,0,0,216,205,29,0,122,104,0,0,80,205,29,0,123,104,0,0,216,202,29,0,124,104,0,0,24,202,29,0,125,104,0,0,48,201,29,0,126,104,0,0,208,200,29,0,127,104,0,0,56,200,29,0,128,104,0,0,56,199,29,0,129,104,0,0,152,198,29,0,130,104,0,0,192,197,29,0,131,104,0,0,224,196,29,0,132,104,0,0,24,196,29,0,133,104,0,0,96,194,29,0,134,104,0,0,120,193,29,0,135,104,0,0,216,192,29,0,136,104,0,0,152,192,29,0,137,104,0,0,40,192,29,0,138,104,0,0,104,191,29,0,139,104,0,0,88,190,29,0,140,104,0,0,168,189,29,0,141,104,0,0,72,189,29,0,142,104,0,0,224,188,29,0,143,104,0,0,192,186,29,0,144,104,0,0,224,185,29,0,145,104,0,0,152,185,29,0,146,104,0,0,208,184,29,0,147,104,0,0,56,184,29,0,148,104,0,0,64,183,29,0,149,104,0,0,144,182,29,0,150,104,0,0,56,182,29,0,150,104,0,0,144,181,29,0,151,104,0,0,248,180,29,0,151,104,0,0,80,179,29,0,152,104,0,0,88,178,29,0,152,104,0,0,8,178,29,0,153,104,0,0,208,177,29,0,153,104,0,0,136,177,29,0,154,104,0,0,64,176,29,0,155,104,0,0,0,175,29,0,156,104,0,0,0,174,29,0,157,104,0,0,64,173,29,0,158,104,0,0,208,172,29,0,159,104,0,0,120,171,29,0,160,104,0,0,232,170,29,0,161,104,0,0,176,170,29,0,162,104,0,0,104,170,29,0,163,104,0,0,40,170,29,0,164,104,0,0,80,169,29,0,165,104,0,0,160,168,29,0,166,104,0,0,80,168,29,0,167,104,0,0,32,167,29,0,168,104,0,0,96,164,29,0,169,104,0,0,88,160,29,0,170,104,0,0,176,155,29,0,171,104,0,0,72,153,29,0,172,104,0,0,24,151,29,0,173,104,0,0,8,149,29,0,174,104,0,0,136,146,29,0,177,104,0,0,104,141,29,0,178,104,0,0,96,140,29,0,179,104,0,0,240,136,29,0,23,105,0,0,104,132,29,0,24,105,0,0,72,129,29,0,25,105,0,0,136,127,29,0,26,105,0,0,176,126,29,0,27,105,0,0,0,126,29,0,28,105,0,0,72,125,29,0,29,105,0,0,136,124,29,0,30,105,0,0,152,123,29,0,31,105,0,0,240,122,29,0,32,105,0,0,128,122,29,0,33,105,0,0,240,121,29,0,34,105,0,0,192,120,29,0,35,105,0,0,232,119,29,0,36,105,0,0,48,119,29,0,37,105,0,0,176,118,29,0,38,105,0,0,16,118,29,0,39,105,0,0,16,117,29,0,40,105,0,0,120,116,29,0,41,105,0,0,0,116,29,0,42,105,0,0,136,115,29,0,43,105,0,0,64,115,29,0,49,105,0,0,152,113,29,0,50,105,0,0,152,112,29,0,51,105,0,0,40,112,29,0,52,105,0,0,144,111,29,0,53,105,0,0,80,111,29,0,54,105,0,0,56,110,29,0,55,105,0,0,216,109,29,0,56,105,0,0,72,109,29,0,57,105,0,0,200,108,29,0,58,105,0,0,104,108,29,0,59,105,0,0,184,106,29,0,60,105,0,0,232,105,29,0,61,105,0,0,128,105,29,0,62,105,0,0,40,105,29,0,63,105,0,0,0,105,29,0,64,105,0,0,224,103,29,0,65,105,0,0,232,102,29,0,66,105,0,0,112,102,29,0,68,105,0,0,24,102,29,0,69,105,0,0,168,101,29,0,70,105,0,0,32,100,29,0,71,105,0,0,232,98,29,0,72,105,0,0,80,98,29,0,73,105,0,0,8,98,29,0,74,105,0,0,56,97,29,0,75,105,0,0,208,96,29,0,76,105,0,0,96,96,29,0,77,105,0,0,40,96,29,0,78,105,0,0,216,95,29,0,79,105,0,0,144,95,29,0,80,105,0,0,64,94,29,0,81,105,0,0,48,93,29,0,82,105,0,0,152,92,29,0,83,105,0,0,88,92,29,0,84,105,0,0,32,92,29,0,85,105,0,0,160,91,29,0,86,105,0,0,200,90,29,0,87,105,0,0,24,90,29,0,88,105,0,0,168,89,29,0,89,105,0,0,96,89,29,0,90,105,0,0,40,88,29,0,91,105,0,0,240,86,29,0,92,105,0,0,192,86,29,0,93,105,0,0,128,86,29,0,94,105,0,0,128,85,29,0,95,105,0,0,24,85,29,0,96,105,0,0,152,84,29,0,97,105,0,0,40,84,29,0,98,105,0,0,56,83,29,0,99,105,0,0,216,82,29,0,100,105,0,0,80,81,29,0,101,105,0,0,184,80,29,0,102,105,0,0,112,80,29,0,103,105,0,0,64,80,29,0,104,105,0,0,248,79,29,0,105,105,0,0,56,79,29,0,106,105,0,0,144,78,29,0,107,105,0,0,248,77,29,0,108,105,0,0,72,75,29,0,109,105,0,0,40,75,29,0,110,105,0,0,16,74,29,0,111,105,0,0,96,73,29,0,112,105,0,0,56,73,29,0,113,105,0,0,24,73,29,0,114,105,0,0,200,72,29,0,115,105,0,0,104,72,29,0,116,105,0,0,232,71,29,0,117,105,0,0,152,71,29,0,118,105,0,0,104,71,29,0,158,105,0,0,160,69,29,0,159,105,0,0,160,66,29,0,160,105,0,0,24,61,29,0,240,105,0,0,128,59,29,0,64,106,0,0,208,56,29,0,155,106,0,0,248,54,29,0,156,106,0,0,32,53,29,0,37,107,0,0,40,49,29,0,108,107,0,0,56,48,29,0,189,107,0,0,176,46,29,0,190,107,0,0,48,43,29,0,191,107,0,0,72,40,29,0,199,107,0,0,96,38,29,0,200,107,0,0,56,37,29,0,201,107,0,0,208,36,29,0,52,108,0,0,120,36,29,0,72,110,0,0,200,35,29,0,188,110,0,0,56,35,29,0,189,110,0,0,240,34,29,0,190,110,0,0,184,34,29,0,191,110,0,0,128,34,29,0,192,110,0,0,176,32,29,0,193,110,0,0,56,32,29,0,194,110,0,0,216,31,29,0,195,110,0,0,176,31,29,0,196,110,0,0,56,31,29,0,197,110,0,0,192,30,29,0,198,110,0,0,80,30,29,0,244,110,0,0,176,29,29,0,245,110,0,0,24,29,29,0,246,110,0,0,160,28,29,0,247,110,0,0,40,27,29,0,248,110,0,0,40,26,29,0,249,110,0,0,240,25,29,0,250,110,0,0,120,25,29,0,251,110,0,0,16,25,29,0,252,110,0,0,72,24,29,0,253,110,0,0,144,23,29,0,254,110,0,0,0,23,29,0,255,110,0,0,128,22,29,0,0,111,0,0,16,22,29,0,1,111,0,0,192,20,29,0,2,111,0,0,0,20,29,0,3,111,0,0,136,19,29,0,4,111,0,0,56,19,29,0,5,111,0,0,240,18,29,0,6,111,0,0,32,18,29,0,7,111,0,0,128,17,29,0,8,111,0,0,200,16,29,0,9,111,0,0,152,16,29,0,10,111,0,0,40,16,29,0,11,111,0,0,40,14,29,0,12,111,0,0,8,13,29,0,13,111,0,0,72,12,29,0,14,111,0,0,8,12,29,0,15,111,0,0,64,11,29,0,16,111,0,0,152,10,29,0,48,111,0,0,32,10,29,0,49,111,0,0,184,9,29,0,50,111,0,0,128,9,29,0,51,111,0,0,248,8,29,0,52,111,0,0,248,7,29,0,53,111,0,0,104,7,29,0,54,111,0,0,32,7,29,0,55,111,0,0,8,7,29,0,56,111,0,0,192,6,29,0,57,111,0,0,248,5,29,0,58,111,0,0,136,5,29,0,59,111,0,0,216,4,29,0,60,111,0,0,144,4,29,0,61,111,0,0,112,4,29,0,62,111,0,0,208,3,29,0,63,111,0,0,32,3,29,0,64,111,0,0,240,2,29,0,65,111,0,0,184,2,29,0,66,111,0,0,48,2,29,0,67,111,0,0,168,1,29,0,68,111,0,0,64,1,29,0,69,111,0,0,192,0,29,0,70,111,0,0,48,0,29,0,71,111,0,0,80,255,28,0,72,111,0,0,248,253,28,0,73,111,0,0,112,253,28,0,74,111,0,0,32,253,28,0,75,111,0,0,248,252,28,0,76,111,0,0,208,252,28,0,184,111,0,0,80,252,28,0,63,113,0,0,208,251,28,0,64,113,0,0,112,251,28,0,190,113,0,0,192,250,28,0,191,113,0,0,168,250,28,0,192,113,0,0,72,248,28,0,193,113,0,0,216,247,28,0,194,113,0,0,184,247,28,0,249,113,0,0,120,247,28,0,250,113,0,0,80,247,28,0,251,113,0,0,8,247,28,0,252,113,0,0,216,246,28,0,253,113,0,0,64,246,28,0,254,113,0,0,8,246,28,0,255,113,0,0,144,244,28,0,0,114,0,0,152,241,28,0,1,114,0,0,112,237,28,0,36,114,0,0,64,235,28,0,37,114,0,0,224,232,28,0,149,114,0,0,232,230,28,0,195,115,0,0,112,229,28,0,196,115,0,0,232,225,28,0,4,116,0,0,80,224,28,0,42,116,0,0,88,222,28,0,43,116,0,0,104,219,28,0,104,116,0,0,72,216,28,0,153,116,0,0,200,214,28,0,154,116,0,0,8,214,28,0,204,116,0,0,184,213,28,0,248,117,0,0,48,213,28,0,131,118,0,0,128,212,28,0,132,118,0,0,0,212,28,0,27,119,0,0,104,211,28,0,28,119,0,0,240,210,28,0,127,119,0,0,160,210,28,0,128,119,0,0,88,209,28,0,136,119,0,0,248,206,28,0,9,120,0,0,160,206,28,0,10,120,0,0,112,206,28,0,11,120,0,0,224,205,28,0,12,120,0,0,216,204,28,0,52,121,0,0,112,204,28,0,145,121,0,0,48,204,28,0,59,122,0,0,184,203,28,0,60,122,0,0,96,203,28,0,61,122,0,0,16,202,28,0,68,122,0,0,120,201,28,0,3,123,0,0,56,201,28,0,4,123,0,0,176,200,28,0,5,123,0,0,128,200,28,0,6,123,0,0,72,199,28,0,7,123,0,0,232,198,28,0,1,125,0,0,32,198,28,0,2,125,0,0,64,197,28,0,3,125,0,0,232,196,28,0,5,125,0,0,144,195,28,0,6,125,0,0,248,194,28,0,7,125,0,0,184,194,28,0,8,125,0,0,104,194,28,0,9,125,0,0,192,193,28,0,10,125,0,0,248,192,28,0,11,125,0,0,184,192,28,0,12,125,0,0,64,192,28,0,13,125,0,0,240,191,28,0,14,125,0,0,176,191,28,0,15,125,0,0,112,190,28,0,16,125,0,0,224,189,28,0,17,125,0,0,136,189,28,0,18,125,0,0,64,189,28,0,19,125,0,0,216,188,28,0,20,125,0,0,104,188,28,0,21,125,0,0,32,188,28,0,22,125,0,0,224,187,28,0,23,125,0,0,136,187,28,0,24,125,0,0,64,187,28,0,25,125,0,0,24,186,28,0,26,125,0,0,128,185,28,0,27,125,0,0,40,185,28,0,28,125,0,0,0,185,28,0,29,125,0,0,168,184,28,0,30,125,0,0,72,184,28,0,31,125,0,0,216,183,28,0,33,125,0,0,56,183,28,0,34,125,0,0,104,182,28,0,35,125,0,0,40,182,28,0,36,125,0,0,56,181,28,0,37,125,0,0,144,180,28,0,38,125,0,0,104,180,28,0,39,125,0,0,24,180,28,0,40,125,0,0,144,179,28,0,41,125,0,0,32,179,28,0,42,125,0,0,192,178,28,0,43,125,0,0,96,178,28,0,44,125,0,0,192,177,28,0,45,125,0,0,104,177,28,0,46,125,0,0,104,175,28,0,47,125,0,0,176,174,28,0,48,125,0,0,56,174,28,0,49,125,0,0,240,173,28,0,50,125,0,0,176,173,28,0,51,125,0,0,72,173,28,0,52,125,0,0,224,172,28,0,53,125,0,0,136,172,28,0,54,125,0,0,32,243,35,0,55,125,0,0,0,243,35,0,56,125,0,0,16,242,35,0,57,125,0,0,184,241,35,0,58,125,0,0,160,241,35,0,59,125,0,0,136,241,35,0,60,125,0,0,96,241,35,0,100,125,0,0,48,241,35,0,104,125,0,0,200,240,35,0,107,125,0,0,128,240,35,0,108,125,0,0,72,240,35,0,109,125,0,0,48,239,35,0,110,125,0,0,160,234,35,0,111,125,0,0,104,231,35,0,112,125,0,0,216,228,35,0,113,125,0,0,248,225,35,0,114,125,0,0,232,224,35,0,115,125,0,0,16,224,35,0,116,125,0,0,184,221,35,0,117,125,0,0,24,220,35,0,118,125,0,0,208,216,35,0,119,125,0,0,24,214,35,0,120,125,0,0,168,210,35,0,121,125,0,0,40,209,35,0,122,125,0,0,120,208,35,0,123,125,0,0,232,207,35,0,124,125,0,0,152,207,35,0,125,125,0,0,48,207,35,0,126,125,0,0,216,206,35,0,127,125,0,0,80,206,35,0,128,125,0,0,240,205,35,0,129,125,0,0,184,205,35,0,130,125,0,0,104,204,35,0,133,125,0,0,208,203,35,0,134,125,0,0,112,203,35,0,135,125,0,0,8,203,35,0,136,125,0,0,136,202,35,0,137,125,0,0,32,202,35,0,138,125,0,0,224,201,35,0,139,125,0,0,112,201,35,0,140,125,0,0,136,200,35,0,141,125,0,0,0,200,35,0,142,125,0,0,168,198,35,0,143,125,0,0,240,197,35,0,144,125,0,0,128,197,35,0,145,125,0,0,0,197,35,0,146,125,0,0,128,196,35,0,147,125,0,0,248,195,35,0,148,125,0,0,120,195,35,0,149,125,0,0,184,194,35,0,150,125,0,0,112,194,35,0,151,125,0,0,80,194,35,0,152,125,0,0,232,192,35,0,153,125,0,0,112,192,35,0,154,125,0,0,48,192,35,0,155,125,0,0,224,191,35,0,156,125,0,0,160,191,35,0,157,125,0,0,0,191,35,0,158,125,0,0,184,190,35,0,161,125,0,0,160,189,35,0,201,125,0,0,88,189,35,0,202,125,0,0,40,189,35,0,203,125,0,0,128,187,35,0,204,125,0,0,24,187,35,0,205,125,0,0,152,186,35,0,206,125,0,0,104,186,35,0,207,125,0,0,24,186,35,0,208,125,0,0,200,185,35,0,209,125,0,0,136,185,35,0,210,125,0,0,48,185,35,0,211,125,0,0,216,184,35,0,212,125,0,0,184,184,35,0,213,125,0,0,200,182,35,0,214,125,0,0,8,182,35,0,215,125,0,0,192,181,35,0,216,125,0,0,144,181,35,0,217,125], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1108460);
/* memory initializer */ allocate([48,181,35,0,218,125,0,0,152,180,35,0,219,125,0,0,32,180,35,0,220,125,0,0,168,179,35,0,221,125,0,0,80,179,35,0,222,125,0,0,40,179,35,0,223,125,0,0,24,178,35,0,224,125,0,0,168,177,35,0,225,125,0,0,112,177,35,0,226,125,0,0,48,177,35,0,227,125,0,0,176,176,35,0,228,125,0,0,248,175,35,0,229,125,0,0,192,175,35,0,230,125,0,0,120,175,35,0,231,125,0,0,224,174,35,0,232,125,0,0,152,174,35,0,233,125,0,0,128,172,35,0,234,125,0,0,0,172,35,0,235,125,0,0,168,171,35,0,236,125,0,0,128,171,35,0,237,125,0,0,56,171,35,0,238,125,0,0,16,171,35,0,239,125,0,0,136,170,35,0,240,125,0,0,64,170,35,0,241,125,0,0,112,169,35,0,242,125,0,0,40,169,35,0,243,125,0,0,248,166,35,0,244,125,0,0,144,166,35,0,245,125,0,0,248,165,35,0,246,125,0,0,216,165,35,0,247,125,0,0,32,165,35,0,248,125,0,0,208,164,35,0,249,125,0,0,184,163,35,0,250,125,0,0,240,162,35,0,251,125,0,0,24,162,35,0,252,125,0,0,32,160,35,0,253,125,0,0,248,156,35,0,254,125,0,0,8,153,35,0,255,125,0,0,24,150,35,0,0,126,0,0,200,147,35,0,1,126,0,0,120,146,35,0,2,126,0,0,128,145,35,0,3,126,0,0,56,142,35,0,4,126,0,0,96,141,35,0,45,126,0,0,16,139,35,0,46,126,0,0,152,134,35,0,47,126,0,0,136,131,35,0,48,126,0,0,184,129,35,0,49,126,0,0,136,128,35,0,50,126,0,0,144,127,35,0,51,126,0,0,136,126,35,0,52,126,0,0,144,125,35,0,53,126,0,0,120,124,35,0,54,126,0,0,248,123,35,0,55,126,0,0,200,122,35,0,56,126,0,0,240,121,35,0,57,126,0,0,200,120,35,0,58,126,0,0,240,119,35,0,59,126,0,0,88,119,35,0,60,126,0,0,232,118,35,0,61,126,0,0,24,118,35,0,62,126,0,0,152,117,35,0,63,126,0,0,248,116,35,0,64,126,0,0,72,116,35,0,65,126,0,0,128,115,35,0,66,126,0,0,144,114,35,0,67,126,0,0,144,113,35,0,68,126,0,0,224,112,35,0,69,126,0,0,96,112,35,0,70,126,0,0,56,111,35,0,71,126,0,0,120,110,35,0,72,126,0,0,72,109,35,0,73,126,0,0,128,108,35,0,74,126,0,0,152,107,35,0,75,126,0,0,248,106,35,0,76,126,0,0,64,106,35,0,77,126,0,0,168,105,35,0,78,126,0,0,224,104,35,0,79,126,0,0,120,104,35,0,80,126,0,0,32,104,35,0,81,126,0,0,168,103,35,0,82,126,0,0,248,102,35,0,83,126,0,0,24,102,35,0,84,126,0,0,184,101,35,0,85,126,0,0,72,101,35,0,86,126,0,0,144,99,35,0,87,126,0,0,152,98,35,0,88,126,0,0,200,97,35,0,89,126,0,0,120,97,35,0,90,126,0,0,56,97,35,0,91,126,0,0,232,96,35,0,92,126,0,0,200,96,35,0,93,126,0,0,40,96,35,0,94,126,0,0,56,95,35,0,95,126,0,0,8,95,35,0,96,126,0,0,40,94,35,0,97,126,0,0,208,92,35,0,98,126,0,0,232,91,35,0,99,126,0,0,192,90,35,0,100,126,0,0,0,90,35,0,101,126,0,0,72,89,35,0,102,126,0,0,88,88,35,0,103,126,0,0,40,87,35,0,104,126,0,0,112,86,35,0,145,126,0,0,192,85,35,0,146,126,0,0,240,84,35,0,147,126,0,0,184,83,35,0,148,126,0,0,120,82,35,0,149,126,0,0,0,82,35,0,150,126,0,0,184,81,35,0,151,126,0,0,112,81,35,0,152,126,0,0,48,81,35,0,153,126,0,0,232,80,35,0,154,126,0,0,168,80,35,0,155,126,0,0,64,80,35,0,156,126,0,0,0,80,35,0,157,126,0,0,208,78,35,0,158,126,0,0,176,77,35,0,159,126,0,0,112,76,35,0,160,126,0,0,24,76,35,0,161,126,0,0,248,75,35,0,162,126,0,0,120,75,35,0,163,126,0,0,176,73,35,0,164,126,0,0,0,73,35,0,165,126,0,0,184,71,35,0,166,126,0,0,80,71,35,0,167,126,0,0,48,70,35,0,168,126,0,0,200,69,35,0,169,126,0,0,64,69,35,0,170,126,0,0,200,68,35,0,171,126,0,0,80,68,35,0,172,126,0,0,192,67,35,0,173,126,0,0,144,66,35,0,174,126,0,0,96,65,35,0,175,126,0,0,8,64,35,0,176,126,0,0,152,62,35,0,177,126,0,0,160,60,35,0,178,126,0,0,144,57,35,0,179,126,0,0,40,55,35,0,180,126,0,0,72,52,35,0,181,126,0,0,112,51,35,0,182,126,0,0,16,50,35,0,183,126,0,0,168,46,35,0,184,126,0,0,128,45,35,0,185,126,0,0,144,43,35,0,186,126,0,0,120,40,35,0,187,126,0,0,160,37,35,0,188,126,0,0,40,36,35,0,189,126,0,0,144,35,35,0,190,126,0,0,16,35,35,0,191,126,0,0,120,34,35,0,192,126,0,0,128,33,35,0,193,126,0,0,192,32,35,0,194,126,0,0,0,32,35,0,195,126,0,0,80,31,35,0,196,126,0,0,240,30,35,0,197,126,0,0,40,30,35,0,198,126,0,0,184,29,35,0,199,126,0,0,8,29,35,0,200,126,0,0,168,28,35,0,201,126,0,0,24,28,35,0,202,126,0,0,128,27,35,0,203,126,0,0,232,26,35,0,204,126,0,0,240,25,35,0,245,126,0,0,56,25,35,0,246,126,0,0,216,24,35,0,247,126,0,0,40,24,35,0,248,126,0,0,120,23,35,0,249,126,0,0,0,23,35,0,250,126,0,0,128,22,35,0,251,126,0,0,88,22,35,0,252,126,0,0,40,22,35,0,253,126,0,0,104,21,35,0,254,126,0,0,224,20,35,0,255,126,0,0,0,20,35,0,0,127,0,0,200,19,35,0,1,127,0,0,112,18,35,0,2,127,0,0,208,17,35,0,3,127,0,0,120,17,35,0,4,127,0,0,0,17,35,0,5,127,0,0,120,16,35,0,6,127,0,0,240,15,35,0,7,127,0,0,24,15,35,0,8,127,0,0,184,14,35,0,9,127,0,0,56,14,35,0,10,127,0,0,208,13,35,0,11,127,0,0,192,12,35,0,12,127,0,0,24,12,35,0,13,127,0,0,160,11,35,0,14,127,0,0,232,10,35,0,15,127,0,0,144,10,35,0,16,127,0,0,104,10,35,0,17,127,0,0,16,10,35,0,18,127,0,0,240,9,35,0,19,127,0,0,136,9,35,0,20,127,0,0,24,9,35,0,21,127,0,0,152,7,35,0,22,127,0,0,72,7,35,0,23,127,0,0,120,6,35,0,24,127,0,0,48,6,35,0,25,127,0,0,224,5,35,0,26,127,0,0,88,5,35,0,27,127,0,0,248,4,35,0,28,127,0,0,176,4,35,0,29,127,0,0,200,3,35,0,30,127,0,0,168,3,35,0,31,127,0,0,16,3,35,0,32,127,0,0,48,2,35,0,33,127,0,0,0,2,35,0,34,127,0,0,208,1,35,0,35,127,0,0,56,1,35,0,36,127,0,0,16,1,35,0,37,127,0,0,216,0,35,0,38,127,0,0,96,0,35,0,39,127,0,0,152,255,34,0,40,127,0,0,64,255,34,0,41,127,0,0,64,254,34,0,42,127,0,0,216,253,34,0,43,127,0,0,88,253,34,0,44,127,0,0,240,252,34,0,45,127,0,0,208,252,34,0,46,127,0,0,152,252,34,0,47,127,0,0,0,251,34,0,48,127,0,0,216,250,34,0,89,127,0,0,88,249,34,0,90,127,0,0,64,249,34,0,91,127,0,0,168,248,34,0,92,127,0,0,248,247,34,0,93,127,0,0,224,247,34,0,94,127,0,0,192,247,34,0,95,127,0,0,136,247,34,0,96,127,0,0,48,247,34,0,97,127,0,0,232,246,34,0,98,127,0,0,200,246,34,0,99,127,0,0,72,246,34,0,100,127,0,0,40,245,34,0,101,127,0,0,104,243,34,0,102,127,0,0,248,240,34,0,103,127,0,0,216,238,34,0,104,127,0,0,56,237,34,0,105,127,0,0,240,235,34,0,106,127,0,0,248,234,34,0,107,127,0,0,176,232,34,0,108,127,0,0,200,231,34,0,109,127,0,0,8,230,34,0,110,127,0,0,112,226,34,0,111,127,0,0,144,223,34,0,112,127,0,0,224,221,34,0,113,127,0,0,80,221,34,0,114,127,0,0,216,220,34,0,115,127,0,0,72,220,34,0,116,127,0,0,224,219,34,0,117,127,0,0,96,219,34,0,118,127,0,0,184,218,34,0,119,127,0,0,88,218,34,0,120,127,0,0,48,218,34,0,121,127,0,0,136,217,34,0,122,127,0,0,240,216,34,0,123,127,0,0,56,216,34,0,124,127,0,0,232,215,34,0,125,127,0,0,136,215,34,0,126,127,0,0,32,215,34,0,127,127,0,0,224,214,34,0,128,127,0,0,144,214,34,0,129,127,0,0,136,213,34,0,130,127,0,0,32,213,34,0,131,127,0,0,0,212,34,0,132,127,0,0,176,210,34,0,133,127,0,0,96,210,34,0,134,127,0,0,192,209,34,0,135,127,0,0,144,209,34,0,136,127,0,0,112,209,34,0,137,127,0,0,16,209,34,0,138,127,0,0,152,208,34,0,139,127,0,0,240,207,34,0,140,127,0,0,160,207,34,0,141,127,0,0,248,206,34,0,142,127,0,0,128,206,34,0,143,127,0,0,64,206,34,0,144,127,0,0,24,206,34,0,145,127,0,0,240,205,34,0,146,127,0,0,32,205,34,0,147,127,0,0,152,204,34,0,148,127,0,0,104,204,34,0,189,127,0,0,240,203,34,0,190,127,0,0,168,203,34,0,191,127,0,0,144,202,34,0,192,127,0,0,168,201,34,0,193,127,0,0,72,201,34,0,194,127,0,0,176,200,34,0,195,127,0,0,120,200,34,0,196,127,0,0,56,200,34,0,197,127,0,0,24,200,34,0,198,127,0,0,0,200,34,0,199,127,0,0,168,199,34,0,200,127,0,0,96,199,34,0,201,127,0,0,128,198,34,0,202,127,0,0,24,198,34,0,203,127,0,0,184,197,34,0,204,127,0,0,120,197,34,0,205,127,0,0,56,197,34,0,206,127,0,0,200,196,34,0,207,127,0,0,88,196,34,0,208,127,0,0,224,195,34,0,209,127,0,0,80,195,34,0,210,127,0,0,56,195,34,0,211,127,0,0,152,194,34,0,212,127,0,0,24,194,34,0,213,127,0,0,152,193,34,0,214,127,0,0,72,193,34,0,215,127,0,0,216,192,34,0,216,127,0,0,128,192,34,0,217,127,0,0,56,192,34,0,218,127,0,0,0,192,34,0,219,127,0,0,232,190,34,0,220,127,0,0,176,190,34,0,221,127,0,0,192,189,34,0,222,127,0,0,96,189,34,0,223,127,0,0,64,189,34,0,224,127,0,0,192,188,34,0,225,127,0,0,160,188,34,0,226,127,0,0,40,188,34,0,227,127,0,0,232,187,34,0,228,127,0,0,176,187,34,0,229,127,0,0,160,186,34,0,230,127,0,0,136,186,34,0,231,127,0,0,8,186,34,0,232,127,0,0,128,185,34,0,233,127,0,0,80,185,34,0,234,127,0,0,56,185,34,0,235,127,0,0,240,184,34,0,236,127,0,0,216,184,34,0,237,127,0,0,120,184,34,0,238,127,0,0,64,184,34,0,239,127,0,0,8,184,34,0,240,127,0,0,24,183,34,0,241,127,0,0,64,181,34,0,242,127,0,0,240,178,34,0,243,127,0,0,56,176,34,0,244,127,0,0,32,174,34,0,245,127,0,0,96,172,34,0,246,127,0,0,96,171,34,0,247,127,0,0,200,169,34,0,248,127,0,0,224,168,34,0,8,33,31,0,56,28,31,0,176,26,31,0,240,25,31,0,40,25,31,0,112,24,31,0,136,23,31,0,184,22,31,0,192,21,31,0,192,20,31,0,232,19,31,0,0,0,0,0,240,231,33,0,104,231,33,0,208,230,33,0,80,230,33,0,16,230,33,0,136,229,33,0,248,184,30,0,112,168,30,0,88,127,30,0,192,111,30,0,240,98,30,0,112,85,30,0,128,68,30,0,176,57,30,0,192,46,30,0,216,36,30,0,248,28,30,0,24,18,30,0,112,239,29,0,208,229,29,0,152,221,29,0,0,0,0,0,184,215,30,0,88,200,30,0,64,2,31,0,160,242,30,0,104,228,30,0,0,0,0,0,168,26,32,0,0,0,0,0,56,62,31,0,177,135,0,0,16,140,30,0,0,0,0,0,104,250,29,0,0,0,0,0,208,140,29,0,0,0,0,0,128,48,29,0,176,135,0,0,208,224,28,0,0,0,0,0,128,220,35,0,176,135,0,0,120,141,35,0,0,0,0,0,168,45,35,0,176,135,0,0,224,231,34,0,176,135,0,0,48,169,34,0,176,135,0,0,24,109,34,0,0,0,0,0,248,52,34,0,176,135,0,0,80,183,31,0,168,176,31,0,80,173,31,0,152,172,31,0,120,171,31,0,128,170,31,0,136,169,31,0,152,168,31,0,48,167,31,0,144,165,31,0,64,164,31,0,80,158,31,0,0,156,31,0,176,154,31,0,184,153,31,0,192,152,31,0,144,151,31,0,48,150,31,0,232,148,31,0,152,147,31,0,144,146,31,0,224,139,31,0,64,138,31,0,136,137,31,0,40,136,31,0,40,135,31,0,0,134,31,0,56,132,31,0,72,131,31,0,200,129,31,0,128,128,31,0,104,123,31,0,112,121,31,0,176,120,31,0,120,119,31,0,0,0,0,0,200,243,32,0,8,233,32,0,152,230,32,0,224,228,32,0,200,226,32,0,64,225,32,0,120,223,32,0,208,221,32,0,80,220,32,0,112,218,32,0,80,216,32,0,176,206,32,0,80,203,32,0,120,201,32,0,168,199,32,0,184,197,32,0,144,195,32,0,168,193,32,0,32,192,32,0,184,190,32,0,168,189,32,0,160,179,32,0,0,177,32,0,232,175,32,0,64,174,32,0,192,172,32,0,192,170,32,0,144,169,32,0,176,168,32,0,176,167,32,0,48,166,32,0,72,158,32,0,64,155,32,0,64,153,32,0,8,151,32,0,120,149,32,0,248,147,32,0,24,145,32,0,152,143,32,0,16,142,32,0,96,141,32,0,80,132,32,0,128,130,32,0,56,129,32,0,48,127,32,0,168,125,32,0,200,122,32,0,24,121,32,0,168,119,32,0,232,117,32,0,112,116,32,0,128,107,32,0,248,104,32,0,160,102,32,0,200,101,32,0,176,100,32,0,224,98,32,0,104,97,32,0,224,95,32,0,24,94,32,0,128,93,32,0,192,85,32,0,128,83,32,0,120,82,32,0,80,81,32,0,96,80,32,0,64,79,32,0,136,77,32,0,112,76,32,0,16,75,32,0,136,70,32,0,64,61,32,0,216,52,32,0,80,48,32,0,192,42,32,0,240,39,32,0,8,36,32,0,136,27,32,0,160,25,32,0,160,20,32,0,64,14,32,0,208,5,32,0,184,1,32,0,56,255,31,0,112,253,31,0,16,252,31,0,248,249,31,0,88,248,31,0,192,246,31,0,88,245,31,0,208,243,31,0,160,237,31,0,216,234,31,0,88,233,31,0,56,232,31,0,216,230,31,0,240,228,31,0,200,226,31,0,200,225,31,0,120,224,31,0,184,223,31,0,8,217,31,0,40,215,31,0,160,213,31,0,112,212,31,0,32,211,31,0,152,209,31,0,248,207,31,0,232,206,31,0,168,205,31,0,192,204,31,0,240,198,31,0,104,196,31,0,152,194,31,0,200,192,31,0,48,191,31,0,8,189,31,0,152,187,31,0,56,186,31,0,112,184,31,0,136,133,33,0,104,131,33,0,144,129,33,0,32,128,33,0,56,125,33,0,80,120,33,0,224,106,33,0,128,98,33,0,160,93,33,0,120,88,33,0,0,84,33,0,248,80,33,0,176,72,33,0,248,68,33,0,160,62,33,0,176,55,33,0,72,41,33,0,72,36,33,0,232,32,33,0,176,28,33,0,144,24,33,0,40,23,33,0,200,20,33,0,232,16,33,0,0,15,33,0,216,13,33,0,216,3,33,0,24,1,33,0,136,254,32,0,200,252,32,0,40,251,32,0,176,249,32,0,96,248,32,0,160,246,32,0,80,245,32,0,0,0,0,0,48,121,29,0,200,113,29,0,8,107,29,0,208,100,29,0,128,94,29,0,80,88,29,0,144,81,29,0,56,74,29,0,32,67,29,0,152,40,29,0,216,32,29,0,88,27,29,0,232,20,29,0,88,14,29,0,32,8,29,0,248,3,29,0,40,254,28,0,40,250,28,0,208,241,28,0,168,216,28,0,120,209,28,0,112,202,28,0,240,195,28,0,160,190,28,0,96,186,28,0,96,181,28,0,160,175,28,0,96,242,35,0,64,237,35,0,104,211,35,0,168,204,35,0,8,199,35,0,88,193,35,0,200,187,35,0,72,183,35,0,88,178,35,0,208,172,35,0,72,167,35,0,48,157,35,0,224,131,35,0,232,120,35,0,224,113,35,0,192,105,35,0,200,98,35,0,8,93,35,0,208,83,35,0,0,79,35,0,80,70,35,0,24,61,35,0,40,38,35,0,72,30,35,0,72,24,35,0,144,18,35,0,224,12,35,0,48,8,35,0,48,3,35,0,96,254,34,0,200,248,34,0,192,243,34,0,216,223,34,0,160,217,34,0,32,212,34,0,16,207,34,0,168,202,34,0,200,198,34,0,176,194,34,0,224,189,34,0,32,186,34,0,128,181,34,0,144,162,34,0,80,157,34,0,104,152,34,0,176,147,34,0,24,143,34,0,216,138,34,0,144,133,34,0,248,128,34,0,184,124,34,0,40,120,34,0,120,102,34,0,248,96,34,0,152,92,34,0,216,88,34,0,136,84,34,0,72,80,34,0,112,76,34,0,216,71,34,0,192,67,34,0,128,63,34,0,56,47,34,0,232,40,34,0,32,38,34,0,48,35,34,0,232,31,34,0,24,29,34,0,48,26,34,0,96,22,34,0,192,18,34,0,24,15,34,0,8,0,34,0,48,249,33,0,216,245,33,0,176,241,33,0,168,237,33,0,240,233,33,0,160,229,33,0,32,227,33,0,248,224,33,0,176,222,33,0,8,210,33,0,192,207,33,0,0,205,33,0,24,203,33,0,72,200,33,0,192,196,33,0,64,193,33,0,184,191,33,0,80,189,33,0,120,186,33,0,88,172,33,0,112,168,33,0,128,166,33,0,16,165,33,0,136,163,33,0,96,160,33,0,16,158,33,0,240,155,33,0,232,153,33,0,80,152,33,0,152,141,33,0,152,138,33,0,8,137,33,0,176,135,33,0,0,0,0,0,104,178,33,0,240,78,35,0,0,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,72,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,218,2,0,0,0,0,0,220,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,0,0,0,0,0,148,1,0,0,0,0,0,0,202,1,0,0,0,0,0,0,0,0,0,0,16,119,31,0,104,117,31,0,120,116,31,0,24,115,31,0,168,113,31,0,40,113,31,0,176,108,31,0,8,107,31,0,80,106,31,0,184,105,31,0,32,105,31,0,72,104,31,0,88,103,31,0,112,102,31,0,160,99,31,0,80,95,31,0,48,88,31,0,96,80,31,0,88,77,31,0,168,73,31,0,64,71,31,0,136,68,31,0,8,63,31,0,152,61,31,0,96,57,31,0,152,52,31,0,120,46,31,0,40,42,31,0,240,39,31,0,152,38,31,0,168,37,31,0,232,36,31,0,248,35,31,0,248,34,31,0,120,34,31,0,0,0,0,0,96,208,33,0,160,82,35,0,0,0,0,0,97,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,10,0,0,0,0,0,0,0,0,0,0,202,1,0,0,172,8,0,0,0,0,0,0,0,0,0,0,144,5,34,0,160,4,34,0,88,3,34,0,128,1,34,0,216,255,33,0,216,254,33,0,96,254,33,0,8,254,33,0,168,253,33,0,248,252,33,0,128,252,33,0,216,251,33,0,224,249,33,0,184,249,33,0,24,249,33,0,216,248,33,0,112,248,33,0,40,248,33,0,240,247,33,0,168,247,33,0,80,247,33,0,8,247,33,0,184,246,33,0,128,246,33,0,192,245,33,0,104,245,33,0,24,245,33,0,0,0,0,0,152,206,33,0,0,0,0,0,40,82,35,0,0,0,0,0,104,70,33,0,177,135,0,0,96,212,29,0,184,203,29,0,16,195,29,0,200,187,29,0,240,179,29,0,248,171,29,0,48,162,29,0,88,130,29,0,144,208,33,0,176,82,35,0,0,0,0,0,96,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,6,0,0,0,0,0,0,0,0,0,0,62,1,0,0,150,10,0,0,0,0,0,0,0,0,0,0,88,213,28,0,128,170,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,1,0,0,154,6,0,0,12,1,0,0,168,2,0,0,202,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,213,28,0,184,170,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,52,8,0,0,176,1,0,0,42,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,230,29,0,104,222,29,0,0,0,0,0,101,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,3,0,0,0,0,0,0,0,0,0,0,210,1,0,0,70,5,0,0,14,1,0,0,0,0,0,0,48,140,33,0,240,69,35,0,0,0,0,0,31,0,0,0,3,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,210,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,6,0,0,0,0,0,0,0,0,0,0,208,2,0,0,10,4,0,0,132,0,0,0,0,0,0,0,128,90,29,0,7,0,0,0,0,0,0,0,142,2,0,0,202,0,0,0,42,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,200,96,29,0,120,10,29,0,0,0,0,0,200,96,29,0,0,32,1,0,5,0,0,0,0,0,0,0,64,0,5,0,40,244,35,0,160,220,2,0,0,0,0,0,128,0,0,0,214,4,0,0,184,2,0,0,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,198,33,0,240,161,33,0,0,0,0,0,120,198,33,0,0,32,1,0,5,0,0,0,0,0,0,0,64,0,5,0,192,250,35,0,208,220,2,0,0,0,0,0,128,0,0,0,214,4,0,0,184,2,0,0,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,209,33,0,208,82,35,0,3,0,0,0,2,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,221,2,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,5,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,217,28,0,216,172,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,184,225,2,0,0,0,0,0,200,0,0,0,86,2,0,0,222,1,0,0,118,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,223,28,0,136,177,33,0,0,0,0,0,0,0,0,0,0,0,0,0,72,226,2,0,0,0,0,0,0,0,0,0,40,0,0,0,86,3,0,0,20,2,0,0,210,0,0,0,86,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,32,209,33,0,8,83,35,0,0,0,0,0,54,49,50,84,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,236,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,209,33,0,240,82,35,0,0,0,0,0,94,0,0,0,0,0,0,0,0,0,0,0,160,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,8,0,0,0,0,0,0,156,1,0,0,0,0,0,0,102,5,0,0,0,0,0,0,0,0,0,0,224,209,33,0,120,83,35,0,0,0,0,0,94,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,97,66,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,30,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,224,28,0,112,178,33,0,0,1,0,0,200,224,28,0,0,0,0,0,0,0,0,0,0,0,0,0,75,97,66,116,16,0,0,0,168,4,0,0,210,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,211,33,0,144,83,35,0,1,0,0,0,75,97,66,116,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,6,0,0,0,0,0,0,0,0,0,0,234,1,0,0,52,3,0,0,0,0,0,0,0,0,0,0,64,0,0,0,7,0,0,0,201,19,0,0,13,0,0,0,253,9,0,0,12,0,0,0,252,1,0,0,15,0,0,0,252,9,0,0,12,0,0,0,131,10,0,0,18,0,0,0,52,45,1,0,17,0,0,0,188,131,0,0,16,0,0,0,58,8,0,0,12,0,0,0,248,7,0,0,17,0,0,0,253,3,0,0,16,0,0,0,255,3,0,0,16,0,0,0,121,0,0,0,13,0,0,0,130,10,0,0,18,0,0,0,157,150,0,0,16,0,0,0,164,2,0,0,16,0,0,0,120,9,0,0,12,0,0,0,67,5,0,0,17,0,0,0,223,65,0,0,15,0,0,0,249,7,0,0,17,0,0,0,243,18,0,0,13,0,0,0,107,90,2,0,18,0,0,0,249,94,2,0,18,0,0,0,250,3,0,0,16,0,0,0,238,32,0,0,14,0,0,0,171,105,9,0,20,0,0,0,156,150,0,0,16,0,0,0,248,94,2,0,18,0,0,0,210,18,0,0,13,0,0,0,133,10,0,0,18,0,0,0,158,150,0,0,16,0,0,0,200,75,0,0,15,0,0,0,61,0,0,0,12,0,0,0,127,47,1,0,17,0,0,0,162,2,0,0,16,0,0,0,159,150,0,0,16,0,0,0,238,37,0,0,14,0,0,0,85,211,18,0,21,0,0,0,125,47,1,0,17,0,0,0,126,47,1,0,17,0,0,0,229,9,0,0,12,0,0,0,129,10,0,0,18,0,0,0,212,180,4,0,19,0,0,0,189,131,0,0,16,0,0,0,120,0,0,0,13,0,0,0,155,150,0,0,16,0,0,0,254,3,0,0,16,0,0,0,165,2,0,0,16,0,0,0,126,0,0,0,13,0,0,0,128,10,0,0,18,0,0,0,163,2,0,0,16,0,0,0,251,3,0,0,16,0,0,0,118,16,0,0,13,0,0,0,132,10,0,0,18,0,0,0,83,1,0,0,15,0,0,0,201,75,0,0,15,0,0,0,85,0,0,0,13,0,0,0,84,211,18,0,21,0,0,0,222,75,0,0,15,0,0,0,229,37,0,0,14,0,0,0,91,2,0,0,10,0,0,0,76,75,0,0,15,0,0,0,107,9,0,0,12,0,0,0,106,9,0,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,7,0,0,0,38,0,0,0,6,0,0,0,43,1,0,0,9,0,0,0,7,0,0,0,3,0,0,0,15,2,0,0,10,0,0,0,4,0,0,0,9,0,0,0,40,0,0,0,12,0,0,0,6,0,0,0,3,0,0,0,10,2,0,0,10,0,0,0,40,1,0,0,9,0,0,0,43,0,0,0,12,0,0,0,17,0,0,0,5,0,0,0,27,0,0,0,11,0,0,0,58,1,0,0,9,0,0,0,255,4,0,0,11,0,0,0,3,0,0,0,4,0,0,0,119,2,0,0,10,0,0,0,6,1,0,0,9,0,0,0,57,8,0,0,12,0,0,0,11,0,0,0,4,0,0,0,123,2,0,0,10,0,0,0,44,1,0,0,9,0,0,0,191,4,0,0,11,0,0,0,9,0,0,0,6,0,0,0,53,0,0,0,12,0,0,0,126,2,0,0,10,0,0,0,200,19,0,0,13,0,0,0,1,0,0,0,6,0,0,0,170,4,0,0,11,0,0,0,8,2,0,0,10,0,0,0,41,0,0,0,12,0,0,0,1,0,0,0,4,0,0,0,84,2,0,0,10,0,0,0,46,1,0,0,9,0,0,0,56,8,0,0,12,0,0,0,36,0,0,0,6,0,0,0,243,4,0,0,11,0,0,0,118,2,0,0,10,0,0,0,246,18,0,0,13,0,0,0,1,0,0,0,5,0,0,0,122,2,0,0,10,0,0,0,62,1,0,0,9,0,0,0,62,0,0,0,12,0,0,0,8,0,0,0,6,0,0,0,19,4,0,0,11,0,0,0,12,0,0,0,10,0,0,0,190,4,0,0,11,0,0,0,20,0,0,0,5,0,0,0,18,4,0,0,11,0,0,0,83,2,0,0,10,0,0,0,122,9,0,0,12,0,0,0,33,0,0,0,6,0,0,0,171,4,0,0,11,0,0,0,11,2,0,0,10,0,0,0,52,0,0,0,12,0,0,0,21,0,0,0,5,0,0,0,120,2,0,0,10,0,0,0,82,2,0,0,10,0,0,0,104,9,0,0,12,0,0,0,5,0,0,0,5,0,0,0,11,0,0,0,10,0,0,0,156,0,0,0,8,0,0,0,14,0,0,0,10,0,0,0,0,1,2,2,6,3,7,3,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,101,0,110,0,116,0,114,0,105,0,101,0,115,0,46,0,116,0,105,0,109,0,101,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,101,0,110,0,116,0,114,0,105,0,101,0,115,0,46,0,108,0,101,0,103,0,97,0,99,0,121,0,95,0,97,0,116,0,116,0,114,0,105,0,98,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,5,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,3,0,0,0,5,0,0,0,8,0,0,0,5,0,0,0,0,0,0,0,6,0,0,0,5,0,0,0,6,0,0,0,13,0,0,0,6,0,0,0,15,0,0,0,6,0,0,0,19,0,0,0,6,0,0,0,8,0,0,0,7,0,0,0,24,0,0,0,7,0,0,0,28,0,0,0,7,0,0,0,36,0,0,0,7,0,0,0,4,0,0,0,8,0,0,0,6,0,0,0,8,0,0,0,18,0,0,0,8,0,0,0,50,0,0,0,8,0,0,0,59,0,0,0,8,0,0,0,74,0,0,0,8,0,0,0,75,0,0,0,8,0,0,0,11,0,0,0,9,0,0,0,38,0,0,0,9,0,0,0,39,0,0,0,9,0,0,0,102,0,0,0,9,0,0,0,116,0,0,0,9,0,0,0,117,0,0,0,9,0,0,0,20,0,0,0,10,0,0,0,28,0,0,0,10,0,0,0,31,0,0,0,10,0,0,0,29,0,0,0,10,0,0,0,43,0,0,0,11,0,0,0,61,0,0,0,11,0,0,0,157,1,0,0,11,0,0,0,159,1,0,0,11,0,0,0,84,0,0,0,12,0,0,0,57,3,0,0,12,0,0,0,56,3,0,0,12,0,0,0,61,3,0,0,12,0,0,0,171,0,0,0,13,0,0,0,241,0,0,0,13,0,0,0,120,6,0,0,13,0,0,0,242,0,0,0,13,0,0,0,224,1,0,0,14,0,0,0,225,1,0,0,14,0,0,0,84,1,0,0,14,0,0,0,242,12,0,0,14,0,0,0,204,3,0,0,15,0,0,0,171,2,0,0,15,0,0,0,231,25,0,0,15,0,0,0,206,3,0,0,15,0,0,0,230,25,0,0,15,0,0,0,84,5,0,0,16,0,0,0,159,7,0,0,16,0,0,0,85,5,0,0,16,0,0,0,61,15,0,0,17,0,0,0,55,15,0,0,17,0,0,0,60,15,0,0,17,0,0,0,53,15,0,0,17,0,0,0,109,30,0,0,18,0,0,0,104,30,0,0,18,0,0,0,216,60,0,0,19,0,0,0,211,60,0,0,19,0,0,0,217,60,0,0,19,0,0,0,164,121,0,0,20,0,0,0,186,52,15,0,25,0,0,0,180,52,15,0,25,0,0,0,181,52,15,0,25,0,0,0,182,52,15,0,25,0,0,0,183,52,15,0,25,0,0,0,184,52,15,0,25,0,0,0,185,52,15,0,25,0,0,0,187,52,15,0,25,0,0,0,188,52,15,0,25,0,0,0,189,52,15,0,25,0,0,0,190,52,15,0,25,0,0,0,191,52,15,0,25,0,0,0,64,105,30,0,26,0,0,0,65,105,30,0,26,0,0,0,66,105,30,0,26,0,0,0,67,105,30,0,26,0,0,0,68,105,30,0,26,0,0,0,69,105,30,0,26,0,0,0,70,105,30,0,26,0,0,0,71,105,30,0,26,0,0,0,72,105,30,0,26,0,0,0,73,105,30,0,26,0,0,0,74,105,30,0,26,0,0,0,75,105,30,0,26,0,0,0,76,105,30,0,26,0,0,0,77,105,30,0,26,0,0,0,78,105,30,0,26,0,0,0,79,105,30,0,26,0,0,0,80,105,30,0,26,0,0,0,81,105,30,0,26,0,0,0,82,105,30,0,26,0,0,0,83,105,30,0,26,0,0,0,84,105,30,0,26,0,0,0,85,105,30,0,26,0,0,0,86,105,30,0,26,0,0,0,87,105,30,0,26,0,0,0,88,105,30,0,26,0,0,0,89,105,30,0,26,0,0,0,90,105,30,0,26,0,0,0,91,105,30,0,26,0,0,0,92,105,30,0,26,0,0,0,93,105,30,0,26,0,0,0,94,105,30,0,26,0,0,0,95,105,30,0,26,0,0,0,96,105,30,0,26,0,0,0,97,105,30,0,26,0,0,0,98,105,30,0,26,0,0,0,99,105,30,0,26,0,0,0,100,105,30,0,26,0,0,0,101,105,30,0,26,0,0,0,102,105,30,0,26,0,0,0,103,105,30,0,26,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,11,0,0,0,4,0,0,0,13,0,0,0,4,0,0,0,21,0,0,0,5,0,0,0,40,0,0,0,6,0,0,0,48,0,0,0,6,0,0,0,50,0,0,0,6,0,0,0,82,0,0,0,7,0,0,0,98,0,0,0,7,0,0,0,102,0,0,0,7,0,0,0,166,0,0,0,8,0,0,0,198,0,0,0,8,0,0,0,207,0,0,0,8,0,0,0,79,1,0,0,9,0,0,0,142,1,0,0,9,0,0,0,156,1,0,0,9,0,0,0,157,2,0,0,10,0,0,0,58,3,0,0,10,0,0,0,56,5,0,0,11,0,0,0,60,6,0,0,11,0,0,0,62,6,0,0,11,0,0,0,63,6,0,0,11,0,0,0,118,6,0,0,11,0,0,0,115,10,0,0,12,0,0,0,122,12,0,0,12,0,0,0,239,12,0,0,12,0,0,0,229,20,0,0,13,0,0,0,221,25,0,0,13,0,0,0,200,41,0,0,14,0,0,0,201,41,0,0,14,0,0,0,221,99,0,0,15,0,0,0,184,51,0,0,14,0,0,0,185,51,0,0,14,0,0,0,182,199,0,0,16,0,0,0,216,99,0,0,15,0,0,0,223,99,0,0,15,0,0,0,179,199,0,0,16,0,0,0,180,199,0,0,16,0,0,0,181,199,0,0,16,0,0,0,222,99,0,0,15,0,0,0,183,199,0,0,16,0,0,0,184,199,0,0,16,0,0,0,185,199,0,0,16,0,0,0,101,143,1,0,17,0,0,0,200,30,3,0,18,0,0,0,72,178,199,0,24,0,0,0,73,178,199,0,24,0,0,0,74,178,199,0,24,0,0,0,75,178,199,0,24,0,0,0,76,178,199,0,24,0,0,0,77,178,199,0,24,0,0,0,78,178,199,0,24,0,0,0,79,178,199,0,24,0,0,0,80,178,199,0,24,0,0,0,81,178,199,0,24,0,0,0,82,178,199,0,24,0,0,0,83,178,199,0,24,0,0,0,84,178,199,0,24,0,0,0,85,178,199,0,24,0,0,0,86,178,199,0,24,0,0,0,87,178,199,0,24,0,0,0,88,178,199,0,24,0,0,0,89,178,199,0,24,0,0,0,90,178,199,0,24,0,0,0,91,178,199,0,24,0,0,0,92,178,199,0,24,0,0,0,93,178,199,0,24,0,0,0,94,178,199,0,24,0,0,0,95,178,199,0,24,0,0,0,96,178,199,0,24,0,0,0,97,178,199,0,24,0,0,0,98,178,199,0,24,0,0,0,99,178,199,0,24,0,0,0,100,178,199,0,24,0,0,0,101,178,199,0,24,0,0,0,102,178,199,0,24,0,0,0,103,178,199,0,24,0,0,0,104,178,199,0,24,0,0,0,105,178,199,0,24,0,0,0,106,178,199,0,24,0,0,0,107,178,199,0,24,0,0,0,108,178,199,0,24,0,0,0,109,178,199,0,24,0,0,0,110,178,199,0,24,0,0,0,111,178,199,0,24,0,0,0,112,178,199,0,24,0,0,0,113,178,199,0,24,0,0,0,114,178,199,0,24,0,0,0,115,178,199,0,24,0,0,0,116,178,199,0,24,0,0,0,117,178,199,0,24,0,0,0,118,178,199,0,24,0,0,0,119,178,199,0,24,0,0,0,120,178,199,0,24,0,0,0,121,178,199,0,24,0,0,0,122,178,199,0,24,0,0,0,123,178,199,0,24,0,0,0,124,178,199,0,24,0,0,0,125,178,199,0,24,0,0,0,126,178,199,0,24,0,0,0,127,178,199,0,24,0,0,0,128,100,143,1,25,0,0,0,129,100,143,1,25,0,0,0,130,100,143,1,25,0,0,0,131,100,143,1,25,0,0,0,132,100,143,1,25,0,0,0,133,100,143,1,25,0,0,0,134,100,143,1,25,0,0,0,135,100,143,1,25,0,0,0,136,100,143,1,25,0,0,0,137,100,143,1,25,0,0,0,138,100,143,1,25,0,0,0,139,100,143,1,25,0,0,0,140,100,143,1,25,0,0,0,141,100,143,1,25,0,0,0,142,100,143,1,25,0,0,0,143,100,143,1,25,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,7,0,0,0,5,0,0,0,8,0,0,0,6,0,0,0,12,0,0,0,6,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,7,0,0,0,18,0,0,0,7,0,0,0,26,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,7,0,0,0,8,0,0,0,39,0,0,0,8,0,0,0,55,0,0,0,8,0,0,0,5,0,0,0,9,0,0,0,76,0,0,0,9,0,0,0,108,0,0,0,9,0,0,0,109,0,0,0,9,0,0,0,8,0,0,0,10,0,0,0,25,0,0,0,10,0,0,0,155,0,0,0,10,0,0,0,27,0,0,0,10,0,0,0,154,0,0,0,10,0,0,0,19,0,0,0,11,0,0,0,52,0,0,0,11,0,0,0,53,0,0,0,11,0,0,0,97,0,0,0,12,0,0,0,72,0,0,0,13,0,0,0,196,0,0,0,13,0,0,0,74,0,0,0,13,0,0,0,198,0,0,0,13,0,0,0,199,0,0,0,13,0,0,0,146,0,0,0,14,0,0,0,139,1,0,0,14,0,0,0,147,0,0,0,14,0,0,0,131,1,0,0,14,0,0,0,130,1,0,0,14,0,0,0,150,0,0,0,14,0,0,0,151,0,0,0,14,0,0,0,128,1,0,0,14,0,0,0,20,3,0,0,15,0,0,0,21,3,0,0,15,0,0,0,5,6,0,0,16,0,0,0,4,6,0,0,16,0,0,0,6,6,0,0,16,0,0,0,14,12,0,0,17,0,0,0,205,3,3,0,23,0,0,0,201,3,3,0,23,0,0,0,200,3,3,0,23,0,0,0,202,3,3,0,23,0,0,0,203,3,3,0,23,0,0,0,204,3,3,0,23,0,0,0,206,3,3,0,23,0,0,0,207,3,3,0,23,0,0,0,208,3,3,0,23,0,0,0,209,3,3,0,23,0,0,0,210,3,3,0,23,0,0,0,211,3,3,0,23,0,0,0,212,3,3,0,23,0,0,0,213,3,3,0,23,0,0,0,214,3,3,0,23,0,0,0,215,3,3,0,23,0,0,0,216,3,3,0,23,0,0,0,217,3,3,0,23,0,0,0,218,3,3,0,23,0,0,0,219,3,3,0,23,0,0,0,220,3,3,0,23,0,0,0,221,3,3,0,23,0,0,0,222,3,3,0,23,0,0,0,223,3,3,0,23,0,0,0,224,3,3,0,23,0,0,0,225,3,3,0,23,0,0,0,226,3,3,0,23,0,0,0,227,3,3,0,23,0,0,0,228,3,3,0,23,0,0,0,229,3,3,0,23,0,0,0,230,3,3,0,23,0,0,0,231,3,3,0,23,0,0,0,232,3,3,0,23,0,0,0,233,3,3,0,23,0,0,0,234,3,3,0,23,0,0,0,235,3,3,0,23,0,0,0,236,3,3,0,23,0,0,0,237,3,3,0,23,0,0,0,238,3,3,0,23,0,0,0,239,3,3,0,23,0,0,0,240,3,3,0,23,0,0,0,241,3,3,0,23,0,0,0,242,3,3,0,23,0,0,0,243,3,3,0,23,0,0,0,244,3,3,0,23,0,0,0,245,3,3,0,23,0,0,0,246,3,3,0,23,0,0,0,247,3,3,0,23,0,0,0,248,3,3,0,23,0,0,0,249,3,3,0,23,0,0,0,250,3,3,0,23,0,0,0,251,3,3,0,23,0,0,0,252,3,3,0,23,0,0,0,253,3,3,0,23,0,0,0,254,3,3,0,23,0,0,0,255,3,3,0,23,0,0,0,128,7,6], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1118700);
/* memory initializer */ allocate([24,0,0,0,129,7,6,0,24,0,0,0,130,7,6,0,24,0,0,0,131,7,6,0,24,0,0,0,132,7,6,0,24,0,0,0,133,7,6,0,24,0,0,0,134,7,6,0,24,0,0,0,135,7,6,0,24,0,0,0,136,7,6,0,24,0,0,0,137,7,6,0,24,0,0,0,138,7,6,0,24,0,0,0,139,7,6,0,24,0,0,0,140,7,6,0,24,0,0,0,141,7,6,0,24,0,0,0,142,7,6,0,24,0,0,0,143,7,6,0,24,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,5,0,0,0,3,0,0,0,9,0,0,0,4,0,0,0,13,0,0,0,4,0,0,0,17,0,0,0,5,0,0,0,29,0,0,0,5,0,0,0,31,0,0,0,5,0,0,0,33,0,0,0,6,0,0,0,49,0,0,0,6,0,0,0,56,0,0,0,6,0,0,0,51,0,0,0,6,0,0,0,57,0,0,0,6,0,0,0,61,0,0,0,6,0,0,0,97,0,0,0,7,0,0,0,121,0,0,0,7,0,0,0,128,0,0,0,8,0,0,0,200,0,0,0,8,0,0,0,202,0,0,0,8,0,0,0,240,0,0,0,8,0,0,0,129,0,0,0,8,0,0,0,192,0,0,0,8,0,0,0,201,0,0,0,8,0,0,0,7,1,0,0,9,0,0,0,6,1,0,0,9,0,0,0,150,1,0,0,9,0,0,0,131,1,0,0,9,0,0,0,227,1,0,0,9,0,0,0,226,1,0,0,9,0,0,0,10,2,0,0,10,0,0,0,11,2,0,0,10,0,0,0,9,6,0,0,11,0,0,0,18,4,0,0,11,0,0,0,19,4,0,0,11,0,0,0,11,6,0,0,11,0,0,0,17,4,0,0,11,0,0,0,10,6,0,0,11,0,0,0,95,6,0,0,11,0,0,0,16,4,0,0,11,0,0,0,93,6,0,0,11,0,0,0,94,6,0,0,11,0,0,0,184,12,0,0,12,0,0,0,16,12,0,0,12,0,0,0,185,12,0,0,12,0,0,0,35,24,0,0,13,0,0,0,69,48,0,0,14,0,0,0,137,96,0,0,15,0,0,0,16,193,0,0,16,0,0,0,72,68,48,0,22,0,0,0,73,68,48,0,22,0,0,0,74,68,48,0,22,0,0,0,75,68,48,0,22,0,0,0,76,68,48,0,22,0,0,0,77,68,48,0,22,0,0,0,78,68,48,0,22,0,0,0,79,68,48,0,22,0,0,0,80,68,48,0,22,0,0,0,81,68,48,0,22,0,0,0,82,68,48,0,22,0,0,0,83,68,48,0,22,0,0,0,84,68,48,0,22,0,0,0,85,68,48,0,22,0,0,0,86,68,48,0,22,0,0,0,87,68,48,0,22,0,0,0,88,68,48,0,22,0,0,0,89,68,48,0,22,0,0,0,90,68,48,0,22,0,0,0,91,68,48,0,22,0,0,0,92,68,48,0,22,0,0,0,93,68,48,0,22,0,0,0,94,68,48,0,22,0,0,0,95,68,48,0,22,0,0,0,96,68,48,0,22,0,0,0,97,68,48,0,22,0,0,0,98,68,48,0,22,0,0,0,99,68,48,0,22,0,0,0,100,68,48,0,22,0,0,0,101,68,48,0,22,0,0,0,102,68,48,0,22,0,0,0,103,68,48,0,22,0,0,0,104,68,48,0,22,0,0,0,105,68,48,0,22,0,0,0,106,68,48,0,22,0,0,0,107,68,48,0,22,0,0,0,108,68,48,0,22,0,0,0,109,68,48,0,22,0,0,0,110,68,48,0,22,0,0,0,111,68,48,0,22,0,0,0,112,68,48,0,22,0,0,0,113,68,48,0,22,0,0,0,114,68,48,0,22,0,0,0,115,68,48,0,22,0,0,0,116,68,48,0,22,0,0,0,117,68,48,0,22,0,0,0,118,68,48,0,22,0,0,0,119,68,48,0,22,0,0,0,120,68,48,0,22,0,0,0,121,68,48,0,22,0,0,0,122,68,48,0,22,0,0,0,123,68,48,0,22,0,0,0,124,68,48,0,22,0,0,0,125,68,48,0,22,0,0,0,126,68,48,0,22,0,0,0,127,68,48,0,22,0,0,0,128,136,96,0,23,0,0,0,129,136,96,0,23,0,0,0,130,136,96,0,23,0,0,0,131,136,96,0,23,0,0,0,132,136,96,0,23,0,0,0,133,136,96,0,23,0,0,0,134,136,96,0,23,0,0,0,135,136,96,0,23,0,0,0,136,136,96,0,23,0,0,0,137,136,96,0,23,0,0,0,138,136,96,0,23,0,0,0,139,136,96,0,23,0,0,0,140,136,96,0,23,0,0,0,141,136,96,0,23,0,0,0,142,136,96,0,23,0,0,0,143,136,96,0,23,0,0,0,151,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,128,230,28,0,104,180,33,0,136,112,32,0,128,230,28,0,1,80,1,0,22,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,248,6,0,0,78,1,0,0,212,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,233,28,0,240,181,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,3,0,0,86,7,0,0,234,2,0,0,168,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,0,0,0,93,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,40,6,0,160,40,6,0,240,40,6,0,64,41,6,0,64,41,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,41,6,0,128,41,6,0,128,41,6,0,192,41,6,0,192,41,6,0,192,41,6,0,224,41,6,0,224,41,6,0,0,42,6,0,0,42,6,0,0,42,6,0,160,41,6,0,160,41,6,0,0,0,0,0,32,42,6,0,32,42,6,0,208,42,6,0,48,43,6,0,48,43,6,0,152,43,6,0,0,44,6,0,0,44,6,0,96,44,6,0,96,44,6,0,96,44,6,0,120,42,6,0,120,42,6,0,0,0,0,0,0,16,64,80,0,0,0,0,0,217,33,0,224,83,35,0,0,0,0,0,24,0,0,0,35,0,0,0,0,0,0,0,208,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,190,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,44,1,0,0,140,4,0,0,0,0,0,0,0,0,0,0,1,5,1,1,3,3,2,3,3,4,2,4,0,5,1,4,1,4,3,2,5,3,4,3,3,3,2,3,0,4,1,3,1,5,1,1,3,3,0,5,3,4,2,3,2,4,1,4,1,6,1,1,1,2,0,6,3,4,2,4,1,5,1,4,1,6,1,1,1,2,3,5,2,5,0,6,1,5,1,3,1,7,1,1,1,2,1,3,1,4,1,6,0,7,1,5,55,0,6,0,86,0,7,0,1,0,17,0,1,0,20,0,2,0,20,0,3,0,20,0,0,0,20,0,4,0,20,0,5,0,20,0,3,0,19,0,21,0,11,0,66,0,9,0,20,0,11,0,3,0,14,0,2,0,14,0,1,0,15,0,1,0,16,0,1,0,12,0,43,0,10,0,24,0,11,0,12,0,11,0,65,0,9,0,120,0,8,0,108,0,8,0,85,0,7,0,15,0,4,0,14,0,4,0,52,0,6,0,81,0,7,0,114,0,8,0,110,0,8,0,64,0,9,0,63,0,9,0,62,0,9,0,61,0,9,0,60,0,9,0,59,0,9,0,58,0,9,0,57,0,9,0,56,0,9,0,55,0,9,0,67,0,9,0,70,0,9,0,71,0,9,0,69,0,9,0,68,0,9,0,73,0,9,0,72,0,9,0,74,0,8,0,121,0,8,0,118,0,8,0,119,0,8,0,113,0,8,0,117,0,8,0,116,0,8,0,115,0,8,0,106,0,8,0,85,0,8,0,112,0,8,0,111,0,8,0,82,0,8,0,109,0,8,0,76,0,8,0,107,0,8,0,64,0,7,0,105,0,8,0,104,0,8,0,103,0,8,0,102,0,8,0,101,0,8,0,100,0,8,0,99,0,8,0,98,0,8,0,97,0,8,0,96,0,8,0,95,0,8,0,94,0,8,0,93,0,8,0,92,0,8,0,91,0,8,0,90,0,8,0,89,0,8,0,88,0,8,0,87,0,8,0,86,0,8,0,61,0,7,0,84,0,8,0,83,0,8,0,63,0,7,0,81,0,8,0,80,0,8,0,79,0,8,0,78,0,8,0,77,0,8,0,65,0,7,0,75,0,8,0,83,0,7,0,62,0,7,0,72,0,8,0,79,0,7,0,82,0,7,0,69,0,8,0,80,0,7,0,67,0,8,0,66,0,8,0,65,0,8,0,66,0,7,0,67,0,7,0,62,0,8,0,68,0,7,0,60,0,8,0,69,0,7,0,70,0,7,0,71,0,7,0,72,0,7,0,73,0,7,0,74,0,7,0,75,0,7,0,76,0,7,0,77,0,7,0,78,0,7,0,88,0,7,0,89,0,7,0,90,0,7,0,91,0,7,0,92,0,7,0,93,0,7,0,68,0,8,0,73,0,8,0,41,0,8,0,63,0,8,0,61,0,8,0,59,0,8,0,44,0,8,0,40,0,8,0,37,0,8,0,38,0,8,0,94,0,7,0,87,0,7,0,84,0,7,0,95,0,7,0,98,0,7,0,99,0,7,0,100,0,7,0,97,0,7,0,101,0,7,0,103,0,7,0,102,0,7,0,53,0,6,0,54,0,6,0,96,0,7,0,57,0,8,0,58,0,8,0,56,0,8,0,55,0,8,0,54,0,8,0,53,0,8,0,52,0,8,0,51,0,8,0,50,0,8,0,49,0,8,0,48,0,8,0,45,0,8,0,43,0,8,0,42,0,8,0,39,0,8,0,64,0,8,0,70,0,8,0,71,0,8,0,38,0,9,0,37,0,9,0,36,0,9,0,35,0,9,0,34,0,9,0,46,0,8,0,47,0,8,0,31,0,9,0,54,0,9,0,29,0,9,0,33,0,9,0,27,0,9,0,28,0,9,0,25,0,9,0,26,0,9,0,24,0,9,0,23,0,9,0,22,0,9,0,30,0,9,0,32,0,9,0,39,0,9,0,40,0,9,0,41,0,9,0,42,0,9,0,43,0,9,0,44,0,9,0,45,0,9,0,46,0,9,0,47,0,9,0,48,0,9,0,53,0,9,0,49,0,9,0,50,0,9,0,51,0,9,0,52,0,9,0,25,0,10,0,42,0,10,0,23,0,10,0,22,0,10,0,21,0,10,0,40,0,10,0,38,0,10,0,37,0,10,0,34,0,10,0,33,0,10,0,24,0,10,0,20,0,10,0,41,0,10,0,18,0,10,0,13,0,10,0,14,0,10,0,15,0,10,0,16,0,10,0,17,0,10,0,26,0,10,0,27,0,10,0,28,0,10,0,29,0,10,0,30,0,10,0,31,0,10,0,32,0,10,0,19,0,10,0,35,0,10,0,36,0,10,0,9,0,11,0,8,0,11,0,7,0,11,0,39,0,10,0,5,0,11,0,11,0,11,0,6,0,11,0,4,0,11,0,3,0,11,0,2,0,11,0,1,0,11,0,10,0,11,0,22,0,11,0,25,0,11,0,23,0,11,0,13,0,11,0,14,0,11,0,15,0,11,0,16,0,11,0,17,0,11,0,18,0,11,0,19,0,11,0,1,0,14,0,248,90,6,0,248,84,6,0,248,72,6,0,248,48,6,0,0,0,0,0,0,0,0,0,3,2,5,3,4,3,3,3,2,3,1,3,1,4,0,4,3,2,5,3,4,3,3,3,2,3,1,3,1,4,0,4,1,1,3,3,2,3,3,4,2,4,1,4,1,5,0,5,1,1,3,3,2,3,3,4,2,4,1,4,1,5,0,5,1,1,3,3,2,3,3,4,2,4,1,4,1,5,0,5,1,1,1,2,1,3,3,5,2,5,1,5,1,6,0,6,90,0,22,0,212,0,22,0,213,0,22,0,214,0,22,0,215,0,22,0,216,0,22,0,217,0,22,0,218,0,22,0,219,0,22,0,220,0,22,0,221,0,22,0,222,0,22,0,223,0,22,0,224,0,22,0,225,0,22,0,226,0,22,0,227,0,22,0,228,0,22,0,229,0,22,0,230,0,22,0,232,0,22,0,203,0,22,0,233,0,22,0,234,0,22,0,231,0,22,0,236,0,22,0,237,0,22,0,238,0,22,0,239,0,22,0,240,0,22,0,241,0,22,0,242,0,22,0,243,0,22,0,244,0,22,0,245,0,22,0,246,0,22,0,247,0,22,0,248,0,22,0,2,1,22,0,235,0,22,0,249,0,22,0,252,0,22,0,253,0,22,0,254,0,22,0,0,1,22,0,92,0,22,0,96,0,22,0,1,1,22,0,113,0,22,0,4,1,22,0,5,1,22,0,251,0,22,0,255,0,22,0,134,0,21,0,250,0,22,0,124,0,22,0,117,0,22,0,3,1,22,0,120,0,22,0,211,0,22,0,123,0,22,0,130,0,22,0,210,0,22,0,209,0,22,0,208,0,22,0,207,0,22,0,206,0,22,0,205,0,22,0,204,0,22,0,195,0,22,0,202,0,22,0,201,0,22,0,200,0,22,0,199,0,22,0,198,0,22,0,197,0,22,0,139,0,22,0,196,0,22,0,194,0,22,0,193,0,22,0,192,0,22,0,191,0,22,0,190,0,22,0,189,0,22,0,188,0,22,0,187,0,22,0,186,0,22,0,185,0,22,0,97,0,22,0,132,0,22,0,133,0,22,0,134,0,22,0,135,0,22,0,136,0,22,0,137,0,22,0,138,0,22,0,140,0,22,0,141,0,22,0,142,0,22,0,143,0,22,0,144,0,22,0,145,0,22,0,146,0,22,0,147,0,22,0,148,0,22,0,149,0,22,0,150,0,22,0,151,0,22,0,152,0,22,0,153,0,22,0,154,0,22,0,155,0,22,0,156,0,22,0,157,0,22,0,158,0,22,0,159,0,22,0,160,0,22,0,161,0,22,0,162,0,22,0,163,0,22,0,164,0,22,0,165,0,22,0,166,0,22,0,167,0,22,0,168,0,22,0,169,0,22,0,170,0,22,0,171,0,22,0,127,0,22,0,143,0,21,0,172,0,22,0,173,0,22,0,174,0,22,0,175,0,22,0,176,0,22,0,177,0,22,0,83,0,20,0,144,0,21,0,178,0,22,0,145,0,21,0,179,0,22,0,180,0,22,0,84,0,20,0,181,0,22,0,182,0,22,0,140,0,21,0,52,0,19,0,61,0,18,0,85,0,20,0,183,0,22,0,184,0,22,0,139,0,21,0,86,0,20,0,61,0,19,0,87,0,20,0,88,0,20,0,64,0,19,0,67,0,19,0,71,0,19,0,42,0,18,0,46,0,19,0,44,0,18,0,70,0,19,0,89,0,20,0,73,0,19,0,45,0,19,0,56,0,18,0,54,0,18,0,57,0,18,0,69,0,19,0,40,0,18,0,48,0,18,0,53,0,18,0,32,0,17,0,68,0,19,0,50,0,18,0,49,0,18,0,31,0,17,0,47,0,18,0,46,0,18,0,45,0,18,0,33,0,17,0,34,0,17,0,35,0,17,0,36,0,17,0,39,0,16,0,35,0,16,0,32,0,16,0,29,0,16,0,37,0,16,0,30,0,16,0,36,0,16,0,42,0,16,0,38,0,16,0,33,0,15,0,41,0,16,0,34,0,15,0,35,0,15,0,36,0,15,0,27,0,15,0,26,0,15,0,29,0,15,0,31,0,15,0,39,0,15,0,23,0,14,0,24,0,14,0,25,0,14,0,27,0,14,0,28,0,14,0,30,0,14,0,37,0,14,0,32,0,14,0,33,0,14,0,19,0,13,0,20,0,13,0,21,0,13,0,22,0,13,0,23,0,13,0,24,0,13,0,25,0,13,0,26,0,13,0,24,0,12,0,23,0,12,0,21,0,12,0,20,0,12,0,19,0,12,0,18,0,12,0,15,0,11,0,16,0,11,0,18,0,11,0,19,0,11,0,27,0,11,0,26,0,11,0,14,0,10,0,19,0,10,0,15,0,10,0,16,0,10,0,17,0,10,0,18,0,10,0,13,0,9,0,20,0,9,0,21,0,9,0,12,0,9,0,19,0,9,0,15,0,8,0,14,0,8,0,16,0,8,0,17,0,8,0,12,0,7,0,9,0,7,0,10,0,7,0,8,0,6,0,9,0,6,0,9,0,5,0,8,0,5,0,5,0,4,0,1,0,1,0,3,0,3,0,7,0,5,0,6,0,5,0,11,0,6,0,10,0,6,0,14,0,7,0,15,0,7,0,11,0,7,0,13,0,7,0,11,0,8,0,13,0,8,0,12,0,8,0,15,0,9,0,16,0,9,0,17,0,9,0,14,0,9,0,18,0,9,0,23,0,10,0,20,0,10,0,22,0,10,0,21,0,10,0,25,0,11,0,24,0,11,0,23,0,11,0,22,0,11,0,21,0,11,0,20,0,11,0,17,0,11,0,25,0,12,0,26,0,12,0,22,0,12,0,29,0,12,0,27,0,12,0,28,0,12,0,32,0,13,0,28,0,13,0,35,0,13,0,34,0,13,0,33,0,13,0,31,0,13,0,30,0,13,0,27,0,13,0,29,0,13,0,36,0,14,0,22,0,14,0,26,0,14,0,34,0,14,0,29,0,14,0,31,0,14,0,21,0,14,0,35,0,14,0,24,0,15,0,32,0,15,0,41,0,15,0,40,0,15,0,38,0,15,0,37,0,15,0,25,0,15,0,28,0,15,0,30,0,15,0,23,0,15,0,44,0,16,0,43,0,16,0,28,0,16,0,33,0,16,0,45,0,16,0,40,0,16,0,31,0,16,0,27,0,16,0,26,0,16,0,34,0,16,0,45,0,17,0,50,0,17,0,44,0,17,0,39,0,17,0,49,0,17,0,51,0,17,0,47,0,17,0,43,0,17,0,55,0,18,0,42,0,17,0,46,0,17,0,48,0,17,0,41,0,17,0,40,0,17,0,38,0,17,0,37,0,17,0,47,0,19,0,51,0,18,0,52,0,18,0,48,0,19,0,58,0,18,0,59,0,18,0,49,0,19,0,60,0,18,0,43,0,18,0,41,0,18,0,72,0,19,0,39,0,18,0,66,0,19,0,65,0,19,0,38,0,18,0,82,0,20,0,81,0,20,0,63,0,19,0,62,0,19,0,57,0,19,0,60,0,19,0,59,0,19,0,58,0,19,0,37,0,18,0,56,0,19,0,80,0,20,0,55,0,19,0,54,0,19,0,135,0,21,0,79,0,20,0,53,0,19,0,78,0,20,0,51,0,19,0,50,0,19,0,77,0,20,0,76,0,20,0,131,0,22,0,75,0,20,0,129,0,22,0,128,0,22,0,142,0,21,0,126,0,22,0,125,0,22,0,132,0,21,0,141,0,21,0,122,0,22,0,121,0,22,0,74,0,20,0,119,0,22,0,118,0,22,0,137,0,21,0,116,0,22,0,115,0,22,0,114,0,22,0,73,0,20,0,112,0,22,0,111,0,22,0,110,0,22,0,109,0,22,0,108,0,22,0,107,0,22,0,106,0,22,0,105,0,22,0,104,0,22,0,103,0,22,0,102,0,22,0,101,0,22,0,100,0,22,0,99,0,22,0,98,0,22,0,138,0,21,0,136,0,21,0,95,0,22,0,94,0,22,0,93,0,22,0,133,0,21,0,91,0,22,0,131,0,21,0,89,0,22,0,88,0,22,0,87,0,22,0,86,0,22,0,85,0,22,0,84,0,22,0,83,0,22,0,82,0,22,0,81,0,22,0,80,0,22,0,79,0,22,0,78,0,22,0,77,0,22,0,76,0,22,0,75,0,22,0,74,0,22,0,73,0,22,0,72,0,22,0,71,0,22,0,70,0,22,0,69,0,22,0,68,0,22,0,67,0,22,0,66,0,22,0,65,0,22,0,64,0,22,0,63,0,22,0,62,0,22,0,61,0,22,0,60,0,22,0,59,0,22,0,58,0,22,0,57,0,22,0,56,0,22,0,55,0,22,0,54,0,22,0,53,0,22,0,52,0,22,0,51,0,22,0,50,0,22,0,49,0,22,0,48,0,22,0,47,0,22,0,46,0,22,0,45,0,22,0,44,0,22,0,43,0,22,0,42,0,22,0,41,0,22,0,40,0,22,0,39,0,22,0,38,0,22,0,37,0,22,0,36,0,22,0,35,0,22,0,34,0,22,0,33,0,22,0,32,0,22,0,31,0,22,0,30,0,22,0,29,0,22,0,28,0,22,0,27,0,22,0,26,0,22,0,25,0,22,0,24,0,22,0,23,0,22,0,22,0,22,0,21,0,22,0,20,0,22,0,19,0,22,0,18,0,22,0,17,0,22,0,16,0,22,0,15,0,22,0,14,0,22,0,13,0,22,0,12,0,22,0,11,0,22,0,10,0,22,0,9,0,22,0,8,0,22,0,7,0,22,0,6,0,22,0,5,0,22,0,4,0,22,0,3,0,22,0,2,0,22,0,1,0,22,0,0,0,22,0,120,137,6,0,120,131,6,0,120,119,6,0,120,95,6,0,0,0,0,0,0,0,0,0,160,0,120,0,128,0,96,0,176,0,144,0,96,1,32,1,192,2,64,2,240,0,180,0,64,1,240,0,0,0,0,0,104,218,33,0,32,84,35,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,216,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,200,2,0,0,0,0,0,0,216,9,0,0,0,0,0,0,0,0,0,0,176,219,33,0,88,84,35,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,224,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,9,0,0,0,0,0,0,0,0,0,0,110,2,0,0,18,4,0,0,206,0,0,0,0,0,0,0,1,1,1,2,1,3,0,3,104,221,33,0,144,84,35,0,0,0,0,0,111,0,0,0,0,0,0,0,0,0,0,0,232,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,141,6,0,0,0,0,0,22,6,0,0,0,0,0,0,10,0,0,0,0,0,0,0,70,2,0,0,0,0,0,0,0,0,0,0,208,222,33,0,168,84,35,0,0,0,0,0,111,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,239,28,0,48,185,33,0,0,0,0,0,120,115,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,26,4,0,0,112,4,0,0,76,1,0,0,80,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,160,223,33,0,200,84,35,0,3,0,0,0,86,98,117,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,5,0,0,0,0,0,0,0,0,0,0,228,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,242,28,0,160,186,33,0,0,0,0,0,104,116,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,10,6,0,0,120,10,0,0,188,2,0,0,18,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,208,250,29,0,0,141,29,0,3,0,0,0,49,86,98,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,141,6,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,3,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,73,33,0,32,29,32,0,3,0,0,0,112,105,82,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,5,0,0,238,1,0,0,0,0,0,0,0,0,0,0,44,5,0,0,0,0,0,0,0,0,0,0,216,73,33,0,48,29,32,0,3,0,0,0,112,105,82,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,5,0,0,0,0,0,0,0,0,0,0,186,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,193,33,0,120,121,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,168,149,6,0,0,0,0,0,200,0,0,0,76,3,0,0,182,2,0,0,154,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,161,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,120,48,29,0,152,214,33,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,178,4,0,0,232,8,0,0,150,0,0,0,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,177,35,0,88,163,35,0,3,0,0,0,4,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,6,0,0,176,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,177,35,0,120,163,35,0,3,0,0,0,4,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,9,0,0,0,0,0,0,0,0,0,0,228,0,0,0,108,4,0,0,0,0,0,0,0,0,0,0,200,246,28,0,120,188,33,0,24,117,32,0,200,246,28,0,0,0,0,0,0,0,0,0,112,105,82,83,0,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,38,0,0,0,230,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,224,33,0,80,85,35,0,3,0,0,0,8,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,5,0,0,238,1,0,0,0,0,0,0,0,0,0,0,44,5,0,0,0,0,0,0,0,0,0,0,208,246,28,0,136,188,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,80,0,0,0,70,0,0,0,84,1,0,0,158,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,224,224,33,0,120,85,35,0,3,0,0,0,8,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,5,0,0,0,0,0,0,0,0,0,0,186,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,23,28,32,36,40,43,46,48,51,54,56,58,60,62,64,66,68,70,72,74,76,77,79,80,82,84,85,87,88,90,91,92,94,95,96,98,99,100,102,103,104,105,107,108,109,110,111,112,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,144,145,146,147,148,149,150,151,151,152,153,154,155,156,156,157,158,159,160,160,161,162,163,164,164,165,166,167,168,168,169,170,171,171,172,173,174,174,175,176,176,177,178,179,179,180,181,182,182,183,184,184,185,186,186,187,188,188,189,190,190,191,192,192,193,194,194,195,196,196,197,198,198,199,200,200,201,202,202,203,204,204,205,205,206,207,207,208,208,209,210,210,211,212,212,213,213,214,215,215,216,216,217,218,218,219,219,220,220,221,222,222,223,223,224,224,225,226,226,227,227,228,228,229,230,230,231,231,232,232,233,233,234,235,235,236,236,237,237,238,238,239,239,240,240,241,242,242,243,243,244,244,245,245,246,246,247,247,248,248,249,249,250,250,251,251,252,252,253,253,254,254,255,255,255,0,0,2,0,2,0,3,0,3,0,3,0,4,0,3,0,5,0,3,0,6,0,3,0,14,0,4,0,30,0,5,0,62,0,6,0,126,0,7,0,254,0,8,0,254,1,9,0,254,3,10,0,254,7,11,0,254,15,12,0,0,0,0,0,128,221,30,0,16,52,30,0,128,191,29,0,152,91,29,0,36,80,1,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,56,150,6,0,0,0,0,0,24,0,0,0,88,9,0,0,66,1,0,0,204,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,91,29,0,8,0,0,0,0,0,0,0,148,2,0,0,84,3,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,112,247,28,0,152,188,33,0,0,0,0,0,112,247,28,0,3,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,151,6,0,0,0,0,0,76,0,0,0,124,6,0,0,18,2,0,0,206,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,117,32,0,128,129,31,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,7,0,0,2,4,0,0,48,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,224,33,0,160,85,35,0,0,0,0,0,11,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,3,0,0,0,0,0,0,0,0,0,0,136,2,0,0,70,5,0,0,0,0,0,0,0,0,0,0,208,247,28,0,8,189,33,0,0,0,0,0,208,247,28,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,166,4,0,0,74,1,0,0,8,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,247,28,0,24,189,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,6,0,0,32,5,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,73,33,0,120,29,32,0,1,0,0,0,76,78,79,83,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,7,0,0,0,0,0,0,192,2,0,0,0,0,0,0,122,7,0,0,0,0,0,0,0,0,0,0,88,225,33,0,184,85,35,0,1,0,0,0,67,78,79,83,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,7,0,0,0,0,0,0,192,2,0,0,0,0,0,0,122,7,0,0,0,0,0,0,0,0,0,0,88,225,33,0,184,85,35,0,1,0,0,0,67,78,79,83,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,5,0,0,0,0,0,0,0,0,0,0,252,1,0,0,238,8,0,0,0,0,0,0,0,0,0,0,8,88,31,0,104,165,30,0,1,0,0,0,3,64,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,6,0,0,0,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,28,0,40,189,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,3,0,0,210,6,0,0,84,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,225,33,0,8,86,35,0,0,0,0,0,87,79,78,83,0,0,0,0,0,0,0,0,16,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,164,6,0,0,0,0,0,144,239,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,4,0,0,0,0,0,0,48,1,0,0,0,0,0,0,224,7,0,0,0,0,0,0,0,0,0,0,104,226,33,0,16,86,35,0,0,0,0,0,87,79,78,83,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,239,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,188,1,0,0,52,6,0,0,0,0,0,0,0,0,0,0,216,226,33,0,64,86,35,0,0,0,0,0,74,86,77,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,164,6,0,0,0,0,0,224,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,9,0,0,0,0,0,0,0,0,0,0,44,0,0,0,216,7,0,0,0,0,0,0,0,0,0,0,64,248,28,0,64,189,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,48,6,0,0,172,0,0,0,34,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,252,28,0,104,190,33,0,0,0,0,0,0,0,0,0,2,80,1,0,28,0,0,0,0,0,0,0,65,0,0,0,48,244,35,0,216,191,13,0,0,0,0,0,40,0,0,0,252,5,0,0,20,1,0,0,236,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,252,28,0,136,190,33,0,0,0,0,0,0,0,0,0,0,0,1,0,8,0,0,0,0,0,0,0,64,0,2,0,56,244,35,0,0,0,0,0,0,0,0,0,4,0,0,0,108,7,0,0,44,2,0,0,140,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,253,28,0,168,190,33,0,0,1,0,0,56,119,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,222,2,0,0,0,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,226,33,0,80,86,35,0,0,0,0,0,50,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,16,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,104,253,28,0,224,190,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,4,0,0,128,8,0,0,222,10,0,0,216,2,0,0,110,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,228,33,0,136,86,35,0,0,0,0,0,84,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,5,0,0,0,0,0,0,0,0,0,0,236,2,0,0,186,10,0,0,0,0,0,0,0,0,0,0,184,74,33,0,56,30,32,0,1,0,0,0,23,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,1,0,0,0,0,0,0,0,0,0,0,60,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,91,29,0,8,0,0,0,0,0,0,0,104,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,19,37,20,0,0,0,0,128,228,33,0,152,86,35,0,1,0,0,0,42,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,9,0,0,0,0,0,0,0,0,0,0,172,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,50,83,0,168,233,82,0,40,87,83,0,40,51,83,0,168,234,82,0,40,89,83,0,40,55,83,0,168,242,82,0,168,105,82,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,95,87,0,168,205,86,0,40,169,85,0,8,96,87,0,232,205,86,0,168,169,85,0,8,97,87,0,232,207,86,0,168,173,85,0,40,105,83,0,232,223,86,0,168,205,85,0,40,169,83,0,0,0,0,0,240,253,28,0,120,191,33,0,0,0,0,0,160,119,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,0,0,0,28,1,0,0,14,10,0,0,220,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,76,34,0,232,25,34,0,0,224,0,0,16,76,34,0,0,0,0,0,0,0,0,0,0,0,0,0,15,80,1,0,0,0,0,0,0,0,0,0,138,1,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,229,33,0,248,86,35,0,1,0,0,0,15,80,1,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,6,0,0,0,0,0,0,0,0,0,0,196,2,0,0,248,5,0,0,0,0,0,0,0,0,0,0,192,229,33,0,0,87,35,0,0,0,0,0,82,73,71,83,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,5,0,0,0,0,0,0,0,0,0,0,176,1,0,0,234,2,0,0,0,0,0,0,0,0,0,0,72,230,33,0,16,87,35,0,0,0,0,0,102,0,0,0,0,0,0,0,0,0,0,0,56,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,3,0,0,0,0,0,0,40,0,0,0,0,0,0,0,210,10,0,0,0,0,0,0,0,0,0,0,152,230,33,0,64,87,35,0,0,0,0,0,102,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,5,0,0,0,0,0,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,4,29,0,184,4,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,0,0,0,0,0,0,0,184,55,7,0,0,0,0,0,200,0,0,0,76,3,0,0,182,2,0,0,154,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,4,29,0,112,195,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,56,10,0,0,54,8,0,0,162,2,0,0,48,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,17,17,17,17,17,17,17,16,17,17,17,17,17,17,17,8,248,9,247,10,246,11,245,12,244,13,243,14,242,15,241,4,4,4,4,252,252,252,252,5,5,5,5,251,251,251,251,6,6,6,6,250,250,250,250,7,7,7,7,249,249,249,249,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,254,254,254,254,254,254,254,254,254,254,254,254], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1128940);
/* memory initializer */ allocate([254,254,254,254,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,5,29,0,128,195,33,0,0,1,0,0,24,5,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,6,0,0,50,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,222,127,191,13,71,24,191,70,156,120,63,125,223,44,191,21,177,16,62,212,110,115,191,11,171,240,190,1,47,191,190,223,154,78,63,168,211,151,62,206,149,199,190,78,78,101,63,29,136,44,188,74,106,43,191,84,164,105,191,98,253,235,189,56,100,12,63,19,145,64,63,238,216,204,62,95,66,125,191,122,169,127,191,16,168,97,191,63,143,116,191,247,185,104,63,229,29,234,190,156,49,17,191,49,179,58,191,180,230,122,191,41,152,65,63,8,136,86,62,61,200,144,61,139,80,72,191,221,181,62,63,133,100,105,191,10,227,118,191,193,136,114,191,44,198,155,62,186,31,253,190,15,104,42,63,243,130,37,63,141,190,106,63,40,88,51,62,13,47,53,191,73,134,6,63,229,84,51,191,21,36,232,190,9,182,126,191,135,149,102,191,21,77,123,63,65,78,70,191,145,245,11,191,71,156,210,188,23,106,138,188,148,107,60,59,71,113,92,191,72,217,217,62,129,42,125,191,199,249,96,191,57,127,4,63,35,85,43,63,208,16,127,191,123,193,20,191,237,235,127,191,194,211,123,63,76,123,13,63,137,48,24,63,62,14,177,62,45,228,114,63,158,107,32,63,187,120,62,191,212,128,69,191,253,123,173,190,229,121,106,191,115,14,23,61,118,74,67,191,120,233,105,191,22,66,76,63,21,139,110,191,122,115,11,63,248,26,244,189,143,60,91,191,169,61,217,62,105,199,109,191,35,180,142,62,150,201,239,189,123,125,127,191,112,177,90,62,213,59,104,191,253,12,67,191,9,104,127,63,14,42,123,63,46,99,117,191,31,240,91,191,148,41,117,63,214,221,110,191,50,23,253,62,74,22,156,62,30,149,52,191,109,87,90,63,78,113,239,62,198,204,105,63,225,150,127,191,57,67,113,189,93,25,53,63,186,102,145,62,229,82,177,62,100,220,115,63,243,134,12,191,58,33,73,191,153,116,65,191,155,56,117,191,46,34,81,190,250,248,82,63,146,111,119,63,239,223,38,191,93,41,99,191,70,186,111,191,82,171,127,63,180,13,106,63,170,159,123,191,132,54,52,191,18,133,22,63,159,188,184,59,104,32,30,63,172,1,100,63,25,32,7,63,142,212,47,191,164,221,78,63,71,190,56,63,36,78,49,191,168,24,33,191,118,138,11,62,232,72,153,62,102,200,235,190,57,246,106,191,249,120,61,191,104,52,126,63,38,251,208,62,227,220,82,63,68,136,61,191,95,49,124,191,222,237,127,191,25,139,117,191,124,12,126,191,252,63,91,190,228,42,111,191,216,46,48,191,73,176,137,190,32,36,107,63,18,168,191,61,178,235,117,191,206,211,184,62,216,54,4,63,58,183,54,191,161,126,28,63,125,98,240,62,105,92,242,62,37,242,139,190,167,244,104,63,148,151,119,63,250,154,229,62,76,251,125,63,188,136,42,63,86,69,119,63,10,205,63,63,170,23,102,191,60,231,126,191,133,33,7,63,198,88,121,63,167,154,44,190,5,18,58,63,56,18,246,190,113,78,116,63,71,65,48,63,131,200,58,191,28,30,68,191,48,133,90,191,107,43,99,63,115,106,80,191,255,140,121,191,80,26,97,191,13,91,63,63,76,58,55,191,60,87,124,191,124,210,85,63,75,71,86,63,94,51,246,190,91,13,125,191,25,173,120,63,40,10,77,63,5,26,5,63,22,111,77,63,127,8,11,188,137,70,68,191,31,244,51,191,172,184,13,63,95,125,117,191,246,132,221,190,220,133,120,63,90,254,190,61,20,142,108,191,84,230,90,63,195,239,49,191,101,128,124,63,174,251,135,62,68,175,59,63,140,142,143,62,69,222,20,62,41,203,61,191,6,60,126,63,204,150,143,188,163,127,83,191,226,31,13,191,38,46,125,191,168,199,122,63,229,177,112,191,75,241,125,191,149,145,43,63,255,69,45,191,179,88,1,62,33,48,187,61,110,78,82,190,107,114,55,191,122,86,122,191,193,101,79,63,173,135,9,63,129,245,207,62,117,133,135,190,227,66,45,191,221,236,113,63,222,85,94,63,110,188,59,190,146,184,126,191,139,201,215,188,250,225,87,63,110,34,213,61,56,190,188,189,190,5,50,63,71,227,127,63,90,26,253,189,173,29,76,191,134,115,106,191,235,167,118,63,74,102,119,63,77,167,76,191,80,171,36,63,92,223,236,189,169,94,146,62,209,103,204,190,199,248,112,63,25,171,125,63,42,174,107,191,153,151,146,62,186,12,105,191,70,65,85,191,168,93,44,191,66,60,116,63,159,182,251,62,220,23,132,189,154,36,5,61,130,233,126,191,35,9,217,62,212,174,39,191,108,81,83,63,233,2,80,191,109,42,4,191,63,24,127,191,183,75,88,63,164,163,60,59,135,206,37,63,49,167,51,63,99,112,81,190,185,175,118,63,112,107,208,62,169,87,48,191,230,211,105,63,33,144,178,190,21,248,54,63,17,120,107,63,83,66,42,63,146,118,125,191,119,210,91,63,227,75,48,63,140,125,14,63,25,174,126,191,149,86,77,190,108,48,113,63,13,57,127,191,218,148,44,191,216,175,253,62,163,96,242,190,67,234,91,191,152,172,18,62,66,3,113,191,138,218,149,190,218,229,107,61,125,57,224,62,41,255,73,191,73,22,186,190,28,20,38,63,95,54,179,189,30,20,122,63,36,7,119,191,109,35,10,191,35,38,14,63,89,246,73,63,1,66,60,63,213,234,118,63,216,39,158,190,55,128,78,191,140,110,18,61,81,39,121,191,151,185,124,63,210,218,247,62,230,31,81,191,216,132,104,191,58,189,45,63,157,22,80,63,56,225,33,190,207,80,90,63,226,166,78,63,59,27,125,190,174,173,244,62,201,57,237,190,113,179,118,63,90,13,197,62,238,206,125,191,140,112,127,190,138,176,84,63,148,163,114,191,126,104,22,191,235,122,83,60,219,147,116,63,171,6,91,191,74,4,119,191,201,228,35,191,74,40,121,191,10,129,253,61,37,252,105,63,215,104,20,63,102,207,127,191,42,250,53,63,254,102,94,191,121,201,79,190,87,89,134,190,220,193,46,191,71,144,124,190,61,93,96,191,250,240,197,60,76,58,139,62,126,24,82,63,34,211,89,191,104,174,98,63,96,120,101,191,162,23,58,190,36,230,133,190,164,153,191,61,77,103,12,63,126,243,11,191,246,181,117,63,121,179,189,62,182,94,25,191,10,40,52,191,247,138,105,63,241,39,177,190,239,145,126,191,11,16,48,191,166,210,154,190,10,112,137,190,175,198,84,63,23,64,251,62,225,61,232,190,157,142,199,62,242,132,116,63,28,66,122,191,86,84,89,61,230,105,49,190,48,126,109,191,242,221,127,63,4,54,21,63,44,67,38,191,133,187,47,63,70,27,246,189,18,76,18,191,206,231,22,191,213,106,178,190,241,23,214,190,170,171,38,62,15,181,127,63,54,17,228,61,228,5,17,191,183,170,103,191,75,254,112,63,183,164,180,62,48,219,65,191,109,88,9,63,141,89,82,62,4,193,113,191,35,243,127,63,68,97,76,63,123,225,148,62,85,55,181,62,32,235,32,191,248,122,198,62,221,106,222,62,83,71,124,191,246,164,123,191,170,66,87,62,60,208,71,62,4,65,113,191,150,107,116,191,50,208,123,63,71,13,111,63,57,117,53,191,225,51,90,191,238,217,170,189,141,63,93,191,117,120,234,190,129,16,199,62,197,5,121,63,177,162,107,63,133,212,31,191,143,65,100,63,169,172,12,63,129,151,188,190,233,238,118,63,232,92,112,63,169,81,102,191,13,32,126,63,92,227,25,189,112,205,112,191,31,159,211,62,193,85,127,63,34,88,44,190,20,206,183,190,26,195,238,190,106,132,86,61,86,71,131,190,31,236,187,62,156,231,197,190,212,161,106,63,209,155,156,190,94,164,48,63,106,214,104,63,204,238,197,190,90,185,126,63,161,195,149,190,231,183,191,62,2,17,26,191,233,39,94,63,63,100,121,191,157,245,118,63,45,118,98,63,181,56,19,63,196,242,84,61,36,205,89,62,131,245,8,191,58,240,120,63,80,20,253,190,199,89,123,63,35,70,125,191,97,19,206,190,157,22,123,191,127,131,58,191,169,248,139,190,214,223,127,63,200,62,129,61,16,159,11,191,15,135,81,190,155,130,17,190,117,136,41,63,85,172,57,63,41,255,88,191,23,87,194,60,42,241,99,191,154,127,99,63,49,131,117,63,142,119,68,63,170,43,60,63,70,124,25,189,17,136,162,190,53,151,188,190,190,165,174,190,167,225,205,62,130,193,244,62,205,216,201,190,92,165,123,63,243,0,163,60,235,135,158,190,10,27,57,190,37,251,127,63,45,144,134,190,156,118,110,191,132,174,123,191,217,205,127,63,131,42,77,191,102,62,133,190,52,143,66,191,27,217,182,190,19,159,69,62,221,189,127,191,115,23,63,63,28,150,93,63,255,81,14,63,151,12,171,62,212,162,92,63,173,119,125,63,163,131,60,61,194,188,42,191,143,155,106,191,11,226,35,63,78,64,32,62,140,230,126,63,106,185,234,62,114,98,34,191,164,217,87,62,19,214,157,189,23,84,101,191,0,100,124,63,24,230,97,63,230,13,77,63,133,174,188,190,87,159,72,63,239,254,232,62,252,85,178,61,46,52,79,63,9,61,94,191,78,117,201,62,146,17,202,190,59,8,43,191,147,143,122,63,134,132,57,191,121,76,115,191,39,72,101,63,55,34,46,62,22,253,11,63,66,228,68,191,19,87,118,191,194,87,127,63,5,156,218,62,216,81,116,63,113,83,120,63,8,236,126,63,115,131,10,191,134,168,143,62,118,134,90,191,183,65,90,63,7,75,37,191,208,142,1,191,216,144,40,191,7,220,120,191,183,126,108,190,27,73,116,63,6,14,126,191,204,33,120,191,157,221,60,63,195,16,158,62,125,142,212,62,198,31,123,190,25,207,33,63,185,31,173,190,196,242,197,190,185,170,110,189,165,37,142,189,241,122,106,190,222,117,120,63,162,138,61,190,102,137,243,62,147,204,214,189,234,176,96,191,152,7,56,191,98,194,71,63,234,120,127,63,121,129,102,63,176,92,19,63,67,12,105,191,116,4,148,62,69,140,118,63,247,1,216,62,102,133,246,62,15,240,110,63,217,232,222,190,47,139,120,191,16,202,93,63,103,5,188,62,138,37,39,63,32,153,79,191,241,199,179,61,21,90,134,190,110,128,109,191,242,7,87,63,52,243,14,63,196,196,127,191,176,210,117,191,70,26,63,63,56,186,248,61,71,108,63,191,212,183,137,190,121,51,117,63,217,92,74,191,187,104,116,63,236,229,175,189,252,98,249,62,95,255,127,63,84,56,237,62,153,139,224,61,20,213,67,191,70,97,100,63,244,239,18,63,236,174,180,62,80,245,64,63,187,144,119,63,137,124,23,191,180,224,100,191,156,57,64,63,236,157,151,190,165,111,124,191,194,45,128,62,85,178,208,190,68,132,102,191,196,86,43,63,211,125,124,63,207,129,121,191,89,84,249,186,195,197,102,63,187,112,127,63,63,98,95,191,185,9,126,63,191,80,106,191,56,193,32,190,47,103,7,189,175,125,190,190,151,237,147,61,63,87,99,191,4,183,126,63,194,143,120,63,179,193,63,191,125,246,127,63,155,207,59,61,3,133,127,63,14,251,99,191,76,198,162,190,119,123,86,191,205,243,121,63,226,73,171,62,176,192,92,191,92,64,127,191,115,176,110,63,255,192,105,190,13,71,65,62,174,39,44,63,76,89,21,189,93,205,82,189,36,14,109,191,118,221,127,63,59,174,111,63,23,101,43,63,236,50,125,63,203,251,126,191,212,161,228,190,69,48,82,63,5,211,126,63,223,234,125,63,254,96,56,63,233,32,39,191,23,153,5,63,196,88,112,63,100,187,63,191,106,164,119,63,220,174,104,63,11,152,99,190,206,60,18,63,185,245,225,190,143,72,109,191,15,97,91,191,39,113,99,63,239,246,106,63,232,88,237,190,240,190,57,63,44,190,127,191,251,66,127,191,135,5,21,63,123,193,70,63,194,118,113,63,1,13,158,61,67,29,22,63,209,124,15,191,209,65,83,63,179,230,123,63,195,18,202,62,188,112,243,62,63,166,47,63,212,32,40,63,73,183,59,62,212,19,6,61,42,212,63,191,21,16,198,190,114,108,3,63,218,52,121,191,151,42,119,191,254,102,8,191,39,11,106,191,70,136,127,63,128,128,28,63,202,166,0,191,50,103,99,191,127,128,163,60,21,44,90,63,96,210,127,63,58,31,114,63,111,62,84,63,13,129,129,189,226,43,22,191,146,233,119,63,127,244,51,190,89,157,246,190,127,151,85,63,50,92,5,190,123,145,115,61,123,8,82,62,111,167,80,63,98,101,114,191,113,71,230,190,86,97,209,62,64,192,101,191,116,155,127,63,198,37,203,62,193,160,63,191,242,107,155,189,178,175,61,63,71,112,67,63,36,190,213,62,214,177,62,191,147,127,114,63,214,23,38,63,202,164,211,62,187,137,31,63,233,84,110,191,30,37,216,62,56,245,157,189,156,142,221,60,203,230,93,189,246,205,76,63,24,89,106,63,4,36,75,191,186,99,185,190,100,131,35,63,116,119,166,61,85,102,7,63,161,185,25,63,250,12,62,63,37,253,55,61,164,175,125,63,28,46,71,190,6,219,77,191,106,152,98,191,134,104,37,191,32,212,56,63,75,192,238,61,70,45,86,191,14,86,115,191,137,42,120,191,80,78,31,191,90,226,83,63,109,32,246,60,226,84,127,191,231,216,122,191,135,3,187,62,120,247,127,191,63,110,184,190,142,31,100,63,250,155,122,191,176,39,213,61,52,9,70,63,115,171,117,63,112,110,181,190,159,40,2,63,35,9,118,63,22,37,46,62,14,191,68,191,213,119,132,62,19,186,127,63,97,216,54,188,90,38,124,63,206,197,75,191,161,172,120,63,31,30,126,191,98,212,126,191,94,144,127,191,116,198,153,60,39,64,53,191,243,113,172,62,74,101,52,191,63,199,110,63,23,155,127,63,232,188,124,191,222,54,34,191,138,176,40,190,241,123,38,190,170,154,117,191,39,119,223,190,109,179,114,191,178,156,127,191,60,99,118,63,233,254,43,190,117,104,125,191,17,58,97,191,44,158,55,191,172,55,226,62,93,137,111,191,194,223,110,63,48,199,127,191,201,125,112,191,115,104,16,191,88,202,98,191,132,214,243,62,76,237,127,63,31,194,86,191,171,246,64,191,159,120,5,60,60,90,112,63,109,27,231,189,118,236,89,63,155,3,6,63,114,69,203,62,26,91,81,63,181,144,189,190,72,231,94,191,118,114,184,190,247,111,177,62,75,19,111,191,140,66,88,191,57,42,39,191,62,210,60,190,132,242,244,61,9,190,127,63,147,99,113,63,76,230,84,63,46,53,64,63,27,238,181,190,81,53,17,63,251,139,118,190,105,233,239,62,104,81,154,190,153,30,121,63,231,215,126,191,140,24,196,190,11,52,124,63,86,13,210,62,49,103,173,60,52,99,197,61,2,183,52,61,59,83,90,191,109,45,106,63,192,127,99,63,129,82,127,191,227,203,246,190,134,210,119,191,239,43,141,62,223,26,22,63,26,173,40,191,133,158,22,63,135,6,125,63,76,252,127,63,70,120,83,190,25,194,11,63,43,11,31,191,236,83,25,191,240,19,80,62,36,105,94,191,4,88,122,191,37,129,118,63,176,149,227,61,5,1,92,62,79,206,211,190,96,120,144,62,80,31,119,62,70,80,3,63,150,247,41,191,21,244,168,189,105,119,9,191,215,251,121,191,52,229,120,191,228,28,98,62,137,185,95,63,103,8,3,190,97,19,67,62,72,73,131,60,98,84,237,190,105,214,115,191,54,172,144,189,73,222,113,191,40,168,108,191,228,43,214,189,250,149,86,191,162,219,138,188,178,140,64,63,245,226,127,191,62,145,215,190,30,73,127,63,10,144,56,191,242,62,179,190,193,214,73,63,177,76,7,63,38,84,121,63,232,174,136,190,243,247,125,63,39,242,17,191,215,148,68,63,186,227,67,191,27,237,81,191,189,60,60,191,93,186,81,63,92,58,127,63,62,206,136,190,131,100,48,63,239,192,221,190,129,108,90,63,108,240,125,63,5,52,107,63,79,146,78,191,146,13,167,190,211,145,220,62,152,115,96,190,24,86,45,63,131,108,116,191,160,191,15,63,229,249,52,191,40,214,221,61,245,183,176,189,28,140,105,63,120,237,40,191,192,189,250,190,184,25,16,63,25,237,99,191,217,112,55,191,252,22,39,63,183,190,40,63,35,165,44,63,173,28,81,191,47,150,244,190,208,236,43,190,221,69,127,191,70,135,111,191,103,173,104,191,221,206,30,63,165,140,135,189,76,214,115,190,159,138,126,63,252,163,64,62,195,19,122,63,46,195,146,190,19,185,114,63,244,157,121,191,244,79,116,191,227,203,75,191,159,106,251,190,106,108,168,62,32,178,127,63,25,211,99,63,94,38,1,63,187,37,92,191,88,121,241,62,9,73,63,190,201,237,30,191,113,0,64,63,96,153,224,190,188,254,127,63,135,126,124,63,120,41,9,191,110,119,29,191,144,40,101,191,59,89,29,189,86,234,50,191,128,31,154,190,103,9,157,189,163,110,214,62,195,63,179,60,187,129,92,191,57,78,125,63,204,25,44,63,187,46,10,190,118,22,53,191,18,246,67,191,76,193,112,63,74,219,184,61,184,232,82,191,126,199,182,61,170,51,164,190,254,93,0,63,65,112,19,63,163,90,125,191,61,253,185,190,77,96,152,61,68,242,127,63,179,177,16,190,255,116,108,191,182,211,122,191,133,99,228,190,78,214,10,191,244,112,226,62,180,152,54,63,189,102,22,61,21,213,34,63,176,145,5,63,170,157,90,191,87,111,114,191,76,157,149,188,25,211,124,191,187,168,82,63,68,213,95,63,218,220,100,63,132,34,111,191,204,213,211,62,119,236,117,63,247,96,110,63,12,176,121,63,224,139,92,63,176,21,127,63,191,175,51,63,237,113,114,191,39,115,151,190,217,126,106,63,42,66,123,191,6,222,127,191,13,71,24,191,70,156,120,63,125,223,44,191,21,177,16,62,212,110,115,191,11,171,240,190,1,47,191,190,223,154,78,63,168,211,151,62,206,149,199,190,78,78,101,63,29,136,44,188,74,106,43,191,84,164,105,191,98,253,235,189,144,10,29,0,128,198,33,0,0,0,0,0,144,10,29,0,0,0,0,0,104,94,7,0,0,0,0,0,0,0,0,0,16,0,0,0,250,10,0,0,244,8,0,0,96,1,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,104,232,33,0,80,87,35,0,0,0,0,0,77,78,65,83,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,5,0,0,0,0,0,0,0,0,0,0,118,0,0,0,128,4,0,0,0,0,0,0,0,0,0,0,0,12,29,0,8,199,33,0,0,0,0,0,144,124,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,112,3,0,0,192,8,0,0,68,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,248,232,33,0,104,87,35,0,3,0,0,0,73,77,65,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,5,0,0,0,0,0,0,0,0,0,0,26,0,0,0,8,9,0,0,0,0,0,0,0,0,0,0,104,233,33,0,120,87,35,0,1,0,0,0,26,0,1,0,0,2,1,0,0,0,0,0,0,0,0,0,96,252,35,0,64,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,4,0,0,0,0,0,0,252,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,233,33,0,136,87,35,0,1,0,0,0,26,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,0,0,0,103,0,0,0,96,210,13,0,0,209,13,0,176,209,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,0,0,0,103,0,0,0,192,225,13,0,96,224,13,0,16,225,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,233,33,0,152,87,35,0,0,0,0,0,70,0,0,0,34,16,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,1,0,0,0,0,0,0,0,0,0,0,152,2,0,0,188,3,0,0,164,0,0,0,0,0,0,0,88,235,33,0,112,88,35,0,0,0,0,0,69,0,0,0,34,16,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,9,0,0,0,0,0,0,0,0,0,0,152,2,0,0,188,3,0,0,164,0,0,0,0,0,0,0,24,51,29,0,56,227,28,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,104,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,82,8,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,104,32,32,0,232,65,31,0,0,0,0,0,7,0,0,0,34,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,88,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,6,0,0,0,0,0,0,0,0,0,0,248,0,0,0,42,8,0,0,164,0,0,0,0,0,0,0,208,235,33,0,184,88,35,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,112,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,82,8,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,240,88,35,0,216,76,33,0,0,0,0,0,6,0,0,0,2,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,88,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,6,0,0,0,0,0,0,0,0,0,0,248,0,0,0,42,8,0,0,0,0,0,0,0,0,0,0,120,17,29,0,184,201,33,0,0,0,0,0,0,0,0,0,6,0,1,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,8,0,0,0,0,0,104,0,0,0,134,3,0,0,56,2,0,0,104,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,18,29,0,0,202,33,0,0,0,0,0,24,18,29,0,5,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,88,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,232,7,0,0,50,2,0,0,220,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,18,29,0,80,202,33,0,0,0,0,0,224,18,29,0,96,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,7,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,19,29,0,104,202,33,0,0,0,0,0,24,19,29,0,104,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,0,0,0,252,3,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,237,33,0,248,88,35,0,0,0,0,0,43,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,7,0,0,0,0,0,0,0,0,0,0,110,1,0,0,72,6,0,0,0,0,0,0,0,0,0,0,128,19,29,0,184,202,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,240,10,0,0,64,6,0,0,240,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,30,30,0,96,68,34,0,0,0,0,0,104,30,30,0,0,64,1,0,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,9,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,238,33,0,56,89,35,0,0,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,120,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,90,8,0,0,0,0,0,96,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,5,0,0,0,0,0,0,68,0,0,0,0,0,0,0,150,3,0,0,0,0,0,0,0,0,0,0,8,239,33,0,112,89,35,0,1,0,0,0,0,64,1,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,166,5,0,0,0,0,0,0,42,1,0,0,0,0,0,0,38,7,0,0,0,0,0,0,0,0,0,0,176,106,33,0,0,61,32,0,1,0,0,0,0,64,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,6,0,0,0,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,30,30,0,240,68,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,88,4,0,0,168,5,0,0,212,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,238,33,0,96,89,35,0,0,0,0,0,39,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,10,0,0,0,0,0,0,0,0,0,0,26,1,0,0,16,8,0,0,0,0,0,0,0,0,0,0,56,20,29,0,232,202,33,0,16,127,32,0,32,136,31,0,3,80,1,0,6,0,0,0,0,0,0,0,0,0,0,0,112,244,35,0,0,0,0,0,0,0,0,0,84,0,0,0,102,1,0,0,52,0,0,0,126,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,186,35,0,16,165,35,0,136,124,33,0,168,74,32,0,176,2,29,0,8,180,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,16,7,0,0,10,3,0,0,240,0,0,0,236,2,0,0,36,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,82,86,49,48,7,0,0,0,82,86,50,48,7,0,0,0,82,86,84,82,69,0,0,0,82,86,51,48,70,0,0,0,82,86,52,48,3,80,1,0,100,110,101,116,0,48,1,0,108,112,99,74,1,48,1,0,50,56,95,56,20,80,1,0,99,111,111,107,31,80,1,0,97,116,114,99,42,80,1,0,115,105,112,114,2,80,1,0,114,97,97,99,2,80,1,0,114,97,99,112,58,80,1,0,76,83,68,58,0,0,0,0,0,0,0,0,132,0,0,0,85,0,0,0,192,39,3,0,216,41,3,0,232,63,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,185,0,0,0,119,0,0,0,72,10,3,0,48,13,3,0,240,13,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,67,0,0,0,72,242,17,0,232,243,17,0,80,244,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,0,0,0,81,0,0,0,176,14,3,0,8,17,3,0,40,39,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,99,0,0,0,80,6,3,0,248,8,3,0,160,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,58,0,0,0,24,87,18,0,184,88,18,0,32,89,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,111,0,0,0,111,0,0,0,128,217,9,0,16,226,9,0,32,229,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,111,0,0,0,111,0,0,0,72,224,9,0,16,226,9,0,32,229,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,58,0,0,0,96,207,13,0,8,213,13,0,136,213,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,23,29,0,128,203,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,230,1,0,0,154,5,0,0,254,2,0,0,0,0,0,0,172,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,239,33,0,128,89,35,0,0,0,0,0,115,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,1,0,0,0,0,0,0,0,0,0,0,242,2,0,0,56,2,0,0,0,0,0,0,0,0,0,0,88,26,29,0,240,204,33,0,48,129,32,0,96,137,31,0,136,211,30,0,184,43,30,0,144,185,29,0,168,86,29,0,224,2,29,0,72,180,28,0,88,177,35,0,224,81,35,0,240,1,35,0,136,193,34,0,80,132,34,0,136,75,34,0,144,25,34,0,48,229,33,0,24,193,33,0,48,229,33,0,96,157,33,0,80,129,33,0,96,70,33,0,120,20,33,0,16,248,32,0,144,221,32,0,0,0,0,0,0,0,0,0,0,128,64,192,32,160,96,224,16,144,80,208,48,176,112,240,8,136,72,200,40,168,104,232,24,152,88,216,56,184,120,248,4,132,68,196,36,164,100,228,20,148,84,212,52,180,116,244,12,140,76,204,44,172,108,236,28,156,92,220,60,188,124,252,2,130,66,194,34,162,98,226,18,146,82,210,50,178,114,242,10,138,74,202,42,170,106,234,26,154,90,218,58,186,122,250,6,134,70,198,38,166,102,230,22,150,86,214,54,182,118,246,14,142,78,206,46,174,110,238,30,158,94,222,62,190,126,254,1,129,65,193,33,161,97,225,17,145,81,209,49,177,113,241,9,137,73,201,41,169,105,233,25,153,89,217,57,185,121,249,5,133,69,197,37,165,101,229,21,149,85,213,53,181,117,245,13,141,77,205,45,173,109,237,29,157,93,221,61,189,125,253,3,131,67,195,35,163,99,227,19,147,83,211,51,179,115,243,11,139,75,203,43,171,107,235,27,155,91,219,59,187,123,251,7,135,71,199,39,167,103,231,23,151,87,215,55,183,119,247,15,143,79,207,47,175,111,239,31,159,95,223,63,191,127,255,160,27,29,0,80,205,33,0,0,0,0,0,72,129,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,178,2,0,0,44,7,0,0,130,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,29,29,0,208,205,33,0,0,0,0,0,96,129,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,122,5,0,0,170,9,0,0,26,1,0,0,96,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,136,239,33,0,144,89,35,0,3,0,0,0,84,88,84,82,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,5,0,0,0,0,0,0,0,0,0,0,210,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,38,29,0,16,111,140,0,12,0,0,0,84,65,82,86,120,131,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1139180);
/* memory initializer */ allocate([232,103,30,0,88,90,30,0,0,0,0,0,184,75,30,0,0,0,0,0,14,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,240,33,0,168,89,35,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,4,0,0,0,0,0,0,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,30,29,0,80,206,33,0,0,1,0,0,144,129,32,0,0,0,0,0,112,98,8,0,0,0,0,0,14,0,0,0,24,0,0,0,0,0,0,0,78,7,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,240,33,0,224,89,35,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,98,8,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,102,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,52,50,48,0,0,0,0,73,89,85,86,0,0,0,0,89,86,49,50,6,0,0,0,89,85,86,57,6,0,0,0,89,86,85,57,7,0,0,0,89,52,49,66,4,0,0,0,89,52,50,66,4,0,0,0,80,52,50,50,4,0,0,0,89,86,49,54,12,0,0,0,73,52,50,48,12,0,0,0,73,89,85,86,12,0,0,0,89,86,49,50,13,0,0,0,89,52,50,66,13,0,0,0,80,52,50,50,8,0,0,0,89,56,48,48,8,0,0,0,89,56,32,32,1,0,0,0,89,85,89,50,1,0,0,0,89,52,50,50,1,0,0,0,86,52,50,50,1,0,0,0,86,89,85,89,1,0,0,0,89,85,78,86,17,0,0,0,85,89,86,89,17,0,0,0,72,68,89,67,17,0,0,0,85,89,78,86,17,0,0,0,85,89,78,89,17,0,0,0,117,121,118,49,17,0,0,0,50,86,117,49,17,0,0,0,65,86,82,110,17,0,0,0,65,86,49,120,17,0,0,0,65,86,117,112,17,0,0,0,86,68,84,90,17,0,0,0,97,117,118,50,17,0,0,0,99,121,117,118,18,0,0,0,89,52,49,49,8,0,0,0,71,82,69,89,25,0,0,0,78,86,49,50,26,0,0,0,78,86,50,49,46,0,0,0,82,71,66,15,50,0,0,0,66,71,82,15,44,0,0,0,82,71,66,16,48,0,0,0,66,71,82,16,45,0,0,0,15,66,71,82,49,0,0,0,15,82,71,66,43,0,0,0,16,66,71,82,47,0,0,0,16,82,71,66,62,0,0,0,82,71,66,12,64,0,0,0,66,71,82,12,63,0,0,0,12,66,71,82,65,0,0,0,12,82,71,66,36,1,0,0,82,66,65,64,38,1,0,0,66,82,65,64,35,1,0,0,64,82,66,65,37,1,0,0,64,66,82,65,28,0,0,0,82,71,66,65,40,1,0,0,82,71,66,0,30,0,0,0,66,71,82,65,42,1,0,0,66,71,82,0,29,0,0,0,65,66,71,82,41,1,0,0,0,66,71,82,27,0,0,0,65,82,71,66,39,1,0,0,0,82,71,66,2,0,0,0,82,71,66,24,3,0,0,0,66,71,82,24,7,0,0,0,52,49,49,80,4,0,0,0,52,50,50,80,13,0,0,0,52,50,50,80,33,0,0,0,52,52,48,80,34,0,0,0,52,52,48,80,5,0,0,0,52,52,52,80,14,0,0,0,52,52,52,80,9,0,0,0,66,49,87,48,10,0,0,0,66,48,87,49,19,0,0,0,66,71,82,8,22,0,0,0,82,71,66,8,20,0,0,0,66,71,82,4,23,0,0,0,82,71,66,4,24,0,0,0,66,52,66,89,21,0,0,0,82,52,66,89,42,0,0,0,82,71,66,48,41,0,0,0,48,82,71,66,68,0,0,0,66,71,82,48,67,0,0,0,48,66,71,82,32,0,0,0,89,49,0,16,31,0,0,0,16,0,49,89,72,0,0,0,89,51,11,10,71,0,0,0,10,11,51,89,74,0,0,0,89,51,10,10,73,0,0,0,10,10,51,89,78,0,0,0,89,51,0,10,77,0,0,0,10,0,51,89,46,1,0,0,89,51,11,12,45,1,0,0,12,11,51,89,50,1,0,0,89,51,10,12,49,1,0,0,12,10,51,89,54,1,0,0,89,51,0,12,53,1,0,0,12,0,51,89,48,1,0,0,89,51,11,14,47,1,0,0,14,11,51,89,52,1,0,0,89,51,10,14,51,1,0,0,14,10,51,89,56,1,0,0,89,51,0,14,55,1,0,0,14,0,51,89,54,0,0,0,89,51,11,16,55,0,0,0,16,11,51,89,56,0,0,0,89,51,10,16,57,0,0,0,16,10,51,89,58,0,0,0,89,51,0,16,59,0,0,0,16,0,51,89,35,0,0,0,89,52,11,8,44,1,0,0,89,52,10,8,43,1,0,0,89,52,0,8,66,0,0,0,89,50,0,8,92,0,0,0,89,52,11,9,91,0,0,0,9,11,52,89,94,0,0,0,89,52,10,9,93,0,0,0,9,10,52,89,96,0,0,0,89,52,0,9,95,0,0,0,9,0,52,89,98,0,0,0,89,52,11,10,97,0,0,0,10,11,52,89,100,0,0,0,89,52,10,10,99,0,0,0,10,10,52,89,102,0,0,0,89,52,0,10,101,0,0,0,10,0,52,89,104,0,0,0,89,52,11,16,103,0,0,0,16,11,52,89,106,0,0,0,89,52,10,16,105,0,0,0,16,10,52,89,108,0,0,0,89,52,0,16,107,0,0,0,16,0,52,89,82,0,0,0,71,51,0,8,84,0,0,0,71,51,0,9,83,0,0,0,9,0,51,71,86,0,0,0,71,51,0,10,85,0,0,0,10,0,51,71,58,1,0,0,71,51,0,12,57,1,0,0,12,0,51,71,60,1,0,0,71,51,0,14,59,1,0,0,14,0,51,71,88,0,0,0,71,51,0,16,87,0,0,0,16,0,51,71,110,0,0,0,88,89,90,36,111,0,0,0,36,90,89,88,65,1,0,0,186,66,71,8,69,1,0,0,186,66,71,16,70,1,0,0,16,71,66,186,66,1,0,0,186,82,71,8,71,1,0,0,186,82,71,16,72,1,0,0,16,71,82,186,67,1,0,0,186,71,66,8,73,1,0,0,186,71,66,16,74,1,0,0,16,66,71,186,68,1,0,0,186,71,82,8,75,1,0,0,186,71,82,16,76,1,0,0,16,82,71,186,0,0,0,0,82,52,50,48,7,0,0,0,82,52,49,49,17,0,0,0,50,118,117,121,17,0,0,0,50,86,117,121,17,0,0,0,65,86,85,73,17,0,0,0,98,120,121,118,1,0,0,0,121,117,118,50,1,0,0,0,121,117,118,115,1,0,0,0,68,86,79,79,46,0,0,0,76,53,53,53,44,0,0,0,76,53,54,53,43,0,0,0,66,53,54,53,3,0,0,0,50,52,66,71,3,0,0,0,98,120,98,103,30,0,0,0,66,71,82,65,28,0,0,0,82,71,66,65,2,0,0,0,98,120,114,103,29,0,0,0,65,66,71,82,31,0,0,0,98,49,54,103,41,0,0,0,98,52,56,114,44,0,0,0,3,0,0,0,5,0,0,0,89,86,50,52,1,0,0,0,89,86,89,85,255,255,255,255,0,0,0,0,248,112,33,0,96,48,33,0,0,0,0,0,0,0,0,0,12,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,24,90,35,0,112,78,33,0,88,33,32,0,184,66,31,0,24,145,30,0,144,254,29,0,24,145,29,0,96,51,29,0,120,227,28,0,248,222,35,0,80,143,35,0,224,48,35,0,216,233,34,0,120,170,34,0,232,110,34,0,216,54,34,0,64,6,34,0,8,216,33,0,120,179,33,0,144,146,33,0,0,0,0,0,0,0,0,0,96,244,33,0,48,90,35,0,1,0,0,0,58,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,124,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,4,0,0,0,0,0,0,0,0,0,0,154,0,0,0,80,3,0,0,100,0,0,0,0,0,0,0,152,244,33,0,72,90,35,0,1,0,0,0,1,48,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,6,0,0,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,245,33,0,96,90,35,0,1,0,0,0,0,48,1,0,96,0,0,0,0,0,0,0,0,0,0,0,144,252,35,0,88,249,35,0,64,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,176,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,7,0,0,0,0,0,0,172,2,0,0,0,0,0,0,50,9,0,0,0,0,0,0,0,0,0,0,64,245,33,0,120,90,35,0,1,0,0,0,0,48,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,7,0,0,0,0,0,0,0,0,0,0,160,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,41,29,0,64,210,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,128,2,0,0,192,5,0,0,10,1,0,0,82,2,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,246,33,0,144,90,35,0,0,0,0,0,134,0,0,0,0,0,0,0,0,0,0,0,152,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,9,0,0,0,0,0,0,248,1,0,0,0,0,0,0,42,10,0,0,0,0,0,0,0,0,0,0,152,246,33,0,168,90,35,0,0,0,0,0,134,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,3,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,79,33,0,160,33,32,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,240,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,9,0,0,0,0,0,0,248,1,0,0,0,0,0,0,42,10,0,0,0,0,0,0,0,0,0,0,32,79,33,0,8,34,32,0,0,0,0,0,146,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,3,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,248,246,33,0,216,90,35,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,160,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,7,0,0,0,0,0,0,240,2,0,0,0,0,0,0,134,10,0,0,0,0,0,0,0,0,0,0,32,247,33,0,80,91,35,0,0,0,0,0,56,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,0,0,0,0,0,0,0,0,28,1,0,0,148,5,0,0,0,0,0,0,0,0,0,0,147,101,94,255,255,255,223,208,171,0,0,0,0,0,0,0,255,255,255,255,255,204,255,255,153,255,255,102,255,255,51,255,255,0,255,204,255,255,204,204,255,204,153,255,204,102,255,204,51,255,204,0,255,153,255,255,153,204,255,153,153,255,153,102,255,153,51,255,153,0,255,102,255,255,102,204,255,102,153,255,102,102,255,102,51,255,102,0,255,51,255,255,51,204,255,51,153,255,51,102,255,51,51,255,51,0,255,0,255,255,0,204,255,0,153,255,0,102,255,0,51,255,0,0,204,255,255,204,255,204,204,255,153,204,255,102,204,255,51,204,255,0,204,204,255,204,204,204,204,204,153,204,204,102,204,204,51,204,204,0,204,153,255,204,153,204,204,153,153,204,153,102,204,153,51,204,153,0,204,102,255,204,102,204,204,102,153,204,102,102,204,102,51,204,102,0,204,51,255,204,51,204,204,51,153,204,51,102,204,51,51,204,51,0,204,0,255,204,0,204,204,0,153,204,0,102,204,0,51,204,0,0,153,255,255,153,255,204,153,255,153,153,255,102,153,255,51,153,255,0,153,204,255,153,204,204,153,204,153,153,204,102,153,204,51,153,204,0,153,153,255,153,153,204,153,153,153,153,153,102,153,153,51,153,153,0,153,102,255,153,102,204,153,102,153,153,102,102,153,102,51,153,102,0,153,51,255,153,51,204,153,51,153,153,51,102,153,51,51,153,51,0,153,0,255,153,0,204,153,0,153,153,0,102,153,0,51,153,0,0,102,255,255,102,255,204,102,255,153,102,255,102,102,255,51,102,255,0,102,204,255,102,204,204,102,204,153,102,204,102,102,204,51,102,204,0,102,153,255,102,153,204,102,153,153,102,153,102,102,153,51,102,153,0,102,102,255,102,102,204,102,102,153,102,102,102,102,102,51,102,102,0,102,51,255,102,51,204,102,51,153,102,51,102,102,51,51,102,51,0,102,0,255,102,0,204,102,0,153,102,0,102,102,0,51,102,0,0,51,255,255,51,255,204,51,255,153,51,255,102,51,255,51,51,255,0,51,204,255,51,204,204,51,204,153,51,204,102,51,204,51,51,204,0,51,153,255,51,153,204,51,153,153,51,153,102,51,153,51,51,153,0,51,102,255,51,102,204,51,102,153,51,102,102,51,102,51,51,102,0,51,51,255,51,51,204,51,51,153,51,51,102,51,51,51,51,51,0,51,0,255,51,0,204,51,0,153,51,0,102,51,0,51,51,0,0,0,255,255,0,255,204,0,255,153,0,255,102,0,255,51,0,255,0,0,204,255,0,204,204,0,204,153,0,204,102,0,204,51,0,204,0,0,153,255,0,153,204,0,153,153,0,153,102,0,153,51,0,153,0,0,102,255,0,102,204,0,102,153,0,102,102,0,102,51,0,102,0,0,51,255,0,51,204,0,51,153,0,51,102,0,51,51,0,51,0,0,0,255,0,0,204,0,0,153,0,0,102,0,0,51,238,0,0,221,0,0,187,0,0,170,0,0,136,0,0,119,0,0,85,0,0,68,0,0,34,0,0,17,0,0,0,238,0,0,221,0,0,187,0,0,170,0,0,136,0,0,119,0,0,85,0,0,68,0,0,34,0,0,17,0,0,0,238,0,0,221,0,0,187,0,0,170,0,0,136,0,0,119,0,0,85,0,0,68,0,0,34,0,0,17,238,238,238,221,221,221,187,187,187,170,170,170,136,136,136,119,119,119,85,85,85,68,68,68,34,34,34,17,17,17,0,0,0,255,251,255,239,217,187,232,201,177,147,101,94,252,222,232,157,136,145,255,255,255,255,255,255,255,255,255,71,72,55,122,94,85,223,208,171,255,251,249,232,202,197,138,124,119,0,0,0,136,247,33,0,112,91,35,0,0,0,0,0,61,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,146,4,0,0,0,0,0,0,0,0,0,0,216,0,0,0,238,5,0,0,54,0,0,0,0,0,0,0,224,247,33,0,128,91,35,0,0,0,0,0,59,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,8,0,0,0,0,0,0,0,0,0,0,158,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,248,33,0,160,91,35,0,1,0,0,0,19,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,251,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,3,0,0,0,0,0,0,0,0,0,0,190,2,0,0,146,8,0,0,0,0,0,0,0,0,0,0,8,44,29,0,112,211,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,228,2,0,0,200,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,249,33,0,184,91,35,0,1,0,0,0,24,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,3,0,0,0,0,0,0,0,0,0,0,100,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,45,29,0,160,212,33,0,0,1,0,0,216,45,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,1,0,0,84,8,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,48,29,0,128,214,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,126,6,0,0,122,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,162,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,249,33,0,208,91,35,0,0,0,0,0,105,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,140,34,0,40,82,34,0,0,0,0,0,104,30,34,0,2,80,1,0,13,0,0,0,0,0,0,0,64,0,5,0,64,253,35,0,208,139,8,0,0,0,0,0,128,0,0,0,214,4,0,0,184,2,0,0,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,3,3,0,4,4,4,4,1,1,1,1,1,1,2,0,1,8,9,2,3,10,11,16,17,24,25,18,19,26,27,4,5,12,20,13,6,7,14,21,28,29,22,15,23,30,31,32,33,40,48,41,34,35,42,49,56,57,50,43,36,37,44,51,58,59,52,45,38,39,46,53,60,61,54,47,55,62,63,200,255,33,0,168,92,35,0,0,0,0,0,149,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,1,0,0,0,0,0,0,0,0,0,0,254,1,0,0,54,3,0,0,0,0,0,0,0,0,0,0,0,6,3,5,0,1,1,1,1,2,0,0,0,0,0,0,16,253,33,0,40,92,35,0,0,0,0,0,149,0,0,0,0,32,0,0,0,0,0,0,184,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,143,8,0,0,0,0,0,208,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,8,0,0,0,0,0,0,104,1,0,0,0,0,0,0,204,6,0,0,0,0,0,0,0,0,0,0,0,8,1,9,16,24,17,25,2,10,3,11,18,26,19,27,32,40,33,34,41,48,56,49,42,35,43,50,57,58,51,59,4,12,5,6,13,20,28,21,14,7,15,22,29,36,44,37,30,23,31,38,45,52,60,53,46,39,47,54,61,62,55,63,216,80,33,0,112,92,35,0,0,0,0,0,149,0,0,0,0,16,0,64,0,0,0,0,80,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,146,8,0,12,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,0,0,0,0,0,0,0,204,2,0,0,0,0,0,0,190,7,0,0,0,0,0,0,0,0,0,0,144,3,34,0,200,92,35,0,0,0,0,0,149,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,38,1,0,0,130,3,0,0,0,0,0,0,0,0,0,0,4,40,77,112,0,0,0,0,32,254,33,0,112,92,35,0,0,0,0,0,149,0,0,0,0,16,0,64,0,0,0,0,200,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,146,8,0,12,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,0,0,0,0,0,0,0,204,2,0,0,0,0,0,0,190,7,0,0,0,0,0,0,0,0,0,0,4,40,76,5,41,6,10,0,168,146,30,0,248,255,29,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,240,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,4,0,0,0,0,0,0,116,1,0,0,0,0,0,0,246,2,0,0,0,0,0,0,0,0,0,0,192,68,31,0,184,146,30,0,0,0,0,0,63,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,63,0,0,16,63,0,0,216,62,248,255,161,62,21,0,115,62,33,64,54,62,8,176,8,62,11,8,205,61,42,198,153,61,130,169,102,61,51,51,51,63,72,225,250,62,178,157,175,62,198,220,117,62,139,26,44,62,245,241,240,61,55,169,168,61,79,32,108,61,60,74,37,61,90,104,231,60,205,204,12,63,72,225,154,62,53,94,42,62,127,103,187,61,188,36,78,61,68,195,226,60,22,110,121,60,232,46,9,60,138,229,150,59,176,0,38,59,0,0,0,63,0,0,128,62,0,0,0,62,0,0,128,61,0,0,0,61,0,0,128,60,0,0,0,60,0,0,128,59,0,0,0,59,0,0,128,58,0,0,0,58,0,0,128,57,0,0,0,57,0,0,128,56,0,0,0,56,0,0,128,55,128,128,8,136,34,170,85,0,3,3,2,2,1,1,0,0,0,4,0,2,0,1,0,0,80,11,34,0,144,93,35,0,0,0,0,0,62,0,0,0,0,16,0,64,0,0,0,0,240,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,153,8,0,0,0,0,0,48,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,5,0,0,0,0,0,0,152,0,0,0,0,0,0,0,38,4,0,0,0,0,0,0,0,0,0,0,200,15,34,0,200,93,35,0,0,0,0,0,62,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,8,0,0,0,0,0,0,0,0,0,0,168,0,0,0,180,7,0,0,0,0,0,0,0,0,0,0,160,52,29,0,56,216,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,206,4,0,0,50,6,0,0,58,1,0,0,34,3,0,0,150,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,54,29,0,184,216,33,0,0,0,0,0,24,54,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,58,5,0,0,118,9,0,0,194,2,0,0,184,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,160,62,31,0,104,140,30,0,3,0,0,0,83,74,104,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,249,8,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,3,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,224,16,34,0,24,94,35,0,0,0,0,0,142,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,17,34,0,152,94,35,0,3,0,0,0,6,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,255,8,0,0,0,0,0,16,4,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,2,0,0,0,0,0,0,0,0,0,0,48,2,0,0,28,2,0,0,0,0,0,0,0,0,0,0,16,81,33,0,24,36,32,0,0,0,0,0,66,0,0,0,0,0,0,0,0,0,0,0,248,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,4,0,0,0,0,0,0,116,1,0,0,0,0,0,0,246,2,0,0,0,0,0,0,0,0,0,0,56,81,33,0,112,36,32,0,0,0,0,0,66,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,6,34,0,24,93,35,0,0,0,0,0,65,0,0,0,0,0,0,0,0,0,0,0,216,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,4,0,0,0,0,0,0,116,1,0,0,0,0,0,0,246,2,0,0,0,0,0,0,0,0,0,0,96,8,34,0,88,93,35,0,0,0,0,0,65,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,17,34,0,200,94,35,0,0,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,24,253,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,5,0,0,0,0,0,0,32,0,0,0,0,0,0,0,30,7,0,0,0,0,0,0,0,0,0,0,248,17,34,0,224,94,35,0,0,0,0,0,110,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,187,35,0,96,183,35,0,1,0,0,0,17,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,150,31,0,88,132,31,0,0,0,0,0,176,116,31,0,5,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,88,29,0,184,81,29,0,1,0,0,0,5,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,160,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,150,31,0,144,132,31,0,0,1,0,0,200,116,31,0,0,0,0,0,32,190,2,0,0,0,0,0,5,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,88,29,0,184,81,29,0,1,0,0,0,5,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,169,32,0,120,145,32,0,0,0,0,0,0,0,0,0,10,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,212,35,0,184,204,35,0,1,0,0,0,10,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,169,32,0,208,145,32,0,0,1,0,0,0,0,0,0,0,0,0,0,80,190,2,0,0,0,0,0,10,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,212,35,0,184,204,35,0,1,0,0,0,10,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,221,32,0,232,193,32,0,0,0,0,0,0,0,0,0,11,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,181,28,0,184,175,28,0,1,0,0,0,11,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,208,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,222,32,0,48,194,32,0,0,1,0,0,0,0,0,0,0,0,0,0,128,190,2,0,0,0,0,0,11,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,181,28,0,184,175,28,0,1,0,0,0,11,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,77,32,0,40,28,32,0,0,0,0,0,0,0,0,0,14,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,202,28,0,0,196,28,0,1,0,0,0,14,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,248,243,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,77,32,0,80,29,32,0,0,1,0,0,0,0,0,0,0,0,0,0,176,190,2,0,0,0,0,0,14,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,202,28,0,0,196,28,0,1,0,0,0,14,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,243,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,121,32,0,184,97,32,0,0,0,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,250,28,0,56,242,28,0,1,0,0,0,15,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,8,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,121,32,0,8,98,32,0,0,1,0,0,0,0,0,0,0,0,0,0,224,190,2,0,0,0,0,0,15,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,250,28,0,56,242,28,0,1,0,0,0,15,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,208,31,0,176,187,31,0,0,0,0,0,192,168,31,0,2,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,14,29,0,48,8,29,0,1,0,0,0,2,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,80,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,208,31,0,240,187,31,0,0,1,0,0,208,168,31,0,0,0,0,0,16,191,2,0,0,0,0,0,2,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,14,29,0,48,8,29,0,1,0,0,0,2,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,248,31,0,24,227,31,0,0,0,0,0,0,0,0,0,3,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,40,29,0,232,32,29,0,1,0,0,0,3,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,128,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,248,31,0,88,227,31,0,0,1,0,0,0,0,0,0,0,0,0,0,64,191,2,0,0,0,0,0,3,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,40,29,0,232,32,29,0,1,0,0,0,3,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,89,32,0,136,65,32,0,1,0,0,0,27,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,48,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1149472);
/* memory initializer */ allocate([48,89,32,0,136,65,32,0,1,0,0,0,27,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,73,33,0,8,21,33,0,0,0,0,0,128,248,32,0,4,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,184,32,0,16,162,32,0,1,0,0,0,4,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,176,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,73,33,0,40,21,33,0,0,1,0,0,144,248,32,0,0,0,0,0,136,96,7,0,0,0,0,0,4,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,184,32,0,16,162,32,0,1,0,0,0,4,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,113,29,0,96,107,29,0,1,0,0,0,80,83,80,32,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,200,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,113,29,0,96,107,29,0,1,0,0,0,80,83,80,32,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,179,35,0,8,85,35,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,172,29,0,152,162,29,0,1,0,0,0,8,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,179,35,0,232,85,35,0,0,1,0,0,0,0,0,0,0,0,0,0,184,96,7,0,0,0,0,0,8,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,172,29,0,152,162,29,0,1,0,0,0,8,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,4,29,0,72,182,28,0,0,0,0,0,0,0,0,0,9,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,203,29,0,40,195,29,0,1,0,0,0,9,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,56,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,4,29,0,216,182,28,0,0,1,0,0,0,0,0,0,0,0,0,0,232,96,7,0,0,0,0,0,9,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,203,29,0,40,195,29,0,1,0,0,0,9,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,239,29,0,232,229,29,0,1,0,0,0,80,83,80,24,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,88,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,239,29,0,232,229,29,0,1,0,0,0,80,83,80,24,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,133,34,0,216,76,34,0,0,0,0,0,0,0,0,0,12,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,47,30,0,32,37,30,0,1,0,0,0,12,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,160,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,135,34,0,80,77,34,0,0,1,0,0,0,0,0,0,0,0,0,0,24,97,7,0,0,0,0,0,12,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,47,30,0,32,37,30,0,1,0,0,0,12,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,99,30,0,216,85,30,0,1,0,0,0,16,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,232,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,99,30,0,216,85,30,0,1,0,0,0,16,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,35,0,24,195,34,0,0,0,0,0,0,0,0,0,13,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,185,30,0,160,168,30,0,1,0,0,0,13,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,8,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,4,35,0,112,195,34,0,0,1,0,0,0,0,0,0,0,0,0,0,72,97,7,0,0,0,0,0,13,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,185,30,0,160,168,30,0,1,0,0,0,13,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,243,30,0,200,228,30,0,1,0,0,0,18,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,152,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,243,30,0,200,228,30,0,1,0,0,0,18,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,193,33,0,88,158,33,0,0,0,0,0,232,129,33,0,0,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,49,31,0,240,29,31,0,1,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,193,33,0,128,158,33,0,0,1,0,0,0,130,33,0,0,0,0,0,120,97,7,0,0,0,0,0,0,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,49,31,0,240,29,31,0,1,0,0,0,0,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,142,31,0,232,125,31,0,1,0,0,0,16,80,83,80,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,8,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,142,31,0,232,125,31,0,1,0,0,0,16,80,83,80,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,26,34,0,240,229,33,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,219,31,0,176,201,31,0,1,0,0,0,1,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,26,34,0,120,230,33,0,0,1,0,0,0,0,0,0,0,0,0,0,168,97,7,0,0,0,0,0,1,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,219,31,0,176,201,31,0,1,0,0,0,1,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,22,31,0,128,9,31,0,0,0,0,0,224,248,30,0,6,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,48,33,0,136,8,33,0,1,0,0,0,6,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,22,31,0,168,9,31,0,0,1,0,0,16,249,30,0,0,0,0,0,248,210,9,0,0,0,0,0,6,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,48,33,0,136,8,33,0,1,0,0,0,6,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,180,33,0,224,146,33,0,1,0,0,0,25,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,32,0,112,147,31,0,0,0,0,0,0,0,0,0,23,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,111,34,0,192,55,34,0,1,0,0,0,23,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,232,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,142,32,0,88,148,31,0,0,1,0,0,0,0,0,0,0,0,0,0,88,35,20,0,0,0,0,0,23,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,111,34,0,192,55,34,0,1,0,0,0,23,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,252,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,72,29,0,96,224,33,0,0,0,0,0,0,0,0,0,22,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,145,35,0,48,50,35,0,1,0,0,0,22,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,16,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,79,29,0,56,226,33,0,0,1,0,0,0,0,0,0,0,0,0,0,136,35,20,0,0,0,0,0,22,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,145,35,0,48,50,35,0,1,0,0,0,22,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,189,29,0,120,89,29,0,0,0,0,0,0,0,0,0,21,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,147,29,0,64,53,29,0,1,0,0,0,21,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,16,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,189,29,0,200,89,29,0,0,1,0,0,0,0,0,0,0,0,0,0,232,35,20,0,0,0,0,0,21,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,147,29,0,64,53,29,0,1,0,0,0,21,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,218,30,0,16,49,30,0,0,0,0,0,0,0,0,0,20,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,37,32,0,184,69,31,0,1,0,0,0,20,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,24,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,218,30,0,152,49,30,0,0,1,0,0,0,0,0,0,0,0,0,0,24,36,20,0,0,0,0,0,20,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,37,32,0,184,69,31,0,1,0,0,0,20,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,24,34,0,104,95,35,0,1,0,0,0,19,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,253,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,5,0,0,0,0,0,0,0,0,0,0,136,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,176,24,34,0,160,95,35,0,1,0,0,0,24,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,253,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,103,31,0,120,63,31,0,0,0,0,0,24,36,31,0,7,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,24,34,0,80,95,35,0,1,0,0,0,7,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,72,253,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,103,31,0,32,64,31,0,0,1,0,0,56,36,31,0,0,0,0,0,32,114,27,0,0,0,0,0,7,0,1,0,12,0,0,0,0,0,0,0,60,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,24,34,0,80,95,35,0,1,0,0,0,7,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,52,29,0,104,228,28,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,152,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,4,0,0,0,0,0,0,116,1,0,0,0,0,0,0,246,2,0,0,0,0,0,0,0,0,0,0,24,0,30,0,168,146,29,0,0,0,0,0,64,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,25,34,0,216,95,35,0,0,0,0,0,67,0,0,0,0,0,0,0,0,0,0,0,112,253,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,232,10,0,0,0,0,0,0,0,0,0,0,184,52,29,0,176,228,28,0,0,0,0,0,67,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,26,34,0,248,95,35,0,0,0,0,0,86,70,65,80,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,7,0,0,0,0,0,0,0,0,0,0,244,1,0,0,16,2,0,0,0,0,0,0,0,0,0,0,56,80,29,0,144,226,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,166,0,0,0,198,1,0,0,86,1,0,0,220,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,33,0,72,38,32,0,1,0,0,0,65,70,65,80,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,3,0,0,0,0,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,255,255,255,255,240,5,29,0,248,183,28,0,128,191,29,0,240,5,29,0,83,85,80,79,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,160,57,9,0,0,0,0,0,24,0,0,0,88,9,0,0,66,1,0,0,204,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,92,29,0,8,0,0,0,72,232,33,0,94,2,0,0,80,3,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,64,1,185,1,224,1,114,3,192,3,0,0,0,0,0,0,176,86,29,0,56,229,33,0,0,145,32,0,176,86,29,0,31,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,32,3,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,89,29,0,200,229,33,0,0,1,0,0,104,145,32,0,176,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,248,1,0,0,200,2,0,0,118,0,0,0,88,0,0,0,0,0,0,0,130,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,80,1,0,0,0,0,0,40,80,1,0,1,0,0,0,1,80,1,0,3,0,0,0,1,0,1,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,63,0,0,0,0,0,0,0,63,1,0,0,0,0,0,0,63,6,0,0,0,0,0,0,0,233,33,0,4,0,0,0,0,0,0,0,178,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,10,12,14,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,56,233,33,0,8,0,0,0,0,0,0,0,108,2,0,0,0,0,0,0,118,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,112,92,29,0,6,0,0,0,0,0,0,0,188,1,0,0,244,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,40,147,32,0,5,0,0,0,0,0,0,0,188,1,0,0,244,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,16,151,31,0,35,0,0,0,0,0,0,0,102,1,0,0,244,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,184,232,33,0,6,0,0,0,0,0,0,0,188,1,0,0,244,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,16,96,29,0,80,235,33,0,184,148,32,0,16,152,31,0,12,80,1,0,31,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,144,150,9,0,0,0,0,0,24,0,0,0,88,9,0,0,66,1,0,0,204,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,96,29,0,200,235,33,0,0,35,0,0,160,96,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,212,9,0,0,244,2,0,0,8,0,0,0,92,3,0,0,84,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,151,9,0,192,155,9,0,112,151,9,0,176,151,9,0,8,97,29,0,0,236,33,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,14,4,0,0,164,6,0,0,14,2,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,34,0,80,98,35,0,0,0,0,0,85,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,4,0,0,0,0,0,0,0,0,0,0,90,0,0,0,30,4,0,0,0,0,0,0,0,0,0,0,169,0,0,0,86,80,57,48,14,0,0,0,82,71,66,15,14,0,0,0,66,71,82,15,14,0,0,0,82,71,66,16,14,0,0,0,66,71,82,16,14,0,0,0,15,66,71,82,14,0,0,0,15,82,71,66,14,0,0,0,16,66,71,82,14,0,0,0,16,82,71,66,14,0,0,0,82,71,66,12,14,0,0,0,66,71,82,12,14,0,0,0,12,66,71,82,14,0,0,0,12,82,71,66,14,0,0,0,82,71,66,65,14,0,0,0,82,71,66,0,14,0,0,0,66,71,82,65,14,0,0,0,66,71,82,0,14,0,0,0,65,66,71,82,14,0,0,0,0,66,71,82,14,0,0,0,65,82,71,66,14,0,0,0,0,82,71,66,14,0,0,0,82,71,66,24,14,0,0,0,66,71,82,24,14,0,0,0,52,49,49,80,14,0,0,0,52,50,50,80,14,0,0,0,52,50,50,80,14,0,0,0,52,52,48,80,14,0,0,0,52,52,48,80,14,0,0,0,52,52,52,80,14,0,0,0,52,52,52,80,14,0,0,0,66,49,87,48,14,0,0,0,66,48,87,49,14,0,0,0,66,71,82,8,14,0,0,0,82,71,66,8,14,0,0,0,66,71,82,4,14,0,0,0,82,71,66,4,14,0,0,0,66,52,66,89,14,0,0,0,82,52,66,89,14,0,0,0,66,71,82,48,14,0,0,0,82,71,66,48,14,0,0,0,48,66,71,82,14,0,0,0,48,82,71,66,14,0,0,0,66,82,65,64,14,0,0,0,82,66,65,64,14,0,0,0,64,66,82,65,14,0,0,0,64,82,66,65,14,0,0,0,89,51,11,10,14,0,0,0,10,11,51,89,14,0,0,0,89,51,10,10,14,0,0,0,10,10,51,89,14,0,0,0,89,51,0,10,14,0,0,0,10,0,51,89,14,0,0,0,89,51,11,12,14,0,0,0,12,11,51,89,14,0,0,0,89,51,10,12,14,0,0,0,12,10,51,89,14,0,0,0,89,51,0,12,14,0,0,0,12,0,51,89,14,0,0,0,89,51,11,14,14,0,0,0,14,11,51,89,14,0,0,0,89,51,10,14,14,0,0,0,14,10,51,89,14,0,0,0,89,51,0,14,14,0,0,0,14,0,51,89,14,0,0,0,89,49,0,16,14,0,0,0,16,0,49,89,14,0,0,0,89,51,11,16,14,0,0,0,16,11,51,89,14,0,0,0,89,51,10,16,14,0,0,0,16,10,51,89,14,0,0,0,89,51,0,16,14,0,0,0,16,0,51,89,14,0,0,0,89,52,11,8,14,0,0,0,89,52,10,8,14,0,0,0,89,52,0,8,14,0,0,0,89,50,0,8,14,0,0,0,89,49,0,9,14,0,0,0,9,0,49,89,14,0,0,0,89,52,11,9,14,0,0,0,9,11,52,89,14,0,0,0,89,52,10,9,14,0,0,0,9,10,52,89,14,0,0,0,89,52,0,9,14,0,0,0,9,0,52,89,14,0,0,0,89,49,0,10,14,0,0,0,10,0,49,89,14,0,0,0,89,52,11,10,14,0,0,0,10,11,52,89,14,0,0,0,89,52,10,10,14,0,0,0,10,10,52,89,14,0,0,0,89,52,0,10,14,0,0,0,10,0,52,89,14,0,0,0,89,49,0,16,14,0,0,0,16,0,49,89,14,0,0,0,89,52,11,16,14,0,0,0,16,11,52,89,14,0,0,0,89,52,10,16,14,0,0,0,16,10,52,89,14,0,0,0,89,52,0,16,14,0,0,0,16,0,52,89,14,0,0,0,71,51,0,8,14,0,0,0,71,51,0,9,14,0,0,0,9,0,51,71,14,0,0,0,71,51,0,10,14,0,0,0,10,0,51,71,14,0,0,0,71,51,0,12,14,0,0,0,12,0,51,71,14,0,0,0,71,51,0,14,14,0,0,0,14,0,51,71,14,0,0,0,71,51,0,16,14,0,0,0,16,0,51,71,14,0,0,0,88,89,90,36,14,0,0,0,36,90,89,88,14,0,0,0,186,66,71,8,14,0,0,0,186,66,71,16,14,0,0,0,16,71,66,186,14,0,0,0,186,82,71,8,14,0,0,0,186,82,71,16,14,0,0,0,16,71,82,186,14,0,0,0,186,71,66,8,14,0,0,0,186,71,66,16,14,0,0,0,16,66,71,186,14,0,0,0,186,71,82,8,14,0,0,0,186,71,82,16,14,0,0,0,16,82,71,186,0,0,0,0,0,0,0,0,2,112,1,0,85,84,70,56,4,112,1,0,83,83,65,0,0,112,1,0,68,86,68,83,1,112,1,0,68,86,66,83,7,112,1,0,68,86,66,84,0,0,0,0,0,0,0,0,112,98,29,0,8,237,33,0,80,149,32,0,112,98,29,0,0,80,1,0,13,0,0,0,0,0,0,0,64,4,0,0,168,215,17,0,0,0,0,0,0,0,0,0,208,14,0,0,76,7,0,0,92,1,0,0,134,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,189,35,0,24,165,35,0,152,124,33,0,176,74,32,0,64,99,31,0,176,74,32,0,48,175,30,0,240,22,30,0,128,166,29,0,24,70,29,0,40,245,28,0,184,239,35,0,216,160,35,0,48,63,35,0,136,245,34,0,176,183,34,0,24,122,34,0,0,65,34,0,168,16,34,0,176,223,33,0,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,0,0,0,0,1,0,0,0,100,117,98,0,0,0,0,0,0,0,0,0,2,0,0,0,111,114,105,103,105,110,97,108,0,0,0,0,4,0,0,0,99,111,109,109,101,110,116,0,0,0,0,0,8,0,0,0,108,121,114,105,99,115,0,0,0,0,0,0,16,0,0,0,107,97,114,97,111,107,101,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,105,29,0,200,240,33,0,0,0,0,4,104,105,29,0,168,215,17,0,0,0,0,0,0,0,0,0,0,0,0,0,208,14,0,0,48,10,0,0,94,8,0,0,14,3,0,0,122,8,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,112,1,0,85,84,70,56,0,0,0,0,0,0,0,0,8,210,17,0,200,215,17,0,248,213,17,0,232,238,18,0,48,228,18,0,240,156,9,0,152,215,17,0,0,0,0,0,20,0,1,0,32,68,70,80,21,0,1,0,80,70,68,32,22,0,1,0,64,68,70,80,23,0,1,0,80,70,68,64,1,0,1,0,16,68,83,80,0,0,1,0,80,83,68,16,13,0,1,0,24,68,83,80,12,0,1,0,80,83,68,24,9,0,1,0,32,68,83,80,8,0,1,0,80,83,68,32,4,0,1,0,80,83,68,8,3,0,1,0,16,68,85,80,2,0,1,0,80,85,68,16,15,0,1,0,24,68,85,80,14,0,1,0,80,85,68,24,11,0,1,0,32,68,85,80,10,0,1,0,80,85,68,32,5,0,1,0,80,85,68,8,27,0,1,0,80,83,80,8,16,80,83,80,16,80,83,80,18,0,1,0,80,83,80,16,80,83,80,24,80,83,80,24,80,83,80,32,80,83,80,32,0,0,0,0,0,0,0,0,152,105,29,0,208,240,33,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,161,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,105,29,0,8,241,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,90,6,0,0,68,2,0,0,224,1,0,0,180,0,0,0,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,108,29,0,24,242,33,0,0,1,0,0,56,151,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,4,0,0,18,2,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,46,34,0,120,98,35,0,1,0,0,0,34,80,1,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,253,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,0,0,0,0,0,0,0,162,2,0,0,0,0,0,0,234,10,0,0,0,0,0,0,0,0,0,0,64,48,34,0,136,98,35,0,1,0,0,0,34,80,1,0,2,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,253,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1159720);
/* memory initializer */ allocate([214,10,0,0,0,0,0,0,0,0,0,0,90,1,0,0,106,5,0,0,0,0,0,0,0,0,0,0,62,12,222,20,214,26,112,30,121,33,225,35,16,38,207,39,135,41,53,43,170,44,250,45,84,47,225,48,125,50,244,51,106,53,203,54,16,56,124,57,13,59,117,60,208,61,29,63,129,64,164,65,194,66,249,67,15,69,28,70,62,71,88,72,76,73,134,74,181,75,184,76,209,77,237,78,20,80,77,81,170,82,217,83,34,85,121,86,181,87,228,88,27,90,54,91,84,92,118,93,163,94,201,95,243,96,19,98,70,99,130,100,8,102,129,103,15,105,208,106,229,108,47,111,242,114,123,122,0,0,0,0,197,229,88,191,220,243,56,63,241,42,195,191,4,3,232,190,81,47,192,62,157,99,188,63,161,186,253,191,49,178,152,191,92,59,21,191,14,22,142,189,132,43,200,62,233,43,104,63,58,62,190,63,186,45,14,64,227,225,24,192,183,67,231,191,164,140,180,191,247,230,137,191,25,172,76,191,161,73,14,191,171,179,170,190,182,160,7,190,55,169,104,61,61,127,130,62,224,103,244,62,118,26,61,63,210,171,133,63,249,157,178,63,252,169,231,63,127,20,25,64,167,235,24,192,31,134,254,191,2,46,224,191,96,59,200,191,9,52,178,191,32,181,155,191,117,2,134,191,119,248,99,191,19,186,67,191,188,60,37,191,56,163,6,191,85,217,207,190,37,31,155,190,250,184,86,190,229,236,253,189,232,74,68,189,230,33,211,60,14,19,205,61,34,227,49,62,49,97,132,62,91,95,180,62,85,250,233,62,135,167,19,63,233,71,51,63,125,177,87,63,160,51,129,63,51,80,151,63,12,62,173,63,67,27,196,63,135,219,221,63,50,114,252,63,201,117,25,64,35,215,36,192,84,171,3,192,201,1,243,191,125,234,226,191,2,72,213,191,250,127,201,191,28,234,191,191,196,64,183,191,203,191,174,191,165,105,166,191,39,50,157,191,117,85,148,191,193,202,139,191,203,188,129,191,204,151,107,191,3,38,84,191,20,204,60,191,10,16,37,191,201,32,15,191,129,175,248,190,201,114,210,190,251,34,177,190,185,250,145,190,42,200,111,190,34,140,63,190,70,182,19,190,152,191,226,189,137,124,151,189,253,192,21,189,28,40,240,187,29,204,166,60,252,54,68,61,226,0,154,61,167,232,200,61,149,239,249,61,207,102,21,62,94,128,45,62,109,198,73,62,26,166,102,62,104,233,130,62,250,242,146,62,7,177,163,62,194,133,180,62,209,30,199,62,170,242,221,62,68,50,244,62,79,62,5,63,254,127,16,63,103,185,28,63,233,40,43,63,61,242,59,63,144,159,77,63,22,223,96,63,29,229,116,63,30,21,133,63,109,143,144,63,135,77,156,63,118,109,167,63,119,132,179,63,48,186,192,63,7,183,207,63,38,225,226,63,28,183,248,63,205,149,18,64,0,0,0,0,51,210,52,219,26,225,111,229,196,232,143,235,9,238,57,240,77,242,42,244,220,245,134,247,18,249,153,250,8,252,108,253,183,254,255,255,81,1,184,2,61,4,232,5,170,7,129,9,152,11,241,13,218,16,159,20,222,25,218,31,92,39,175,50,2,2,2,2,2,2,2,2,2,3,3,4,4,5,6,6,7,8,9,10,12,14,15,0,192,108,29,0,56,242,33,0,0,0,0,0,72,151,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,60,7,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,51,34,0,176,98,35,0,0,0,0,0,147,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,240,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,7,0,0,0,0,0,0,0,0,0,0,184,0,0,0,174,4,0,0,0,0,0,0,0,0,0,0,8,109,29,0,136,242,33,0,0,0,0,0,8,109,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,104,5,0,0,58,0,0,0,232,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,0,0,0,65,8,66,8,71,8,82,8,0,0,0,0,0,0,0,0,27,0,0,0,65,8,82,8,71,8,66,8,0,0,0,0,0,0,0,0,3,0,0,0,66,8,71,8,82,8,0,0,0,0,0,0,0,0,0,0,30,0,0,0,66,8,71,8,82,8,65,8,0,0,0,0,0,0,0,0,2,0,0,0,82,8,71,8,66,8,0,0,0,0,0,0,0,0,0,0,63,0,0,0,70,4,82,4,71,4,66,4,0,0,0,0,0,0,0,0,41,0,0,0,82,8,114,8,71,8,103,8,66,8,98,8,0,0,0,0,41,0,0,0,82,16,71,16,66,16,0,0,0,0,0,0,0,0,0,0,42,0,0,0,114,8,82,8,103,8,71,8,98,8,66,8,0,0,0,0,45,0,0,0,70,1,82,5,71,5,66,5,0,0,0,0,0,0,0,0,43,0,0,0,82,5,71,6,66,5,0,0,0,0,0,0,0,0,0,0,28,0,0,0,82,8,71,8,66,8,65,8,0,0,0,0,0,0,0,0,11,0,0,0,80,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,10,4,1,2,1,1,2,1,1,16,0,0,0,17,0,0,0,6,14,43,52,4,1,1,10,4,1,2,1,1,2,1,2,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,16,111,29,0,24,244,33,0,168,152,32,0,16,111,29,0,0,0,1,0,2,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,0,0,0,10,5,0,0,74,2,0,0,202,5,0,0,214,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,116,29,0,40,247,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,0,0,0,242,0,0,0,26,1,0,0,10,0,0,0,124,7,0,0,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,1,3,2,2,1,0,0,0,13,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,1,3,2,2,2,0,0,0,13,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,128,154,31,0,176,223,30,0,168,152,32,0,0,0,0,0,0,0,1,0,2,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,0,0,0,10,5,0,0,74,2,0,0,202,5,0,0,214,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,3,4,1,2,2,1,1,17,0,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,1,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,3,4,1,2,2,1,3,3,0,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,3,4,1,2,2,1,4,2,0,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,3,4,1,2,2,1,32,2,3,14,0,0,0,13,0,0,0,6,14,43,52,4,1,1,1,4,1,2,2,2,1,2,0,13,0,0,0,25,0,0,0,6,14,43,52,4,1,1,7,4,1,2,2,3,1,1,0,14,0,0,0,89,0,0,0,6,14,43,52,4,1,1,1,4,1,2,1,127,0,0,0,13,0,0,0,14,0,0,0,6,14,43,52,4,1,1,10,4,1,2,1,1,2,1,0,15,0,0,0,14,0,0,0,6,14,43,52,4,1,1,1,4,1,2,2,113,0,0,0,13,0,0,0,100,0,0,0,6,14,43,52,4,1,1,1,4,1,2,2,3,2,0,0,14,0,0,0,100,0,0,0,6,14,43,52,4,1,1,10,4,1,2,2,1,50,0,0,14,0,0,0,28,0,0,0,6,14,43,52,4,1,1,10,4,1,2,1,1,2,2,1,16,0,0,0,128,0,0,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,13,0,0,0,0,0,1,0,6,14,43,52,4,1,1,1,4,2,2,1,127,0,0,0,13,0,0,0,0,0,1,0,6,14,43,52,4,1,1,7,4,2,2,1,126,0,0,0,13,0,0,0,1,0,1,0,6,14,43,52,4,1,1,4,4,2,2,2,3,1,1,0,15,0,0,0,7,0,1,0,6,14,43,52,4,1,1,1,4,2,2,2,3,2,1,0,15,0,0,0,3,80,1,0,6,14,43,52,4,1,1,1,4,2,2,2,3,2,5,0,15,0,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,3,1,4,3,6,5,7,4,7,3,7,11,9,10,9,9,9,17,10,16,10,15,10,14,10,13,10,12,10,11,10,10,10,9,10,8,10,7,10,6,10,5,10,4,10,7,11,6,11,5,11,4,11,3,11,2,11,3,12,2,12,0,0,0,0,0,0,8,117,29,0,144,247,33,0,0,0,0,0,8,117,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,4,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,84,33,0,0,40,32,0,0,0,0,0,50,67,86,77,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,4,0,0,0,0,0,0,0,0,0,0,96,1,0,0,86,0,0,0,0,0,0,0,0,0,0,0,40,54,34,0,216,98,35,0,0,0,0,0,49,67,86,77,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,4,0,0,0,0,0,0,0,0,0,0,96,1,0,0,86,0,0,0,0,0,0,0,0,0,0,0,75,4,0,0,0,51,3,0,152,59,3,0,176,46,3,0,96,42,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,4,0,0,64,26,3,0,216,34,3,0,240,21,3,0,160,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,120,29,0,240,248,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,14,5,0,0,100,0,0,0,46,0,0,0,0,0,0,0,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,124,29,0,120,252,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,252,7,0,0,80,5,0,0,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,57,34,0,72,99,35,0,0,0,0,0,166,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,5,0,0,0,0,0,0,0,0,0,0,142,2,0,0,50,8,0,0,0,0,0,0,0,0,0,0,56,147,34,0,240,110,35,0,0,0,0,0,54,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,5,0,0,0,0,0,0,0,0,0,0,220,2,0,0,154,2,0,0,0,0,0,0,0,0,0,0,144,55,34,0,8,99,35,0,0,0,0,0,47,0,0,0,0,0,0,0,0,0,0,0,168,253,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,9,0,0,0,0,0,0,50,1,0,0,0,0,0,0,106,6,0,0,0,0,0,0,0,0,0,0,8,56,34,0,32,99,35,0,0,0,0,0,47,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,0,0,0,0,0,0,0,0,0,0,0,104,2,0,0,218,2,0,0,0,0,0,0,0,0,0,0,112,64,34,0,176,99,35,0,0,0,0,0,168,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,111,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,10,0,0,0,0,0,0,0,0,0,0,56,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,48,66,34,0,168,100,35,0,0,0,0,0,163,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,147,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,7,0,0,0,0,0,0,0,0,0,0,82,1,0,0,54,1,0,0,0,0,0,0,0,0,0,0,8,67,34,0,240,100,35,0,0,0,0,0,46,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,7,0,0,0,0,0,0,0,0,0,0,32,2,0,0,244,5,0,0,0,0,0,0,0,0,0,0,120,124,29,0,200,252,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,5,0,0,232,9,0,0,176,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,81,29,0,88,74,29,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,152,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,212,9,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,72,243,30,0,40,229,30,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,0,0,0,0,0,0,0,0,0,0,68,1,0,0,164,9,0,0,0,0,0,0,0,0,0,0,232,100,29,0,168,94,29,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,184,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,213,9,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,216,17,31,0,128,3,31,0,0,0,0,0,16,0,0,0,3,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,0,0,0,0,0,0,0,0,0,0,68,1,0,0,164,9,0,0,0,0,0,0,0,0,0,0,80,50,31,0,112,30,31,0,0,0,0,0,15,0,0,0,3,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,0,0,0,0,0,0,0,0,0,0,68,1,0,0,164,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,23,0,6,0,9,0,5,0,5,0,5,0,6,0,5,0,71,0,9,0,32,0,7,0,16,0,7,0,2,0,5,0,124,0,9,0,58,0,7,0,29,0,7,0,2,0,6,0,236,0,9,0,119,0,8,0,0,0,8,0,3,0,5,0,183,0,9,0,44,0,7,0,19,0,7,0,1,0,6,0,104,1,10,0,70,0,8,0,63,0,8,0,30,0,6,0,18,7,13,0,181,0,9,0,66,0,8,0,34,0,7,0,197,1,11,0,30,1,10,0,135,0,9,0,6,0,4,0,3,0,9,0,30,0,7,0,28,0,6,0,18,0,7,0,136,3,12,0,68,0,9,0,112,0,9,0,31,0,6,0,62,2,11,0,57,0,8,0,142,0,9,0,1,0,7,0,198,1,11,0,182,0,9,0,69,0,9,0,20,0,6,0,63,2,11,0,125,0,9,0,24,0,9,0,7,0,7,0,199,1,11,0,134,0,9,0,25,0,9,0,21,0,6,0,219,1,10,0,2,0,9,0,70,0,9,0,13,0,8,0,19,7,13,0,218,1,10,0,105,1,10,0,32,61,34,0,128,99,35,0,0,0,0,0,164,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,93,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,10,0,0,0,0,0,0,0,0,0,0,232,0,0,0,174,2,0,0,0,0,0,0,0,0,0,0,168,75,34,0,216,101,35,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,168,75,34,0,144,86,33,0,104,41,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,232,72,31,0,160,150,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,144,4,30,0,56,150,29,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,64,55,29,0,16,231,28,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,168,75,34,0,24,225,35,0,176,146,35,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,160,51,35,0,8,236,34,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,120,172,34,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,112,34,0,136,56,34,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,125,29,0,120,253,33,0,0,0,0,0,232,156,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,32,8,0,0,8,7,0,0,184,1,0,0,58,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,200,125,29,0,224,253,33,0,0,0,0,0,8,157,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,190,0,0,0,138,0,0,0,158,1,0,0,70,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,248,69,34,0,160,101,35,0,3,0,0,0,50,76,80,77,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,5,0,0,0,0,0,0,0,0,0,0,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,126,29,0,56,254,33,0,24,157,32,0,88,157,31,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,9,0,0,118,0,0,0,30,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,127,29,0,112,254,33,0,0,1,0,0,0,0,0,0,0,0,0,0,136,213,9,0,0,0,0,0,1,0,0,0,20,0,0,0,204,2,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,73,31,0,0,106,35,0,0,0,0,0,2,0,0,0,43,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,176,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,6,0,0,0,0,0,0,0,0,0,0,170,0,0,0,176,4,0,0,38,0,0,0,0,0,0,0,24,230,30,0,8,59,30,0,8,2,0,0,0,0,0,0,0,0,0,0,72,214,9,0,0,0,0,0,0,0,0,0,104,160,0,0,0,0,0,0,0,10,0,0,120,0,0,0,168,2,0,0,0,0,0,0,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,142,29,0,24,5,34,0,24,161,32,0,216,160,31,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,16,215,9,0,0,0,0,0,128,0,0,0,92,5,0,0,56,3,0,0,106,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,164,32,0,208,162,31,0,8,2,0,0,0,0,0,0,0,0,0,0,64,215,9,0,0,0,0,0,0,0,0,0,104,160,0,0,76,8,0,0,0,10,0,0,170,0,0,0,168,2,0,0,0,0,0,0,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,170,29,0,24,18,34,0,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,3,0,0,98,8,0,0,164,2,0,0,12,0,0,0,0,0,0,0,0,0,0,0,176,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,80,1,0,0,80,1,0,1,80,1,0,0,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,24,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,57,0,0,110,6,0,0,36,0,0,0,12,0,0,0,136,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,8,0,8,8,8,8,10,12,14,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,34,36,38,40,42,44,46,102,0,0,0,67,0,0,0,72,242,17,0,232,243,17,0,80,244,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,126,0,124,0,120,0,112,0,96,0,64,0,0,2,0,2,0,6,0,3,0,15,0,4,0,13,0,5,0,12,0,5,0,21,0,6,0,19,0,6,0,18,0,6,0,23,0,7,0,31,0,8,0,30,0,8,0,29,0,8,0,37,0,9,0,36,0,9,0,35,0,9,0,33,0,9,0,33,0,10,0,32,0,10,0,15,0,10,0,14,0,10,0,7,0,11,0,6,0,11,0,32,0,11,0,33,0,11,0,80,0,12,0,81,0,12,0,82,0,12,0,14,0,4,0,20,0,6,0,22,0,7,0,28,0,8,0,32,0,9,0,31,0,9,0,13,0,10,0,34,0,11,0,83,0,12,0,85,0,12,0,11,0,5,0,21,0,7,0,30,0,9,0,12,0,10,0,86,0,12,0,17,0,6,0,27,0,8,0,29,0,9,0,11,0,10,0,16,0,6,0,34,0,9,0,10,0,10,0,13,0,6,0,28,0,9,0,8,0,10,0,18,0,7,0,27,0,9,0,84,0,12,0,20,0,7,0,26,0,9,0,87,0,12,0,25,0,8,0,9,0,10,0,24,0,8,0,35,0,11,0,23,0,8,0,25,0,9,0,24,0,9,0,7,0,10,0,88,0,12,0,7,0,4,0,12,0,6,0,22,0,8,0,23,0,9,0,6,0,10,0,5,0,11,0,4,0,11,0,89,0,12,0,15,0,6,0,22,0,9,0,5,0,10,0,14,0,6,0,4,0,10,0,17,0,7,0,36,0,11,0,16,0,7,0,37,0,11,0,19,0,7,0,90,0,12,0,21,0,8,0,91,0,12,0,20,0,8,0,19,0,8,0,26,0,8,0,21,0,9,0,20,0,9,0,19,0,9,0,18,0,9,0,17,0,9,0,38,0,11,0,39,0,11,0,92,0,12,0,93,0,12,0,94,0,12,0,95,0,12,0,3,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,9,9,10,11,12,13,14,0,0,0,0,0,0,0,0,1,1,1,2,2,3,3,4,4,5,5,6,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,1,2,3,4,5,6,7,8,9,10,1,2,3,4,5,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,1,1,1,1,1,2,3,4,5,6,7,8,1,2,3,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,112,42,32,0,120,73,31,0,0,0,0,0,13,0,0,0,32,32,0,0,0,0,0,0,32,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,215,9,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,1,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,255,255,255,255,3,0,0,0,2,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,19,0,20,0,21,0,22,0,23,0,24,0,26,0,27,0,20,0,21,0,22,0,23,0,25,0,26,0,27,0,28,0,21,0,22,0,23,0,24,0,26,0,27,0,28,0,30,0,22,0,23,0,24,0,26,0,27,0,28,0,30,0,31,0,23,0,24,0,25,0,27,0,28,0,30,0,31,0,33,0,8,0,17,0,18,0,19,0,21,0,23,0,25,0,27,0,17,0,18,0,19,0,21,0,23,0,25,0,27,0,28,0,20,0,21,0,22,0,23,0,24,0,26,0,28,0,30,0,21,0,22,0,23,0,24,0,26,0,28,0,30,0,32,0,22,0,23,0,24,0,26,0,28,0,30,0,32,0,35,0,23,0,24,0,26,0,28,0,30,0,32,0,35,0,38,0,25,0,26,0,28,0,30,0,32,0,35,0,38,0,41,0,27,0,28,0,30,0,32,0,35,0,38,0,41,0,45,0,144,37,30,0,112,29,30,0,0,0,0,0,13,0,0,0,43,16,0,0,0,0,0,0,192,121,18,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,80,217,9,0,48,216,9,0,192,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,3,0,0,0,0,0,0,0,0,0,0,68,1,0,0,164,9,0,0,164,0,0,0,0,0,0,0,99,13,15,17,19,21,23,0,0,8,8,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,20,21,22,23,24,25,3,3,3,2,2,2,2,3,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,0,0,0,0,0,0,3,2,2,2,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,0,0,0,0,0,0,88,196,29,0,104,95,29,0,64,167,32,0,88,196,29,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,6,2,0,0,0,0,0,88,0,0,0,150,9,0,0,234,0,0,0,86,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,177,30,0,40,140,30,0,0,0,0,0,16,116,30,0,0,0,0,0,2,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,151,30,0,168,5,30,0,0,0,0,0,2,0,0,0,32,32,0,0,64,249,17,0,32,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,224,9,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,152,88,33,0,8,43,32,0,0,0,0,0,2,0,0,0,43,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,72,219,9,0,176,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,6,0,0,0,0,0,0,0,0,0,0,170,0,0,0,176,4,0,0,38,0,0,0,0,0,0,0,232,8,29,0,32,187,28,0,64,167,32,0,88,196,29,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,140,6,0,0,0,0,0,88,0,0,0,150,9,0,0,234,0,0,0,86,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,184,35,0,240,93,35,0,64,167,32,0,144,184,35,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,135,20,0,0,0,0,0,88,0,0,0,150,9,0,0,234,0,0,0,86,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,1,0,0,0,8,0,0,0,1,0,0,0,9,0,0,0,1,0,0,0,10,0,0,0,1,0,0,0,12,0,0,0,1,0,0,0,15,0,0,0,1,0,0,0,16,0,0,0,1,0,0,0,18,0,0,0,1,0,0,0,20,0,0,0,1,0,0,0,24,0,0,0,1,0,0,0,25,0,0,0,1,0,0,0,30,0,0,0,1,0,0,0,32,0,0,0,1,0,0,0,36,0,0,0,1,0,0,0,40,0,0,0,1,0,0,0,45,0,0,0,1,0,0,0,48,0,0,0,1,0,0,0,50,0,0,0,1,0,0,0,60,0,0,0,1,0,0,0,72,0,0,0,1,0,0,0,75,0,0,0,1,0,0,0,80,0,0,0,1,0,0,0,90,0,0,0,1,0,0,0,96,0,0,0,1,0,0,0,100,0,0,0,1,0,0,0,120,0,0,0,1,0,0,0,150,0,0,0,1,0,0,0,180,0,0,0,1,0,0,0,200,0,0,0,1,0,0,0,240,0,0,0,1,0,0,0,238,2,0,0,233,3,0,0,32,3,0,0,233,3,0,0,192,3,0,0,233,3,0,0,232,3,0,0,233,3,0,0,176,4,0,0,233,3,0,0,226,4,0,0,233,3,0,0,220,5,0,0,233,3,0,0,64,6,0,0,233,3,0,0,83,7,0,0,233,3,0,0,208,7,0,0,233,3,0,0,96,9,0,0,233,3,0,0,196,9,0,0,233,3,0,0,184,11,0,0,233,3,0,0,166,14,0,0,233,3,0,0,160,15,0,0,233,3,0,0,192,18,0,0,233,3,0,0,136,19,0,0,233,3,0,0,112,23,0,0,233,3,0,0,76,29,0,0,233,3,0,0,64,31,0,0,233,3,0,0,16,39,0,0,233,3,0,0,224,46,0,0,233,3,0,0,152,58,0,0,233,3,0,0,32,78,0,0,233,3,0,0,192,93,0,0,233,3,0,0,48,117,0,0,233,3,0,0,96,234,0,0,233,3,0,0,0,0,0,0,0,0,0,0,40,0,18,0,152,223,9,0,24,223,9,0,152,222,9,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,16,0,0,0,9,0,0,0,221,0,0,0,100,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,200,233,30,0,192,219,30,0,16,207,30,0,80,190,30,0,0,0,0,0,1,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,42,32,0,152,73,31,0,0,0,0,0,1,0,0,0,32,32,0,0,56,2,18,0,40,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,229,9,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,72,118,34,0,0,106,35,0,0,0,0,0,1,0,0,0,43,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,176,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,6,0,0,0,0,0,0,0,0,0,0,170,0,0,0,176,4,0,0,38,0,0,0,0,0,0,0,240,231,30,0,240,60,30,0,64,167,32,0,0,0,0,0,0,80,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,47,2,0,0,0,0,0,88,0,0,0,150,9,0,0,234,0,0,0,86,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,168,29,0,72,17,34,0,64,167,32,0,16,165,31,0,0,80,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,215,9,0,0,0,0,0,88,0,0,0,150,9,0,0,234,0,0,0,86,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,8,0,16,0,19,0,22,0,26,0,27,0,29,0,34,0,16,0,16,0,22,0,24,0,27,0,29,0,34,0,37,0,19,0,22,0,26,0,27,0,29,0,34,0,34,0,38,0,22,0,22,0,26,0,27,0,29,0,34,0,37,0,40,0,22,0,26,0,27,0,29,0,32,0,35,0,40,0,48,0,26,0,27,0,29,0,32,0,35,0,40,0,48,0,58,0,26,0,27,0,29,0,34,0,38,0,46,0,56,0,69,0,27,0,29,0,35,0,38,0,46,0,56,0,69,0,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,0,0,0,0,0,0,128,63,127,106,44,63,93,254,51,63,170,241,66,63,63,53,78,63,185,252,87,63,106,188,100,63,81,107,106,63,150,67,123,63,150,67,131,63,96,229,136,63,246,40,140,63,246,40,148,63,193,202,153,63,0,0,0,0,4,0,0,0,1,0,5,0,6,0,14,0,30,0,62,0,126,0,254,0,254,1,255,1,3,2,2,3,3,4,5,6,7,8,9,9,0,0,0,0,0,0,1,0,2,0,6,0,14,0,30,0,62,0,126,0,254,0,254,1,254,3,255,3,2,2,2,3,4,5,6,7,8,9,10,10,0,0,0,0,1,9,11,5,9,5,13,6,13,4,23,7,19,7,31,8,12,4,22,7,18,7,30,8,19,5,27,8,23,8,19,8,11,4,21,7,17,7,29,8,17,5,25,8,21,8,17,8,15,6,15,8,13,8,3,9,15,5,11,8,7,8,7,9,10,4,20,7,16,7,28,8,14,6,14,8,12,8,2,9,16,5,24,8,20,8,16,8,14,5,10,8,6,8,6,9,18,5,26,8,22,8,18,8,13,5,9,8,5,8,5,9,12,5,8,8,4,8,4,9,7,3,10,5,8,5,12,6,1,1,1,2,1,3,1,4,3,6,5,7,4,7,3,7,11,9,10,9,9,9,17,10,16,10,15,10,14,10,13,10,12,10,0,0,0,0,0,0,1,1,3,3,2,3,3,4,2,4,3,5,2,5,7,7,6,7,11,8,10,8,9,8,8,8,7,8,6,8,23,10,22,10,21,10,20,10,19,10,18,10,35,11,34,11,33,11,32,11,31,11,30,11,29,11,28,11,27,11,26,11,25,11,24,11,8,11,15,11,0,8], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1169964);
/* memory initializer */ allocate([192,93,0,0,233,3,0,0,24,0,0,0,1,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,30,0,0,0,1,0,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,60,0,0,0,1,0,0,0,15,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,10,0,0,0,1,0,0,0,12,0,0,0,1,0,0,0,15,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,171,29,0,144,18,34,0,0,0,0,0,16,171,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,136,0,0,0,28,7,0,0,122,1,0,0,58,4,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,170,29,0,104,18,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,160,9,0,0,72,10,0,0,164,1,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,122,34,0,96,106,35,0,1,0,0,0,35,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,1,0,0,0,0,0,0,0,0,0,0,66,2,0,0,0,0,0,0,194,0,0,0,0,0,0,0,72,123,34,0,112,106,35,0,1,0,0,0,28,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,5,0,0,0,0,0,0,0,0,0,0,244,0,0,0,190,5,0,0,58,1,0,0,0,0,0,0,27,0,0,0,30,0,0,0,8,0,0,0,12,0,0,0,30,0,0,0,0,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,15,0,0,0,31,0,0,0,63,0,0,0,127,0,0,0,255,0,0,0,255,1,0,0,255,3,0,0,255,7,0,0,255,15,0,0,255,31,0,0,255,63,0,0,255,127,0,0,255,255,0,0,0,0,0,0,251,255,255,255,249,255,255,255,3,0,0,0,246,255,255,255,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,253,255,255,255,253,255,255,255,252,255,255,255,252,255,255,255,251,255,255,255,251,255,255,255,250,255,255,255,249,255,255,255,249,255,255,255,248,255,255,255,247,255,255,255,246,255,255,255,245,255,255,255,243,255,255,255,242,255,255,255,240,255,255,255,239,255,255,255,237,255,255,255,235,255,255,255,232,255,255,255,230,255,255,255,227,255,255,255,225,255,255,255,221,255,255,255,218,255,255,255,215,255,255,255,211,255,255,255,207,255,255,255,203,255,255,255,198,255,255,255,193,255,255,255,188,255,255,255,183,255,255,255,177,255,255,255,171,255,255,255,165,255,255,255,159,255,255,255,152,255,255,255,145,255,255,255,139,255,255,255,131,255,255,255,124,255,255,255,117,255,255,255,109,255,255,255,102,255,255,255,95,255,255,255,87,255,255,255,80,255,255,255,73,255,255,255,66,255,255,255,60,255,255,255,54,255,255,255,48,255,255,255,213,0,0,0,218,0,0,0,222,0,0,0,225,0,0,0,227,0,0,0,228,0,0,0,228,0,0,0,227,0,0,0,224,0,0,0,221,0,0,0,215,0,0,0,208,0,0,0,200,0,0,0,189,0,0,0,177,0,0,0,163,0,0,0,146,0,0,0,127,0,0,0,106,0,0,0,83,0,0,0,57,0,0,0,29,0,0,0,254,255,255,255,220,255,255,255,184,255,255,255,145,255,255,255,103,255,255,255,59,255,255,255,12,255,255,255,218,254,255,255,165,254,255,255,111,254,255,255,53,254,255,255,249,253,255,255,187,253,255,255,123,253,255,255,57,253,255,255,245,252,255,255,176,252,255,255,105,252,255,255,33,252,255,255,216,251,255,255,143,251,255,255,70,251,255,255,253,250,255,255,180,250,255,255,108,250,255,255,38,250,255,255,225,249,255,255,158,249,255,255,94,249,255,255,33,249,255,255,231,248,255,255,178,248,255,255,129,248,255,255,86,248,255,255,47,248,255,255,16,248,255,255,247,247,255,255,229,247,255,255,219,247,255,255,217,247,255,255,224,247,255,255,241,247,255,255,245,7,0,0,208,7,0,0,160,7,0,0,101,7,0,0,30,7,0,0,203,6,0,0,108,6,0,0,255,5,0,0,134,5,0,0,0,5,0,0,107,4,0,0,202,3,0,0,26,3,0,0,93,2,0,0,146,1,0,0,185,0,0,0,211,255,255,255,224,254,255,255,223,253,255,255,210,252,255,255,185,251,255,255,148,250,255,255,100,249,255,255,42,248,255,255,230,246,255,255,153,245,255,255,68,244,255,255,233,242,255,255,135,241,255,255,33,240,255,255,183,238,255,255,76,237,255,255,223,235,255,255,115,234,255,255,9,233,255,255,163,231,255,255,67,230,255,255,233,228,255,255,153,227,255,255,83,226,255,255,26,225,255,255,239,223,255,255,213,222,255,255,205,221,255,255,218,220,255,255,253,219,255,255,56,219,255,255,143,218,255,255,1,218,255,255,146,217,255,255,68,217,255,255,25,217,255,255,18,217,255,255,49,217,255,255,121,217,255,255,234,217,255,255,136,218,255,255,83,219,255,255,77,220,255,255,120,221,255,255,212,222,255,255,100,224,255,255,40,226,255,255,34,228,255,255,174,25,0,0,71,23,0,0,168,20,0,0,209,17,0,0,192,14,0,0,119,11,0,0,245,7,0,0,58,4,0,0,70,0,0,0,26,252,255,255,182,247,255,255,28,243,255,255,75,238,255,255,70,233,255,255,14,228,255,255,164,222,255,255,9,217,255,255,65,211,255,255,76,205,255,255,44,199,255,255,229,192,255,255,121,186,255,255,234,179,255,255,59,173,255,255,111,166,255,255,138,159,255,255,142,152,255,255,127,145,255,255,96,138,255,255,53,131,255,255,1,124,255,255,200,116,255,255,143,109,255,255,88,102,255,255,40,95,255,255,2,88,255,255,235,80,255,255,231,73,255,255,250,66,255,255,39,60,255,255,115,53,255,255,226,46,255,255,118,40,255,255,54,34,255,255,35,28,255,255,66,22,255,255,151,16,255,255,36,11,255,255,237,5,255,255,246,0,255,255,66,252,254,255,211,247,254,255,172,243,254,255,209,239,254,255,66,236,254,255,4,233,254,255,23,230,254,255,125,227,254,255,57,225,254,255,76,223,254,255,183,221,254,255,122,220,254,255,152,219,254,255,16,219,254,255,30,37,1,0,0,0,0,0,248,111,27,0,248,111,27,0,136,111,27,0,136,111,27,0,192,110,27,0,0,0,0,0,5,112,1,0,8,0,0,0,13,0,0,0,32,0,0,0,28,0,0,0,33,0,0,0,53,54,50,72,35,0,0,0,2,80,1,0,64,0,0,0,46,80,1,0,64,0,0,0,2,0,0,0,97,0,0,0,2,0,0,0,96,0,0,0,2,0,0,0,98,0,0,0,2,0,0,0,99,0,0,0,2,0,0,0,100,0,0,0,2,0,0,0,101,0,0,0,2,80,1,0,102,0,0,0,2,80,1,0,103,0,0,0,2,80,1,0,104,0,0,0,1,80,1,0,105,0,0,0,0,80,1,0,105,0,0,0,1,0,0,0,106,0,0,0,1,80,1,0,107,0,0,0,8,0,0,0,108,0,0,0,62,0,0,0,109,0,0,0,89,0,0,0,110,0,0,0,71,0,0,0,163,0,0,0,117,0,0,0,164,0,0,0,3,80,1,0,165,0,0,0,4,80,1,0,169,0,0,0,5,80,1,0,221,0,0,0,0,112,1,0,224,0,0,0,24,80,1,0,225,0,0,0,1,0,2,0,1,0,0,0,1,0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,192,185,35,0,176,96,35,0,88,10,35,0,192,185,35,0,2,80,1,0,13,0,0,0,0,0,0,0,64,0,5,0,96,255,35,0,200,60,10,0,0,0,0,0,128,0,0,0,214,4,0,0,184,2,0,0,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,147,35,0,208,51,35,0,1,0,0,0,14,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,6,0,0,0,0,0,0,0,0,0,0,124,2,0,0,170,0,0,0,42,1,0,0,0,0,0,0,104,147,35,0,224,51,35,0,1,0,0,0,14,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,2,2,0,0,24,0,0,0,218,0,0,0,0,0,0,0,32,151,30,0,0,5,30,0,1,0,0,0,1,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,1,0,0,0,0,0,0,0,0,0,0,34,1,0,0,0,0,0,0,136,0,0,0,0,0,0,0,240,55,29,0,176,231,28,0,1,0,0,0,13,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,1,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,136,0,0,0,0,0,0,0,0,56,29,0,232,231,28,0,1,0,0,0,13,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,10,0,0,0,0,0,0,0,0,0,0,230,2,0,0,0,0,0,0,18,1,0,0,0,0,0,0,240,232,30,0,8,62,30,0,24,168,32,0,240,232,30,0,1,80,1,0,62,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,72,61,10,0,0,0,0,0,232,12,0,0,94,0,0,0,192,2,0,0,228,1,0,0,0,0,0,0,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,176,29,0,232,20,34,0,0,1,0,0,56,168,32,0,0,0,0,0,128,20,21,0,0,0,0,0,0,0,0,0,48,0,0,0,242,1,0,0,20,1,0,0,246,2,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,151,30,0,32,5,30,0,1,0,0,0,1,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,10,0,0,0,0,0,0,0,0,0,0,28,2,0,0,0,0,0,0,18,1,0,0,0,0,0,0,72,87,33,0,24,42,32,0,1,0,0,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,247,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,1,0,0,0,0,0,0,0,0,0,0,34,1,0,0,0,0,0,0,136,0,0,0,0,0,0,0,64,81,34,0,208,102,35,0,1,0,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,253,35,0,112,249,35,0,112,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,172,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,61,10,0,0,0,0,0,64,2,0,0,0,0,0,0,88,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,174,29,0,64,20,34,0,24,168,32,0,104,166,31,0,0,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,80,34,0,176,102,35,0,1,0,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,192,253,35,0,104,249,35,0,88,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,236,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,61,10,0,0,0,0,0,52,7,0,0,0,0,0,0,218,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,87,33,0,80,42,32,0,1,0,0,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,247,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,10,0,0,0,0,0,0,0,0,0,0,28,2,0,0,0,0,0,0,18,1,0,0,0,0,0,0,32,88,34,0,192,103,35,0,1,0,0,0,43,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,1,0,0,0,0,0,0,0,0,0,0,34,1,0,0,0,0,0,0,136,0,0,0,0,0,0,0,192,89,34,0,56,104,35,0,1,0,0,0,43,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,10,0,0,0,0,0,0,0,0,0,0,28,2,0,0,0,0,0,0,18,1,0,0,0,0,0,0,120,123,34,0,128,106,35,0,3,0,0,0,5,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,210,3,0,0,188,0,0,0,0,0,0,0,0,0,0,0,170,10,0,0,0,0,0,0,0,0,0,0,160,123,34,0,160,106,35,0,3,0,0,0,5,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,6,0,0,0,0,0,0,0,0,0,0,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,14,0,16,0,18,0,20,0,21,0,27,0,32,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,63,30,0,96,199,29,0,0,0,0,0,192,63,30,0,2,80,1,0,13,0,0,0,0,0,0,0,64,0,5,0,64,245,35,0,80,65,10,0,0,0,0,0,128,0,0,0,214,4,0,0,184,2,0,0,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,173,32,0,32,171,31,0,0,128,0,0,0,0,0,0,0,0,0,0,64,70,10,0,0,0,0,0,0,0,0,0,128,0,0,0,202,2,0,0,30,6,0,0,172,2,0,0,178,6,0,0,180,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,123,34,0,192,106,35,0,0,0,0,0,120,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,50,3,0,0,0,0,0,0,0,0,0,0,0,3,1,2,3,4,5,6,7,8,9,9,10,11,12,13,14,15,16,17,18,18,19,20,21,22,23,24,25,26,27,28,0,2,3,4,5,6,7,8,9,10,11,13,14,15,16,17,18,19,20,21,22,24,25,26,27,28,29,30,31,31,31,26,40,124,34,0,216,106,35,0,0,0,0,0,81,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,8,0,0,0,0,0,0,0,0,0,0,154,2,0,0,236,10,0,0,0,0,0,0,0,0,0,0,56,209,29,0,240,33,34,0,104,173,32,0,56,209,29,0,14,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,34,4,0,0,74,1,0,0,112,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,209,29,0,240,33,34,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,68,5,0,0,140,3,0,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,209,29,0,48,34,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,242,9,0,0,144,5,0,0,12,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,80,1,0,45,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,0,0,250,0,0,0,12,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,9,31,0,184,248,30,0,0,0,0,0,24,9,31,0,29,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,51,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,11,1,0,0,0,0,0,0,59,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,55,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,15,1,0,0,0,0,0,0,63,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,55,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,15,1,0,0,0,0,0,0,63,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,55,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,9,1,8,1,7,1,6,1,5,1,4,1,3,4,3,5,3,6,3,7,3,3,3,5,4,9,5,17,6,33,7,65,8,129,9,1,9,1,8,1,7,1,6,1,5,1,4,1,3,2,2,3,2,3,3,5,4,9,5,17,6,33,7,65,8,129,9,0,0,0,0,1,9,1,8,1,7,1,6,1,5,1,4,1,3,1,1,3,3,5,4,9,5,17,6,33,7,65,8,129,9,0,0,0,0,0,0,0,0,0,0,200,177,35,0,232,82,35,0,0,1,0,0,200,177,35,0,0,0,0,0,0,0,0,0,0,0,0,0,29,80,1,0,0,0,0,0,0,0,0,0,138,1,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,126,34,0,32,107,35,0,1,0,0,0,29,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,8,0,0,0,0,0,0,0,0,0,0,60,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,210,29,0,96,34,34,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,9,0,0,150,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,101,120,116,47,112,108,97,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,112,1,0,105,109,97,103,101,47,103,105,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,0,0,0,105,109,97,103,101,47,106,112,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,105,109,97,103,101,47,112,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,0,0,105,109,97,103,101,47,116,105,102,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,116,114,117,101,116,121,112,101,45,102,111,110,116,0,0,0,0,0,0,128,1,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,102,111,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,97,112,112,108,105,99,97,116,105,111,110,47,118,110,100,46,109,115,45,111,112,101,110,116,121,112,101,0,0,0,0,0,70,84,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,191,35,0,128,165,35,0,168,124,33,0,184,74,32,0,0,0,0,0,0,0,0,0,65,95,65,65,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,80,1,0,65,95,65,67,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,80,1,0,65,95,65,76,65,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,80,1,0,65,95,68,84,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,80,1,0,65,95,69,65,67,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41,80,1,0,65,95,70,76,65,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,80,1,0,65,95,77,76,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,80,1,0,65,95,77,80,69,71,47,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,1,0,65,95,77,80,69,71,47,76,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,1,0,65,95,77,80,69,71,47,76,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,80,1,0,65,95,79,80,85,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,85,80,79,65,95,79,80,85,83,47,69,88,80,69,82,73,77,69,78,84,65,76,0,0,0,0,0,83,85,80,79,65,95,80,67,77,47,70,76,79,65,84,47,73,69,69,69,0,0,0,0,0,0,0,0,21,0,1,0,65,95,80,67,77,47,70,76,79,65,84,47,73,69,69,69,0,0,0,0,0,0,0,0,23,0,1,0,65,95,80,67,77,47,73,78,84,47,66,73,71,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,65,95,80,67,77,47,73,78,84,47,66,73,71,0,0,0,0,0,0,0,0,0,0,0,13,0,1,0,65,95,80,67,77,47,73,78,84,47,66,73,71,0,0,0,0,0,0,0,0,0,0,0,9,0,1,0,65,95,80,67,77,47,73,78,84,47,76,73,84,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,95,80,67,77,47,73,78,84,47,76,73,84,0,0,0,0,0,0,0,0,0,0,0,12,0,1,0,65,95,80,67,77,47,73,78,84,47,76,73,84,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,65,95,80,67,77,47,73,78,84,47,76,73,84,0,0,0,0,0,0,0,0,0,0,0,5,0,1,0,65,95,81,85,73,67,75,84,73,77,69,47,81,68,77,50,0,0,0,0,0,0,0,0,19,80,1,0,65,95,82,69,65,76,47,49,52,95,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,1,0,65,95,82,69,65,76,47,50,56,95,56,0,0,0,0,0,0,0,0,0,0,0,0,0,1,48,1,0,65,95,82,69,65,76,47,65,84,82,67,0,0,0,0,0,0,0,0,0,0,0,0,0,31,80,1,0,65,95,82,69,65,76,47,67,79,79,75,0,0,0,0,0,0,0,0,0,0,0,0,0,20,80,1,0,65,95,82,69,65,76,47,83,73,80,82,0,0,0,0,0,0,0,0,0,0,0,0,0,42,80,1,0,65,95,84,82,85,69,72,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,80,1,0,65,95,84,84,65,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,80,1,0,65,95,86,79,82,66,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,80,1,0,65,95,87,65,86,80,65,67,75,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,80,1,0,68,95,87,69,66,86,84,84,47,83,85,66,84,73,84,76,69,83,0,0,0,0,0,0,84,84,86,87,68,95,87,69,66,86,84,84,47,67,65,80,84,73,79,78,83,0,0,0,0,0,0,0,84,84,86,87,68,95,87,69,66,86,84,84,47,68,69,83,67,82,73,80,84,73,79,78,83,0,0,0,84,84,86,87,68,95,87,69,66,86,84,84,47,77,69,84,65,68,65,84,65,0,0,0,0,0,0,0,84,84,86,87,83,95,84,69,88,84,47,85,84,70,56,0,0,0,0,0,0,0,0,0,0,0,0,0,112,105,82,83,83,95,84,69,88,84,47,85,84,70,56,0,0,0,0,0,0,0,0,0,0,0,0,0,2,112,1,0,83,95,84,69,88,84,47,85,84,70,56,0,0,0,0,0,0,0,0,0,0,0,0,0,8,112,1,0,83,95,84,69,88,84,47,65,83,67,73,73,0,0,0,0,0,0,0,0,0,0,0,0,2,112,1,0,83,95,84,69,88,84,47,65,83,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,112,1,0,83,95,84,69,88,84,47,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,112,1,0,83,95,65,83,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,112,1,0,83,95,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,112,1,0,83,95,84,69,88,84,47,65,83,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,83,83,65,83,95,84,69,88,84,47,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,83,83,65,83,95,65,83,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,83,83,65,83,95,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,83,83,65,83,95,86,79,66,83,85,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,83,95,68,86,66,83,85,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,112,1,0,83,95,72,68,77,86,47,80,71,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,112,1,0,86,95,68,73,82,65,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,0,0,0,86,95,77,74,80,69,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,86,95,77,80,69,71,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,86,95,77,80,69,71,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,86,95,77,80,69,71,52,47,73,83,79,47,65,83,80,0,0,0,0,0,0,0,0,0,13,0,0,0,86,95,77,80,69,71,52,47,73,83,79,47,65,80,0,0,0,0,0,0,0,0,0,0,13,0,0,0,86,95,77,80,69,71,52,47,73,83,79,47,83,80,0,0,0,0,0,0,0,0,0,0,13,0,0,0,86,95,77,80,69,71,52,47,73,83,79,47,65,86,67,0,0,0,0,0,0,0,0,0,28,0,0,0,86,95,77,80,69,71,72,47,73,83,79,47,72,69,86,67,0,0,0,0,0,0,0,0,53,54,50,72,86,95,77,80,69,71,52,47,77,83,47,86,51,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,86,95,80,82,79,82,69,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,86,95,82,69,65,76,47,82,86,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,86,95,82,69,65,76,47,82,86,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,86,95,82,69,65,76,47,82,86,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,69,0,0,0,86,95,82,69,65,76,47,82,86,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,70,0,0,0,86,95,83,78,79,87,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,79,78,83,86,95,84,72,69,79,82,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,86,95,85,78,67,79,77,80,82,69,83,83,69,68,0,0,0,0,0,0,0,0,0,0,14,0,0,0,86,95,86,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,141,0,0,0,86,95,86,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,134,34,0,112,108,35,0,0,0,0,0,9,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,3,0,0,0,0,0,0,0,0,0,0,64,1,0,0,70,5,0,0,0,0,0,0,0,0,0,0,80,103,31,0,88,62,31,0,232,35,31,0,168,22,31,0,0,0,0,0,8,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,153,30,0,56,6,30,0,0,0,0,0,8,0,0,0,0,48,0,64,0,0,0,0,64,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,104,87,29,0,72,3,29,0,0,1,0,0,224,180,28,0,0,0,0,0,24,90,10,0,0,0,0,0,8,0,0,0,20,0,0,0,0,0,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,19,30,0,96,241,29,0,0,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,232,89,10,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,3,0,0,0,0,0,0,0,0,0,0,210,1,0,0,70,5,0,0,14,1,0,0,0,0,0,0,160,136,34,0,152,108,35,0,0,0,0,0,114,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,1,0,0,0,0,0,0,0,0,0,0,250,2,0,0,184,1,0,0,0,0,0,0,0,0,0,0,32,211,29,0,224,34,34,0,48,174,32,0,112,171,31,0,0,0,0,0,0,0,0,0,68,86,68,109,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,0,0,0,208,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,213,29,0,128,35,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,78,2,0,0,224,8,0,0,144,2,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,168,137,34,0,160,108,35,0,3,0,0,0,68,86,68,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,4,0,0,0,0,0,0,0,0,0,0,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,214,29,0,216,35,34,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,6,0,0,100,9,0,0,78,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,88,122,26,0,10,0,0,0,144,181,19,0,1,6,0,0,16,4,23,0,144,252,22,0,15,0,0,0,4,0,0,0,208,123,26,0,20,0,0,0,144,186,19,0,2,6,0,0,144,18,23,0,144,11,23,0,14,0,0,0,1,0,0,0,128,126,26,0,40,0,0,0,144,191,19,0,4,6,0,0,144,32,23,0,144,25,23,0,14,0,0,0,0,8,20,0,16,165,10,0,1,6,4,4,72,224,6,0,9,84,54,7,200,0,0,0,16,0,0,0,88,122,26,0,10,0,0,0,144,181,19,0,1,6,0,0,16,4,23,0,144,252,22,0,15,0,0,0,4,0,0,0,208,123,26,0,20,0,0,0,144,186,19,0,2,6,0,0,144,18,23,0,144,11,23,0,14,0,0,0,1,0,0,0,128,126,26,0,40,0,0,0,144,191,19,0,4,6,0,0,144,32,23,0,144,25,23,0,14,0,0,0,0,8,20,0,16,165,10,0,1,6,4,4,72,224,6,0,9,84,54,7,200,0,0,0,16,0,0,0,88,122,26,0,10,0,0,0,144,181,19,0,1,6,0,0,144,48,23,0,144,39,23,0,18,0,0,0,4,0,0,0,208,123,26,0,20,0,0,0,144,186,19,0,2,6,0,0,16,66,23,0,144,57,23,0,17,0,0,0,1,0,0,0,128,126,26,0,40,0,0,0,144,191,19,0,4,6,0,0,16,83,23,0,144,74,23,0,17,0,0,0,0,8,20,0,16,165,10,0,1,6,4,4,72,224,6,0,9,84,54,7,200,0,0,0,16,0,0,0,88,122,26,0,10,0,0,0,144,181,19,0,1,6,0,0,144,48,23,0,144,39,23,0,18,0,0,0,4,0,0,0,208,123,26,0,20,0,0,0,144,186,19,0,2,6,0,0,16,66,23,0,144,57,23,0,17,0,0,0,1,0,0,0,128,126,26,0,40,0,0,0,144,191,19,0,4,6,0,0,16,83,23,0,144,74,23,0,17,0,0,0,0,8,20,0,16,165,10,0,1,6,4,4,72,224,6,0,9,84,54,7,200,0,0,0,16,0,0,0,88,122,26,0,10,0,0,0,144,181,19,0,1,6,0,0,16,103,23,0,144,91,23,0,23,0,0,0,4,0,0,0,208,123,26,0,20,0,0,0,144,186,19,0,2,6,0,0,16,125,23,0,144,114,23,0,21,0,0,0,1,0,0,0,128,126,26,0,40,0,0,0,144,191,19,0,4,6,0,0,144,146,23,0,144,135,23,0,22,0,0,0,0,8,20,0,16,165,10,0,1,6,4,4,72,224,6,0,9,84,54,7,200,0,0,0,16,0,0,0,88,122,26,0,10,0,0,0,144,181,19,0,1,6,0,0,16,103,23,0,144,91,23,0,23,0,0,0,4,0,0,0,208,123,26,0,20,0,0,0,144,186,19,0,2,6,0,0,16,125,23,0,144,114,23,0,21,0,0,0,1,0,0,0,128,126,26,0,40,0,0,0,144,191,19,0,4,6,0,0,144,146,23,0,144,135,23,0,22,0,0,0,0,8,20,0,16,165,10,0,1,6,4,4,72,224,6,0,9,84,54,7,200,0,0,0,8,0,0,0,112,122,26,0,10,0,0,0,144,196,19,0,1,6,0,0,16,165,23,0,144,157,23,0,15,0,0,0,2,0,0,0,248,123,26,0,20,0,0,0,144,201,19,0,2,6,0,0,144,179,23,0,144,172,23,0,14,0,0,0,1,0,0,0,208,126,26,0,32,0,0,0,144,206,19,0,4,6,0,0,16,194,23,0,144,186,23,0,15,0,0,0,0,4,16,0,176,190,10,0,1,6,4,3,72,233,6,0,9,56,36,7,200,0,0,0,8,0,0,0,160,122,26,0,10,0,0,0,144,210,19,0,1,6,0,0,16,209,23,0,144,201,23,0,15,0,0,0,2,0,0,0,72,124,26,0,20,0,0,0,144,215,19,0,2,6,0,0,144,223,23,0,144,216,23,0,14,0,0,0,1,0,0,0,144,127,26,0,32,0,0,0,144,220,19,0,4,6,0,0,16,238,23,0,144,230,23,0,15,0,0,0,0,4,16,0,48,211,10,0,1,6,4,3,72,242,6,0,9,56,36,7,200,0,0,0,8,0,0,0,184,122,26,0,10,0,0,0,144,224,19,0,1,5,0,0,144,253,23,0,144,245,23,0,16,0,0,0,2,0,0,0,152,124,26,0,20,0,0,0,16,227,19,0,2,5,0,0,16,13,24,0,144,5,24,0,15,0,0,0,1,0,0,0,208,127,26,0,30,0,0,0,144,229,19,0,3,6,0,0,144,28,24,0,144,20,24,0,16,0,0,0,0,4,16,0,176,231,10,0,1,6,4,3,72,251,6,0,9,56,60,7,200,0,0,0,8,0,0,0,232,122,26,0,10,0,0,0,144,234,19,0,1,5,0,0,144,44,24,0,144,36,24,0,16,0,0,0,2,0,0,0,232,124,26,0,24,0,0,0,16,237,19,0,2,5,0,0,16,60,24,0,144,52,24,0,15,0,0,0,1,0,0,0,80,128,26,0,30,0,0,0,16,240,19,0,3,6,0,0,144,75,24,0,144,67,24,0,16,0,0,0,0,4,16,0,176,231,10,0,1,6,4,3,72,10,7,0,9,28,30,7,200,0,0,0,8,0,0,0,0,123,26,0,10,0,0,0,16,245,19,0,1,5,0,0,16,94,24,0,144,83,24,0,21,0,0,0,2,0,0,0,24,125,26,0,20,0,0,0,144,247,19,0,2,5,0,0,144,113,24,0,144,104,24,0,18,0,0,0,1,0,0,0,144,128,26,0,30,0,0,0,16,250,19,0,3,6,0,0,144,132,24,0,144,122,24,0,20,0,0,0,0,2,16,0,176,253,10,0,1,6,4,3,72,25,7,0,9,36,30,7,200,0,0,0,8,0,0,0,48,123,26,0,8,0,0,0,16,255,19,0,1,5,0,0,16,153,24,0,144,142,24,0,21,0,0,0,2,0,0,0,104,125,26,0,16,0,0,0,16,1,20,0,2,5,0,0,144,172,24,0,144,163,24,0,18,0,0,0,1,0,0,0,16,129,26,0,24,0,0,0,16,3,20,0,3,6,0,0,16,191,24,0,144,181,24,0,19,0,0,0,0,2,16,0,48,18,11,0,1,6,4,3,72,35,7,0,9,28,20,7,200,0,0,0,8,0,0,0,16,122,26,0,10,0,0,0,144,161,19,0,1,5,0,0,144,209,24,0,144,200,24,0,18,0,0,0,2,0,0,0,88,123,26,0,20,0,0,0,16,164,19,0,2,5,0,0,144,226,24,0,144,218,24,0,16,0,0,0,1,0,0,0,176,125,26,0,30,0,0,0,144,166,19,0,3,6,0,0,16,243,24,0,144,234,24,0,17,0,0,0,0,2,12,0,80,149,10,0,1,5,3,3,72,204,6,0,8,28,20,6,200,0,0,0,8,0,0,0,40,122,26,0,10,0,0,0,144,171,19,0,1,5,0,0,144,4,25,0,144,251,24,0,18,0,0,0,2,0,0,0,128,123,26,0,20,0,0,0,16,174,19,0,2,5,0,0,144,21,25,0,144,13,25,0,16,0,0,0,1,0,0,0,240,125,26,0,30,0,0,0,144,176,19,0,3,6,0,0,16,38,25,0,144,29,25,0,17,0,0,0,0,2,12,0,48,157,10,0,1,5,3,3,72,214,6,0,8,28,20,6,200,0,0,0,8,0,0,0,16,122,26,0,10,0,0,0,144,161,19], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1180208);
/* memory initializer */ allocate([1,5,0,0,16,60,25,0,144,46,25,0,27,0,0,0,2,0,0,0,88,123,26,0,20,0,0,0,16,164,19,0,2,5,0,0,144,84,25,0,144,73,25,0,22,0,0,0,1,0,0,0,176,125,26,0,30,0,0,0,144,166,19,0,3,6,0,0,144,107,25,0,144,95,25,0,24,0,0,0,0,2,12,0,80,149,10,0,1,5,3,3,72,204,6,0,8,28,20,6,200,0,0,0,8,0,0,0,40,122,26,0,10,0,0,0,144,171,19,0,1,5,0,0,16,60,25,0,144,46,25,0,27,0,0,0,2,0,0,0,128,123,26,0,20,0,0,0,16,174,19,0,2,5,0,0,144,84,25,0,144,73,25,0,22,0,0,0,1,0,0,0,240,125,26,0,30,0,0,0,144,176,19,0,3,6,0,0,144,107,25,0,144,95,25,0,24,0,0,0,0,2,12,0,48,157,10,0,1,5,3,3,72,214,6,0,8,28,20,6,200,0,0,0,160,139,34,0,8,109,35,0,1,0,0,0,64,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,9,0,0,0,0,0,0,0,0,0,0,202,0,0,0,26,6,0,0,0,0,0,0,0,0,0,0,90,254,215,109,200,29,143,74,153,34,250,177,28,56,20,83,118,105,100,115,0,0,16,0,128,0,0,170,0,56,155,113,97,117,100,115,0,0,16,0,128,0,0,170,0,56,155,113,40,189,173,70,208,111,150,71,147,178,21,92,81,220,4,141,40,140,34,0,32,109,35,0,0,0,0,0,38,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,9,0,0,0,0,0,0,0,0,0,0,34,0,0,0,82,8,0,0,0,0,0,0,0,0,0,0,120,216,29,0,200,36,34,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,184,92,10,0,0,0,0,0,12,0,0,0,118,2,0,0,106,0,0,0,148,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,0,98,0,139,1,47,6,191,24,255,35,0,0,0,0,6,7,9,11,13,14,14,0,1,1,1,2,1,3,1,4,136,187,33,0,56,153,33,0,152,121,33,0,0,0,0,0,80,99,31,0,64,175,30,0,0,23,30,0,144,166,29,0,40,70,29,0,56,245,28,0,200,239,35,0,232,160,35,0,64,63,35,0,152,245,34,0,184,183,34,0,32,122,34,0,8,65,34,0,184,16,34,0,192,223,33,0,0,0,0,0,144,224,29,0,24,39,34,0,56,176,32,0,208,172,31,0,3,80,1,0,13,0,0,0,4,112,1,0,64,4,3,0,96,245,35,0,88,110,10,0,0,0,0,0,224,0,0,0,14,9,0,0,84,2,0,0,158,4,0,0,0,0,0,0,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,228,29,0,192,40,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,1,0,0,162,0,0,0,22,1,0,0,144,1,0,0,186,2,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,224,29,0,64,98,29,0,48,12,29,0,128,189,28,0,3,80,1,0,0,0,0,0,0,0,0,0,64,0,3,0,104,1,36,0,184,89,10,0,0,0,0,0,224,0,0,0,14,9,0,0,84,2,0,0,158,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,91,33,0,240,45,32,0,1,0,0,0,10,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,247,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,180,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,140,34,0,104,109,35,0,1,0,0,0,9,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,180,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,132,31,0,96,116,31,0,0,0,0,0,48,132,31,0,0,0,0,0,13,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,229,29,0,248,40,34,0,0,1,0,0,224,229,29,0,0,0,0,0,248,123,10,0,0,0,0,0,13,0,0,0,20,0,0,0,172,7,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,3,0,0,0,0,0,248,231,29,0,80,42,34,0,0,0,0,0,0,0,0,0,120,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,180,3,0,0,172,2,0,0,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,232,29,0,112,42,34,0,0,1,0,0,16,232,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,10,0,0,216,0,0,0,196,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,175,11,0,40,175,11,0,232,174,11,0,200,174,11,0,168,174,11,0,152,174,11,0,136,174,11,0,120,174,11,0,104,174,11,0,104,175,11,0,0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,5,5,6,6,7,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,0,0,0,0,0,0,232,143,34,0,112,110,35,0,0,0,0,0,73,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,3,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,232,29,0,160,42,34,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,80,1,0,0,0,0,0,60,6,0,0,36,1,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,232,29,0,0,43,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,9,0,0,64,0,0,0,106,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,144,34,0,184,110,35,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,96,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,9,0,0,0,0,0,0,224,2,0,0,0,0,0,0,254,4,0,0,0,0,0,0,0,0,0,0,144,233,29,0,232,43,34,0,40,178,32,0,168,174,31,0,2,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,23,13,0,0,0,0,0,24,40,0,0,94,10,0,0,36,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,44,30,0,80,186,29,0,0,1,0,0,232,44,30,0,0,0,0,0,0,0,0,0,0,0,0,0,50,80,1,0,0,0,0,0,0,0,0,0,138,1,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,148,34,0,32,111,35,0,0,0,0,0,148,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,1,0,0,0,0,0,0,0,0,0,0,6,1,0,0,232,2,0,0,0,0,0,0,0,0,0,0,144,148,34,0,80,111,35,0,0,0,0,0,86,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,248,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,1,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,148,34,0,136,111,35,0,0,0,0,0,139,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,4,0,0,0,0,0,0,0,0,0,0,70,0,0,0,28,0,0,0,70,1,0,0,0,0,0,0,160,234,29,0,136,44,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,80,7,0,0,118,8,0,0,232,0,0,0,98,4,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,149,34,0,152,111,35,0,0,0,0,0,150,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,10,0,0,0,0,0,0,0,0,0,0,106,1,0,0,64,4,0,0,0,0,0,0,0,0,0,0,152,150,34,0,184,111,35,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,144,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,9,0,0,0,0,0,0,0,2,0,0,0,0,0,0,38,8,0,0,0,0,0,0,0,0,0,0,224,152,29,0,136,58,29,0,0,0,0,0,12,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,3,0,0,0,0,0,0,0,0,0,0,210,1,0,0,70,5,0,0,0,0,0,0,0,0,0,0,192,158,34,0,248,112,35,0,0,0,0,0,89,0,0,0,0,2,0,0,0,0,0,0,168,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,2,0,0,0,0,0,0,96,2,0,0,0,0,0,0,150,1,0,0,0,0,0,0,0,0,0,0,248,154,34,0,120,112,35,0,0,0,0,0,89,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,208,109,13,0,48,146,8,0,116,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,234,29,0,224,44,34,0,120,178,32,0,8,175,31,0,0,0,0,0,0,0,0,0,66,85,83,74,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,4,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,237,29,0,104,46,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,202,7,0,0,248,4,0,0,194,1,0,0,162,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,248,157,34,0,200,112,35,0,3,0,0,0,66,85,83,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,5,0,0,0,0,0,0,0,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,24,32,40,48,56,1,9,17,25,33,41,49,57,2,10,18,26,34,42,50,58,3,11,19,27,35,43,51,59,4,12,20,28,36,44,52,60,5,13,21,29,37,45,53,61,6,14,22,30,38,46,54,62,7,15,23,31,39,47,55,63,5,2,1,1,0,1,1,0,1,1,2,2,1,1,1,1,3,3,1,1,2,2,1,1,4,4,1,1,1,1,2,2,5,5,1,1,3,3,1,1,6,6,1,2,1,2,7,7,1,1,8,8,1,1,4,2,1,4,2,1,3,3,1,1,1,9,9,1,2,1,2,1,5,5,1,1,10,10,1,1,3,3,2,2,1,1,11,11,6,4,4,1,6,1,2,1,2,12,8,1,12,7,8,7,1,16,1,16,1,3,3,13,1,13,2,2,1,15,1,5,14,15,1,5,14,1,17,8,17,8,1,4,4,2,2,1,25,25,24,24,1,3,1,3,1,8,6,7,6,1,18,8,18,1,7,23,2,2,23,1,1,21,22,9,9,22,19,1,21,5,19,5,1,33,20,33,20,8,4,4,1,32,2,2,8,3,32,26,3,1,7,7,26,6,1,6,1,1,16,1,10,1,10,2,16,29,28,2,29,28,1,27,5,8,5,27,1,8,3,7,3,31,41,31,1,41,6,1,6,7,4,4,1,1,2,1,2,11,34,30,11,1,30,15,15,34,36,40,36,40,35,35,37,37,39,39,38,38,1,255,0,2,254,0,3,253,1,255,4,252,5,251,1,255,6,250,2,254,7,249,1,255,8,248,9,247,3,253,1,255,10,246,2,254,11,245,1,255,12,4,244,252,1,255,13,243,1,255,14,242,2,5,15,254,251,241,253,3,16,240,17,1,255,239,6,18,250,238,2,254,19,237,1,255,20,236,4,252,7,249,21,235,1,255,2,3,253,22,254,234,8,23,248,1,2,233,255,2,254,254,24,1,232,255,25,5,251,1,231,255,9,247,26,1,230,3,1,255,27,253,255,229,1,3,255,253,28,252,4,10,246,228,1,255,1,255,29,6,227,250,30,252,3,3,253,226,1,4,255,31,253,1,11,245,255,225,32,255,255,2,254,1,1,224,1,4,255,252,33,255,1,1,255,5,5,251,223,255,244,12,251,249,1,1,7,34,4,252,255,4,222,252,35,36,254,221,254,220,2,13,2,255,1,243,1,255,37,1,251,6,5,255,38,250,248,5,8,255,1,1,219,255,5,39,251,251,6,250,218,217,242,40,14,2,1,1,254,216,255,254,2,255,255,255,1,1,1,255,1,255,1,255,1,255,0,38,0,1,1,2,2,3,3,4,4,5,5,6,8,6,8,7,7,9,9,10,10,11,11,1,12,1,12,13,13,16,14,16,14,15,15,17,17,18,0,18,19,20,21,19,22,21,20,22,25,24,2,25,24,23,23,2,26,28,26,28,29,27,29,27,33,33,1,32,1,3,32,30,36,3,36,30,31,31,35,34,37,41,34,35,37,4,41,4,49,8,8,49,40,38,5,38,40,39,5,39,42,43,42,7,57,6,43,44,6,50,7,44,57,48,50,48,45,45,46,47,51,46,47,58,1,51,58,1,52,59,53,9,52,55,55,59,53,56,54,56,54,9,64,64,60,63,60,63,61,62,61,62,2,10,2,10,11,1,11,13,12,1,12,13,16,16,8,8,14,3,3,15,14,15,4,4,1,17,17,5,1,7,7,5,6,1,2,2,6,22,1,25,21,22,8,24,1,21,25,24,8,18,18,23,9,20,23,33,29,33,20,1,19,1,29,36,9,36,19,41,28,57,32,3,28,3,1,27,49,49,1,32,26,26,2,4,4,7,57,41,2,7,10,5,37,16,10,27,8,8,13,16,37,13,1,5,0,1,255,1,255,1,255,1,255,1,255,1,1,255,255,1,255,1,255,1,255,1,255,2,1,254,255,1,255,1,1,255,255,1,255,1,255,1,0,255,1,1,1,255,1,255,255,255,1,1,2,255,255,1,255,254,1,1,255,255,1,1,255,255,1,255,3,1,253,2,255,1,1,254,255,255,255,1,1,1,1,1,255,255,255,2,255,254,1,2,254,255,1,1,2,255,255,1,254,255,1,1,255,2,1,2,255,1,254,255,254,255,255,1,1,255,1,255,1,1,1,255,255,1,4,255,255,252,1,1,1,2,255,255,1,255,255,1,255,255,1,254,1,255,1,1,255,255,1,1,255,255,3,2,253,254,2,5,254,2,2,251,254,254,254,2,253,3,2,3,253,2,254,254,3,253,6,2,254,3,250,3,253,253,3,7,252,4,253,2,249,2,2,254,252,2,8,254,254,254,4,2,254,2,3,2,254,254,2,2,254,248,254,9,254,2,253,254,2,254,2,2,2,4,254,252,10,2,2,254,247,254,2,254,5,4,252,4,254,2,251,252,253,4,2,253,3,254,251,5,3,3,254,253,246,252,2,11,1,1,0,2,2,1,1,3,3,4,4,0,1,1,5,5,2,2,6,6,7,7,1,8,1,8,3,3,9,9,1,2,2,1,4,10,4,10,11,11,1,5,12,12,1,5,13,13,3,3,6,6,2,2,14,14,16,16,15,7,15,8,8,7,1,1,17,17,4,4,1,1,18,18,2,2,5,5,25,3,9,3,25,9,19,24,19,24,1,21,20,1,21,22,20,22,23,23,8,6,33,6,8,33,7,7,26,26,1,32,1,32,28,4,28,10,29,27,27,10,41,4,29,2,2,41,36,31,49,31,34,30,34,36,30,35,1,49,11,5,35,11,1,3,3,5,37,37,8,40,8,40,12,12,42,42,1,38,16,57,1,6,16,39,38,6,7,7,13,13,39,43,2,43,57,2,50,9,44,9,50,4,15,48,44,4,1,15,48,14,14,1,45,45,8,3,5,8,51,47,3,46,46,47,5,51,1,17,17,58,1,58,2,52,52,2,53,7,59,6,6,56,53,55,7,55,1,54,59,56,54,10,1,10,4,60,1,60,8,4,8,64,64,61,1,63,3,63,62,61,5,11,5,3,11,62,1,255,0,1,255,2,254,1,255,1,255,0,3,253,1,255,2,254,1,255,1,255,4,1,252,255,2,254,1,255,5,3,253,251,2,1,254,255,1,255,6,2,1,255,250,254,1,255,3,253,2,254,4,252,1,255,1,255,1,2,255,2,254,254,7,249,1,255,3,253,8,248,1,255,5,251,3,253,1,4,2,252,255,254,1,1,255,255,9,1,1,247,255,1,255,255,1,255,3,253,1,3,253,255,3,253,1,255,10,1,246,255,1,4,255,2,1,255,1,254,1,252,255,6,250,255,1,1,1,255,1,1,255,255,255,1,11,255,254,4,255,2,245,5,251,252,255,1,4,1,252,255,254,2,1,255,12,1,254,1,244,4,2,1,255,252,4,252,2,254,255,1,7,255,255,249,255,253,1,3,1,5,2,1,255,251,13,254,255,2,254,243,1,255,5,6,5,251,1,1,250,1,255,255,251,255,14,2,254,1,242,255,8,1,255,248,1,5,1,5,251,1,255,1,251,255,15,1,255,255,255,3,241,253,6,1,16,255,6,250,250,1,255,1,240,1,7,255,1,255,250,253,6,249,3,255,0,35,0,1,1,2,2,3,3,4,4,1,1,5,5,6,6,7,7,8,8,9,9,2,2,10,10,1,1,11,11,12,12,3,3,13,13,0,14,14,16,15,16,15,4,4,17,1,17,1,5,5,18,18,2,2,6,6,8,19,7,8,7,19,20,20,21,21,22,24,22,24,23,23,1,1,25,25,3,3,26,26,9,9,27,27,28,28,33,29,4,33,29,1,4,1,32,32,2,2,31,10,30,10,30,31,34,34,5,5,36,36,35,41,35,11,41,11,37,1,8,8,37,6,1,6,40,7,7,40,12,38,12,39,39,38,49,13,49,13,3,42,3,42,16,16,43,43,14,14,1,1,44,15,44,15,2,2,57,48,50,48,57,50,4,45,45,4,46,47,47,46,1,51,1,17,17,51,8,9,9,5,58,8,58,5,52,52,55,56,53,56,55,59,59,53,54,1,6,54,7,7,6,1,2,3,2,3,64,60,60,10,10,64,61,62,61,63,1,63,62,1,18,24,18,4,25,4,8,21,21,1,24,22,25,22,8,11,19,11,23,1,20,23,19,20,5,12,5,1,16,2,12,13,2,13,1,16,0,1,255,1,255,1,255,1,255,2,254,1,255,1,255,1,255,1,255,1,255,2,254,1,255,3,253,1,255,1,255,2,254,1,255,0,1,255,1,1,255,255,2,254,1,4,255,252,2,254,1,255,253,3,2,254,2,1,2,254,254,255,1,255,1,255,1,1,255,255,1,255,5,251,1,255,3,253,1,255,2,254,1,255,1,255,1,1,3,255,255,6,253,250,255,1,4,252,1,2,1,254,255,255,1,255,3,253,1,255,1,1,255,2,255,254,1,7,253,3,255,3,249,253,1,253,3,255,2,1,254,1,255,255,1,2,255,254,252,255,4,1,2,254,1,255,254,2,8,248,255,2,1,254,251,5,1,255,255,1,255,1,4,255,1,252,255,255,1,1,9,1,247,2,254,255,252,3,253,252,255,4,1,4,1,255,1,255,1,1,255,1,255,255,255,10,4,1,4,252,252,246,6,5,250,251,1,255,1,3,253,255,1,255,255,255,11,1,1,245,254,254,2,5,254,251,251,2,254,12,2,254,2,2,5,253,254,3,254,244,254,2,2,2,251,3,5,13,253,7,253,253,249,3,243,3,0,34,0,1,1,1,2,2,1,3,3,1,1,1,4,4,1,5,2,1,5,2,1,1,6,6,1,1,1,1,1,7,3,1,2,3,0,1,2,7,1,1,1,8,1,1,8,1,1,1,9,1,9,1,2,1,1,2,1,1,10,4,1,10,1,4,1,1,1,1,1,3,1,1,1,3,2,1,5,1,1,1,2,5,1,11,1,11,1,1,1,1,1,1,1,1,1,1,2,1,6,1,6,1,1,2,1,1,1,1,1,1,1,12,3,1,12,1,1,1,2,1,1,3,1,1,1,1,1,1,4,1,1,1,2,1,1,4,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,3,1,2,1,1,5,1,1,1,1,1,7,1,7,1,1,2,3,1,1,1,1,5,1,1,1,1,1,1,2,13,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,13,2,1,1,4,1,1,1,3,1,6,1,1,1,14,1,1,1,1,1,14,6,1,1,1,1,15,2,4,1,2,3,15,1,1,1,8,1,1,8,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,0,1,255,2,1,255,254,1,255,3,253,4,1,255,252,1,2,5,255,254,251,6,1,255,250,7,249,8,248,1,2,9,3,254,0,247,253,255,10,246,11,1,245,12,255,244,13,243,1,14,255,242,4,15,241,252,16,240,1,2,17,255,239,254,18,238,19,237,20,3,236,21,235,253,5,22,2,234,233,23,251,254,24,1,232,255,25,231,26,230,229,27,28,29,228,227,6,30,2,225,254,226,31,250,224,32,33,223,34,221,222,1,4,220,255,35,37,36,7,219,38,252,218,39,41,40,216,217,3,42,213,215,249,214,43,253,44,212,45,211,46,47,8,209,208,210,50,206,48,49,51,207,52,204,5,205,248,203,53,3,200,56,55,54,202,2,60,254,201,58,9,251,59,57,199,193,253,198,196,195,61,197,194,247,1,64,62,69,192,63,65,189,188,66,191,68,190,187,67,186,255,10,71,185,4,73,72,70,6,180,253,74,178,182,1,78,80,184,181,76,255,3,183,79,75,77,1,11,252,177,246,250,255,179,173,176,2,81,172,254,83,175,82,174,84,169,170,85,245,171,86,167,87,168,88,89,2,33,1,1,0,2,1,2,1,3,3,1,1,4,4,2,2,1,1,5,5,6,1,6,1,7,7,3,3,2,8,2,8,1,1,0,9,9,1,1,10,4,10,4,11,11,2,1,2,1,12,12,3,3,1,1,13,5,5,13,14,1,1,14,2,2,6,6,15,1,1,15,16,4,7,16,4,7,1,1,3,3,8,8,2,2,1,1,17,17,1,1,18,18,5,5,2,2,1,1,9,19,9,19,20,3,3,20,1,10,21,1,10,4,4,21,22,6,6,22,1,1,23,24,2,2,23,24,11,1,1,11,7,25,7,1,1,25,8,8,3,26,3,1,12,2,2,26,1,12,5,5,27,4,1,4,1,27,28,1,28,13,1,13,2,29,2,1,32,6,1,30,14,29,14,6,3,31,3,1,30,1,32,31,33,9,33,1,1,7,9,7,2,2,1,1,4,36,34,4,5,10,10,5,34,1,1,35,8,8,36,3,35,1,15,3,2,1,16,15,16,2,37,1,37,1,1,1,6,6,38,1,38,11,1,39,39,40,11,2,41,4,40,1,2,4,1,1,1,41,3,1,3,1,5,7,5,7,1,255,0,1,2,255,254,1,255,3,253,1,255,2,254,4,252,1,255,1,5,255,251,1,255,2,254,3,1,253,255,6,250,0,1,255,7,249,1,2,255,254,1,255,4,8,252,248,1,255,3,253,9,247,1,2,254,255,1,10,246,255,5,251,2,254,1,11,245,255,1,3,2,255,253,254,12,244,4,252,2,254,250,6,13,243,1,255,14,242,1,255,3,253,7,249,15,241,2,1,254,255,1,5,251,255,240,2,1,16,254,4,252,255,1,3,253,255,17,239,1,1,248,8,255,255,2,18,238,254,3,1,253,19,237,255,3,253,6,1,250,20,2,9,247,255,236,254,4,252,1,251,21,5,235,255,1,234,255,2,22,254,10,1,246,23,1,4,233,1,2,255,254,252,249,1,7,232,255,24,255,255,1,3,255,231,25,4,253,252,11,245,26,230,6,1,1,250,251,253,3,5,255,229,27,1,4,252,255,248,255,28,2,8,244,228,254,254,2,12,255,29,1,227,30,226,5,251,1,225,255,3,31,255,1,1,253,243,1,249,255,224,13,7,32,33,223,255,247,222,9,34,250,5,6,251,2,13,1,1,0,1,1,2,2,1,1,3,3,1,1,0,2,2,4,1,4,1,1,1,5,5,1,1,6,6,2,2,1,1,3,3,7,7,1,1,8,8,1,1,2,2,1,9,1,9,4,4,10,1,1,10,1,1,11,11,3,3,1,2,1,2,1,1,12,12,5,5,1,1,13,1,1,13,2,2,1,1,6,6,1,1,4,14,4,14,3,1,3,1,1,1,15,7,15,2,2,7,1,1,1,8,1,8,16,16,1,1,1,1,2,1,1,2,1,1,3,5,5,3,4,1,1,4,1,1,17,17,9,1,1,9,2,2,1,1,10,10,1,6,1,1,6,18,1,1,18,1,1,1,2,2,3,1,3,1,1,1,4,1,19,1,19,7,1,1,20,1,4,20,1,7,11,2,1,11,21,2,8,5,1,8,1,5,21,1,1,1,22,1,1,22,1,1,3,3,1,23,2,12,24,1,1,2,1,1,12,23,1,1,24,1,1,1,4,1,1,1,2,1,6,6,4,2,1,1,1,1,1,1,1,14,13,3,1,25,9,25,14,1,9,3,13,1,1,1,1,1,10,1,1,2,10,2,236,255,0,2,254,1,255,3,253,1,255,4,252,0,2,254,1,5,255,251,6,250,1,255,7,249,1,255,3,253,8,248,2,254,1,255,9,247,1,255,10,246,4,252,11,1,245,255,2,254,1,12,244,255,13,243,1,255,3,253,14,5,242,251,241,15,255,1,2,254,16,240,1,17,239,255,6,250,18,238,2,254,237,19,253,1,3,255,4,20,252,1,235,21,1,2,255,249,7,254,22,234,23,2,233,254,1,255,232,24,231,25,248,230,26,8,229,27,5,3,253,251,252,28,228,4,29,227,1,255,254,226,30,2,9,247,225,31,2,254,224,3,32,223,253,1,33,222,255,34,221,35,246,10,250,36,6,220,37,219,251,38,1,218,255,3,39,217,255,40,5,1,216,253,2,245,215,254,1,11,253,252,41,3,42,4,255,213,214,43,1,212,45,255,44,211,249,7,210,1,244,2,1,209,46,12,47,48,254,255,208,49,255,206,207,50,250,205,51,52,243,53,252,4,6,13,203,204,202,55,54,201,200,254,2,248,56,1,253,255,2,58,3,8,254,57,198,196,197,199,253,60,59,242,3,14,2,38,1,1,0,2,2,1,1,3,3,4,4,5,5,1,1,6,6,2,2,7,7,8,8,1,1,3,3,9,9,10,10,1,1,2,2,4,4,11,0,11,12,12,13,13,1,1,5,5,14,14,15,16,15,16,3,3,1,6,1,6,2,2,7,7,8,8,17,17,1,1,4,4,18,18,2,2,1,19,1,20,19,20,21,21,3,3,22,22,5,5,24,1,1,23,9,23,24,9,2,2,10,1,1,10,6,6,25,4,4,25,7,7,26,8,1,8,3,1,26,3,11,11,27,27,2,28,1,2,28,1,12,12,5,5,29,13,13,29,32,1,1,33,31,30,32,4,30,33,4,31,3,14,1,1,3,34,34,2,2,14,6,6,35,36,35,36,1,15,1,16,16,15,7,9,7,9,37,8,8,37,1,1,39,2,38,39,2,40,5,38,40,5,3,3,4,4,10,10,1,1,1,1,41,2,41,2,6,6,1,1,11,42,11,43,3,42,3,17,4,43,1,17,7,1,8,44,4,7,44,5,8,2,5,1,2,48,45,1,12,45,12,48,13,13,1,9,9,46,1,46,47,47,49,18,18,49,1,255,0,1,255,2,254,1,255,1,255,1,255,3,253,1,255,254,2,1,255,1,255,4,252,254,2,1,255,1,255,5,251,253,3,2,254,1,0,255,1,255,1,255,6,250,2,254,1,255,1,1,255,255,253,3,7,2,249,254,252,4,2,254,2,254,1,255,8,248,3,253,1,255,251,5,9,1,247,1,255,255,1,255,252,4,1,255,3,253,1,246,10,1,2,255,255,254,6,250,2,11,245,254,3,253,1,252,4,255,3,253,1,3,12,253,251,244,255,5,2,254,1,255,249,1,13,7,255,243,2,254,4,252,1,2,254,255,1,14,242,1,1,1,255,251,255,255,5,255,250,2,241,15,6,1,255,248,8,254,252,4,1,1,255,255,16,2,240,254,2,254,4,3,252,253,255,252,4,1,239,17,255,247,1,1,9,1,251,255,255,5,249,7,6,250,3,253,18,238,19,237,1,246,255,10,251,5,20,236,253,1,3,1,8,255,248,2,7,255,235,254,5,21,5,255,249,251,1,250,251,245,6,22,11,1,1,234,253,255,3,255,3,253,233,4,252,1,23,255,1,255,1,254,2,255,4,11,1,1,1,1,0,2,2,1,1,3,3,0,1,1,2,2,4,4,1,1,5,5,1,1,2,2,3,3,6,6,1,1,7,7,8,1,8,2,2,1,4,4,1,3,1,3,9,9,2,2,1,5,1,5,10,10,1,1,11,11,3,6,3,4,4,6,2,2,1,12,1,12,7,13,7,13,1,1,8,8,2,2,14,14,16,15,16,5,5,1,3,15,1,3,4,4,1,1,17,17,2,2,6,6,1,18,1,18,22,21,22,21,25,24,25,19,9,20,9,23,19,24,20,3,23,7,3,1,1,7,28,26,29,5,28,26,5,8,29,4,8,27,2,2,4,27,1,1,10,36,10,33,33,36,30,1,32,32,1,30,6,31,31,35,3,6,11,11,3,2,35,2,34,1,34,1,37,37,12,7,12,5,41,5,4,7,1,8,13,4,1,41,13,38,8,38,9,1,40,40,9,1,39,2,2,49,39,42,3,3,14,16,49,14,16,42,43,43,6,6,15,1,1,15,44,44,1,1,50,48,4,5,4,7,5,2,10,10,48,7,50,45,2,1,45,8,8,1,46,46,3,47,47,3,1,1,1,255,2,254,0,1,255,3,253,1,255,0,4,252,2,254,1,255,5,251,1,255,6,250,3,253,2,254,1,255,7,249,1,255,1,8,255,4,252,248,2,254,9,3,247,253,1,255,5,251,10,2,246,254,1,255,11,245,1,255,252,2,4,3,253,254,6,250,12,1,244,255,2,1,254,255,13,243,2,254,7,249,1,255,1,1,255,3,253,14,5,255,242,251,4,252,15,241,1,255,8,248,253,3,16,1,240,255,1,1,255,255,1,1,255,1,2,1,254,1,255,255,255,6,255,3,250,17,239,253,1,1,1,4,255,255,252,3,255,5,253,255,247,9,251,1,18,238,2,1,254,1,255,255,1,19,255,1,237,255,4,1,255,1,7,252,254,2,249,10,255,246,1,20,255,236,1,255,2,4,254,5,1,251,6,252,21,4,2,250,235,255,254,1,252,255,253,22,255,1,3,234,255,11,245,1,1,1,8,248,2,2,255,254,254,255,1,255,251,5,2,23,233,254,1,255,24,232,255,255,7,6,249,5,250,12,253,3,1,251,1,1,244,25,255,251,5,231,255,1,9,1,255,247,26,230,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,144,238,29,0,240,46,34,0,0,0,0,0,144,238,29,0,0,0,0,0,141,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,0,0,214,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,242,29,0,40,48,34,0,0,1,0,0,0,0,0,0,128,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,9,0,0,104,2,0,0,44,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,246,29,0,168,49,34,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,3,0,0,100,2,0,0,242,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,249,29,0,80,52,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,54,7,0,0,130,8,0,0,210,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,196,32,0,24,172,32,0,88,10,35,0,248,148,32,0,2,80,1,0,28,0,0,0,0,0,0,0,64,0,5,0,184,248,35,0,168,191,13,0,0,0,0,0,128,0,0,0,214,4,0,0,184,2,0,0,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,253,29,0,184,53,34,0,0,0,0,0,208,182,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,136,245,35,0,0,0,0,0,0,0,0,0,0,0,0,0,142,8,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,29,0,240,54,34,0,0,1,0,0,136,183,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,6,0,0,78,10,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,83,33,0,24,24,33,0,88,10,35,0,160,250,32,0,2,80,1,0,28,0,0,0,0,0,0,0,64,0,5,0,8,249,35,0,104,206,13,0,0,0,0,0,128,0,0,0,214,4,0,0,184,2,0,0,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,1,30,0,240,55,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,4,0,0,218,10,0,0,2,2,0,0,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,128,86,85,85,85,0,0,0,64,52,51,51,51,171,170,170,42,37,73,146,36,0,0,0,32,29,199,113,28,154,153,153,25,117,209,69,23,86,85,85,21,20,59,177,19,147,36,73,18,18,17,17,17,0,0,0,16,16,15,15,15,143,227,56,14,95,67,121,13,205,204,204,12,13,195,48,12,187,232,162,11,45,100,33,11,171,170,170,10,164,112,61,10,138,157,216,9,95,66,123,9,74,146,36,9,177,220,211,8,137,136,136,8,133,16,66,8,0,0,0,8,125,240,193,7,136,135,135,7,8,117,80,7,200,113,28,7,70,62,235,6,176,161,188,6,7,105,144,6,103,102,102,6,100,112,62,6,135,97,24,6,209,23,244,5,94,116,209,5,6,91,176,5,23,178,144,5,11,98,114,5,86,85,85,5,42,120,57,5,82,184,30,5,6,5,5,5,197,78,236,4,63,135,212,4,48,161,189,4,75,144,167,4,37,73,146,4,32,193,125,4,89,238,105,4,152,199,86,4,69,68,68,4,84,92,50,4,67,8,33,4,5,65,16,4,0,0,0,4,4,63,240,3,63,248,224,3,54,38,210,3,196,195,195,3,15,204,181,3,132,58,168,3,210,10,155,3,228,56,142,3,225,192,129,3,35,159,117,3,55,208,105,3,216,80,94,3,237,29,83,3,132,52,72,3,211,145,61,3,52,51,51,3,32,22,41,3,50,56,31,3,34,151,21,3,196,48,12,3,4,3,3,3,233,11,250,2,145,73,241,2,47,186,232,2,12,92,224,2,131,45,216,2,3,45,208,2,12,89,200,2,45,176,192,2,6,49,185,2,71,218,177,2,171,170,170,2,254,160,163,2,21,188,156,2,213,250,149,2,41,92,143,2,13,223,136,2,131,130,130,2,152,69,124,2,99,39,118,2,3,39,112,2,160,67,106,2,106,124,100,2,152,208,94,2,106,63,89,2,38,200,83,2,24,106,78,2,147,36,73,2,241,246,67,2,144,224,62,2,214,224,57,2,45,247,52,2,3,35,48,2,204,99,43,2,3,185,38,2,35,34,34,2,174,158,29,2,42,46,25,2,34,208,20,2,34,132,16,2,187,73,12,2,131,32,8,2,17,8,4,2,0,0,0,2,241,7,252,1,130,31,248,1,90,70,244,1,32,124,240,1,124,192,236,1,27,19,233,1,173,115,229,1,226,225,225,1,111,93,222,1,8,230,218,1,102,123,215,1,66,29,212,1,89,203,208,1,105,133,205,1,49,75,202,1,114,28,199,1,241,248,195,1,113,224,192,1,185,210,189,1,146,207,186,1,196,214,183,1,28,232,180,1,101,3,178,1,108,40,175,1,2,87,172,1,247,142,169,1,27,208,166,1,66,26,164,1,64,109,161,1,234,200,158,1,21,45,156,1,154,153,153,1,80,14,151,1,16,139,148,1,181,15,146,1,25,156,143,1,25,48,141,1,145,203,138,1,96,110,136,1,98,24,134,1,120,201,131,1,130,129,129,1,96,64,127,1,245,5,125,1,33,210,122,1,201,164,120,1,207,125,118,1,24,93,116,1,136,66,114,1,6,46,112,1,119,31,110,1,194,22,108,1,206,19,106,1,130,22,104,1,199,30,102,1,134,44,100,1,168,63,98,1,23,88,96,1,188,117,94,1,131,152,92,1,87,192,90,1,36,237,88,1,212,30,87,1,86,85,85,1,149,144,83,1,127,208,81,1,2,21,80,1,11,94,78,1,137,171,76,1,107,253,74,1,159,83,73,1,21,174,71,1,189,12,70,1,135,111,68,1,99,214,66,1,66,65,65,1,20,176,63,1,204,34,62,1,91,153,60,1,178,19,59,1,195,145,57,1,130,19,56,1,224,152,54,1,208,33,53,1,70,174,51,1,53,62,50,1,145,209,48,1,76,104,47,1,93,2,46,1,181,159,44,1,75,64,43,1,19,228,41,1,2,139,40,1,12,53,39,1,40,226,37,1,74,146,36,1,104,69,35,1,121,251,33,1,113,180,32,1,72,112,31,1,244,46,30,1,107,240,28,1,165,180,27,1,151,123,26,1,57,69,25,1,130,17,24,1,105,224,22,1,230,177,21,1,241,133,20,1,130,92,19,1,143,53,18,1,18,17,17,1,2,239,15,1,87,207,14,1,11,178,13,1,21,151,12,1,111,126,11,1,17,104,10,1,244,83,9,1,17,66,8,1,97,50,7,1,222,36,6,1,128,25,5,1,66,16,4,1,28,9,3,1,9,4,2,1,2,1,1,1,0,0,0,1,0,0,0,0,0,16,137,11,63,12,155,13,0,16,93,20,144,29,254,57,137,11,81,8,212,8,207,9,137,11,175,14,81,21,207,41,63,12,212,8,95,9,106,10,63,12,150,15,161,22,99,44,155,13,207,9,106,10,146,11,155,13,81,17,36,25,81,49,0,16,137,11,63,12,155,13,0,16,93,20,144,29,254,57,93,20,175,14,150,15,81,17,93,20,235,25,161,37,207,73,144,29,81,21,161,22,36,25,144,29,161,37,161,54,40,107], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1190448);
/* memory initializer */ allocate([254,57,207,41,99,44,81,49,254,57,207,73,40,107,49,210,8,178,34,0,32,114,35,0,0,0,0,0,40,0,0,0,2,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,158,0,0,0,92,7,0,0,0,0,0,0,0,0,0,0,88,43,35,0,120,131,35,0,1,0,0,0,1,64,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,6,0,0,0,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,16,7,7,17,18,8,8,3,3,3,3,3,3,3,3,19,20,9,9,21,22,10,10,4,4,4,4,4,4,4,4,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,23,24,11,11,25,26,12,12,5,5,5,5,5,5,5,5,27,28,13,13,29,30,14,14,6,6,6,6,6,6,6,6,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,248,4,4,9,247,252,252,2,2,2,2,2,2,2,2,10,246,5,5,11,245,251,251,254,254,254,254,254,254,254,254,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,12,244,6,6,13,243,250,250,3,3,3,3,3,3,3,3,14,242,7,7,15,241,249,249,253,253,253,253,253,253,253,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,7,7,9,9,7,7,5,5,5,5,5,5,5,5,9,9,7,7,9,9,7,7,5,5,5,5,5,5,5,5,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,9,9,7,7,9,9,7,7,5,5,5,5,5,5,5,5,9,9,7,7,9,9,7,7,5,5,5,5,5,5,5,5,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,0,0,2,3,1,1,0,0,0,0,0,0,0,0,4,5,2,2,6,7,3,3,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,9,4,4,10,11,5,5,2,2,2,2,2,2,2,2,12,13,6,6,14,15,7,7,3,3,3,3,3,3,3,3,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,15,0,4,0,21,0,6,0,23,0,7,0,31,0,8,0,37,0,9,0,36,0,9,0,33,0,10,0,32,0,10,0,7,0,11,0,6,0,11,0,32,0,11,0,6,0,3,0,20,0,6,0,30,0,8,0,15,0,10,0,33,0,11,0,80,0,12,0,14,0,4,0,29,0,8,0,14,0,10,0,81,0,12,0,13,0,5,0,35,0,9,0,13,0,10,0,12,0,5,0,34,0,9,0,82,0,12,0,11,0,5,0,12,0,10,0,83,0,12,0,19,0,6,0,11,0,10,0,84,0,12,0,18,0,6,0,10,0,10,0,17,0,6,0,9,0,10,0,16,0,6,0,8,0,10,0,22,0,7,0,85,0,12,0,21,0,7,0,20,0,7,0,28,0,8,0,27,0,8,0,33,0,9,0,32,0,9,0,31,0,9,0,30,0,9,0,29,0,9,0,28,0,9,0,27,0,9,0,26,0,9,0,34,0,11,0,35,0,11,0,86,0,12,0,87,0,12,0,7,0,4,0,25,0,9,0,5,0,11,0,15,0,6,0,4,0,11,0,14,0,6,0,13,0,6,0,12,0,6,0,19,0,7,0,18,0,7,0,17,0,7,0,16,0,7,0,26,0,8,0,25,0,8,0,24,0,8,0,23,0,8,0,22,0,8,0,21,0,8,0,20,0,8,0,19,0,8,0,24,0,9,0,23,0,9,0,22,0,9,0,21,0,9,0,20,0,9,0,19,0,9,0,18,0,9,0,17,0,9,0,7,0,10,0,6,0,10,0,5,0,10,0,4,0,10,0,36,0,11,0,37,0,11,0,38,0,11,0,39,0,11,0,88,0,12,0,89,0,12,0,90,0,12,0,91,0,12,0,92,0,12,0,93,0,12,0,94,0,12,0,95,0,12,0,3,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,8,8,9,9,10,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,0,0,0,1,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,0,0,1,2,3,4,5,6,7,8,9,10,11,12,1,2,3,4,5,6,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,216,3,30,0,48,56,34,0,0,1,0,0,40,184,32,0,0,0,0,0,176,239,13,0,0,0,0,0,8,0,0,0,20,0,0,0,0,0,0,0,218,5,0,0,158,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,88,184,34,0,208,114,35,0,0,0,0,0,113,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,10,0,0,0,0,0,0,0,0,0,0,88,2,0,0,30,3,0,0,0,0,0,0,0,0,0,0,8,185,34,0,0,115,35,0,0,0,0,0,112,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,0,0,0,0,0,0,0,0,0,0,88,2,0,0,30,3,0,0,0,0,0,0,0,0,0,0,56,186,34,0,88,115,35,0,0,0,0,0,29,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,6,0,0,0,0,0,0,0,0,0,0,182,1,0,0,224,4,0,0,0,0,0,0,0,0,0,0,96,186,34,0,104,115,35,0,0,0,0,0,76,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,9,0,0,0,0,0,0,0,0,0,0,144,0,0,0,142,1,0,0,0,0,0,0,0,0,0,0,0,188,34,0,176,115,35,0,1,0,0,0,27,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,8,0,0,0,0,0,0,0,0,0,0,142,0,0,0,56,3,0,0,44,0,0,0,0,0,0,0,64,182,31,0,96,244,30,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,128,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,4,0,0,24,9,0,0,98,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,190,32,0,72,184,31,0,0,0,0,0,0,0,0,0,0,0,0,0,176,242,13,0,0,0,0,0,0,0,0,0,120,4,0,0,0,0,0,0,100,10,0,0,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,10,30,0,136,60,34,0,0,0,0,0,176,186,32,0,0,0,0,0,8,0,0,0,0,0,0,0,129,8,0,0,0,0,0,0,224,242,13,0,0,0,0,0,28,4,0,0,24,9,0,0,98,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,25,30,0,232,65,34,0,1,0,0,0,0,0,0,0,0,0,0,0,16,243,13,0,0,0,0,0,0,0,0,0,120,4,0,0,38,6,0,0,100,10,0,0,26,0,0,0,132,8,0,0,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,27,30,0,136,67,34,0,168,190,32,0,104,184,31,0,60,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,166,9,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,27,30,0,136,67,34,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,7,0,0,10,2,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,188,34,0,248,115,35,0,0,0,0,0,137,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,10,0,0,0,0,0,0,0,0,0,0,126,0,0,0,172,10,0,0,0,0,0,0,0,0,0,0,64,30,30,0,40,68,34,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,164,3,0,0,186,9,0,0,206,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,188,34,0,248,115,35,0,0,0,0,0,138,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,10,0,0,0,0,0,0,0,0,0,0,126,0,0,0,172,10,0,0,0,0,0,0,0,0,0,0,88,106,35,0,232,19,35,0,0,0,0,0,88,106,35,0,0,0,0,0,192,254,35,0,0,0,0,0,0,0,0,0,32,0,0,0,110,0,0,0,162,8,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,96,31,0,120,172,30,0,0,0,0,0,70,68,73,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,5,0,0,0,0,0,0,0,0,0,0,214,0,0,0,250,8,0,0,0,0,0,0,0,0,0,0,112,31,30,0,184,69,34,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,48,9,0,0,16,5,0,0,168,0,0,0,0,0,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,189,34,0,0,116,35,0,0,0,0,0,48,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,8,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,3,0,0,0,0,0,0,0,0,0,0,126,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,65,76,66,84,66,80,77,84,67,79,77,84,67,79,78,84,67,79,80,84,68,76,89,84,69,78,67,84,69,88,84,84,70,76,84,84,73,84,49,84,73,84,50,84,73,84,51,84,75,69,89,84,76,65,78,84,76,69,78,84,77,69,68,84,79,65,76,84,79,70,78,84,79,76,89,84,79,80,69,84,79,87,78,84,80,69,49,84,80,69,50,84,80,69,51,84,80,69,52,84,80,79,83,84,80,85,66,84,82,67,75,84,82,83,78,84,82,83,79,84,83,82,67,84,83,83,69,0,0,0,0,0,0,0,0,104,119,31,0,128,105,31,0,216,72,31,0,0,38,31,0,160,24,31,0,56,12,31,0,16,252,30,0,72,236,30,0,224,222,30,0,240,209,30,0,152,194,30,0,72,180,30,0,136,150,30,0,152,119,30,0,40,107,30,0,88,93,30,0,200,79,30,0,200,64,30,0,56,53,30,0,128,42,30,0,128,33,30,0,0,0,0,0,105,109,97,103,101,47,103,105,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,0,0,0,105,109,97,103,101,47,106,112,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,105,109,97,103,101,47,106,112,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,105,109,97,103,101,47,112,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,0,0,105,109,97,103,101,47,116,105,102,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,0,0,0,105,109,97,103,101,47,98,109,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,0,0,0,74,80,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,80,78,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,68,69,78,84,68,79,82,84,68,82,67,84,68,82,76,84,68,84,71,84,73,80,76,84,77,67,76,84,77,79,79,84,80,82,79,84,83,79,65,84,83,79,80,84,83,79,84,84,83,83,84,0,0,0,0,24,126,32,0,48,101,32,0,248,80,32,0,48,101,32,0,96,41,32,0,184,252,31,0,96,231,31,0,168,211,31,0,80,192,31,0,0,171,31,0,32,153,31,0,112,135,31,0,0,0,0,0,0,0,0,0,84,68,65,84,84,73,77,69,84,79,82,89,84,82,68,65,84,83,73,90,84,89,69,82,0,0,0,0,0,0,0,0,104,42,30,0,168,74,34,0,248,192,32,0,32,187,31,0,120,248,30,0,144,75,30,0,216,206,29,0,144,102,29,0,24,17,29,0,128,192,28,0,0,190,35,0,208,101,35,0,216,14,35,0,128,204,34,0,120,144,34,0,8,86,34,0,168,32,34,0,24,239,33,0,136,201,33,0,24,164,33,0,88,134,33,0,120,86,33,0,112,27,33,0,216,251,32,0,232,225,32,0,136,198,32,0,32,173,32,0,24,150,32,0,0,0,0,0,0,0,0,0,128,202,35,0,32,166,35,0,208,124,33,0,200,74,32,0,96,99,31,0,88,175,30,0,24,23,30,0,176,166,29,0,64,70,29,0,72,245,28,0,224,239,35,0,56,161,35,0,128,63,35,0,184,245,34,0,208,183,34,0,48,122,34,0,32,65,34,0,200,16,34,0,208,223,33,0,144,187,33,0,64,153,33,0,216,121,33,0,152,56,33,0,32,14,33,0,96,244,32,0,40,217,32,0,8,190,32,0,160,166,32,0,208,141,32,0,224,116,32,0,208,93,32,0,112,72,32,0,160,15,32,0,168,244,31,0,24,224,31,0,8,205,31,0,8,184,31,0,240,164,31,0,24,147,31,0,0,129,31,0,136,113,31,0,240,96,31,0,120,53,31,0,8,34,31,0,128,20,31,0,72,6,31,0,248,245,30,0,168,231,30,0,24,218,30,0,152,203,30,0,176,187,30,0,48,173,30,0,72,131,30,0,224,113,30,0,32,101,30,0,136,87,30,0,104,70,30,0,216,59,30,0,224,48,30,0,144,38,30,0,24,30,30,0,96,21,30,0,56,243,29,0,104,231,29,0,32,223,29,0,168,213,29,0,112,205,29,0,72,196,29,0,0,189,29,0,32,181,29,0,248,172,29,0,88,165,29,0,32,133,29,0,40,122,29,0,24,115,29,0,72,108,29,0,136,101,29,0,96,95,29,0,56,89,29,0,176,82,29,0,8,75,29,0,72,69,29,0,248,42,29,0,24,34,29,0,40,28,29,0,192,21,29,0,208,14,29,0,240,8,29,0,104,4,29,0,56,255,28,0,152,250,28,0,56,244,28,0,40,219,28,0,64,210,28,0,80,203,28,0,216,196,28,0,120,191,28,0,56,187,28,0,24,182,28,0,56,177,28,0,216,242,35,0,24,239,35,0,0,214,35,0,136,205,35,0,224,199,35,0,72,194,35,0,208,188,35,0,168,184,35,0,32,179,35,0,136,174,35,0,32,169,35,0,16,160,35,0,48,135,35,0,232,121,35,0,136,114,35,0,48,106,35,0,8,100,35,0,8,94,35,0,224,84,35,0,240,79,35,0,72,71,35,0,136,62,35,0,24,40,35,0,216,30,35,0,168,24,35,0,184,19,35,0,184,13,35,0,8,9,35,0,144,3,35,0,48,255,34,0,32,249,34,0,8,245,34,0,56,226,34,0,32,218,34,0,200,212,34,0,152,207,34,0,104,203,34,0,80,199,34,0,8,195,34,0,160,190,34,0,112,186,34,0,8,183,34,0,8,164,34,0,200,157,34,0,40,153,34,0,32,148,34,0,152,143,34,0,120,139,34,0,80,43,30,0,88,75,34,0,48,193,32,0,80,43,30,0,0,0,0,0,79,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,90,2,0,0,248,2,0,0,226,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,44,30,0,144,75,34,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,254,3,0,0,178,3,0,0,68,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,95,33,0,160,49,32,0,1,0,0,0,59,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,247,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,8,0,0,0,0,0,0,0,0,0,0,142,0,0,0,56,3,0,0,44,0,0,0,0,0,0,0,216,189,34,0,40,116,35,0,0,0,0,0,26,0,0,0,0,16,0,64,0,0,0,0,248,254,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,38,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,0,0,0,0,152,1,0,0,0,0,0,0,8,1,0,0,0,0,0,0,0,0,0,0,120,191,34,0,96,116,35,0,0,0,0,0,26,0,0,0,3,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,38,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,10,0,0,0,0,0,0,0,0,0,0,62,2,0,0,8,0,0,0,0,0,0,0,0,0,0,0,80,44,30,0,216,75,34,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,94,5,0,0,226,7,0,0,54,2,0,0,142,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,192,34,0,168,116,35,0,0,0,0,0,174,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,5,0,0,0,0,0,0,0,0,0,0,206,0,0,0,234,6,0,0,0,0,0,0,0,0,0,0,56,49,30,0,8,77,34,0,0,0,0,0,40,194,32,0,0,80,1,0,2,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,72,55,14,0,0,0,0,0,104,0,0,0,208,10,0,0,18,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,52,30,0,96,78,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,26,3,0,0,96,9,0,0,146,1,0,0,210,7,0,0,132,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,2,0,0,0,0,0,3,4,4,0,0,0,0,0,6,7,6,0,0,0,0,144,168,31,0,32,150,31,0,0,0,0,0,144,168,31,0,0,0,0,0,53,54,50,72,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,34,0,0,0,35,0,0,0,35,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,37,0,0,0,40,45,51,57,64,72,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,2,2,3,3,3,3,3,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,254,58,10,254,254,58,10,254,254,58,10,254,254,58,10,254,252,54,16,254,252,54,16,254,252,54,16,254,252,54,16,254,250,46,28,252,250,46,28,252,250,46,28,252,250,46,28,252,252,36,36,252,252,36,36,252,252,36,36,252,252,36,36,252,252,28,46,250,252,28,46,250,252,28,46,250,252,28,46,250,254,16,54,252,254,16,54,252,254,16,54,252,254,16,54,252,254,10,58,254,254,10,58,254,254,10,58,254,254,10,58,254,0,1,0,2,1,0,3,2,1,0,4,3,2,1,0,5,4,3,2,1,0,6,5,4,3,2,1,0,7,6,5,4,3,2,1,0,7,6,5,4,3,2,1,7,6,5,4,3,2,7,6,5,4,3,7,6,5,4,7,6,5,7,6,7,0,0,1,0,1,2,0,1,2,3,0,1,2,3,4,0,1,2,3,4,5,0,1,2,3,4,5,6,0,1,2,3,4,5,6,7,1,2,3,4,5,6,7,2,3,4,5,6,7,3,4,5,6,7,4,5,6,7,5,6,7,6,7,7,0,1,0,2,1,0,3,2,1,0,3,2,1,3,2,3,0,0,1,0,1,2,0,1,2,3,1,2,3,2,3,3,40,53,30,0,136,78,34,0,0,1,0,0,208,194,32,0,0,0,0,0,88,249,14,0,0,0,0,0,53,54,50,72,20,0,0,0,224,0,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,201,34,0,216,117,35,0,0,0,0,0,53,54,50,72,34,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,249,14,0,96,146,8,0,92,29,0,0,0,0,0,0,222,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,36,6,0,0,0,0,0,0,0,0,0,0,24,0,0,0,200,5,0,0,228,0,0,0,0,0,0,0,96,57,30,0,232,79,34,0,0,0,0,0,0,0,0,0,2,80,1,0,28,0,0,0,0,0,0,0,65,0,0,0,0,0,0,0,0,250,14,0,0,0,0,0,28,0,0,0,230,4,0,0,62,1,0,0,108,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,207,31,0,120,187,31,0,0,0,0,0,184,207,31,0,0,0,0,0,28,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,128,1,0,2,0,3,0,32,128,160,0,0,0,0,3,3,3,3,7,7,7,7,11,11,11,11,15,15,15,15,3,7,11,15,3,7,11,15,3,7,11,15,3,7,11,15,128,59,30,0,168,80,34,0,0,1,0,0,232,195,32,0,0,0,0,0,8,2,15,0,0,0,0,0,28,0,0,0,20,0,0,0,34,6,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,240,34,0,216,177,34,0,0,0,0,0,28,0,0,0,34,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,2,15,0,128,146,8,0,48,189,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,10,0,0,0,0,0,0,0,0,0,0,206,2,0,0,186,6,0,0,86,0,0,0,0,0,0,0,71,114,97,121,0,52,50,48,0,0,52,50,50,0,0,52,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,29,30,31,32,32,33,34,34,35,35,36,36,37,37,37,38,38,38,39,39,39,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,35,36,37,38,38,39,40,40,41,41,42,42,43,43,43,44,44,44,45,45,45,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,41,42,43,44,44,45,46,46,47,47,48,48,49,49,49,50,50,50,51,51,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,47,48,49,50,50,51,52,52,53,53,54,54,55,55,55,56,56,56,57,57,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,53,54,55,56,56,57,58,58,59,59,60,60,61,61,61,62,62,62,63,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,59,60,61,62,62,63,64,64,65,65,66,66,67,67,67,68,68,68,69,69,69,69,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,65,66,67,68,68,69,70,70,71,71,72,72,73,73,73,74,74,74,75,75,75,75,4,1,255,255,0,0,0,0,5,255,2,255,6,0,0,0,255,0,9,255,255,255,255,255,0,0,0,0,0,0,0,0,0,255,10,0,255,255,255,0,255,11,0,0,0,0,0,0,9,8,7,7,6,6,6,6,5,5,5,5,5,5,5,5,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1200688);
/* memory initializer */ allocate([80,121,29,0,48,114,29,0,0,0,0,0,20,0,0,0,0,32,0,0,0,0,0,0,208,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,5,15,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,216,230,35,0,152,236,28,0,0,0,0,0,20,0,0,0,43,0,0,0,0,0,0,0,192,121,18,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,4,0,0,0,0,0,0,0,0,0,0,68,1,0,0,164,9,0,0,164,0,0,0,0,0,0,0,208,234,28,0,32,228,35,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,4,0,0,0,0,0,0,0,0,0,0,68,1,0,0,164,9,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,1,1,0,0,0,1,1,1,1,1,0,0,0,0,0,0,1,1,0,0,0,1,1,1,1,1,0,0,0,0,0,0,1,1,102,0,0,0,58,0,0,0,24,87,18,0,184,88,18,0,32,89,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,11,0,0,0,16,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,4,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,26,32,0,72,248,31,0,184,226,31,0,200,26,32,0,0,0,0,0,5,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,3,1,5,4,4,5,4,6,6,2,4,3,4,7,6,4,6,5,6,1,6,1,10,1,7,1,8,0,0,0,1,1,2,2,3,3,4,4,4,5,5,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,12,1,1,2,3,1,1,2,3,1,0,0,0,0,0,0,0,1,3,3,3,4,6,6,6,9,0,0,0,0,0,0,0,1,3,2,5,3,4,3,3,3,7,6,5,4,4,3,2,2,5,4,5,1,0,0,0,2,12,14,15,0,0,0,0,1,4,4,6,5,8,8,7,3,7,7,9,6,9,9,9,3,7,7,8,9,0,0,0,11,13,13,13,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,128,0,96,0,176,0,144,0,96,1,32,1,192,2,64,2,128,5,128,4,0,0,0,0,0,0,0,0,200,162,29,0,24,131,29,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,184,253,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,8,15,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,61,30,0,24,81,34,0,0,1,0,0,0,0,0,0,0,0,0,0,248,7,15,0,0,0,0,0,5,0,0,0,20,0,0,0,42,2,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,61,29,0,152,236,28,0,0,0,0,0,5,0,0,0,43,0,0,0,0,0,0,0,192,121,18,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,4,0,0,0,0,0,0,0,0,0,0,68,1,0,0,164,9,0,0,164,0,0,0,0,0,0,0,0,1,2,3,4,5,6,6,7,8,9,9,10,10,11,11,12,12,12,13,13,13,14,14,14,14,14,15,15,15,15,15,3,4,5,5,4,5,9,4,3,5,7,4,2,6,11,4,2,5,3,6,5,4,10,4,4,4,8,4,6,4,3,2,64,0,0,0,64,0,0,0,96,8,15,0,104,9,15,0,168,9,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,3,1,4,3,6,5,7,4,7,3,7,11,9,10,9,9,9,17,10,16,10,15,10,14,10,13,10,12,10,0,0,0,0,0,0,8,121,32,0,88,97,32,0,120,77,32,0,8,121,32,0,0,0,0,0,4,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,0,0,2,0,0,0,3,0,8,0,0,0,8,0,2,0,8,0,3,0,8,0,128,0,8,0,130,0,8,0,131,0,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,4,7,1,5,9,8,10,3,2,6,0,0,0,0,0,0,1,3,2,3,2,3,2,7,6,11,10,9,8,7,6,23,22,21,20,19,18,35,34,33,32,31,30,29,28,27,26,25,24,15,1,0,0,0,0,0,1,3,3,4,4,5,5,7,7,8,8,8,8,8,8,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,16,0,0,0,0,0,208,234,34,0,0,121,35,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,8,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,10,15,0,0,0,0,0,112,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,104,61,30,0,48,81,34,0,0,1,0,0,104,61,30,0,0,0,0,0,104,10,15,0,0,0,0,0,4,0,0,0,20,0,0,0,180,1,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,237,34,0,72,121,35,0,0,0,0,0,4,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,112,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,4,0,0,0,0,0,0,0,0,0,0,104,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,5,9,5,13,6,13,4,23,7,19,7,31,8,12,4,22,7,18,7,30,8,19,5,27,8,23,8,19,8,11,4,21,7,17,7,29,8,17,5,25,8,21,8,17,8,15,6,15,8,13,8,3,9,15,5,11,8,7,8,7,9,10,4,20,7,16,7,28,8,14,6,14,8,12,8,2,9,16,5,24,8,20,8,16,8,14,5,10,8,6,8,6,9,18,5,26,8,22,8,18,8,13,5,9,8,5,8,5,9,12,5,8,8,4,8,4,9,7,3,10,5,8,5,12,6,0,0,64,63,30,0,224,81,34,0,0,0,0,0,64,63,30,0,0,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,0,0,0,48,5,0,0,8,2,0,0,244,4,0,0,166,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,65,30,0,176,82,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,76,2,0,0,196,3,0,0,190,1,0,0,0,0,0,0,34,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,33,0,96,53,32,0,1,0,0,0,30,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,10,0,0,0,0,0,0,0,0,0,0,248,2,0,0,0,0,0,0,58,0,0,0,0,0,0,0,205,12,205,44,51,83,255,127,228,255,236,255,244,255,252,255,4,0,12,0,20,0,28,0,200,255,216,255,232,255,248,255,8,0,24,0,40,0,56,0,172,255,196,255,220,255,244,255,12,0,36,0,60,0,84,0,144,255,176,255,208,255,240,255,16,0,48,0,80,0,112,0,116,255,156,255,196,255,236,255,20,0,60,0,100,0,140,0,88,255,136,255,184,255,232,255,24,0,72,0,120,0,168,0,60,255,116,255,172,255,228,255,28,0,84,0,140,0,196,0,32,255,96,255,160,255,224,255,32,0,96,0,160,0,224,0,4,255,76,255,148,255,220,255,36,0,108,0,180,0,252,0,232,254,56,255,136,255,216,255,40,0,120,0,200,0,24,1,204,254,36,255,124,255,212,255,44,0,132,0,220,0,52,1,176,254,16,255,112,255,208,255,48,0,144,0,240,0,80,1,148,254,252,254,100,255,204,255,52,0,156,0,4,1,108,1,120,254,232,254,88,255,200,255,56,0,168,0,24,1,136,1,92,254,212,254,76,255,196,255,60,0,180,0,44,1,164,1,64,254,192,254,64,255,192,255,64,0,192,0,64,1,192,1,8,254,152,254,40,255,184,255,72,0,216,0,104,1,248,1,208,253,112,254,16,255,176,255,80,0,240,0,144,1,48,2,152,253,72,254,248,254,168,255,88,0,8,1,184,1,104,2,96,253,32,254,224,254,160,255,96,0,32,1,224,1,160,2,40,253,248,253,200,254,152,255,104,0,56,1,8,2,216,2,240,252,208,253,176,254,144,255,112,0,80,1,48,2,16,3,184,252,168,253,152,254,136,255,120,0,104,1,88,2,72,3,128,252,128,253,128,254,128,255,128,0,128,1,128,2,128,3,16,252,48,253,80,254,112,255,144,0,176,1,208,2,240,3,160,251,224,252,32,254,96,255,160,0,224,1,32,3,96,4,48,251,144,252,240,253,80,255,176,0,16,2,112,3,208,4,192,250,64,252,192,253,64,255,192,0,64,2,192,3,64,5,80,250,240,251,144,253,48,255,208,0,112,2,16,4,176,5,224,249,160,251,96,253,32,255,224,0,160,2,96,4,32,6,112,249,80,251,48,253,16,255,240,0,208,2,176,4,144,6,0,249,0,251,0,253,0,255,0,1,0,3,0,5,0,7,32,248,96,250,160,252,224,254,32,1,96,3,160,5,224,7,64,247,192,249,64,252,192,254,64,1,192,3,64,6,192,8,96,246,32,249,224,251,160,254,96,1,32,4,224,6,160,9,128,245,128,248,128,251,128,254,128,1,128,4,128,7,128,10,160,244,224,247,32,251,96,254,160,1,224,4,32,8,96,11,192,243,64,247,192,250,64,254,192,1,64,5,192,8,64,12,224,242,160,246,96,250,32,254,224,1,160,5,96,9,32,13,0,242,0,246,0,250,0,254,0,2,0,6,0,10,0,14,64,240,192,244,64,249,192,253,64,2,192,6,64,11,192,15,128,238,128,243,128,248,128,253,128,2,128,7,128,12,128,17,192,236,64,242,192,247,64,253,192,2,64,8,192,13,64,19,0,235,0,241,0,247,0,253,0,3,0,9,0,15,0,21,64,233,192,239,64,246,192,252,64,3,192,9,64,16,192,22,128,231,128,238,128,245,128,252,128,3,128,10,128,17,128,24,192,229,64,237,192,244,64,252,192,3,64,11,192,18,64,26,0,228,0,236,0,244,0,252,0,4,0,12,0,20,0,28,129,224,129,233,128,242,128,251,128,4,128,13,128,22,128,31,1,221,1,231,0,241,0,251,0,5,0,15,0,25,0,35,129,217,129,228,128,239,128,250,128,5,128,16,128,27,128,38,1,214,1,226,0,238,0,250,0,6,0,18,0,30,0,42,129,210,129,223,128,236,128,249,128,6,128,19,128,32,128,45,1,207,1,221,0,235,0,249,0,7,0,21,0,35,0,49,129,203,129,218,128,233,128,248,128,7,128,22,128,37,128,52,1,200,1,216,0,232,0,248,0,8,0,24,0,40,0,56,1,193,1,211,0,229,0,247,0,9,0,27,255,44,255,62,1,186,1,206,0,226,0,246,0,10,0,30,255,49,255,69,1,179,1,201,0,223,0,245,0,11,0,33,255,54,255,76,1,172,1,196,0,220,0,244,0,12,0,36,255,59,255,83,1,165,1,191,0,217,0,243,0,13,0,39,255,64,255,90,1,158,1,186,0,214,0,242,0,14,0,42,255,69,255,97,1,151,1,181,0,211,0,241,0,15,0,45,255,74,255,104,1,144,1,176,0,208,0,240,0,16,0,48,255,79,255,111,160,65,30,0,0,83,34,0,0,1,0,0,160,65,30,0,0,0,0,0,200,11,15,0,0,0,0,0,18,80,1,0,8,0,0,0,0,0,0,0,42,6,0,0,66,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,239,34,0,88,121,35,0,1,0,0,0,18,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,10,0,0,0,0,0,0,0,0,0,0,248,2,0,0,0,0,0,0,58,0,0,0,0,0,0,0,112,99,27,0,112,99,27,0,112,99,27,0,112,99,27,0,112,99,27,0,112,99,27,0,112,99,27,0,160,98,27,0,112,99,27,0,112,99,27,0,212,98,27,0,108,98,27,0,112,99,27,0,8,99,27,0,108,98,27,0,108,98,27,0,60,99,27,0,108,98,27,0,108,98,27,0,108,98,27,0,108,98,27,0,108,98,27,0,108,98,27,0,156,97,27,0,108,98,27,0,108,98,27,0,208,97,27,0,104,97,27,0,108,98,27,0,4,98,27,0,104,97,27,0,104,97,27,0,56,98,27,0,104,97,27,0,104,97,27,0,104,97,27,0,19,17,15,15,13,13,13,13,11,11,11,11,11,11,11,11,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,96,70,30,0,32,85,34,0,224,197,32,0,96,70,30,0,0,0,0,0,98,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,232,14,15,0,0,0,0,0,20,0,0,0,22,8,0,0,60,1,0,0,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,246,34,0,8,122,35,0,0,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,40,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,15,15,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,9,0,0,0,0,0,0,30,2,0,0,0,0,0,0,214,1,0,0,0,0,0,0,0,0,0,0,72,66,30,0,144,83,34,0,0,1,0,0,0,0,0,0,0,0,0,0,176,20,21,0,0,0,0,0,0,0,0,0,28,0,0,0,182,2,0,0,162,7,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,245,34,0,192,121,35,0,0,0,0,0,98,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,103,21,0,0,0,0,0,116,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,10,0,0,0,0,0,0,0,0,0,0,114,2,0,0,112,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,103,110,16,40,166,212,32,50,51,12,113,24,136,98,16,25,25,134,56,140,68,48,33,2,86,78,110,97,135,62,115,77,152,12,3,6,156,11,115,230,192,181,24,99,13,57,224,91,2,212,198,25,26,121,140,50,52,36,240,22,129,19,247,255,128,2,0,1,241,128,128,128,160,0,0,3,0,32,0,0,6,80,128,0,0,0,0,1,104,238,49,18,17,0,0,0,0,0,0,0,0,0,0,1,103,122,16,41,182,212,32,42,51,29,199,98,161,8,64,84,102,59,142,197,66,2,16,37,100,44,137,232,133,228,33,75,144,131,6,149,209,6,70,151,32,200,215,67,8,17,194,30,76,145,15,1,64,22,236,7,140,4,4,5,0,0,3,0,1,0,0,3,0,100,132,0,0,0,0,0,0,0,0,1,104,206,49,18,17,0,0,0,0,0,0,0,0,0,0,1,103,122,16,41,182,212,32,34,51,25,198,99,35,33,1,17,152,206,51,25,24,33,2,86,185,61,125,126,79,227,63,17,241,158,8,184,140,84,67,192,120,2,39,226,112,30,48,16,16,20,0,0,3,0,4,0,0,3,0,202,16,0,0,0,0,0,0,0,0,0,0,1,104,206,51,72,208,0,0,0,0,0,0,0,0,0,0,1,103,122,16,41,182,212,32,34,51,25,198,99,35,33,1,17,152,206,51,25,24,33,3,58,70,101,106,101,36,173,233,18,50,20,26,38,52,173,164,65,130,35,1,80,43,26,36,105,72,48,64,46,17,18,8,198,140,4,65,40,76,52,240,30,1,19,242,224,60,96,32,32,40,0,0,3,0,8,0,0,3,1,148,0,0,0,0,1,104,206,51,72,208,0,0,0,0,0,0,0,29,2,188,3,0,3,109,3,69,2,56,2,163,2,38,6,123,2,224,4,184,5,156,2,222,4,71,3,114,5,0,10,106,5,223,3,157,3,175,2,96,2,160,8,29,3,120,4,23,2,64,3,31,3,250,2,93,2,130,4,64,3,98,4,235,3,156,4,175,2,152,4,12,5,133,3,220,2,120,6,177,2,128,3,214,6,224,4,80,3,236,8,174,3,254,3,56,3,192,5,131,2,5,2,253,2,0,2,50,2,24,7,242,5,182,2,34,7,140,10,192,2,12,2,160,2,162,5,245,2,184,8,116,3,39,2,242,4,184,8,239,3,156,6,164,3,234,2,9,3,108,4,54,3,158,3,202,4,3,3,99,2,132,11,62,5,240,3,22,5,82,2,134,4,66,6,124,2,104,4,80,13,142,3,158,5,204,7,102,2,63,2,153,2,167,3,116,2,119,2,168,4,61,3,132,2,158,3,28,4,111,3,220,3,202,4,173,3,208,10,212,10,53,2,64,5,0,9,35,2,116,2,228,2,127,2,20,2,50,4,187,3,184,4,86,2,100,4,136,4,132,3,182,4,131,3,218,4,234,2,21,2,112,2,178,5,4,4,223,2,170,6,78,4,180,2,106,7,250,3,236,3,128,8,220,3,223,2,42,6,14,3,106,6,129,3,4,2,242,2,20,8,190,2,120,6,40,9,50,3,246,5,139,3,140,2,80,2,32,4,140,2,130,2,76,8,136,5,12,3,104,10,226,4,215,2,102,7,215,2,84,4,148,8,145,2,213,3,232,18,152,3,168,6,128,19,214,4,215,3,116,9,141,3,70,4,200,10,167,3,8,4,240,10,100,2,85,3,252,11,64,3,62,2,11,2,4,7,155,3,210,2,124,7,102,5,202,4,6,6,160,3,246,2,245,2,72,2,0,2,110,4,65,2,103,2,252,4,186,2,62,2,8,10,52,9,225,3,168,10,184,13,27,2,122,3,145,3,182,2,160,3,64,4,37,3,88,2,80,5,112,8,183,3,56,12,48,3,182,3,78,2,187,3,79,3,43,3,70,4,115,3,44,2,24,5,120,3,92,2,95,3,146,4,87,3,255,3,229,3,8,4,164,3,204,4,0,5,115,2,52,2,61,2,108,3,132,3,168,5,6,4,89,3,0,7,14,5,185,3,222,6,76,6,86,3,178,6,66,4,142,4,119,2,34,5,178,4,239,2,200,5,137,3,27,3,146,6,248,3,56,2,214,5,154,4,215,3,110,3,101,2,14,2,192,6,166,5,11,3,88,8,68,5,6,3,182,3,137,2,171,3,156,4,191,2,131,3,212,4,15,2,134,4,170,5,135,2,204,3,2,5,135,2,195,2,180,5,151,2,132,2,78,6,60,2,66,2,188,13,198,4,53,3,108,10,217,2,146,6,56,12,73,2,222,5,136,12,221,2,208,3,144,26,103,3,136,5,152,13,231,2,128,5,180,14,131,3,146,4,188,14,120,2,107,3,252,15,220,2,126,2,40,12,241,2,60,10,44,13,177,3,98,7,184,14,201,3,240,8,224,7,47,2,86,3,200,6,217,2,19,3,148,7,174,2,35,2,92,8,123,2,162,2,128,17,248,4,60,3,136,15,80,2,130,6,32,17,109,2,108,5,48,17,33,3,187,3,48,18,10,2,134,2,240,18,113,2,100,6,120,19,79,2,106,3,232,20,23,2,233,3,208,43,170,3,160,4,157,3,208,12,196,5,223,2,44,6,64,4,126,4,40,6,162,2,143,2,15,3,16,2,15,2,4,8,74,5,14,3,168,6,88,7,66,2,142,3,2,4,180,2,114,3,188,5,74,2,171,2,203,2,227,2,97,2,205,2,10,3,5,3,185,2,154,3,17,3,45,3,254,2,139,2,216,3,210,3,84,2,6,4,46,4,245,2,56,4,44,5,175,2,154,4,84,4,96,8,211,3,211,2,214,3,178,2,168,3,188,3,15,2,156,4,234,3,35,2,5,2,26,5,57,3,64,3,160,4,206,3,0,4,189,3,135,3,238,4,66,4,138,3,4,4,208,2,137,2,168,4,167,2,182,2,164,9,200,5,211,3,28,11,90,5,109,3,30,5,67,3,80,3,228,5,71,3,186,2,206,6,6,4,1,3,118,7,84,3,61,2,0,5,91,3,150,4,48,6,95,3,84,4,150,6,196,2,84,5,150,7,0,3,80,4,123,3,24,2,178,2,248,3,48,2,151,2,124,8,102,3,68,5,100,9,231,3,146,4,98,7,198,3,121,3,68,8,144,3,9,3,248,8,252,3,202,2,8,19,52,7,164,3,88,9,10,3,161,3,44,10,4,3,232,2,204,10,189,3,210,2,200,22,252,5,216,3,140,8,7,2,240,4,28,9,20,2,154,3,200,19,227,3,108,9,148,10,59,2,106,3,104,9,33,2,154,2,152,19,60,4,107,3,0,21,215,3,172,4,160,21,211,3,218,2,224,20,122,2,208,6,56,22,194,2,68,5,24,23,209,3,166,4,184,23,137,3,251,2,160,23,70,2,246,5,192,46,245,3,24,7,64,50,169,3,108,7,16,49,62,4,230,3,206,7,172,2,92,7,200,9,121,2,200,7,228,4,55,2,67,3,198,5,59,2,205,3,60,10,1,3,134,5,248,10,184,3,118,4,92,11,200,2,4,4,160,11,174,2,229,2,182,5,40,2,202,2,224,12,223,3,172,5,54,6,103,2,32,2,152,13,126,4,56,3,140,12,64,3,155,3,204,12,71,3,19,2,220,13,18,3,84,3,148,14,252,2,58,2,96,22,138,3,56,10,128,24,36,3,204,8,24,12,23,2,108,3,156,12,86,2,137,2,136,25,247,2,156,5,248,25,225,3,78,3,208,26,55,2,186,4,192,54,244,3,22,5,80,13,36,2,74,4,248,27,240,3,206,6,224,27,232,3,158,4,56,29,8,4,68,3,24,29,100,2,16,6,64,30,102,2,48,3,192,32,9,3,158,5,80,34,182,2,18,3,114,3,228,5,44,4,85,2,69,3,254,2,246,4,186,3,128,5,35,3,38,2,30,3,118,5,28,5,30,3,56,7,254,5,226,2,202,3,163,2,96,2,240,4,194,2,172,2,180,6,255,2,102,4,60,8,253,2,124,5,188,8,156,3,235,3,168,9,24,4,99,2,231,3,174,3,195,3,70,4,89,3,167,3,120,11,158,3,114,4,142,7,234,2,39,2,8,13,121,2,226,6,180,14,189,2,174,5,98,7,52,2,124,2,0,16,102,4,25,3,96,15,44,2,116,4,96,15,28,2,228,2,120,16,252,2,106,3,32,33,48,5,246,3,136,8,3,2,18,4,80,17,166,3,64,5,176,18,177,3,88,4,152,19,38,4,221,2,0,36,252,3,236,7,240,38,156,3,164,4,48,21,141,3,182,4,112,25,232,2,62,4,15,15,15,15,15,16,14,15,14,14,14,14,14,14,14,14,14,13,14,14,13,14,13,14,13,13,13,14,13,13,14,13,13,13,13,13,14,13,12,12,13,13,13,12,13,13,13,13,13,12,13,13,12,12,13,13,13,13,14,14,13,13,13,13,13,13,13,12,12,12,13,13,12,12,12,13,12,12,12,12,12,12,12,11,12,12,12,12,12,12,12,12,12,11,12,12,12,12,12,12,12,12,12,13,13,13,13,14,13,13,13,13,13,13,13,12,12,12,12,13,13,13,13,13,13,13,13,14,13,12,12,11,12,12,11,11,11,11,11,11,11,11,11,11,12,11,11,11,11,11,11,11,11,11,12,12,11,11,11,11,12,12,12,12,11,11,12,12,12,12,12,13,12,12,12,13,12,12,13,12,12,13,13,13,13,13,13,13,13,14,14,14,12,12,11,11,12,12,12,12,11,12,11,12,12,12,12,12,13,13,12,12,13,13,13,14,12,13,13,13,13,13,13,13,11,10,11,10,11,11,10,10,11,11,11,11,10,9,11,10,12,12,11,12,12,12,12,13,11,12,12,12,13,13,12,12,0,0,162,123,53,111,153,92,130,70,234,47,129,27,57,11,0,0,195,249,157,247,56,248,44,250,91,252,28,254,68,255,0,0,171,124,252,114,225,99,196,80,102,59,167,37,87,17,0,0,194,242,53,234,107,230,242,230,240,234,67,241,174,248,0,0,59,6,167,10,231,12,247,12,34,11,238,7,255,3,0,0,137,252,9,250,188,248,172,248,178,249,130,251,189,253,0,0,245,1,91,3,17,4,20,4,124,3,119,2,59,1,0,0,246,254,59,254,225,253,230,253,57,254,195,254,100,255,0,0,130,0,218,0,2,1,253,0,212,0,147,0,72,0,0,0,197,255,155,255,134,255,133,255,150,255,179,255,216,255,0,71,30,0,136,85,34,0,0,1,0,0,0,71,30,0,0,0,0,0,192,224,15,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,220,3,0,0,174,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,247,34,0,64,122,35,0,1,0,0,0,54,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,10,0,0,0,0,0,0,0,0,0,0,162,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,221,32,0,136,193,32,0,128,169,32,0,16,145,32,0,53,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,248,34,0,88,122,35,0,1,0,0,0,53,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,2,0,0,0,0,0,0,84,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,74,30,0,208,85,34,0,0,1,0,0,104,198,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,7,0,0,40,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,248,34,0,88,122,35,0,1,0,0,0,53,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,225,15,0,0,0,0,0,220,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,72,33,0,136,20,33,0,72,248,32,0,16,72,33,0,28,16,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,239,255,239,255,239,255,239,255,227,243,78,245,184,246,216,247,175,248,103,249,1,250,137,250,1,251,110,251,208,251,42,252,125,252,202,252,18,253,86,253,150,253,210,253,11,254,65,254,116,254,165,254,212,254,2,255,45,255,86,255,126,255,165,255,29,12,178,10,72,9,40,8,81,7,153,6,255,5,119,5,255,4,146,4,48,4,214,3,131,3,54,3,238,2,170,2,106,2,46,2,245,1,191,1,140,1,91,1,44,1,254,0,211,0,170,0,130,0,91,0,54,0,17,0,202,255,239,255,0,0,3,246,180,249,159,251,238,252,238,253,189,254,106,255,253,9,76,6,97,4,18,3,18,2,67,1,150,0,0,0,98,252,54,255,158,3,202,0,96,75,30,0,224,85,34,0,0,1,0,0,120,198,32,0,0,0,0,0,0,0,0,0,0,0,0,0,28,16,1,0,0,0,0,0,0,0,0,0,146,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,251,34,0,248,122,35,0,0,0,0,0,77,50,71,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,1,0,0,0,0,0,0,0,0,0,0,6,0,0,0,142,3,0,0,0,0,0,0,0,0,0,0,200,252,34,0,8,123,35,0,0,0,0,0,131,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,226,15,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,1,0,0,0,0,0,0,0,0,0,0,134,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,75,30,0,16,86,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,58,6,0,0,36,3,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,253,34,0,40,123,35,0,0,0,0,0,77,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,9,0,0,0,0,0,0,0,0,0,0,26,2,0,0,144,10,0,0,0,0,0,0,0,0,0,0,200,174,32,0,24,172,31,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,40,248,15,0,0,0,0,0,12,0,0,0,94,1,0,0,70,2,0,0,168,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,77,30,0,248,86,34,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,6,0,0,46,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,237,35,0,240,168,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,230,0,0,0,116,2,0,0,202,2,0,0,248,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,127,33,0,72,64,35,0,0,0,0,0,35,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,7,0,0,0,0,0,0,0,0,0,0,112,1,0,0,42,7,0,0,0,0,0,0,0,0,0,0,129,159,88,5,86,195,206,17,191,1,0,170,0,85,89,90,160,118,42,247,10,235,208,17,172,228,0,0,192,204,22,186,214,23,100,15,24,195,208,17,164,63,0,160,201,34,49,150,227,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,111,179,57,103,95,29,194,74,129,146,40,187,14,115,209,106,32,88,30,0,64,89,34,0,232,199,32,0,32,88,30,0,13,16,1,0,22,0,0,0,0,0,0,0,64,4,2,0,240,245,35,0,0,0,0,0,0,0,0,0,40,0,0,0,38,9,0,0,24,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,253,34,0,112,123,35,0,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,104,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,1,16,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,168,92,30,0,104,90,34,0,0,0,0,0,168,92,30,0,0,0,0,0,216,1,16,0,0,0,0,0,0,0,0,0,96,0,0,0,32,1,0,0,142,2,0,0,148,0,0,0,124,9,0,0,136,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,56,32,0,120,83,31,0,0,0,0,0,22,0,0,0,3,0,0,0,0,0,0,0,208,163,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,4,0,0,0,0,0,0,0,0,0,0,68,1,0,0,164,9,0,0,0,0,0,0,0,0,0,0,128,93,30,0,152,90,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,146,1,0,0,142,5,0,0,72,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,34,0,192,123,35,0,0,0,0,0,51,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,4,0,0,0,0,0,0,0,0,0,0,170,2,0,0,66,7,0,0,0,0,0,0,0,0,0,0,144,255,34,0,224,123,35,0,0,0,0,0,87,0,0,0,0,0,0,0,0,0,0,0,112,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,122,0,0,0,0,0,0,0,148,4,0,0,0,0,0,0,0,0,0,0,120,1,35,0,88,124,35,0,0,0,0,0,87,0,0,0,2,0,0,0,0,0,0,0,128,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,4,0,0,0,0,0,0,0,0,0,0,4,2,0,0,2,5,0,0,0,0,0,0,0,0,0,0,128,0,35,0,32,124,35,0,0,0,0,0,132,0,0,0,0,0,0,0,0,0,0,0,120,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,130,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,2,0,0,0,0,0,0,150,0,0,0,0,0,0,0,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,51,51,0,102,102,102,0,153,153,153,0,204,204,204,0,255,255,255,0,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,0,0,51,51,0,0,102,102,0,0,153,153,0,0,204,204,0,0,255,255,0,51,51,0,0,102,102,0,0,153,153,0,0,204,204,0,0,255,255,0,0,51,0,51,0,102,0,102,0,153,0,153,0,204,0,204,0,255,0,255,0,51,255,255,0,102,255,255,0,153,255,255,0,204,255,255,0,255,51,255,0,255,102,255,0,255,153,255,0,255,204,255,0,255,255,51,0,255,255,102,0,255,255,153,0,255,255,204,0,51,204,204,0,102,204,204,0,153,204,204,0,255,204,204,0,204,51,204,0,204,102,204,0,204,153,204,0,204,255,204,0,204,204,51,0,204,204,102,0,204,204,153,0,204,204,255,0,51,153,153,0,102,153,153,0,204,153,153,0,255,153,153,0,153,51,153,0,153,102,153,0,153,204,153,0,153,255,153,0,153,153,51,0,153,153,102,0,153,153,204,0,153,153,255,0,51,102,102,0,153,102,102,0,204,102,102,0,255,102,102,0,102,51,102,0,102,153,102,0,102,204,102,0,102,255,102,0,102,102,51,0,102,102,153,0,102,102,204,0,102,102,255,0,102,51,51,0,153,51,51,0,204,51,51,0,255,51,51,0,51,102,51,0,51,153,51,0,51,204,51,0,51,255,51,0,51,51,102,0,51,51,153,0,51,51,204,0,51,51,255,0,102,51,0,0,0,102,51,0,51,0,102,0,51,102,0,0,102,0,51,0,0,51,102,0,153,102,51,0,51,153,102,0,102,51,153,0,102,153,51,0,153,51,102,0,51,102,153,0,204,153,102,0,102,204,153,0,153,102,204,0,153,204,102,0,204,102,153,0,102,153,204,0,255,204,153,0,153,255,204,0,204,153,255,0,204,255,153,0,255,153,204,0,153,204,255,0,17,17,17,0,34,34,34], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1209816);
/* memory initializer */ allocate([68,68,68,0,85,85,85,0,170,170,170,0,187,187,187,0,221,221,221,0,238,238,238,0,216,101,33,0,200,56,32,0,0,0,0,0,132,0,0,0,2,0,0,0,0,0,0,0,240,247,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,3,0,0,0,0,0,0,0,0,0,0,4,2,0,0,250,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,88,1,0,16,177,2,0,0,238,2,0,64,31,0,0,128,62,0,0,34,86,0,0,192,93,0,0,0,125,0,0,68,172,0,0,128,187,0,0,0,119,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,12,6,0,0,10,0,0,0,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,30,0,0,91,34,0,192,200,32,0,0,95,30,0,12,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,80,3,16,0,0,0,0,0,8,0,0,0,184,3,0,0,118,1,0,0,110,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,4,35,0,152,124,35,0,1,0,0,0,12,80,1,0,96,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,136,255,35,0,0,0,0,0,0,0,0,0,128,3,16,0,0,0,0,0,168,42,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,9,0,0,0,0,0,0,218,2,0,0,0,0,0,0,254,6,0,0,0,0,0,0,0,0,0,0,184,95,30,0,80,91,34,0,0,1,0,0,184,95,30,0,0,0,0,0,0,0,0,0,0,0,0,0,12,80,1,0,0,0,0,0,134,1,0,0,80,2,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,6,35,0,208,124,35,0,1,0,0,0,12,80,1,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,102,1,0,0,212,0,0,0,0,0,0,0,0,0,0,0,144,92,29,0,5,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,64,2,0,0,128,4,0,0,0,9,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,240,96,30,0,232,91,34,0,0,0,0,0,112,201,32,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,210,5,0,0,94,0,0,0,26,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,99,30,0,208,92,34,0,0,0,0,0,144,201,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,168,3,0,0,212,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,101,30,0,14,0,0,0,0,0,0,0,58,0,0,0,108,0,0,0,198,1,0,0,66,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,4,0,0,0,0,0,0,0,0,0,0,16,0,0,0,200,79,16,0,0,0,0,0,124,1,0,0,0,0,0,0,128,9,35,0,128,125,35,0,0,0,0,0,176,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,6,0,0,0,0,0,0,0,0,0,0,78,1,0,0,64,3,0,0,0,0,0,0,0,0,0,0,224,9,35,0,168,125,35,0,1,0,0,0,83,87,70,70,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,5,0,0,0,0,0,0,0,0,0,0,214,2,0,0,92,9,0,0,0,0,0,0,0,0,0,0,152,95,33,0,16,50,32,0,0,0,0,0,68,0,0,0,0,16,0,64,0,0,0,0,56,247,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,38,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,0,0,0,0,152,1,0,0,0,0,0,0,8,1,0,0,0,0,0,0,0,0,0,0,168,95,33,0,40,50,32,0,0,0,0,0,68,0,0,0,3,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,38,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,10,0,0,0,0,0,0,0,0,0,0,62,2,0,0,8,0,0,0,0,0,0,0,0,0,0,0,224,10,35,0,80,126,35,0,0,0,0,0,34,0,0,0,32,32,0,0,0,0,0,0,176,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,91,16,0,0,0,0,0,136,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,91,16,0,0,0,0,0,62,8,0,0,0,0,0,0,204,1,0,0,0,0,0,0,230,3,0,0,0,0,0,0,0,0,0,0,80,12,35,0,104,126,35,0,0,0,0,0,34,0,0,0,2,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,3,0,0,0,0,0,0,0,0,0,0,210,2,0,0,88,2,0,0,0,0,0,0,0,0,0,0,24,103,30,0,224,93,34,0,0,0,0,0,232,201,32,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,214,1,0,0,110,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,104,30,0,104,94,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,5,0,0,130,4,0,0,216,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,105,30,0,176,94,34,0,0,0,0,0,248,105,30,0,0,80,1,0,1,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,80,16,0,0,158,7,0,0,72,3,0,0,22,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,106,30,0,40,95,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,16,0,0,122,1,0,0,210,2,0,0,100,3,0,0,54,2,0,0,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,3,4,8,9,13,14,18,19,23,24,28,29,33,34,38,39,43,44,48,49,53,54,58,59,63,64,68,69,73,74,78,79,0,2,5,4,12,10,7,9,25,24,20,22,14,15,19,17,36,31,21,26,1,6,16,11,27,29,32,30,39,37,34,35,1,3,8,6,18,16,11,13,38,36,31,33,21,23,28,26,216,99,32,0,216,79,32,0,128,38,32,0,216,99,32,0,2,80,1,0,28,0,0,0,0,0,0,0,64,0,1,0,56,248,35,0,184,35,20,0,0,0,0,0,128,0,0,0,214,4,0,0,184,2,0,0,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,17,35,0,232,126,35,0,0,0,0,0,82,88,69,48,2,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,38,20,0,0,0,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,1,0,0,240,3,0,0,0,0,0,0,0,0,0,0,152,17,35,0,248,126,35,0,1,0,0,0,99,118,101,115,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,17,35,0,32,127,35,0,0,0,0,0,48,51,49,69,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,7,0,0,0,0,0,0,0,0,0,0,56,2,0,0,124,4,0,0,0,0,0,0,0,0,0,0,48,18,35,0,48,127,35,0,0,0,0,0,116,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,0,0,0,0,0,0,0,0,0,0,0,12,1,0,0,28,3,0,0,0,0,0,0,0,0,0,0,128,107,30,0,112,95,34,0,0,1,0,0,168,202,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,8,0,0,44,10,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,0,25,0,32,0,41,0,51,0,65,0,81,0,103,0,129,0,163,0,205,0,3,1,70,1,154,1,4,2,138,2,51,3,7,4,18,5,98,6,9,8,30,10,189,12,9,16,48,20,107,25,0,32,73,40,183,50,217,63,248,124,33,0,136,63,35,0,1,0,0,0,56,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,5,0,0,0,0,0,0,0,0,0,0,24,1,0,0,32,2,0,0,0,0,0,0,0,0,0,0,168,56,33,0,176,15,32,0,1,0,0,0,55,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,5,0,0,0,0,0,0,0,0,0,0,24,1,0,0,32,2,0,0,0,0,0,0,0,0,0,0,24,125,33,0,176,63,35,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,1,0,0,0,0,0,0,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,170,0,0,255,0,170,0,255,170,170,0,255,0,0,170,255,170,0,170,255,0,170,170,255,170,170,170,255,85,0,0,255,255,0,0,255,85,170,0,255,255,170,0,255,85,0,170,255,255,0,170,255,85,170,170,255,255,170,170,255,0,85,0,255,170,85,0,255,0,255,0,255,170,255,0,255,0,85,170,255,170,85,170,255,0,255,170,255,170,255,170,255,85,85,0,255,255,85,0,255,85,255,0,255,255,255,0,255,85,85,170,255,255,85,170,255,85,255,170,255,255,255,170,255,0,0,85,255,170,0,85,255,0,170,85,255,170,170,85,255,0,0,255,255,170,0,255,255,0,170,255,255,170,170,255,255,85,0,85,255,255,0,85,255,85,170,85,255,255,170,85,255,85,0,255,255,255,0,255,255,85,170,255,255,255,170,255,255,0,85,85,255,170,85,85,255,0,255,85,255,170,255,85,255,0,85,255,255,170,85,255,255,0,255,255,255,170,255,255,255,85,85,85,255,255,85,85,255,85,255,85,255,255,255,85,255,85,85,255,255,255,85,255,255,85,255,255,255,255,255,255,255,184,18,35,0,80,127,35,0,0,0,0,0,123,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,8,0,0,0,0,0,0,0,0,0,0,162,0,0,0,36,5,0,0,0,0,0,0,0,0,0,0,248,19,35,0,112,127,35,0,0,0,0,0,121,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,9,0,0,0,0,0,0,0,0,0,0,146,1,0,0,4,2,0,0,0,0,0,0,0,0,0,0,136,20,35,0,168,127,35,0,0,0,0,0,122,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,21,35,0,224,127,35,0,0,0,0,0,130,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,222,1,0,0,58,10,0,0,0,0,0,0,0,0,0,0,72,21,35,0,0,128,35,0,0,0,0,0,119,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,8,0,0,0,0,0,0,0,0,0,0,56,1,0,0,144,6,0,0,0,0,0,0,0,0,0,0,128,112,116,63,165,102,105,63,103,220,94,63,165,102,105,63,2,204,84,63,0,3,66,63,103,220,94,63,0,3,66,63,163,229,40,63,2,204,84,63,133,226,48,63,140,8,19,63,245,47,75,63,24,69,33,63,0,0,0,63,0,3,66,63,140,8,19,63,103,220,222,62,30,64,57,63,188,13,6,63,0,3,194,62,133,226,48,63,128,112,244,62,163,229,168,62,163,229,40,63,103,220,222,62,140,8,147,62,24,69,33,63,245,47,203,62,0,0,128,62,185,252,25,63,30,64,185,62,103,220,94,62,140,8,19,63,163,229,168,62,0,3,66,62,195,100,12,63,185,252,153,62,163,229,40,62,188,13,6,63,195,100,140,62,140,8,19,62,0,0,0,63,0,0,128,62,0,0,0,62,128,112,244,62,165,102,105,62,103,220,222,61,165,102,233,62,2,204,84,62,0,3,194,61,103,220,222,62,0,3,66,62,163,229,168,61,2,204,212,62,133,226,48,62,140,8,147,61,245,47,203,62,24,69,33,62,0,0,128,61,0,3,194,62,140,8,19,62,103,220,94,61,30,64,185,62,188,13,6,62,0,3,66,61,133,226,176,62,128,112,244,61,163,229,40,61,163,229,168,62,103,220,222,61,140,8,19,61,24,69,161,62,245,47,203,61,0,0,0,61,185,252,153,62,30,64,185,61,103,220,222,60,140,8,147,62,163,229,168,61,0,3,194,60,195,100,140,62,185,252,153,61,163,229,168,60,188,13,134,62,195,100,140,61,140,8,147,60,0,0,128,62,0,0,128,61,0,0,128,60,128,112,116,62,165,102,105,61,103,220,94,60,165,102,105,62,2,204,84,61,0,3,66,60,32,193,33,0,192,157,33,0,104,129,33,0,32,193,33,0,41,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,149,1,0,8,149,1,0,72,148,1,0,200,146,1,0,200,140,1,0,200,128,1,0,200,104,1,0,0,1,2,3,4,5,6,7,8,8,8,8,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,17,17,17,17,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,19,171,234,110,251,73,210,205,236,137,200,50,230,33,196,12,227,8,194,131,225,2,193,193,224,129,192,96,224,64,192,48,224,32,192,24,224,0,0,0,0,85,213,183,237,37,201,102,230,68,196,25,227,17,194,134,225,4,193,194,224,129,192,96,224,64,192,48,224,32,192,24,224,16,192,12,224,0,0,0,0,73,18,137,8,33,4,8,2,2,1,129,0,64,0,32,0,16,0,8,0,2,0,0,0,1,0,0,0,0,0,1,0,0,0,0,3,1,0,0,0,2,0,1,0,0,0,3,3,2,0,0,2,0,0,2,0,0,2,0,3,2,0,0,3,2,0,2,0,0,3,3,3,2,0,1,0,0,0,2,0,2,0,0,3,2,0,2,0,2,0,2,0,2,0,3,3,2,0,3,2,0,0,2,0,3,2,0,3,2,0,3,3,2,0,2,0,3,3,3,3,3,1,0,0,0,0,3,1,0,0,0,3,3,2,0,0,2,0,3,2,0,0,3,3,3,2,0,2,0,0,3,2,0,2,0,3,3,2,0,3,2,0,3,2,0,3,3,3,3,3,1,0,0,0,3,3,2,0,0,3,3,3,2,0,2,0,3,3,2,0,3,3,3,3,3,2,0,0,3,3,3,2,0,3,3,3,3,3,2,0,3,3,3,3,3,3,136,24,35,0,72,128,35,0,1,0,0,0,41,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,36,0,56,122,19,0,0,0,0,0,240,132,20,0,0,0,0,0,160,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,162,28,0,0,0,0,0,116,10,0,0,0,0,0,0,10,2,0,0,0,0,0,0,174,5,0,0,0,0,0,0,0,0,0,0,88,126,33,0,72,75,32,0,0,1,0,0,88,126,33,0,0,0,0,0,0,0,0,0,0,0,0,0,41,80,1,0,0,0,0,0,114,4,0,0,138,1,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,1,1,1,1,0,0,0,0,0,0,40,54,33,0,96,13,32,0,1,0,0,0,41,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,246,35,0,0,0,0,0,0,0,0,0,32,133,20,0,0,0,0,0,32,211,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,1,0,0,0,0,0,0,0,0,0,0,138,0,0,0,160,8,0,0,0,0,0,0,0,0,0,0,0,2,3,4,5,7,8,9,3,4,5,6,7,8,9,10,11,12,14,16,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,109,30,0,136,96,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,0,0,176,8,0,0,194,10,0,0,24,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,111,30,0,200,96,34,0,0,0,0,0,72,203,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,90,8,0,0,46,9,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,25,35,0,160,128,35,0,0,0,0,0,157,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,114,30,0,136,97,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,198,2,0,0,152,10,0,0,180,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,27,35,0,176,128,35,0,0,0,0,0,99,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,7,0,0,0,0,0,0,0,0,0,0,68,2,0,0,62,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,27,35,0,208,128,35,0,0,0,0,0,25,0,0,0,0,32,0,0,0,0,0,0,72,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,94,7,0,0,0,0,0,0,0,0,0,0,176,29,35,0,80,129,35,0,0,0,0,0,25,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,9,0,0,0,0,0,0,0,0,0,0,100,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,28,35,0,16,129,35,0,3,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,4,0,0,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,29,35,0,56,129,35,0,3,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,135,20,0,0,0,0,0,88,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,3,0,0,0,0,0,0,0,0,0,0,140,2,0,0,10,7,0,0,0,0,0,0,0,0,0,0,208,30,35,0,168,129,35,0,3,0,0,0,1,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,30,35,0,136,129,35,0,3,0,0,0,1,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,5,0,0,0,0,0,0,0,0,0,0,106,2,0,0,106,7,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,1,0,0,3,4,0,0,5,6,2,1,1,0,0,0,7,8,9,10,3,4,2,1,1,1,0,0,0,0,0,0,11,12,13,14,5,6,3,4,2,2,1,0,0,0,0,0,5,3,3,2,1,1,1,0,1,6,4,3,1,1,1,2,3,4,5,7,8,9,10,7,8,4,3,2,2,2,2,2,1,1,1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,1,2,1,3,4,1,2,5,6,1,1,7,8,1,1,2,3,4,9,10,11,1,1,1,1,2,2,3,5,6,7,12,13,14,15,16,17,1,1,1,1,2,2,3,3,4,5,8,18,19,20,21,22,3,4,5,6,9,10,11,0,0,3,4,6,12,13,14,0,0,0,0,2,2,2,2,3,3,5,7,7,8,9,10,11,15,16,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,0,0,0,0,0,0,0,0,2,3,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,4,0,0,0,0,0,0,0,0,0,2,0,7,0,8,0,9,0,20,0,21,0,22,0,23,0,48,0,49,0,50,0,51,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,224,0,225,0,226,0,227,0,228,0,229,0,230,0,231,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,239,0,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,224,3,225,3,226,3,227,3,228,3,229,3,230,3,206,7,207,7,208,7,209,7,210,7,211,7,212,7,213,7,172,15,173,15,174,15,175,15,176,15,177,15,178,15,179,15,180,15,181,15,182,15,183,15,184,15,185,15,186,15,187,15,188,15,189,15,190,15,191,15,128,31,129,31,130,31,131,31,132,31,133,31,134,31,135,31,136,31,137,31,138,31,139,31,140,31,141,31,142,31,143,31,144,31,145,31,146,31,147,31,148,31,149,31,150,31,151,31,152,31,153,31,154,31,155,31,156,31,157,31,158,31,159,31,160,31,161,31,162,31,163,31,164,31,165,31,166,31,167,31,168,31,169,31,170,31,171,31,172,31,173,31,174,31,175,31,176,31,177,31,178,31,179,31,180,31,181,31,182,31,183,31,184,31,185,31,186,31,187,31,188,31,189,31,190,31,191,31,0,127,1,127,2,127,3,127,4,127,5,127,6,127,7,127,8,127,9,127,10,127,11,127,12,127,13,127,14,127,15,127,16,127,17,127,18,127,19,127,20,127,21,127,22,127,23,127,24,127,25,127,26,127,27,127,28,127,29,127,30,127,31,127,32,127,33,127,34,127,35,127,36,127,37,127,38,127,39,127,40,127,41,127,42,127,43,127,44,127,45,127,46,127,47,127,48,127,49,127,50,127,51,127,52,127,53,127,54,127,55,127,56,127,57,127,58,127,59,127,60,127,61,127,62,127,63,127,64,127,65,127,66,127,67,127,68,127,69,127,70,127,71,127,72,127,73,127,74,127,75,127,76,127,77,127,78,127,79,127,80,127,81,127,82,127,83,127,84,127,85,127,86,127,87,127,88,127,89,127,90,127,91,127,92,127,93,127,94,127,95,127,96,127,97,127,98,127,99,127,100,127,101,127,102,127,103,127,104,127,105,127,106,127,107,127,108,127,109,127,110,127,111,127,112,127,113,127,114,127,115,127,116,127,117,127,118,127,119,127,120,127,121,127,122,127,123,127,124,127,125,127,126,127,127,127,128,127,129,127,130,127,131,127,132,127,133,127,134,127,135,127,136,127,137,127,138,127,139,127,140,127,141,127,142,127,143,127,144,127,145,127,146,127,147,127,148,127,149,127,150,127,151,127,152,127,153,127,154,127,155,127,156,127,157,127,158,127,159,127,160,127,161,127,162,127,163,127,164,127,165,127,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,194,127,195,127,196,127,197,127,198,127,199,127,200,127,201,127,202,127,203,127,204,127,205,127,206,127,207,127,208,127,209,127,210,127,211,127,212,127,213,127,214,127,215,127,216,127,217,127,218,127,219,127,220,127,221,127,222,127,223,127,224,127,225,127,226,127,227,127,228,127,229,127,230,127,231,127,232,127,233,127,234,127,235,127,236,127,237,127,238,127,239,127,240,127,241,127,242,127,243,127,244,127,245,127,246,127,247,127,248,127,249,127,250,127,251,127,252,127,253,127,254,127,255,127,6,0,0,0,0,0,0,0,3,3,4,4,3,3,4,4,2,3,3,4,2,3,3,4,2,2,3,3,2,2,3,3,1,2,2,3,1,2,2,3,1,1,2,2,1,1,2,2,0,1,1,2,0,1,1,2,0,0,1,1,0,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,0,1,0,0,0,0,176,114,30,0,192,97,34,0,0,0,0,0,176,114,30,0,0,0,1,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,202,8,0,222,4,0,0,150,2,0,0,20,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,65,0,0,70,65,0,0,71,69,0,0,119,66,0,0,71,69,0,0,21,71,0,0,159,70,0,0,159,70,0,0,21,71,0,0,37,73,0,0,127,72,0,0,252,74,0,0,127,72,0,0,37,73,0,0,84,75,0,0,164,74,0,0,236,76,0,0,236,76,0,0,164,74,0,0,84,75,0,0,152,83,0,0,189,76,0,0,38,79,0,0,246,78,0,0,38,79,0,0,189,76,0,0,152,83,0,0,205,88,0,0,85,85,0,0,131,81,0,0,79,81,0,0,79,81,0,0,131,81,0,0,85,85,0,0,205,88,0,0,133,90,0,0,133,90,0,0,152,83,0,0,152,83,0,0,152,83,0,0,133,90,0,0,133,90,0,0,24,96,0,0,212,92,0,0,1,86,0,0,1,86,0,0,212,92,0,0,24,96,0,0,179,98,0,0,137,95,0,0,144,88,0,0,137,95,0,0,179,98,0,0,115,101,0,0,103,98,0,0,103,98,0,0,115,101,0,0,91,104,0,0,58,109,0,0,91,104,0,0,202,115,0,0,202,115,0,0,48,123,0,0,128,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,42,0,0,0,38,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,38,0,0,0,42,0,0,0,44,0,0,0,43,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,43,0,0,0,44,0,0,0,68,0,0,0,68,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,68,0,0,0,68,0,0,0,96,0,0,0,92,0,0,0,86,0,0,0,86,0,0,0,92,0,0,0,96,0,0,0,98,0,0,0,96,0,0,0,88,0,0,0,96,0,0,0,98,0,0,0,202,0,0,0,196,0,0,0,196,0,0,0,202,0,0,0,208,0,0,0,218,0,0,0,208,0,0,0,232,0,0,0,232,0,0,0,246,0,0,0,128,0,0,0,24,0,0,0,24,0,0,0,26,0,0,0,26,0,0,0,26,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,38,0,0,0,36,0,0,0,36,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,84,0,0,0,76,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,76,0,0,0,84,0,0,0,88,0,0,0,86,0,0,0,82,0,0,0,82,0,0,0,82,0,0,0,82,0,0,0,86,0,0,0,88,0,0,0,182,0,0,0,182,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,182,0,0,0,182,0,0,0,192,0,0,0,186,0,0,0,192,0,0,0,172,0,0,0,186,0,0,0,192,0,0,0,138,1,0,0,126,1,0,0,98,1,0,0,126,1,0,0,138,1,0,0,150,1,0,0,138,1,0,0,138,1,0,0,150,1,0,0,162,1,0,0,182,1,0,0,162,1,0,0,208,1,0,0,208,1,0,0,236,1,0,0,0,128,0,0,71,69,0,0,70,65,0,0,159,70,0,0,37,73,0,0,152,83,0,0,71,69,0,0,252,74,0,0,164,74,0,0,85,85,0,0,0,64,0,0,71,69,0,0,37,73,0,0,152,83,0,0,70,65,0,0,159,70,0,0,38,79,0,0,133,90,0,0,21,71,0,0,236,76,0,0,37,73,0,0,38,79,0,0,79,81,0,0,212,92,0,0,71,69,0,0,252,74,0,0,164,74,0,0,85,85,0,0,38,79,0,0,133,90,0,0,21,71,0,0,236,76,0,0,152,83,0,0,137,95,0,0,84,75,0,0,131,81,0,0,152,83,0,0,133,90,0,0,1,86,0,0,103,98,0,0,37,73,0,0,38,79,0,0,79,81,0,0,212,92,0,0,152,83,0,0,137,95,0,0,84,75,0,0,131,81,0,0,137,95,0,0,58,109,0,0,205,88,0,0,24,96,0,0,115,101,0,0,202,115,0,0,152,83,0,0,133,90,0,0,1,86,0,0,103,98,0,0,137,95,0,0,58,109,0,0,205,88,0,0,24,96,0,0,115,101,0,0,202,115,0,0,128,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,42,0,0,0,38,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,38,0,0,0,42,0,0,0,44,0,0,0,43,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,45,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,45,0,0,0,45,0,0,0,48,0,0,0,46,0,0,0,43,0,0,0,43,0,0,0,46,0,0,0,48,0,0,0,49,0,0,0,48,0,0,0,44,0,0,0,48,0,0,0,49,0,0,0,101,0,0,0,98,0,0,0,98,0,0,0,101,0,0,0,104,0,0,0,109,0,0,0,104,0,0,0,116,0,0,0,116,0,0,0,123,0,0,0,128,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,25,0,0,0,25,0,0,0,25,0,0,0,25,0,0,0,26,0,0,0,25,0,0,0,26,0,0,0,25,0,0,0,26,0,0,0,26,0,0,0,26,0,0,0,27,0,0,0,27,0,0,0,26,0,0,0,26,0,0,0,42,0,0,0,38,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,38,0,0,0,42,0,0,0,44,0,0,0,43,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,43,0,0,0,44,0,0,0,91,0,0,0,91,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,91,0,0,0,91,0,0,0,96,0,0,0,93,0,0,0,86,0,0,0,86,0,0,0,93,0,0,0,96,0,0,0,197,0,0,0,191,0,0,0,177,0,0,0,191,0,0,0,197,0,0,0,203,0,0,0,197,0,0,0,197,0,0,0,203,0,0,0,209,0,0,0,219,0,0,0,209,0,0,0,232,0,0,0,232,0,0,0,246,0,0,0,200,98,34,0,104,204,32,0,0,0,0,0,104,197,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,202,8,0,190,2,0,0,14,7,0,0,146,0,0,0,234,0,0,0,160,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,118,30,0,8,99,34,0,0,1,0,0,64,118,30,0,0,0,0,0,0,0,0,0,0,0,0,0,4,80,1,0,8,0,0,0,84,7,0,0,34,7,0,0,206,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,75,34,0,192,25,34,0,80,229,33,0,232,75,34,0,4,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,118,30,0,96,99,34,0,0,1,0,0,192,118,30,0,0,0,0,0,0,0,0,0,0,0,0,0,4,80,1,0,0,0,0,0,142,7,0,0,138,1,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,35,0,184,130,35,0,0,0,0,0,95,0,0,0,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1220056);
/* memory initializer */ allocate([24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,6,0,0,0,0,0,0,0,0,0,0,186,1,0,0,136,8,0,0,0,0,0,0,0,0,0,0,112,106,33,0,184,60,32,0,1,0,0,0,26,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,5,0,0,0,0,0,0,0,0,0,0,44,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,119,30,0,128,99,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,0,0,240,7,0,0,166,8,0,0,32,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,35,35,0,232,130,35,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,88,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,3,0,0,0,0,0,0,166,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,37,35,0,48,131,35,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,194,34,0,200,132,34,0,0,0,0,0,48,194,34,0,0,0,0,0,100,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,47,35,0,48,132,35,0,0,0,0,0,100,0,0,0,0,32,0,0,0,0,0,0,152,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,153,20,0,0,0,0,0,96,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,153,20,0,0,0,0,0,38,2,0,0,0,0,0,0,80,0,0,0,0,0,0,0,154,10,0,0,0,0,0,0,0,0,0,0,240,119,30,0,192,99,34,0,0,1,0,0,0,0,0,0,0,0,0,0,24,153,20,0,0,0,0,0,100,0,0,0,20,0,0,0,224,2,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,50,35,0,8,133,35,0,0,0,0,0,100,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,7,0,0,0,0,0,0,0,0,0,0,226,1,0,0,152,9,0,0,0,0,0,0,0,0,0,0,211,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,0,14,0,0,0,14,0,6,0,0,0,10,0,0,0,4,0,0,0,88,187,20,0,152,187,20,0,24,188,20,0,40,188,20,0,72,190,20,0,80,192,20,0,56,188,20,0,64,189,20,0,88,193,20,0,216,193,20,0,216,187,20,0,175,0,0,0,185,0,0,0,109,1,0,0,184,1,0,0,0,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,0,0,0,0,0,0,0,0,213,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,64,9,0,0,64,9,0,4,0,0,0,8,0,0,0,3,0,0,0,152,181,20,0,248,181,20,0,216,181,20,0,232,181,20,0,72,184,20,0,80,186,20,0,56,182,20,0,64,183,20,0,152,180,20,0,24,181,20,0,88,181,20,0,115,0,0,0,120,0,0,0,145,0,0,0,240,0,0,0,34,1,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,214,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,0,14,0,0,0,14,0,4,0,0,0,8,0,0,0,4,0,0,0,216,174,20,0,56,175,20,0,24,175,20,0,40,175,20,0,136,177,20,0,144,179,20,0,120,175,20,0,128,176,20,0,88,193,20,0,216,193,20,0,152,174,20,0,175,0,0,0,185,0,0,0,220,0,0,0,109,1,0,0,184,1,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,217,4,0,0,128,7,0,0,56,4,0,0,1,0,0,0,0,0,14,0,0,0,7,0,6,0,0,0,10,0,0,0,4,0,0,0,24,174,20,0,88,174,20,0,24,188,20,0,40,188,20,0,72,190,20,0,80,192,20,0,56,188,20,0,64,189,20,0,88,193,20,0,216,193,20,0,216,187,20,0,185,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,4,0,0,128,7,0,0,56,4,0,0,1,0,0,0,0,64,9,0,0,160,4,0,4,0,0,0,8,0,0,0,3,0,0,0,152,173,20,0,216,173,20,0,216,181,20,0,232,181,20,0,72,184,20,0,80,186,20,0,56,182,20,0,64,183,20,0,152,180,20,0,24,181,20,0,88,181,20,0,120,0,0,0,145,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,219,4,0,0,128,7,0,0,56,4,0,0,1,0,0,0,0,0,14,0,0,0,7,0,4,0,0,0,8,0,0,0,4,0,0,0,24,173,20,0,88,173,20,0,24,175,20,0,40,175,20,0,136,177,20,0,144,179,20,0,120,175,20,0,128,176,20,0,88,193,20,0,216,193,20,0,152,174,20,0,185,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,4,0,0,0,5,0,0,208,2,0,0,0,0,0,0,0,0,7,0,0,0,7,0,6,0,0,0,10,0,0,0,4,0,0,0,88,167,20,0,184,167,20,0,152,167,20,0,168,167,20,0,8,170,20,0,16,172,20,0,248,167,20,0,0,169,20,0,88,166,20,0,216,166,20,0,24,167,20,0,90,0,0,0,90,0,0,0,180,0,0,0,220,0,0,0,0,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,0,0,0,0,0,0,0,0,227,4,0,0,0,5,0,0,208,2,0,0,0,0,0,0,0,0,7,0,0,0,7,0,4,0,0,0,8,0,0,0,4,0,0,0,152,160,20,0,248,160,20,0,216,160,20,0,232,160,20,0,72,163,20,0,80,165,20,0,56,161,20,0,64,162,20,0,152,159,20,0,24,160,20,0,88,160,20,0,90,0,0,0,90,0,0,0,110,0,0,0,180,0,0,0,220,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,228,4,0,0,0,5,0,0,208,2,0,0,0,0,0,0,0,160,4,0,0,160,4,0,4,0,0,0,8,0,0,0,5,0,0,0,216,153,20,0,56,154,20,0,24,154,20,0,40,154,20,0,136,156,20,0,144,158,20,0,120,154,20,0,128,155,20,0,152,159,20,0,24,160,20,0,88,160,20,0,60,0,0,0,60,0,0,0,75,0,0,0,120,0,0,0,145,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,229,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,224,2,0,0,224,2,0,4,0,0,0,8,0,0,0,3,0,0,0,152,181,20,0,248,181,20,0,216,181,20,0,232,181,20,0,72,184,20,0,80,186,20,0,56,182,20,0,64,183,20,0,152,180,20,0,24,181,20,0,88,181,20,0,36,0,0,0,36,0,0,0,45,0,0,0,75,0,0,0,90,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,232,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,0,28,0,0,0,28,0,6,0,0,0,10,0,0,0,4,0,0,0,88,187,20,0,152,153,20,0,24,188,20,0,40,188,20,0,72,190,20,0,80,192,20,0,56,188,20,0,64,189,20,0,88,193,20,0,216,193,20,0,216,187,20,0,94,1,0,0,134,1,0,0,184,1,0,0,218,2,0,0,112,3,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,0,0,0,0,0,55,14,68,3,58,17,72,37,18,50,32,40,22,54,35,9,64,5,59,13,67,8,63,46,27,41,23,49,31,44,26,2,57,16,71,1,56,15,70,39,21,52,34,38,19,51,33,11,66,7,62,10,65,6,60,48,30,43,25,47,29,42,24,0,55,14,68,3,58,17,72,17,9,23,15,16,8,22,14,5,29,3,27,4,28,2,26,21,13,19,11,20,12,18,10,0,24,6,30,1,25,7,31,16,8,22,14,17,9,23,15,4,28,2,26,5,29,3,27,20,12,18,10,21,13,19,11,1,25,7,31,0,24,6,30,17,9,23,15,16,8,22,14,117,62,158,103,113,58,155,100,34,199,21,186,31,196,17,182,144,89,131,76,141,86,127,72,0,165,41,206,10,175,52,217,110,55,151,96,120,65,162,107,28,193,14,179,38,203,24,189,138,83,124,69,148,93,134,79,7,172,48,213,3,168,45,210,117,62,158,103,113,58,155,100,36,68,60,92,34,66,58,90,100,4,124,28,98,2,122,26,52,84,44,76,50,82,42,74,116,20,108,12,114,18,106,10,32,64,56,88,38,70,62,94,96,0,120,24,102,6,126,30,48,80,40,72,54,86,46,78,112,16,104,8,118,22,110,14,36,68,60,92,34,66,58,90,8,4,11,7,8,4,11,7,2,14,1,13,2,14,1,13,10,6,9,5,10,6,9,5,0,12,3,15,0,12,3,15,8,4,11,7,8,4,11,7,6,2,6,2,6,2,6,2,0,4,0,4,0,4,0,4,6,2,6,2,6,2,6,2,1,3,1,3,1,3,1,3,2,0,2,0,2,0,2,0,1,3,1,3,1,3,1,3,0,0,2,0,5,0,8,0,11,0,15,0,20,0,24,0,29,0,35,0,41,0,47,0,53,0,60,0,67,0,74,0,82,0,89,0,97,0,106,0,114,0,123,0,132,0,141,0,150,0,160,0,170,0,180,0,190,0,201,0,211,0,222,0,233,0,244,0,0,1,11,1,23,1,35,1,47,1,59,1,71,1,84,1,97,1,110,1,123,1,136,1,149,1,163,1,177,1,191,1,205,1,219,1,233,1,248,1,6,2,21,2,36,2,51,2,66,2,81,2,97,2,112,2,128,2,144,2,160,2,176,2,193,2,209,2,226,2,242,2,3,3,20,3,37,3,54,3,72,3,89,3,107,3,124,3,142,3,160,3,178,3,196,3,215,3,233,3,252,3,14,4,33,4,52,4,71,4,90,4,109,4,129,4,148,4,168,4,187,4,207,4,227,4,247,4,11,5,31,5,52,5,72,5,93,5,113,5,134,5,155,5,176,5,197,5,218,5,240,5,5,6,26,6,48,6,70,6,92,6,113,6,135,6,158,6,180,6,202,6,224,6,247,6,14,7,36,7,59,7,82,7,105,7,128,7,143,7,150,7,157,7,163,7,169,7,176,7,182,7,188,7,193,7,199,7,204,7,209,7,214,7,219,7,224,7,229,7,233,7,237,7,241,7,245,7,248,7,252,7,255,7,2,8,5,8,8,8,10,8,13,8,15,8,17,8,18,8,20,8,21,8,22,8,23,8,24,8,24,8,24,8,24,8,24,8,24,8,23,8,22,8,21,8,20,8,18,8,17,8,15,8,12,8,10,8,7,8,4,8,1,8,253,7,250,7,246,7,241,7,237,7,232,7,227,7,221,7,216,7,210,7,204,7,197,7,190,7,183,7,176,7,168,7,160,7,151,7,142,7,133,7,124,7,114,7,104,7,93,7,82,7,71,7,59,7,47,7,35,7,22,7,8,7,250,6,236,6,221,6,206,6,191,6,174,6,158,6,140,6,123,6,104,6,86,6,66,6,46,6,25,6,4,6,238,5,215,5,191,5,167,5,142,5,116,5,89,5,61,5,32,5,2,5,227,4,195,4,162,4,127,4,90,4,53,4,13,4,227,3,184,3,138,3,89,3,37,3,238,2,178,2,113,2,41,2,215,1,120,1,255,0,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,22,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,9,9,5,6,7,8,8,10,11,12,13,13,0,0,0,0,0,19,0,0,0,0,192,177,35,0,144,82,35,0,0,0,0,0,80,2,35,0,0,0,0,0,117,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,120,30,0,32,100,34,0,0,1,0,0,0,0,0,0,0,0,0,0,136,201,20,0,0,0,0,0,117,0,0,0,20,0,0,0,216,10,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,35,0,64,134,35,0,0,0,0,0,117,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,5,0,0,0,0,0,0,0,0,0,0,194,2,0,0,26,2,0,0,158,0,0,0,0,0,0,0,224,92,29,0,5,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,30,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,146,183,116,145,89,112,112,68,136,223,6,59,130,204,33,61,56,121,30,0,120,100,34,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,250,3,0,0,222,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,35,0,64,135,35,0,0,0,0,0,151,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,1,0,0,0,0,0,0,0,0,0,0,144,1,0,0,194,8,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,4,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,0,0,108,9,0,0,18,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,67,35,0,8,136,35,0,1,0,0,0,4,80,1,0,0,2,0,0,0,0,0,0,0,0,0,0,104,95,7,0,168,0,36,0,200,250,35,0,0,0,0,0,0,0,0,0,0,0,0,0,252,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,21,0,0,0,0,0,68,10,0,0,0,0,0,0,52,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,35,0,120,138,35,0,1,0,0,0,4,80,1,0,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,0,36,0,0,0,0,0,0,0,0,0,160,119,21,0,240,146,8,0,160,116,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,4,0,0,0,0,0,0,0,0,0,0,204,0,0,0,46,7,0,0,0,0,0,0,0,0,0,0,168,122,30,0,232,100,34,0,0,0,0,0,40,198,31,0,16,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,3,0,0,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,122,30,0,232,100,34,0,0,0,0,0,120,205,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,3,0,0,134,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,48,49,50,51,52,53,54,55,56,57,97,98,99,100,101,102,64,3,29,0,208,180,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,48,139,31,0,24,213,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,110,33,0,160,63,32,0,0,0,0,0,27,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,3,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,73,35,0,56,139,35,0,0,0,0,0,80,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,1,0,0,0,0,0,0,0,0,0,0,120,2,0,0,138,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1230308);
/* memory initializer */ allocate([1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,152,123,30,0,40,101,34,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,94,9,0,0,88,3,0,0,166,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,74,35,0,128,139,35,0,0,0,0,0,65,73,80,67,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,3,0,0,0,0,0,0,0,0,0,0,232,2,0,0,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,138,120,0,64,239,118,0,128,184,118,0,208,74,121,0,160,111,120,0,64,185,118,0,80,76,121,0,160,114,120,0,64,191,118,0,128,88,115,0,176,138,120,0,96,239,118,0,128,184,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,74,121,0,96,111,120,0,192,184,118,0,80,75,121,0,160,112,120,0,64,187,118,0,80,80,121,0,160,122,120,0,64,207,118,0,128,120,115,0,176,202,120,0,96,111,119,0,128,184,116,0,0,0,0,0,104,76,35,0,64,140,35,0,1,0,0,0,20,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,3,0,0,0,0,0,0,0,0,0,0,196,0,0,0,138,3,0,0,0,0,0,0,0,0,0,0,96,133,30,0,184,104,34,0,0,0,0,0,0,0,0,0,0,0,0,0,200,173,21,0,0,0,0,0,0,0,0,0,28,0,0,0,2,8,0,0,14,8,0,0,164,0,0,0,210,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,176,119,35,0,176,151,35,0,1,0,0,0,62,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,3,0,0,0,0,0,0,232,1,0,0,0,0,0,0,54,9,0,0,0,0,0,0,0,0,0,0,216,119,35,0,8,152,35,0,1,0,0,0,62,80,1,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,10,0,0,0,0,0,0,0,0,0,0,168,1,0,0,252,6,0,0,26,1,0,0,0,0,0,0,0,0,1,0,1,0,0,0,5,0,1,0,1,0,0,0,12,0,1,0,1,0,0,0,8,0,1,0,1,0,0,0,6,16,1,0,2,0,0,0,21,0,1,0,3,0,0,0,23,0,1,0,3,0,0,0,7,0,1,0,6,0,0,0,6,0,1,0,7,0,0,0,37,80,1,0,10,0,0,0,32,73,75,79,16,0,0,0,1,16,1,0,17,0,0,0,17,0,1,0,17,0,0,0,32,73,75,79,23,0,0,0,14,16,1,0,32,0,0,0,21,80,1,0,34,0,0,0,30,80,1,0,49,0,0,0,30,80,1,0,50,0,0,0,0,32,1,0,56,0,0,0,53,80,1,0,66,0,0,0,11,16,1,0,69,0,0,0,0,80,1,0,80,0,0,0,1,80,1,0,85,0,0,0,0,32,1,0,87,0,0,0,1,32,1,0,88,0,0,0,3,16,1,0,97,0,0,0,2,16,1,0,98,0,0,0,11,16,1,0,100,0,0,0,1,16,1,0,105,0,0,0,64,80,1,0,117,0,0,0,2,80,1,0,255,0,0,0,53,80,1,0,17,1,0,0,42,80,1,0,48,1,0,0,7,80,1,0,96,1,0,0,8,80,1,0,97,1,0,0,38,80,1,0,98,1,0,0,39,80,1,0,99,1,0,0,12,16,1,0,0,2,0,0,31,80,1,0,112,2,0,0,28,16,1,0,143,2,0,0,27,80,1,0,1,4,0,0,59,80,1,0,2,4,0,0,30,80,1,0,0,21,0,0,21,80,1,0,1,21,0,0,2,80,1,0,0,22,0,0,50,80,1,0,2,22,0,0,3,80,1,0,0,32,0,0,41,80,1,0,0,32,0,0,4,80,1,0,1,32,0,0,67,78,79,83,72,32,0,0,76,78,79,83,72,32,0,0,6,0,1,0,117,108,0,0,2,80,1,0,109,112,0,0,2,80,1,0,67,65,0,0,2,64,1,0,74,89,0,0,53,80,1,0,0,161,0,0,2,80,1,0,6,161,0,0,36,80,1,0,9,161,0,0,12,80,1,0,172,241,0,0,13,16,1,0,70,83,0,0,5,80,1,0,111,86,0,0,0,0,0,0,0,0,0,0,3,80,1,0,44,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,40,80,1,0,191,170,35,233,88,203,113,68,161,25,255,250,1,228,206,98,41,80,1,0,175,135,251,167,2,45,251,66,164,212,5,205,147,132,59,221,0,80,1,0,43,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,74,70,73,70,0,0,0,0,0,0,0,0,5,16,1,0,65,80,67,77,0,0,1,0,78,79,78,69,0,0,0,0,0,0,0,0,5,0,1,0,0,1,0,0,1,16,1,0,1,1,0,0,0,0,0,0,0,0,0,0,14,0,0,0,114,97,119,32,14,0,0,0,121,117,118,50,14,0,0,0,50,118,117,121,14,0,0,0,121,117,118,115,14,0,0,0,76,53,53,53,14,0,0,0,76,53,54,53,14,0,0,0,66,53,54,53,14,0,0,0,50,52,66,71,14,0,0,0,66,71,82,65,14,0,0,0,82,71,66,65,14,0,0,0,65,66,71,82,14,0,0,0,98,49,54,103,14,0,0,0,98,52,56,114,14,0,0,0,98,120,98,103,14,0,0,0,98,120,114,103,14,0,0,0,98,120,121,118,14,0,0,0,78,79,49,54,14,0,0,0,68,86,79,79,14,0,0,0,82,52,50,48,14,0,0,0,82,52,49,49,146,0,0,0,82,49,48,107,146,0,0,0,82,49,48,103,134,0,0,0,114,50,49,48,73,85,86,65,65,86,85,73,80,82,86,65,65,86,114,112,80,82,86,65,83,85,68,83,128,0,0,0,118,50,49,48,128,0,0,0,98,120,121,50,56,48,51,86,118,51,48,56,56,48,52,86,118,52,48,56,158,0,0,0,118,52,49,48,80,49,52,89,89,52,49,80,52,86,85,89,121,117,118,52,54,49,50,84,89,50,49,54,8,0,0,0,106,112,101,103,8,0,0,0,109,106,112,97,8,0,0,0,65,86,68,74,8,0,0,0,100,109,98,49,9,0,0,0,109,106,112,98,23,0,0,0,83,86,81,49,23,0,0,0,115,118,113,49,23,0,0,0,115,118,113,105,24,0,0,0,83,86,81,51,13,0,0,0,109,112,52,118,13,0,0,0,68,73,86,88,13,0,0,0,88,86,73,68,13,0,0,0,51,73,86,50,5,0,0,0,104,50,54,51,5,0,0,0,115,50,54,51,25,0,0,0,100,118,99,112,25,0,0,0,100,118,99,32,25,0,0,0,100,118,112,112,25,0,0,0,100,118,53,112,25,0,0,0,100,118,53,110,25,0,0,0,65,86,100,118,25,0,0,0,65,86,100,49,25,0,0,0,100,118,104,113,25,0,0,0,100,118,104,112,25,0,0,0,100,118,104,49,25,0,0,0,100,118,104,50,25,0,0,0,100,118,104,52,25,0,0,0,100,118,104,53,25,0,0,0,100,118,104,54,25,0,0,0,100,118,104,51,30,0,0,0,86,80,51,49,43,0,0,0,114,112,122,97,44,0,0,0,99,118,105,100,49,0,0,0,56,66,80,83,50,0,0,0,115,109,99,32,56,0,0,0,114,108,101,32,82,73,71,83,114,108,101,49,46,0,0,0,87,82,76,69,59,0,0,0,113,100,114,119,14,0,0,0,87,82,65,87,53,54,50,72,104,101,118,49,53,54,50,72,104,118,99,49,28,0,0,0,97,118,99,49,28,0,0,0,97,105,53,112,28,0,0,0,97,105,53,113,28,0,0,0,97,105,53,50,28,0,0,0,97,105,53,51,28,0,0,0,97,105,53,53,28,0,0,0,97,105,53,54,28,0,0,0,97,105,49,112,28,0,0,0,97,105,49,113,28,0,0,0,97,105,49,50,28,0,0,0,97,105,49,51,28,0,0,0,97,105,49,53,28,0,0,0,97,105,49,54,28,0,0,0,97,105,118,120,28,0,0,0,65,86,105,110,1,0,0,0,109,49,118,49,1,0,0,0,109,112,101,103,1,0,0,0,109,49,118,32,2,0,0,0,109,50,118,49,2,0,0,0,104,100,118,49,2,0,0,0,104,100,118,50,2,0,0,0,104,100,118,51,2,0,0,0,104,100,118,52,2,0,0,0,104,100,118,53,2,0,0,0,104,100,118,54,2,0,0,0,104,100,118,55,2,0,0,0,104,100,118,56,2,0,0,0,104,100,118,57,2,0,0,0,104,100,118,97,2,0,0,0,109,120,53,110,2,0,0,0,109,120,53,112,2,0,0,0,109,120,52,110,2,0,0,0,109,120,52,112,2,0,0,0,109,120,51,110,2,0,0,0,109,120,51,112,2,0,0,0,120,100,53,49,2,0,0,0,120,100,53,52,2,0,0,0,120,100,53,53,2,0,0,0,120,100,53,57,2,0,0,0,120,100,53,97,2,0,0,0,120,100,53,98,2,0,0,0,120,100,53,99,2,0,0,0,120,100,53,100,2,0,0,0,120,100,53,101,2,0,0,0,120,100,53,102,2,0,0,0,120,100,118,49,2,0,0,0,120,100,118,50,2,0,0,0,120,100,118,51,2,0,0,0,120,100,118,52,2,0,0,0,120,100,118,53,2,0,0,0,120,100,118,54,2,0,0,0,120,100,118,55,2,0,0,0,120,100,118,56,2,0,0,0,120,100,118,57,2,0,0,0,120,100,118,97,2,0,0,0,120,100,118,98,2,0,0,0,120,100,118,99,2,0,0,0,120,100,118,100,2,0,0,0,120,100,118,101,2,0,0,0,120,100,118,102,2,0,0,0,120,100,104,100,2,0,0,0,120,100,104,50,2,0,0,0,65,86,109,112,2,0,0,0,109,112,50,118,89,0,0,0,109,106,112,50,94,0,0,0,116,103,97,32,97,0,0,0,116,105,102,102,98,0,0,0,103,105,102,32,62,0,0,0,112,110,103,32,62,0,0,0,77,78,71,32,71,0,0,0,118,99,45,49,88,0,0,0,97,118,115,50,117,0,0,0,100,114,97,99,100,0,0,0,65,86,100,110,5,0,0,0,72,50,54,51,17,0,0,0,51,73,86,68,14,0,0,0,65,86,49,120,14,0,0,0,65,86,117,112,102,0,0,0,115,103,105,32,129,0,0,0,100,112,120,32,82,88,69,48,101,120,114,32,149,0,0,0,97,112,99,104,149,0,0,0,97,112,99,110,149,0,0,0,97,112,99,115,149,0,0,0,97,112,99,111,149,0,0,0,97,112,52,104,51,0,0,0,102,108,105,99,170,0,0,0,105,99,111,100,0,0,0,0,0,0,0,0,5,112,1,0,116,101,120,116,5,112,1,0,116,120,51,103,56,48,54,99,99,54,48,56,0,0,0,0,0,0,0,0,2,80,1,0,109,112,52,97,3,80,1,0,97,99,45,51,3,80,1,0,115,97,99,51,0,16,1,0,105,109,97,52,16,80,1,0,97,108,97,99,0,32,1,0,115,97,109,114,1,32,1,0,115,97,119,98,4,80,1,0,100,116,115,99,4,80,1,0,100,116,115,104,4,80,1,0,100,116,115,108,4,80,1,0,68,84,83,32,41,80,1,0,101,99,45,51,6,80,1,0,118,100,118,97,6,80,1,0,100,118,99,97,18,80,1,0,97,103,115,109,60,80,1,0,105,108,98,99,9,80,1,0,77,65,67,51,10,80,1,0,77,65,67,54,43,80,1,0,46,109,112,49,0,80,1,0,46,109,112,50,1,80,1,0,46,109,112,51,1,80,1,0,85,0,115,109,34,80,1,0,110,109,111,115,7,0,1,0,97,108,97,119,20,0,1,0,102,108,51,50,21,0,1,0,102,108,51,50,22,0,1,0,102,108,54,52,23,0,1,0,102,108,54,52,6,0,1,0,117,108,97,119,1,0,1,0,116,119,111,115,0,0,1,0,115,111,119,116,1,0,1,0,108,112,99,109,0,0,1,0,108,112,99,109,13,0,1,0,105,110,50,52,12,0,1,0,105,110,50,52,9,0,1,0,105,110,51,50,8,0,1,0,105,110,51,50,4,0,1,0,115,111,119,116,5,0,1,0,114,97,119,32,5,0,1,0,78,79,78,69,24,80,1,0,81,99,108,112,24,80,1,0,81,99,108,113,24,80,1,0,115,113,99,112,19,80,1,0,81,68,77,50,51,80,1,0,81,68,77,67,36,80,1,0,115,112,101,120,36,80,1,0,83,80,88,78,8,80,1,0,87,77,65,50,99,118,101,115,115,101,118,99,118,109,115,115,115,115,109,118,0,0,0,0,0,0,0,0,7,0,1,0,1,0,1,0,21,0,1,0,4,0,0,0,23,0,1,0,8,0,0,0,6,0,1,0,1,0,2,0,0,0,1,0,2,0,0,0,12,0,1,0,3,0,0,0,8,0,1,0,4,0,4,0,4,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,7,0,1,0,1,0,1,0,20,0,1,0,4,0,0,0,22,0,1,0,8,0,0,0,6,0,1,0,1,0,2,0,1,0,1,0,2,0,0,0,13,0,1,0,3,0,0,0,9,0,1,0,4,0,4,0,4,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,2,80,1,0,97,97,99,32,3,80,1,0,97,99,45,51,0,16,1,0,105,109,97,52,1,16,1,0,109,115,0,17,6,16,1,0,109,115,0,2,16,80,1,0,97,108,97,99,0,32,1,0,115,97,109,114,18,80,1,0,97,103,115,109,30,80,1,0,109,115,0,49,60,80,1,0,105,108,98,99,9,80,1,0,77,65,67,51,10,80,1,0,77,65,67,54,43,80,1,0,46,109,112,49,0,80,1,0,46,109,112,50,1,80,1,0,46,109,112,51,1,80,1,0,109,115,0,85,7,0,1,0,97,108,97,119,6,0,1,0,117,108,97,119,24,80,1,0,81,99,108,112,19,80,1,0,81,68,77,50,19,80,1,0,81,68,77,67,0,0,0,0,0,0,0,0,28,0,0,0,72,50,54,52,28,0,0,0,104,50,54,52,28,0,0,0,88,50,54,52,28,0,0,0,120,50,54,52,28,0,0,0,97,118,99,49,28,0,0,0,68,65,86,67,28,0,0,0,83,77,86,50,28,0,0,0,86,83,83,72,28,0,0,0,81,50,54,52,28,0,0,0,86,50,54,52,28,0,0,0,71,65,86,67,28,0,0,0,85,77,83,86,28,0,0,0,73,78,77,67,5,0,0,0,72,50,54,51,5,0,0,0,88,50,54,51,5,0,0,0,84,50,54,51,5,0,0,0,76,50,54,51,5,0,0,0,86,88,49,75,5,0,0,0,90,121,71,111,5,0,0,0,77,50,54,51,5,0,0,0,108,115,118,109,20,0,0,0,72,50,54,51,21,0,0,0,73,50,54,51,4,0,0,0,72,50,54,49,5,0,0,0,85,50,54,51,13,0,0,0,70,77,80,52,13,0,0,0,68,73,86,88,13,0,0,0,68,88,53,48,13,0,0,0,88,86,73,68,13,0,0,0,77,80,52,83,13,0,0,0,77,52,83,50,13,0,0,0,4,0,0,0,13,0,0,0,90,77,80,52,13,0,0,0,68,73,86,49,13,0,0,0,66,76,90,48,13,0,0,0,109,112,52,118,13,0,0,0,85,77,80,52,13,0,0,0,87,86,49,70,13,0,0,0,83,69,68,71,13,0,0,0,82,77,80,52,13,0,0,0,51,73,86,50,13,0,0,0,87,65,87,86,13,0,0,0,70,70,68,83,13,0,0,0,70,86,70,87,13,0,0,0,68,67,79,68,13,0,0,0,77,86,88,77,13,0,0,0,80,77,52,86,13,0,0,0,83,77,80,52,13,0,0,0,68,88,71,77,13,0,0,0,86,73,68,77,13,0,0,0,77,52,84,51,13,0,0,0,71,69,79,88,13,0,0,0,71,50,54,52,13,0,0,0,72,68,88,52,13,0,0,0,68,77,52,86,13,0,0,0,68,77,75,50,13,0,0,0,68,89,77,52,13,0,0,0,68,73,71,73,13,0,0,0,69,80,72,86,13,0,0,0,69,77,52,65,13,0,0,0,77,52,67,67,13,0,0,0,83,78,52,48,13,0,0,0,86,83,80,88,13,0,0,0,85,76,68,88,13,0,0,0,71,69,79,86,13,0,0,0,83,73,80,80,13,0,0,0,83,77,52,86,13,0,0,0,88,86,73,88,13,0,0,0,68,114,101,88,13,0,0,0,81,77,80,52,13,0,0,0,80,76,86,49,17,0,0,0,77,80,52,51,17,0,0,0,68,73,86,51,17,0,0,0,77,80,71,51,17,0,0,0,68,73,86,53,17,0,0,0,68,73,86,54,17,0,0,0,68,73,86,52,17,0,0,0,68,86,88,51,17,0,0,0,65,80,52,49,17,0,0,0,67,79,76,49,17,0,0,0,67,79,76,48,16,0,0,0,77,80,52,50,16,0,0,0,68,73,86,50,15,0,0,0,77,80,71,52,15,0,0,0,77,80,52,49,18,0,0,0,87,77,86,49,19,0,0,0,87,77,86,50,19,0,0,0,71,88,86,69,25,0,0,0,100,118,115,100,25,0,0,0,100,118,104,100,25,0,0,0,100,118,104,49,25,0,0,0,100,118,115,108,25,0,0,0,100,118,50,53,25,0,0,0,100,118,53,48,25,0,0,0,99,100,118,99,25,0,0,0,67,68,86,72,25,0,0,0,67,68,86,53,25,0,0,0,100,118,99,32,25,0,0,0,100,118,99,115,25,0,0,0,100,118,104,49,25,0,0,0,100,118,105,115,25,0,0,0,112,100,118,99,25,0,0,0,83,76,50,53,25,0,0,0,83,76,68,86,1,0,0,0,109,112,103,49,1,0,0,0,109,112,103,50,2,0,0,0,109,112,103,50,2,0,0,0,77,80,69,71,1,0,0,0,80,73,77,49,2,0,0,0,80,73,77,50,1,0,0,0,86,67,82,50,1,0,0,0,1,0,0,16,2,0,0,0,2,0,0,16,13,0,0,0,4,0,0,16,2,0,0,0,68,86,82,32,2,0,0,0,77,77,69,83,2,0,0,0,76,77,80,50,2,0,0,0,115,108,105,102,2,0,0,0,69,77,50,86,2,0,0,0,77,55,48,49,2,0,0,0,109,112,103,118,1,0,0,0,66,87,49,48,1,0,0,0,88,77,80,71,8,0,0,0,77,74,80,71,8,0,0,0,76,74,80,71,8,0,0,0,100,109,98,49,8,0,0,0,109,106,112,97,10,0,0,0,76,74,80,71,8,0,0,0,74,80,71,76,12,0,0,0,77,74,76,83,12,0,0,0,77,74,80,71,8,0,0,0,77,74,76,83,8,0,0,0,106,112,101,103,8,0,0,0,73,74,80,71,110,82,86,65,65,86,82,110,8,0,0,0,65,67,68,86,8,0,0,0,81,73,86,71,8,0,0,0,83,76,77,74,8,0,0,0,67,74,80,71,8,0,0,0,73,74,76,86,8,0,0,0,77,86,74,80,8,0,0,0,65,86,73,49,8,0,0,0,65,86,73,50,8,0,0,0,77,84,83,74,8,0,0,0,90,74,80,71,8,0,0,0,77,77,74,80,26,0,0,0,72,70,89,85,68,0,0,0,70,70,86,72,27,0,0,0,67,89,85,86,14,0,0,0,0,0,0,0,14,0,0,0,3,0,0,0,14,0,0,0,73,52,50,48,14,0,0,0,89,85,89,50,14,0,0,0,89,52,50,50,14,0,0,0,86,52,50,50,14,0,0,0,89,85,78,86,14,0,0,0,85,89,78,86,14,0,0,0,85,89,78,89,14,0,0,0,117,121,118,49,14,0,0,0,50,86,117,49,14,0,0,0,50,118,117,121,14,0,0,0,121,117,118,115,14,0,0,0,121,117,118,50,14,0,0,0,80,52,50,50,14,0,0,0,89,86,49,50,14,0,0,0,89,86,49,54,14,0,0,0,89,86,50,52,14,0,0,0,85,89,86,89,14,0,0,0,86,89,85,89,14,0,0,0,73,89,85,86,14,0,0,0,89,56,48,48,14,0,0,0,89,56,32,32,14,0,0,0,72,68,89,67,14,0,0,0,89,86,85,57,14,0,0,0,86,68,84,90,14,0,0,0,89,52,49,49,14,0,0,0,78,86,49,50,14,0,0,0,78,86,50,49,14,0,0,0,89,52,49,66,14,0,0,0,89,52,50,66,14,0,0,0,89,85,86,57,14,0,0,0,89,86,85,57,14,0,0,0,97,117,118,50,14,0,0,0,89,86,89,85,131,0,0,0,70,82,87,85,146,0,0,0,82,49,48,107,134,0,0,0,114,50,49,48,128,0,0,0,118,50,49,48,56,48,51,86,118,51,48,56,56,48,52,86,118,52,48,56,86,85,89,65,65,89,85,86,158,0,0,0,118,52,49,48,52,86,85,89,121,117,118,52,29,0,0,0,73,86,51,49,29,0,0,0,73,86,51,50,112,0,0,0,73,86,52,49,113,0,0,0,73,86,53,48,30,0,0,0,86,80,51,49,30,0,0,0,86,80,51,48,91,0,0,0,86,80,53,48,92,0,0,0,86,80,54,48,92,0,0,0,86,80,54,49,92,0,0,0,86,80,54,50,107,0,0,0,86,80,54,65,93,0,0,0,86,80,54,70,93,0,0,0,70,76,86,52,141,0,0,0,86,80,56,48,169,0,0,0,86,80,57,48,32,0,0,0,65,83,86,49,33,0,0,0,65,83,86,50,36,0,0,0,86,67,82,49,34,0,0,0,70,70,86,49,42,0,0,0,88,120,97,110,114,0,0,0,76,77,50,48,46,0,0,0,109,114,108,101,46,0,0,0,1,0,0,0,46,0,0,0,2,0,0,0,47,0,0,0,77,83,86,67,47,0,0,0,109,115,118,99,47,0,0,0,67,82,65,77,47,0,0,0,99,114,97,109,47,0,0,0,87,72,65,77,47,0,0,0,119,104,97,109,44,0,0,0,99,118,105,100,52,0,0,0,68,85,67,75,52,0,0,0,80,86,69,90,54,0,0,0,77,83,90,72,55,0,0,0,90,76,73,66,87,79,78,83,83,78,79,87,35,0,0,0,52,88,77,86,22,0,0,0,70,76,86,49,22,0,0,0,83,50,54,51,87,0,0,0,70,83,86,49,23,0,0,0,115,118,113,49,57,0,0,0,116,115,99,99,58,0,0,0,85,76,84,73,60,0,0,0,86,73,88,76,61,0,0,0,81,80,69,71,61,0,0,0,81,49,46,48,61,0,0,0,81,49,46,49,72,0,0,0,87,77,86,51,152,0,0,0,87,77,86,80,71,0,0,0,87,86,67,49,71,0,0,0,87,77,86,65,153,0,0,0,87,86,80,50,73,0,0,0,76,79,67,79,74,0,0,0,87,78,86,49,74,0,0,0,89,85,86,56,75,0,0,0,65,65,83,52,75,0,0,0,65,65,83,67,76,0,0,0,82,84,50,49,77,0,0,0,70,80,83,49,31,0,0,0,116,104,101,111,78,0,0,0,84,77,50,48,80,0,0,0,67,83,67,68,82,0,0,0,90,77,66,86,86,0,0,0,75,77,86,67,88,0,0,0,67,65,86,83,89,0,0,0,109,106,112,50,89,0,0,0,77,74,50,67,89,0,0,0,76,74,50,67,89,0,0,0,76,74,50,75,89,0,0,0,73,80,74,50,90,0,0,0,86,77,110,99,94,0,0,0,116,103,97,32,62,0,0,0,77,80,78,71,62,0,0,0,80,78,71,49,37,0,0,0,67,76,74,82,117,0,0,0,100,114,97,99,43,0,0,0,97,122,112,114,43,0,0,0,82,80,90,65,43,0,0,0,114,112,122,97,11,0,0,0,83,80,53,52,124,0,0,0,65,85,82,65,125,0,0,0,65,85,82,50,129,0,0,0,100,112,120,32,139,0,0,0,75,71,86,49,148,0,0,0,76,65,71,83,108,0,0,0,65,77,86,70,154,0,0,0,85,76,82,65,154,0,0,0,85,76,82,71,154,0,0,0,85,76,89,48,154,0,0,0,85,76,89,50,154,0,0,0,85,76,72,48,154,0,0,0,85,76,72,50,156,0,0,0,86,66,76,69,48,51,49,69,69,49,51,48,157,0,0,0,120,116,111,114,162,0,0,0,90,69,67,79,80,49,52,89,89,52,49,80,51,0,0,0,65,70,76,67,163,0,0,0,77,83,83,49,164,0,0,0,77,83,65,49,165,0,0,0,84,83,67,50,166,0,0,0,77,84,83,50,167,0,0,0,67,76,76,67,168,0,0,0,77,83,83,50,24,0,0,0,83,86,81,51,86,50,49,48,48,49,50,118,86,50,49,48,97,49,50,118,77,50,71,0,71,50,77,50,77,50,71,0,71,50,77,51,77,50,71,0,71,50,77,52,176,0,0,0,70,73,67,86,0,0,0,0,0,0,0,0,32,67,70,65,0,0,0,0,16,80,83,80,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,78,79,78,69,4,0,1,0,78,79,78,69,5,0,1,0,114,97,119,32,13,0,1,0,78,79,78,69,9,0,1,0,78,79,78,69,20,0,1,0,102,108,51,50,22,0,1,0,102,108,54,52,7,0,1,0,97,108,97,119,6,0,1,0,117,108,97,119,13,0,1,0,105,110,50,52,9,0,1,0,105,110,51,50,9,80,1,0,77,65,67,51,10,80,1,0,77,65,67,54,18,80,1,0,71,83,77,32,28,16,1,0,71,55,50,50,71,55,50,54,71,55,50,54,1,0,1,0,116,119,111,115,0,0,1,0,115,111,119,116,0,16,1,0,105,109,97,52,19,80,1,0,81,68,77,50,24,80,1,0,81,99,108,112,0,0,0,0,0,0,0,0,1,0,1,0,78,79,78,69,4,0,1,0,78,79,78,69,5,0,1,0,114,97,119,32,13,0,1,0,78,79,78,69,9,0,1,0,78,79,78,69,20,0,1,0,102,108,51,50,22,0,1,0,102,108,54,52,7,0,1,0,97,108,97,119,6,0,1,0,117,108,97,119,13,0,1,0,105,110,50,52,9,0,1,0,105,110,51,50,9,80,1,0,77,65,67,51,10,80,1,0,77,65,67,54,18,80,1,0,71,83,77,32,28,16,1,0,71,55,50,50,71,55,50,54,71,55,50,54,1,0,1,0,116,119,111,115,0,0,1,0,115,111,119,116,0,16,1,0,105,109,97,52,19,80,1,0,81,68,77,50,24,80,1,0,81,99,108,112,0,0,0,0,0,0,0,0,224,120,35,0,72,152,35,0,0,0,0,0,167,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,2,0,0,0,0,0,0,0,0,0,0,206,1,0,0,24,7,0,0,0,0,0,0,0,0,0,0,176,122,35,0,240,152,35,0,0,0,0,0,37,0,0,0,0,0,0,0,0,0,0,0,208,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,166,22,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,5,0,0,0,0,0,0,234,0,0,0,0,0,0,0,182,3,0,0,0,0,0,0,0,0,0,0,176,122,35,0,240,152,35,0,0,0,0,0,37,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,10,0,0,0,0,0,0,0,0,0,0,202,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,124,35,0,224,153,35,0,0,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,216,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,169,22,0,0,0,0,0,128,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,0,0,0,0,0,0,0,182,2,0,0,0,0,0,0,148,10,0,0,0,0,0,0,0,0,0,0,32,125,35,0,144,154,35,0,0,0,0,0,44,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,6,0,0,0,0,0,0,0,0,0,0,54,0,0,0,124,3,0,0,0,0,0,0,0,0,0,0,0,0,0,255,170,0,0,255,0,170,0,255,170,170,0,255,0,0,170,255,170,0,170,255,0,85,170,255,170,170,170,255,85,85,85,255,255,85,85,255,85,255,85,255,255,255,85,255,85,85,255,255,255,85,255,255,85,255,255,255,255,255,255,255,232,92,29,0,8,0,0,0,0,0,0,0,86,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,136,137,30,0,200,107,34,0,0,1,0,0,56,209,32,0,0,0,0,0,64,233,22,0,0,0,0,0,0,0,0,0,64,0,0,0,170,8,0,0,98,10,0,0,38,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,126,35,0,224,154,35,0,0,0,0,0,160,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,7,0,0,0,0,0,0,0,0,0,0,140,1,0,0,238,9,0,0,0,0,0,0,0,0,0,0,32,128,35,0,0,155,35,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,1,0,0,0,0,0,0,0,0,0,0,250,1,0,0,254,8,0,0,0,0,0,0,0,0,0,0,200,139,30,0,192,108,34,0,0,1,0,0,200,139,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,6,0,0,164,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,7,3,6,3,73,224,196,241,230,59,2,223,30,246,253,239,8,30,255,230,252,234,10,16,220,251,245,56,37,6,246,251,243,253,6,251,11,4,237,251,240,41,24,13,4,245,219,23,251,46,254,227,251,217,235,247,0,49,12,247,240,230,22,15,211,236,251,40,22,17,230,31,242,2,242,10,30,20,229,247,217,39,18,5,34,231,208,228,245,34,254,215,9,249,239,21,20,24,239,223,0,232,10,42,3,251,10,42,11,8,253,3,16,9,22,254,0,223,246,18,7,58,10,28,222,252,231,10,9,21,249,220,230,220,221,28,12,42,253,240,244,228,21,42,251,235,16,26,252,19,237,39,15,15,1,13,19,239,239,14,241,55,4,19,28,236,205,242,250,7,0,230,27,252,18,216,250,16,255,241,0,201,251,240,237,14,253,49,14,1,234,226,244,0,24,15,9,239,211,227,4,28,51,35,216,0,228,24,14,251,252,235,249,223,0,224,241,35,12,1,245,198,5,240,228,0,1,33,0,11,217,5,242,6,3,31,28,255,203,223,237,25,46,26,245,242,217,229,9,239,252,223,6,0,4,255,5,10,239,234,5,199,251,9,20,13,18,35,245,3,240,234,17,13,40,19,255,201,221,251,27,44,37,49,176,6,240,11,30,226,247,228,228,227,243,6,254,28,253,251,249,196,5,9,11,255,24,19,229,13,224,13,15,19,19,35,17,217,213,247,4,42,32,41,78,235,213,4,218,17,17,251,55,24,241,220,14,4,24,232,12,5,17,31,202,251,254,27,43,244,2,9,247,241,22,253,28,21,236,3,20,28,9,251,9,255,236,43,239,3,12,0,20,252,223,227,6,22,38,249,0,1,29,30,193,235,3,11,27,255,242,45,246,247,1,12,47,37,228,0,254,26,4,243,39,242,226,248,234,248,12,244,34,27,227,2,26,254,8,225,16,3,17,57,242,250,19,13,16,246,8,17,20,254,38,0,17,240,245,27,44,45,252,8,227,5,249,30,255,235,7,249,0,0,209,9,18,15,22,242,4,0,28,57,233,235,25,254,1,0,249,53,19,3,17,15,36,0,237,24,21,43,247,0,33,246,222,5,239,221,15,1,53,30,6,197,0,246,24,243,17,229,1,255,219,13,4,20,20,238,246,240,248,245,39,18,26,0,210,236,41,15,37,15,221,10,245,44,3,208,10,6,17,2,245,205,248,8,38,3,4,225,12,254,210,255,10,4,5,249,230,19,246,251,18,34,45,15,202,232,18,13,31,7,251,253,235,249,254,196,10,251,32,34,249,236,11,240,8,236,21,227,1,24,2,13,27,6,251,241,253,248,21,1,55,21,15,218,219,3,65,32,23,30,182,17,0,31,18,183,5,0,253,5,231,244,3,1,22,253,9,223,12,24,250,254,33,247,235,251,236,27,19,7,34,37,34,234,212,0,41,29,17,21,76,221,225,228,207,43,216,0,29,242,8,5,10,18,230,210,0,7,6,3,231,249,254,40,28,14,18,253,229,228,248,211,243,34,243,229,241,31,12,3,7,241,247,9,228,29,211,5,250,213,247,12,2,36,244,226,245,3,17,3,222,234,3,24,12,24,2,32,228,234,227,227,5,50,235,225,218,29,7,251,36,227,237,215,222,18,211,250,8,246,251,43,23,11,214,203,5,5,6,30,14,248,20,26,1,16,25,4,3,241,7,215,233,253,252,253,8,48,255,17,224,248,3,254,243,4,206,255,229,217,233,51,15,30,229,219,249,1,17,29,5,233,25,10,242,26,8,41,1,247,243,230,251,12,244,249,242,45,250,9,31,232,233,229,227,247,213,8,26,249,30,239,252,3,230,221,5,232,246,228,247,12,5,33,5,8,5,227,230,232,9,233,242,12,217,204,5,18,39,24,219,253,0,10,249,234,208,12,248,220,12,247,244,22,244,237,250,228,0,227,238,253,11,17,246,18,246,7,229,238,245,249,3,28,209,201,238,15,34,16,248,239,246,216,243,222,209,0,5,252,16,21,8,254,214,213,10,230,246,254,31,11,27,19,235,10,12,236,3,245,25,236,231,231,227,228,28,34,25,38,179,2,11,255,7,209,204,5,227,223,255,28,0,15,228,230,254,226,0,254,22,252,33,3,220,21,253,15,2,251,4,252,250,247,219,225,5,32,20,30,81,231,242,248,195,0,231,28,54,20,253,242,17,248,0,212,16,35,13,18,213,249,6,11,33,252,30,11,234,216,6,213,3,50,242,238,22,18,255,240,12,252,8,29,217,244,226,33,19,248,235,250,8,9,13,228,4,31,24,18,204,233,12,252,18,5,14,47,232,222,242,229,22,66,234,234,255,16,250,232,41,238,254,235,211,232,226,21,33,24,239,24,29,241,240,205,21,33,13,45,253,248,28,254,7,254,37,19,7,229,22,217,249,12,251,5,45,35,241,255,229,1,20,17,232,218,221,26,255,252,221,32,21,3,254,221,8,29,24,44,244,232,34,238,248,7,21,55,5,235,2,233,11,28,243,1,22,33,235,246,36,243,251,249,216,205,228,36,52,27,18,220,2,234,0,223,21,2,253,243,230,11,14,4,10,246,18,242,234,220,24,235,1,28,216,214,42,5,25,5,224,6,17,31,237,191,223,41,16,255,0,227,250,252,13,239,9,255,8,242,221,253,19,245,252,0,1,21,233,226,3,251,20,44,208,210,19,3,20,253,253,249,6,236,231,179,224,29,31,30,4,2,14,227,240,216,26,0,253,12,13,10,36,247,241,248,24,250,7,234,40,239,248,247,225,238,66,22,11,19,184,13,29,18,252,166,219,34,252,1,243,9,6,245,254,232,13,253,7,11,4,252,42,231,225,1,8,29,6,239,19,254,10,6,218,234,42,19,6,11,116,236,188,226,228,83,28,238,32,234,243,235,5,28,5,249,232,248,234,17,233,30,231,45,15,247,245,238,22,246,4,254,19,244,23,3,213,2,12,252,47,0,211,7,249,69,23,243,254,205,224,242,253,47,19,8,219,245,246,16,224,15,237,29,0,1,228,18,20,252,240,13,38,3,15,0,190,0,7,243,77,243,200,213,243,57,23,230,11,237,229,16,17,22,246,241,237,246,234,43,16,30,254,31,245,250,251,247,52,2,20,0,8,206,33,27,237,19,255,9,8,6,223,252,7,44,18,235,233,208,210,24,9,40,3,1,224,243,245,43,7,14,3,15,230,3,235,26,50,8,0,16,27,222,25,23,213,17,250,1,71,247,197,227,248,30,26,245,30,240,8,212,247,14,5,2,237,216,218,241,249,50,239,38,249,242,232,213,22,250,22,19,17,222,254,236,233,246,39,16,2,11,220,9,13,17,21,250,251,211,246,220,238,33,19,19,225,212,229,241,240,34,245,22,234,252,216,249,21,0,1,35,36,238,246,232,210,244,34,8,32,254,209,214,7,5,21,238,9,244,251,251,2,8,246,252,242,214,218,10,33,49,5,24,223,244,239,221,52,6,38,22,7,184,7,3,0,6,25,30,220,18,232,253,28,249,16,243,230,215,232,1,251,26,3,12,229,210,229,10,24,34,10,8,207,254,222,0,51,12,17,38,25,200,0,0,234,3,20,22,121,247,206,246,216,40,43,9,58,12,231,215,11,2,31,251,248,19,241,32,215,30,240,16,20,228,0,253,26,234,19,0,36,4,22,12,250,247,255,232,52,10,229,27,238,26,38,14,23,240,212,223,3,20,45,10,236,15,253,31,206,14,246,0,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1236049);
/* memory initializer */ allocate([239,241,32,24,240,255,15,55,20,14,8,227,244,249,224,82,253,218,233,232,15,38,2,37,15,217,254,23,252,15,244,253,17,241,58,255,29,6,2,251,230,7,4,56,247,35,3,25,223,32,36,17,7,241,247,13,17,241,15,253,1,33,7,1,244,198,5,15,13,29,3,240,13,252,57,246,13,11,243,235,241,247,40,55,253,14,19,44,239,24,32,251,4,235,238,76,1,215,247,237,244,41,17,55,18,253,193,253,244,30,5,253,244,225,0,232,49,248,9,255,223,244,227,27,238,37,21,34,239,253,245,14,233,25,254,7,22,238,29,1,231,36,21,20,247,234,200,245,6,45,21,241,240,236,255,223,34,254,250,239,233,228,6,25,244,16,37,53,255,245,241,248,231,20,245,37,8,227,234,252,219,36,9,34,22,239,232,8,238,15,254,1,242,225,25,15,48,13,252,228,225,251,235,57,252,53,24,23,201,6,12,37,250,11,11,225,28,250,16,16,206,31,14,0,250,220,239,0,0,29,14,245,238,236,25,6,33,19,236,213,235,235,14,55,0,32,40,42,217,255,8,14,248,6,3,119,232,217,212,205,66,242,15,31,230,255,0,7,16,237,228,237,22,230,4,243,28,240,29,5,255,16,240,8,221,246,214,252,17,29,237,214,249,0,241,50,253,240,251,226,53,237,20,253,201,237,8,0,34,251,245,224,18,241,4,234,13,246,13,247,8,0,19,7,227,225,230,13,33,21,234,191,247,252,233,79,239,229,200,220,41,237,8,10,234,241,39,20,9,221,221,241,20,230,31,26,27,6,15,236,0,23,248,38,234,5,218,241,236,39,4,238,9,243,255,10,3,252,238,241,27,232,13,232,205,222,47,12,28,235,237,229,16,241,30,17,12,12,0,220,10,7,27,37,240,241,234,3,252,31,1,214,7,238,247,74,244,226,214,226,14,240,23,29,237,20,235,249,1,237,239,242,246,213,229,3,48,248,22,240,249,4,214,9,225,6,236,250,252,3,213,234,236,28,5,5,7,249,252,247,0,235,28,250,208,2,242,241,20,251,0,229,242,224,228,251,32,254,6,224,3,244,251,8,231,242,252,12,11,252,209,211,234,22,254,34,250,238,201,241,245,235,16,8,240,6,16,5,252,221,232,246,244,213,255,43,47,14,8,213,251,10,222,39,238,22,240,239,214,13,237,1,253,14,20,222,14,4,239,5,232,230,20,229,211,244,24,254,13,235,248,234,240,224,254,34,31,20,249,198,5,251,2,38,244,2,255,1,230,5,233,235,250,8,11,124,243,235,233,194,23,0,43,57,8,243,238,14,246,6,230,253,49,237,19,225,27,249,0,11,236,29,255,12,209,4,217,11,34,28,247,251,237,243,222,55,6,1,14,215,10,252,48,22,236,225,246,5,7,20,247,240,45,248,19,216,12,255,241,252,246,12,34,11,215,240,232,30,49,20,243,228,234,238,213,84,250,247,220,209,255,252,36,36,12,229,20,26,239,247,223,1,47,237,46,9,27,15,243,241,238,35,6,42,223,20,220,1,252,38,14,18,254,229,236,15,13,13,1,230,242,247,41,1,240,210,27,18,1,4,240,245,43,248,45,0,11,21,227,226,248,19,42,41,228,0,236,20,11,30,10,252,251,224,228,79,254,244,234,214,228,255,51,54,15,8,215,0,232,6,241,1,17,220,244,242,47,0,250,245,230,16,229,13,213,22,238,10,12,2,222,15,223,13,243,10,18,10,15,235,215,250,56,19,243,247,223,247,250,20,1,245,13,232,243,233,32,6,234,230,241,0,8,12,219,1,254,28,27,251,219,249,221,8,235,39,4,0,221,229,203,250,44,33,18,251,254,11,225,247,234,6,15,220,13,25,46,23,236,219,232,23,237,43,227,38,242,0,230,12,246,38,240,0,0,227,25,22,2,250,189,245,49,255,246,232,5,3,243,4,251,250,11,231,12,16,31,28,220,203,243,6,16,42,232,17,1,18,246,4,243,15,238,251,249,29,231,234,254,6,67,11,207,1,10,24,251,253,13,252,5,6,245,25,244,240,225,228,36,53,13,250,240,214,24,239,255,238,10,252,13,241,18,5,7,217,252,0,35,27,53,6,212,223,238,5,2,245,31,9,22,250,241,36,243,231,210,233,20,37,24,233,19,213,29,218,14,0,26,244,10,218,16,0,0,246,238,246,241,21,41,6,200,237,13,9,33,9,6,236,255,11,243,24,13,23,224,250,22,26,15,0,248,244,37,255,2,228,229,5,37,7,35,248,21,177,2,12,22,42,28,1,205,202,241,248,41,0,24,250,15,255,239,36,12,14,209,0,6,11,26,240,27,243,43,234,18,246,244,254,34,241,33,243,13,241,243,243,255,26,14,9,215,255,16,46,229,238,255,252,16,11,213,8,211,0,245,235,29,30,8,237,214,215,28,0,20,236,245,226,246,4,5,32,28,172,6,9,36,47,1,4,220,220,244,27,236,230,17,9,33,255,209,19,210,247,229,241,13,15,18,221,250,214,33,236,36,255,4,218,242,238,2,27,20,201,250,255,242,41,246,4,208,234,20,31,10,251,249,236,9,16,211,8,237,40,244,1,15,4,10,244,222,245,41,16,24,226,207,236,13,28,22,18,43,132,13,21,23,62,233,0,213,199,248,13,18,242,10,250,26,3,207,19,237,31,229,7,0,245,20,227,1,244,47,252,39,245,222,228,9,5,19,13,34,34,242,252,17,251,24,26,236,27,45,12,232,2,243,21,8,22,16,32,2,222,225,236,7,58,251,5,254,218,12,254,1,255,26,251,23,21,6,248,245,222,6,18,55,15,11,21,240,248,16,250,240,251,4,35,24,10,12,43,1,213,209,242,248,43,5,246,34,217,18,234,16,17,42,243,19,255,3,242,236,251,249,7,4,9,0,21,228,6,48,254,14,15,236,5,0,27,14,32,28,5,224,2,250,32,253,12,5,248,25,14,4,244,245,4,47,45,22,234,2,182,12,30,42,30,242,16,233,227,19,236,21,7,255,19,17,14,10,43,27,253,208,8,234,16,7,252,42,247,31,250,20,6,4,253,43,22,20,228,251,246,253,4,18,15,229,24,243,24,51,34,209,244,228,21,19,27,240,15,226,239,244,244,0,36,246,249,229,219,16,15,22,253,4,225,255,42,249,18,9,177,17,27,56,36,215,19,248,246,22,15,217,236,247,35,35,15,236,26,225,230,229,250,241,20,0,233,8,218,22,251,38,15,20,217,252,18,247,13,1,206,3,16,5,30,203,19,236,3,55,19,248,0,222,5,11,32,238,15,252,22,243,10,243,9,248,0,237,249,29,31,26,243,223,235,22,65,9,4,23,137,24,39,44,51,190,14,241,225,26,1,0,249,240,19,28,19,234,26,252,13,228,16,227,251,1,240,16,248,35,10,42,4,239,227,19,42,7,0,15,31,228,6,240,240,50,225,242,0,6,36,17,0,0,227,242,11,18,20,231,250,223,237,20,43,21,21,242,201,0,224,216,214,39,1,248,242,8,250,253,219,248,29,22,4,37,220,247,222,234,17,24,248,18,241,2,255,14,31,231,241,208,243,4,28,31,5,21,199,4,203,232,233,55,250,244,219,6,245,245,249,234,18,227,255,25,220,235,236,9,22,56,11,250,211,235,15,16,20,1,33,222,2,6,17,23,28,250,231,12,240,219,203,1,11,15,8,25,236,11,180,255,41,9,19,12,215,239,201,238,3,63,3,12,226,251,3,12,31,0,24,207,8,247,1,33,12,29,229,18,219,235,222,17,3,11,242,23,231,2,243,239,15,241,3,255,223,249,255,12,58,251,241,243,227,253,16,243,4,199,10,243,245,13,21,15,9,216,201,3,242,237,212,17,232,224,5,252,21,18,174,3,38,23,24,241,218,254,219,241,39,2,233,4,241,12,3,239,15,198,1,227,250,254,5,26,249,252,200,9,221,253,231,33,224,220,239,249,15,9,204,246,27,229,18,230,218,242,233,16,44,33,253,236,211,246,20,241,3,225,50,242,10,0,251,17,15,224,232,16,1,241,201,236,242,248,29,12,7,32,135,9,50,10,40,216,213,247,198,244,25,41,245,254,225,5,8,237,15,224,41,226,16,240,236,28,0,3,230,22,237,0,220,252,234,244,6,9,1,24,36,238,24,3,228,7,240,13,26,41,24,255,5,230,253,244,27,46,27,246,232,222,246,248,49,2,34,0,205,244,239,218,231,56,0,0,22,253,236,234,224,2,47,42,249,251,235,18,247,12,5,5,254,248,10,4,14,42,38,246,223,207,251,232,33,12,17,35,204,250,218,234,249,72,249,253,0,250,231,226,254,245,36,247,243,239,235,6,5,45,10,36,18,223,237,237,31,44,27,15,16,222,11,234,22,4,40,7,235,0,255,221,220,18,10,24,46,12,222,248,185,9,59,29,8,226,230,11,226,16,248,44,9,242,251,254,19,40,38,15,7,206,17,218,7,14,24,43,234,6,234,237,239,34,2,20,23,10,217,240,248,250,33,4,249,212,238,21,23,48,46,232,247,216,253,255,32,13,11,213,249,242,253,241,26,253,21,230,206,248,0,240,229,34,231,233,43,239,6,255,179,13,56,43,13,199,233,26,245,19,27,240,239,234,10,15,19,10,22,213,240,226,2,225,11,6,5,9,204,254,236,0,248,50,223,229,19,237,1,247,209,0,45,249,7,187,233,13,2,51,32,14,3,209,237,248,37,11,10,240,32,241,19,227,0,255,28,238,236,4,16,243,218,253,241,0,66,0,249,13,140,20,68,30,28,173,228,18,224,22,13,21,251,228,251,7,24,8,22,239,23,226,25,211,241,9,11,18,234,10,252,2,237,12,233,253,43,254,244,4,72,243,227,238,4,90,37,222,4,255,13,247,250,11,2,24,243,3,249,245,252,4,214,25,31,255,248,227,250,17,237,2,246,250,38,22,214,237,250,245,3,7,250,20,25,77,32,227,225,226,252,254,242,29,16,40,230,0,3,244,243,246,220,9,15,8,232,6,249,22,216,17,8,9,31,18,190,234,245,237,32,250,239,225,19,65,33,215,240,1,0,29,6,4,243,17,247,1,248,14,35,3,237,11,4,0,255,235,23,30,253,5,236,212,48,46,237,253,236,3,220,13,5,7,40,51,28,220,204,229,238,36,254,22,0,33,235,254,3,13,26,245,242,252,246,10,238,14,22,36,232,21,255,228,40,42,214,251,231,251,27,255,236,239,24,38,35,230,1,4,35,224,235,253,2,35,248,227,232,212,12,24,222,18,8,249,235,201,251,21,254,23,245,228,13,255,234,223,21,10,215,18,2,21,45,24,30,235,223,232,17,232,227,15,16,51,235,223,243,211,3,8,228,2,249,2,219,237,249,27,234,39,7,244,5,251,211,221,15,1,244,4,248,227,39,12,30,223,237,8,21,6,248,247,243,28,252,225,232,238,52,23,244,4,238,251,242,209,24,34,14,27,234,190,22,22,1,240,6,24,175,25,14,8,61,0,25,228,202,236,3,14,239,8,0,44,240,221,243,238,43,7,250,245,223,4,226,245,22,40,250,43,253,206,14,18,234,238,1,16,77,254,245,1,249,47,52,251,29,33,1,228,0,241,28,26,2,30,0,2,234,4,223,253,36,235,3,241,254,5,252,4,6,9,37,31,251,224,236,226,8,17,10,40,13,34,47,0,251,4,240,235,248,2,42,43,246,26,10,2,225,245,229,237,21,246,244,20,253,11,231,20,25,25,29,28,228,222,231,218,37,3,0,246,7,22,48,244,8,36,244,9,12,234,12,19,6,28,0,29,18,3,245,239,10,238,10,249,27,18,11,7,253,228,47,55,18,241,222,240,225,24,23,27,29,9,43,248,230,7,226,17,4,253,26,35,251,24,10,28,9,244,251,223,251,248,251,29,26,24,247,23,14,244,39,52,251,238,217,232,32,8,253,2,13,252,50,1,27,39,23,205,241,226,27,37,7,255,239,227,251,23,231,246,14,230,248,215,255,9,13,26,5,244,12,7,14,211,6,247,220,29,19,41,34,238,45,6,248,10,5,213,233,245,42,53,251,251,250,226,242,8,236,230,255,240,231,252,253,15,249,41,23,3,4,3,248,208,1,239,249,15,9,247,28,227,45,251,6,43,9,244,254,220,12,30,11,253,239,253,34,22,253,232,244,232,254,224,28,22,29,29,251,206,21,31,38,227,249,5,180,35,31,28,49,213,40,0,227,14,248,251,246,238,26,46,0,249,250,253,25,7,2,216,228,242,238,3,27,28,8,45,13,222,13,27,15,225,244,253,74,239,0,225,238,73,251,0,3,251,25,12,253,255,234,3,247,33,244,232,6,2,223,9,21,5,20,229,237,249,222,219,222,22,44,0,215,227,239,235,5,3,21,7,2,60,246,5,224,222,7,20,245,16,248,20,235,29,255,232,254,243,229,250,5,15,3,8,235,255,201,235,241,38,37,253,191,224,233,226,35,246,11,212,253,48,246,250,239,254,11,51,8,248,218,253,252,31,244,2,46,1,246,252,251,7,26,237,10,5,238,222,211,241,54,24,238,243,225,249,223,10,34,251,17,35,241,255,203,226,250,59,0,10,232,13,239,27,255,1,37,243,252,236,236,18,10,16,8,11,217,238,230,0,46,20,215,241,219,241,29,251,7,226,1,21,249,7,0,0,47,247,238,241,234,14,252,0,228,199,23,21,231,2,255,0,7,203,237,253,239,241,220,0,19,232,235,213,9,0,217,14,30,8,22,8,244,12,222,229,29,254,230,2,248,31,240,253,239,199,14,6,237,243,240,10,248,239,236,2,218,0,239,16,11,229,212,211,4,248,247,1,20,213,17,253,244,0,236,4,33,29,250,234,218,7,0,255,227,226,63,21,253,245,229,1,14,211,10,9,255,244,209,219,28,0,2,230,252,13,178,21,43,252,38,239,239,5,201,232,15,36,242,252,232,24,244,251,239,225,54,5,2,229,213,12,254,247,9,15,234,3,228,235,20,253,236,228,247,5,80,250,16,245,226,30,9,28,28,29,13,250,2,228,3,5,7,60,251,247,245,1,232,237,27,243,32,243,241,237,237,221,239,39,43,9,252,214,224,215,11,14,39,27,247,17,4,33,250,0,252,1,251,246,17,22,251,57,5,247,236,243,238,221,11,253,16,22,239,243,216,237,1,55,35,5,229,212,219,207,40,0,28,232,242,5,4,21,7,33,0,32,15,221,244,255,11,58,251,16,28,0,255,223,0,245,39,251,14,250,253,225,228,1,53,33,19,231,210,230,228,20,51,14,6,249,0,26,229,4,238,40,6,240,1,15,0,55,5,16,19,242,3,207,242,255,22,30,12,0,232,241,247,17,45,29,252,228,205,221,34,4,25,246,247,235,7,36,26,36,35,228,244,214,3,16,12,28,235,214,5,21,240,230,4,237,19,217,241,241,255,243,237,17,17,242,15,201,252,237,222,25,48,28,11,222,2,41,247,7,17,235,236,232,17,33,0,24,246,214,253,5,246,214,245,248,3,253,240,247,234,2,0,33,10,238,249,198,246,228,252,11,37,233,5,210,2,29,5,39,21,9,0,207,244,9,16,26,234,241,45,20,5,216,234,239,26,225,14,254,14,246,226,236,27,9,39,217,238,251,183,32,60,15,26,197,254,33,226,10,3,17,248,226,1,26,4,22,246,240,36,5,11,200,219,250,10,5,13,3,250,5,245,252,19,5,16,215,232,243,142,47,68,52,55,54,8,54,114,51,171,51,148,51,21,47,122,48,164,54,12,56,39,57,44,51,103,52,168,51,236,47,206,46,1,54,187,52,130,55,53,54,196,57,243,53,53,51,185,44,219,51,33,50,149,53,184,49,128,53,215,49,117,48,246,39,153,47,108,45,105,51,242,45,146,52,24,48,18,50,203,40,229,49,235,46,196,54,42,46,1,54,165,48,170,51,206,40,106,51,105,46,220,55,59,50,160,63,178,52,205,58,171,39,20,50,255,44,149,54,9,47,233,58,91,49,118,55,118,55,91,49,233,58,9,47,149,54,255,44,20,50,171,39,205,58,178,52,160,63,59,50,220,55,105,46,106,51,206,40,170,51,165,48,1,54,42,46,196,54,235,46,229,49,203,40,18,50,24,48,146,52,242,45,105,51,108,45,153,47,246,39,117,48,215,49,128,53,184,49,149,53,33,50,219,51,185,44,53,51,243,53,196,57,53,54,130,55,187,52,1,54,206,46,236,47,168,51,103,52,44,51,39,57,12,56,164,54,122,48,21,47,148,51,171,51,114,51,8,54,55,54,68,52,142,47,38,252,15,252,14,243,12,245,254,250,250,245,211,240,245,243,249,6,244,4,236,3,240,12,255,12,46,24,0,33,253,9,244,244,248,249,17,250,0,254,60,240,3,234,10,224,0,228,239,238,253,231,219,233,246,3,2,3,0,3,242,0,242,255,0,2,32,9,255,25,7,13,251,13,8,1,2,8,246,6,27,244,28,254,6,249,15,9,245,1,243,245,216,4,227,242,237,251,233,248,226,243,239,0,242,12,34,20,254,25,2,240,252,244,15,16,29,7,24,10,49,232,16,236,2,230,2,249,231,246,245,231,224,253,229,2,248,248,245,247,232,239,240,242,243,2,20,5,252,17,14,244,3,13,33,25,14,23,15,19,46,250,21,8,254,240,251,248,245,4,8,15,232,4,254,230,253,240,240,242,247,254,255,4,19,7,36,17,9,13,0,31,251,244,7,248,11,241,243,252,68,238,9,247,250,221,238,231,230,249,10,1,240,253,255,247,6,237,252,241,252,250,0,248,20,254,23,2,7,5,12,35,1,13,24,0,253,0,234,4,35,242,34,10,246,246,255,12,236,12,0,15,238,24,236,229,242,228,229,229,236,237,254,248,5,7,25,13,5,5,6,5,2,244,31,15,23,255,12,8,57,230,22,249,242,228,242,253,221,0,3,1,245,16,238,246,252,225,241,228,242,233,255,235,7,254,11,255,3,255,18,9,10,13,49,24,8,14,2,16,25,15,22,11,18,4,15,234,8,254,239,247,208,236,226,239,240,11,255,16,2,10,251,26,254,252,22,0,2,10,250,13,242,10,233,0,10,254,1,0,47,3,11,250,15,243,2,218,250,243,241,234,216,228,228,0,251,8,10,15,7,7,252,13,255,242,9,242,0,2,4,18,249,36,250,8,253,13,249,8,14,7,36,13,10,10,18,0,0,5,231,248,213,0,208,238,229,0,244,3,249,250,249,13,241,251,11,253,0,2,0,244,250,10,0,23,22,11,26,12,36,251,24,252,7,249,6,239,242,251,234,234,221,248,210,255,239,253,0,2,254,246,251,0,242,241,254,238,254,252,11,249,1,36,18,32,7,27,17,20,33,13,29,24,1,1,254,238,0,9,253,17,229,0,235,226,244,245,251,254,12,4,9,19,18,247,13,250,11,248,254,35,248,10,249,255,4,245,246,254,55,1,17,6,255,240,241,221,241,254,0,4,237,248,236,243,255,242,7,253,18,0,10,5,19,237,0,235,8,240,9,39,0,36,10,7,247,4,236,5,22,5,42,26,250,8,1,2,247,17,246,18,235,19,217,225,233,233,240,241,2,244,7,6,5,247,1,246,7,240,4,9,0,10,17,22,16,2,14,9,44,250,30,8,247,246,245,242,233,5,248,4,242,12,219,242,244,230,252,240,8,240,9,249,6,237,244,231,5,232,15,13,8,36,34,31,1,18,4,18,253,251,247,249,15,255,5,13,2,12,5,2,235,233,254,240,0,5,250,13,233,3,224,10,241,8,44,28,9,37,254,13,247,241,244,229,249,244,0,245,18,239,235,231,11,237,250,253,245,0,7,245,243,225,255,0,9,1,5,12,238,0,225,254,243,255,30,14,7,29,9,18,255,10,4,238,234,3,246,254,243,243,3,251,7,4,9,34,251,20,254,3,240,253,236,239,245,249,239,0,222,243,223,254,228,8,32,24,5,29,3,244,0,241,11,253,3,2,24,1,8,231,248,233,3,243,253,17,236,8,0,246,248,245,238,0,255,246,251,0,228,239,224,241,230,255,19,9,3,21,15,249,6,9,29,5,246,17,15,9,4,250,253,5,255,252,245,16,250,23,19,29,0,253,6,226,3,239,246,251,243,254,239,3,5,3,35,21,17,17,2,35,254,241,3,228,243,235,243,243,26,237,241,244,251,234,232,0,235,12,21,15,8,245,7,244,14,236,2,250,249,250,240,247,6,251,21,7,15,10,13,39,5,10,20,237,228,251,234,251,251,241,9,7,247,2,248,37,242,31,11,29,5,16,245,226,249,227,235,238,233,237,238,247,249,3,23,17,14,9,8,9,6,241,27,252,254,250,12,255,16,229,254,246,243,240,236,20,227,20,14,16,13,8,247,243,2,223,247,237,239,233,239,234,250,250,9,2,12,2,20,13,13,10,45,4,240,8,2,7,240,14,254,8,20,17,9,2,14,16,250,5,232,228,235,236,248,9,4,25,255,11,234,24,241,248,21,5,11,14,251,18,245,7,229,236,242,249,1,247,6,2,242,247,16,255,253,242,0,5,253,248,240,220,237,253,1,6,17,24,4,7,235,11,242,238,7,247,9,7,6,22,253,33,246,245,228,7,249,0,230,6,11,10,12,23,12,23,5,24,243,5,237,248,218,235,236,254,250,12,245,251,233,11,227,247,9,0,7,6,1,249,254,7,253,3,254,6,27,3,252,250,0,249,8,4,0,6,247,13,245,249,245,241,219,252,247,251,5,11,251,247,234,255,229,238,252,242,5,0,12,253,4,32,14,12,239,22,17,11,248,12,3,21,3,14,248,5,4,28,7,32,254,248,244,222,252,244,1,6,9,4,249,17,4,243,11,255,19,252,0,39,252,7,245,235,236,240,246,245,13,0,248,3,0,252,235,245,247,16,10,18,5,240,246,240,5,241,13,5,15,1,250,4,6,233,254,240,17,244,10,44,3,33,6,244,222,255,236,253,238,4,17,23,252,20,252,26,253,36,0,32,2,12,227,222,240,232,246,250,0,244,248,4,248,243,0,250,16,244,5,13,3,7,13,3,248,254,14,0,3,249,5,5,248,2,239,9,238,24,2,19,10,4,228,239,251,228,2,249,4,241,249,248,250,233,243,235,14,236,17,18,11,33,30,11,233,13,5,9,60,10,7,255,9,248,6,243,2,241,255,246,243,245,15,0,6,9,255,0,243,1,245,253,243,21,13,26,249,31,246,249,240,223,225,246,22,248,1,254,82,255,252,237,6,229,250,227,244,230,1,232,251,238,17,17,17,6,10,0,249,254,247,240,244,11,0,11,247,23,0,253,248,248,243,255,8,7,249,6,49,2,21,0,1,254,9,8,250,250,248,246,248,9,254,0,252,254,243,244,233,241,244,240,230,21,2,21,245,23,252,223,249,223,250,13,34,5,27,10,71,246,9,239,255,236,253,248,235,238,250,232,0,1,0,16,6,251,0,243,239,237,245,227,231,11,245,6,243,15,7,227,0,248,11,22,20,21,17,18,67,8,14,11,249,245,245,247,249,253,13,16,8,9,24,244,10,243,251,239,254,252,3,246,6,17,4,19,0,11,250,13,247,223,242,246,16,239,246,252,90,253,2,250,246,227,232,230,235,241,15,2,16,1,25,4,21,240,6,238,3,248,5,232,8,7,247,4,255,3,5,18,255,249,2,255,2,255,237,3,57,0,27,13,242,251,249,11,241,4,5,16,13,29,6,243,0,231,240,225,244,234,2,233,250,16,249,14,254,3,0,244,0,223,9,13,28,253,14,7,79,245,15,252,238,233,236,251,226,249,7,2,21,21,8,3,10,228,252,225,250,231,3,219,252,7,236,0,252,252,11,249,6,248,27,22,14,12,5,16,47,30,15,14,14,9,9,233,13,246,244,249,240,241,253,253,255,14,9,12,9,8,0,10,242,4,247,2,251,8,243,253,238,246,211,253,16,252,4,0,69,17,3,253,10,248,253,216,255,235,246,235,248,233,255,13,8,11,21,11,15,4,0,254,243,251,233,244,249,0,255,0,246,14,228,5,1,11,251,7,36,21,28,16,6,16,12,254,4,254,236,249,245,4,236,252,244,2,255,0,0,248,254,254,229,4,235,254,247,0,250,227,247,246,235,21,28,10,29,11,58,9,16,255,2,254,0,237,246,243,239,235,253,253,237,12,254,0,10,255,5,244,0,241,230,251,222,240,245,249,4,231,254,14,253,29,13,25,20,20,55,28,21,27,254,7,248,236,4,1,1,18,5,4,5,240,2,248,5,251,19,2,14,3,6,0,238,252,2,245,248,18,245,246,227,253,10,243,248,253,77,16,9,9,250,245,235,219,246,246,4,5,13,253,7,0,13,245,17,250,25,255,15,247,7,247,224,237,0,238,2,22,253,15,244,5,252,2,239,5,44,20,34,29,246,13,252,0,252,9,251,19,10,24,245,239,248,236,251,237,9,242,12,247,250,0,226,247,0,237,254,249,254,246,251,20,21,1,17,9,66,8,23,11,242,251,239,240,237,254,253,5,18,17,246,0,1,233,6,236,15,238,14,234,251,246,212,233,254,230,9,253,4,14,12,29,7,16,7,18,18,9,239,252,11,3,0,11,7,4,10,3,10,238,24,253,14,7,4,10,240,1,229,252,229,17,12,30,0,35,247,253,244,220,221,226,254,243,2,245,40,254,227,234,7,242,244,251,249,249,12,247,18,230,26,14,24,4,16,9,246,254,230,238,230,7,255,15,255,27,2,0,252,245,239,235,240,1,249,253,8,1,253,254,3,10,3,32,255,12,2,4,15,1,7,253,2,252,250,253,230,241,227,239,216,17,0,26,254,27,254,227,252,220,246,250,9,0,27,0,30,245,241,236,0,248,247,15,241,0,5,247,23,250,8,13,13,249,5,253,236,237,229,225,217,7,243,11,252,19,8,231,3,245,7,2,252,16,18,9,26,7,245,8,251,1,239,14,255,15,24,30,32,1,33,240,18,242,0,248,250,252,244,244,250,13,2,23,8,15,252,17,251,220,238,226,248,234,246,242,48,252,233,247,247,239,226,254,240,3,26,16,40,250,35,1,28,239,12,247,0,248,245,231,251,3,246,8,6,7,6,22,1,245,255,235,234,249,237,251,15,0,2,10,243,7,242,35,246,23,16,31,37,21,16,239,6,230,246,235,240,235,243,231,237,13,248,19,5,7,1,248,2,220,5,250,3,248,15,255,37,244,247,249,239,245,230,18,231,12,19,17,45,14,17,0,17,226,1,234,246,231,244,218,238,3,234,4,3,0,13,253,10,245,23,2,246,7,5,7,5,29,247,11,15,22,3,0,18,8,255,6,7,233,6,250,5,12,15,21,5,8,239,9,228,0,245,6,2,12,245,0,242,243,207,234,248,247,4,247,27,16,235,250,12,3,247,240,3,254,1,249,15,225,7,10,16,9,27,21,11,5,240,253,230,247,232,249,0,4,0,4,250,11,224,242,233,6,251,255,252,20,3,13,8,28,6,21,10,16,248,7,12,253,245,249,251,0,4,8,252,248,238,253,215,0,234,2,0,4,251,231,250,242,231,1,2,4,29,2,17,8,248,252,4,10,250,5,252,5,250,250,20,246,247,9,4,254,16,7,1,244,239,240,217,247,220,244,254,253,6,235,1,11,249,10,245,20,20,11,13,27,253,24,255,19,242,3,9,20,12,33,29,253,15,236,9,247,11,3,16,2,254,2,249,253,236,0,10,249,249,22,249,243,223,233,242,238,249,244,35,15,241,6,252,1,229,244,251,8,15,19,37,245,16,254,20,244,23,2,22,255,255,245,251,243,222,242,8,242,4,26,0,11,240,242,227,254,239,253,3,19,9,26,248,26,246,24,0,28,5,33,34,17,254,236,255,234,0,246,6,242,253,246,236,252,224,252,7,241,0,253,0,243,247,0,253,252,17,0,25,7,254,8,244,7,233,8,243,16,7,20,42,9,0,253,9,231,12,246,12,238,254,232,237,243,210,237,5,234,10,0,8,11,8,9,239,11,7,8,231,249,2,248,12,249,23,248,13,240,249,236,214,247,0,3,247,25,244,10,244,18,2,24,19,13,46,19,251,22,246,0,248,245,248,247,17,245,249,248,253,237,247,230,8,230,10,232,0,228,251,223,222,239,2,20,1,22,0,10,250,14,3,10,20,4,32,4,249,15,0,3,0,13,9,0,3,4,239,0,221,241,15,250,4,255,27,12,5,248,241,237,219,11,240,2,236,12,233,254,234,1,1,11,5,13,34,14,248,14,252,230,0,245,16,14,29,2,17,3,243,229,3,232,1,237,14,253,247,236,244,223,227,3,241,20,247,9,245,253,240,254,2,254,7,3,20,0,246,7,7,234,7,13,33,23,14,18,7,12,239,248,8,4,252,246,6,251,4,251,6,6,236,10,9,247,252,2,240,249,255,12,17,16,39,9,36,12,2,3,250,21,255,245,7,246,11,236,236,245,4,236,253,243,248,228,250,235,246,240,8,249,244,3,11,7,5,0,252,248,4,8,18,3,41,0,22,254,0,252,5,25,6,14,25,255,254,252,227,254,229,240,21,6,244,253,9,16,253,2,255,7,241,31,249,246,240,247,229,235,245,251,16,3,26,9,24,7,0,252,0,252,6,245,32,14,23,250,5,1,251,227,9,245,241,234,253,0,238,248,1,250,249,23,250,6,251,244,241,235,251,248,17,247,28,0,11,250,254,244,11,0,14,13,49,22,8,9,252,9,219,12,9,7,17,11,26,238,25,244,237,239,211,242,239,0,239,30,255,22,10,25,12,38,18,253,22,252,253,0,243,3,246,11,233,254,10,249,251,249,241,0,254,246,13,249,14,221,10,233,240,225,219,235,240,17,250,26,10,21,16,21,13,25,19,243,8,237,251,249,255,8,254,36,251,6,253,8,241,1,208,4,23,9,9,17,30,2,16,253,230,240,216,6,221,255,228,17,244,9,0,8,11,25,5,253,10,248,250,249,250,234,255,11,1,21,22,7,19,5,230,249,11,248,5,255,17,242,1,241,232,226,224,255,223,16,238,14,0,8,6,4,12,12,6,243,254,233,248,241,4,239,5,36,18,30,8,22,10,14,226,11,15,20,0,8,9,241,15,0,251,9,233,6,248,243,243,7,251,3,20,19,27,31,39,249,13,245,4,237,248,25,253,11,249,254,4,240,238,247,248,255,3,2,253,246,253,224,1,244,254,252,241,255,249,3,254,4,6,3,26,15,29,17,40,239,0,230,2,229,2,29,4,36,10,6,247,0,229,0,216,2,29,22,249,14,12,5,7,7,244,9,238,26,230,242,232,252,240,247,10,2,26,18,26,249,1,241,1,229,254,0,4,11,17,21,16,255,7,3,238,247,17,4,245,253,0,245,249,252,246,253,246,18,232,3,242,249,252,246,16,255,27,4,27,239,244,226,0,221,9,3,12,36,35,30,2,13,254,11,190,248,233,245,14,5,17,16,19,2,3,251,238,239,10,0,255,23,250,20,241,18,242,22,5,10,44,23,2,26,247,3,252,242,244,227,249,240,249,238,212,236,222,227,10,243,4,0,4,247,5,237,246,232,11,17,8,20,5,19,247,14,244,9,6,0,30,9,0,19,2,7,2,10,5,236,235,255,239,247,179,240,247,247,6,11,21,37,10,10,252,251,243,3,249,0,243,11,239,6,231,1,241,9,249,9,32,19,0,18,254,234,3,241,12,251,4,254,17,251,201,228,235,229,2,249,8,20,252,255,255,238,251,252,251,16,254,8,251,5,237,254,242,253,250,0,18,4,254,11,8,238,11,10,29,3,246,13,8,3,198,247,240,1,254,2,0,19,10,13,17,21,3,3,19,244,2,0,246,1,251,12,0,15,26,5,34,16,11,7,252,25,2,242,3,227,243,231,236,236,220,235,228,240,250,240,244,2,252,2,20,7,11,252,20,4,12,254,1,0,0,8,2,2,27,252,21,2,9,0,6,29,9,10,21,235,228,246,227,245,187,239,253,3,246,8,3,40,1,21,10,21,8,23,1,243,248,245,235,245,241,252,0,2,13,5,23,12,7,0,1,0,10,242,28,251,255,245,5,249,209,226,241,242,242,247,247,23,243,10,12,7,16,15,3,3,1,242,247,244,247,248,0,246,14,252,9,254,5,248,13,3,18,10,45,3,240,4,252,0,177,11,241,4,18,23,20,5,30,7,249,254,235,235,248,253,246,28,4,31,6,25,253,37,4,249,20,0,4,4,245,7,250,8,229,234,242,244,251,240,199,0,229,243,14,5,7,245,15,252,251,240,243,227,250,13,0,25,16,31,12,22,254,23,6,240,7,242,2,253,0,12,0,33,247,243,228,3,242,249,166,3,254,6,10,29,24,26,21,15,241,254,240,255,231,252,235,16,250,18,253,8,251,24,248,249,9,252,1,253,251,238,1,7,254,1,254,1,19,253,189,248,242,245,7,11,11,9,7,3,243,240,248,247,232,12,246,13,5,17,2,4,253,10,250,239,252,237,0,245,6,243,9,33,14,10,240,17,10,4,185,10,247,17,1,20,3,8,21,18,6,24,0,255,0,240,250,5,0,13,17,19,11,29,25,245,11,250,13,241,249,29,0,8,245,234,236,235,239,238,207,254,235,0,255,2,247,248,6,6,8,10,8,247,2,0,4,2,13,12,23,15,12,16,26,235,254,235,11,233,4,33,7,33,6,243,222,251,229,246,174,1,4,19,250,27,6,29,12,26,255,24,5,18,239,239,239,250,246,0,7,2,9,16,12,245,0,245,9,233,0,3,8,8,13,1,248,249,7,250,196,246,249,1,247,8,250,13,254,15,1,10,13,11,241,0,250,247,1,0,13,255,11,3,13,235,243,230,7,225,10,7,16,33,31,10,234,8,255,2,253,7,251,251,8,254,17,247,18,232,254,237,246,252,28,17,5,28,254,7,252,15,7,8,6,23,13,21,242,20,239,238,245,223,226,245,23,243,251,247,18,252,239,233,4,236,4,230,3,220,0,224,254,244,29,34,16,24,10,6,0,12,8,252,8,13,0,6,240,12,251,243,253,249,243,253,8,2,242,0,243,0,8,253,0,4,21,11,9,240,246,238,251,16,10,16,251,15,243,251,241,255,6,252,250,23,2,16,239,12,246,212,253,223,250,12,34,1,20,3,8,244,253,235,253,242,8,251,252,228,249,224,2,8,12,34,4,12,255,250,247,252,7,239,252,13,245,1,237,4,0,217,4,249,11,21,20,16,10,11,4,6,0,7,248,252,0,250,9,243,11,7,11,15,37,4,9,5,251,245,5,9,22,1,27,18,4,14,251,0,244,3,252,224,242,244,17,234,239,245,26,250,245,246,244,233,244,233,251,232,13,251,19,8,38,21,20,2,6,244,11,5,23,245,29,9,247,0,249,250,255,7,2,249,3,253,2,250,229,253,250,254,14,9,240,1,3,14,0,251,3,8,16,36,19,3,255,250,239,232,252,249,21,245,14,18,249,9,247,249,250,234,3,223,10,11,28,249,7,0,16,242,2,248,236,239,247,254,242,240,6,251,24,28,21,20,8,247,252,231,1,245,22,232,15,8,235,251,245,242,5,238,11,249,27,20,14,7,255,9,240,27,2,10,13,16,20,236,29,236,242,240,243,248,9,13,254,33,9,19,17,23,17,22,6,6,247,254,244,254,236,243,243,246,211,252,16,248,254,249,5,15,247,249,9,254,8,219,14,225,245,227,251,240,11,30,7,29,21,18,23,19,18,9,7,253,233,239,242,247,248,247,250,15,229,4,2,6,244,1,230,19,15,12,5,22,24,0,21,244,235,241,248,11,249,12,242,20,254,6,7,6,16,9,250,5,235,249,241,246,243,217,251,246,236,19,28,5,22,5,252,6,3,251,1,4,11,240,6,233,237,227,0,3,250,30,253,17,10,5,13,2,17,253,251,253,221,235,239,239,254,221,2,15,253,28,13,21,13,13,248,25,8,23,253,13,3,239,20,248,0,10,8,11,18,0,1,10,5,0,28,17,32,15,26,1,237,247,253,235,241,7,250,247,227,251,10,239,241,247,13,13,253,5,249,252,247,222,5,236,2,253,16,3,20,17,11,7,17,0,34,13,33,2,28,248,224,232,251,227,253,12,0,15,245,3,253,254,232,255,238,17,21,25,245,19,6,3,11,0,249,11,13,31,1,0,247,255,251,244,18,0,31,2,13,1,226,242,249,227,247,238,1,246,252,18,22,253,10,2,3,5,9,7,241,1,251,243,254,244,251,254,21,23,2,16,0,251,6,243,23,253,32,246,15,248,212,228,247,219,2,243,9,15,12,27,7,12,0,11,212,6,226,248,9,10,11,14,23,251,8,252,14,244,37,14,12,26,4,16,248,16,247,7,250,19,12,25,251,24,241,243,248,220,222,225,255,238,252,238,234,251,214,230,6,248,255,254,9,239,10,238,21,237,39,31,23,23,16,15,254,12,249,250,251,9,255,10,249,16,252,247,0,246,239,234,240,254,242,247,201,255,239,250,1,16,15,35,15,2,0,252,19,8,20,13,1,14,249,3,238,0,246,251,237,19,0,21,248,16,247,217,0,220,246,249,9,252,20,251,223,243,227,232,255,255,2,18,0,247,3,239,27,0,21,30,12,11,5,2,244,252,247,237,238,9,243,6,245,8,2,221,8,246,7,1,252,11,10,2,220,5,232,4,249,7,250,17,14,5,22,22,35,8,46,1,17,3,0,254,2,10,5,0,14,15,2,18,2,4,245,7,255,220,238,224,249,229,239,236,242,249,220,243,246,246,238,0,0,251,25,8,43,0,48,18,27,0,12,253,7,6,7,243,15,5,245,3,0,254,0,12,6,246,0,233,234,245,230,244,209,253,245,6,241,13,254,38,6,13,15,22,40,28,28,0,5,248,246,241,249,249,4,243,1,14,247,14,0,254,252,238,7,220,6,248,3,243,7,248,231,241,234,245,238,252,241,22,248,2,17,9,48,20,30,17,16,245,1,240,254,246,5,230,2,4,234,0,254,246,6,243,14,246,23,0,246,2,255,0,199,26,234,7,14,28,14,3,35,0,253,255,11,240,18,10,4,31,15,28,14,23,1,21,249,2,245,1,253,1,238,247,246,243,207,232,248,242,254,240,221,14,222,246,10,10,1,244,20,244,0,241,18,232,20,27,14,28,27,27,20,19,2,8,251,249,231,243,251,251,250,251,254,12,225,241,233,1,244,248,188,18,247,9,6,35,18,25,26,7,246,255,16,3,1,9,250,19,4,15,4,6,0,8,236,2,233,254,249,251,244,221,255,243,232,0,3,0,22,252,210,6,235,248,2,16,5,8,11,252,248,241,24,252,2,26,3,16,16,14,9,2,1,252,237,249,220,239,247,243,0,225,5,12,249,8,245,15,13,4,207,24,240,20,254,26,254,7,25,10,11,25,32,3,27,254,8,8,11,9,24,17,16,14,13,254,236,251,4,239,242,12,253,243,223,231,242,233,241,237,229,12,228,2,250,7,241,247,11,255,13,11,40,252,29,14,19,5,23,8,30,13,17,0,14,244,222,236,2,231,254,16,4,12,241,240,227,249,232,246,196,16,253,22,246,32,0,28,17,18,3,25,37,23,10,253,254,253,0,253,14,0,14,1,0,254,224,247,1,231,249,243,5,243,248,255,254,248,10,250,218,4,241,4,242,13,244,11,2,6,6,11,45,16,11,13,7,250,12,252,20,253,16,244,1,244,210,232,0,223,3,247,12,12,8,7,239,6,0,2,201,76,42,72,189,71,112,68,56,82,55,71,152,72,31,65,139,79,125,74,209,75,254,71,84,85,65,73,157,76,3,68,165,79,12,85,161,78,198,84,242,81,248,79,171,76,187,75,229,83,94,90,81,85,111,93,73,86,15,84,142,82,116,81,219,76,157,69,100,74,69,68,18,78,59,66,14,72,214,62,146,82,211,73,216,81,241,73,204,83,169,69,136,78,7,67,58,77,88,78,112,79,130,81,129,75,41,71,220,73,84,70,52,84,188,85,39,90,81,93,186,81,88,76,248,81,69,77,69,77,248,81,88,76,186,81,81,93,39,90,188,85,52,84,84,70,220,73,41,71,129,75,130,81,112,79,88,78,58,77,7,67,136,78,169,69,204,83,241,73,216,81,211,73,146,82,214,62,14,72,59,66,18,78,69,68,100,74,157,69,219,76,116,81,142,82,15,84,73,86,111,93,81,85,94,90,229,83,187,75,171,76,248,79,242,81,198,84,161,78,12,85,165,79,3,68,157,76,65,73,84,85,254,71,209,75,125,74,139,79,31,65,152,72,55,71,56,82,112,68,189,71,42,72,201,76,168,44,30,0,8,186,29,0,0,0,0,0,8,87,29,0,0,0,0,0,88,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,30,0,240,108,34,0,0,1,0,0,0,0,0,0,0,0,0,0,144,119,25,0,0,0,0,0,88,0,0,0,20,0,0,0,36,8,0,0,218,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,128,192,192,192,0,0,0,67,131,76,140,73,137,70,134,99,163,102,166,83,147,89,153,115,179,192,0,0,0,0,0,0,1,0,254,255,0,0,0,0,1,0,253,255,120,130,35,0,224,155,35,0,0,0,0,0,88,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,9,0,0,0,0,0,0,0,0,0,0,38,0,0,0,130,10,0,0,82,0,0,0,0,0,0,0,120,147,30,0,152,111,34,0,8,211,32,0,120,147,30,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,16,246,35,0,0,0,0,0,0,0,0,0,24,0,0,0,60,1,0,0,212,2,0,0,26,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,151,30,0,64,113,34,0,0,0,0,0,0,0,0,0,32,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,82,9,0,0,76,10,0,0,200,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,155,30,0,32,114,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,8,0,0,228,3,0,0,22,3,0,0,72,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,133,35,0,128,156,35,0,0,0,0,0,103,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,8,0,0,0,0,0,0,0,0,0,0,212,1,0,0,130,6,0,0,0,0,0,0,0,0,0,0,200,159,30,0,168,116,34,0,0,0,0,0,200,159,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,210,9,0,0,4,10,0,0,166,0,0,0,62,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,28,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,0,139,35,0,224,156,35,0,0,0,0,0,88,73,80,66,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,163,30,0,200,118,34,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,10,0,0,4,0,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,142,35,0,104,157,35,0,0,0,0,0,155,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,55,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,1,0,0,0,0,0,0,0,0,0,0,234,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,168,30,0,192,119,34,0,0,0,0,0,64,168,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,238,4,0,0,6,3,0,0,244,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1246289);
/* memory initializer */ allocate([104,120,33,0,160,70,32,0,1,0,0,0,57,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,8,0,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,143,35,0,128,157,35,0,0,0,0,0,79,0,0,0,0,0,0,0,0,0,0,0,232,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,94,0,0,0,0,0,0,0,124,1,0,0,0,0,0,0,0,0,0,0,168,147,35,0,216,157,35,0,0,0,0,0,79,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,175,30,0,216,121,34,0,16,217,32,0,40,175,30,0,54,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,7,0,0,24,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,175,30,0,216,121,34,0,0,0,0,0,40,175,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,4,0,0,234,4,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,178,30,0,16,123,34,0,0,0,0,0,160,178,30,0,0,0,0,0,40,246,35,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,186,7,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,35,0,136,159,35,0,0,0,0,0,84,88,84,66,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,5,0,0,0,0,0,0,0,0,0,0,214,0,0,0,250,8,0,0,0,0,0,0,0,0,0,0,56,163,35,0,120,160,35,0,1,0,0,0,48,80,1,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,6,0,0,0,0,0,0,0,0,0,0,238,0,0,0,132,9,0,0,0,0,0,0,0,0,0,0,96,121,33,0,160,71,32,0,1,0,0,0,49,80,1,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,6,0,0,0,0,0,0,0,0,0,0,238,0,0,0,132,9,0,0,0,0,0,0,0,0,0,0,88,180,30,0,112,123,34,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,8,0,0,130,2,0,0,58,3,0,0,230,2,0,0,0,0,0,0,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,164,35,0,200,160,35,0,0,0,0,0,136,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,5,0,0,0,0,0,0,0,0,0,0,14,2,0,0,104,10,0,0,78,0,0,0,0,0,0,0,96,180,30,0,136,123,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,12,7,0,0,36,9,0,0,184,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,165,35,0,8,161,35,0,0,0,0,0,118,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,5,0,0,0,0,0,0,0,0,0,0,112,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,80,181,30,0,216,123,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,104,6,0,0,196,7,0,0,50,0,0,0,140,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,166,35,0,32,161,35,0,0,0,0,0,104,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,6,0,0,0,0,0,0,0,0,0,0,198,0,0,0,22,9,0,0,0,0,0,0,0,0,0,0,255,5,102,63,251,115,93,63,7,238,68,63,1,194,31,63,3,180,229,62,246,211,135,62,250,111,196,61,9,0,41,189,231,143,9,190,27,72,55,190,11,208,54,190,24,8,18,190,253,239,173,189,249,255,167,188,3,96,23,61,3,128,158,61,253,159,195,61,3,240,186,61,255,47,141,61,9,64,18,61,0,0,0,0,2,64,250,188,246,127,78,189,246,127,105,189,4,64,80,189,10,96,15,189,47,0,104,188,252,255,217,59,6,0,189,60,247,127,4,61,251,95,9,61,5,0,226,60,17,128,137,60,249,255,134,59,7,0,245,187,237,127,128,188,232,127,158,188,10,128,150,188,226,127,97,188,255,255,230,187,0,0,0,0,6,0,191,59,252,255,25,60,25,0,42,60,253,255,19,60,255,255,197,59,251,255,27,59,232,255,143,186,3,0,112,187,10,0,163,187,255,255,164,187,255,255,131,187,6,0,30,187,0,0,24,186,20,0,136,58,242,255,17,59,2,0,54,59,237,255,49,59,254,255,11,59,17,0,152,58,0,0,0,0,0,0,0,0,96,159,33,0,40,74,35,0,0,0,0,0,86,85,89,65,0,0,0,0,0,0,0,0,0,251,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,2,0,0,0,0,0,0,192,1,0,0,0,0,0,0,78,4,0,0,0,0,0,0,0,0,0,0,112,159,33,0,104,74,35,0,0,0,0,0,86,85,89,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,10,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,166,35,0,64,161,35,0,0,0,0,0,73,85,86,65,0,2,0,0,0,0,0,0,32,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,6,0,0,0,0,0,0,28,0,0,0,0,0,0,0,154,1,0,0,0,0,0,0,0,0,0,0,184,166,35,0,112,161,35,0,0,0,0,0,73,85,86,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,2,0,0,0,0,0,0,0,0,0,0,178,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,46,34,0,40,98,35,0,0,0,0,0,0,0,0,0,200,63,10,0,2,0,0,0,142,9,0,0,0,0,0,0,150,0,0,0,164,4,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,83,33,0,240,38,32,0,0,0,0,0,0,0,0,0,184,103,27,0,2,0,0,0,142,9,0,0,0,0,0,0,150,0,0,0,164,4,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,181,30,0,0,124,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,80,9,0,0,78,3,0,0,28,0,0,0,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,166,35,0,168,161,35,0,0,0,0,0,83,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,1,0,0,0,0,0,0,0,0,0,0,54,2,0,0,218,7,0,0,0,0,0,0,0,0,0,0,96,145,30,0,192,254,29,0,0,0,0,0,80,82,86,65,0,0,0,0,0,0,0,0,232,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,9,0,0,0,0,0,0,248,1,0,0,0,0,0,0,42,10,0,0,0,0,0,0,0,0,0,0,80,67,31,0,104,145,30,0,0,0,0,0,80,82,86,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,3,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,169,35,0,248,161,35,0,0,0,0,0,110,82,86,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,208,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,10,0,0,0,0,0,0,0,0,0,0,184,1,0,0,138,6,0,0,0,0,0,0,0,0,0,0,232,181,30,0,48,124,34,0,0,1,0,0,232,181,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,5,0,0,148,3,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,126,31,0,136,200,30,0,136,112,32,0,0,0,0,0,1,80,1,0,22,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,248,6,0,0,78,1,0,0,212,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,205,30,0,128,130,34,0,168,220,32,0,112,205,30,0,3,80,1,0,13,0,0,0,0,0,0,0,0,0,0,0,104,246,35,0,0,0,0,0,0,0,0,0,40,0,0,0,26,10,0,0,226,1,0,0,164,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,210,30,0,208,131,34,0,0,0,0,0,0,0,0,0,0,0,0,0,224,20,21,0,0,0,0,0,0,0,0,0,96,0,0,0,16,4,0,0,68,7,0,0,152,2,0,0,152,3,0,0,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,180,28,0,120,157,33,0,184,176,6,0,144,174,6,0,48,177,6,0,0,0,0,0,0,0,0,0,0,0,0,0,64,1,0,0,230,7,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,212,28,0,32,169,33,0,152,181,6,0,96,177,6,0,16,182,6,0,0,0,0,0,0,0,0,0,0,0,0,0,84,1,0,0,170,5,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,247,28,0,224,188,33,0,0,0,0,0,0,0,0,0,248,173,21,0,3,0,0,0,226,8,0,0,0,0,0,0,30,0,0,0,18,1,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,11,29,0,160,198,33,0,232,47,27,0,112,47,27,0,72,216,26,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,126,1,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,71,35,0,240,138,35,0,0,0,0,0,124,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,3,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,171,35,0,104,162,35,0,0,0,0,0,125,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,7,0,0,0,0,0,0,0,0,0,0,174,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,212,30,0,112,132,34,0,160,221,32,0,32,212,30,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,136,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,110,2,0,0,74,1,0,0,22,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,212,30,0,112,132,34,0,0,0,0,0,0,0,0,0,128,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,1,0,0,180,6,0,0,170,1,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,228,60,0,188,15,61,0,24,53,61,0,42,100,61,0,188,143,61,0,24,181,61,0,42,228,61,0,188,15,62,0,24,53,62,0,42,100,62,0,188,143,62,0,24,181,62,0,42,228,62,0,188,15,63,0,24,53,63,0,42,100,63,0,188,143,63,0,24,181,63,0,42,228,63,0,188,15,64,0,24,53,64,0,42,100,64,0,188,143,64,0,24,181,64,0,42,228,64,0,188,15,65,0,24,53,65,0,42,100,65,0,188,143,65,0,24,181,65,0,42,228,65,0,188,15,66,0,24,53,66,0,42,100,66,0,188,143,66,0,24,181,66,0,42,228,66,0,188,15,67,0,24,53,67,0,42,100,67,0,188,143,67,0,24,181,67,0,42,228,67,0,188,15,68,0,24,53,68,0,42,100,68,0,188,143,68,0,24,181,68,0,42,228,68,0,188,15,69,0,24,53,69,0,42,100,69,0,188,143,69,0,24,181,69,0,42,228,69,0,188,15,70,0,24,53,70,0,42,100,70,0,188,143,70,0,24,181,70,0,42,228,70,0,188,15,71,0,24,53,71,0,42,100,71,0,0,16,0,32,0,48,0,64,0,80,0,96,0,112,0,128,0,160,0,192,0,224,0,0,1,32,1,64,1,96,1,128,1,192,1,0,2,64,2,128,2,192,2,0,3,128,3,0,4,128,4,0,5,128,5,0,6,128,6,0,7,128,7,0,8,0,0,0,0,0,0,0,0,0,0,0,126,63,63,0,204,229,62,0,36,164,62,0,230,80,62,0,50,25,62,0,66,148,61,0,230,17,61,240,56,27,0,232,56,27,0,0,0,0,0,0,0,0,0,3,0,0,0,5,0,0,0,8,0,0,0,8,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,5,0,0,0,16,57,27,0,8,57,27,0,0,57,27,0,248,56,27,0,48,57,27,0,40,57,27,0,32,57,27,0,24,57,27,0,88,67,27,0,24,67,27,0,0,0,0,0,0,0,0,0,8,67,27,0,248,66,27,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,248,68,27,0,248,68,27,0,120,68,27,0,248,67,27,0,216,67,27,0,216,67,27,0,184,67,27,0,152,67,27,0,40,70,27,0,40,70,27,0,232,69,27,0,168,69,27,0,152,69,27,0,152,69,27,0,136,69,27,0,120,69,27,0,0,0,0,0,0,0,0,0,8,74,27,0,0,0,0,0,4,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,32,74,27,0,24,74,27,0,24,74,27,0,16,74,27,0,56,74,27,0,48,74,27,0,48,74,27,0,40,74,27,0,40,172,35,0,144,162,35,0,1,0,0,0,40,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,154,1,0,0,64,8,0,0,0,0,0,0,0,0,0,0,216,174,35,0,192,162,35,0,1,0,0,0,31,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,9,0,0,0,0,0,0,0,0,0,0,116,2,0,0,160,10,0,0,0,0,0,0,0,0,0,0,112,175,35,0,8,163,35,0,1,0,0,0,47,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,7,0,0,0,0,0,0,0,0,0,0,174,2,0,0,230,9,0,0,0,0,0,0,0,0,0,0,0,8,1,9,16,24,17,25,2,10,3,11,18,26,19,27,4,12,5,13,32,40,33,41,6,14,7,15,20,28,21,29,34,42,35,43,48,56,49,57,22,30,23,31,36,44,37,45,50,58,51,59,38,46,39,47,52,60,53,61,54,62,55,63,3,4,3,3,3,2,0,3,2,2,2,3,2,4,0,0,1,2,13,4,15,4,12,4,5,3,14,4,4,3,0,2,2,2,7,5,11,5,3,5,13,5,5,5,9,5,1,5,14,5,6,5,10,5,2,5,12,5,4,5,8,5,3,2,15,5,0,0,0,0,0,0,0,2,59,6,10,4,58,6,2,3,57,6,60,6,56,6,3,3,61,6,8,4,31,5,9,4,11,4,13,4,12,4,63,10,47,10,55,10,39,10,59,10,43,10,51,10,35,10,61,10,45,10,53,10,37,10,57,10,41,10,49,10,33,10,31,8,23,8,27,8,19,8,29,8,21,8,25,8,17,8,15,6,11,6,13,6,9,6,7,4,5,4,3,2,0,5,2,2,4,4,6,4,8,6,12,6,10,6,14,6,16,8,24,8,20,8,28,8,18,8,26,8,22,8,30,8,32,10,48,10,40,10,56,10,36,10,52,10,44,10,60,10,34,10,50,10,42,10,58,10,38,10,54,10,46,10,62,10,0,0,144,123,33,0,152,73,32,0,0,0,0,0,33,0,0,0,0,0,0,0,0,0,0,0,248,247,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,1,0,0,0,0,0,0,166,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,123,33,0,160,73,32,0,0,0,0,0,33,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,2,0,0,0,0,0,0,0,0,0,0,146,2,0,0,110,8,0,0,0,0,0,0,0,0,0,0,144,175,35,0,72,163,35,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,56,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,1,0,0,0,0,0,0,166,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,176,35,0,80,163,35,0,0,0,0,0,32,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,2,0,0,0,0,0,0,0,0,0,0,146,2,0,0,110,8,0,0,0,0,0,0,0,0,0,0,232,216,30,0,208,133,34,0,0,0,0,0,232,216,30,0,16,80,83,80,0,0,0,0,0,0,0,0,0,0,0,0,136,246,35,0,144,79,27,0,0,0,0,0,48,0,0,0,72,3,0,0,162,1,0,0,218,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,218,30,0,32,134,34,0,0,1,0,0,80,218,30,0,144,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,1,0,0,182,10,0,0,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,218,30,0,96,135,34,0,80,222,32,0,136,208,31,0,0,0,0,0,0,0,0,0,4,112,1,0,192,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,206,5,0,0,196,0,0,0,220,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,123,33,0,168,73,32,0,3,0,0,0,32,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,6,0,0,176,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,219,30,0,160,135,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,122,9,0,0,176,5,0,0,140,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,168,123,33,0,216,73,32,0,3,0,0,0,32,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,9,0,0,0,0,0,0,0,0,0,0,168,2,0,0,108,4,0,0,0,0,0,0,0,0,0,0,80,31,29,0,176,206,33,0,0,0,0,0,176,167,6,0,8,170,6,0,0,0,0,0,250,6,0,0,0,0,0,0,128,0,0,0,198,3,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,48,29,0,72,213,33,0,0,0,0,0,128,202,26,0,216,102,27,0,0,0,0,0,108,6,0,0,0,0,0,0,0,0,0,0,214,7,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,149,31,0,248,195,34,0,0,0,0,0,72,149,27,0,160,151,27,0,0,0,0,0,142,10,0,0,0,0,0,0,162,0,0,0,114,8,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,61,32,0,192,87,31,0,0,0,0,0,248,202,26,0,192,167,28,0,0,0,0,0,232,3,0,0,0,0,0,0,108,1,0,0,158,1,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,65,32,0,232,241,28,0,192,104,16,0,0,0,0,0,56,105,16,0,0,0,0,0,0,0,0,0,0,0,0,0,148,0,0,0,222,6,0,0,72,0,0,0,0,0,0,0,0,0,0,0,62,2,0,0,184,61,29,0,184,219,33,0,112,203,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,145,35,0,232,241,28,0,232,203,26,0,0,0,0,0,112,166,28,0,0,0,0,0,0,0,0,0,0,0,0,0,148,0,0,0,222,6,0,0,72,0,0,0,0,0,0,0,0,0,0,0,62,2,0,0,192,239,25,188,77,91,207,17,168,253,0,128,95,92,68,43,0,87,251,32,85,91,207,17,168,253,0,128,95,92,68,43,0,10,31,0,32,137,34,0,224,222,32,0,32,209,31,0,8,80,1,0,17,0,0,0,0,0,0,0,64,0,0,0,88,246,35,0,0,0,0,0,0,0,0,0,104,109,2,0,242,3,0,0,26,2,0,0,164,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,7,220,183,183,169,207,17,142,230,0,192,12,32,83,101,144,8,0,51,177,229,207,17,137,244,0,160,201,3,73,203,32,219,254,76,246,117,207,17,156,15,0,160,201,3,73,203,232,221,30,0,32,137,34,0,224,222,32,0,32,209,31,0,8,80,1,0,17,0,0,0,0,0,0,0,64,0,0,0,8,2,36,0,0,0,0,0,0,0,0,0,104,109,2,0,90,5,0,0,26,2,0,0,164,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,28,35,68,152,148,209,73,161,65,29,19,78,69,112,84,234,203,248,197,175,91,119,72,132,103,170,140,68,250,76,202,184,206,35,0,168,166,35,0,8,125,33,0,232,74,32,0,136,99,31,0,136,175,30,0,80,23,30,0,224,166,29,0,112,70,29,0,88,245,28,0,240,239,35,0,96,161,35,0,152,63,35,0,192,245,34,0,216,183,34,0,56,122,34,0,40,65,34,0,208,16,34,0,216,223,33,0,232,187,33,0,120,153,33,0,56,122,33,0,0,57,33,0,48,14,33,0,128,244,32,0,192,245,34,0,64,217,32,0,32,190,32,0,176,166,32,0,216,141,32,0,240,116,32,0,216,93,32,0,0,0,0,0,0,0,0,0,1,205,135,244,81,169,207,17,142,230,0,192,12,32,83,101,169,70,67,124,224,239,252,75,178,41,57,62,222,65,92,133,0,225,27,182,78,91,207,17,168,253,0,128,95,92,68,43,48,38,178,117,142,102,207,17,166,217,0,170,0,98,206,108,17,210,211,171,186,169,207,17,142,230,0,192,12,32,83,101,181,3,191,95,46,169,207,17,142,227,0,192,12,32,83,101,161,220,171,140,71,169,207,17,142,228,0,192,12,32,83,101,64,164,208,210,7,227,210,17,151,240,0,160,201,94,168,80,203,165,230,20,114,198,50,67,131,153,169,105,82,6,91,90,226,101,251,58,239,71,242,64,172,44,112,169,13,113,211,67,157,140,23,49,225,3,40,69,181,130,61,249,219,34,245,3,20,230,138,41,34,38,23,76,185,53,218,224,126,233,40,156,252,179,17,34,35,189,210,17,180,183,0,160,201,85,252,110,144,232,30,0,184,139,34,0,0,96,0,0,0,0,0,0,0,0,0,0,232,82,27,0,0,0,0,0,0,0,0,0,216,107,2,0,236,9,0,0,226,6,0,0,154,2,0,0,30,8,0,0,10,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,38,178,117,142,102,207,17,166,217,0,170,0,98,206,108,251,179,17,34,35,189,210,17,180,183,0,160,201,85,252,110,51,38,178,117,142,102,207,17,166,217,0,170,0,98,206,108,192,207,218,89,230,89,208,17,163,172,0,160,201,3,72,246,64,82,209,134,29,49,208,17,163,164,0,160,201,3,72,246,65,82,209,134,29,49,208,17,163,164,0,160,201,3,72,246,64,158,105,248,77,91,207,17,168,253,0,128,95,92,68,43,80,205,195,191,143,97,207,17,139,178,0,170,0,180,226,32,128,233,30,0,64,140,34,0,0,0,0,0,88,224,32,0,0,0,0,0,120,92,27,0,0,0,0,0,0,0,0,0,32,0,0,0,136,1,0,0,74,10,0,0,170,2,0,0,176,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,168,235,30,0,240,140,34,0,0,0,0,0,128,224,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,236,4,0,0,204,9,0,0,70,3,0,0,122,2,0,0,158,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,178,35,0,152,163,35,0,1,0,0,0,33,80,1,0,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,1,36,0,0,0,0,0,0,0,0,0,56,97,27,0,0,0,0,0,40,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,0,0,0,0,0,0,0,0,18,0,0,0,166,7,0,0,50,1,0,0,0,0,0,0,112,236,30,0,0,141,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,92,1,0,0,226,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,179,35,0,168,163,35,0,0,0,0,0,143,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,6,0,0,0,0,0,0,0,0,0,0,176,0,0,0,204,8,0,0,0,0,0,0,0,0,0,0,168,236,30,0,144,141,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,12,0,0,218,8,0,0,244,6,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,179,35,0,208,163,35,0,0,0,0,0,135,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,1,0,0,0,0,0,0,0,0,0,0,38,2,0,0,220,2,0,0,0,0,0,0,0,0,0,0,192,151,29,0,64,57,29,0,0,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,24,244,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,124,1,0,0,0,0,0,0,242,8,0,0,0,0,0,0,0,0,0,0,224,73,33,0,64,29,32,0,0,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,3,0,0,0,0,0,0,0,0,0,0,136,2,0,0,70,5,0,0,0,0,0,0,0,0,0,0,16,180,35,0,232,163,35,0,1,0,0,0,1,32,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,4,0,0,0,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,180,35,0,16,164,35,0,1,0,0,0,0,32,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,1,0,0,0,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,237,30,0,200,141,34,0,200,224,32,0,128,237,30,0,0,32,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,1,0,0,156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,237,30,0,200,141,34,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,6,0,0,106,0,0,0,116,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,24,1,9,2,10,17,25,32,40,48,56,57,49,41,33,26,18,3,11,4,12,19,27,34,42,50,58,35,43,51,59,20,28,5,13,6,14,21,29,36,44,52,60,37,45,53,61,22,30,7,15,23,31,38,46,54,62,39,47,55,63,0,1,2,3,8,9,16,17,10,11,4,5,6,7,15,14,13,12,19,18,24,25,32,33,26,27,20,21,22,23,28,29,30,31,34,35,40,41,48,49,42,43,36,37,38,39,44,45,46,47,50,51,56,57,58,59,52,53,54,55,60,61,62,63,168,181,35,0,56,164,35,0,1,0,0,0,46,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,0,0,0,0,0,0,0,0,0,0,0,132,2,0,0,68,4,0,0,78,1,0,0,0,0,0,0,120,72,33,0,240,45,35,0,1,0,0,0,16,80,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,249,35,0,168,78,19,0,0,0,0,0,0,0,0,0,0,0,0,0,120,193,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,8,0,0,0,0,0,0,118,1,0,0,0,0,0,0,200,7,0,0,0,0,0,0,0,0,0,0,32,74,33,0,96,47,35,0,1,0,0,0,16,80,1,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,6,0,0,0,0,0,0,0,0,0,0,128,2,0,0,182,9,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,55,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,63,1,0,0,0,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,2,0,1,0,0,0,0,0,2,0,1,3,0,0,0,0,2,0,1,3,4,0,0,0,2,0,1,4,5,3,0,0,2,0,1,4,5,6,3,0,2,6,7,0,1,4,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,176,217,35,0,232,166,35,0,32,125,33,0,240,74,32,0,1,0,1,0,62,0,0,0,0,0,0,0,0,0,0,0,136,1,36,0,136,115,27,0,0,0,0,0,48,0,0,0,236,0,0,0,110,0,0,0,244,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,220,35,0,56,167,35,0,0,0,0,0,0,0,0,0,144,1,36,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,14,2,0,0,148,2,0,0,82,3,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,75,33,0,0,48,35,0,0,0,0,0,170,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,5,0,0,0,0,0,0,0,0,0,0,84,0,0,0,40,10,0,0,0,0,0,0,0,0,0,0,0,2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,120,220,35,0,88,167,35,0,0,224,0,0,120,220,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,226,4,0,0,114,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,252,30,0,176,146,34,0,160,4,2,0,40,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,0,0,0,96,1,0,0,8,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,6,31,0,72,148,34,0,216,204,26,0,96,204,26,0,200,6,2,0,0,0,1,0,96,4,0,0,0,0,0,0,10,1,0,0,36,2,0,0,184,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,40,15,31,0,0,97,30,0,248,234,13,0,80,20,9,0,152,205,2,0,0,0,0,0,234,3,0,0,0,0,0,0,90,1,0,0,192,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,9,31,0,0,149,34,0,128,172,6,0,24,171,6,0,248,172,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,2,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,11,31,0,128,150,34,0,168,94,8,0,48,94,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,98,5,0,0,156,203,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,15,31,0,192,151,34,0,144,13,9,0,184,12,9,0,8,14,9,0,0,0,0,0,166,6,0,0,0,0,0,0,186,0,0,0,164,10,0,0,176,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,198,35,0,32,113,35,0,248,234,13,0,80,20,9,0,48,178,11,0,0,0,0,0,34,8,0,0,0,0,0,0,90,1,0,0,192,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,21,31,0,72,154,34,0,0,0,0,0,80,205,26,0,192,110,13,0,1,0,0,0,120,1,0,0,0,0,0,0,138,0,0,0,208,4,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,23,35,0,16,211,34,0,248,234,13,0,80,20,9,0,32,102,14,0,0,0,0,0,20,3,0,0,0,0,0,0,90,1,0,0,192,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,41,31,0,32,161,34,0,248,234,13,0,80,20,9,0,248,120,20,0,0,0,0,0,124,8,0,0,0,0,0,0,90,1,0,0,192,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,22,31,0,224,154,34,0,120,132,20,0,0,132,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,25,31,0,8,156,34,0,56,177,21,0,64,175,21,0,176,177,21,0,0,0,0,0,30,0,0,0,0,0,0,0,222,0,0,0,246,6,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,26,31,0,120,156,34,0,200,205,26,0,0,0,0,0,96,197,22,0,2,0,0,0,112,2,0,0,0,0,0,0,0,0,0,0,78,9,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,29,31,0,24,157,34,0,184,206,26,0,64,206,26,0,64,198,22,0,0,0,0,0,190,6,0,0,0,0,0,0,0,0,0,0,26,9,0,0,32,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,37,34,0,128,245,33], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1256544);
/* memory initializer */ allocate([248,234,13,0,80,20,9,0,144,214,25,0,0,0,0,0,146,9,0,0,0,0,0,0,90,1,0,0,192,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,231,32,0,24,216,31,0,248,234,13,0,80,20,9,0,96,120,26,0,0,0,0,0,10,10,0,0,0,0,0,0,90,1,0,0,192,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,26,29,0,144,201,28,0,248,234,13,0,80,20,9,0,96,131,26,0,0,0,0,0,172,3,0,0,0,0,0,0,90,1,0,0,192,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,220,29,0,176,112,29,0,248,234,13,0,80,20,9,0,160,133,26,0,0,0,0,0,158,2,0,0,0,0,0,0,90,1,0,0,192,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,83,33,0,112,96,35,0,0,51,27,0,120,48,27,0,120,51,27,0,0,0,0,0,170,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,54,31,0,24,164,34,0,56,75,27,0,96,74,27,0,176,75,27,0,0,0,0,0,154,4,0,0,0,0,0,0,6,0,0,0,60,0,0,0,208,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,104,62,31,0,248,168,34,0,40,77,27,0,224,75,27,0,224,77,27,0,0,0,0,0,36,4,0,0,0,0,0,0,72,0,0,0,250,5,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,73,31,0,152,172,34,0,232,78,27,0,16,78,27,0,96,79,27,0,0,0,0,0,0,0,0,0,0,0,0,0,88,1,0,0,242,4,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,85,33,0,96,40,32,0,48,207,26,0,0,0,0,0,176,82,27,0,2,0,0,0,78,0,0,0,0,0,0,0,26,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,77,31,0,104,175,34,0,112,235,13,0,200,20,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,92,33,0,88,47,32,0,32,208,26,0,168,207,26,0,168,83,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,84,31,0,184,178,34,0,224,84,27,0,216,83,27,0,88,85,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,8,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,87,33,0,240,41,32,0,0,86,27,0,136,85,27,0,120,86,27,0,0,0,0,0,34,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,184,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,97,31,0,112,182,34,0,16,88,27,0,168,86,27,0,136,88,27,0,0,0,0,0,18,8,0,0,0,0,0,0,192,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,95,33,0,216,115,35,0,48,89,27,0,184,88,27,0,168,89,27,0,0,0,0,0,92,4,0,0,0,0,0,0,6,1,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,220,34,0,8,120,35,0,152,208,26,0,0,0,0,0,200,90,27,0,2,0,0,0,32,10,0,0,0,0,0,0,214,0,0,0,0,0,0,0,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,103,31,0,96,184,34,0,112,91,27,0,248,90,27,0,232,91,27,0,0,0,0,0,0,0,0,0,4,0,0,0,208,0,0,0,96,3,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,105,31,0,16,185,34,0,64,95,27,0,184,92,27,0,184,95,27,0,0,0,0,0,174,0,0,0,0,0,0,0,52,0,0,0,108,2,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,253,34,0,48,123,35,0,96,96,27,0,232,95,27,0,216,96,27,0,0,0,0,0,62,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,106,31,0,104,185,34,0,224,100,27,0,168,99,27,0,88,101,27,0,0,0,2,0,66,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,107,31,0,152,185,34,0,136,209,26,0,16,209,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,114,31,0,24,187,34,0,0,0,0,0,0,210,26,0,56,105,27,0,1,0,0,0,234,9,0,0,0,0,0,0,20,0,0,0,46,1,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,117,31,0,64,188,34,0,0,0,0,0,104,105,27,0,64,106,27,0,1,0,0,0,108,8,0,0,0,0,0,0,242,0,0,0,198,4,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,151,34,0,248,91,34,0,248,234,13,0,80,20,9,0,144,110,27,0,0,0,0,0,52,5,0,0,0,0,0,0,90,1,0,0,192,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,103,33,0,160,57,32,0,0,0,0,0,80,114,27,0,88,115,27,0,1,0,0,0,180,5,0,0,0,0,0,0,52,1,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,120,31,0,224,188,34,0,240,210,26,0,120,210,26,0,56,144,27,0,0,0,0,0,246,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,90,33,0,176,45,32,0,224,211,26,0,104,211,26,0,0,0,0,0,0,0,0,0,228,9,0,0,0,0,0,0,230,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,130,31,0,128,191,34,0,208,212,26,0,88,212,26,0,24,149,27,0,0,0,1,0,92,2,0,0,0,0,0,0,0,0,0,0,152,5,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,248,32,0,160,227,31,0,16,153,27,0,216,151,27,0,152,153,27,0,0,0,0,0,142,10,0,0,0,0,0,0,162,0,0,0,146,2,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,135,31,0,168,192,34,0,48,155,27,0,200,153,27,0,168,155,27,0,0,0,0,0,96,6,0,0,0,0,0,0,68,1,0,0,192,4,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,137,31,0,96,193,34,0,16,29,28,0,56,28,28,0,136,29,28,0,0,0,2,0,0,0,0,0,0,0,0,0,16,0,0,0,206,7,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,138,31,0,224,193,34,0,48,71,28,0,40,70,28,0,168,71,28,0,0,0,0,0,226,10,0,0,0,0,0,0,216,0,0,0,134,8,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,222,35,0,96,167,35,0,0,1,0,0,80,222,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,5,0,0,86,5,0,0,90,2,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,138,31,0,224,212,30,0,0,0,0,0,192,138,31,0,9,16,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,222,35,0,112,167,35,0,0,1,0,0,240,222,35,0,0,0,0,0,0,0,0,0,0,0,0,0,9,16,1,0,4,0,0,0,0,0,0,0,134,7,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,225,35,0,160,167,35,0,176,125,33,0,48,75,32,0,2,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,155,27,0,0,0,0,0,76,1,0,0,56,6,0,0,26,3,0,0,190,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,230,0,230,0,230,0,51,1,153,1,0,2,102,2,230,0,230,0,230,0,230,0,51,1,153,1,0,2,102,2,232,40,29,0,8,217,28,0,1,0,0,0,14,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,7,0,0,0,0,0,0,36,0,0,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,1,3,5,7,9,11,13,15,255,253,251,249,247,245,243,241,32,28,30,0,144,16,30,0,1,0,0,0,14,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,45,30,0,192,35,30,0,1,0,0,0,8,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,67,30,0,88,56,30,0,1,0,0,0,18,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,239,29,0,168,130,29,0,1,0,0,0,13,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,7,0,0,0,0,0,0,36,0,0,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,200,97,30,0,8,84,30,0,1,0,0,0,13,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,16,0,17,0,19,0,21,0,23,0,25,0,28,0,31,0,34,0,37,0,41,0,45,0,50,0,55,0,60,0,66,0,73,0,80,0,88,0,97,0,107,0,118,0,130,0,143,0,157,0,173,0,190,0,209,0,230,0,253,0,23,1,51,1,81,1,115,1,152,1,193,1,238,1,32,2,86,2,146,2,212,2,28,3,108,3,195,3,36,4,142,4,2,5,131,5,16,6,171,6,86,7,18,8,224,8,195,9,189,10,208,11,255,12,76,14,186,15,76,17,7,19,238,20,6,23,84,25,220,27,165,30,182,33,21,37,202,40,223,44,91,49,75,54,185,59,178,65,68,72,126,79,113,87,47,96,206,105,98,116,255,127,0,0,0,0,0,0,0,126,30,0,208,110,30,0,1,0,0,0,15,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,183,30,0,184,165,30,0,1,0,0,0,16,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,213,30,0,0,199,30,0,1,0,0,0,17,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,0,19,0,21,0,23,0,25,0,28,0,31,0,34,0,37,0,41,0,45,0,50,0,55,0,60,0,66,0,73,0,80,0,88,0,97,0,107,0,118,0,130,0,143,0,157,0,173,0,190,0,209,0,230,0,253,0,23,1,51,1,81,1,115,1,152,1,193,1,238,1,32,2,86,2,146,2,212,2,28,3,108,3,195,3,36,4,142,4,2,5,131,5,16,6,0,0,0,0,0,0,112,49,31,0,224,127,30,0,1,0,0,0,6,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,7,0,0,0,0,0,0,36,0,0,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,144,240,30,0,8,227,30,0,1,0,0,0,6,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,28,28,0,40,28,28,0,136,98,19,0,8,28,28,0,255,255,255,255,2,4,6,8,255,255,255,255,2,4,6,8,16,16,31,0,8,1,31,0,1,0,0,0,4,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,48,33,0,128,9,32,0,1,0,0,0,1,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,7,0,0,0,0,0,0,36,0,0,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,152,46,31,0,72,28,31,0,1,0,0,0,1,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,108,31,0,192,88,31,0,1,0,0,0,5,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,31,0,120,123,31,0,1,0,0,0,32,68,65,82,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,78,33,0,232,48,35,0,1,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,7,0,0,0,0,0,0,36,0,0,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,200,176,31,0,128,158,31,0,1,0,0,0,0,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,217,31,0,64,199,31,0,1,0,0,0,32,73,75,79,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,6,32,0,216,237,31,0,1,0,0,0,27,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,85,32,0,192,61,32,0,1,0,0,0,23,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,132,32,0,160,107,32,0,1,0,0,0,24,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,179,32,0,96,158,32,0,1,0,0,0,3,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,233,32,0,224,206,32,0,1,0,0,0,2,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,12,4,20,0,0,0,0,16,32,8,32,0,0,0,0,240,42,33,0,64,4,33,0,1,0,0,0,29,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,141,33,0,224,107,33,0,1,0,0,0,19,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,99,33,0,216,53,32,0,1,0,0,0,71,55,50,54,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,4,0,0,0,0,0,0,0,0,0,0,158,2,0,0,0,0,0,0,54,1,0,0,0,0,0,0,216,247,34,0,72,122,35,0,1,0,0,0,11,16,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,255,35,0,0,0,0,0,0,0,0,0,240,224,15,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,78,21,0,0,0,0,0,124,2,0,0,0,0,0,0,150,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,247,34,0,72,122,35,0,1,0,0,0,11,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,4,0,0,0,0,0,0,0,0,0,0,158,2,0,0,0,0,0,0,54,1,0,0,0,0,0,0,192,248,34,0,160,122,35,0,1,0,0,0,28,16,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,255,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,2,0,0,0,0,0,0,84,1,0,0,0,0,0,0,44,9,0,0,0,0,0,0,0,0,0,0,24,249,34,0,184,122,35,0,1,0,0,0,28,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,225,15,0,0,0,0,0,148,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,146,3,0,0,0,0,0,0,0,0,0,0,230,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,210,33,0,32,173,33,0,1,0,0,0,25,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,47,34,0,136,0,34,0,1,0,0,0,21,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,162,34,0,184,102,34,0,1,0,0,0,22,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,38,35,0,160,224,34,0,1,0,0,0,20,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,212,35,0,56,133,35,0,1,0,0,0,26,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,41,29,0,48,217,28,0,1,0,0,0,10,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,240,29,0,248,130,29,0,1,0,0,0,32,75,84,68,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,50,31,0,112,128,30,0,1,0,0,0,12,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,49,33,0,80,10,32,0,1,0,0,0,32,67,70,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,4,0,16,0,14,0,12,0,18,104,16,192,18,0,20,0,8,0,4,0,252,0,252,0,248,0,0,0,0,0,8,0,4,0,248,0,250,0,252,0,246,56,247,4,247,0,244,0,248,0,252,0,4,0,0,0,0,216,75,33,0,128,48,35,0,1,0,0,0,9,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,3,0,0,0,0,0,0,80,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,76,33,0,168,48,35,0,1,0,0,0,9,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,10,0,0,0,0,0,0,0,0,0,0,108,1,0,0,0,0,0,0,104,0,0,0,0,0,0,0,230,0,230,0,230,0,230,0,51,1,153,1,0,2,102,2,0,3,102,2,0,2,153,1,51,1,230,0,230,0,230,0,0,192,0,16,0,204,198,0,64,128,0,48,60,115,98,0,128,86,33,0,144,51,35,0,1,0,0,0,7,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,225,35,0,200,167,35,0,0,0,0,0,192,125,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,0,0,130,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,108,29,0,48,22,29,0,0,0,0,0,128,108,29,0,0,0,0,0,216,1,36,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,6,10,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,226,35,0,88,168,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,134,0,0,0,66,8,0,0,100,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,115,186,110,119,98,225,79,109,57,245,33,71,12,184,250,206,238,23,233,38,233,191,237,33,245,96,253,187,4,232,9,58,12,175,11,211,8,146,4,0,0,23,252,140,249,180,248,126,249,133,251,48,254,218,0,244,2,36,4,75,4,136,3,38,2,135,0,11,255,254,253,134,253,166,253,61,254,25,255,0,0,191,0,52,1,84,1,40,1,198,0,78,0,220,255,136,255,93,255,91,255,124,255,177,255,237,255,34,0,73,0,91,0,89,0,70,0,38,0,0,0,0,0,0,0,0,0,4,0,7,0,12,0,16,0,21,0,28,0,34,0,42,0,51,0,61,0,72,0,84,0,97,0,111,0,127,0,145,0,164,0,184,0,207,0,231,0,1,1,29,1,59,1,91,1,126,1,163,1,202,1,244,1,32,2,79,2,129,2,182,2,238,2,42,3,104,3,169,3,239,3,55,4,131,4,211,4,38,5,126,5,217,5,57,6,156,6,4,7,111,7,224,7,84,8,205,8,75,9,205,9,84,10,223,10,111,11,4,12,158,12,61,13,224,13,137,14,54,15,232,15,159,16,92,17,29,18,227,18,174,19,126,20,83,21,45,22,11,23,239,23,215,24,196,25,181,26,171,27,166,28,165,29,168,30,176,31,188,32,204,33,223,34,247,35,19,37,50,38,85,39,123,40,164,41,208,42,0,44,50,45,103,46,158,47,216,48,20,50,82,51,146,52,212,53,23,55,91,56,161,57,231,58,47,60,119,61,191,62,8,64,80,65,153,66,225,67,41,69,112,70,182,71,251,72,63,74,130,75,195,76,2,78,63,79,122,80,178,81,233,82,28,84,77,85,123,86,166,87,205,88,241,89,18,91,47,92,72,93,93,94,110,95,123,96,132,97,137,98,137,99,132,100,123,101,109,102,91,103,67,104,39,105,6,106,223,106,180,107,132,108,79,109,20,110,213,110,144,111,70,112,247,112,163,113,74,114,236,114,137,115,33,116,180,116,66,117,203,117,80,118,207,118,74,119,193,119,51,120,160,120,9,121,110,121,206,121,42,122,131,122,215,122,40,123,117,123,190,123,3,124,70,124,133,124,192,124,249,124,46,125,97,125,145,125,190,125,232,125,16,126,54,126,89,126,122,126,153,126,182,126,209,126,234,126,1,127,23,127,44,127,62,127,80,127,96,127,111,127,124,127,137,127,149,127,159,127,169,127,178,127,186,127,193,127,200,127,206,127,212,127,217,127,221,127,225,127,229,127,232,127,235,127,238,127,240,127,242,127,244,127,245,127,247,127,248,127,249,127,250,127,251,127,252,127,252,127,253,127,253,127,254,127,254,127,254,127,254,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,0,1,0,0,1,1,0,1,2,0,2,0,0,2,1,0,2,2,1,0,0,1,0,1,1,0,2,1,1,0,1,1,1,1,1,2,1,2,0,1,2,1,1,2,2,2,0,0,2,0,1,2,0,2,2,1,0,2,1,1,2,1,2,2,2,0,2,2,1,2,2,2,3,0,0,3,0,1,3,0,2,3,1,0,3,1,1,64,5,216,4,120,4,16,4,15,17,19,21,0,0,0,0,128,187,68,172,0,125,0,0,13,25,37,61,253,0,0,0,3,80,1,0,41,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,230,10,0,0,2,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,35,29,0,184,208,33,0,16,131,32,0,176,35,29,0,3,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,63,62,61,60,59,58,57,56,55,54,53,52,52,51,50,49,48,47,47,46,45,44,44,43,42,41,41,40,39,38,38,37,36,36,35,35,34,33,33,32,32,31,30,30,29,29,28,28,27,27,26,26,25,25,24,24,23,23,22,22,21,21,21,20,20,19,19,19,18,18,18,17,17,17,16,16,16,15,15,15,14,14,14,13,13,13,13,12,12,12,12,11,11,11,11,10,10,10,10,10,9,9,9,9,9,8,8,8,8,8,8,7,7,7,7,7,7,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,4,4,4,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,4,240,4,128,5,208,4,240,4,128,5,64,4,96,4,176,4,0,4,16,4,80,4,224,3,224,3,32,4,192,3,208,3,240,3,176,3,192,3,224,3,176,3,176,3,208,3,160,3,176,3,192,3,160,3,160,3,176,3,160,3,160,3,176,3,160,3,160,3,176,3,160,3,160,3,160,3,144,3,160,3,160,3,144,3,144,3,160,3,144,3,144,3,160,3,128,3,144,3,160,3,128,3,128,3,160,3,112,3,128,3,160,3,112,3,128,3,160,3,96,3,112,3,144,3,96,3,112,3,144,3,80,3,96,3,144,3,80,3,96,3,144,3,64,3,80,3,128,3,64,3,80,3,128,3,48,3,64,3,128,3,32,3,64,3,112,3,16,3,32,3,96,3,0,3,16,3,80,3,240,2,0,3,64,3,240,2,240,2,48,3,240,2,240,2,32,3,240,2,240,2,16,3,0,3,240,2,0,3,16,3,0,3,240,2,64,3,32,3,240,2,144,3,80,3,240,2,224,3,144,3,0,3,32,4,224,3,16,3,96,4,32,4,48,3,144,4,80,4,80,3,160,4,160,4,192,3,96,4,144,4,16,4,64,4,96,4,112,4,64,4,64,4,160,4,32,5,128,4,96,4,0,8,48,6,64,4,64,8,64,8,80,4,64,8,64,8,224,4,0,0,0,0,64,0,69,0,96,0,64,0,70,0,96,0,80,0,87,0,120,0,80,0,88,0,120,0,96,0,104,0,144,0,96,0,105,0,144,0,112,0,121,0,168,0,112,0,122,0,168,0,128,0,139,0,192,0,128,0,140,0,192,0,160,0,174,0,240,0,160,0,175,0,240,0,192,0,208,0,32,1,192,0,209,0,32,1,224,0,243,0,80,1,224,0,244,0,80,1,0,1,22,1,128,1,0,1,23,1,128,1,64,1,92,1,224,1,64,1,93,1,224,1,128,1,161,1,64,2,128,1,162,1,64,2,192,1,231,1,160,2,192,1,232,1,160,2,0,2,45,2,0,3,0,2,46,2,0,3,128,2,184,2,192,3,128,2,185,2,192,3,0,3,67,3,128,4,0,3,68,3,128,4,128,3,207,3,64,5,128,3,208,3,64,5,0,4,90,4,0,6,0,4,91,4,0,6,128,4,229,4,192,6,128,4,230,4,192,6,0,5,113,5,128,7,0,5,114,5,128,7,0,0,0,0,240,2,176,2,112,2,48,2,240,1,112,1,240,0,0,248,248,52,33,0,0,13,32,0,1,0,0,0,3,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,249,35,0,56,122,19,0,0,0,0,0,216,139,28,0,0,0,0,0,160,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,162,28,0,0,0,0,0,236,7,0,0,0,0,0,0,80,1,0,0,0,0,0,0,174,5,0,0,0,0,0,0,0,0,0,0,128,0,0,1,128,1,0,2,128,2,0,3,128,3,0,4,63,83,103,123,0,0,0,0,168,51,33,0,64,12,32,0,1,0,0,0,3,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,249,35,0,56,122,19,0,0,0,0,0,168,139,28,0,0,0,0,0,160,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,162,28,0,0,0,0,0,116,10,0,0,0,0,0,0,10,2,0,0,0,0,0,0,174,5,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,2,0,0,0,0,2,1,0,0,0,0,2,1,3,0,0,0,1,2,0,0,0,0,1,3,2,0,0,0,2,1,3,0,0,0,2,1,4,3,0,0,1,2,3,0,0,0,1,3,4,2,0,0,2,1,3,4,0,0,2,1,4,5,3,104,230,35,0,112,168,35,0,0,1,0,0,104,230,35,0,0,0,0,0,0,0,0,0,0,0,0,0,3,80,1,0,0,0,0,0,174,9,0,0,138,1,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,102,33,0,144,58,35,0,1,0,0,0,3,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,249,35,0,0,0,0,0,0,0,0,0,168,162,28,0,0,0,0,0,32,211,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,1,0,0,0,0,0,0,0,0,0,0,138,0,0,0,160,8,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,2,0,0,0,0,2,1,0,0,0,0,2,1,3,0,0,0,1,2,0,0,0,0,1,3,2,0,0,0,2,1,3,0,0,0,2,1,4,3,0,0,1,2,3,0,0,0,1,4,2,3,0,0,2,1,3,4,0,0,2,1,5,3,4,0,0,0,7,0,9,0,11,2,1,2,3,3,4,4,5,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,7,0,0,0,0,0,0,0,3,6,0,0,0,0,0,0,51,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,7,6,0,0,0,0,0,0,55,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,11,1,0,0,0,0,0,0,15,0,0,0,0,0,0,0,11,6,0,0,0,0,0,0,59,0,0,0,0,0,0,0,15,1,0,0,0,0,0,0,15,6,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,160,0,192,0,224,0,0,1,64,1,128,1,192,1,0,2,64,2,128,2,0,0,0,1,1,1,1,1,2,2,3,3,3,4,4,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,31,34,37,40,43,46,49,55,61,67,73,79,85,97,109,121,133,157,181,205,229,253,0,0,0,0,0,104,103,33,0,200,58,35,0,0,0,0,0,75,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,4,0,0,0,0,0,0,0,0,0,0,200,1,0,0,150,4,0,0,0,0,0,0,0,0,0,0,0,64,197,88,159,83,66,75,0,64,73,50,163,34,168,17,197,88,33,123,252,115,98,104,197,88,191,69,11,48,126,24,159,83,252,115,65,109,84,98,159,83,179,65,65,45,18,23,66,75,98,104,84,98,126,88,66,75,33,59,186,40,195,20,0,64,197,88,159,83,66,75,0,64,73,50,163,34,168,17,73,50,191,69,179,65,33,59,73,50,130,39,55,27,224,13,163,34,11,48,65,45,186,40,163,34,55,27,191,18,142,9,168,17,126,24,18,23,195,20,168,17,224,13,142,9,223,4,81,0,81,0,81,0,81,0,81,0,81,0,64,0,64], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1266784);
/* memory initializer */ allocate([169,0,169,0,33,1,0,0,64,80,22,0,248,75,22,0,80,75,22,0,168,74,22,0,0,74,22,0,88,73,22,0,216,72,22,0,88,72,22,0,0,71,22,0,232,78,22,0,160,76,22,0,0,0,0,0,56,182,25,0,8,180,25,0,176,179,25,0,88,179,25,0,0,179,25,0,168,178,25,0,104,178,25,0,40,178,25,0,120,177,25,0,136,181,25,0,96,180,25,0,0,0,0,0,232,255,3,0,230,255,3,0,231,255,3,0,229,255,3,0,245,255,7,0,241,255,7,0,237,255,7,0,246,255,7,0,238,255,7,0,239,255,7,0,240,255,7,0,252,255,7,0,253,255,7,0,255,255,7,0,254,255,7,0,247,255,7,0,248,255,7,0,251,255,7,0,249,255,7,0,228,255,3,0,250,255,7,0,227,255,3,0,239,255,1,0,240,255,1,0,245,255,0,0,238,255,1,0,242,255,0,0,243,255,0,0,244,255,0,0,241,255,0,0,246,127,0,0,247,127,0,0,249,63,0,0,245,63,0,0,247,63,0,0,243,63,0,0,246,63,0,0,242,63,0,0,247,31,0,0,245,31,0,0,249,15,0,0,247,15,0,0,246,15,0,0,249,7,0,0,244,15,0,0,248,7,0,0,249,3,0,0,247,3,0,0,245,3,0,0,248,1,0,0,247,1,0,0,250,0,0,0,248,0,0,0,246,0,0,0,121,0,0,0,58,0,0,0,56,0,0,0,26,0,0,0,11,0,0,0,4,0,0,0,0,0,0,0,10,0,0,0,12,0,0,0,27,0,0,0,57,0,0,0,59,0,0,0,120,0,0,0,122,0,0,0,247,0,0,0,249,0,0,0,246,1,0,0,249,1,0,0,244,3,0,0,246,3,0,0,248,3,0,0,245,7,0,0,244,7,0,0,246,7,0,0,247,7,0,0,245,15,0,0,248,15,0,0,244,31,0,0,246,31,0,0,248,31,0,0,248,63,0,0,244,63,0,0,240,255,0,0,244,127,0,0,246,255,0,0,245,127,0,0,226,255,3,0,217,255,7,0,218,255,7,0,219,255,7,0,220,255,7,0,221,255,7,0,222,255,7,0,216,255,7,0,210,255,7,0,211,255,7,0,212,255,7,0,213,255,7,0,214,255,7,0,242,255,7,0,223,255,7,0,231,255,7,0,232,255,7,0,233,255,7,0,234,255,7,0,235,255,7,0,230,255,7,0,224,255,7,0,225,255,7,0,226,255,7,0,227,255,7,0,228,255,7,0,229,255,7,0,215,255,7,0,236,255,7,0,244,255,7,0,243,255,7,0,0,0,0,0,18,18,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,18,19,18,17,17,16,17,16,16,16,16,15,15,14,14,14,14,14,14,13,13,12,12,12,11,12,11,10,10,10,9,9,8,8,8,7,6,6,5,4,3,1,4,4,5,6,6,7,7,8,8,9,9,10,10,10,11,11,11,11,12,12,13,13,13,14,14,16,15,16,15,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,0,0,0,0,0,0,80,28,33,0,156,1,0,0,18,1,0,0,116,2,0,0,96,0,0,0,0,0,0,0,33,33,38,40,40,40,41,41,37,37,37,34,34,0,0,0,2,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,174,6,0,0,2,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,37,31,31,0,0,0,0,0,0,0,0,12,12,12,14,14,14,15,15,15,15,15,15,15,0,0,0,41,41,47,49,49,51,47,47,43,43,43,40,40,0,0,0,50,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,56,33,0,8,15,32,0,1,0,0,0,50,80,1,0,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,246,35,0,176,170,28,0,0,0,0,0,0,0,0,0,0,0,0,0,192,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,10,0,0,0,0,0,0,0,0,0,0,170,1,0,0,128,7,0,0,236,0,0,0,0,0,0,0,64,115,33,0,96,61,35,0,1,0,0,0,2,80,1,0,96,2,0,0,0,0,0,0,0,0,0,0,240,215,9,0,168,249,35,0,0,0,0,0,0,0,0,0,224,169,28,0,0,0,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,6,0,0,0,0,0,0,88,0,0,0,0,0,0,0,122,4,0,0,0,0,0,0,0,0,0,0,233,14,94,59,231,9,186,59,38,226,10,60,33,32,64,60,4,24,123,60,84,24,157,60,243,244,189,60,182,148,223,60,129,204,0,61,11,212,17,61,172,182,34,61,90,101,51,61,96,234,67,61,112,79,84,61,157,156,100,61,248,216,116,61,200,133,130,61,184,157,138,61,169,183,146,61,12,212,154,61,219,240,162,61,169,12,171,61,189,38,179,61,214,63,187,61,212,89,195,61,208,118,203,61,0,153,211,61,126,194,219,61,233,244,227,61,112,49,236,61,245,120,244,61,180,205,252,61,157,153,2,62,89,214,6,62,100,30,11,62,133,114,15,62,18,211,19,62,85,64,24,62,136,186,28,62,95,65,33,62,27,212,37,62,13,114,42,62,154,26,47,62,231,204,51,62,236,135,56,62,193,74,61,62,167,20,66,62,19,229,70,62,165,187,75,62,19,152,80,62,36,122,85,62,166,97,90,62,98,78,95,62,29,64,100,62,159,54,105,62,222,49,110,62,0,50,115,62,24,55,120,62,42,65,125,62,19,40,129,62,249,177,131,62,51,62,134,62,171,204,136,62,80,93,139,62,32,240,141,62,14,133,144,62,12,28,147,62,247,180,149,62,159,79,152,62,214,235,154,62,110,137,157,62,253,39,160,62,234,198,162,62,185,101,165,62,9,4,168,62,147,161,170,62,35,62,173,62,139,217,175,62,169,115,178,62,158,12,181,62,186,164,183,62,57,60,186,62,57,211,188,62,185,105,191,62,163,255,193,62,225,148,196,62,88,41,199,62,224,188,201,62,72,79,204,62,101,224,206,62,20,112,209,62,32,254,211,62,80,138,214,62,118,20,217,62,117,156,219,62,42,34,222,62,109,165,224,62,28,38,227,62,34,164,229,62,161,31,232,62,224,152,234,62,11,16,237,62,51,133,239,62,67,248,241,62,26,105,244,62,154,215,246,62,175,67,249,62,56,173,251,62,15,20,254,62,14,60,0,63,171,108,1,63,230,155,2,63,200,201,3,63,88,246,4,63,150,33,6,63,129,75,7,63,25,116,8,63,91,155,9,63,70,193,10,63,214,229,11,63,10,9,13,63,226,42,14,63,94,75,15,63,129,106,16,63,79,136,17,63,204,164,18,63,254,191,19,63,237,217,20,63,163,189,21,63,214,212,22,63,150,234,23,63,229,254,24,63,194,17,26,63,47,35,27,63,44,51,28,63,185,65,29,63,216,78,30,63,136,90,31,63,203,100,32,63,162,109,33,63,16,117,34,63,23,123,35,63,187,127,36,63,254,130,37,63,223,132,38,63,96,133,39,63,128,132,40,63,66,130,41,63,166,126,42,63,173,121,43,63,88,115,44,63,168,107,45,63,157,98,46,63,54,88,47,63,115,76,48,63,84,63,49,63,216,48,50,63,252,32,51,63,193,15,52,63,35,253,52,63,35,233,53,63,189,211,54,63,241,188,55,63,187,164,56,63,28,139,57,63,16,112,58,63,150,83,59,63,171,53,60,63,75,22,61,63,114,245,61,63,27,211,62,63,69,175,63,63,237,137,64,63,16,99,65,63,173,58,66,63,193,16,67,63,68,229,67,63,52,184,68,63,137,137,69,63,65,89,70,63,87,39,71,63,201,243,71,63,146,190,72,63,176,135,73,63,31,79,74,63,218,20,75,63,222,216,75,63,39,155,76,63,176,91,77,63,116,26,78,63,110,215,78,63,156,146,79,63,247,75,80,63,125,3,81,63,42,185,81,63,249,108,82,63,232,30,83,63,246,206,83,63,31,125,84,63,97,41,85,63,185,211,85,63,36,124,86,63,161,34,87,63,46,199,87,63,199,105,88,63,106,10,89,63,22,169,89,63,202,69,90,63,132,224,90,63,70,121,91,63,13,16,92,63,219,164,92,63,177,55,93,63,141,200,93,63,113,87,94,63,94,228,94,63,88,111,95,63,99,248,95,63,130,127,96,63,184,4,97,63,10,136,97,63,125,9,98,63,21,137,98,63,218,6,99,63,215,130,99,63,21,253,99,63,160,117,100,63,131,236,100,63,202,97,101,63,127,213,101,63,174,71,102,63,106,184,102,63,202,39,103,63,230,149,103,63,216,2,104,63,184,110,104,63,160,217,104,63,167,67,105,63,233,172,105,63,131,21,106,63,153,125,106,63,80,229,106,63,203,76,107,63,26,180,107,63,62,27,108,63,53,130,108,63,250,232,108,63,46,79,109,63,30,180,109,63,14,23,110,63,67,119,110,63,173,211,110,63,235,42,111,63,154,123,111,63,90,196,111,63,81,4,112,63,107,94,112,63,60,113,112,63,169,134,112,63,34,158,112,63,234,182,112,63,69,208,112,63,122,233,112,63,68,2,113,63,210,26,113,63,87,51,113,63,6,76,113,63,243,100,113,63,19,126,113,63,89,151,113,63,185,176,113,63,45,202,113,63,186,227,113,63,97,253,113,63,37,23,114,63,9,49,114,63,14,75,114,63,51,101,114,63,121,127,114,63,226,153,114,63,107,180,114,63,21,207,114,63,224,233,114,63,203,4,115,63,217,31,115,63,10,59,115,63,96,86,115,63,219,113,115,63,122,141,115,63,60,169,115,63,31,197,115,63,36,225,115,63,77,253,115,63,155,25,116,63,16,54,116,63,173,82,116,63,112,111,116,63,87,140,116,63,98,169,116,63,145,198,116,63,228,227,116,63,94,1,117,63,1,31,117,63,204,60,117,63,189,90,117,63,212,120,117,63,14,151,117,63,107,181,117,63,237,211,117,63,149,242,117,63,100,17,118,63,90,48,118,63,116,79,118,63,178,110,118,63,16,142,118,63,144,173,118,63,50,205,118,63,247,236,118,63,225,12,119,63,239,44,119,63,31,77,119,63,111,109,119,63,222,141,119,63,108,174,119,63,24,207,119,63,229,239,119,63,211,16,120,63,225,49,120,63,15,83,120,63,89,116,120,63,190,149,120,63,61,183,120,63,214,216,120,63,140,250,120,63,95,28,121,63,78,62,121,63,88,96,121,63,121,130,121,63,177,164,121,63,254,198,121,63,97,233,121,63,221,11,122,63,113,46,122,63,28,81,122,63,222,115,122,63,180,150,122,63,155,185,122,63,148,220,122,63,158,255,122,63,188,34,123,63,238,69,123,63,52,105,123,63,141,140,123,63,245,175,123,63,107,211,123,63,239,246,123,63,129,26,124,63,35,62,124,63,213,97,124,63,152,133,124,63,106,169,124,63,72,205,124,63,49,241,124,63,37,21,125,63,37,57,125,63,50,93,125,63,77,129,125,63,119,165,125,63,173,201,125,63,237,237,125,63,55,18,126,63,137,54,126,63,229,90,126,63,76,127,126,63,193,163,126,63,66,200,126,63,207,236,126,63,103,17,127,63,7,54,127,63,175,90,127,63,94,127,127,63,18,164,127,63,202,200,127,63,132,237,127,63,63,9,128,63,161,27,128,63,8,46,128,63,113,64,128,63,222,82,128,63,76,101,128,63,188,119,128,63,45,138,128,63,158,156,128,63,14,175,128,63,125,193,128,63,234,211,128,63,87,230,128,63,197,248,128,63,51,11,129,63,162,29,129,63,16,48,129,63,126,66,129,63,234,84,129,63,83,103,129,63,187,121,129,63,35,140,129,63,138,158,129,63,240,176,129,63,86,195,129,63,185,213,129,63,25,232,129,63,117,250,129,63,206,12,130,63,38,31,130,63,123,49,130,63,206,67,130,63,31,86,130,63,107,104,130,63,177,122,130,63,243,140,130,63,47,159,130,63,103,177,130,63,155,195,130,63,203,213,130,63,246,231,130,63,26,250,130,63,55,12,131,63,76,30,131,63,89,48,131,63,95,66,131,63,96,84,131,63,89,102,131,63,75,120,131,63,52,138,131,63,18,156,131,63,230,173,131,63,176,191,131,63,113,209,131,63,40,227,131,63,215,244,131,63,122,6,132,63,18,24,132,63,158,41,132,63,28,59,132,63,141,76,132,63,243,93,132,63,77,111,132,63,155,128,132,63,220,145,132,63,15,163,132,63,52,180,132,63,73,197,132,63,80,214,132,63,72,231,132,63,51,248,132,63,17,9,133,63,223,25,133,63,158,42,133,63,77,59,133,63,234,75,133,63,119,92,133,63,244,108,133,63,98,125,133,63,193,141,133,63,15,158,133,63,77,174,133,63,120,190,133,63,145,206,133,63,153,222,133,63,145,238,133,63,121,254,133,63,81,14,134,63,25,30,134,63,208,45,134,63,116,61,134,63,7,77,134,63,137,92,134,63,250,107,134,63,93,123,134,63,176,138,134,63,244,153,134,63,40,169,134,63,74,184,134,63,91,199,134,63,92,214,134,63,78,229,134,63,48,244,134,63,4,3,135,63,200,17,135,63,126,32,135,63,36,47,135,63,186,61,135,63,65,76,135,63,185,90,135,63,35,105,135,63,127,119,135,63,208,133,135,63,22,148,135,63,83,162,135,63,133,176,135,63,164,190,135,63,170,204,135,63,144,218,135,63,97,232,135,63,57,246,135,63,55,4,136,63,116,18,136,63,201,32,136,63,206,46,136,63,24,60,136,63,60,72,136,63,231,82,136,63,184,75,136,63,3,72,136,63,230,63,136,63,198,51,136,63,127,36,136,63,234,18,136,63,210,255,135,63,206,235,135,63,62,215,135,63,126,194,135,63,228,173,135,63,123,153,135,63,8,133,135,63,79,112,135,63,22,91,135,63,57,69,135,63,163,46,135,63,65,23,135,63,3,255,134,63,250,229,134,63,86,204,134,63,73,178,134,63,0,152,134,63,154,125,134,63,35,99,134,63,166,72,134,63,46,46,134,63,181,19,134,63,38,249,133,63,106,222,133,63,108,195,133,63,5,168,133,63,0,140,133,63,38,111,133,63,67,81,133,63,52,50,133,63,228,17,133,63,66,240,132,63,60,205,132,63,209,168,132,63,16,131,132,63,9,92,132,63,202,51,132,63,109,10,132,63,19,224,131,63,225,180,131,63,246,136,131,63,108,92,131,63,87,47,131,63,200,1,131,63,207,211,130,63,118,165,130,63,189,118,130,63,163,71,130,63,41,24,130,63,66,232,129,63,218,183,129,63,217,134,129,63,44,85,129,63,191,34,129,63,130,239,128,63,101,187,128,63,89,134,128,63,75,80,128,63,37,25,128,63,163,193,127,63,119,78,127,63,175,216,126,63,72,96,126,63,66,229,125,63,158,103,125,63,175,231,124,63,26,102,124,63,132,227,123,63,145,96,123,63,178,221,122,63,37,91,122,63,36,217,121,63,230,87,121,63,44,215,120,63,67,86,120,63,115,212,119,63,8,81,119,63,153,203,118,63,8,68,118,63,57,186,117,63,18,46,117,63,152,159,116,63,240,14,116,63,63,124,115,63,174,231,114,63,137,81,114,63,70,186,113,63,92,34,113,63,64,138,112,63,87,242,111,63,244,90,111,63,106,196,110,63,6,47,110,63,111,154,109,63,168,5,109,63,174,111,108,63,133,215,107,63,204,60,107,63,190,159,106,63,158,0,106,63,174,95,105,63,98,189,104,63,89,26,104,63,53,119,103,63,147,212,102,63,149,50,102,63,224,144,101,63,21,239,100,63,214,76,100,63,235,169,99,63,65,6,99,63,199,97,98,63,109,188,97,63,56,22,97,63,64,111,96,63,158,199,95,63,108,31,95,63,194,118,94,63,186,205,93,63,108,36,93,63,243,122,92,63,102,209,91,63,152,37,91,63,76,123,90,63,14,208,89,63,255,35,89,63,61,119,88,63,232,201,87,63,30,28,87,63,254,109,86,63,167,191,85,63,55,17,85,63,202,98,84,63,101,180,83,63,240,5,83,63,83,87,82,63,117,168,81,63,12,249,80,63,161,72,80,63,184,150,79,63,222,226,78,63,55,45,78,63,124,118,77,63,112,191,76,63,209,8,76,63,49,83,75,63,242,158,74,63,117,236,73,63,19,60,73,63,74,141,72,63,196,222,71,63,31,47,71,63,5,125,70,63,237,199,69,63,33,16,69,63,244,85,68,63,186,153,67,63,241,219,66,63,66,29,66,63,88,94,65,63,220,159,64,63,69,226,63,63,219,37,63,63,226,106,62,63,158,177,61,63,30,250,60,63,64,68,60,63,224,143,59,63,210,220,58,63,97,42,58,63,77,119,57,63,79,194,56,63,43,10,56,63,90,78,55,63,18,143,54,63,142,204,53,63,16,7,53,63,76,63,52,63,107,118,51,63,153,173,50,63,252,229,49,63,53,32,49,63,92,92,48,63,131,154,47,63,186,218,46,63,231,28,46,63,200,96,45,63,24,166,44,63,144,236,43,63,233,51,43,63,212,123,42,63,4,196,41,63,43,12,41,63,231,83,40,63,195,154,39,63,73,224,38,63,5,36,38,63,164,101,37,63,248,164,36,63,212,225,35,63,13,28,35,63,191,83,34,63,69,137,33,63,1,189,32,63,87,239,31,63,213,32,31,63,59,82,30,63,73,132,29,63,190,183,28,63,51,237,27,63,30,37,27,63,243,95,26,63,34,158,25,63,221,223,24,63,21,37,24,63,183,109,23,63,173,185,22,63,90,8,22,63,159,88,21,63,87,169,20,63,90,249,19,63,109,71,19,63,63,146,18,63,125,216,17,63,223,24,17,63,36,83,16,63,9,136,15,63,93,184,14,63,239,228,13,63,48,15,13,63,43,57,12,63,242,100,11,63,144,148,10,63,70,201,9,63,146,3,9,63,231,67,8,63,173,138,7,63,31,215,6,63,75,39,6,63,53,121,5,63,228,202,4,63,234,26,4,63,101,104,3,63,118,178,2,63,71,248,1,63,223,57,1,63,34,120,0,63,245,103,255,62,167,220,253,62,40,80,252,62,154,206,250,62,97,61,249,62,227,179,247,62,114,50,246,62,238,183,244,62,32,67,243,62,208,210,241,62,116,101,240,62,47,249,238,62,35,140,237,62,129,28,236,62,183,169,234,62,116,52,233,62,115,189,231,62,117,69,230,62,120,205,228,62,193,86,227,62,148,226,225,62,40,114,224,62,91,5,223,62,177,154,221,62,160,48,220,62,164,197,218,62,208,88,217,62,206,233,215,62,77,120,214,62,6,4,213,62,129,141,211,62,21,22,210,62,33,159,208,62,254,41,207,62,88,183,205,62,49,71,204,62,131,217,202,62,69,110,201,62,69,5,200,62,39,158,198,62,143,56,197,62,31,212,195,62,135,112,194,62,131,13,193,62,208,170,191,62,44,72,190,62,136,229,188,62,5,131,187,62,196,32,186,62,233,190,184,62,132,93,183,62,147,252,181,62,23,156,180,62,14,60,179,62,124,220,177,62,111,125,176,62,242,30,175,62,17,193,173,62,215,99,172,62,84,7,171,62,146,171,169,62,160,80,168,62,129,246,166,62,50,157,165,62,173,68,164,62,238,236,162,62,239,149,161,62,170,63,160,62,28,234,158,62,67,149,157,62,35,65,156,62,196,237,154,62,45,155,153,62,102,73,152,62,115,248,150,62,85,168,149,62,9,89,148,62,144,10,147,62,237,188,145,62,38,112,144,62,65,36,143,62,67,217,141,62,48,143,140,62,4,70,139,62,189,253,137,62,90,182,136,62,221,111,135,62,80,42,134,62,189,229,132,62,43,162,131,62,161,95,130,62,31,30,129,62,80,187,127,62,121,60,125,62,190,191,122,62,41,69,120,62,196,204,117,62,151,86,115,62,166,226,112,62,235,112,110,62,97,1,108,62,4,148,105,62,213,40,103,62,223,191,100,62,44,89,98,62,199,244,95,62,175,146,93,62,218,50,91,62,62,213,88,62,207,121,86,62,136,32,84,62,104,201,81,62,112,116,79,62,159,33,77,62,235,208,74,62,69,130,72,62,154,53,70,62,217,234,67,62,248,161,65,62,244,90,63,62,207,21,61,62,135,210,58,62,68,145,56,62,83,82,54,62,2,22,52,62,163,220,49,62,129,166,47,62,238,115,45,62,55,69,43,62,172,26,41,62,155,244,38,62,127,218,36,62,226,199,34,62,49,186,32,62,34,177,30,62,110,172,28,62,199,171,26,62,228,174,24,62,122,181,22,62,64,191,20,62,234,203,18,62,46,219,16,62,239,236,14,62,54,1,13,62,17,24,11,62,139,49,9,62,176,77,7,62,136,108,5,62,27,142,3,62,115,178,1,62,53,179,255,61,69,7,252,61,53,97,248,61,34,193,244,61,35,39,241,61,58,147,237,61,114,5,234,61,206,125,230,61,95,252,226,61,55,129,223,61,111,12,220,61,23,158,216,61,57,54,213,61,212,212,209,61,227,121,206,61,99,37,203,61,90,215,199,61,218,143,196,61,240,78,193,61,174,20,190,61,23,225,186,61,37,180,183,61,208,141,180,61,15,110,177,61,232,84,174,61,102,66,171,61,155,54,168,61,147,49,165,61,81,51,162,61,202,59,159,61,244,74,156,61,198,96,153,61,64,125,150,61,111,160,147,61,97,202,144,61,35,251,141,61,181,50,139,61,12,113,136,61,26,182,133,61,212,1,131,61,58,84,128,61,175,90,123,61,110,26,118,61,202,231,112,61,188,194,107,61,40,171,102,61,237,160,97,61,240,163,92,61,44,180,87,61,177,209,82,61,149,252,77,61,232,52,73,61,172,122,68,61,195,205,63,61,23,46,59,61,141,155,54,61,42,22,50,61,8,158,45,61,74,51,41,61,8,214,36,61,72,134,32,61,235,67,28,61,213,14,24,61,237,230,19,61,35,204,15,61,122,190,11,61,242,189,7,61,144,202,3,61,71,200,255,60,186,20,248,60,197,121,240,60,202,246,232,60,107,139,225,60,175,55,218,60,144,251,210,60,20,215,203,60,117,202,196,60,42,214,189,60,163,250,182,60,87,56,176,60,60,144,169,60,176,3,163,60,26,148,156,60,210,66,150,60,189,15,144,60,62,249,137,60,182,253,131,60,253,54,124,60,213,162,112,60,81,61,101,60,15,5,90,60,140,248,78,60,105,24,68,60,31,103,57,60,84,231,46,60,128,155,36,60,132,131,26,60,166,156,16,60,0,228,6,60,198,173,250,59,29,233,231,59,223,124,213,59,187,107,195,59,202,184,177,59,105,103,160,59,95,124,143,59,191,248,125,59,99,216,93,59,78,147,62,59,184,23,32,59,44,83,2,59,191,101,202,58,179,66,145,58,188,21,50,58,249,40,134,57,253,131,43,185,5,198,23,186,151,149,129,186,134,78,182,186,26,212,233,186,143,234,13,187,242,244,37,187,178,212,60,187,80,87,82,187,14,113,102,187,69,62,121,187,62,110,133,187,31,181,141,187,88,139,149,187,199,16,157,187,144,101,164,187,124,169,171,187,86,239,178,187,126,61,186,187,168,153,193,187,200,8,201,187,163,129,208,187,59,236,215,187,60,48,223,187,84,53,230,187,32,232,236,187,244,57,243,187,97,28,249,187,58,129,254,187,70,177,1,188,86,225,3,188,252,209,5,188,185,132,7,188,128,253,8,188,250,66,10,188,9,92,11,188,78,79,12,188,254,34,13,188,130,220,13,188,66,129,14,188,180,22,15,188,167,160,15,188,150,33,16,188,218,155,16,188,192,17,17,188,245,130,17,188,167,236,17,188,253,75,18,188,8,158,18,188,172,223,18,188,153,13,19,188,138,36,19,188,69,33,19,188,185,0,19,188,55,192,18,188,250,92,18,188,126,212,17,188,237,37,17,188,147,82,16,188,157,91,15,188,99,66,14,188,158,9,13,188,128,181,11,188,60,74,10,188,247,203,8,188,90,63,7,188,109,169,5,188,36,15,4,188,69,117,2,188,255,220,0,188,240,135,254,187,87,79,251,187,84,11,248,187,73,181,244,187,189,69,241,187,207,180,237,187,70,251,233,187,137,21,230,187,23,4,226,187,113,199,221,187,110,96,217,187,22,211,212,187,244,38,208,187,150,99,203,187,93,144,198,187,103,178,193,187,100,204,188,187,24,225,183,187,7,243,178,187,157,2,174,187,65,14,169,187,114,20,164,187,129,19,159,187,192,8,154,187,189,240,148,187,10,200,143,187,116,139,138,187,148,59,133,187,94,185,127,187,27,230,116,187,238,5,106,187,178,29,95,187,152,47,84,187,32,61,73,187,164,71,62,187,36,80,51,187,34,87,40,187,243,92,29,187,110,98,18,187,20,104,7,187,117,220,248,186,112,234,226,186,199,251,204,186,209,18,183,186,67,52,161,186,121,101,139,186,248,84,107,186,167,16,64,186,184,6,21,186,114,126,212,185,62,14,127,185,136,211,172,184,148,66,172,56,80,186,124,57,103,78,209,57,203,232,17,58,243,231,58,58,241,155,99,58,175,252,133,58,191,251,153,58,33,198,173,58,35,87,193,58,189,170,212,58,148,189,231,58,253,142,250,58,208,142,6,59,147,180,15,59,199,183,24,59,20,151,33,59,163,81,42,59,155,229,50,59,167,82,59,59,27,152,67,59,33,182,75,59,187,172,83,59,140,120,91,59,12,20,99,59,48,121,106,59,154,162,113,59,115,143,120,59,109,67,127,59,6,225,130,59,22,7,134,59,190,21,137,59,129,14,140,59,56,243,142,59,101,197,145,59,94,133,148,59,246,49,151,59,22,202,153,59,167,76,156,59,186,182,158,59,134,3,161,59,45,46,163,59,63,50,165,59,160,13,167,59,126,192,168,59,2,75,170,59,152,173,171,59,175,234,172,59,121,6,174,59,103,5,175,59,107,235,175,59,139,188,176,59,208,124,177,59,254,47,178,59,199,217,178,59,127,121,179,59,116,10,180,59,221,135,180,59,93,237,180,59,110,54,181,59,113,94,181,59,245,96,181,59,222,57,181,59,146,230,180,59,79,102,180,59,19,184,179,59,95,219,178,59,202,209,177,59,47,159,176,59,129,71,175,59,111,206,173,59,215,55,172,59,190,135,170,59,22,194,168,59,123,234,166,59,156,4,165,59,236,19,163,59,217,27,161,59,128,31,159,59,161,31,157,59,77,26,155,59,174,13,153,59,20,248,150,59,102,214,148,59,114,164,146,59,28,94,144,59,136,255,141,59,2,132,139,59,110,230,136,59,152,33,134,59,226,48,131,59,201,17,128,59,195,136,121,59,130,145,114,59,39,62,107,59,231,149,99,59,4,166,91,59,233,123,83,59,45,37,75,59,24,179,66,59,207,58,58,59,73,209,49,59,168,138,41,59,251,110,33,59,103,123,25,59,144,172,17,59,113,254,9,59,157,99,2,59,218,137,245,58,119,23,230,58,198,68,214,58,231,241,197,58,189,12,181,58,39,131,163,58,182,68,145,58,84,188,124,58,55,240,85,58,162,119,46,58,32,165,6,58,60,114,189,57,98,146,91,57,28,126,117,56,196,245,189,184,1,98,121,185,168,40,201,185,107,146,10,186,250,114,48,186,50,82,86,186,143,71,124,186,157,53,145,186,90,107,164,186,171,198,183,186,46,63,203,186,42,205,222,186,145,103,242,186,85,3,3,187,138,209,12,187,181,153,22,187,207,87,32,187,128,10,42,187,247,179,51,187,100,87,61,187,245,246,70,187,0,147,80,187,173,41,90,187,120,185,99,187,140,65,109,187,104,193,118,187,69,28,128,187,206,210,132,187,119,131,137,187,86,46,142,187,24,212,146,187,189,117,151,187,178,19,156,187,32,174,160,187,222,68,165,187,235,215,169,187,199,103,174,187,223,244,178,187,51,127,183,187,193,6,188,187,161,139,192,187,252,13,197,187,211,141,201,187,38,11,206,187,244,133,210,187,148,254,214,187,157,117,219,187,184,235,223,187,126,97,228,187,154,215,232,187,248,78,237,187,90,200,241,187,235,68,246,187,153,197,250,187,122,75,255,187,211,235,1,188,143,53,4,188,125,131,6,188,29,214,8,188,252,45,11,188,175,139,13,188,226,239,15,188,109,91,18,188,47,207,20,188,12,76,23,188,207,210,25,188,47,100,28,188,247,0,31,188,212,169,33,188,32,92,36,188,199,17,39,188,222,195,41,188,13,107,44,188,226,2,47,188,103,138,49,188,206,0,52,188,44,101,54,188,246,182,56,188,202,245,58,188,73,33,61,188,49,57,63,188,66,61,65,188,103,45,67,188,127,9,69,188,150,209,70,188,182,133,72,188,9,38,74,188,188,178,75,188,24,44,77,188,106,146,78,188,39,230,79,188,198,39,81,188,209,87,82,188,65,119,83,188,76,135,84,188,52,137,85,188,124,126,86,188,112,103,87,188,131,67,88,188,223,17,89,188,216,209,89,188,36,131,90,188,12,38,91,188,220,186,91,188,235,65,92,188,120,187,92,188,174,39,93,188,185,134,93,188,195,216,93,188,46,30,94,188,143,87,94,188,135,133,94,188,184,168,94,188,54,193,94,188,98,206,94,188,164,207,94,188,81,196,94,188,62,172,94,188,213,135,94,188,110,87,94,188,137,27,94,188,38,212,93,188,218,128,93,188,67,33,93,188,247,180,92,188,108,60,92,188,227,184,91,188,213,43,91,188,164,150,90,188,200,250,89,188,174,89,89,188,216,180,88,188,211,13,88,188,46,102,87,188,139,166,86,188,83,13,86,188,41,105,85,188,12,186,84,188,29,0,84,188,70,59,83,188,168,107,82,188,34,145,81,188,180,171,80,188,73,187,79,188,204,191,78,188,6,185,77,188,226,166,76,188,32,137,75,188,160,95,74,188,204,42,73,188,113,235,71,188,81,162,70,188,44,80,69,188,56,245,67,188,42,145,66,188,172,35,65,188,126,172,63,188,11,44,62,188,52,163,60,188,241,18,59,188,45,124,57,188,128,223,55,188,105,61,54,188,85,150,52,188,185,234,50,188,11,59,49,188,227,135,47,188,224,209,45,188,110,25,44,188,163,94,42,188,233,160,40,188,222,223,38,188,34,27,37,188,76,83,35,188,30,138,33,188,27,193,31,188,209,249,29,188,85,53,28,188,171,116,26,188,147,184,24,188,239,1,23,188,96,81,21,188,103,167,19,188,122,4,18,188,25,105,16,188,155,213,14,188,97,74,13,188,213,199,11,188,45,78,10,188,138,221,8,188,224,117,7,188,27,23,6,188,16,193,4,188,104,115,3,188,183,45,2,188,116,239,0,188,248,111,255,187,229,5,253,187,108,145,250,187,51,4,248,187,59,81,245,187,187,115,242,187,247,109,239,187,94,66,236,187,116,243,232,187,103,131,229,187,103,244,225,187,117,72,222,187,172,129,218,187,248,161,214,187,180,171,210,187,205,160,206,187,113,131,202,187,122,85,198,187,126,24,194,187,44,206,189,187,6,120,185,187,186,23,181,187,223,174,176,187,248,62,172,187,158,201,167,187,252,79,163,187,255,210,158,187,190,83,154,187,17,211,149,187,247,81,145,187,181,209,140,187,118,83,136,187,82,216,131,187,106,195,126,187,153,225,117,187,54,14,109,187,111,75,100,187,115,156,91,187,32,5,83,187,208,136,74,187,221,42,66,187,160,236,57,187,195,205,49,187,110,205,41,187,204,234,33,187,177,37,26,187,71,126,18,187,187,244,10,187,98,137,3,187,38,123,248,186,252,39,234,186,249,29,220,186,205,97,206,186,126,245,192,186,92,214,179,186,99,2,167,186,144,119,154,186,227,53,142,186,184,64,130,186,32,52,109,186,229,137,86,186,111,135,64,186,33,52,43,186,176,150,22,186,123,180,2,186,252,22,223,185,82,35,186,185,125,120,150,185,88,255,103,185,29,68,37,185,47,19,201,184,43,72,22,184,212,150,190,55,117,63,167,56,121,145,13,57,7,109,69,57,168,244,122,57,59,233,150,57,224,206,174,57,73,252,196,57,36,65,217,57,27,156,235,57,193,50,252,57,86,149,5,58,99,85,12,58,13,117,18,58,53,21,24,58,21,88,29,58,224,91,34,58,180,50,39,58,241,225,43,58,71,110,48,58,20,219,52,58,156,31,57,58,103,38,61,58,250,217,64,58,225,38,68,58,174,255,70,58,253,90,73,58,105,47,75,58,231,118,76,58,119,49,77,58,119,100,77,58,246,23,77,58,169,82,76,58,162,30,75,58,251,139,73,58,28,166,71,58,118,124,69,58,110,24,67,58,24,134,64,58,128,205,61,58,14,248,58,58,118,12,56,58,192,14,53,58,242,2,50,58,103,236,46,58,31,203,43,58,24,157,40,58,76,96,37,58,98,17,34,58,174,175,30,58,212,55,27,58,213,169,23,58,2,3,20,58,5,68,16,58,137,107,12,58,227,122,8,58,190,112,4,58,30,81,0,58,193,62,248,57,21,191,239,57,72,43,231,57,102,139,222,57,220,236,213,57,183,87,205,57,180,214,196,57,225,113,188,57,250,51,180,57,181,35,172,57,113,70,164,57,52,160,156,57,161,43,149,57,182,232,141,57,23,210,134,57,212,204,127,57,84,67,114,57,172,7,101,57,207,17,88,57,28,103,75,57,146,7,63,57,63,251,50,57,130,71,39,57,9,239,27,57,146,252,16,57,123,117,6,57,66,190,248,56,106,120,229,56,203,30,211,56,102,177,193,56,219,42,177,56,43,139,161,56,152,199,146,56,130,229,132,56,156,169,111,56,56,32,87,56,150,57,64,56,196,202,42,56,126,222,22,56,8,106,4,56,192,218,230,55,28,166,199,55,158,75,171,55,81,160,145,55,121,29,117,55,218,215,75,55,198,111,39,55,99,100,7,55,123,21,215,54,198,111,167,54,232,171,125,54,9,144,58,54,139,136,3,54,219,42,177,53,249,29,92,53,235,245,246,52,149,191,86,52,149,191,86,51,89,217,0,179,89,217,128,179,119,204,43,179,119,204,43,178,119,204,43,50,119,204,43,50,119,204,43,50,119,204,43,50,119,204,43,178,119,204,43,179,149,191,86,179,89,217,0,179,149,191,86,51,149,191,86,52,192,218,230,52,255,177,78,53,122,22,165,53,82,158,245,53,68,120,44,54,242,137,105,54,52,172,152,54,133,243,194,54,211,240,243,54,15,210,21,55,166,49,53,55,20,109,88,55,103,89,127,55,66,38,149,55,189,141,172,55,144,35,198,55,201,188,225,55,103,89,255,55,114,135,15,56,227,99,32,56,7,66,50,56,154,44,69,56,224,24,89,56,150,17,110,56,255,5,130,56,107,137,141,56,176,141,153,56,45,24,166,56,37,30,179,56,246,164,192,56,66,167,206,56,77,26,221,56,89,243,235,56,75,34,251,56,226,80,5,57,214,48,13,57,80,46,21,57,68,65,29,57,177,105,37,57,139,159,45,57,47,232,53,57,238,64,62,57,119,172,70,57,28,40,79,57,58,185,87,57,129,98,96,57,65,33,105,57,42,248,113,57,128,220,122,57,194,225,129,57,237,83,134,57,178,188,138,57,11,24,143,57,235,93,147,57,75,138,151,57,28,149,155,57,177,123,159,57,170,56,163,57,169,198,166,57,174,37,170,57,185,85,173,57,27,84,176,57,219,36,179,57,248,199,181,57,203,62,184,57,171,138,186,57,71,174,188,57,165,173,190,57,199,136,192,57,178,67,194,57,22,225,195,57,243,96,197,57,153,192,198,57,90,253,199,57,47,19,201,57,16,254,201,57,154,180,202,57,196,50,203,57,210,109,203,57,15,95,203,57,20,253,202,57,118,58,202,57,128,16,201,57,203,117,199,57,81,102,197,57,187,224,194,57,169,223,191,57,124,104,188,57,144,128,184,57,162,50,180,57,24,136,175,57,94,142,170,57,63,88,165,57,131,248,159,57,247,129,154,57,167,252,148,57,235,105,143,57,20,199,137,57,202,18,132,57,241,129,124,57,78,120,112,57,181,221,99,57,135,132,86,57,219,73,72,57,152,29,57,57,55,226,40,57,75,138,23,57,50,27,5,57,194,127,227,56,52,65,187,56,162,208,145,56,41,253,78,56,110,237,241,55,22,102,8,55,47,188,84,183,131,205,12,184,23,226,100,184,154,214,158,184,164,183,203,184,0,47,249,184,21,169,19,185,76,27,43,185,147,251,66,185,57,71,91,185,130,243,115,185,217,122,134,185,127,29,147,185,171,221,159,185,169,180,172,185,19,153,185,185,139,133,198,185,9,118,211,185,142,106,224,185,114,100,237,185,11,101,250,185,130,181,3,186,41,57,10,186,34,186,16,186,192,55,23,186,255,175,29,186,136,33,36,186,88,138,42,186,107,232,48,186,190,57,55,186,252,126,61,186,122,183,67,186,141,226,73,186,135,255,79,186,103,12,86,186,127,8,92,186,121,242,97,186,84,202,103,186,98,141,109,186,161,59,115,186,16,211,120,186,2,83,126,186,185,220,129,186,220,130,132,186,231,26,135,186,46,164,137,186,8,31,140,186,114,138,142,186,23,230,144,186,246,49,147,186,187,109,149,186,14,153,151,186,155,179,153,186,182,189,155,186,95,182,157,186,64,158,159,186,89,116,161,186,170,56,163,186,220,234,164,186,153,138,166,186,54,23,168,186,179,144,169,186,185,246,170,186,160,73,172,186,100,136,173,186,6,179,174,186,219,200,175,186,140,201,176,186,24,180,177,186,43,138,178,186,117,77,179,186,79,1,180,186,106,169,180,186,117,71,181,186,26,220,181,186,91,103,182,186,140,233,182,186,3,99,183,186,193,211,183,186,198,59,184,186,103,155,184,186,250,241,184,186,210,63,185,186,70,132,185,186,84,191,185,186,167,240,185,186,233,23,186,186,197,52,186,186,141,70,186,186,153,77,186,186,61,73,186,186,33,57,186,186,156,28,186,186,172,243,185,186,252,189,185,186,224,122,185,186,173,41,185,186,13,203,184,186,172,94,184,186,52,229,183,186,166,94,183,186,3,203,182,186,73,42,182,186,207,124,181,186,63,194,180,186,153,250,179,186,51,38,179,186,98,69,178,186,123,87,177,186,42,93,176,186,111,86,175,186,74,67,174,186,186,35,173,186,192,247,171,186,8,192,170,186,59,124,169,186,91,45,168,186,19,211,166,186,98,109,165,186,245,252,163,186,31,129,162,186,140,250,160,186,146,105,159,186,136,206,157,186,22,41,156,186,235,122,154,186,93,196,152,186,108,6,151,186,200,66,149,186,113,122,147,186,189,173,145,186,176,222,143,186,73,13,142,186,141,59,140,186,248,231,35,0,168,168,35,0,0,1,0,0,248,231,35,0,0,0,0,0,0,0,0,0,0,0,0,0,2,80,1,0,0,0,0,0,160,5,0,0,46,5,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,124,33,0,16,63,35,0,1,0,0,0,2,80,1,0,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,249,35,0,176,170,28,0,0,0,0,0,16,170,28,0,0,0,0,0,160,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,10,0,0,0,0,0,0,0,0,0,0,192,0,0,0,128,7,0,0,236,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,8,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,8,142,22,0,8,142,22,0,176,124,22,0,176,124,22,0,40,122,22,0,40,122,22,0,88,119,22,0,88,119,22,0,144,113,22,0,144,113,22,0,72,132,22,0,0,0,0,0,80,141,22,0,80,141,22,0,192,129,22,0,192,129,22,0,88,121,22,0,88,121,22,0,192,129,22,0,192,129,22,0,192,129,22,0,192,129,22,0,192,129,22,0,0,0,0,0,96,141,22,0,96,141,22,0,96,141,22,0,96,141,22,0,128,121,22,0,128,121,22,0,216,118,22,0,216,118,22,0,56,112,22,0,56,112,22,0,0,130,22,0,0,0,0,0,192,124,33,0,88,63,35,0,0,0,0,0,144,0,0,0,32,0,0,0,0,0,0,0,184,249,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,2,0,0,0,0,0,0,64,2,0,0,0,0,0,0,82,10,0,0,0,0,0,0,0,0,0,0,120,56,33,0,56,15,32,0,0,0,0,0,145,0,0,0,32,0,0,0,0,0,0,0,192,246,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,2,0,0,0,0,0,0,64,2,0,0,0,0,0,0,82,10,0,0,0,0,0,0,0,0,0,0,152,233,35,0,208,168,35,0,0,0,0,0,96,126,33,0,0,0,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,237,164,19,35,45,191,79,69,173,138,217,91,167,249,31,238,18,246,34,182,173,71,113,70,173,108,5,169,142,101,222,58,55,250,211,251,198,251,42,253,206,252,218,253,95,254,87,1,233,1,19,1,210,252,2,254,56,253,91,252,210,253,20,255,32,0,235,11,195,1,45,1,98,254,19,255,85,253,169,253,43,14,67,254,24,255,56,0,58,0,112,0,54,251,129,253,0,16,124,253,30,255,233,255,90,0,162,0,57,1,104,0,151,250,231,21,84,254,164,252,65,254,247,254,111,255,124,255,115,0,56,255,187,250,0,251,64,251,234,251,111,253,43,0,53,5,63,3,163,2,150,4,142,250,240,8,48,7,86,253,15,254,0,255,22,0,22,0,5,1,70,0,167,250,198,252,49,252,238,8,183,254,245,254,142,0,36,0,181,1,57,1,34,6,52,0,42,254,110,2,12,255,9,255,142,255,22,0,139,255,227,253,113,251,172,253,215,252,95,252,99,253,185,254,102,0,4,2,230,10,85,2,219,250,154,252,47,5,219,3,231,255,135,1,208,255,174,255,209,0,14,255,72,17,201,254,116,254,3,253,130,254,176,254,147,254,98,254,182,255,243,255,103,4,180,253,83,5,54,253,112,1,62,254,122,254,148,254,84,0,139,0,72,7,89,7,241,255,234,252,231,254,226,254,38,0,70,255,225,255,18,255,31,251,6,1,183,252,219,2,98,254,195,255,238,254,24,1,100,0,45,2,183,252,249,252,17,252,217,251,81,253,138,254,152,254,31,0,24,4,143,13,151,250,160,9,184,252,175,251,54,253,112,254,56,0,189,1,76,2,171,1,249,6,187,251,241,252,177,252,41,0,233,255,209,1,136,1,126,1,172,1,250,253,7,255,198,255,233,252,79,253,187,253,74,12,73,255,40,1,66,0,37,251,35,4,204,251,150,252,160,1,32,2,253,0,66,0,168,0,211,0,148,250,229,4,138,0,41,253,3,254,137,3,63,1,215,254,67,0,243,253,66,250,189,8,169,255,35,2,44,2,17,255,90,0,109,255,142,255,210,254,7,252,200,252,183,253,25,0,0,0,62,0,142,5,101,255,215,255,192,254,155,251,211,251,146,251,241,252,105,4,45,0,183,0,47,0,204,2,160,2,153,1,111,251,114,252,65,254,222,255,79,0,95,0,199,1,248,1,125,1,86,1,147,252,6,254,212,252,219,252,215,11,7,255,250,253,187,255,52,2,243,0,5,1,180,254,78,254,83,255,219,255,61,0,45,0,251,255,6,0,103,250,15,252,148,5,73,252,186,253,154,0,143,0,113,2,127,1,131,1,144,250,58,251,190,253,229,0,14,5,218,0,114,255,99,1,107,255,201,0,195,250,145,251,167,252,1,253,239,254,11,8,255,0,66,2,94,1,59,1,239,251,151,253,254,0,8,254,1,255,160,255,231,253,116,254,107,1,50,4,175,250,228,1,26,2,235,252,64,253,65,254,200,0,9,2,213,0,90,0,97,251,110,251,157,252,76,252,22,253,236,1,251,5,132,5,12,2,82,0,78,2,30,252,108,252,165,252,88,253,12,0,230,2,193,3,230,0,255,0,34,0,38,0,80,255,255,255,88,7,16,255,255,252,237,253,13,1,224,255,252,252,18,254,245,2,185,253,91,253,231,254,205,2,184,1,49,2,91,0,159,251,226,251,91,251,180,251], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1277024);
/* memory initializer */ allocate([23,253,95,254,195,255,46,1,7,12,25,7,152,250,57,250,59,250,27,250,203,251,189,254,134,3,44,9,184,5,14,4,25,254,77,255,65,254,201,254,216,254,73,254,84,255,118,8,245,0,228,255,230,251,122,254,18,255,121,2,46,1,177,254,75,3,204,255,185,0,230,0,146,255,79,254,78,253,148,0,63,0,223,254,108,254,43,254,156,7,245,0,224,7,57,5,171,254,214,253,151,253,55,254,76,254,53,254,112,254,248,253,107,253,249,255,54,4,203,3,186,254,180,254,233,255,19,253,83,0,152,255,58,8,77,252,157,252,141,252,63,253,79,254,221,255,164,0,171,1,134,2,100,252,148,8,112,253,226,252,230,254,217,0,29,255,134,0,190,1,241,255,184,253,33,0,185,0,197,253,97,255,60,7,107,254,162,255,195,255,173,255,183,254,252,253,118,254,62,254,83,255,116,255,202,255,100,255,226,0,58,7,16,253,232,250,158,250,5,251,7,252,88,253,175,254,100,1,107,4,47,16,160,251,27,251,11,251,164,252,90,0,205,3,152,0,118,3,97,2,174,5,227,255,36,0,139,255,209,252,117,253,166,254,37,8,98,254,24,0,163,255,21,255,177,251,148,251,10,253,158,255,217,5,5,5,223,254,222,255,146,1,122,253,125,2,99,8,91,253,162,254,246,254,24,255,195,255,57,255,153,254,167,0,10,6,48,3,59,254,221,255,5,255,44,254,21,254,141,254,175,253,146,252,165,5,229,252,139,2,108,0,101,255,55,255,242,255,250,0,241,254,36,253,25,3,154,0,224,254,170,255,16,0,45,2,130,2,176,253,181,253,169,255,147,254,203,254,217,6,216,255,95,0,239,253,169,255,42,255,22,255,135,19,46,254,13,253,224,252,239,252,46,253,236,253,65,253,242,253,47,254,79,2,97,15,27,255,220,252,216,252,70,253,192,253,155,253,6,254,43,253,10,0,13,0,139,255,201,255,101,0,52,0,125,0,180,255,231,255,228,255,189,5,11,255,8,0,231,255,65,0,203,255,250,254,230,254,101,254,180,253,101,253,94,5,48,1,237,252,107,253,93,253,55,0,64,1,208,2,252,255,110,1,153,255,120,255,180,254,198,254,219,254,218,255,127,0,151,0,124,1,206,250,198,250,150,253,216,255,4,5,220,5,210,1,253,253,105,0,95,255,19,0,185,2,95,254,209,253,195,254,56,253,12,253,201,253,242,2,201,5,11,251,155,249,187,250,120,249,115,250,190,10,212,0,235,13,182,255,19,6,41,250,132,251,108,251,71,5,28,254,39,254,138,5,45,2,131,3,123,2,236,23,140,251,126,251,15,3,92,250,27,250,239,251,1,7,107,17,45,5,7,8,103,252,230,252,55,253,89,6,206,255,78,0,97,255,105,1,87,3,42,40,3,250,175,251,210,249,88,249,95,249,96,250,23,252,96,3,246,7,189,250,177,252,117,250,194,5,167,250,91,251,155,251,113,253,122,255,182,3,138,250,34,255,38,250,18,251,37,10,217,2,217,9,224,253,201,1,10,8,237,14,224,249,215,249,221,7,75,249,172,249,244,250,211,10,255,9,78,19,39,250,216,249,68,249,242,249,17,249,58,249,183,251,133,253,142,7,146,10,137,250,30,252,149,6,138,251,1,254,59,6,237,254,93,3,228,1,190,3,162,250,4,253,175,251,43,250,114,249,162,249,247,253,18,20,53,0,51,5,45,19,160,250,86,8,154,249,26,6,227,249,49,250,167,249,160,12,134,18,7,252,183,250,68,251,207,249,227,250,141,251,185,255,204,252,40,23,171,11,127,253,222,250,82,251,98,251,19,252,226,253,249,250,70,251,177,251,209,26,150,251,95,5,140,252,217,4,236,253,83,255,188,255,15,0,53,1,192,0,152,251,173,251,175,252,193,250,185,8,255,250,233,253,89,253,38,15,73,7,109,250,156,17,2,252,21,253,163,251,176,251,223,255,157,2,192,4,202,5,176,250,205,251,53,250,146,250,170,250,14,253,238,251,2,253,139,13,144,253,56,252,179,251,119,254,134,252,65,254,29,252,42,9,115,252,240,252,209,3,139,251,79,251,136,20,240,249,232,253,117,250,0,0,84,2,44,2,118,6,156,251,55,251,194,252,243,4,49,253,255,6,222,253,215,254,210,3,122,1,114,10,19,251,121,251,73,252,253,251,233,9,42,254,152,254,244,254,74,4,126,251,23,250,39,253,81,250,39,22,44,251,224,252,150,252,94,6,249,4,117,7,145,253,44,253,137,5,209,253,186,254,255,254,67,255,9,1,220,0,228,254,234,250,8,251,57,251,182,252,242,16,90,252,23,252,17,254,128,11,199,16,100,252,20,252,183,251,0,252,184,254,200,6,106,0,196,1,158,0,0,252,227,253,240,250,24,17,163,251,56,251,181,252,73,4,97,4,227,4,195,252,162,250,244,8,31,250,58,7,127,251,81,252,45,252,234,253,164,5,26,250,42,250,133,251,139,250,255,5,230,252,235,255,33,5,126,2,247,3,208,251,5,251,114,251,190,249,174,249,157,250,189,17,30,255,121,8,120,3,167,250,88,9,193,251,76,252,50,4,162,2,128,1,124,0,244,1,237,2,142,1,189,251,47,253,142,255,241,255,157,1,200,0,135,0,34,1,189,0,95,251,92,251,197,250,243,249,153,252,194,253,29,9,166,254,42,2,189,14,33,251,5,250,128,250,226,250,17,252,45,11,161,9,96,2,56,4,200,4,177,251,59,250,92,7,124,250,120,252,63,250,178,252,68,255,14,3,1,8,63,250,251,5,6,250,77,250,246,249,20,251,168,252,167,4,140,2,165,3,208,19,80,250,139,249,175,14,41,249,237,253,145,250,201,16,138,254,17,253,222,249,38,251,181,5,250,250,111,252,147,253,232,6,222,4,11,5,11,3,176,250,105,6,98,4,139,253,184,254,59,255,241,0,103,1,48,2,24,2,62,250,6,254,13,250,42,1,241,249,26,251,39,252,19,14,221,16,190,3,139,252,15,255,121,251,94,252,31,251,210,5,199,252,18,1,91,1,51,1,220,251,253,251,215,252,217,251,18,6,172,6,14,255,233,255,168,1,36,3,219,250,171,252,35,6,106,7,239,0,212,253,42,1,95,255,9,3,253,2,72,250,29,4,82,251,124,251,107,252,0,0,180,5,191,1,154,4,117,2,81,250,201,249,40,1,7,249,98,249,161,249,85,14,235,14,109,13,202,12,68,252,102,253,150,252,228,254,166,252,54,255,81,253,192,6,0,254,73,252,84,18,176,250,38,251,92,251,23,250,63,254,226,249,21,250,54,251,17,15,222,4,55,251,164,252,212,251,20,253,229,255,124,1,166,4,79,2,40,2,145,250,194,0,5,253,49,254,75,1,247,254,190,2,181,0,34,1,111,255,186,252,177,250,155,250,223,249,137,250,192,251,179,250,241,250,26,254,156,253,102,6,182,253,178,5,250,252,33,255,148,253,152,255,189,0,88,1,13,1,19,6,148,5,157,252,147,253,218,254,50,255,32,0,235,0,5,1,161,0,3,252,151,255,142,2,21,255,230,254,249,255,189,0,97,255,38,255,113,0,184,251,218,250,24,251,201,250,93,252,36,254,239,251,81,251,146,251,221,10,57,250,58,251,139,250,157,252,209,252,107,253,228,2,16,255,134,4,223,2,101,250,21,252,95,1,34,252,11,255,184,255,165,254,184,255,128,5,122,2,95,249,65,249,2,250,76,249,100,250,154,255,146,1,238,5,111,7,31,5,59,250,94,252,157,254,252,1,94,255,21,0,210,255,198,1,131,1,173,0,224,250,252,250,50,250,108,251,180,250,59,252,174,251,224,6,98,253,115,8,186,255,161,1,209,253,101,253,223,253,79,252,83,254,149,254,157,0,0,5,11,8,217,250,245,250,49,252,182,250,31,251,244,252,36,254,130,5,228,4,87,251,97,252,74,250,103,3,255,250,209,250,124,252,4,6,251,5,203,4,141,249,202,250,207,251,16,253,102,255,198,2,62,3,5,3,23,1,51,1,242,250,228,252,7,253,244,3,47,6,92,254,79,255,189,254,154,0,70,2,2,252,166,252,251,252,48,1,143,252,253,252,171,254,169,3,14,1,164,1,84,253,24,252,229,252,121,252,97,253,193,253,14,0,255,12,16,2,125,3,197,3,227,253,77,252,253,251,168,15,199,251,25,253,33,252,216,252,165,3,130,250,107,251,89,29,200,252,43,255,227,252,120,253,216,255,176,0,217,0,238,250,87,26,13,253,24,255,72,254,88,253,243,254,196,255,176,255,171,255,131,252,236,251,42,253,35,253,190,252,127,253,231,0,245,252,11,254,40,7,240,250,244,9,194,10,19,0,46,255,60,253,51,255,182,255,18,0,55,0,55,251,157,251,41,251,79,27,79,253,16,1,222,254,56,0,100,1,163,2,87,6,146,251,161,253,146,5,152,252,255,1,220,251,152,1,253,0,167,1,168,7,199,250,128,251,39,252,100,252,228,7,114,254,92,1,92,16,20,4,118,253,193,252,93,11,35,8,55,254,251,255,243,251,60,252,128,255,216,255,131,23,166,252,87,252,209,253,144,253,167,253,101,254,120,0,223,254,156,1,9,251,185,250,18,15,66,251,176,8,187,254,91,255,23,2,47,2,130,1,76,7,137,2,13,1,245,0,60,253,246,252,77,255,244,255,101,0,244,255,45,251,132,252,195,252,10,10,194,253,81,254,170,0,167,0,236,1,19,2,94,252,187,251,243,251,103,251,129,251,112,252,46,254,47,1,65,6,249,15,46,251,88,12,137,253,190,251,27,253,238,254,103,0,13,0,100,1,33,1,149,10,165,251,13,252,59,252,76,252,205,253,147,7,102,3,163,4,38,2,252,251,63,251,42,253,70,252,74,253,15,253,145,14,141,0,6,2,86,3,178,251,114,4,77,252,148,253,133,254,76,254,72,0,193,1,176,1,172,1,168,251,252,4,32,2,178,254,67,254,179,0,224,255,219,255,9,0,28,0,28,251,167,11,61,252,232,4,163,1,246,255,17,0,211,0,218,0,191,0,126,0,82,252,77,253,239,253,235,253,63,255,192,4,150,0,133,1,152,0,89,251,37,252,82,252,164,252,49,254,63,253,97,255,184,0,101,7,56,4,217,6,74,253,159,253,69,253,61,0,13,1,130,255,93,0,236,0,124,1,241,253,58,252,178,254,163,0,106,253,223,12,35,254,79,2,3,1,126,2,141,1,181,0,170,253,127,255,35,0,205,255,134,255,64,0,224,255,158,255,185,250,140,251,44,13,15,253,248,252,206,2,1,2,134,0,164,1,98,1,152,251,222,253,25,253,41,1,27,7,179,255,179,0,17,0,181,0,206,0,252,251,253,251,11,253,13,253,123,254,11,4,227,0,249,0,59,1,139,1,93,252,143,252,183,4,247,252,91,255,237,253,137,254,73,0,90,1,76,1,121,251,236,252,172,4,191,3,80,254,175,254,243,0,176,0,65,1,249,255,157,250,205,250,3,251,14,251,97,252,0,0,248,9,15,10,169,1,48,0,8,10,230,255,183,252,6,253,89,253,206,253,92,254,186,0,68,0,69,0,25,253,63,255,10,1,92,0,178,6,15,255,155,254,163,255,4,255,34,255,140,252,127,254,132,9,66,254,106,255,235,253,64,255,223,255,226,0,8,0,12,253,100,251,42,251,22,251,30,251,133,251,4,253,141,0,3,12,40,16,25,251,248,250,78,251,92,251,58,251,23,251,12,254,197,7,222,15,48,5,212,254,70,255,113,254,183,254,182,254,235,253,199,254,238,7,193,0,128,255,91,252,8,252,66,0,112,6,28,255,191,254,236,0,114,0,100,1,212,0,91,253,198,252,240,252,98,253,28,254,89,254,68,255,215,0,172,9,140,2,96,13,199,7,172,3,192,253,82,252,242,251,183,251,119,251,160,251,68,252,5,253,96,254,8,11,149,5,75,253,13,253,57,254,98,253,233,253,31,255,206,18,116,0,84,252,71,252,16,252,168,252,227,252,186,253,237,253,43,255,100,254,175,9,100,255,38,255,193,254,88,255,20,255,8,255,207,254,253,253,32,255,130,254,11,254,9,253,139,0,253,6,254,254,169,254,89,255,209,2,10,252,188,251,49,252,210,251,154,251,246,252,78,255,36,0,10,2,251,20,110,254,185,250,215,249,130,249,150,249,232,249,31,251,154,252,90,2,8,35,154,251,178,251,162,251,208,251,78,252,1,254,226,1,99,6,84,4,167,9,89,252,20,253,210,254,67,254,214,252,153,254,153,5,173,255,80,1,42,7,56,253,251,252,16,253,159,253,121,254,113,2,246,9,147,1,65,254,238,255,251,254,91,0,232,19,57,255,137,252,6,252,40,253,94,252,103,252,84,253,234,255,118,9,70,8,95,254,11,253,235,252,36,253,230,252,239,252,104,253,141,253,117,3,215,1,30,3,83,254,84,253,58,254,71,255,185,0,230,255,34,252,143,254,24,4,231,255,158,255,208,2,41,0,196,255,253,255,164,255,234,252,109,255,78,3,167,15,166,254,117,252,175,252,38,253,129,253,182,252,136,35,105,2,116,251,5,251,156,250,140,250,145,250,172,250,194,250,200,251,143,2,55,22,249,1,206,252,146,251,155,251,144,251,157,251,192,251,28,252,3,0,36,0,208,255,228,255,121,0,201,255,172,0,213,255,21,0,182,255,1,6,187,255,122,1,218,255,143,255,159,0,107,255,159,253,75,253,228,252,53,253,76,2,120,1,24,253,109,253,196,254,145,0,192,1,147,2,64,1,19,3,197,254,68,252,86,253,173,253,185,254,146,0,92,1,69,3,65,2,13,252,10,252,121,253,97,255,167,2,158,0,38,1,158,2,251,1,28,2,162,1,46,2,12,0,94,253,123,252,127,252,197,252,86,253,67,1,20,10,41,251,226,250,40,251,134,251,199,250,23,5,30,254,167,8,234,7,174,8,136,251,92,251,71,251,231,9,169,251,180,252,205,5,113,2,230,4,180,4,44,23,164,251,45,251,72,251,223,252,4,252,210,253,107,5,233,5,201,251,148,12,128,252,197,251,114,251,198,8,70,251,186,252,74,252,64,252,252,2,117,54,229,250,207,252,27,251,58,7,216,250,175,250,62,251,97,253,12,3,185,252,212,251,248,252,161,11,54,253,80,252,201,252,188,253,101,1,79,2,46,1,202,251,129,252,4,252,44,12,136,251,158,5,133,252,185,255,248,5,18,255,239,250,4,252,8,18,95,251,254,253,126,251,123,251,109,7,68,9,149,251,247,250,7,251,247,250,225,250,205,250,196,250,183,1,199,1,91,9,231,253,100,251,105,9,196,251,188,253,145,7,78,3,205,255,103,2,75,4,14,15,103,251,112,252,185,251,144,2,29,252,121,253,226,12,48,252,76,254,35,48,245,250,93,251,195,250,171,18,168,250,179,250,219,250,39,252,127,5,255,253,149,250,56,251,211,251,62,251,163,251,75,255,71,251,0,21,160,16,234,255,48,251,107,251,190,252,226,251,77,252,157,253,202,252,50,255,196,21,36,252,43,4,187,252,226,2,180,254,218,255,197,255,143,0,248,0,130,1,65,254,47,251,22,251,111,251,69,14,235,251,111,253,98,252,212,7,153,8,116,251,130,27,234,250,223,250,212,252,150,0,127,255,49,1,186,1,230,2,95,251,243,250,60,251,152,252,232,250,20,251,171,252,243,250,146,11,195,11,78,255,93,251,193,251,128,252,129,252,227,251,204,14,59,0,87,255,96,6,79,251,247,250,143,20,128,252,75,1,172,252,218,0,57,3,105,4,0,4,217,255,94,251,226,251,70,7,82,251,218,7,205,251,19,252,190,2,14,6,139,17,225,251,134,252,123,253,37,252,161,9,17,2,194,0,184,255,114,1,11,6,56,252,175,252,127,251,59,25,116,251,219,251,4,252,186,252,125,0,114,14,112,251,214,251,90,7,121,251,73,254,7,252,9,253,232,2,22,5,212,252,39,252,22,252,251,251,153,252,106,14,86,255,92,2,111,2,248,4,247,23,12,252,49,251,214,251,97,252,198,251,89,9,181,252,1,6,216,4,158,252,119,251,158,252,239,25,30,252,164,252,248,254,214,254,213,1,160,4,156,252,18,251,119,8,103,251,84,8,37,252,205,253,201,3,121,4,228,5,33,253,48,251,190,251,76,251,227,5,179,251,119,254,243,2,207,3,222,4,152,7,212,251,111,251,240,251,37,252,235,250,112,21,223,251,78,12,98,7,147,251,165,10,157,251,61,252,109,7,4,1,28,254,193,1,52,2,120,4,167,2,162,251,35,252,66,253,212,253,162,0,177,2,200,2,161,2,187,1,73,253,33,251,5,252,215,251,106,254,137,251,214,6,25,253,84,10,98,9,109,251,123,251,221,251,201,252,80,253,34,5,178,5,117,2,89,3,88,3,149,252,220,250,142,13,219,251,178,252,7,253,56,253,69,252,210,3,175,7,44,252,189,13,30,252,71,252,121,252,56,0,228,0,226,255,103,1,48,2,198,38,102,251,224,251,141,253,72,252,31,254,112,251,244,254,67,253,213,253,137,252,68,251,232,6,124,251,116,254,13,253,137,255,58,6,181,3,177,4,180,252,198,6,32,5,181,254,12,254,232,254,131,255,37,255,117,255,240,1,159,251,53,251,135,251,41,255,157,251,3,253,83,255,215,15,62,4,185,5,54,253,120,252,123,252,55,253,207,251,209,4,227,252,133,2,58,0,129,3,250,253,144,253,71,254,214,253,115,4,37,2,147,0,72,0,127,0,172,1,176,251,45,252,129,9,75,7,19,255,23,253,232,254,110,0,26,3,119,2,231,251,117,4,50,252,104,252,175,252,120,254,122,2,158,1,102,2,29,3,118,251,192,250,88,251,21,251,201,251,112,252,157,10,244,9,55,7,128,7,20,252,189,251,18,252,76,253,171,255,232,255,246,3,147,5,239,2,184,253,169,23,74,251,208,251,229,252,103,252,177,251,123,251,145,253,206,252,81,10,49,12,196,251,185,251,85,252,104,253,74,253,116,3,43,2,144,0,81,2,150,252,206,251,161,1,253,251,250,255,234,252,151,6,80,0,250,3,226,2,241,253,66,252,67,253,135,254,252,255,155,0,48,1,164,254,77,252,170,254,221,8,240,251,100,4,18,254,180,255,76,0,2,0,114,0,62,255,92,1,136,3,210,1,191,253,51,253,107,0,217,255,227,255,158,0,101,0,149,0,56,252,103,252,46,2,248,254,67,254,138,0,135,255,223,255,105,0,243,0,34,254,233,251,87,252,17,253,159,253,202,252,59,253,48,252,18,252,240,10,172,251,244,250,225,251,8,251,241,250,128,251,49,1,136,251,123,2,19,8,184,253,145,251,105,253,150,251,14,253,15,252,87,252,253,253,193,5,73,3,45,251,198,250,231,250,139,251,171,251,63,251,18,255,123,7,222,13,2,9,61,252,39,252,150,252,251,2,198,252,74,253,19,0,135,1,123,1,8,3,186,253,64,251,251,250,116,251,4,251,231,250,7,251,71,10,189,253,183,9,34,4,113,253,216,252,146,252,114,252,18,252,158,251,178,253,105,253,172,1,137,8,155,251,248,251,204,251,151,252,141,251,251,251,35,254,184,6,214,4,169,251,225,250,193,250,50,4,208,250,99,251,54,252,126,254,55,9,241,6,235,251,91,251,163,251,227,251,82,252,183,254,245,1,213,4,40,3,254,3,158,252,232,251,90,253,61,6,248,5,250,254,0,255,231,0,162,1,216,2,175,25,143,252,245,250,22,251,190,251,251,253,244,254,200,255,106,0,39,1,209,254,146,251,167,251,118,253,4,254,51,7,21,255,115,255,198,1,64,3,68,251,88,3,108,254,148,253,86,253,25,254,187,255,97,3,85,1,95,0,42,14,243,251,170,250,187,250,154,251,210,253,187,0,87,1,145,2,253,2,102,254,33,253,234,251,1,252,127,252,95,253,146,254,102,12,240,4,208,2,38,253,102,252,245,253,203,252,202,15,49,254,45,0,73,1,213,0,163,255,45,1,13,252,21,1,184,252,204,252,61,254,161,1,214,1,227,2,185,3,61,251,250,250,247,249,110,250,71,251,221,252,132,4,31,5,49,5,49,5,125,253,144,251,80,251,112,252,197,4,73,253,86,1,142,3,137,3,44,3,28,252,147,254,4,19,30,253,177,253,147,253,17,0,214,255,0,0,100,0,37,8,66,251,102,250,104,250,37,251,191,253,142,253,140,0,77,5,29,7,216,251,19,251,163,249,11,250,48,250,179,251,137,253,39,2,228,13,134,15,133,253,178,252,19,252,122,253,221,252,123,0,105,255,101,1,89,8,185,3,112,251,225,251,165,251,219,251,201,252,117,253,2,15,94,2,235,1,235,1,239,250,217,251,34,252,229,251,78,251,41,252,44,254,209,255,163,0,80,1,149,251,66,254,85,253,132,2,108,253,93,253,227,4,117,1,195,0,133,255,171,251,82,254,28,7,91,7,162,252,25,253,247,254,119,0,66,0,215,255,255,250,0,253,149,7,69,252,226,251,168,252,16,2,107,1,232,1,33,2,88,252,86,253,210,252,158,21,198,252,165,254,58,0,218,255,168,0,14,0,200,4,49,253,212,254,2,253,105,254,118,2,13,1,39,0,26,255,67,253,65,6,66,252,79,252,69,252,34,253,25,254,236,255,112,5,32,2,26,1,138,255,147,251,119,251,215,251,85,252,43,255,127,255,241,254,195,1,10,10,129,252,219,252,232,253,175,5,216,5,121,253,57,255,114,0,95,0,214,255,182,8,169,252,53,253,205,252,226,6,69,253,206,255,147,255,163,0,207,0,178,254,9,253,225,12,123,253,1,10,77,0,17,255,253,254,237,254,67,254,232,250,208,13,74,6,242,253,98,252,186,253,244,255,44,0,76,255,187,255,220,252,83,4,171,5,156,252,173,252,179,253,158,254,171,255,88,0,80,1,231,253,68,254,40,0,231,0,53,253,245,253,161,254,133,254,133,255,171,0,199,4,184,254,201,253,134,8,221,254,160,254,20,0,99,255,174,254,133,253,146,8,36,254,88,6,222,252,6,253,183,253,11,255,48,0,63,0,211,255,224,255,122,253,79,3,212,253,41,253,253,254,29,5,239,0,128,255,13,253,6,252,128,253,108,3,126,253,118,252,114,5,230,255,82,1,204,0,148,0,36,252,247,253,135,0,217,252,41,4,243,253,176,255,8,255,127,1,68,3,9,2,13,0,215,253,159,252,96,252,137,253,119,255,173,255,190,1,221,0,132,7,48,0,147,253,179,252,242,252,224,253,237,253,94,254,177,255,147,3,57,253,223,4,86,252,2,253,29,252,179,5,31,0,199,0,5,1,190,0,98,253,73,251,11,252,108,0,98,253,204,0,151,1,10,1,217,1,230,3,162,253,101,252,53,7,219,251,142,3,250,252,12,1,237,1,178,0,61,0,146,7,43,251,14,252,183,251,244,252,144,254,101,4,98,1,142,1,38,2,8,4,152,251,84,251,116,252,1,253,17,2,22,9,216,2,227,0,243,255,167,251,145,254,126,1,85,252,186,251,128,252,49,254,190,1,128,3,104,4,177,253,201,252,130,252,236,11,56,252,109,8,103,255,185,255,111,0,118,0,174,251,94,252,113,252,127,6,119,252,77,253,30,255,247,1,153,2,190,2,19,8,131,251,196,252,222,3,174,252,86,254,97,255,148,0,123,1,0,2,12,251,146,250,44,250,193,250,117,250,198,8,32,255,76,8,243,5,58,5,10,2,77,6,168,254,74,253,25,254,187,254,37,1,96,0,138,254,89,253,148,254,124,0,79,251,6,251,202,251,255,253,15,0,21,4,17,2,168,2,131,0,213,251,250,251,136,252,218,252,134,255,234,3,22,5,245,2,39,254,238,253,230,253,203,252,139,254,72,0,29,3,96,3,9,1,226,253,190,251,15,255,185,251,75,251,33,252,108,251,161,19,92,254,216,2,205,1,103,0,21,9,109,252,12,252,170,252,163,251,226,7,135,254,221,255,10,1,187,1,75,252,117,251,216,251,223,251,222,252,209,2,254,4,214,1,52,1,7,1,218,1,251,252,247,251,132,252,227,0,226,255,39,0,101,0,200,1,220,1,17,251,107,28,78,252,123,251,232,250,102,252,248,0,143,0,158,255,56,1,91,13,110,254,119,253,139,253,214,253,208,255,231,1,72,0,85,255,81,253,113,251,77,7,244,253,210,5,155,252,20,255,111,0,68,0,77,0,171,255,201,5,138,3,91,251,215,250,156,251,214,253,173,1,65,1,46,3,187,2,232,251,230,1,166,252,184,251,208,251,24,253,140,6,183,255,81,2,120,2,11,3,15,251,66,250,157,250,230,251,220,253,13,3,12,2,254,3,55,4,131,251,135,14,216,251,100,251,121,251,249,252,45,255,241,0,236,1,43,2,209,11,12,11,175,252,147,251,217,251,201,253,186,255,114,255,80,255,194,255,154,253,209,6,84,253,158,253,198,5,149,253,21,255,151,254,172,255,212,255,125,251,214,5,97,251,70,251,242,250,7,252,182,254,210,0,163,3,88,5,230,250,154,10,228,251,152,251,60,251,116,252,105,9,185,1,54,1,62,1,243,21,93,255,19,252,168,252,193,252,124,253,156,253,9,253,254,252,56,254,199,0,217,253,188,250,176,255,131,0,31,254,78,1,202,0,110,1,222,4,35,251,243,1,82,250,116,254,93,253,255,254,13,2,233,3,110,3,51,4,20,252,14,252,153,251,77,252,48,252,76,1,205,13,35,5,9,1,85,253,166,251,32,4,15,252,130,4,40,253,44,255,108,2,169,0,102,0,146,255,110,253,122,252,42,251,67,251,42,251,98,252,33,253,57,254,106,4,19,20,96,251,190,0,54,6,164,253,224,252,139,254,146,254,251,0,208,2,59,2,250,255,48,1,52,251,143,254,109,253,6,254,231,255,22,255,57,1,62,9,111,2,193,5,197,254,12,3,24,4,96,254,182,253,31,253,251,251,186,251,227,1,43,253,253,252,133,254,244,254,241,255,185,2,238,6,255,255,25,252,37,252,157,252,197,250,25,251,6,252,116,253,131,255,131,2,190,11,113,9,225,253,93,6,21,6,84,253,200,253,38,254,124,255,221,254,174,254,191,254,30,251,129,2,98,255,89,252,193,253,193,253,154,0,159,1,30,3,141,5,75,12,111,7,177,254,1,253,39,253,141,253,157,253,16,253,188,252,33,253,166,2,246,1,78,252,44,2,203,252,205,255,0,255,94,0,151,0,70,0,216,252,188,254,153,254,53,14,30,1,166,255,147,254,155,253,242,252,153,252,75,0,27,4,244,252,25,254,47,0,17,1,232,6,154,255,196,252,13,251,187,251,140,5,144,253,225,0,27,5,85,0,239,0,104,255,119,253,171,252,208,251,228,252,124,253,103,5,119,4,57,255,94,0,231,255,70,0,52,0,216,251,183,9,180,252,161,253,181,253,148,0,214,2,224,0,18,255,28,254,67,252,39,253,237,5,54,5,37,254,195,254,3,255,70,255,1,0,17,0,192,252,170,5,167,1,128,5,192,253,199,252,138,253,189,253,200,254,58,1,20,3,126,1,24,252,220,251,5,253,200,3,121,255,56,0,143,0,221,1,32,253,30,0,183,15,68,0,246,254,92,254,230,253,17,253,131,252,145,252,89,252,59,0,209,1,119,3,161,254,116,5,176,0,6,255,84,253,5,252,253,253,209,252,67,252,73,254,188,0,210,14,86,0,158,255,11,255,195,252,102,7,126,254,159,252,233,5,24,0,6,254,231,254,153,253,36,254,148,254,253,250,61,252,173,254,123,255,95,255,32,254,25,0,230,0,84,5,23,7,230,6,180,252,113,250,95,251,52,252,54,254,237,254,138,0,37,5,242,6,241,250,150,252,69,251,232,252,167,253,12,254,253,8,133,3,56,5,74,3,75,5,86,254,120,251,65,252,223,252,79,254,60,7,144,0,28,1,169,0,158,251,173,252,67,252,16,1,119,254,49,3,94,3,6,1,77,1,34,3,64,1,192,253,79,6,153,253,138,252,201,254,108,0,13,0,1,0,64,1,75,251,194,3,29,254,233,252,19,253,134,4,165,2,199,255,166,0,23,1,164,252,213,4,53,252,223,251,170,253,227,254,116,3,150,4,145,2,209,254,206,8,62,253,167,251,113,253,207,2,234,0,132,255,57,255,121,255,152,254,10,253,145,253,127,254,238,255,171,12,214,1,117,255,226,254,248,253,71,252,87,251,140,251,239,250,143,251,4,253,25,0,235,0,169,8,221,5,89,5,232,7,13,3,183,250,189,252,200,252,167,253,253,254,116,255,131,1,159,2,3,0,50,252,8,253,140,252,27,254,197,2,225,5,161,255,65,1,227,2,74,6,100,255,235,5,180,255,92,254,143,254,67,255,6,254,63,253,117,252,228,251,252,253,232,251,28,252,41,254,171,4,212,0,184,0,32,3,129,6,235,2,251,251,11,252,21,3,65,253,47,2,117,255,158,255,124,1,11,2,157,254,255,7,2,253,33,252,215,252,202,253,255,254,14,255,229,1,42,5,197,7,182,254,79,252,209,253,64,254,217,4,43,3,10,0,1,253,62,251,64,6,13,253,172,1,39,253,157,254,103,253,96,254,136,255,125,1,36,2,51,253,242,255,51,6,138,252,247,255,97,1,71,3,201,0,58,254,168,251,202,250,203,254,148,2,137,254,107,253,1,254,157,5,28,2,236,1,0,0,95,0,71,15,19,255,211,254,206,253,29,254,199,253,225,252,141,252,188,253,98,253,44,252,224,251,128,252,227,252,15,6,11,1,232,3,81,6,75,0,148,251,109,254,36,252,194,252,141,253,140,4,35,5,58,6,54,1,204,253,189,251,205,253,171,4,70,254,62,4,168,254,80,255,254,254,175,0,220,1,155,3,219,255,139,253,105,252,254,4,158,253,113,0,198,254,175,255,192,0,219,2,80,252,239,250,172,251,90,252,253,254,128,2,140,4,46,5,46,2,1,253,249,253,149,252,94,252,207,252,235,253,240,1,45,10,79,5,125,255,14,252,144,3,225,251,203,254,0,3,58,255,90,255,180,255,173,1,128,2,211,12,129,252,51,251,171,252,171,252,113,254,147,0,44,0,237,0,239,1,191,252,115,252,20,252,213,252,15,4,91,6,62,255,39,1,226,2,34,1,253,252,237,0,112,252,33,254,120,253,250,253,30,255,61,2,42,9,163,1,245,3,230,5,159,252,151,252,42,252,211,253,86,2,50,0,81,0,175,255,130,251,128,253,13,252,199,7,207,253,116,255,42,0,175,0,9,2,31,3,159,12,210,255,20,252,30,252,140,251,186,251,67,252,164,252,8,0,42,9,212,0,13,254,201,255,27,252,145,253,180,253,38,0,198,255,207,3,249,5,38,252,133,252,159,251,149,253,175,7,49,254,249,255,120,2,0,3,185,3,129,9,99,252,9,252,15,252,149,252,236,254,122,1,208,1,182,2,27,3,236,251,167,253,110,253,1,1,126,252,3,254,166,254,112,8,182,2,184,3,234,250,149,253,246,1,134,254,144,253,78,255,93,1,156,255,204,0,34,2,86,250,153,251,234,250,239,250,229,251,184,252,98,13,66,5,41,6,187,6,13,251,58,253,152,252,192,1,1,252,40,253,247,253,122,255,106,3,168,3,146,251,219,253,203,0,92,252,229,251,243,2,160,253,57,255,90,3,240,3,27,7,182,252,251,252,29,253,50,3,141,254,33,1,37,1,144,2,192,2,52,1,15,252,65,252,191,251,210,1,44,254,23,1,129,3,252,2,29,3,103,250,4,251,27,251,210,250,98,251,32,252,171,255,243,16,87,8,88,8,107,4,107,252,58,252,165,252,135,252,154,4,62,0,147,2,3,3,114,3,52,7,161,253,160,4,2,253,219,252,127,254,195,255,246,1,136,2,220,2,35,251,35,5,206,252,197,252,109,2,180,253,193,0,224,1,137,2,8,3,102,251,78,251,128,251,192,251,167,252,65,255,207,255,129,0,158,7,213,4,75,250,246,250,194,250,135,250,198,250,67,251,145,253,224,0,246,15,213,9,130,251,210,252,21,253,148,3,39,3,224,254,63,1,180,1,48,2,206,2,136,1,51,252,36,252,155,1,70,252,10,254,214,0,109,2,88,3,63,3,12,251,172,15,172,252,22,252,10,252,191,253,32,0,40,2,219,3,114,4,75,251,217,250,135,251,96,252,80,0,115,1,21,1,11,3,91,3,134,3,139,251,33,252,67,252,195,2,132,252,74,4,126,0,125,1,156,2,102,3,26,251,29,252,117,251,98,252,131,251,12,10,239,255,235,2,176,5,229,5,20,252,157,252,181,4,227,252,170,3,111,253,90,1,8,2,14,3,104,3,208,250,200,251,169,251,213,251,179,8,132,252,153,2,68,6,145,5,197,5,77,7,100,253,56,253,20,4,224,252,117,255,0,0,99,1,97,2,205,2,88,251,136,253,218,13,244,252,154,252,11,254,141,0,248,1,153,3,3,4,155,251,193,251,130,4,108,253,37,252,169,3,82,0,110,5,80,5,219,4,235,4,218,253,255,252,237,252,25,253,150,254,244,255,177,0,65,1,249,1,133,251,125,252,77,252,175,252,91,5,50,254,129,255,16,0,240,2,186,3,131,250,192,1,99,251,21,251,76,251,156,252,44,254,110,0,13,5,239,4,13,251,100,251,42,251,94,252,84,252,148,3,1,7,141,2,46,4,113,4,40,255,27,252,179,252,109,253,69,253,82,255,246,2,193,3,161,1,118,2,157,251,155,6,205,4,36,253,87,252,21,254,178,255,9,1,232,2,96,3,163,18,168,252,19,252,17,252,90,252,28,254,239,255,67,2,93,3,191,3,16,251,70,0,63,252,160,252,164,252,210,254,58,1,20,3,231,1,174,2,147,251,234,252,46,254,49,2,212,252,0,255,30,8,198,255,245,2,185,3,147,251,226,254,113,253,36,254,233,255,139,253,7,0,182,0,170,1,248,1,170,251,58,1,241,1,202,252,106,253,14,253,155,4,190,6,184,2,187,3,1,7,137,251,12,251,1,251,73,251,151,252,73,255,10,6,160,5,25,5,2,251,116,5,245,252,46,2,184,252,224,255,238,255,1,1,104,2,245,2,9,1,118,252,243,1,127,252,178,252,77,254,106,1,178,1,240,2,220,2,197,1,150,0,251,251,98,251,85,251,84,252,215,254,108,3,60,4,27,4,159,250,74,5,132,251,223,250,69,251,87,252,146,254,150,7,43,5,130,5,55,1,242,254,175,255,97,255,42,0,42,0,7,0,101,1,255,0,29,1,181,7,106,5,16,253,151,252,108,252,46,254,217,255,237,1,126,2,247,2,198,250,83,4,199,251,115,251,242,251,28,254,186,6,22,2,14,4,78,4,90,250,68,251,199,250,84,250,114,250,245,250,78,253,98,6,68,5,104,6,236,251,72,255,11,253,85,253,156,255,20,4,113,1,93,1,176,1,72,2,143,251,240,253,145,5,14,5,182,252,255,254,224,255,33,1,127,2,28,3,118,250,51,251,254,250,145,250,115,250,46,251,172,252,3,253,225,2,28,8,176,251,96,252,88,252,192,251,122,1,3,253,67,6,69,2,241,2,157,3,89,251,183,252,105,252,70,11,117,252,24,255,180,0,31,2,188,3,46,4,222,250,181,252,36,3,186,251,71,251,249,251,142,253,186,2,25,4,128,4,0,1,63,3,183,252,210,252,183,252,202,255,134,0,91,1,23,2,146,2,104,0,223,252,65,252,249,253,106,254,156,0,12,0,13,0,124,1,238,1,136,251,168,251,51,252,59,252,108,252,38,254,31,255,204,1,146,1,222,2,88,250,220,250,2,251,231,0,194,251,190,253,72,2,91,4,251,4,236,4,215,250,61,252,153,251,248,250,41,0,178,251,225,255,51,5,235,3,121,4,112,0,10,251,193,250,160,250,166,251,246,252,136,1,126,7,141,4,222,4,33,251,154,252,48,251,133,251,205,251,58,2,181,0,191,7,203,3,192,4,227,250,81,251,4,1,144,251,74,252,26,253,43,4,191,2,126,4,120,4,131,250,3,250,228,249,243,249,16,251,31,253,61,4,170,6,14,7,249,6,26,1,107,251,152,251,92,251,53,252,139,252,221,254,254,0,73,3,219,3,114,255,212,251,16,251,48,251,222,251,138,0,34,2,9,2,72,4,219,3,122,3,88,252,4,252,229,251,153,252,247,253,150,6,113,2,162,3,168,3,193,250,100,252,49,251,33,251,228,251,73,252,86,4,125,0,58,3,92,4,109,26,130,253,172,251,47,252,89,253,66,254,187,254,80,254,129,255,96,0,199,253,147,253,230,251,183,252,224,252,194,5,146,4,60,0,74,1,223,0,219,250,87,3,51,1,93,252,120,253,219,253,108,255,23,2,130,2,189,1,82,14,134,251,113,251,80,252,184,253,174,3,228,254,25,0,61,2,216,1,239,251,184,251,71,251,198,251,254,252,31,253,117,255,25,8,241,2,64,3,251,1,196,252,168,251,150,251,188,16,46,253,251,254,199,255,243,1,44,1,156,250,150,251,135,0,126,252,208,252,117,254,195,0,197,1,138,2,25,2,71,252,171,251,59,251,43,252,21,253,121,253,56,9,211,1,77,3,172,2,103,251,232,252,26,251,132,251,64,5,23,253,189,254,180,0,217,2,227,2,4,252,183,0,106,20,130,253,154,254,170,255,244,254,113,255,84,0,141,255,224,1,225,253,51,251,183,251,174,253,41,252,232,252,121,254,77,10,125,5,7,253,158,252,94,251,51,252,232,252,128,253,36,255,154,255,141,4,87,12,39,251,223,251,214,250,17,252,37,253,44,0,8,1,156,2,85,10,56,6,69,11,125,251,189,250,71,251,203,254,119,251,120,16,192,255,62,3,104,2,80,253,130,253,172,253,202,0,103,253,145,253,13,254,8,255,0,2,237,2,141,250,60,253,194,251,185,4,23,253,145,254,117,5,23,1,118,1,3,1,179,250,2,255,6,9,47,7,109,255,36,0,110,254,44,1,207,255,47,0,208,250,32,252,125,13,135,252,147,253,135,0,181,1,70,0,151,2,90,1,197,250,144,251,5,251,19,26,227,250,237,8,155,252,130,4,128,2,105,2,7,254,238,251,40,252,66,253,3,5,37,6,88,255,135,0,249,0,253,0,241,252,161,251,194,250,49,252,153,251,111,5,63,253,87,17,136,4,77,3,253,250,56,251,250,250,138,251,5,252,123,252,110,253,99,255,231,0,99,2,30,252,49,254,7,252,58,4,39,7,53,254,92,255,114,0,0,0,108,0,150,250,201,251,218,250,189,251,236,9,51,253,250,2,134,5,81,3,64,2,131,250,202,253,144,10,28,252,85,8,90,253,148,1,25,1,4,0,224,255,62,250,202,13,253,8,57,253,105,252,207,254,131,255,184,0,194,1,73,0,148,251,31,6,84,6,217,253,58,255,123,253,19,0,8,0,190,0,191,0,27,253,40,253,154,1,43,4,190,254,17,255,86,0,11,0,119,255,36,255,23,254,161,253,61,252,46,14,144,253,34,254,244,255,124,0,219,0,63,0,248,7,75,0,58,5,219,254,179,254,176,254,182,254,10,255,152,254,168,254,71,252,119,254,14,6,67,253,152,253,2,255,116,7,211,0,72,1,213,255,191,251,213,254,46,4,45,253,101,252,122,8,112,254,243,255,228,255,108,0,212,252,112,254,108,3,118,253,28,5,252,252,0,255,56,255,117,0,73,1,137,2,129,253,181,1,64,253,201,253,236,255,45,255,197,0,74,1,86,1,134,6,44,254,104,252,180,253,204,3,202,254,9,0,210,255,70,0,227,255,223,250,148,6,230,252,45,252,16,253,72,7,83,255,108,0,248,0,36,1,33,251,54,251,221,251,32,1,144,255,189,0,20,0,28,2,198,1,124,1,245,251,221,252,243,4,1,253,234,2,51,5,107,0,61,1,158,0,140,255,45,8,45,253,216,251,118,252,55,253,235,252,250,253,48,0,238,1,250,3,43,7,183,250,233,250,182,251,209,253,32,3,8,2,150,2,103,2,62,2,254,250,242,253,37,7,194,251,139,252,156,254,229,253,206,255,237,1,146,1,247,252,138,254,14,253,185,6,67,253,38,8,164,254,218,0,138,0,109,0,169,250,54,251,239,251,157,7,79,254,221,254,149,254,55,2,101,2,48,2,142,4,31,254,31,253,169,4,33,254,93,255,187,255,2,0,133,0,239,0,92,250,88,250,186,250,37,252,216,254,94,2,243,2,31,2,229,2,38,3,173,252,133,9,23,0,87,253,98,253,241,254,73,254,29,255,13,255,58,255,229,250,168,1,68,251,37,252,23,253,143,254,162,0,129,2,147,3,99,2,232,255,40,253,219,251,109,253,40,3,236,253,217,4,23,255,10,1,97,1,175,0,210,0,250,254,184,254,101,0,18,255,66,0,173,254,40,254,97,254,184,3,46,250,234,250,69,252,10,251,144,22,232,252,9,3,73,4,39,3,202,250,108,251,69,251,100,252,147,252,154,9,157,254,81,2,168,3,187,2,176,254,68,253,6,253,199,253,175,254,130,2,97,0,185,1,68,255,235,253,218,251,188,0,151,252,223,252,162,1,89,255,199,255,227,255,79,0,241,0,170,251,30,25,208,252,217,252,50,254,167,253,200,255,211,255,188,0,74,0,53,11,43,0,158,251,225,252,252,252,177,252,114,5,220,255,38,1,13,0,232,250,107,8,234,253,9,6,197,254,187,254,183,0,31,0,116,1,187,0,105,3,96,5,243,251,214,252,252,253,21,255,229,1,99,0,31,1,71,1,206,251,179,4,191,251,142,252,253,253,224,253,249,7,216,255,208,0,191,0,85,2,139,251,6,251,139,252,126,254,106,0,81,2,138,1,159,2,166,2,244,250,21,15,195,251,130,251,20,253,38,255,244,1,55,0,79,1,213,1,145,12,72,11,142,252,125,253,178,253,6,254,43,0,53,254,46,255,34,255,59,252,149,9,194,252,245,252,16,7,180,253,130,0,4,0,130,0,233,255,11,251,94,5,42,251,132,251,245,253,109,253,86,255,210,254,31,4,109,5,69,250,201,9,94,252,99,251,182,252,252,253,143,1,118,3,81,3,226,2,129,22,114,254,25,253,76,252,80,252,179,252,141,252,128,252,213,252,164,253,138,251,148,250,90,251,83,253,138,255,218,5,54,6,37,1,52,2,96,1,124,0,83,3,125,255,116,253,195,253,233,254,12,253,34,254,65,3,158,2,49,10,142,251,173,251,0,252,29,253,122,253,125,254,33,0,123,2,13,4,51,253,34,252,119,251,76,252,108,253,26,255,69,0,206,9,250,4,73,3,207,255,152,252,4,253,45,255,230,11,226,255,113,255,201,254,188,254,99,254,8,253,67,0,107,2,69,253,43,253,49,1,28,254,12,5,216,1,100,255,200,253,37,251,24,251,30,252,221,252,126,254,156,6,84,2,45,5,10,5,20,254,17,252,36,253,236,252,112,4,158,253,45,0,27,5,164,1,137,2,234,253,205,251,75,252,145,254,219,0,188,1,136,255,251,0,220,1,14,7,134,3,97,252,129,251,145,252,109,253,27,253,251,255,42,1,69,7,227,3,12,255,249,251,138,251,195,251,72,252,251,252,44,254,247,255,101,6,8,14,53,252,130,251,81,251,39,252,79,253,195,254,150,0,28,2,167,10,142,6,33,255,109,254,102,0,122,252,251,252,33,255,110,12,55,254,75,0,68,255,221,254,84,254,155,255,147,254,70,254,176,254,128,255,223,255,13,3,218,4,245,1,15,253,178,252,245,2,68,254,201,254,158,4,4,0,248,255,134,255,74,7,240,253,114,255,62,6,241,255,37,255,211,253,220,252,108,252,59,252,114,0,130,0,88,14,237,255,151,252,232,254,247,252,105,252,200,252,114,253,54,4,39,0,206,255,119,0,101,254,201,254,153,254,199,255,119,255,7,0,244,252,132,252,1,253,89,255,22,5,157,6,51,255,205,255,82,255,185,255,70,3,36,255,147,251,31,252,58,253,172,254,138,2,61,5,191,0,251,255,231,2,225,253,131,255,201,253,70,0,214,255,11,254,64,254,47,0,127,4,144,1,250,252,243,252,44,5,65,4,32,0,0,255,97,254,160,254,42,255,144,3,139,251,36,252,130,253,69,5,251,0,124,0,252,255,89,0,240,255,90,253,199,253,222,5,146,0,114,0,48,3,158,255,243,254,146,253,216,252,134,253,247,12,194,4,189,254,18,253,220,253,243,253,193,253,177,253,38,253,35,0,252,2,143,5,62,2,160,254,96,253,222,252,198,254,204,254,227,255,240,251,51,253,213,1,165,1,241,253,92,254,77,2,195,0,44,2,216,1,142,253,160,252,123,255,203,13,101,253,52,254,245,253,103,0,23,0,203,254,77,9,136,0,173,4,113,254,113,254,11,254,130,253,125,252,211,252,61,253,7,255,207,2,53,3,35,252,139,253,200,253,130,2,252,255,41,1,70,0,175,251,198,1,144,1,21,255,206,253,71,6,140,255,51,255,1,0,22,254,7,0,245,253,252,2,73,1,224,3,16,255,7,255,237,254,146,254,247,254,150,2,221,252,137,1,201,253,11,254,224,255,178,0,115,1,126,0,110,255,212,6,252,253,134,253,117,254,12,1,125,3,154,0,220,255,148,253,25,252,48,1,210,5,0,254,203,252,33,254,130,7,158,253,31,254,30,254,219,252,28,252,240,255,201,253,30,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1287264);
/* memory initializer */ allocate([234,255,77,2,142,255,69,0,66,1,102,1,176,252,181,4,253,1,241,253,25,0,111,0,13,255,59,255,236,255,62,0,220,5,47,252,50,252,121,254,213,253,192,1,0,255,79,0,136,1,35,2,192,5,4,251,77,251,37,252,197,254,3,2,87,3,183,0,231,0,62,0,104,251,115,254,15,11,241,253,193,253,77,254,174,0,175,254,211,2,107,0,10,254,3,253,57,254,100,4,38,255,164,5,53,0,55,255,121,255,245,254,2,254,222,251,155,252,106,4,128,255,118,254,16,0,105,3,85,2,199,1,16,0,0,0,245,255,14,0,244,255,9,0,6,0,242,255,245,255,233,255,59,254,224,251,36,252,55,253,245,254,26,3,186,3,81,5,54,3,64,254,123,1,139,4,80,1,44,253,55,0,109,0,237,0,176,255,36,253,7,252,248,254,142,2,237,251,9,252,114,253,91,0,17,0,36,2,248,1,164,3,223,251,129,251,60,252,126,255,147,4,110,255,228,2,134,0,22,3,27,2,177,253,191,253,124,254,154,0,97,2,85,1,145,2,70,3,133,254,152,252,199,2,103,253,206,252,219,253,105,255,197,9,228,255,67,255,1,255,134,254,149,254,123,251,95,252,137,252,174,254,134,7,223,255,230,255,241,3,253,2,177,255,158,255,219,255,57,252,202,253,244,3,137,3,11,255,41,0,66,1,194,0,108,255,36,255,85,255,17,255,14,255,109,255,242,255,221,0,63,2,218,6,243,11,10,255,55,253,72,253,132,253,128,253,181,252,183,252,13,253,250,9,8,254,200,253,194,254,188,254,85,255,218,254,18,255,224,254,82,255,223,254,249,4,25,255,29,4,228,254,174,254,118,254,29,255,209,254,30,255,198,3,230,2,151,252,9,254,182,253,226,254,119,0,197,255,83,1,218,255,181,252,209,3,64,254,18,255,227,0,179,255,217,2,6,0,45,0,19,254,21,1,151,250,247,250,178,252,139,255,120,1,251,2,41,2,1,3,158,2,116,253,208,12,6,253,142,252,116,254,213,254,124,0,242,254,225,255,46,255,109,9,132,2,234,252,112,252,187,253,5,254,146,255,104,254,202,255,226,255,120,2,201,3,136,253,50,255,187,3,161,255,190,253,175,254,135,254,45,254,240,4,67,0,170,252,161,252,115,252,17,253,152,253,33,254,51,2,22,8,52,252,198,5,62,254,53,253,165,252,79,253,190,0,224,2,105,2,18,2,74,4,173,251,155,251,41,252,254,252,23,255,201,0,55,3,103,250,242,250,239,255,124,251,211,254,161,4,27,5,84,4,33,251,37,7,73,5,231,253,55,254,116,0,62,2,200,2,159,0,23,254,255,1,172,254,54,0,119,0,213,0,95,1,47,250,24,251,212,250,148,251,126,14,6,1,63,4,185,5,102,250,253,251,164,251,57,3,106,253,84,254,147,255,21,4,229,0,241,2,164,253,90,254,122,0,36,255,23,1,119,1,163,254,84,253,59,255,234,1,96,255,140,255,136,255,146,0,75,20,129,252,50,252,10,253,244,253,21,0,249,2,248,3,64,251,151,0,96,3,166,253,53,253,177,253,165,254,80,2,15,251,208,250,161,250,146,252,108,253,219,253,143,0,206,16,103,250,3,251,104,1,248,251,189,252,127,254,81,1,87,4,191,250,30,251,124,251,146,3,58,6,22,0,144,3,244,3,216,249,125,250,172,250,127,251,74,3,72,255,240,0,22,5,50,250,118,251,222,4,144,252,194,252,14,0,183,9,71,6,152,250,98,255,196,253,47,252,43,0,226,255,72,255,60,2,199,10,132,252,0,253,246,253,223,254,212,255,95,1,63,2,244,250,222,253,152,14,159,253,230,253,231,255,2,2,156,3,236,6,103,6,121,252,173,253,249,254,84,1,67,2,158,2,111,250,2,3,101,251,104,252,122,251,93,253,240,1,184,4,199,250,216,4,250,251,236,251,48,7,56,1,41,3,140,3,79,250,130,5,40,251,197,251,227,253,56,2,208,10,152,5,31,251,134,252,54,4,254,4,210,253,63,0,61,2,10,3,251,250,140,7,20,252,122,252,173,254,59,0,17,0,147,2,184,250,89,252,147,252,93,13,57,254,160,0,52,3,206,4,210,250,46,252,218,3,234,252,5,6,41,0,30,2,231,2,45,250,118,251,147,250,15,251,96,252,117,255,181,19,211,8,98,251,78,5,71,252,58,5,10,254,122,0,237,2,71,3,252,250,37,17,23,252,211,252,91,254,44,0,87,3,48,4,122,6,143,252,203,252,129,5,213,254,4,0,197,1,188,2,136,251,168,251,206,4,234,252,91,254,226,4,244,255,143,2,9,6,152,252,175,4,136,253,147,254,56,0,159,1,151,2,135,250,91,251,133,250,91,251,135,251,81,253,140,255,96,4,232,6,212,251,0,252,139,253,160,5,88,0,66,2,199,2,141,249,231,249,228,249,106,250,243,251,240,4,235,255,152,7,240,249,200,250,3,251,148,3,100,254,27,0,150,9,125,6,204,7,193,251,57,251,100,252,119,254,137,6,26,3,249,3,174,250,124,255,151,0,25,2,32,252,38,7,9,3,223,3,201,249,181,250,42,250,116,250,102,253,103,9,138,12,44,8,166,251,144,253,193,251,121,252,216,252,74,254,89,7,142,2,140,251,254,0,151,255,212,0,130,1,49,0,0,1,58,1,83,0,98,0,152,251,123,252,190,253,106,1,190,2,179,2,167,4,52,255,177,254,30,255,154,255,212,255,251,255,120,0,57,0,170,251,109,254,117,253,218,252,54,255,55,2,178,2,93,1,116,252,205,251,83,252,207,5,208,1,251,2,14,3,131,1,210,251,34,252,3,253,217,254,133,6,85,1,113,3,232,0,11,252,237,251,211,2,201,254,38,1,134,2,62,2,72,0,89,251,222,253,73,255,237,1,161,0,201,0,209,1,71,255,102,250,168,250,229,251,64,0,129,1,236,2,218,3,28,253,238,253,81,251,206,253,142,0,108,5,207,5,203,2,177,250,105,3,93,251,101,252,57,254,122,7,147,1,248,3,35,251,57,251,144,253,17,254,212,2,140,2,177,1,73,2,37,250,3,251,155,250,132,251,143,6,90,8,227,3,144,5,191,250,217,250,240,250,138,3,28,255,254,5,250,1,0,4,164,249,126,250,114,250,83,251,113,5,234,255,168,10,248,6,35,251,224,251,82,252,2,0,91,255,141,255,72,3,57,2,248,3,89,251,189,251,162,252,55,254,95,0,39,8,5,4,76,250,50,250,77,250,176,251,197,253,157,3,210,4,167,3,224,249,207,255,211,250,25,251,192,255,59,1,70,3,194,3,141,249,230,249,186,249,221,249,228,250,132,254,196,7,69,8,176,252,100,254,37,252,142,254,200,4,208,254,10,0,242,1,13,250,188,250,163,250,65,252,252,252,183,14,109,2,237,6,93,252,140,253,169,0,255,253,61,0,206,254,226,3,220,1,164,251,145,252,149,252,28,254,229,252,190,3,94,255,188,1,126,38,33,254,117,251,133,251,220,250,143,251,33,252,82,252,10,2,227,2,238,251,230,250,240,251,130,255,123,4,198,13,88,7,35,254,29,254,184,254,125,252,39,4,219,4,158,253,47,253,241,253,140,254,171,0,90,0,196,0,215,25,113,251,91,251,201,251,70,252,207,252,191,252,198,8,183,1,14,4,227,251,144,251,86,252,219,252,2,252,239,251,51,253,229,7,85,1,167,3,116,251,50,251,195,253,232,6,103,43,167,251,150,252,137,253,145,254,7,0,203,251,99,252,22,6,174,252,106,252,13,253,0,254,196,1,4,1,144,1,237,252,58,252,78,253,184,253,181,252,222,252,44,8,120,0,103,0,68,2,22,253,0,254,15,255,147,253,211,10,26,254,244,254,2,1,171,0,232,0,15,251,27,251,24,59,157,251,243,251,139,252,171,251,104,253,109,253,16,255,22,6,115,252,120,251,33,251,57,251,249,251,35,252,97,254,176,13,33,6,117,253,39,251,135,251,10,252,214,250,24,252,158,254,59,0,197,2,110,16,156,251,38,252,135,253,48,252,117,252,132,253,141,254,255,0,171,4,108,3,111,255,134,251,6,252,32,252,32,254,6,253,248,26,65,253,81,254,19,4,232,251,130,253,114,255,138,1,172,252,38,253,235,253,151,254,234,0,221,0,210,251,94,252,4,253,138,12,244,252,0,255,241,6,2,1,51,1,126,1,56,251,219,3,30,19,197,13,100,254,210,253,205,252,161,252,196,253,15,254,105,251,83,251,213,29,171,251,20,253,140,255,206,254,27,0,130,1,118,2,202,250,158,250,234,250,48,49,209,250,53,252,89,0,37,253,3,1,201,0,145,251,73,252,183,253,192,255,161,13,205,10,43,0,75,0,241,253,94,255,49,11,192,250,142,250,145,250,49,251,20,253,62,252,27,21,207,2,138,5,44,253,179,251,69,252,25,253,87,252,216,251,185,251,167,253,196,255,155,1,167,251,151,252,165,253,97,11,208,9,173,254,220,255,26,0,217,255,78,0,11,253,26,252,246,253,186,252,131,21,51,252,28,3,24,2,250,0,56,1,173,250,80,252,133,23,198,255,193,20,78,253,219,253,27,254,190,255,123,255,23,251,116,23,230,24,207,5,48,252,37,252,55,252,221,252,253,251,144,253,57,252,208,6,176,13,6,0,109,253,77,253,186,254,127,255,207,255,148,0,248,251,85,253,27,7,12,7,21,254,60,254,217,254,33,0,236,255,42,0,54,251,194,251,232,252,12,25,111,253,234,254,153,255,231,255,174,255,207,0,146,9,250,255,113,9,251,0,146,253,175,253,103,254,63,255,173,254,208,254,162,252,101,253,153,9,12,254,74,254,8,254,128,5,143,0,203,0,9,1,152,251,132,251,231,10,139,254,73,252,81,8,182,252,234,254,81,0,51,1,237,252,202,252,95,10,164,253,236,7,237,252,4,0,79,1,170,0,219,0,137,2,55,254,204,3,161,253,153,254,42,254,18,255,68,0,199,255,107,0,237,8,242,253,22,254,164,253,179,0,215,255,230,0,64,0,20,0,50,0,222,252,144,4,21,255,248,254,196,254,189,5,13,254,108,0,183,0,150,0,212,251,218,252,113,254,220,4,157,254,231,1,199,255,194,1,195,0,248,0,158,251,184,251,255,12,68,252,60,4,26,5,247,0,186,1,169,0,27,1,88,13,159,253,133,252,145,252,171,252,195,253,227,254,109,255,124,1,96,2,247,4,150,252,93,252,40,0,35,252,152,5,189,7,222,255,29,1,190,0,122,252,50,252,21,16,156,252,240,252,184,253,154,254,200,0,5,1,9,2,79,252,43,252,251,252,189,13,63,252,116,9,9,0,62,1,187,0,66,1,18,252,245,252,242,253,156,11,56,253,190,253,192,253,167,0,156,0,14,1,204,1,182,255,19,255,171,3,72,254,253,253,126,0,63,0,82,0,67,0,211,251,176,251,101,252,134,253,66,255,127,4,14,2,104,11,125,0,54,2,136,251,103,16,34,5,54,254,200,253,176,254,253,253,180,254,160,254,113,255,254,252,27,1,254,252,239,252,217,252,164,254,93,0,171,1,181,0,78,1,226,252,194,252,212,254,3,254,233,4,214,253,61,5,6,0,242,0,16,1,250,251,62,0,13,5,84,1,240,2,19,254,250,255,222,255,33,0,85,0,131,252,78,251,244,0,125,255,206,254,166,29,192,252,164,1,80,0,167,1,225,252,154,252,94,252,48,253,128,253,86,9,103,254,79,255,91,0,114,1,160,252,75,252,70,3,194,253,22,255,43,2,46,0,247,255,173,255,146,0,199,252,34,254,104,253,199,255,99,3,216,254,132,254,183,255,70,0,171,0,156,251,26,41,28,255,159,253,66,252,255,251,220,253,128,254,255,254,55,0,38,21,180,1,117,253,20,253,97,253,243,253,231,255,239,254,248,254,57,0,151,251,182,7,111,255,114,6,195,254,254,253,207,254,178,255,102,255,59,0,245,4,240,3,2,254,57,253,234,253,154,254,194,0,117,0,102,0,57,0,187,252,236,4,130,255,18,254,47,0,94,255,156,3,184,255,130,0,97,0,230,2,221,252,57,253,13,253,110,254,68,255,24,0,53,1,187,0,123,1,188,251,230,22,121,253,217,252,53,253,72,253,104,254,227,255,104,0,97,1,226,12,145,8,249,254,252,252,116,252,14,253,63,254,92,255,99,255,212,255,38,252,9,9,172,253,56,0,9,8,34,254,74,0,205,255,51,0,121,0,125,252,1,7,173,253,99,253,25,253,79,253,222,253,71,0,201,0,126,1,219,251,47,13,248,252,148,252,120,253,105,254,212,255,4,1,2,1,137,1,2,45,100,3,92,250,220,249,118,249,47,249,204,248,176,249,69,249,28,250,27,0,191,254,75,253,171,253,138,254,132,254,71,1,209,0,99,2,158,4,220,253,176,0,224,253,27,254,171,254,136,254,129,254,0,4,36,5,252,255,192,0,119,253,45,252,79,252,222,252,73,255,165,14,44,3,96,254,241,253,34,253,35,4,247,253,156,3,50,254,137,253,180,255,182,0,126,0,100,0,115,253,125,253,91,251,16,251,224,250,225,250,68,251,8,252,38,255,223,32,19,252,222,2,23,5,240,254,115,254,247,253,11,255,133,1,242,0,22,255,202,1,112,252,65,251,52,251,248,250,149,251,179,252,108,254,144,3,121,21,157,1,89,12,80,254,108,255,168,6,105,253,28,252,15,252,117,250,95,252,220,255,41,254,128,253,197,253,59,255,195,253,50,254,26,10,77,255,130,254,11,253,129,252,184,251,140,251,64,251,229,251,80,253,212,255,239,12,190,13,38,254,226,9,195,5,92,253,66,253,247,252,132,254,196,254,230,253,44,254,60,253,30,2,43,255,55,253,113,252,30,254,72,253,121,255,2,5,214,7,75,22,220,1,61,253,253,252,118,253,236,252,246,252,171,252,62,252,98,252,10,0,245,255,3,0,1,0,244,255,242,255,21,0,7,0,243,255,246,255,126,250,80,249,99,5,125,22,218,0,48,251,205,253,95,252,84,253,197,252,251,254,16,4,102,255,203,254,157,255,62,0,88,3,199,0,154,253,98,252,142,253,32,6,254,254,118,1,47,4,116,255,6,255,180,254,192,252,62,253,161,252,54,253,19,253,9,12,242,1,73,253,117,254,168,253,233,254,76,2,245,0,50,12,183,254,91,253,250,254,67,0,19,0,238,253,142,252,162,252,247,251,96,255,6,6,124,7,96,254,168,253,215,253,37,255,126,255,15,254,69,253,183,6,160,0,221,12,44,255,101,252,235,251,7,253,42,251,242,251,7,6,226,2,220,253,227,253,109,254,231,254,141,255,161,255,199,254,237,255,220,254,112,4,8,14,184,2,114,253,168,252,42,253,75,253,223,251,13,251,46,253,131,254,85,253,84,5,226,255,77,2,198,1,6,1,199,255,6,252,200,254,78,3,117,255,181,253,129,255,178,9,78,255,23,255,47,252,228,252,250,255,250,0,220,0,41,6,117,4,5,255,119,253,215,252,229,251,151,252,6,253,34,252,14,252,134,252,127,252,129,253,97,253,172,7,20,3,6,9,113,23,20,0,16,252,121,251,72,251,72,251,218,250,53,251,195,252,144,6,1,252,26,252,56,251,79,252,255,252,215,255,241,7,196,0,149,3,79,6,234,7,114,253,10,252,106,252,18,253,93,253,185,252,5,6,26,1,174,1,221,251,60,253,5,254,246,253,87,255,182,1,196,0,67,3,10,3,129,3,164,1,14,2,215,4,198,0,32,253,71,252,189,252,27,255,164,254,214,2,1,253,31,5,248,0,159,254,218,253,249,3,6,255,36,253,0,1,81,255,130,253,251,2,7,253,67,252,214,253,27,2,252,0,43,1,175,1,101,2,46,17,134,254,2,252,4,252,34,252,11,253,147,253,173,255,222,255,122,0,36,254,77,0,225,252,140,255,194,17,237,252,33,253,50,254,149,252,117,252,163,250,182,250,181,250,60,251,0,252,168,255,18,5,28,11,172,3,111,4,213,8,94,8,181,0,33,253,100,252,83,252,225,252,53,253,106,253,86,0,49,253,247,253,115,0,192,253,69,253,28,4,15,5,199,255,42,0,230,0,60,11,245,1,218,254,98,255,104,0,99,255,253,253,106,253,37,252,211,251,65,253,39,252,219,251,78,252,146,252,245,254,141,1,132,0,22,2,58,14,18,5,208,253,67,253,242,253,218,254,197,0,54,1,75,0,253,255,11,1,170,254,10,8,184,254,85,254,59,253,80,253,14,0,213,255,237,0,250,1,6,11,175,254,124,252,206,252,130,253,64,255,115,3,242,255,241,254,209,253,6,11,91,255,36,252,91,252,107,252,165,253,185,253,115,254,211,1,68,4,236,251,33,254,174,9,126,254,233,253,3,255,63,0,207,255,79,0,27,0,74,255,156,255,106,1,140,253,107,253,61,253,21,6,136,0,79,1,89,0,59,255,65,22,220,0,39,254,40,254,227,251,1,252,193,251,77,251,12,253,135,254,107,252,99,252,200,253,19,255,142,5,197,0,158,255,102,2,99,3,193,252,195,252,55,252,48,253,158,1,56,4,171,6,60,3,135,255,11,253,236,251,223,254,48,3,28,1,41,3,172,255,234,255,216,253,247,255,193,0,153,254,66,0,186,253,94,253,200,7,225,255,58,0,171,1,253,253,213,254,164,3,160,253,177,251,212,251,8,252,254,252,200,0,7,4,88,4,2,4,170,253,206,252,133,252,133,253,196,252,158,252,118,253,187,18,105,254,215,0,171,252,117,1,72,253,159,0,227,3,209,1,3,254,109,0,60,0,10,0,7,33,198,0,25,252,149,251,169,251,85,251,34,251,88,251,99,251,90,252,147,254,4,253,79,253,179,253,34,253,175,9,64,252,255,4,104,0,47,255,12,252,200,252,221,251,103,252,212,252,52,255,199,0,89,2,64,12,125,2,205,11,11,15,22,254,238,255,94,252,199,251,147,251,98,251,12,251,44,252,160,252,79,252,234,254,193,3,254,253,133,255,50,2,106,3,126,255,80,1,242,12,181,254,168,251,118,251,53,251,50,251,108,251,36,252,193,254,254,13,122,3,50,0,87,253,236,252,118,252,148,252,195,252,197,252,215,255,88,13,28,253,111,252,131,252,148,1,11,8,117,253,38,254,46,1,4,2,66,2,175,10,56,251,82,251,207,251,165,251,226,251,55,253,157,6,174,251,21,251,210,2,24,251,57,251,150,6,53,6,211,7,118,252,225,9,93,8,116,254,174,254,220,255,52,0,220,1,63,1,92,254,49,2,20,254,242,253,153,254,35,255,2,255,16,253,144,251,78,253,128,252,211,16,149,254,214,255,83,5,51,253,244,251,150,252,11,9,72,252,152,252,6,1,138,5,225,2,94,5,6,254,42,254,237,254,130,255,242,0,172,1,90,253,87,253,187,253,248,3,215,253,3,254,27,254,104,254,123,37,9,252,112,251,92,252,212,252,78,253,89,255,241,2,89,252,73,254,57,8,242,253,58,253,198,253,9,0,36,2,18,2,228,250,220,251,161,254,50,252,242,251,93,0,203,21,31,253,254,250,106,5,252,250,37,251,175,251,22,3,121,8,67,253,108,253,213,253,37,5,245,10,24,3,161,8,22,254,10,253,18,251,197,251,207,251,162,3,214,252,86,255,22,9,67,251,250,250,107,13,145,251,229,251,220,0,224,11,207,7,91,252,105,253,54,253,169,252,140,254,169,253,75,254,117,1,241,22,37,252,199,251,21,252,21,253,241,254,70,2,45,4,107,252,14,253,44,22,203,253,152,253,116,254,177,0,140,3,34,12,179,5,90,253,225,253,172,254,47,0,80,1,237,1,220,251,147,5,208,253,5,253,58,253,107,253,193,0,83,2,28,252,184,9,180,253,16,253,26,5,114,0,36,1,177,2,78,251,30,9,107,251,113,251,13,253,97,1,175,6,36,6,92,252,17,253,51,8,233,7,95,254,62,0,202,1,99,2,43,252,35,17,129,253,208,253,248,253,104,255,6,1,236,2,196,252,206,252,86,253,130,20,128,253,242,254,129,1,25,4,208,251,250,252,78,7,100,253,234,5,98,255,27,1,25,3,193,251,130,251,125,252,149,252,68,255,72,255,0,26,7,9,118,252,118,6,66,254,141,6,114,253,155,255,108,1,209,2,8,251,248,30,212,252,192,253,60,253,165,254,141,1,104,4,246,14,246,251,225,251,196,8,9,253,62,253,79,0,125,3,102,252,213,251,180,10,156,252,166,252,105,4,34,0,72,4,151,9,74,253,178,7,118,253,94,253,125,255,114,1,185,2,211,251,143,251,76,252,235,251,193,251,60,252,111,1,67,4,0,16,64,252,103,252,154,252,117,5,1,254,66,255,33,2,111,253,86,251,232,253,73,252,186,251,117,0,48,253,228,9,182,251,133,251,103,251,228,6,11,253,135,255,68,9,218,7,78,14,72,252,29,252,130,252,143,253,208,1,219,2,95,3,161,253,7,254,145,1,89,254,228,253,96,8,243,2,82,254,37,250,38,251,78,251,90,251,142,253,225,4,60,13,75,9,41,252,190,251,117,252,3,252,12,252,154,252,163,10,53,6,111,252,76,1,154,255,99,0,226,0,6,0,176,0,98,1,156,0,220,255,195,252,250,252,83,253,241,255,242,1,247,1,238,7,103,254,169,253,196,253,171,254,254,255,111,0,46,1,20,3,22,252,46,252,95,252,23,252,138,252,66,2,227,3,213,4,21,253,72,253,115,253,119,4,62,0,250,1,59,2,226,3,31,252,122,252,153,252,106,253,247,5,114,1,211,3,212,3,46,254,28,254,19,3,251,254,61,0,250,0,121,1,144,255,92,253,233,253,168,254,18,1,107,1,185,0,78,1,208,255,136,251,185,251,13,252,216,253,189,1,75,5,183,4,172,251,152,251,195,251,198,252,173,255,209,7,241,4,149,5,0,252,175,4,97,253,67,253,68,254,168,4,187,0,161,2,241,251,224,251,71,252,36,253,103,1,202,2,19,3,167,3,93,251,147,251,168,251,53,252,110,8,184,6,33,3,224,7,224,251,212,251,135,252,16,7,247,1,124,3,102,1,17,4,100,251,96,251,212,251,236,252,143,5,195,253,93,8,157,7,238,251,100,252,175,252,0,2,139,253,240,254,11,3,47,3,147,7,211,251,188,251,253,251,254,252,48,0,18,6,5,5,171,251,132,251,123,251,247,251,90,252,11,3,78,5,24,6,227,251,222,0,185,251,23,252,87,253,230,255,88,4,11,4,112,251,251,250,111,251,100,251,195,251,183,251,33,5,40,12,96,252,113,253,213,252,150,253,19,6,32,254,71,0,211,1,60,251,157,251,16,252,191,253,179,252,14,15,235,1,86,7,229,251,7,253,105,2,118,253,59,254,51,0,16,3,245,2,31,252,141,252,119,252,60,253,155,252,201,3,192,255,143,2,52,1,236,253,213,252,50,252,127,253,81,254,81,13,2,1,55,2,129,2,35,5,45,253,30,253,10,254,142,0,166,2,189,255,86,255,73,0,191,255,157,10,220,252,66,252,146,252,236,253,206,253,238,0,241,1,36,2,206,2,156,252,99,253,92,252,20,252,250,253,10,254,226,254,149,1,171,11,140,5,174,0,245,252,20,253,193,253,103,255,216,255,84,1,157,1,19,1,131,1,197,3,82,0,218,253,24,253,176,253,177,253,164,253,93,255,172,1,75,3,0,251,220,6,144,254,9,3,227,255,59,254,195,255,43,0,50,0,137,0,182,3,27,255,224,5,21,254,159,254,89,255,227,254,98,255,162,255,71,255,105,250,47,1,161,2,10,253,158,253,204,254,223,4,92,1,95,0,31,0,95,6,171,7,144,253,254,252,46,254,106,255,134,255,133,255,34,0,115,255,141,252,138,254,76,252,139,253,92,13,252,252,120,254,225,255,91,2,134,2,8,253,153,252,88,252,76,252,41,253,235,13,136,254,90,3,187,2,49,2,166,250,62,9,249,252,39,251,175,251,9,255,177,0,176,1,158,1,123,1,176,250,223,251,79,252,176,252,200,253,245,252,136,253,184,254,217,254,169,1,163,254,118,2,237,254,241,253,182,1,47,0,62,255,160,255,17,255,223,253,155,250,79,253,108,6,141,4,75,254,103,255,63,255,51,1,183,0,66,0,201,250,30,10,121,8,65,254,77,254,195,254,174,255,204,0,45,0,111,255,212,250,51,255,179,15,51,252,190,253,28,0,175,0,250,1,235,0,158,255,116,252,218,254,163,5,174,252,212,253,171,6,235,254,58,0,241,0,68,255,171,252,196,253,191,253,234,4,239,3,66,255,1,0,253,255,103,0,207,255,9,21,137,0,61,253,190,252,2,254,251,253,120,254,122,254,25,255,237,254,31,251,109,20,212,252,131,252,159,254,105,253,227,255,187,0,45,0,10,0,148,250,109,251,229,251,156,1,133,254,101,254,240,0,62,2,120,2,28,1,186,252,112,252,100,252,246,11,73,253,103,254,32,255,166,1,37,1,11,1,100,250,43,251,233,250,231,250,110,252,13,255,53,3,71,3,19,4,4,5,102,251,16,254,58,6,32,253,216,6,167,253,116,254,74,1,231,0,48,0,27,251,40,3,128,252,57,252,115,253,172,255,4,0,186,1,107,1,77,2,19,252,96,253,81,253,163,255,238,254,96,5,24,255,204,255,143,1,255,0,195,251,66,251,192,251,20,253,12,4,158,1,220,0,253,1,180,1,243,1,120,253,3,253,93,252,41,252,10,253,225,253,133,254,141,255,12,3,255,12,194,251,131,252,251,252,143,252,85,253,245,255,190,254,90,13,227,2,193,3,173,250,95,252,131,3,19,252,232,252,174,254,71,255,190,2,115,2,126,2,155,251,151,250,97,250,149,250,160,251,87,253,121,255,104,2,14,12,233,9,96,250,71,251,253,251,71,251,142,253,173,0,150,2,131,3,93,3,132,8,131,1,8,4,168,3,140,0,159,254,210,254,222,254,182,254,217,253,5,252,227,13,188,255,71,254,229,253,12,254,229,255,89,254,6,254,246,253,97,254,43,9,98,7,200,254,26,253,89,253,89,253,115,253,159,253,79,254,40,254,149,10,13,253,127,251,214,251,252,251,162,252,198,252,197,254,78,0,163,6,149,254,83,254,78,253,66,255,154,254,101,253,117,7,39,0,255,255,138,0,200,249,233,249,179,250,238,249,18,253,45,3,140,6,1,6,209,3,243,254,128,32,166,253,140,251,127,251,144,251,106,251,20,252,189,251,148,250,93,251,5,254,31,12,56,255,103,253,178,253,131,254,147,254,216,255,217,254,177,253,61,252,15,1,183,8,221,253,191,255,242,254,192,255,243,0,73,255,220,253,228,252,235,254,249,255,88,255,39,6,151,254,35,0,237,255,192,0,102,255,128,254,144,0,86,254,240,253,170,253,246,252,215,254,55,7,52,2,218,0,96,3,114,253,27,254,77,254,45,0,197,2,118,2,245,255,77,253,145,255,249,252,156,254,246,253,199,8,177,255,79,254,148,253,82,2,79,0,60,0,196,252,37,254,0,3,177,255,113,253,38,2,55,255,77,0,90,3,245,255,221,252,149,4,3,4,53,252,112,253,120,253,216,255,17,0,208,2,176,0,225,251,88,252,254,254,38,2,62,4,41,4,0,0,39,254,148,254,30,0,53,0,250,255,202,255,232,255,21,0,175,255,168,255,211,255,242,255,81,0,162,2,91,251,231,251,178,252,23,254,232,255,209,255,165,0,146,2,117,7,15,255,122,254,125,254,58,254,193,254,219,253,205,254,144,255,10,3,206,5,198,254,34,0,163,255,225,252,230,253,171,8,67,254,39,0,218,255,254,254,85,254,81,252,8,253,166,253,193,253,62,254,120,1,156,2,111,3,191,4,64,251,240,252,122,253,221,254,19,1,251,3,179,255,124,0,0,1,142,4,102,254,31,252,135,251,162,251,84,252,199,252,208,253,125,255,238,3,14,19,135,250,250,250,220,250,142,250,177,0,105,252,162,0,244,8,0,7,218,4,6,253,169,3,88,255,124,252,195,252,203,0,201,4,114,2,134,255,253,253,224,3,58,255,242,252,231,255,74,0,251,3,162,253,148,254,162,254,251,255,195,1,68,1,9,1,137,251,204,252,126,1,150,254,85,0,227,252,181,2,58,6,177,254,27,255,116,254,45,255,156,254,159,255,141,255,92,0,49,0,36,254,156,251,196,251,174,253,28,255,216,2,16,0,77,2,189,4,73,3,195,252,82,7,117,252,24,252,131,5,147,253,61,253,100,1,181,1,37,0,199,250,158,251,233,249,84,250,183,250,51,252,18,15,121,4,201,4,55,8,161,253,75,255,45,2,83,254,15,0,16,254,68,254,245,253,182,248,146,251,10,251,213,11,170,251,226,252,200,252,109,253,44,0,102,2,35,4,149,4,202,2,92,252,185,251,219,251,103,252,246,251,151,252,7,0,152,252,148,2,201,250,40,250,169,249,131,250,210,251,88,253,175,3,134,0,66,255,21,11,246,251,35,255,175,254,228,253,197,253,83,255,101,254,10,9,145,255,202,3,60,251,244,251,184,251,109,255,63,4,92,2,145,254,83,0,205,1,167,2,203,250,194,0,244,250,141,251,183,251,198,253,4,254,147,255,54,0,194,3,32,10,168,251,80,252,132,253,247,253,12,0,230,0,186,1,50,2,112,2,173,251,90,251,18,6,43,252,227,5,11,252,118,254,83,2,55,3,70,4,83,250,238,250,242,0,95,251,82,253,227,253,90,3,75,1,183,2,173,4,21,251,200,3,100,251,26,251,16,253,193,5,222,0,86,1,205,3,5,4,161,249,36,250,173,249,19,250,237,250,147,6,155,8,139,4,201,4,217,5,91,251,87,252,93,252,121,12,47,252,60,253,250,254,37,2,149,3,185,5,192,2,203,253,60,253,78,3,126,255,190,254,255,254,221,0,111,1,53,1,120,250,157,251,213,250,20,251,107,254,231,12,46,255,17,3,239,3,80,6,237,251,51,253,44,0,56,3,163,1,20,254,189,253,164,253,241,255,164,2,213,251,201,251,57,15,69,251,38,254,4,252,179,253,114,0,81,2,224,5,55,250,31,251,244,251,12,252,49,253,78,3,67,255,215,254,225,255,185,4,31,249,226,249,87,250,147,249,72,250,142,5,24,0,105,8,97,5,156,7,56,250,140,2,95,252,97,254,79,253,126,254,92,6,233,1,231,1,244,2,112,250,219,252,217,4,228,0,71,253,196,254,167,1,148,2,45,2,75,2,224,4,247,252,64,4,176,252,14,254,113,254,196,255,169,0,241,1,177,2,47,22,246,252,171,251,162,251,129,252,238,251,8,254,134,1,134,6,213,1,209,3,95,252,107,251,222,251,25,252,72,253,120,7,52,0,17,5,57,4,67,250,37,251,225,251,129,1,239,253,142,3,79,0,252,1,201,4,241,2,144,2,229,250,41,251,66,250,170,251,25,251,150,254,47,9,121,3,151,6,226,249,205,250,126,250,151,250,11,3,13,254,39,255,168,3,16,8,213,5,37,250,191,250,118,251,22,3,165,251,95,253,35,8,242,3,76,2,241,4,97,250,112,251,242,250,240,2,115,250,46,251,87,255,239,253,70,6,83,8,236,249,94,250,92,250,231,1,20,251,141,251,104,1,224,9,202,7,150,6,244,249,63,250,205,253,155,251,199,3,210,5,223,5,231,1,223,3,0,4,106,250,129,251,65,251,39,253,22,253,6,253,40,254,10,3,121,3,6,3,207,250,151,251,103,5,50,251,45,253,198,5,123,1,161,0,242,4,214,4,69,250,181,252,3,251,213,250,53,253,58,0,74,255,20,20,250,2,187,6,251,250,110,4,105,251,223,251,14,5,252,255,95,254,45,2,171,3,158,4,39,0,53,2,215,252,65,253,241,252,141,252,144,255,156,1,32,4,179,2,239,254,202,250,126,252,191,250,211,251,33,251,151,255,126,2,155,26,133,4,214,3,168,252,219,252,187,251,243,4,21,253,118,253,55,1,25,1,52,4,91,5,78,6,133,252,138,252,116,254,10,255,191,255,77,0,216,1,93,2,81,252,178,0,3,254,112,0,114,255,0,2,190,255,109,0,144,0,76,0,118,11,77,251,108,250,11,250,11,251,174,249,151,251,72,255,31,255,85,12,7,255,4,251,225,251,73,254,95,255,244,254,28,1,102,2,10,3,158,2,37,251,146,6,151,3,44,254,33,254,171,254,31,0,212,1,69,1,94,2,199,251,45,253,83,0,113,254,237,254,110,253,240,0,149,0,186,10,167,2,219,249,249,250,18,254,7,3,207,3,17,253,209,255,222,6,140,2,131,4,71,250,207,251,193,251,254,251,33,1,84,1,192,1,68,5,95,1,170,2,17,8,97,251,223,250,230,249,46,254,246,249,203,251,35,254,196,11,208,9,232,249,4,250,95,250,51,251,93,3,91,254,235,5,147,8,139,4,138,5,12,251,177,251,220,252,186,251,182,12,57,253,210,253,201,2,134,5,148,6,30,2,243,252,197,252,210,252,11,255,105,4,96,255,210,0,130,1,106,2,159,249,232,1,208,249,221,249,187,250,106,253,199,2,236,5,125,6,137,6,26,250,6,250,245,3,108,251,169,1,121,250,168,252,147,11,210,8,127,7,24,253,72,251,161,252,134,253,39,253,212,251,167,252,223,254,189,2,47,26,34,250,183,250,5,250,164,250,148,250,213,251,112,5,100,0,10,10,167,6,241,249,36,250,205,249,99,249,39,249,105,250,232,251,138,4,28,5,1,12,26,252,217,249,251,253,190,250,243,250,43,250,161,250,171,251,221,252,156,11,90,250,220,250,166,251,131,250,40,251,223,251,171,251,179,253,63,10,90,6,237,249,254,251,190,250,69,250,122,252,11,5,176,0,118,2,197,16,157,7,47,251,174,250,94,252,105,251,162,251,161,250,108,251,57,252,32,19,99,16,48,249,230,249,251,248,233,248,215,249,86,251,115,1,254,12,111,12,255,11,111,250,19,249,230,249,178,250,221,253,10,255,24,0,242,253,34,250,192,114,164,252,154,253,167,252,229,252,25,3,152,253,155,6,131,255,156,0,47,2,149,249,74,250,13,250,123,250,29,251,176,253,246,3,96,7,243,0,17,4,236,4,109,250,136,250,28,252,66,252,85,251,117,24,31,0,199,3,240,2,192,14,49,252,184,252,61,253,72,253,213,253,45,0,135,4,4,0,102,1,110,18,65,250,72,250,245,250,172,250,90,252,146,252,78,20,239,254,19,6,98,250,63,249,213,249,66,250,228,248,100,250,25,251,137,253,191,16,185,15,209,4,84,253,20,253,26,253,221,253,27,255,65,1,126,0,26,3,158,2,33,26,239,251,120,251,163,252,22,252,48,252,147,0,100,253,9,2,172,3,94,251,49,8,198,253,223,6,5,255,70,254,164,255,46,0,99,0,12,0,200,250,219,251,75,17,79,252,163,252,52,254,206,254,238,1,225,1,24,2,179,251,175,251,135,10,60,1,223,252,97,255,18,4,191,253,178,255,84,1,43,9,168,5,135,0,131,254,80,253,19,254,2,255,22,255,182,255,176,255,233,251,34,251,39,253,39,252,23,21,6,252,131,2,54,3,121,3,176,1,184,254,150,250,116,250,66,253,86,250,15,27,173,251,209,1,89,6,92,4,22,251,31,11,131,252,129,252,247,253,249,254,112,0,157,0,44,2,244,1,182,0,116,253,30,255,2,1,130,253,202,253,93,254,99,253,32,255,35,255,83,251,29,255,186,253,92,0,122,7,72,255,245,255,238,255,14,1,166,0,242,250,194,255,0,6,166,9,99,254,149,253,113,254,24,0,106,0,54,0,57,251,112,10,96,9,202,255,191,253,76,253,211,254,253,255,206,0,89,0,112,250,45,250,233,32,208,251,14,255,92,254,62,255,255,255,233,1,75,1,86,252,217,250,189,9,181,250,39,2,249,8,197,0,247,255,205,2,178,1,43,251,251,252,3,252,105,15,202,253,116,0,246,0,150,0,254,1,114,1,28,46,55,254,18,252,49,251,105,251,194,251,59,251,77,2,89,253,11,253,97,251,102,25,184,253,58,254,139,253,198,253,99,254,160,254,233,254,224,255,44,251,78,252,8,253,255,5,159,252,56,253,32,255,87,1,135,2,101,2,188,250,86,252,63,252,81,32,150,251,177,253,31,255,210,0,164,1,140,0,33,251,114,251,58,252,38,252,160,251,117,252,75,255,214,1,96,7,137,4,204,251,238,250,151,13,129,251,106,9,116,254,1,0,212,255,101,1,82,2,128,252,233,2,223,255,90,254,180,254,253,254,0,0,48,0,143,0,190,0,15,252,187,252,148,252,141,254,142,254,240,5,106,255,251,0,240,0,192,1,0,252,16,252,200,253,62,254,157,253,232,253,227,6,222,255,99,1,198,1,255,252,169,253,129,253,31,253,112,252,43,253,8,254,26,255,20,2,222,12,203,251,223,254,149,252,226,253,194,253,164,253,173,254,207,9,223,1,230,2,62,251,78,252,41,5,246,253,224,253,74,252,3,253,120,2,127,2,241,1,84,252,83,251,90,251,80,251,88,251,64,252,50,253,98,2,228,12,181,12,21,250,103,249,250,248,250,248,255,248,28,249,176,249,33,0,73,9,98,30,100,253,209,6,221,5,17,3,176,254,201,252,60,253,66,254,57,254,212,252,158,34,159,0,139,251,19,251,213,250,237,250,19,251,53,251,66,251,190,251,0,14,44,8,176,2,237,253,176,252,24,252,233,251,88,251,176,251,137,252,43,20,165,254,151,251,251,250,200,250,245,250,31,251,171,251,14,254,207,9,157,253,65,253,252,253,16,255,188,255,143,1,34,6,252,0,251,255,43,0,117,251,112,251,16,252,103,252,29,252,199,253,157,3,231,5,233,3,231,7,126,50,135,0,194,249,14,249,201,248,198,248,212,248,58,249,97,249,102,249,109,2,39,18,76,2,16,253,51,252,28,252,71,252,199,251,220,251,96,253,156,252,3,1,76,19,139,255,50,253,117,252,196,252,248,252,162,253,43,252,22,252,242,253,127,254,15,2,221,5,17,255,38,0,25,0,112,0,179,255,98,4,6,255,160,254,167,251,179,251,82,252,87,253,36,20,224,252,132,253,182,22,96,255,247,252,199,252,180,252,21,253,71,253,123,253,100,253,20,254,88,252,235,1,232,254,13,10,243,254,32,253,137,254,247,254,158,255,13,255,104,252,20,255,190,1,71,4,102,253,168,253,10,255,15,3,26,1,0,0,216,251,140,255,223,8,138,255,30,254,16,255,69,255,241,254,36,0,91,0,73,253,2,255,129,254,76,252,233,2,162,10,127,255,225,252,238,0,133,254,56,11,252,253,156,252,145,253,217,253,237,254,22,0,123,1,71,255,26,255,244,5,96,253,218,251,116,251,103,251,143,251,222,251,234,252,6,0,64,19,217,253,123,254,52,254,118,254,94,253,182,253,185,254,78,255,103,2,52,11,69,250,77,251,220,250,160,251,28,252,235,2,37,255,231,7,83,7,254,0,153,252,32,252,218,251,170,251,131,251,32,252,20,254,40,0,16,2,254,20,83,0,209,253,162,252,8,253,227,253,28,0,207,0,117,2,246,1,236,4,39,254,170,251,200,250,146,250,124,250,157,250,207,250,199,251,18,255,116,38,204,250,230,250,5,251,143,252,13,251,31,251,19,255,66,11,207,13,72,2,243,255,52,0,206,255,252,255,7,0,5,0,20,0,201,255,5,0,45,0,51,6,94,1,191,0,105,2,153,0,20,255,176,254,119,253,226,252,217,251,171,5,195,2,253,0,35,253,101,252,165,252,147,253,30,253,213,253,87,6,191,6,101,254,44,253,252,252,22,253,93,253,80,253,47,255,147,3,110,2,242,251,38,254,169,254,165,255,83,255,152,255,255,0,96,0,11,6,5,3,143,253,224,8,166,255,3,254,241,253,9,255,109,255,22,255,211,255,166,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,255,226,252,252,252,235,0,3,2,75,255,136,255,3,254,120,254,121,251,180,252,239,251,143,252,87,251,79,4,200,251,214,0,79,6,27,7,230,5,110,252,90,251,239,254,181,251,246,253,28,252,50,255,106,15,228,3,142,6,60,251,79,251,34,11,2,252,77,4,210,252,68,255,111,3,13,6,255,4,151,251,136,7,14,6,38,0,156,254,194,253,99,255,30,1,225,1,219,1,201,251,104,251,163,252,220,253,111,253,131,254,26,2,180,3,186,252,11,3,131,251,62,252,252,6,245,252,26,253,201,254,205,0,43,1,216,1,203,2,190,2,181,252,93,252,234,252,144,253,180,254,68,1,10,3,17,3,158,2,143,251,75,251,153,255,98,251,209,251,74,252,101,0,15,2,60,6,236,3,170,2,204,253,227,251,180,252,96,251,196,6,162,252,202,7,36,252,107,4,211,251,4,251,227,251,14,25,21,251,70,255,94,252,118,0,119,1,68,4,71,24,124,252,104,252,89,252,43,252,54,252,2,253,122,252,178,254,93,6,186,251,138,251,125,251,245,252,188,251,243,3,22,254,39,4,33,6,60,5,194,8,223,250,139,23,217,250,199,250,235,252,240,250,55,254,51,3,228,8,209,251,215,251,53,253,34,3,28,252,141,1,92,9,229,255,201,4,167,3,120,5,162,252,222,252,54,7,255,253,7,255,64,253,3,2,104,3,150,2,139,251,244,22,77,253,108,254,165,253,108,255,199,255,187,0,137,2,20,3,164,251,109,252,217,253,3,15,31,253,123,255,242,1,155,0,227,0,206,2,6,7,117,5,156,252,52,253,182,253,188,253,185,255,189,255,55,1,24,2,161,9,244,253,45,7,25,255,46,255,7,1,231,0,246,255,92,255,188,254,73,252,150,251,86,20,243,253,165,253,111,254,223,0,182,1,243,3,53,4,42,253,178,251,11,252,126,254,238,252,185,16,183,254,6,1,38,2,12,5,139,253,81,252,48,252,5,3,157,252,140,3,88,253,102,255,106,1,32,4,229,251,65,253,203,250,112,250,254,251,231,252,165,252,142,252,108,255,230,38,87,251,124,251,203,251,217,4,11,252,42,253,117,255,39,2,126,4,251,3,35,253,27,252,117,253,143,253,202,255,210,2,73,0,242,255,105,1,179,1,173,15,20,251,85,251,172,5,175,251,249,4,98,253,10,6,14,4,144,6,212,252,220,251,171,252,222,251,46,8,223,252,55,254,192,254,171,2,192,3,5,252,122,251,162,251,246,251,151,253,148,1,96,5,79,3,246,3,183,3,244,255,20,252,59,251,149,251,137,2,228,251,186,1,89,255,165,252,28,15,64,251,238,250,225,250,50,11,226,250,129,253,201,251,40,6,224,6,45,7,118,0,200,251,162,252,179,252,215,251,211,251,151,8,2,253,239,1,29,5,28,252,240,251,27,253,77,5,190,6,126,1,8,1,92,0,147,2,153,2,243,252,180,250,7,8,82,251,15,0,95,8,119,2,57,2,150,3,96,4,76,252,27,251,46,251,138,9,218,251,158,8,48,0,148,2,30,7,200,5,129,253,115,2,80,254,35,254,77,3,216,0,228,0,152,0,157,0,39,1,140,9,116,252,47,254,0,253,109,0,251,0,72,0,197,255,169,0,149,1,43,17,187,252,93,252,185,252,41,255,204,253,143,2,103,1,247,1,40,1,186,13,198,251,95,251,197,252,63,11,56,251,213,252,54,252,36,3,143,3,212,11,252,250,80,253,54,251,29,251,217,253,33,251,237,254,113,13,18,9,138,253,67,251,148,255,89,251,105,4,170,252,32,11,73,6,24,4,255,5,224,10,35,251,4,3,50,251,238,250,82,253,243,250,129,253,22,1,151,9,247,38,203,251,47,251,225,251,117,255,171,252,208,255,24,0,48,253,21,2,89,251,249,10,9,252,125,252,228,255,3,253,109,255,146,0,80,2,46,3,205,48,6,251,208,251,239,250,109,3,212,251,101,251,248,251,255,3,102,251,184,252,162,3,108,253,192,4,146,254,106,254,159,255,77,0,179,0,84,1,51,252,31,252,232,8,239,6,137,253,239,255,70,255,251,1,203,1,133,2,47,8,5,252,213,251,75,252,167,252,78,251,120,252,208,255,132,4,249,4,50,251,35,251,77,251,244,251,130,251,69,252,169,4,151,7,157,5,49,5,150,253,225,251,38,253,10,252,89,19,155,251,65,4,61,4,23,4,21,4,45,3,244,251,246,4,53,253,84,253,160,255,125,255,33,1,14,3,116,2,45,252,36,4,49,252,60,252,213,252,242,255,223,0,166,1,51,2,184,2,123,252,135,253,240,1,120,255,22,0,173,255,204,255,8,1,24,0,147,0,66,254,83,251,22,251,81,253,41,251,229,252,214,251,84,251,147,0,93,10,49,251,5,251,40,251,239,251,20,251,121,251,169,7,222,255,121,11,80,8,218,250,181,250,210,250,236,250,191,250,210,250], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1297504);
/* memory initializer */ allocate([154,252,214,254,222,7,50,15,91,252,10,252,165,252,206,251,6,254,117,251,70,252,205,252,184,1,220,2,186,253,12,251,74,251,243,251,199,251,25,251,130,251,189,252,56,9,189,5,48,251,152,250,148,250,30,2,177,250,162,253,201,250,60,7,94,8,138,14,62,251,215,250,12,251,73,251,77,251,220,250,70,252,72,253,122,18,104,11,55,251,230,250,149,251,7,251,4,251,42,251,240,251,31,8,92,10,139,7,113,251,234,250,147,2,236,253,118,253,208,253,252,251,186,0,200,4,251,10,128,252,63,254,25,252,201,252,175,255,148,252,246,1,219,254,168,2,221,2,188,252,169,251,148,251,159,252,139,251,86,252,44,252,7,5,69,2,158,5,185,250,51,251,106,251,1,253,123,5,182,0,20,2,189,1,159,1,98,2,185,251,253,252,138,251,149,12,221,252,88,253,210,254,62,1,185,1,182,1,92,251,121,4,16,6,240,253,119,3,221,253,83,254,124,0,99,0,128,0,0,253,25,4,206,253,97,4,175,253,160,255,151,255,105,0,251,0,154,0,148,6,62,6,133,253,83,253,79,255,45,255,244,254,234,0,138,255,207,255,49,253,151,252,188,251,39,252,90,253,106,254,22,255,151,1,141,2,123,12,223,3,184,253,150,252,242,255,85,253,148,11,255,252,62,254,31,1,94,1,85,3,221,252,194,253,225,6,102,254,196,255,26,255,178,255,235,255,19,0,9,251,83,17,95,253,234,252,110,0,13,255,175,255,147,0,191,0,145,0,195,21,157,253,134,253,69,253,61,255,231,254,7,255,210,254,240,254,189,255,131,252,112,253,23,253,71,253,218,253,129,253,103,254,13,12,127,1,30,3,201,254,172,254,204,253,237,252,44,14,180,254,2,254,37,255,209,1,95,1,21,253,196,251,52,252,41,253,108,254,138,253,80,255,181,1,24,13,210,3,138,252,17,253,1,253,188,253,75,253,82,252,221,252,98,255,220,255,253,255,58,252,94,253,3,12,98,252,84,255,247,255,216,255,111,0,169,0,212,0,181,0,213,252,53,253,38,252,247,253,82,253,75,15,18,0,198,255,243,1,210,0,93,251,121,252,109,252,246,253,14,4,221,1,20,3,34,1,156,1,14,252,233,252,68,253,58,253,34,0,238,6,0,255,96,0,131,0,241,0,29,251,38,8,251,255,3,253,66,254,141,0,93,0,160,0,88,0,129,0,127,251,147,4,88,251,207,251,121,254,69,255,206,0,160,1,188,1,136,2,195,2,226,253,8,254,18,253,145,253,120,253,8,3,180,2,165,0,74,1,88,4,81,251,148,252,84,254,181,3,65,0,250,0,104,0,108,0,173,0,99,8,119,252,178,252,228,253,136,254,125,255,143,255,124,0,58,1,229,1,229,4,253,253,155,5,241,253,21,0,156,255,144,254,172,255,137,255,112,255,161,250,91,251,91,251,25,252,45,253,66,255,28,3,127,2,187,2,48,3,92,251,105,252,171,2,74,3,177,0,194,255,231,255,71,0,15,0,16,0,157,0,80,0,181,254,169,254,12,0,193,0,123,255,162,255,162,255,192,255,230,250,19,2,107,252,114,255,250,4,102,0,241,255,184,0,159,0,148,0,213,255,177,251,187,253,93,254,191,1,124,255,52,255,187,0,119,2,205,1,234,250,118,251,97,252,128,3,203,0,164,0,201,255,31,1,32,2,229,1,22,251,233,252,165,2,79,252,12,255,155,255,167,1,106,1,42,1,133,1,199,252,128,253,122,253,18,1,183,255,238,254,193,5,243,255,132,0,169,0,1,253,101,251,92,251,211,251,78,253,84,255,19,3,109,5,87,6,76,3,87,255,130,252,105,252,51,0,15,0,170,1,186,254,43,6,182,0,77,0,202,0,95,254,155,254,239,255,106,8,179,255,161,253,179,253,137,254,251,254,136,254,175,0,195,252,223,252,189,253,222,254,12,255,21,2,27,5,105,3,147,252,105,251,123,251,42,253,205,1,193,6,177,1,219,0,246,0,94,2,233,252,197,252,137,2,123,3,52,3,208,2,151,1,127,253,41,253,60,253,194,9,193,3,157,255,226,253,238,253,5,254,232,253,160,253,126,253,146,253,60,1,195,0,47,253,219,253,3,255,240,5,171,0,175,255,140,254,179,254,142,4,208,251,50,251,157,251,249,251,156,252,142,254,209,0,25,6,215,6,113,0,145,254,143,1,105,253,246,255,241,254,182,3,118,0,177,254,240,254,161,252,60,0,149,252,58,7,14,255,236,254,218,255,150,255,215,1,30,0,55,3,168,254,16,253,54,253,203,254,93,254,86,0,68,6,6,255,71,255,185,252,65,253,207,253,231,254,21,7,199,255,255,0,10,1,224,255,99,0,144,1,216,9,59,1,140,254,206,254,1,254,219,253,109,253,8,253,39,253,209,253,119,255,158,253,174,0,156,3,202,254,63,253,205,254,117,3,0,2,157,253,183,251,108,251,208,251,10,253,241,253,64,255,22,1,228,2,70,13,144,251,153,1,26,255,159,254,119,255,66,1,70,1,109,1,133,0,173,0,243,8,124,253,43,253,172,253,233,253,172,254,168,255,191,255,203,255,17,1,8,253,122,254,119,253,119,0,13,255,34,255,190,6,143,255,44,0,70,1,150,253,55,1,41,9,15,255,114,254,113,254,130,254,190,254,68,254,55,254,81,7,58,254,7,254,42,0,225,1,187,0,207,255,7,254,134,253,14,253,28,4,171,253,35,5,41,1,100,254,146,255,51,255,216,253,86,253,244,253,225,251,81,254,203,3,149,254,229,253,146,254,39,0,227,3,181,0,220,1,150,2,229,0,67,254,146,6,51,255,75,255,239,254,15,254,83,253,140,253,247,23,235,255,190,252,90,252,22,252,214,251,93,252,50,252,122,252,125,253,204,252,99,7,62,253,224,254,4,255,25,255,177,255,126,0,35,0,37,0,10,0,246,255,220,255,250,255,247,255,209,255,249,255,1,0,11,0,254,255,132,2,59,1,145,0,159,254,116,254,84,254,155,254,196,255,19,1,109,0,101,251,72,252,70,253,138,0,30,1,171,0,138,1,7,1,46,3,239,1,22,254,110,0,113,1,87,2,9,0,87,2,81,254,23,255,184,254,187,255,154,1,22,252,50,254,77,0,97,0,196,0,133,0,165,255,0,2,49,0,109,2,76,254,160,254,122,254,45,255,68,255,58,254,194,254,44,0,144,5,34,250,73,250,200,250,103,251,145,254,89,0,219,1,99,3,38,2,52,3,219,252,188,253,221,252,167,255,207,252,155,6,208,254,120,0,36,0,52,2,153,1,243,253,204,252,106,1,55,252,154,252,163,253,191,7,225,3,210,2,225,5,77,4,182,252,176,252,106,252,133,254,185,255,1,1,243,1,95,2,83,6,68,252,0,252,155,252,24,253,182,255,27,3,172,2,20,2,122,2,176,250,206,252,49,0,43,252,111,0,39,254,50,253,35,254,121,1,198,2,137,250,175,251,128,251,0,252,122,9,156,254,65,255,55,4,143,3,140,4,215,252,233,252,105,252,171,10,173,252,112,254,143,255,242,0,252,1,79,3,51,251,175,4,114,252,103,4,82,253,129,254,26,0,96,1,24,2,134,2,234,252,37,251,177,251,110,251,148,251,215,251,236,252,247,253,161,0,2,15,182,251,141,252,228,251,8,0,177,251,21,253,216,253,32,254,15,255,52,3,64,13,254,252,254,252,44,253,180,253,86,254,103,255,170,1,127,2,212,2,90,6,55,253,133,4,32,253,20,254,0,254,96,255,205,1,57,2,71,2,185,250,52,5,58,251,178,250,240,0,5,6,44,253,100,2,47,6,170,4,219,251,34,252,97,253,55,252,72,252,64,9,70,254,99,254,141,7,255,3,112,255,229,254,32,252,84,252,215,3,24,255,50,3,85,1,246,1,37,2,116,250,12,251,1,251,67,251,147,253,227,7,173,2,156,7,240,4,176,4,243,250,104,253,136,1,176,252,98,3,167,4,36,255,95,0,194,1,128,2,202,250,74,4,17,253,67,253,16,5,165,254,164,255,233,0,20,2,87,2,72,252,74,253,13,12,116,252,0,255,18,254,79,255,123,0,41,3,173,3,18,0,191,251,223,252,47,1,7,253,11,0,120,2,32,1,220,1,6,2,15,255,142,251,212,251,155,252,36,1,121,0,230,255,160,255,201,1,36,2,150,255,240,252,162,3,68,253,50,7,212,252,151,253,205,254,174,1,143,2,70,253,133,4,179,3,221,252,106,253,25,253,207,255,96,4,92,1,66,2,87,3,231,251,15,253,189,255,198,2,165,254,228,255,182,2,155,1,212,1,195,255,239,0,23,0,208,251,11,253,221,1,110,253,150,254,239,0,64,2,57,250,1,251,250,250,91,253,85,252,46,253,145,12,82,1,26,6,30,6,157,3,149,3,71,253,60,253,133,2,65,254,232,254,202,2,247,1,40,2,230,251,3,252,121,3,68,252,90,252,193,2,201,1,104,2,44,2,155,2,205,250,205,255,0,255,208,255,22,255,240,0,245,2,182,255,148,0,100,1,2,251,2,6,234,0,140,254,40,254,35,255,88,254,18,254,170,0,39,2,216,0,38,1,139,252,231,0,249,254,78,1,192,255,202,255,35,1,94,1,140,251,206,251,81,251,162,250,2,251,179,252,221,253,155,2,192,17,130,7,125,252,94,252,70,252,160,251,188,251,132,4,97,7,108,254,3,1,90,4,68,252,188,252,113,3,196,254,47,252,164,252,202,0,7,255,121,0,48,3,92,251,60,14,195,252,148,252,98,253,39,254,95,255,164,1,83,3,118,3,10,252,167,4,86,252,66,252,160,252,229,2,241,0,189,3,32,1,117,2,125,251,126,252,80,4,235,252,28,0,157,252,188,253,28,10,68,3,210,4,71,252,19,253,166,3,113,4,202,254,79,255,143,255,244,0,20,2,168,1,171,254,166,253,144,252,175,251,209,254,131,254,241,253,151,7,126,0,247,2,3,251,243,251,59,0,241,252,229,1,179,253,61,5,225,2,232,1,197,2,63,250,72,251,198,251,77,2,23,3,223,2,191,1,66,1,67,3,219,2,164,251,87,253,176,253,192,2,8,2,223,253,152,255,232,255,7,1,202,1,120,2,47,253,194,251,57,251,130,251,158,252,1,6,255,10,123,0,73,4,42,251,163,252,63,251,42,251,19,251,110,252,141,4,166,1,199,2,115,3,84,251,52,252,84,254,26,255,171,0,8,0,64,254,171,4,189,1,184,1,99,254,117,255,137,254,200,253,243,252,248,253,99,2,182,253,113,3,77,2,44,253,204,3,117,252,230,252,205,252,127,253,114,6,66,0,254,0,191,2,156,250,112,251,57,252,164,2,3,253,231,253,66,2,6,6,175,2,65,3,127,4,213,252,76,252,29,252,10,255,21,5,135,254,6,1,120,2,140,2,250,5,89,253,86,253,225,3,102,253,55,254,184,255,236,255,61,1,4,2,93,3,240,253,24,0,189,253,126,254,53,0,14,2,180,255,66,0,89,1,197,255,156,253,165,0,75,255,158,255,222,255,190,255,30,1,95,0,108,0,162,251,109,255,131,2,225,251,0,253,10,254,181,253,27,0,65,8,43,3,61,251,77,252,213,252,92,251,119,4,159,253,15,253,88,0,28,11,144,5,108,250,198,251,7,251,62,4,74,251,109,251,23,1,2,254,21,9,221,6,99,250,142,2,2,251,13,251,163,251,74,252,11,3,157,8,126,4,77,4,52,250,15,252,81,251,120,250,65,251,145,2,31,253,122,2,242,4,206,6,91,250,87,251,178,250,122,251,9,252,29,252,113,253,195,15,174,7,111,7,211,251,186,3,181,251,109,251,251,251,206,252,192,253,152,255,110,5,45,4,47,2,110,252,246,251,128,251,37,252,186,253,34,255,138,1,180,4,7,3,72,250,205,255,65,252,19,252,60,254,91,1,162,255,1,0,13,2,83,2,212,250,54,251,178,251,199,252,97,252,248,252,186,253,175,0,139,6,120,2,165,252,28,0,110,252,47,255,44,254,143,253,26,255,134,2,67,2,190,1,132,251,146,251,24,252,183,253,203,2,6,3,114,2,138,2,61,8,126,252,39,253,17,255,43,255,79,3,77,0,115,1,122,252,234,252,61,7,153,252,208,252,163,0,39,1,121,1,182,6,210,251,184,252,233,252,76,6,127,255,144,0,194,1,194,252,117,7,229,253,35,3,101,254,68,255,122,0,148,0,178,4,193,2,72,253,190,253,43,255,231,255,126,0,142,0,237,12,197,251,159,252,253,252,42,254,19,255,212,3,9,2,172,1,29,252,21,252,16,12,24,252,57,254,64,1,247,1,153,253,210,6,17,253,34,253,68,4,31,0,97,0,225,0,105,251,239,8,254,4,91,254,197,254,91,0,130,0,120,0,77,251,115,16,54,252,146,252,28,255,71,0,71,1,32,1,12,252,174,252,191,5,36,253,204,4,201,0,146,0,15,1,156,252,240,253,172,4,232,2,70,255,85,0,38,0,153,0,199,251,129,252,26,253,246,3,86,4,66,0,237,0,79,1,12,252,143,251,5,17,218,251,199,253,121,1,12,1,189,1,179,4,51,253,46,4,227,253,184,255,227,255,91,0,104,0,48,25,132,251,211,251,214,252,109,253,118,0,228,254,44,1,195,251,84,252,42,255,147,253,243,252,146,253,253,6,199,2,115,251,107,6,134,252,215,252,235,253,148,0,128,1,117,1,114,252,38,252,169,252,248,251,63,14,34,254,124,255,201,2,253,255,94,253,244,251,68,252,125,252,138,10,117,2,153,2,4,253,214,251,107,251,222,251,76,253,112,255,90,4,123,12,12,252,125,253,98,253,11,6,192,253,95,1,251,0,17,1,74,252,51,2,26,253,248,0,107,255,2,2,100,0,185,0,63,255,152,253,113,253,255,0,148,254,189,254,172,0,0,1,52,1,228,0,16,0,69,255,13,255,219,0,88,0,53,0,0,252,152,2,194,1,96,254,67,255,17,255,43,0,102,0,192,255,13,254,97,255,112,254,137,3,192,255,188,255,46,0,225,251,179,255,211,252,107,253,59,0,179,255,226,0,65,1,200,4,215,253,76,254,25,3,101,255,173,255,251,255,72,0,116,253,127,252,99,255,189,253,229,253,78,3,181,0,62,1,14,3,57,252,222,252,199,253,250,255,108,1,28,2,1,2,59,254,193,251,147,251,155,251,172,252,98,255,128,4,241,12,247,3,68,254,61,4,47,254,195,254,214,254,41,254,18,255,121,253,146,5,15,255,149,0,212,254,87,255,237,255,28,255,210,12,243,254,255,251,211,251,183,251,209,251,229,253,23,5,87,4,91,252,27,253,223,252,215,253,98,0,137,1,7,4,238,252,39,253,189,252,214,252,178,255,33,6,119,2,176,3,7,4,139,2,103,254,115,254,166,254,35,255,157,255,40,255,168,255,45,255,93,254,193,0,18,5,196,0,35,255,145,252,244,251,233,250,254,250,228,251,193,253,27,1,38,12,57,5,233,1,49,254,128,253,112,0,85,1,190,254,5,1,10,1,110,6,207,252,24,251,7,251,63,251,249,251,114,255,107,14,196,11,28,6,223,254,194,252,54,252,248,251,205,251,35,252,44,2,52,0,180,253,179,253,155,253,20,253,160,254,6,8,187,255,239,252,50,253,13,254,115,255,192,0,116,5,190,1,253,255,254,253,156,253,3,0,171,0,43,4,142,255,147,255,212,252,131,252,248,252,170,254,148,5,165,1,182,1,40,2,91,252,137,251,49,255,32,5,23,3,166,0,58,255,177,255,136,253,98,4,231,253,148,253,194,1,97,0,171,255,174,0,224,6,123,0,88,255,229,1,179,255,201,253,248,252,72,252,10,253,104,251,214,250,181,250,73,251,96,252,79,255,85,24,99,254,5,1,185,254,176,252,43,253,117,254,81,3,253,5,55,255,132,255,160,11,177,254,65,253,94,253,41,253,75,252,247,253,209,0,236,3,70,3,56,0,35,254,17,253,165,253,102,252,153,253,40,7,64,254,183,254,108,255,73,0,211,1,127,19,170,255,215,252,96,252,73,252,68,252,205,252,17,253,49,7,234,252,56,253,140,255,143,255,165,255,0,0,124,254,39,253,60,255,246,2,135,254,68,0,85,0,172,1,221,255,251,255,2,0,247,255,18,0,225,255,53,0,233,255,26,0,128,252,67,254,68,255,50,3,165,254,212,255,246,1,66,2,101,0,152,11,13,1,44,253,66,253,21,253,49,253,95,253,163,29,68,0,109,251,159,250,95,250,81,250,63,250,102,251,187,2,73,2,15,0,209,8,9,254,84,252,195,251,248,250,245,250,43,251,105,251,94,251,141,251,12,2,201,4,184,5,238,251,47,253,123,252,41,0,40,253,54,3,111,253,54,4,29,254,250,5,23,254,229,4,158,3,186,254,148,1,89,0,89,251,110,251,43,251,97,6,213,5,47,254,218,3,160,4,167,252,192,252,212,254,213,252,88,252,101,253,2,255,236,1,204,15,144,251,41,252,169,252,176,253,57,255,127,1,108,3,28,8,238,251,5,252,39,253,155,5,231,255,64,0,77,3,33,252,103,252,163,252,148,3,110,254,217,253,236,0,173,1,133,20,47,251,12,251,98,254,1,7,49,254,199,253,157,6,83,251,178,24,137,252,45,255,79,252,228,253,114,2,135,3,31,252,220,5,22,254,165,5,4,253,120,255,65,1,36,2,206,1,28,255,127,0,190,254,225,1,73,255,88,0,155,0,215,252,180,252,65,252,171,15,187,253,24,255,74,1,218,3,124,252,108,252,211,251,158,252,45,252,73,254,176,15,22,6,1,252,73,8,181,6,156,253,180,253,66,254,223,0,174,1,7,10,52,252,70,8,250,251,124,252,104,253,180,0,90,3,160,12,33,252,148,251,71,8,66,254,220,253,254,254,127,3,62,252,72,255,79,10,57,4,107,253,34,255,36,1,18,2,72,252,231,6,43,255,67,253,55,4,37,0,131,0,233,1,149,252,19,253,95,12,248,252,223,4,147,255,173,255,124,2,134,251,210,251,23,252,216,251,82,252,75,11,113,4,49,6,222,250,136,253,101,251,175,251,77,4,51,0,246,7,244,7,98,252,41,253,180,0,235,5,202,253,167,4,101,0,83,2,199,8,148,254,197,254,151,255,126,255,177,255,121,0,210,0,58,31,234,250,126,252,239,252,10,253,247,252,31,0,159,1,232,2,116,253,176,2,202,4,119,253,163,253,244,254,58,1,99,2,150,2,16,255,101,254,70,253,78,254,121,1,83,1,185,3,214,252,93,252,30,4,28,254,214,254,209,2,10,2,154,3,234,251,72,252,153,252,150,253,242,254,163,1,123,2,238,3,129,0,186,252,44,253,220,0,225,1,253,0,73,1,205,0,56,254,44,253,163,2,86,2,76,1,242,255,35,1,8,252,73,253,30,2,246,4,242,1,56,254,143,255,106,1,221,253,212,251,102,251,19,251,119,251,119,252,134,1,156,8,224,251,178,251,235,21,180,251,204,251,122,252,104,1,210,3,230,253,226,254,229,4,82,254,55,254,108,255,255,255,196,255,164,251,69,252,53,11,98,252,88,253,87,4,194,2,74,3,225,250,5,251,130,251,20,255,163,2,129,3,246,2,144,3,94,7,165,251,25,252,172,255,180,253,142,8,85,255,227,2,31,253,150,0,122,252,170,252,107,252,78,1,45,2,22,2,173,252,217,255,231,255,214,0,120,255,183,255,7,1,234,0,3,252,52,5,225,253,113,253,56,253,117,253,80,0,223,1,19,6,141,7,61,253,27,254,50,255,139,0,56,1,149,1,168,9,108,251,79,252,85,252,55,253,56,2,141,5,172,2,70,0,17,251,45,251,74,2,61,255,215,251,63,254,110,12,137,251,17,2,98,252,210,253,163,1,134,1,119,1,51,2,190,251,42,13,80,253,240,253,166,254,136,0,61,1,103,2,221,252,47,252,198,251,218,252,23,14,69,254,100,255,106,4,248,250,49,6,62,251,54,251,45,252,103,1,19,6,122,5,171,254,96,254,32,254,152,254,97,254,30,2,108,255,190,254,185,251,206,251,250,2,160,252,134,253,234,6,84,1,210,1,240,251,190,252,228,5,61,253,143,0,74,0,138,5,137,3,186,251,58,253,219,253,164,252,117,1,212,5,232,7,229,2,86,252,114,252,101,10,193,251,175,251,123,252,127,1,138,3,243,2,205,252,69,2,156,253,92,254,49,1,88,1,107,1,156,254,33,252,179,252,229,251,64,8,202,6,42,2,186,3,252,251,81,252,132,252,128,252,20,255,94,253,52,4,167,2,157,253,181,251,165,252,110,252,68,254,142,3,235,1,197,2,217,251,7,3,240,1,99,253,208,254,160,2,5,1,240,1,194,251,61,252,13,4,129,253,122,255,191,253,33,0,95,2,210,251,119,253,218,2,20,253,92,7,238,255,90,1,115,2,191,251,162,251,69,252,239,2,78,253,94,2,180,4,13,4,8,252,185,251,217,1,105,252,244,251,83,253,208,6,192,4,190,252,108,252,104,252,134,253,62,4,38,254,161,0,108,2,27,252,125,252,231,255,13,254,143,1,149,1,163,0,145,1,50,0,150,0,250,0,94,1,194,1,58,2,188,2,72,3,232,3,146,4,90,5,64,6,58,7,102,8,196,9,84,11,72,13,160,15,192,18,168,22,88,27,52,33,4,41,188,52,104,66,0,0,0,0,0,0,112,7,20,0,112,7,20,0,112,7,20,0,96,7,20,0,0,0,0,0,0,0,0,0,0,0,40,0,80,0,180,255,160,0,102,255,236,0,20,255,0,0,241,255,50,0,206,255,115,0,141,255,235,0,21,255,152,7,20,0,152,7,20,0,152,7,20,0,96,7,20,0,0,0,0,0,0,0,0,0,0,0,236,255,15,0,176,255,100,0,96,255,180,0,96,255,1,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,255,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,254,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,11,10,16,24,40,51,61,12,12,14,19,26,58,60,55,14,13,16,24,40,57,69,56,14,17,22,29,51,87,80,62,18,22,37,56,68,109,103,77,24,35,55,64,81,104,113,92,49,64,78,87,103,121,120,101,72,92,95,98,112,100,103,99,17,18,24,47,99,99,99,99,18,21,26,66,99,99,99,99,24,26,56,99,99,99,99,99,47,66,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,80,127,29,0,184,37,29,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,80,127,29,0,136,214,28,0,184,37,29,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,80,127,29,0,128,1,32,0,232,208,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,127,29,0,152,41,31,0,40,129,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,127,29,0,216,35,35,0,136,221,34,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,96,161,34,0,136,221,34,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,216,100,34,0,128,45,34,0,20,0,0,0,1,0,0,0,25], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1307744);
/* memory initializer */ allocate([192,255,255,255,223,65,16,0,1,0,0,0,0,0,144,254,33,0,128,45,34,0,20,0,0,0,1,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,96,209,33,0,24,171,33,0,52,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,128,140,33,0,80,105,33,0,56,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,24,40,33,0,80,105,33,0,56,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,248,2,33,0,40,232,32,0,64,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,112,205,32,0,40,232,32,0,64,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,176,178,32,0,128,157,32,0,76,0,0,0,82,76,79,67,112,131,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,144,106,32,0,128,157,32,0,76,0,0,0,82,76,79,67,112,131,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,33,0,108,0,0,0,40,27,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,31,248,31,249,31,250,31,251,31,248,63,249,63,252,7,254,0,126,0,14,0,2,0,0,0,6,0,30,0,62,0,254,1,250,15,246,31,250,63,251,63,252,63,253,63,254,63,255,63,0,0,0,0,0,0,13,13,13,13,13,14,14,11,8,7,4,2,1,3,5,6,9,12,13,14,14,14,14,14,14,0,0,0,0,0,0,0,226,255,3,0,227,255,3,0,228,255,3,0,229,255,3,0,230,255,3,0,231,255,3,0,232,255,3,0,233,255,3,0,234,255,3,0,235,255,3,0,236,255,3,0,237,255,3,0,238,255,3,0,239,255,3,0,240,255,3,0,247,255,0,0,240,255,1,0,252,63,0,0,254,7,0,0,252,7,0,0,254,0,0,0,126,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,30,0,0,0,62,0,0,0,254,1,0,0,253,7,0,0,254,15,0,0,250,127,0,0,246,255,0,0,241,255,3,0,242,255,3,0,243,255,3,0,244,255,3,0,245,255,3,0,246,255,3,0,247,255,3,0,248,255,3,0,249,255,3,0,250,255,3,0,251,255,3,0,252,255,3,0,253,255,3,0,254,255,3,0,254,255,7,0,255,255,7,0,0,0,0,0,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,16,17,14,11,11,8,7,4,2,1,3,5,6,9,11,12,15,16,18,18,18,18,18,18,18,18,18,18,18,18,18,18,19,19,0,0,0,0,0,0,0,240,255,15,0,241,255,15,0,242,255,15,0,243,255,15,0,244,255,15,0,245,255,15,0,246,255,15,0,243,255,3,0,245,255,7,0,238,255,7,0,239,255,7,0,246,255,7,0,244,255,3,0,242,255,3,0,247,255,15,0,240,255,7,0,245,255,1,0,240,255,3,0,244,255,1,0,247,255,0,0,246,255,0,0,248,127,0,0,251,63,0,0,253,15,0,0,253,7,0,0,253,3,0,0,253,1,0,0,253,0,0,0,62,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,30,0,0,0,252,0,0,0,252,1,0,0,252,3,0,0,252,7,0,0,252,15,0,0,252,31,0,0,250,63,0,0,249,127,0,0,250,127,0,0,248,255,0,0,249,255,0,0,246,255,1,0,247,255,1,0,245,255,3,0,246,255,3,0,241,255,3,0,248,255,15,0,241,255,7,0,242,255,7,0,243,255,7,0,249,255,15,0,247,255,7,0,244,255,7,0,250,255,15,0,251,255,15,0,252,255,15,0,253,255,15,0,254,255,15,0,255,255,15,0,0,0,0,0,20,20,20,20,20,20,20,18,19,19,19,19,18,18,20,19,17,18,17,16,16,15,14,12,11,10,9,8,6,4,2,1,3,5,8,9,10,11,12,13,14,15,15,16,16,17,17,18,18,18,20,19,19,19,20,19,19,20,20,20,20,20,20,0,231,255,7,0,232,255,7,0,210,255,15,0,211,255,15,0,212,255,15,0,213,255,15,0,214,255,15,0,215,255,15,0,216,255,15,0,218,255,7,0,217,255,15,0,218,255,15,0,219,255,15,0,220,255,15,0,219,255,7,0,221,255,15,0,220,255,7,0,221,255,7,0,222,255,15,0,228,255,3,0,223,255,15,0,224,255,15,0,225,255,15,0,222,255,7,0,226,255,15,0,227,255,15,0,228,255,15,0,223,255,7,0,229,255,15,0,224,255,7,0,232,255,3,0,225,255,7,0,224,255,3,0,233,255,3,0,239,255,1,0,229,255,3,0,236,255,1,0,237,255,1,0,238,255,1,0,244,255,0,0,243,255,0,0,240,255,0,0,247,127,0,0,246,127,0,0,250,63,0,0,250,31,0,0,249,31,0,0,250,15,0,0,248,15,0,0,249,7,0,0,251,3,0,0,252,1,0,0,250,1,0,0,251,0,0,0,124,0,0,0,60,0,0,0,28,0,0,0,12,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,13,0,0,0,29,0,0,0,61,0,0,0,250,0,0,0,252,0,0,0,251,1,0,0,250,3,0,0,248,7,0,0,250,7,0,0,251,7,0,0,249,15,0,0,251,15,0,0,248,31,0,0,251,31,0,0,248,63,0,0,249,63,0,0,241,255,0,0,242,255,0,0,234,255,1,0,235,255,1,0,225,255,3,0,226,255,3,0,234,255,3,0,227,255,3,0,230,255,3,0,231,255,3,0,235,255,3,0,230,255,15,0,226,255,7,0,231,255,15,0,232,255,15,0,233,255,15,0,234,255,15,0,235,255,15,0,236,255,15,0,227,255,7,0,237,255,15,0,238,255,15,0,239,255,15,0,240,255,15,0,228,255,7,0,241,255,15,0,236,255,3,0,242,255,15,0,243,255,15,0,229,255,7,0,230,255,7,0,244,255,15,0,245,255,15,0,246,255,15,0,247,255,15,0,248,255,15,0,249,255,15,0,250,255,15,0,251,255,15,0,252,255,15,0,253,255,15,0,254,255,15,0,255,255,15,0,0,0,0,0,19,19,20,20,20,20,20,20,20,19,20,20,20,20,19,20,19,19,20,18,20,20,20,19,20,20,20,19,20,19,18,19,18,18,17,18,17,17,17,16,16,16,15,15,14,13,13,12,12,11,10,9,9,8,7,6,5,4,3,2,2,3,4,5,6,8,8,9,10,11,11,11,12,12,13,13,14,14,16,16,17,17,18,18,18,18,18,18,18,20,19,20,20,20,20,20,20,19,20,20,20,20,19,20,18,20,20,19,19,20,20,20,20,20,20,20,20,20,20,20,20,0,0,0,0,0,0,0,112,190,29,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,141,29,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,229,31,0,108,0,0,0,16,75,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,207,29,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,198,29,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,32,115,112,114,111,112,45,112,97,114,97,109,101,116,101,114,45,115,101,116,115,61,0,59,32,112,114,111,102,105,108,101,45,108,101,118,101,108,45,105,100,61,0,0,0,0,0,40,123,30,0,120,236,29,0,4,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,224,111,64,16,0,1,0,168,127,29,0,40,38,29,0,184,214,28,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,127,29,0,32,209,35,0,152,129,35,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,127,29,0,32,36,35,0,0,222,34,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,127,29,0,136,161,34,0,16,101,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,127,29,0,232,45,34,0,192,254,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,127,29,0,128,209,33,0,120,171,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,127,29,0,176,140,33,0,232,105,33,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,127,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,40,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,0,0,0,0,0,0,0,0,0,0,0,188,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,16,33,0,108,0,0,0,120,36,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,4,181,63,240,55,152,63,0,0,128,63,240,55,24,63,243,4,53,63,240,55,24,63,0,0,0,63,0,0,0,0,152,217,30,0,108,0,0,0,32,134,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,192,224,240,248,252,254,255,0,1,2,4,8,16,32,64,12,4,4,4,4,4,8,8,8,12,16,20,36,0,0,0,0,0,0,0,0,0,0,0,0,15,4,8,4,8,8,4,8,8,12,12,12,24,28,40,76,0,0,0,0,0,0,0,0,0,17,4,8,8,4,12,12,8,8,24,16,20,24,32,40,60,80,152,0,0,0,0,0,0,0,0,0,0,0,0,11,4,4,8,4,4,12,16,24,20,28,4,0,0,0,0,0,0,0,0,0,0,0,0,0,15,4,8,4,4,8,8,16,20,12,20,20,28,40,56,8,0,0,0,0,0,0,0,0,0,16,8,4,8,8,12,16,20,24,40,32,32,44,56,80,112,16,0,0,0,0,0,0,0,0,0,0,0,0,0,10,4,8,4,8,8,12,20,24,24,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,4,8,8,4,12,12,16,24,16,20,24,32,40,36,0,0,0,0,0,0,0,0,0,0,23,4,4,4,8,4,4,8,8,8,8,8,12,12,16,16,24,24,32,44,48,60,84,72,0,0,0,0,0,0,52,0,0,0,47,0,0,0,43,0,0,0,37,0,0,0,29,0,0,0,22,0,0,0,16,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,3,2,2,1,1,1,5,5,0,0,0,0,0,0,168,41,20,0,104,40,20,0,101,85,137,62,194,152,156,62,245,72,159,62,21,137,188,62,235,195,208,62,92,10,122,62,199,83,148,62,19,199,166,62,61,202,199,62,209,176,211,62,53,5,111,62,56,0,154,62,177,106,168,62,221,105,197,62,65,69,210,62,87,163,132,62,233,90,152,62,49,22,175,62,148,71,197,62,123,110,211,62,245,187,120,62,251,159,149,62,221,132,167,62,170,121,193,62,45,129,206,62,233,169,124,62,24,81,152,62,31,49,172,62,134,220,201,62,168,93,216,62,21,232,90,62,207,173,169,62,51,109,174,62,113,178,195,62,152,155,209,62,119,145,136,62,59,167,157,62,158,58,176,62,152,207,202,62,45,6,217,62,224,189,133,62,48,31,156,62,35,242,168,62,108,13,197,62,90,41,215,62,178,137,127,62,151,99,150,62,107,235,170,62,161,203,193,62,115,147,213,62,21,99,119,62,230,124,154,62,147,188,174,62,26,193,196,62,181,23,213,62,92,49,132,62,141,125,162,62,208,181,178,62,132,128,198,62,50,190,212,62,191,95,122,62,79,12,157,62,23,237,171,62,115,195,193,62,239,166,207,62,254,214,128,62,86,223,159,62,251,76,173,62,121,132,202,62,86,18,217,62,89,89,105,62,161,181,162,62,41,56,173,62,158,6,205,62,189,222,210,62,249,212,142,62,106,46,165,62,205,145,182,62,207,219,205,62,203,239,216,62,174,103,44,61,229,72,142,61,116,189,228,61,136,55,21,62,69,243,85,62,168,13,97,61,61,51,201,61,1,113,225,61,185,184,34,62,251,105,82,62,167,23,57,61,41,2,154,61,120,243,233,61,247,104,30,62,206,52,74,62,75,166,74,61,183,40,163,61,11,187,0,62,185,131,45,62,62,189,84,62,87,43,43,61,22,247,129,61,57,39,247,61,212,79,34,62,62,247,80,62,11,42,65,61,172,14,162,61,149,130,249,61,169,65,32,62,76,114,100,62,64,101,95,61,229,138,164,61,201,149,4,62,151,129,27,62,243,142,78,62,39,197,100,61,73,191,192,61,43,134,15,62,52,88,54,62,112,16,107,62,255,34,58,61,225,156,150,61,180,123,244,61,91,32,30,62,109,38,87,62,121,99,129,61,186,8,195,61,31,60,253,61,131,247,52,62,227,167,94,62,128,32,88,61,115,192,172,61,47,88,237,61,246,178,33,62,158,76,84,62,45,113,84,61,148,143,166,61,35,221,12,62,83,160,59,62,37,152,93,62,65,241,53,61,14,14,141,61,216,76,6,62,1,138,38,62,8,202,93,62,11,65,74,61,10,178,167,61,204,206,5,62,151,65,44,62,217,233,108,62,167,1,101,61,152,236,185,61,52,177,8,62,121,229,38,62,96,165,86,62,184,103,123,61,64,240,201,61,213,123,23,62,186,117,69,62,102,31,109,62,0,2,0,3,4,0,0,0,3,3,4,0,0,0,0,0,8,65,20,0,8,59,20,0,8,43,20,0,0,0,0,0,39,151,114,62,28,32,131,62,6,72,162,62,136,166,208,62,160,94,152,62,126,159,165,62,122,1,178,62,46,197,191,62,46,37,140,62,116,186,152,62,202,235,168,62,26,103,196,62,118,158,157,62,132,105,170,62,158,87,199,62,168,167,207,62,55,106,111,62,150,69,133,62,142,21,188,62,250,11,207,62,182,83,152,62,106,118,161,62,114,48,197,62,200,236,205,62,160,60,146,62,184,42,159,62,54,228,186,62,180,6,197,62,184,168,171,62,176,223,181,62,42,139,195,62,138,32,204,62,109,18,77,62,214,65,128,62,214,164,189,62,196,48,221,62,212,175,157,62,154,227,170,62,222,101,183,62,234,187,193,62,2,42,133,62,152,170,166,62,26,184,182,62,90,252,196,62,98,75,154,62,248,199,174,62,178,243,204,62,56,173,213,62,214,190,136,62,198,104,152,62,150,73,189,62,66,61,199,62,98,155,139,62,106,12,179,62,110,170,200,62,120,17,208,62,102,114,129,62,144,3,179,62,222,227,196,62,48,214,207,62,36,148,175,62,216,160,191,62,134,153,207,62,94,56,215,62,184,59,129,62,108,141,143,62,86,147,164,62,52,225,198,62,122,12,152,62,148,100,162,62,46,14,187,62,134,51,206,62,224,85,144,62,122,91,154,62,10,46,171,62,86,181,208,62,228,91,167,62,70,193,177,62,82,2,192,62,248,140,207,62,71,11,114,62,144,4,162,62,186,137,178,62,126,153,195,62,212,92,147,62,184,147,160,62,42,109,207,62,56,197,216,62,206,20,142,62,70,139,154,62,170,151,190,62,16,163,214,62,58,113,168,62,26,75,185,62,250,212,205,62,74,165,214,62,9,92,102,62,36,157,140,62,66,8,193,62,152,25,202,62,162,34,154,62,52,84,174,62,86,241,191,62,178,24,206,62,88,17,133,62,170,33,169,62,110,9,183,62,158,59,209,62,172,23,154,62,126,128,182,62,66,63,207,62,24,83,216,62,121,72,98,62,92,9,162,62,102,177,205,62,174,106,215,62,12,60,143,62,124,91,169,62,162,130,210,62,40,137,221,62,94,75,135,62,202,26,162,62,126,139,196,62,4,149,223,62,186,82,176,62,166,78,197,62,250,146,217,62,46,20,226,62,139,193,96,62,138,34,114,62,180,87,175,62,74,152,217,62,234,58,149,62,38,2,165,62,144,230,190,62,128,132,200,62,152,177,140,62,12,17,162,62,76,215,176,62,180,197,191,62,204,4,159,62,216,167,171,62,248,105,198,62,114,157,216,62,143,145,100,62,174,212,152,62,92,162,188,62,24,202,199,62,36,2,148,62,174,44,167,62,136,171,192,62,6,177,209,62,190,20,135,62,68,50,158,62,208,77,195,62,178,47,207,62,162,179,177,62,200,198,186,62,220,5,198,62,40,28,207,62,17,178,95,62,74,29,141,62,68,181,185,62,170,40,214,62,74,77,161,62,18,127,174,62,108,219,193,62,8,234,202,62,120,56,143,62,224,154,169,62,244,89,184,62,112,41,195,62,220,31,163,62,36,20,173,62,220,105,209,62,86,80,220,62,210,68,135,62,6,211,148,62,124,184,188,62,84,28,221,62,52,152,139,62,158,30,186,62,132,4,203,62,50,22,215,62,91,250,103,62,108,58,179,62,232,166,201,62,234,63,211,62,122,195,180,62,104,103,189,62,112,190,209,62,112,79,218,62,14,134,133,62,32,2,146,62,124,31,177,62,54,133,203,62,128,43,154,62,20,10,168,62,140,78,182,62,224,84,210,62,14,130,147,62,154,126,158,62,228,0,176,62,240,136,217,62,118,248,158,62,146,237,179,62,84,149,201,62,10,195,212,62,199,164,99,62,24,82,167,62,208,134,193,62,228,25,204,62,190,23,155,62,172,67,165,62,232,15,204,62,198,217,217,62,224,228,141,62,18,214,163,62,124,70,193,62,38,189,219,62,64,110,173,62,82,97,183,62,4,24,209,62,136,218,217,62,197,249,95,62,232,154,145,62,104,193,201,62,110,43,213,62,116,29,154,62,12,45,176,62,92,239,188,62,216,134,212,62,226,194,143,62,2,134,170,62,64,226,192,62,164,136,203,62,66,248,160,62,10,177,185,62,36,235,216,62,158,64,226,62,156,108,136,62,132,245,157,62,244,120,203,62,8,188,213,62,90,164,150,62,24,14,175,62,240,80,211,62,194,169,222,62,20,25,147,62,222,52,170,62,128,249,193,62,54,96,224,62,236,219,182,62,238,217,203,62,172,24,220,62,240,115,227,62,247,46,107,62,131,133,128,62,168,157,174,62,106,10,207,62,28,197,150,62,220,125,171,62,160,135,184,62,20,114,196,62,162,149,147,62,30,154,159,62,248,209,169,62,0,239,186,62,226,86,166,62,234,249,176,62,24,208,198,62,82,217,207,62,176,108,128,62,172,36,142,62,112,217,189,62,228,236,199,62,178,72,150,62,116,25,168,62,240,194,200,62,70,165,209,62,44,53,145,62,230,150,155,62,84,203,193,62,74,108,203,62,68,7,171,62,26,167,180,62,92,103,203,62,4,34,212,62,161,55,99,62,21,246,128,62,140,82,190,62,182,19,221,62,240,91,160,62,140,174,174,62,72,35,187,62,72,242,198,62,214,235,138,62,222,166,173,62,220,168,185,62,232,157,202,62,54,119,157,62,234,15,178,62,96,86,205,62,178,147,221,62,110,206,132,62,160,17,147,62,236,12,198,62,212,228,207,62,30,43,146,62,56,45,176,62,144,217,205,62,102,189,214,62,128,20,136,62,138,31,174,62,0,35,189,62,230,163,218,62,136,29,181,62,94,216,196,62,156,208,210,62,128,52,218,62,35,184,121,62,50,101,137,62,24,53,175,62,150,2,204,62,34,23,150,62,230,100,171,62,28,49,185,62,68,253,203,62,232,42,149,62,224,85,160,62,32,77,172,62,252,134,198,62,12,127,156,62,160,206,185,62,12,188,198,62,90,163,207,62,79,182,94,62,58,154,159,62,20,129,192,62,152,165,219,62,132,17,149,62,158,164,168,62,8,204,206,62,14,60,216,62,86,170,148,62,216,122,158,62,136,11,194,62,246,206,211,62,186,188,168,62,48,59,193,62,228,43,208,62,124,119,217,62,109,96,124,62,70,14,139,62,176,144,187,62,194,139,220,62,186,210,160,62,210,140,172,62,16,197,194,62,160,123,210,62,96,154,141,62,148,150,167,62,112,186,183,62,68,159,219,62,76,101,162,62,60,203,183,62,120,61,207,62,2,121,225,62,187,154,120,62,50,127,171,62,44,60,203,62,120,158,211,62,28,234,147,62,254,192,166,62,12,129,216,62,86,52,227,62,102,31,142,62,48,165,166,62,248,61,199,62,178,212,225,62,82,223,183,62,16,9,200,62,144,142,215,62,48,21,223,62,223,116,97,62,31,170,125,62,138,113,181,62,200,205,217,62,42,178,156,62,192,229,167,62,122,230,187,62,138,80,201,62,8,167,138,62,26,55,162,62,222,248,176,62,166,204,210,62,4,121,165,62,138,224,176,62,22,145,199,62,32,216,215,62,27,11,124,62,216,241,159,62,130,143,190,62,230,171,202,62,28,147,155,62,212,17,166,62,170,128,197,62,32,12,212,62,30,233,143,62,166,32,163,62,130,115,197,62,44,47,206,62,50,0,181,62,222,210,190,62,50,227,202,62,142,126,211,62,17,62,86,62,156,44,151,62,142,184,194,62,128,208,220,62,130,143,166,62,80,135,177,62,138,207,189,62,34,55,200,62,144,162,146,62,26,231,175,62,26,75,189,62,194,156,199,62,180,212,167,62,50,218,177,62,30,153,207,62,188,96,217,62,108,144,129,62,196,245,154,62,38,171,195,62,162,27,220,62,4,190,150,62,88,210,189,62,138,119,202,62,164,202,214,62,78,151,134,62,234,172,176,62,142,235,206,62,140,3,216,62,154,233,186,62,138,206,195,62,106,172,211,62,182,203,220,62,106,194,126,62,42,147,144,62,130,70,187,62,28,108,210,62,244,84,157,62,50,217,167,62,78,93,193,62,90,88,223,62,138,218,152,62,68,41,164,62,222,125,179,62,10,241,218,62,146,236,161,62,136,206,185,62,114,197,198,62,104,233,217,62,212,208,116,62,134,161,169,62,78,154,189,62,106,253,212,62,66,131,155,62,142,101,170,62,10,10,210,62,48,2,219,62,164,141,151,62,232,85,163,62,158,26,195,62,216,153,218,62,156,62,170,62,212,155,185,62,194,188,216,62,30,202,225,62,148,197,112,62,142,169,140,62,234,250,210,62,20,247,222,62,32,157,152,62,246,238,181,62,202,23,194,62,170,164,212,62,182,29,145,62,144,198,176,62,246,161,189,62,134,222,209,62,254,173,165,62,100,23,187,62,62,92,211,62,28,175,220,62,248,161,141,62,62,220,153,62,254,241,205,62,102,112,218,62,102,202,150,62,22,15,185,62,110,218,214,62,92,190,223,62,176,228,148,62,232,241,174,62,94,26,201,62,40,17,227,62,40,2,184,62,36,215,206,62,70,182,225,62,94,243,231,62,145,167,100,62,224,238,116,62,236,196,165,62,174,231,215,62,38,237,150,62,150,57,163,62,248,216,180,62,244,167,200,62,220,159,132,62,216,215,158,62,72,232,175,62,220,69,202,62,248,8,162,62,176,85,173,62,108,98,201,62,138,16,211,62,237,222,117,62,46,187,145,62,192,118,184,62,236,139,194,62,120,4,152,62,82,176,161,62,196,56,202,62,154,139,212,62,106,36,146,62,172,30,156,62,192,84,185,62,186,192,207,62,158,192,172,62,188,157,182,62,12,51,197,62,16,135,210,62,43,100,101,62,242,45,133,62,160,31,202,62,246,211,214,62,134,238,153,62,134,235,174,62,240,141,189,62,44,111,199,62,20,42,136,62,136,107,166,62,124,169,191,62,152,225,200,62,152,206,161,62,224,84,174,62,132,1,206,62,182,73,215,62,170,40,138,62,226,208,150,62,220,132,185,62,176,21,208,62,160,203,142,62,198,59,184,62,228,152,195,62,54,55,210,62,114,130,133,62,112,132,169,62,60,20,199,62,242,155,207,62,126,206,175,62,80,234,195,62,188,85,212,62,192,249,220,62,55,243,125,62,48,250,139,62,220,141,169,62,186,127,214,62,200,110,155,62,240,128,166,62,172,241,189,62,236,46,212,62,110,197,141,62,18,219,153,62,216,86,181,62,152,140,219,62,46,182,165,62,238,57,184,62,224,111,199,62,74,142,209,62,125,169,116,62,188,173,158,62,108,52,181,62,24,81,213,62,190,245,143,62,76,115,157,62,172,32,213,62,50,134,224,62,72,229,147,62,134,159,158,62,52,86,188,62,14,64,223,62,216,69,173,62,202,195,189,62,220,181,212,62,24,242,220,62,247,12,119,62,164,23,140,62,180,115,199,62,98,56,211,62,148,153,152,62,124,36,174,62,224,185,197,62,12,225,211,62,130,155,144,62,38,199,169,62,24,68,183,62,196,0,211,62,82,142,155,62,202,189,189,62,188,193,207,62,206,239,220,62,203,208,116,62,20,143,159,62,100,239,211,62,44,224,222,62,138,195,136,62,124,18,175,62,176,182,213,62,214,220,224,62,84,48,137,62,14,172,170,62,228,224,197,62,22,251,223,62,116,87,174,62,42,33,200,62,232,247,222,62,176,240,229,62,141,28,87,62,230,26,110,62,106,59,185,62,240,218,220,62,0,202,150,62,2,220,170,62,6,186,195,62,102,26,204,62,254,160,143,62,12,221,166,62,2,136,179,62,198,38,201,62,254,214,163,62,32,246,175,62,102,58,200,62,36,0,224,62,253,223,97,62,186,54,155,62,198,118,195,62,18,25,207,62,174,126,146,62,138,212,168,62,106,181,198,62,0,55,217,62,40,36,138,62,244,145,166,62,138,32,194,62,0,141,212,62,160,114,171,62,112,15,189,62,198,27,202,62,118,231,210,62,151,20,84,62,194,169,139,62,118,211,193,62,68,129,222,62,36,233,156,62,26,130,177,62,254,54,198,62,50,159,206,62,234,80,138,62,180,124,177,62,118,97,193,62,118,249,202,62,170,50,163,62,16,50,174,62,198,121,212,62,156,22,226,62,72,102,132,62,30,245,160,62,66,236,186,62,242,221,215,62,194,191,144,62,118,81,181,62,2,65,208,62,0,201,219,62,255,8,129,62,160,220,183,62,238,74,202,62,140,23,214,62,68,182,181,62,212,249,191,62,182,130,214,62,82,78,223,62,66,153,135,62,120,252,149,62,10,207,167,62,252,76,209,62,150,148,157,62,244,209,171,62,138,115,185,62,70,205,217,62,220,177,147,62,174,212,161,62,162,211,184,62,114,207,214,62,168,94,162,62,198,39,182,62,42,198,207,62,252,18,217,62,20,5,125,62,136,38,173,62,98,100,190,62,198,188,202,62,200,175,157,62,148,86,170,62,210,18,205,62,104,101,224,62,162,24,143,62,206,226,161,62,190,98,203,62,28,151,222,62,14,97,176,62,110,120,187,62,70,105,210,62,14,42,226,62,75,102,113,62,36,212,150,62,42,208,203,62,48,107,213,62,166,201,160,62,0,93,180,62,126,30,194,62,138,106,210,62,180,229,144,62,50,32,173,62,18,252,198,62,146,248,207,62,56,178,165,62,26,83,179,62,142,46,219,62,188,172,228,62,214,194,133,62,152,98,166,62,234,232,204,62,198,195,217,62,64,78,156,62,36,48,175,62,206,84,217,62,208,61,227,62,202,34,147,62,134,61,170,62,198,226,201,62,104,148,226,62,206,134,191,62,102,214,205,62,82,163,220,62,242,104,227,62,209,33,112,62,22,47,131,62,218,182,174,62,100,153,216,62,134,105,156,62,68,135,168,62,98,150,180,62,198,237,200,62,164,9,144,62,34,73,155,62,90,166,178,62,198,76,201,62,56,207,164,62,62,106,179,62,50,109,203,62,64,65,212,62,224,111,117,62,52,188,149,62,22,4,194,62,178,6,203,62,96,87,157,62,116,131,168,62,94,2,204,62,188,16,213,62,130,15,146,62,178,23,158,62,90,44,201,62,44,49,212,62,70,91,176,62,134,114,185,62,210,148,203,62,126,226,213,62,47,167,109,62,32,30,137,62,34,147,193,62,196,126,222,62,182,6,156,62,176,39,180,62,142,127,192,62,238,99,202,62,172,35,134,62,22,66,177,62,162,26,190,62,50,43,211,62,0,70,159,62,162,187,179,62,206,8,213,62,212,97,222,62,60,202,140,62,20,224,151,62,22,105,198,62,102,136,209,62,248,245,148,62,52,123,181,62,66,111,201,62,64,2,209,62,202,50,139,62,202,230,176,62,74,53,198,62,204,93,216,62,94,251,185,62,158,140,195,62,38,232,206,62,174,52,214,62,83,171,123,62,198,186,139,62,186,86,178,62,208,174,217,62,212,214,160,62,154,253,172,62,222,250,186,62,150,16,207,62,26,145,150,62,96,69,162,62,226,163,175,62,82,240,207,62,218,22,161,62,248,172,190,62,102,35,205,62,8,251,213,62,110,161,111,62,142,197,160,62,10,25,196,62,238,161,222,62,106,87,150,62,130,28,164,62,70,89,210,62,236,110,223,62,28,58,148,62,8,168,159,62,158,202,197,62,160,166,224,62,20,19,167,62,216,255,194,62,186,229,214,62,206,169,224,62,27,106,128,62,190,231,144,62,238,181,195,62,72,85,222,62,48,83,163,62,218,144,176,62,62,209,190,62,62,156,216,62,142,166,147,62,192,89,172,62,222,78,189,62,38,161,217,62,38,186,156,62,192,130,195,62,30,31,214,62,236,160,221,62,10,131,111,62,186,145,176,62,206,8,211,62,58,194,219,62,22,108,146,62,22,145,175,62,102,168,217,62,64,123,227,62,168,73,143,62,204,117,173,62,106,191,200,62,152,142,225,62,248,160,186,62,20,176,195,62,194,18,220,62,78,66,228,62,137,4,112,62,248,198,131,62,44,25,184,62,146,52,220,62,36,45,156,62,204,185,167,62,68,177,193,62,76,83,205,62,114,23,142,62,250,225,162,62,136,79,188,62,12,151,205,62,170,131,170,62,42,46,182,62,208,108,198,62,238,104,217,62,201,230,122,62,244,7,160,62,128,68,200,62,92,73,209,62,34,24,152,62,216,52,174,62,184,44,201,62,190,152,219,62,244,64,142,62,254,104,166,62,200,124,203,62,150,243,212,62,28,237,178,62,38,160,189,62,176,124,202,62,16,37,221,62,143,10,109,62,4,1,149,62,92,125,193,62,38,81,221,62,32,121,163,62,96,20,181,62,48,16,195,62,32,178,203,62,38,82,148,62,6,86,179,62,0,239,194,62,164,194,203,62,6,113,168,62,14,58,180,62,180,58,211,62,214,12,224,62,176,115,141,62,196,194,154,62,64,113,195,62,228,182,222,62,78,43,143,62,48,89,191,62,196,34,211,62,14,123,220,62,64,195,129,62,126,92,187,62,160,114,212,62,146,144,221,62,32,145,192,62,14,80,202,62,52,101,213,62,68,181,221,62,204,143,134,62,50,152,147,62,12,222,177,62,118,46,217,62,190,150,154,62,58,243,175,62,64,10,193,62,12,80,222,62,188,125,152,62,48,161,165,62,192,158,186,62,96,250,221,62,88,222,169,62,204,136,186,62,148,230,203,62,150,194,222,62,228,6,127,62,174,222,167,62,132,101,196,62,120,1,223,62,136,251,155,62,134,196,167,62,160,67,214,62,102,252,225,62,66,11,152,62,20,214,165,62,220,234,199,62,170,60,225,62,198,22,176,62,152,244,187,62,120,234,219,62,56,243,227,62,8,208,132,62,242,76,149,62,232,9,207,62,50,226,220,62,214,86,152,62,234,19,183,62,240,41,199,62,224,41,220,62,124,113,145,62,112,251,178,62,12,24,195,62,80,3,220,62,72,196,166,62,188,239,191,62,196,41,221,62,78,3,229,62,202,213,135,62,98,38,161,62,40,90,213,62,24,229,223,62,216,205,153,62,202,82,181,62,88,105,219,62,54,177,235,62,146,157,152,62,24,216,178,62,16,5,205,62,62,124,229,62,134,75,192,62,28,84,213,62,192,95,226,62,12,204,231,62,17,222,199,61,53,87,253,61,38,129,45,62,13,119,194,61,97,232,77,62,190,76,104,62,245,107,184,61,173,190,24,62,54,248,103,62,213,99,46,62,203,244,73,62,103,249,127,62,183,196,222,61,169,158,27,62,138,83,51,62,215,103,5,62,191,88,90,62,106,40,107,62,1,213,255,61,23,216,63,62,6,160,81,62,125,124,77,62,109,117,106,62,134,241,137,62,193,252,183,61,59,87,0,62,166,151,87,62,65,24,197,61,135,40,84,62,40,35,130,62,109,118,216,61,35,38,55,62,134,236,76,62,77,203,31,62,239,215,96,62,92,8,149,62,143,176,12,62,75,213,35,62,14,95,71,62,113,172,219,61,121,127,115,62,138,158,138,62,107,104,18,62,65,99,78,62,82,182,95,62,185,105,91,62,10,52,139,62,234,54,154,62,255,197,226,61,145,229,8,62,30,152,30,62,147,116,218,61,75,235,52,62,148,141,134,62,73,171,187,61,119,200,50,62,222,151,96,62,159,116,60,62,105,111,105,62,96,181,125,62,195,115,226,61,15,1,34,62,166,183,72,62,153,191,8,62,25,216,109,62,159,239,128,62,25,170,31,62,65,54,54,62,186,84,95,62,211,223,68,62,51,128,127,62,72,111,148,62,55,224,232,61,111,46,13,62,218,204,79,62,175,9,210,61,121,65,61,62,154,150,149,62,185,223,11,62,245,126,34,62,114,49,119,62,27,246,48,62,101,73,127,62,182,213,153,62,245,39,12,62,25,6,33,62,158,249,87,62,249,17,4,62,73,13,123,62,228,9,137,62,213,208,42,62,179,136,65,62,242,229,108,62,139,210,109,62,162,193,134,62,180,45,162,62,159,89,189,61,189,182,245,61,66,218,67,62,63,153,231,61,241,118,85,62,122,223,106,62,103,68,206,61,209,11,16,62,212,32,132,62,197,4,43,62,15,87,95,62,134,114,134,62,186,127,0,62,105,151,38,62,198,213,60,62,119,16,28,62,87,26,84,62,64,134,125,62,99,189,12,62,179,150,56,62,114,236,94,62,141,215,84,62,199,48,127,62,44,39,138,62,107,138,191,61,49,199,24,62,78,144,81,62,199,94,229,61,127,163,102,62,94,238,124,62,141,224,223,61,159,118,70,62,246,238,90,62,73,82,51,62,86,74,129,62,166,215,140,62,109,52,12,62,251,178,53,62,118,174,74,62,63,24,12,62,217,31,115,62,40,201,145,62,55,158,36,62,53,167,77,62,138,81,95,62,189,81,111,62,252,97,136,62,20,103,149,62,249,15,244,61,89,14,15,62,134,58,64,62,245,49,6,62,107,88,70,62,176,86,133,62,29,187,221,61,211,40,41,62,134,69,117,62,91,18,80,62,101,93,103,62,144,99,127,62,93,161,253,61,47,75,21,62,150,207,92,62,245,85,47,62,145,196,115,62,98,21,132,62,21,238,42,62,149,33,65,62,242,48,88,62,247,172,87,62,228,94,134,62,38,246,144,62,213,146,216,61,175,142,11,62,214,84,97,62,97,66,199,61,41,19,111,62,64,156,151,62,131,133,9,62,65,156,70,62,110,227,116,62,187,43,40,62,82,70,138,62,216,153,150,62,191,47,18,62,129,254,40,62,146,122,101,62,177,237,21,62,152,228,125,62,106,246,153,62,53,249,50,62,23,157,96,62,254,224,115,62,139,251,113,62,168,210,148,62,14,241,167,62,231,160,233,61,223,67,8,62,126,86,49,62,115,154,232,61,233,223,66,62,70,123,119,62,1,245,175,61,181,218,39,62,26,165,115,62,5,140,69,62,143,62,92,62,1,222,116,62,59,150,12,62,221,63,35,62,26,9,56,62,75,206,15,62,39,108,99,62,106,190,118,62,167,193,15,62,207,38,66,62,42,146,82,62,181,198,88,62,153,65,114,62,220,255,143,62,195,239,184,61,141,53,2,62,110,44,111,62,147,133,225,61,47,90,86,62,50,177,139,62,223,5,239,61,91,31,54,62,250,39,100,62,89,13,58,62,235,214,109,62,166,203,140,62,29,18,22,62,199,138,45,62,214,207,66,62,123,171,223,61,52,206,134,62,16,181,147,62,35,105,25,62,57,106,88,62,158,100,106,62,149,99,74,62,132,3,145,62,64,56,161,62,141,247,254,61,181,154,21,62,186,28,42,62,157,29,10,62,59,108,59,62,152,29,148,62,193,21,191,61,151,96,60,62,158,68,116,62,247,120,69,62,165,86,117,62,212,79,132,62,45,137,253,61,171,135,41,62,2,105,85,62,149,197,26,62,217,117,113,62,110,192,132,62,5,70,26,62,33,157,66,62,226,215,105,62,243,239,74,62,136,122,131,62,14,50,158,62,228,146,3,62,123,169,24,62,54,35,75,62,187,137,188,61,41,83,89,62,100,253,149,62,81,25,17,62,69,126,48,62,26,84,132,62,127,116,73,62,7,57,107,62,128,112,151,62,123,151,22,62,221,248,44,62,34,87,84,62,209,148,11,62,158,79,133,62,234,177,144,62,213,98,57,62,131,171,78,62,178,153,116,62,207,54,123,62,40,116,143,62,122,184,159,62,9,67,213,61,207,59,8,62,6,100,66,62,189,131,252,61,233,166,86,62,191,194,125,62,23,9,254,61,201,169,35,62,200,136,132,62,189,137,63,62,123,150,89,62,28,238,132,62,145,121,254,61,125,240,49,62,122,122,69,62,91,187,34,62,151,204,102,62,164,31,121,62,111,26,29,62,35,105,68,62,130,69,86,62,45,155,104,62,209,154,128,62,70,146,139,62,209,30,225,61,229,222,32,62,58,78,97,62,25,248,7,62,207,192,96,62,4,184,136,62,239,230,1,62,191,155,75,62,166,40,95,62,77,2,68,62,192,61,129,62,36,153,139,62,25,1,31,62,31,226,55,62,154,151,77,62,223,188,240,61,153,209,125,62,202,214,157,62,23,175,41,62,61,99,87,62,58,179,106,62,145,28,103,62,226,161,145,62,94,204,159,62,123,156,4,62,109,251,23,62,54,129,56,62,113,119,30,62,147,126,74,62,70,216,136,62,41,173,3,62,27,104,52,62,226,169,117,62,195,21,92,62,113,86,115,62,166,128,132,62,237,102,3,62,163,41,35,62,206,16,104,62,73,124,31,62,177,175,125,62,236,37,140,62,161,245,51,62,5,180,74,62,238,95,96,62,151,223,95,62,103,181,123,62,120,216,153,62,109,17,241,61,83,1,21,62,238,193,115,62,153,173,241,61,105,37,101,62,30,158,150,62,73,251,26,62,113,172,64,62,143,182,126,62,15,219,65,62,118,6,138,62,30,107,150,62,59,126,25,62,229,185,50,62,218,32,115,62,81,33,15,62,126,29,139,62,36,157,157,62,69,92,60,62,207,179,84,62,218,41,104,62,169,84,130,62,82,225,151,62,96,76,166,62,10,142,93,60,55,41,149,60,173,91,33,61,45,235,187,60,81,145,18,61,65,195,215,61,207,76,171,60,199,42,249,60,66,20,183,61,23,193,154,60,85,195,28,61,203,32,13,62,199,13,168,60,189,221,233,60,216,128,151,61,186,79,64,61,249,22,140,61,78,124,223,61,146,64,1,61,167,30,105,61,128,134,175,61,210,33,28,61,81,74,159,61,85,39,69,62,205,48,177,60,117,243,239,60,52,2,128,61,65,28,255,60,5,98,117,61,159,168,210,61,158,13,248,60,29,36,91,61,0,239,159,61,22,75,133,61,63,173,185,61,133,71,18,62,32,20,6,61,37,115,78,61,61,78,128,61,20,10,88,61,165,1,127,61,31,67,250,61,144,226,14,61,243,134,131,61,18,154,187,61,188,73,72,61,169,40,215,61,111,221,44,62,249,40,193,60,237,126,3,61,149,190,101,61,33,32,227,60,51,151,71,61,161,78,207,61,243,190,224,60,193,223,37,61,14,121,191,61,98,141,51,61,136,24,119,61,249,14,28,62,83,92,220,60,173,130,57,61,65,20,133,61,180,96,83,61,39,42,121,61,88,210,222,61,0,15,44,61,156,156,122,61,12,255,174,61,23,32,146,61,193,214,208,61,23,213,50,62,31,172,236,60,79,143,41,61,141,107,87,61,56,149,1,61,49,228,135,61,234,229,255,61,32,63,48,61,63,139,82,61,88,51,163,61,160,222,105,61,39,24,222,61,143,136,19,62,250,201,10,61,139,190,78,61,186,116,149,61,93,254,133,61,137,254,161,61,70,176,236,61,150,222,29,61,227,36,150,61,154,134,209,61,243,184,134,61,97,194,210,61,157,245,88,62,146,129,125,60,71,147,167,60,247,176,95,61,159,188,186,60,133,34,32,61,247,158,244,61,83,103,251,60,255,45,58,61,148,5,168,61,171,26,185,60,117,61,68,61,251,247,47,62,71,19,222,60,115,141,36,61,249,192,143,61,72,19,75,61,29,102,162,61,40,194,214,61,244,192,250,60,235,9,103,61,142,121,194,61,162,227,129,61,1,181,186,61,101,40,61,62,153,88,199,60,1,144,32,61,223,79,129,61,32,115,10,61,99,87,135,61,129,100,227,61,60,23,16,61,53,82,109,61,150,153,147,61,32,237,132,61,135,82,177,61,61,92,30,62,35,39,239,60,249,111,83,61,132,56,142,61,60,132,115,61,201,107,147,61,49,126,2,62,142,220,89,61,31,179,130,61,28,99,202,61,116,211,177,61,201,133,16,62,119,84,68,62,241,202,204,60,193,128,20,61,75,83,78,61,91,55,231,60,139,14,95,61,31,188,230,61,68,135,20,61,81,9,60,61,96,50,193,61,148,168,105,61,163,215,152,61,25,250,34,62,159,161,223,60,177,8,59,61,58,30,154,61,74,17,82,61,145,79,174,61,177,27,253,61,122,76,73,61,55,23,115,61,82,247,188,61,42,201,144,61,53,247,215,61,127,57,69,62,35,250,229,60,223,107,43,61,43,128,112,61,2,61,62,61,95,187,144,61,56,16,1,62,14,102,43,61,126,29,129,61,94,233,156,61,226,134,172,61,219,0,232,61,183,34,19,62,44,14,43,61,253,40,101,61,200,97,145,61,228,100,99,61,1,150,194,61,235,202,2,62,20,12,114,61,223,225,150,61,220,210,197,61,88,151,160,61,165,211,16,62,157,165,94,62,17,111,172,60,253,29,239,60,63,110,60,61,176,114,21,61,203,100,61,61,249,57,219,61,111,20,220,60,125,242,32,61,14,70,172,61,27,144,223,60,171,214,98,61,247,251,16,62,87,141,203,60,109,204,20,61,86,37,156,61,106,55,87,61,37,225,158,61,156,162,234,61,202,2,39,61,29,39,93,61,128,226,185,61,242,183,106,61,35,214,156,61,141,227,55,62,189,140], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1317986);
/* memory initializer */ allocate([201,60,67,215,11,61,172,14,139,61,250,52,39,61,207,250,128,61,175,208,203,61,22,227,28,61,79,115,98,61,196,203,161,61,73,76,148,61,249,178,208,61,213,129,22,62,124,38,25,61,183,179,64,61,83,20,134,61,164,5,88,61,139,200,137,61,99,8,15,62,164,9,38,61,145,102,144,61,178,147,189,61,130,160,53,61,47,8,226,61,115,109,76,62,193,212,208,60,235,96,14,61,111,45,120,61,222,93,50,61,253,14,90,61,1,218,221,61,85,12,229,60,35,63,73,61,250,25,181,61,134,0,76,61,253,147,180,61,121,66,28,62,226,205,2,61,247,77,61,61,141,84,140,61,60,171,109,61,99,35,140,61,213,177,235,61,52,186,49,61,13,110,141,61,132,13,173,61,36,125,151,61,95,52,244,61,171,152,53,62,50,145,2,61,197,74,60,61,159,113,106,61,140,173,56,61,208,10,104,61,137,44,7,62,208,11,60,61,65,120,95,61,100,107,176,61,251,130,152,61,13,24,233,61,195,114,37,62,230,209,34,61,53,230,74,61,6,250,147,61,98,127,138,61,219,49,170,61,215,15,3,62,10,9,108,61,33,103,142,61,10,17,215,61,42,90,140,61,177,92,249,61,237,235,97,62,173,250,178,60,77,12,245,60,85,112,83,61,38,60,21,61,115,112,73,61,195,120,252,61,180,149,31,61,205,58,67,61,196,122,176,61,166,213,41,61,97,231,140,61,179,107,45,62,66,109,9,61,25,35,43,61,98,248,150,61,248,168,109,61,135,61,178,61,74,65,231,61,36,181,68,61,253,66,105,61,2,89,206,61,102,76,117,61,227,180,175,61,225,56,78,62,219,49,245,60,195,184,33,61,185,96,132,61,116,46,31,61,77,93,165,61,163,149,236,61,220,33,15,61,13,205,128,61,62,220,164,61,229,17,141,61,249,63,203,61,33,62,36,62,22,49,21,61,175,187,90,61,68,63,137,61,166,255,110,61,151,211,160,61,13,38,17,62,10,66,71,61,241,213,148,61,16,55,194,61,166,213,111,61,138,143,11,62,55,104,75,62,73,184,213,60,139,242,24,61,37,127,100,61,172,205,59,61,255,149,101,61,43,132,241,61,20,163,47,61,79,214,82,61,72,190,199,61,54,149,130,61,85,231,178,61,253,95,44,62,230,76,26,61,111,175,59,61,186,20,161,61,164,71,138,61,167,13,184,61,124,145,244,61,126,203,95,61,213,143,136,61,150,13,183,61,0,84,158,61,97,90,249,61,127,94,76,62,75,71,1,61,105,4,57,61,75,40,128,61,62,38,27,61,213,141,164,61,249,75,14,62,118,51,80,61,167,111,125,61,102,56,170,61,136,144,183,61,7,216,3,62,87,217,40,62,112,242,65,61,19,209,107,61,232,185,156,61,34,210,146,61,11,187,202,61,67,51,5,62,11,214,128,61,149,243,161,61,120,68,215,61,106,91,180,61,206,43,41,62,209,84,90,62,2,2,3,3,0,0,0,0,32,103,20,0,32,101,20,0,32,77,20,0,32,71,20,0,112,15,142,62,42,74,162,62,194,126,202,62,166,81,172,62,126,102,184,62,110,80,195,62,20,251,158,62,212,216,169,62,166,213,187,62,254,200,172,62,192,40,203,62,94,32,211,62,166,47,143,62,134,168,187,62,206,71,197,62,220,207,161,62,150,110,197,62,210,119,205,62,34,179,158,62,136,211,175,62,62,120,217,62,108,95,181,62,8,65,209,62,102,38,216,62,54,87,151,62,30,224,170,62,34,92,198,62,124,185,170,62,142,33,198,62,38,126,205,62,94,150,165,62,160,4,187,62,14,56,197,62,144,122,175,62,64,111,206,62,206,255,214,62,80,44,142,62,98,214,195,62,6,253,206,62,102,241,162,62,150,190,202,62,82,218,220,62,16,128,155,62,68,185,194,62,54,213,223,62,18,175,193,62,112,108,208,62,102,105,216,62,208,212,115,62,44,86,175,62,106,104,217,62,138,244,176,62,196,195,188,62,238,55,205,62,4,168,162,62,222,13,175,62,10,171,207,62,182,148,187,62,62,48,199,62,122,243,207,62,178,74,153,62,48,60,180,62,254,198,204,62,88,101,166,62,220,177,199,62,234,197,214,62,162,99,165,62,122,121,188,62,114,222,205,62,212,130,185,62,150,119,213,62,130,148,221,62,222,158,139,62,184,233,183,62,26,144,218,62,172,109,177,62,100,62,189,62,78,204,212,62,90,16,171,62,18,35,182,62,194,34,203,62,188,200,172,62,254,30,210,62,242,26,218,62,0,84,153,62,84,228,194,62,86,41,214,62,174,139,164,62,140,136,210,62,178,138,219,62,204,218,167,62,206,26,189,62,26,105,222,62,14,231,194,62,254,39,218,62,186,176,226,62,252,178,137,62,56,150,175,62,250,31,204,62,210,27,173,62,124,175,192,62,226,185,200,62,12,174,165,62,82,142,178,62,34,191,190,62,46,242,177,62,70,40,201,62,150,163,215,62,218,189,155,62,228,57,184,62,114,101,195,62,160,225,160,62,44,225,205,62,106,21,215,62,218,68,154,62,238,174,185,62,86,200,219,62,172,88,190,62,238,33,204,62,146,229,220,62,58,151,140,62,44,211,171,62,174,20,215,62,168,103,176,62,76,233,199,62,62,21,208,62,214,133,166,62,94,182,193,62,158,18,202,62,56,159,182,62,86,249,199,62,186,33,222,62,164,233,134,62,136,95,202,62,182,162,216,62,130,207,172,62,20,254,200,62,102,7,227,62,16,9,161,62,82,14,195,62,10,105,216,62,226,161,192,62,46,168,213,62,46,231,220,62,220,17,134,62,46,191,188,62,62,251,206,62,154,14,182,62,126,136,193,62,62,175,202,62,232,205,167,62,208,46,181,62,234,115,210,62,250,213,185,62,240,134,204,62,70,82,212,62,26,107,158,62,50,98,191,62,94,12,201,62,248,122,169,62,222,53,205,62,142,15,221,62,94,171,165,62,180,187,188,62,174,188,213,62,80,191,178,62,200,138,218,62,178,72,227,62,158,88,148,62,170,62,186,62,154,46,210,62,28,232,181,62,110,86,199,62,106,173,211,62,94,82,172,62,20,111,184,62,254,45,217,62,168,11,174,62,112,134,209,62,234,95,225,62,56,14,154,62,110,215,204,62,74,254,213,62,166,84,162,62,38,54,216,62,234,107,226,62,176,152,167,62,128,196,196,62,202,78,220,62,138,72,204,62,56,231,219,62,46,15,227,62,185,22,127,62,190,193,166,62,12,206,210,62,162,29,177,62,50,182,188,62,248,229,198,62,84,94,160,62,124,175,173,62,60,115,198,62,198,241,179,62,96,38,204,62,172,71,211,62,242,67,150,62,6,100,192,62,88,250,201,62,8,33,166,62,246,212,201,62,20,89,209,62,162,27,160,62,28,39,183,62,212,255,211,62,212,166,187,62,212,251,208,62,76,8,217,62,26,149,153,62,10,251,169,62,12,211,208,62,80,123,171,62,138,180,197,62,32,181,210,62,86,105,171,62,16,126,187,62,204,100,201,62,32,25,178,62,152,213,207,62,116,107,220,62,108,104,146,62,146,98,202,62,152,13,213,62,242,209,165,62,182,29,208,62,28,141,226,62,176,40,162,62,216,214,196,62,124,250,224,62,26,7,198,62,172,218,210,62,188,12,219,62,64,201,115,62,240,132,185,62,20,163,220,62,230,97,177,62,40,23,194,62,168,41,208,62,84,22,162,62,14,131,182,62,32,221,202,62,6,171,187,62,118,120,199,62,152,148,215,62,94,216,157,62,56,30,190,62,0,212,208,62,60,65,172,62,148,116,200,62,116,144,216,62,234,100,165,62,254,201,194,62,144,176,209,62,44,255,186,62,18,23,219,62,128,43,227,62,146,72,139,62,76,209,192,62,20,12,222,62,248,31,183,62,248,105,193,62,232,127,209,62,138,73,172,62,130,122,186,62,240,137,209,62,220,55,178,62,214,211,213,62,120,215,221,62,164,2,155,62,52,189,202,62,48,16,222,62,122,209,169,62,252,205,213,62,212,90,223,62,172,164,170,62,26,248,194,62,248,21,225,62,158,182,198,62,194,181,223,62,24,211,230,62,236,21,131,62,12,47,178,62,80,137,216,62,74,9,177,62,144,113,195,62,152,40,203,62,40,184,166,62,146,102,179,62,52,80,198,62,106,183,182,62,254,17,204,62,176,170,216,62,82,58,154,62,172,24,198,62,0,130,206,62,0,7,168,62,196,222,205,62,48,186,214,62,30,247,160,62,82,243,188,62,112,102,222,62,224,160,190,62,186,198,210,62,172,139,225,62,194,185,148,62,8,61,178,62,12,57,218,62,72,90,176,62,216,236,195,62,28,171,213,62,170,115,171,62,246,161,192,62,96,23,207,62,44,210,183,62,182,55,207,62,36,163,222,62,220,233,142,62,144,124,210,62,148,231,222,62,130,61,178,62,156,38,204,62,172,211,228,62,4,111,167,62,38,188,199,62,124,39,226,62,150,30,200,62,218,241,214,62,112,204,222,62,54,185,130,62,218,165,189,62,212,71,221,62,242,148,181,62,138,211,198,62,68,80,206,62,212,169,164,62,176,127,181,62,28,74,219,62,110,21,192,62,248,51,204,62,16,15,212,62,98,184,159,62,154,105,200,62,20,58,211,62,240,95,175,62,102,240,202,62,76,112,221,62,138,224,170,62,112,186,192,62,160,80,215,62,196,1,181,62,44,196,219,62,180,93,235,62,22,119,147,62,54,137,193,62,200,54,222,62,36,28,182,62,154,245,194,62,136,166,216,62,186,79,176,62,4,143,190,62,208,206,220,62,12,59,181,62,168,13,212,62,52,201,226,62,216,10,156,62,126,53,211,62,64,77,222,62,214,252,171,62,246,99,217,62,184,139,228,62,116,254,175,62,20,0,197,62,228,219,222,62,230,102,210,62,148,158,225,62,104,123,231,62,51,179,11,62,18,179,44,62,202,153,81,62,195,44,62,62,14,63,106,62,165,0,129,62,178,105,251,61,220,105,62,62,163,19,143,62,7,47,73,62,129,106,135,62,155,33,148,62,96,171,0,62,88,36,26,62,201,98,141,62,71,3,73,62,52,128,119,62,249,146,147,62,55,118,15,62,206,179,99,62,25,161,140,62,120,24,133,62,145,0,141,62,61,56,159,62,75,65,34,62,0,30,65,62,186,80,84,62,159,79,72,62,80,177,98,62,171,244,146,62,163,125,45,62,18,116,78,62,131,36,141,62,191,125,89,62,221,75,135,62,163,204,162,62,51,91,59,62,50,86,76,62,59,12,107,62,147,93,92,62,135,90,134,62,5,155,144,62,19,235,21,62,104,167,114,62,173,131,148,62,13,58,123,62,193,81,155,62,185,60,175,62,73,199,12,62,64,19,34,62,92,245,116,62,213,216,78,62,148,98,97,62,13,2,138,62,128,97,242,61,58,187,107,62,25,46,145,62,133,238,102,62,65,103,139,62,153,181,156,62,213,234,10,62,178,59,68,62,159,37,136,62,65,110,72,62,14,126,109,62,231,245,160,62,237,7,44,62,216,43,105,62,27,204,141,62,91,22,128,62,221,110,154,62,39,101,164,62,53,178,8,62,110,13,78,62,232,129,111,62,145,101,83,62,222,110,116,62,93,28,142,62,145,88,55,62,168,121,72,62,57,178,143,62,109,36,83,62,69,50,135,62,225,139,170,62,197,99,51,62,28,193,67,62,83,220,131,62,85,225,105,62,12,47,123,62,187,50,158,62,81,51,57,62,202,108,121,62,7,224,151,62,236,99,141,62,189,211,157,62,187,146,177,62,17,104,12,62,16,97,56,62,160,65,98,62,21,185,57,62,108,54,104,62,233,112,138,62,159,64,0,62,226,234,55,62,169,233,158,62,13,73,67,62,231,81,147,62,245,127,160,62,37,158,5,62,38,73,36,62,139,185,153,62,229,13,74,62,11,68,131,62,47,148,142,62,69,103,34,62,28,20,115,62,47,156,134,62,12,14,134,62,243,48,142,62,239,170,169,62,193,25,40,62,62,77,62,62,72,69,113,62,137,131,86,62,134,196,98,62,49,149,149,62,173,207,42,62,232,196,90,62,9,150,138,62,173,89,107,62,215,165,147,62,69,203,156,62,165,134,58,62,104,164,77,62,246,238,117,62,233,87,102,62,13,37,138,62,139,50,149,62,9,224,39,62,183,44,128,62,91,126,142,62,218,113,131,62,215,23,151,62,91,227,180,62,135,149,15,62,158,237,52,62,34,178,124,62,83,117,92,62,154,183,106,62,47,80,135,62,62,208,247,61,232,146,95,62,235,9,165,62,42,44,130,62,235,71,140,62,183,175,151,62,19,60,36,62,88,44,60,62,181,45,144,62,19,87,64,62,82,30,115,62,153,216,168,62,39,14,54,62,246,36,104,62,5,202,154,62,252,218,140,62,219,99,150,62,117,239,159,62,255,50,46,62,124,173,61,62,51,8,124,62,175,19,99,62,142,171,117,62,127,227,146,62,7,196,71,62,134,86,85,62,147,162,147,62,199,60,115,62,99,205,140,62,111,248,173,62,227,227,64,62,218,70,81,62,169,198,131,62,37,47,125,62,13,103,133,62,197,177,154,62,107,243,42,62,152,214,124,62,33,70,163,62,144,101,142,62,255,66,160,62,113,12,187,62,219,178,20,62,246,246,38,62,126,79,102,62,15,161,82,62,166,33,98,62,86,113,129,62,187,16,248,61,76,22,73,62,175,169,153,62,139,189,92,62,61,4,136,62,31,49,153,62,194,129,223,61,100,193,54,62,25,159,147,62,139,100,80,62,196,29,118,62,233,181,151,62,183,198,28,62,70,211,102,62,9,215,145,62,153,30,128,62,137,51,142,62,133,81,166,62,227,76,42,62,100,213,70,62,242,182,88,62,211,30,78,62,216,124,103,62,103,36,150,62,115,27,25,62,178,87,91,62,167,90,145,62,3,41,99,62,221,9,146,62,223,225,163,62,123,31,66,62,22,137,83,62,62,220,107,62,47,204,108,62,252,201,124,62,197,102,148,62,171,116,14,62,139,180,132,62,5,150,152,62,129,97,122,62,77,186,144,62,217,246,184,62,132,241,250,61,36,143,44,62,177,176,138,62,29,71,81,62,140,237,107,62,113,40,139,62,65,17,18,62,74,190,99,62,133,136,149,62,149,119,120,62,57,11,142,62,37,34,152,62,161,178,27,62,174,165,73,62,135,163,133,62,161,26,95,62,148,189,123,62,87,196,157,62,1,172,66,62,64,165,108,62,131,115,143,62,120,53,130,62,161,145,150,62,127,230,173,62,153,117,32,62,146,154,85,62,168,123,105,62,169,125,102,62,230,1,128,62,169,112,141,62,13,127,54,62,88,252,74,62,245,191,155,62,165,146,85,62,217,180,149,62,13,142,177,62,73,40,47,62,64,82,80,62,81,121,134,62,85,205,107,62,187,131,132,62,179,188,159,62,21,200,61,62,144,168,123,62,239,0,159,62,14,46,148,62,237,71,159,62,83,101,177,62,189,240,25,62,36,143,43,62,126,242,117,62,125,74,56,62,84,220,114,62,165,148,133,62,133,118,25,62,178,163,74,62,61,167,157,62,221,219,87,62,87,140,147,62,161,212,168,62,73,223,6,62,98,227,41,62,227,82,165,62,237,252,91,62,231,113,129,62,23,88,152,62,177,43,60,62,100,57,115,62,175,153,140,62,192,218,130,62,95,6,141,62,199,41,177,62,205,11,59,62,26,66,76,62,165,60,93,62,25,67,86,62,150,190,99,62,237,209,154,62,161,129,60,62,80,102,88,62,213,168,144,62,141,245,118,62,27,21,152,62,9,200,161,62,41,135,73,62,68,230,88,62,125,114,119,62,153,150,120,62,117,101,132,62,227,30,150,62,29,184,34,62,45,184,135,62,83,107,148,62,132,32,132,62,71,71,163,62,251,24,178,62,55,86,24,62,194,219,42,62,155,157,136,62,247,31,93,62,242,116,107,62,83,85,141,62,123,187,13,62,184,6,117,62,255,235,167,62,155,157,121,62,71,170,147,62,107,178,156,62,171,61,46,62,196,139,66,62,245,251,143,62,55,96,96,62,69,25,132,62,113,52,167,62,135,198,68,62,30,251,100,62,253,236,152,62,38,14,140,62,179,200,159,62,61,90,169,62,215,89,38,62,104,217,81,62,123,181,129,62,83,58,101,62,12,96,115,62,75,61,155,62,55,156,70,62,126,110,89,62,103,121,157,62,59,110,107,62,139,92,152,62,179,204,172,62,35,225,65,62,54,12,81,62,241,165,142,62,109,30,120,62,9,220,139,62,21,119,161,62,219,186,30,62,53,129,147,62,185,7,172,62,134,36,140,62,19,149,169,62,185,158,185,62,245,11,28,62,18,195,48,62,228,40,67,62,75,183,73,62,190,189,103,62,50,27,124,62,158,229,246,61,152,82,83,62,107,249,143,62,195,91,70,62,139,54,139,62,79,72,154,62,99,251,11,62,152,202,29,62,43,132,144,62,203,8,74,62,61,223,129,62,45,164,148,62,43,232,18,62,210,185,121,62,193,18,141,62,34,87,132,62,87,235,139,62,185,105,164,62,167,28,30,62,208,113,70,62,188,16,93,62,71,236,82,62,224,168,101,62,131,75,146,62,99,185,50,62,102,124,85,62,183,48,143,62,203,24,96,62,83,131,139,62,19,121,167,62,83,223,53,62,26,26,90,62,200,219,116,62,231,169,106,62,101,177,132,62,213,40,145,62,47,33,33,62,106,184,117,62,97,200,155,62,49,130,123,62,211,54,162,62,209,145,175,62,85,98,18,62,132,202,37,62,79,230,129,62,201,60,87,62,48,50,100,62,29,206,138,62,97,227,1,62,250,232,93,62,173,112,152,62,77,139,108,62,119,106,143,62,65,115,153,62,233,166,28,62,30,167,70,62,251,184,139,62,41,248,89,62,170,87,119,62,191,14,162,62,45,67,47,62,24,207,99,62,47,107,150,62,154,4,129,62,79,199,155,62,55,156,169,62,173,98,8,62,74,234,84,62,210,190,130,62,77,34,89,62,144,0,120,62,49,235,147,62,13,11,61,62,152,248,77,62,225,157,146,62,141,134,95,62,127,178,141,62,253,108,176,62,185,247,59,62,24,68,76,62,99,57,134,62,197,185,110,62,85,150,127,62,39,182,161,62,225,116,66,62,196,204,124,62,191,33,152,62,190,207,140,62,115,29,165,62,15,167,177,62,125,184,17,62,80,80,69,62,246,87,93,62,85,95,72,62,100,154,99,62,221,156,141,62,117,112,8,62,238,137,74,62,225,82,165,62,73,77,61,62,77,30,152,62,65,247,166,62,253,206,25,62,38,6,53,62,59,68,149,62,25,5,80,62,105,236,132,62,251,42,153,62,241,117,41,62,240,15,116,62,103,50,147,62,218,201,138,62,45,63,148,62,67,152,163,62,13,165,44,62,238,152,75,62,62,224,107,62,113,241,90,62,94,25,112,62,169,248,148,62,197,203,50,62,92,120,94,62,181,69,146,62,209,252,105,62,65,166,151,62,213,16,162,62,45,170,63,62,48,215,97,62,246,112,117,62,197,96,106,62,95,244,134,62,219,71,154,62,165,42,54,62,207,41,132,62,39,31,144,62,248,222,132,62,229,73,157,62,19,149,178,62,183,181,20,62,82,1,55,62,40,180,132,62,223,81,96,62,222,240,115,62,55,91,133,62,55,25,19,62,136,203,86,62,127,180,161,62,181,16,128,62,253,240,142,62,23,61,156,62,231,143,24,62,100,14,78,62,145,169,144,62,155,99,85,62,38,66,113,62,137,211,176,62,79,74,62,62,6,237,98,62,185,29,159,62,190,210,143,62,209,71,151,62,221,167,166,62,87,30,49,62,216,206,73,62,73,179,123,62,123,195,96,62,58,164,122,62,35,81,150,62,203,82,60,62,22,42,92,62,115,197,153,62,13,58,123,62,81,133,137,62,91,88,178,62,159,150,69,62,134,149,83,62,81,224,136,62,30,123,130,62,123,139,137,62,161,106,155,62,251,24,53,62,7,199,132,62,17,229,161,62,170,244,148,62,225,154,161,62,85,201,188,62,71,227,32,62,218,183,49,62,232,57,106,62,7,156,89,62,130,8,108,62,183,34,129,62,63,241,17,62,212,211,78,62,179,5,150,62,231,19,92,62,139,94,142,62,175,219,160,62,195,53,11,62,184,102,57,62,29,11,141,62,191,45,75,62,86,121,119,62,177,63,156,62,131,88,35,62,86,35,109,62,77,64,151,62,68,51,132,62,75,31,147,62,45,5,164,62,111,9,51,62,48,131,69,62,236,81,88,62,67,5,79,62,108,121,104,62,195,25,156,62,211,153,45,62,250,232,88,62,247,62,152,62,247,141,107,62,15,64,149,62,187,54,167,62,43,186,71,62,74,202,88,62,178,43,105,62,27,163,115,62,25,60,129,62,249,114,152,62,7,116,29,62,100,117,124,62,101,41,161,62,213,189,113,62,99,109,155,62,125,194,189,62,249,252,13,62,20,251,43,62,49,10,140,62,1,240,90,62,188,184,104,62,205,146,146,62,35,21,0,62,238,244,121,62,173,231,154,62,61,95,113,62,155,250,143,62,161,40,158,62,253,84,27,62,86,240,87,62,127,18,135,62,41,7,98,62,27,108,129,62,251,0,162,62,233,92,61,62,196,43,117,62,91,251,145,62,140,227,132,62,103,159,158,62,3,33,167,62,81,215,38,62,178,45,97,62,242,208,113,62,157,208,111,62,104,241,127,62,233,26,142,62,153,248,46,62,244,12,75,62,49,144,164,62,221,31,109,62,199,206,140,62,173,74,189,62,141,82,56,62,112,169,83,62,95,219,138,62,1,202,115,62,27,13,130,62,187,204,165,62,133,237,75,62,49,48,130,62,251,109,157,62,216,41,147,62,79,108,166,62,59,128,178,62,153,197,20,62,168,243,67,62,26,175,127,62,197,84,71,62,216,153,118,62,157,250,141,62,157,211,28,62,106,10,71,62,177,180,167,62,225,251,80,62,137,225,152,62,9,153,164,62,1,193,31,62,102,91,57,62,183,19,154,62,137,6,88,62,83,244,130,62,119,189,157,62,13,229,61,62,114,255,126,62,163,77,140,62,104,138,140,62,189,49,148,62,135,118,173,62,65,48,53,62,246,36,71,62,57,104,99,62,17,146,93,62,0,70,108,62,41,125,155,62,97,60,66,62,8,208,91,62,29,175,147,62,113,155,118,62,9,166,152,62,37,158,167,62,121,161,78,62,88,181,96,62,65,18,117,62,181,200,126,62,147,31,136,62,55,54,150,62,129,101,58,62,223,91,137,62,11,134,150,62,202,83,131,62,1,213,163,62,255,174,185,62,71,156,34,62,226,164,51,62,83,231,136,62,59,164,101,62,42,89,114,62,183,38,142,62,199,200,24,62,252,5,104,62,87,197,176,62,244,85,128,62,189,163,149,62,207,140,160,62,255,227,33,62,188,11,79,62,189,240,152,62,7,80,106,62,209,133,126,62,253,127,176,62,191,123,64,62,98,186,111,62,197,196,155,62,166,65,146,62,181,55,161,62,73,130,172,62,151,149,38,62,56,12,95,62,193,206,131,62,79,109,101,62,93,169,124,62,235,1,154,62,227,47,78,62,138,134,95,62,75,70,160,62,191,189,115,62,5,161,152,62,115,254,180,62,23,154,75,62,118,252,89,62,37,196,139,62,206,80,128,62,187,10,137,62,61,39,164,62,227,0,47,62,171,229,137,62,45,58,171,62,128,39,156,62,249,33,172,62,33,0,187,62,193,42,23,62,148,159,57,62,244,158,81,62,193,102,70,62,0,71,98,62,101,7,134,62,141,66,7,62,46,135,71,62,39,45,145,62,165,185,84,62,171,139,138,62,187,163,149,62,141,204,2,62,202,230,42,62,53,90,145,62,161,60,82,62,66,193,125,62,81,56,145,62,185,233,29,62,24,106,102,62,49,72,138,62,122,255,136,62,103,160,145,62,33,97,158,62,53,230,44,62,30,126,63,62,164,74,79,62,185,76,79,62,70,239,93,62,123,14,150,62,85,140,39,62,144,202,92,62,59,202,144,62,233,235,102,62,63,86,136,62,7,194,162,62,33,166,65,62,72,139,82,62,190,113,99,62,201,140,98,62,149,68,133,62,241,199,149,62,1,76,31,62,118,198,124,62,217,76,148,62,47,94,126,62,55,79,156,62,17,236,181,62,79,44,2,62,214,216,33,62,213,33,130,62,55,235,81,62,138,190,96,62,217,130,142,62,103,128,8,62,240,31,107,62,189,234,146,62,175,117,114,62,147,44,137,62,113,208,157,62,235,59,16,62,240,75,80,62,91,232,139,62,47,171,84,62,4,38,112,62,199,47,166,62,27,111,53,62,14,27,107,62,11,44,145,62,98,211,133,62,171,49,154,62,203,182,164,62,123,41,24,62,48,194,84,62,114,223,124,62,151,122,91,62,200,3,126,62,141,101,139,62,7,157,52,62,154,159,73,62,161,166,149,62,59,243,74,62,39,12,141,62,13,181,178,62,127,97,52,62,14,227,69,62,67,2,138,62,231,167,114,62,160,8,128,62,159,23,157,62,67,73,52,62,56,17,130,62,27,109,155,62,52,223,144,62,243,128,154,62,195,57,181,62,155,215,20,62,78,22,60,62,82,98,112,62,175,126,70,62,186,43,108,62,105,31,137,62,67,75,14,62,56,62,63,62,97,80,160,62,63,190,76,62,213,36,142,62,121,108,166,62,179,101,18,62,28,108,47,62,147,36,155,62,59,186,84,62,63,115,132,62,67,217,147,62,75,230,47,62,18,3,118,62,243,235,139,62,160,198,138,62,237,1,146,62,31,161,167,62,95,238,45,62,0,12,64,62,82,223,101,62,39,99,92,62,192,203,104,62,101,11,151,62,155,207,51,62,194,42,95,62,5,189,140,62,35,76,112,62,101,61,148,62,141,11,162,62,119,129,66,62,106,223,81,62,209,225,124,62,51,254,114,62,207,96,137,62,147,212,148,62,211,10,46,62,98,185,129,62,227,198,149,62,238,147,138,62,137,35,152,62,191,93,182,62,93,51,28,62,232,56,46,62,105,98,129,62,201,96,96,62,244,143,113,62,63,27,138,62,217,168,17,62,202,107,95,62,51,12,168,62,196,223,133,62,97,89,142,62,3,209,154,62,237,53,29,62,34,78,67,62,157,236,149,62,69,67,86,62,217,205,127,62,69,64,166,62,113,97,51,62,208,95,116,62,129,223,156,62,88,227,139,62,253,159,155,62,101,26,164,62,113,216,39,62,138,41,66,62,39,54,131,62,145,102,104,62,20,226,117,62,131,224,149,62,97,66,72,62,12,11,89,62,127,65,152,62,165,212,118,62,225,181,147,62,95,54,172,62,137,160,71,62,176,128,86,62,5,59,131,62,120,213,125,62,167,214,134,62,229,94,159,62,17,64,45,62,124,134,113,62,225,40,172,62,204,110,146,62,241,157,166,62,117,30,184,62,65,2,32,62,36,242,52,62,244,137,91,62,69,3,86,62,12,88,101,62,243,146,133,62,21,6,11,62,74,119,80,62,235,106,156,62,105,55,96,62,215,21,143,62,159,81,153,62,69,72,9,62,178,156,54,62,29,145,148,62,229,106,90,62,210,202,117,62,241,198,153,62,129,81,40,62,140,223,103,62,25,8,147,62,241,96,128,62,167,198,143,62,233,178,171,62,189,147,39,62,174,214,73,62,32,121,98,62,141,34,85,62,34,105,108,62,71,159,151,62,141,238,34,62,252,108,95,62,247,79,151,62,5,164,117,62,47,76,144,62,115,239,166,62,177,240,65,62,72,31,85,62,76,43,116,62,109,150,110,62,191,234,132,62,49,60,150,62,137,105,36,62,247,164,130,62,41,18,155,62,248,203,129,62,11,145,151,62,1,70,188,62,83,63,5,62,254,8,51,62,109,94,133,62,183,63,87,62,46,45,111,62,125,237,144,62,179,5,28,62,52,191,102,62,81,129,155,62,255,84,118,62,35,236,141,62,221,157,156,62,135,168,39,62,64,116,71,62,155,219,137,62,95,32,103,62,50,175,118,62,215,216,162,62,23,170,68,62,218,95,107,62,43,100,148,62,112,136,134,62,47,204,155,62,83,222,171,62,143,14,42,62,104,200,83,62,47,119,117,62,31,74,101,62,2,14,128,62,89,18,146,62,139,236,64,62,78,175,80,62,53,40,155,62,91,60,108,62,115,247,146,62,89,25,179,62,219,100,58,62,22,54,91,62,139,229,134,62,47,254,114,62,105,177,135,62,183,184,162,62,71,210,65,62,185,129,132,62,107,23,156,62,62,48,152,62,227,97,162,62,43,146,182,62,255,105,34,62,150,242,54,62,182,185,119,62,143,144,71,62,30,127,119,62,5,60,134,62,95,235,33,62,204,213,88,62,141,105,159,62,191,27,94,62,229,251,152,62,85,89,164,62,247,218,24,62,204,41,51,62,131,115,161,62,243,240,98,62,231,41,131,62,43,153,155,62,255,51,52,62,126,89,121,62,155,84,146,62,100,120,135,62,129,50,146,62,247,177,176,62,219,117,56,62,192,52,82,62,19,151,99,62,247,218,87,62,60,191,103,62,145,252,160,62,103,115,55,62,94,119,86,62,233,40,150,62,88,182,127,62,185,31,149,62,209,129,167,62,19,120,75,62,10,20,93,62,146,245,127,62,251,128,118,62,111,155,135,62,91,106,153,62,23,92,47,62,19,77,137,62,227,109,155,62,48,3,138,62,241,215,161,62,111,144,182,62,165,45,26,62,136,156,60,62,191,143,137,62,213,37,94,62,240,151,118,62,131,209,142,62,41,166,10,62,153,107,133,62,47,75,170,62,56,38,131,62,133,93,147,62,135,192,156,62,117,100,42,62,74,64,65,62,53,7,150,62,25,183,106,62,231,235,133,62,77,173,167,62,105,6,75,62,210,143,110,62,33,40,153,62,186,247,146,62,181,60,157,62,157,147,167,62,201,30,52,62,242,251,88,62,181,174,128,62,21,163,109,62,62,126,122,62,175,80,153,62,217,91,67,62,32,46,89,62,43,110,166,62,133,22,109,62,97,218,160,62,19,123,175,62,65,200,71,62,104,149,86,62,117,24,143,62,161,47,118,62,163,9,138,62,165,241,167,62,145,236,47,62,219,128,144,62,209,38,161,62,82,218,137,62,245,74,173,62,237,134,194,62,231,197,35,62,236,60,54,62,102,163,77,62,197,211,78,62,96,52,108,62,203,119,131,62,169,61,9,62,82,6,88,62,151,194,145,62,29,154,80,62,85,236,144,62,95,75,155,62,97,255,19,62,122,174,40,62,237,245,145,62,137,60,83,62,218,157,126,62,133,191,151,62,249,238,33,62,252,240,111,62,73,46,143,62,130,173,135,62,37,79,143,62,21,34,163,62,205,136,42,62,190,179,60,62,86,178,91,62,213,236,79,62,206,192,112,62,211,215,147,62,1,119,44,62,68,215,80,62,111,48,147,62,217,73,109,62,13,85,140,62,79,70,166,62,5,206,61,62,120,64,91,62,242,134,106,62,89,77,120,62,163,116,133,62,89,233,144,62,113,149,43,62,14,214,119,62,21,83,153,62,149,138,116,62,121,84,163,62,73,130,183,62,211,55,13,62,178,128,30,62,49,254,135,62,111,21,88,62,118,255,101,62,57,86,143,62,31,223,12,62,24,136,102,62,65,94,158,62,219,189,106,62,169,99,141,62,97,103,161,62,211,86,36,62,252,38,72,62,151,251,144,62,243,191,95,62,248,233,115,62,87,34,169,62,239,91,58,62,158,158,110,62,71,40,150,62,174,84,130,62,69,248,160,62,155,59,172,62,215,141,19,62,92,20,104,62,255,77,128,62,63,90,92,62,195,185,128,62,73,241,145,62,183,45,64,62,170,93,81,62,81,157,150,62,215,6,108,62,153,114,137,62,217,105,180,62,111,118,61,62,98,218,75,62,123,58,139,62,27,100,120,62,94,194,130,62,187,111,159,62,159,217,71,62,156,20,127,62,83,22,153,62,30,59,145,62,73,19,161,62,191,19,182,62,51,32,27,62,174,121,74,62,244,11,110,62,163,212,76,62,170,159,107,62,165,89,144,62,87,10,14,62,148,107,68,62,33,10,177,62,95,76,73,62,147,3,156,62,5,93,174,62,79,120,13,62,116,17,65,62,251,82,153,62,59,154,82,62,231,173,137,62,95,111,156,62,43,150,48,62,238,41,111,62,11,86,150,62,128,80,138,62,71,233,152,62,139,56,168,62,127,179,51,62,72,244,67,62,72,61,113,62,139,215,97,62,152,104,112,62,93,62,151,62,167,27,62,62,126,175,99,62,241,76,143,62,195,246,106,62,127,237,155,62,5,61,166,62,235,98,63,62,2,164,92,62,96,243,128,62,99,140,112,62,1,221,138,62,203,139,153,62,251,149,61,62,189,27,131,62,71,42,150,62,196,27,135,62,207,63,157,62,183,159,185,62,145,220,36,62,124,59,55,62,79,249,130,62,81,22,103,62,176,149,121,62,55,137,137,62,73,204,30,62,250,236,107,62,215,90,164,62,192,230,128,62,187,46,143,62,27,223,160,62,173,193,32,62,54,114,84,62,57,114,148,62,241,178,94,62,193,237,132,62,221,106,174,62,21,14,53,62,24,162,108,62,141,151,162,62,42,223,144,62,51,133,153,62,13,116,172,62,5,110,58,62,30,129,75,62,144,3,129,62,145,75,103,62,163,67,129,62,207,50,150,62,129,158,77,62,132,3,95,62,71,187,154,62,167,92,125,62,79,226,146,62,139,21,178,62,137,244,77,62,156,230,91,62,53,72,134,62,124,7,130,62,5,249,137,62,1,208,159,62,165,158,67,62,29,240,130,62,65,69,170,62,254,4,149,62,235,180,169,62,161,183,188,62,225,0,33,62,184,210,61,62,30,197,102,62,105,11,85,62,64,18,116,62,235,70,135,62,105,95,22,62,178,28,90,62,215,178,153,62,177,224,95,62,117,157,148,62,63,59,158,62,225,37,19,62,158,82,64,62,73,74,145,62,205,77,84,62,136,248,122,62,137,47,158,62,105,43,40,62,100,75,105,62,45,41,158,62,88,26,134,62,177,41,149,62,9,190,169,62,149,190,46,62,98,2,79,62,66,14,95,62,129,200,84,62,118,86,112,62,195,18,157,62,233,63,48,62,220,49,91,62,55,204,158,62,109,157,106,62,169,216,143,62,119,228,170,62,85,87,73,62,76,218,93,62,225,224,110,62,5,127,115,62,227,151,132,62,189,245,155,62,9,232,30,62,53,172,134,62,129,76,163,62,201,95,127,62,1,74,162,62,21,106,193,62,15,255,26,62,254,53,51,62,61,118,142,62,239,21,97,62,214,239,109,62,25,240,145,62,195,13,18,62,152,96,118,62,73,182,155,62,91,151,120,62,69,73,145,62,193,134,161,62,39,63,33,62,48,129,84,62,67,37,141,62,179,63,106,62,7,18,127,62,227,1,168,62,35,116,67,62,24,215,115,62,107,252,150,62,44,100,136,62,189,238,160,62,23,102,173,62,91,189,46,62,80,103,103,62,48,79,125,62,15,30,114,62,171,137,129,62,161,145,147,62,187,223,61,62,98,206,81,62,105,20,161,62,155,152,94,62,185,207,150,62,89,84,188,62,235,22,65,62,166,86,92,62,159,198,139,62,13,252,122,62,159,0,133,62,47,206,164,62,243,52,75,62,219,182,133,62,167,90,162,62,88,24,153,62,37,110,168,62,235,158,182,62,247,11,34,62,146,209,68,62,234,246,123,62,27,62,79,62,194,234,125,62,197,34,139,62,131,151,37,62,76,214,90,62,249,158,167,62,215,144,91,62,95,113,156,62,141,221,170,62,35,180,37,62,112,116,66,62,15,250,158,62,235,179,96,62,245,177,135,62,27,91,158,62,191,210,64,62,214,159,127,62,255,44,146,62,4,229,137,62,79,128,153,62,63,246,174,62,51,139,48,62,108,10,88,62,98,61,105,62,123,145,97,62,212,161,111,62,93,45,160,62,203,167,59,62,54,100,99,62,209,4,149,62,27,90,120,62,103,122,158,62,213,40,169,62,31,135,84,62,246,13,102,62,70,73,122,62,65,194,123,62,237,98,138,62,71,58,156,62,215,70,61,62,69,80,139,62,19,4,160,62,214,106,140,62,51,123,164,62,51,211,191,62,137,107,42,62,96,235,60,62,191,91,137,62,229,231,105,62,168,219,120,62,119,247,143,62,249,238,35,62,25,131,129,62,231,240,171,62,72,51,134,62,131,86,151,62,243,111,160,62,69,186,43,62,178,95,78,62,189,133,154,62,221,135,115,62,237,16,133,62,161,44,173,62,109,240,73,62,248,97,123,62,49,195,162,62,34,207,152,62,119,111,163,62,217,147,174,62,213,77,47,62,50,182,101,62,89,133,134,62,117,41,108,62,225,177,129,62,199,55,154,62,209,186,81,62,236,52,99,62,23,229,166,62,215,86,100,62,123,216,156,62,51,145,179,62,9,173,77,62,80,135,92,62,65,123,145,62,188,124,128,62,245,73,136,62,61,174,170,62,45,211,51,62,209,107,150,62,85,63,174,62,156,95,149,62,115,99,174,62,125,70,195,62,109,203,85,61,179,182,171,61,130,212,216,61,103,200,3,62,237,151,96,61,26,14,9,62,153,48,241,61,181,177,70,62,191,148,91,61,5,37,228,61,40,189,245,61,155,3,23,62,160,234,163,61,133,110,18,62,81,6,40,62,137,219,86,62,5,109,85,61,175,210,203,61,140,173,177,61,1,110,62,62,16,51,159,61,187,169,6,62,11,102,36,62,239,75,58,62,242,2,152,61,217,44,226,61,244,246,242,61,157,131,51,62,174,124,135,61,119,99,40,62,201,136,73,62,227,225,93,62,45,240,119,61,163,158,193,61,208,164,217,61,247,144,23,62,110,162,112,61,29,69,23,62,84,13,10,62,185,90,78,62,49,27,135,61,249,123,238,61,233,120,7,62,23,242,28,62,182,199,189,61,53,63,22,62,161,150,55,62,153,250,96,62,197,174,144,61,215,200,204,61,238,28,218,61,5,192,55,62,2,18,180,61,107,75,0,62,219,83,29,62,231,153,74,62,83,243,181,61,101,84,230,61,121,216,23,62,149,137,43,62,176,59,167,61,43,86,45,62,73,204,84,62,15,148,108,62,223,223,123,61,71,68,171,61,244,112,234,61,13,16,12,62,101,185,140,61,215,105,13,62,207,83,226,61,119,133,92,62,93,152,99,61,109,90,250,61,230,230,246,61,45,240,36,62,218,113,170,61,247,52,31,62,143,132,37,62,79,191,105,62,179,217,128,61,227,142,217,61,70,209,169,61,179,188,83,62,190,50,181,61,37,15,11,62,197,216,45,62,173,108,70,62,203,48,159,61,39,89,246,61,152,200,5,62,123,193,60,62,144,181,141,61,165,163,60,62,59,204,80,62,85,181,127,62,97,238,144,61,247,248,184,61,86,38,222,61,141,218,37,62,126,209,146,61,43,184,26,62,57,28,14,62,147,13,96,62,255,108,138,61,54,200,1,62,63,157,8,62,25,228,44,62,52,251,196,61,199,137,34,62,23,246,62,62,7,61,114,62,88,164,168,61,115,39,209,61,76,125,205,61,183,152,71,62,36,250,203,61,5,179,11,62,197,211,58,62,253,138,80,62,17,122,200,61,30,27,248,61,171,241,20,62,211,2,60,62,134,71,196,61,217,83,48,62,171,167,100,62,41,85,124,62,245,173,104,60,236,211,158,60,30,239,238,60,109,122,133,61,178,82,169,60,119,205,75,61,95,173,33,61,30,194,195,61,246,247,185,60,59,117,34,61,45,176,92,61,133,175,128,61,158,255,237,60,26,225,106,61,161,157,55,61,74,68,236,61,244,3,159,60,5,22,14,61,131,51,51,61,107,73,138,61,153,156,17,61,193,96,74,61,66,51,143,61,112,158,177,61,177,163,227,60,69,197,62,61,49,52,109,61,116,37,138,61,43,108,66,61,38,100,97,61,6,145,161,61,107,195,250,61,49,161,181,60,220,233,247,60,212,232,10,61,92,252,146,61,148,63,2,61,137,99,76,61,75,126,122,61,72,221,178,61,46,36,219,60,197,128,34,61,93,231,53,61,136,80,169,61,179,103,31,61,69,191,103,61,241,185,119,61,120,23,214,61,60,126,220,60,223,75,18,61,195,100,40,61,62,47,150,61,157,6,41,61,67,185,70,61,122,14,147,61,158,128,217,61,215,117,10,61,31,203,45,61,164,104,114,61,74,82,163,61,99,142,64,61,216,186,128,61,142,236,192,61,168,44,5,62,250,31,159,60,30,108,223,60,133,228,23,61,208,43,136,61,218,124,229,60,241,88,83,61,77,234,90,61,12,160,189,61,210,220,208,60,17,75,49,61,203,10,98,61,40,197,150,61,249,51,11,61,92,241,119,61,24,53,125,61,172,207,9,62,104,15,193,60,211,129,17,61,181,57,81,61,166,44,139,61,55,17,29,61,191,105,86,61,124,109,152,61,230,219,197,61,180,126,2,61,31,73,61,61,102,129,125,61,118,42,150,61,137,237,52,61,208,65,109,61,76,135,162,61,205,144,16,62,30,174,202,60,0,143,4,61,73,219,9,61,222,202,164,61,247,107,10,61,255,56,95,61,8,222,133,61,230,32,195,61,236,82,240,60,39,122,47,61,59,55,88,61,66,38,167,61,13,35,36,61,43,49,125,61,238,105,138,61,127,4,240,61,84,69,248,60,225,122,30,61,93,225,69,61,64,10,152,61,67,56,51,61,253,39,86,61,4,117,170,61,204,9,225,61,149,216,25,61,69,163,57,61,241,48,135,61,44,88,163,61,249,30,78,61,121,188,113,61,12,163,179,61,156,26,39,62,0,0,0,0,88,40,20,0,0,0,0,0,240,42,20,0,8,71,20,0,0,0,0,0,0,0,0,0,96,40,20,0,0,0,0,0,248,42,20,0,16,71,20,0,0,0,0,0,211,217,201,188,96,60,131,187,174,182,226,189,36,151,95,63,18,131,128,63,63,53,126,63,153,42,216,62,112,95,199,62,18,131,0,63,154,153,185,63,231,251,169,63,129,149,163,63,149,101,72,62,9,27,94,62,49,8,140,62,14,45,146,63,82,184,158,63,147,24,148,63,236,192,73,63,77,132,45,63,162,69,214,62,18,131,192,63,109,231,187,63,29,90,196,63,37,117,162,62,177,225,137,62,173,23,195,189,74,12,146,63,70,182,147,63,203,161,133,63,97,195,3,63,6,18,20,63,202,84,97,63,137,65,192,63,147,24,180,63,29,90,180,63,19,242,161,62,16,233,183,62,96,229,144,62,168,198,155,63,150,67,155,63,227,165,155,63,170,241,130,63,193,202,145,63,173,23,195,189,100,59,207,63,10,215,211,63,14,45,210,63,24,38,19,62,172,28,26,62,208,10,140,61,245,185,122,63,33,176,130,63,219,249,142,63,242,176,240,62,111,129,36,63,82,73,13,63,23,217,174,63,229,208,178,63,207,247,179,63,207,102,149,62,245,185,154,62,217,206,119,62,80,141,167,63,23,217,158,63,246,40,156,63,182,132,76,63,65,241,67,63,168,53,61,63,4,86,206,63,137,65,192,63,76,55,185,63,20,208,132,62,167,121,71,62,229,208,130,62,227,165,139,63,51,51,147,63,229,208,162,63,242,65,175,62,225,122,212,62,203,161,165,63,223,79,221,63,137,65,176,63,236,81,136,63,215,18,210,62,94,75,168,62,11,70,165,62,152,110,146,63,207,247,163,63,125,63,181,63,25,4,134,63,219,249,142,63,173,105,30,63,244,253,244,63,188,116,227,63,74,12,194,63,181,108,173,188,228,20,93,62,14,190,112,62,109,231,139,63,150,67,139,63,248,83,131,63,228,131,14,63,238,90,2,63,233,72,238,62,174,71,193,63,213,120,185,63,94,186,153,63,106,222,113,62,68,105,175,62,65,130,130,62,31,133,171,63,205,204,156,63,219,249,142,63,231,251,153,63,102,136,195,62,121,88,104,62,119,190,175,63,70,182,179,63,113,61,234,63,129,149,131,62,2,154,136,62,194,134,39,62,49,8,156,63,68,139,140,63,178,157,143,63,229,208,50,63,62,121,88,63,254,212,136,63,102,102,198,63,197,32,192,63,252,169,177,63,170,241,146,62,8,172,156,62,208,68,184,62,180,200,150,63,246,40,172,63,240,167,166,63,92,143,162,63,31,133,155,63,126,140,57,62,205,204,220,63,188,116,227,63,57,180,216,63,170,96,84,62,25,115,87,62,246,151,29,62,164,112,141,63,29,90,132,63,223,79,141,63,181,21,43,63,58,35,42,63,90,245,41,63,129,149,179,63,209,34,187,63,20,174,183,63,77,132,173,62,110,52,192,62,246,40,92,62,47,221,164,63,154,153,169,63,96,229,160,63,79,175,100,63,220,70,83,63,110,52,80,63,61,10,199,63,172,28,202,63,236,81,200,63,231,29,167,62,217,61,121,62,188,5,146,62,219,249,158,63,61,10,151,63,35,219,153,63,185,141,6,62,13,224,45,62,33,176,210,63,25,4,230,63,127,106,204,63,23,217,158,63,23,183,241,62,140,219,8,63,173,250,156,62,111,18,163,63,248,83,179,63,145,237,172,63,113,61,186,63,115,104,177,63,166,155,36,63,231,251,233,63,219,249,238,63,154,153,233,63,2,43,167,190,226,88,151,190,218,27,124,190,225,122,132,63,92,143,130,63,78,98,128,63,219,138], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1328226);
/* memory initializer */ allocate([189,62,182,132,220,62,15,11,53,63,162,69,182,63,246,40,172,63,86,14,173,63,11,36,104,62,76,55,137,62,145,126,155,62,123,20,158,63,59,223,159,63,33,176,146,63,0,145,126,63,25,4,38,63,75,89,6,63,244,253,196,63,219,249,190,63,4,86,206,63,248,83,195,62,49,8,172,62,173,23,195,189,47,221,148,63,152,110,146,63,219,249,142,63,241,99,44,63,93,254,67,63,193,202,129,63,57,180,200,63,98,16,184,63,113,61,186,63,114,138,174,62,149,212,169,62,93,109,197,62,61,10,151,63,29,90,164,63,29,90,164,63,100,59,159,63,90,100,155,63,173,23,195,189,78,98,224,63,68,139,204,63,100,59,223,63,228,131,30,62,150,33,14,62,23,217,78,62,188,116,131,63,37,6,145,63,109,231,139,63,185,252,199,62,197,32,64,63,74,12,18,63,143,194,181,63,45,178,173,63,6,129,197,63,157,128,166,62,46,144,160,62,151,144,143,62,145,237,172,63,80,141,167,63,8,172,156,63,41,203,96,63,100,59,79,63,139,253,53,63,141,151,206,63,113,61,202,63,139,108,183,63,102,247,164,62,177,80,107,62,118,224,92,62,227,165,155,63,35,219,137,63,178,157,159,63,201,118,174,63,10,215,163,63,117,147,168,63,197,32,224,63,250,126,186,63,199,75,151,63,174,182,226,62,151,255,208,62,1,222,162,62,147,24,148,63,86,14,157,63,223,79,205,63,166,155,164,63,211,77,162,63,64,19,81,63,100,59,255,63,233,38,1,64,199,75,167,63,238,206,218,60,20,208,132,62,41,237,173,62,244,253,148,63,113,61,138,63,27,158,110,63,126,140,25,63,172,139,27,63,215,18,2,63,117,147,184,63,117,147,184,63,0,0,176,63,106,188,116,62,253,246,181,62,68,105,175,62,106,188,164,63,199,75,167,63,152,110,146,63,154,153,153,63,59,223,63,63,67,28,203,62,217,206,199,63,14,45,194,63,170,241,242,63,181,55,184,62,60,78,177,62,143,194,245,61,221,36,166,63,0,0,144,63,158,239,135,63,161,248,65,63,252,169,129,63,254,212,152,63,106,188,196,63,252,169,193,63,90,100,187,63,50,230,206,62,224,190,206,62,194,134,199,62,6,129,165,63,49,8,156,63,78,98,176,63,0,0,160,63,74,12,178,63,127,251,122,62,139,108,199,63,193,202,225,63,27,47,221,63,113,61,138,62,19,242,65,62,129,4,69,62,63,53,142,63,4,86,142,63,221,36,150,63,188,5,66,63,34,142,85,63,134,201,244,62,90,100,187,63,86,14,189,63,49,8,188,63,232,217,204,62,192,236,158,62,83,5,99,62,186,73,172,63,84,227,181,63,158,239,167,63,135,22,137,63,34,142,101,63,23,72,64,63,23,217,206,63,43,135,198,63,213,120,201,63,222,113,170,62,141,151,142,62,156,196,160,62,207,247,163,63,131,192,154,63,141,151,158,63,178,157,143,62,12,147,137,62,33,176,210,63,39,49,232,63,193,202,193,63,174,71,193,63,123,131,31,63,61,10,215,62,191,125,189,62,215,163,160,63,121,233,182,63,172,28,186,63,14,45,210,63,53,94,202,63,52,17,54,63,49,8,236,63,150,67,251,63,92,143,242,63,20,92,44,189,172,173,24,190,92,114,156,189,84,227,133,63,116,181,117,63,213,231,106,63,11,70,229,62,168,198,235,62,115,215,2,63,33,176,194,63,66,96,165,63,168,198,171,63,248,83,99,62,65,130,130,62,18,131,128,62,217,206,151,63,18,131,160,63,84,227,149,63,217,95,102,63,182,243,253,62,228,20,253,62,221,36,182,63,182,243,189,63,41,92,207,63,187,39,143,62,205,59,142,62,78,98,144,190,143,194,149,63,2,43,151,63,94,186,137,63,23,72,208,62,76,166,90,63,68,105,111,63,131,192,202,63,125,63,181,63,55,137,177,63,113,61,170,62,209,34,187,62,12,2,171,62,8,172,156,63,96,229,160,63,41,92,159,63,217,206,135,63,252,169,145,63,173,23,195,189,2,43,215,63,172,28,218,63,221,36,214,63,57,214,69,62,62,121,24,62,183,209,0,62,170,241,130,63,150,67,139,63,92,143,146,63,47,221,4,63,229,242,47,63,56,103,4,63,215,163,176,63,10,215,179,63,8,172,188,63,187,184,173,62,82,184,158,62,84,116,100,62,223,79,173,63,59,223,159,63,92,143,162,63,40,126,60,63,7,206,89,63,138,31,83,63,4,86,206,63,106,188,196,63,233,38,193,63,116,36,151,62,42,58,82,62,166,155,132,62,252,169,145,63,49,8,156,63,55,137,161,63,246,40,172,63,244,253,164,63,150,67,171,63,158,239,183,63,123,20,174,63,117,147,184,63,89,23,247,62,140,219,168,62,221,181,196,62,49,8,156,63,217,206,167,63,47,221,180,63,209,34,155,63,217,206,151,63,60,189,34,63,119,190,239,63,39,49,248,63,162,69,214,63,174,71,161,63,2,43,167,63,160,26,175,63,33,176,146,63,35,219,137,63,51,51,131,63,168,87,26,63,151,255,0,63,93,254,19,63,193,202,193,63,143,194,181,63,213,120,169,63,75,200,135,62,47,110,163,62,26,192,155,62,160,26,175,63,16,88,153,63,154,153,153,63,182,243,157,63,90,100,251,62,172,226,13,61,127,106,172,63,20,174,199,63,63,53,238,63,132,158,141,62,125,208,147,62,5,197,79,62,96,229,160,63,164,112,141,63,92,143,146,63,145,237,172,63,27,47,173,63,207,247,179,63,156,196,192,63,113,61,202,63,4,86,174,63,132,13,143,62,166,10,198,62,127,251,218,62,182,243,157,63,131,192,170,63,12,2,171,63,10,215,163,63,137,65,160,63,254,212,56,62,55,137,177,63,33,176,178,63,80,141,183,63,24,149,148,62,178,157,239,61,13,224,45,62,233,38,145,63,35,219,137,63,219,249,142,63,115,215,50,63,48,187,55,63,209,145,60,63,41,92,175,63,23,217,190,63,41,92,191,63,32,99,206,62,184,175,3,63,106,77,51,62,190,159,170,63,137,65,176,63,96,229,160,63,195,211,107,63,221,181,100,63,97,195,99,63,90,100,203,63,141,151,206,63,170,241,194,63,229,97,161,62,246,151,93,62,66,96,165,62,102,102,166,63,92,143,146,63,209,34,155,63,152,110,162,63,41,92,159,63,178,157,191,63,252,169,225,63,227,165,219,63,217,206,167,63,14,190,240,62,159,205,10,63,154,119,220,62,168,198,171,63,139,108,183,63,221,36,182,63,127,106,188,63,70,182,179,63,48,76,86,63,217,206,247,63,37,6,241,63,150,67,235,63,74,12,162,63,143,194,165,63,240,167,166,63,213,120,137,63,137,65,128,63,170,241,130,63,11,70,5,63,160,26,207,62,135,167,39,63,250,126,186,63,78,98,176,63,201,118,174,63,12,2,139,62,212,154,134,62,142,117,145,62,193,202,161,63,33,176,162,63,102,102,150,63,209,34,171,63,61,10,167,63,2,43,167,63,61,10,199,63,135,22,201,63,147,24,212,63,40,15,171,62,143,83,212,62,17,199,186,190,98,16,152,63,20,174,151,63,166,155,148,63,54,171,30,63,89,134,56,63,147,24,148,63,250,126,202,63,31,133,187,63,252,169,193,63,138,142,196,62,99,238,186,62,220,70,195,62,90,100,155,63,156,196,160,63,66,96,165,63,63,53,174,63,201,118,174,63,158,239,167,63,6,129,229,63,57,180,216,63,203,161,213,63,0,111,65,62,92,143,2,62,165,189,129,62,176,114,136,63,162,69,150,63,37,6,145,63,229,242,255,62,101,25,82,63,20,208,20,63,27,47,189,63,125,63,181,63,178,157,191,63,220,70,195,62,101,170,160,62,179,234,147,62,33,176,178,63,133,235,161,63,242,210,157,63,243,31,114,63,136,133,106,63,102,102,22,63,25,4,214,63,96,229,208,63,180,200,198,63,188,116,179,62,174,71,129,62,215,18,114,62,12,2,155,63,252,169,145,63,123,20,158,63,74,12,178,63,104,145,157,63,164,112,173,63,88,57,228,63,174,71,193,63,213,120,153,63,34,108,216,62,140,219,232,62,136,244,187,62,207,247,163,63,18,131,160,63,166,155,212,63,150,67,171,63,18,131,176,63,93,254,115,63,213,120,9,64,31,133,251,63,131,192,202,63,157,244,190,61,61,10,183,62,143,83,180,62,209,34,155,63,12,2,139,63,203,161,133,63,118,224,28,63,228,20,29,63,209,34,27,63,182,243,189,63,96,229,192,63,33,176,178,63,78,98,144,62,129,4,197,62,83,150,161,62,160,26,175,63,106,188,164,63,78,98,144,63,100,59,175,63,86,14,173,63,242,210,173,63,156,196,176,63,133,235,225,63,100,59,7,64,39,49,168,63,246,40,172,63,131,192,170,63,184,30,165,63,25,4,150,63,100,59,143,63,121,233,166,63,137,65,176,63,240,167,182,63,82,184,190,63,184,30,197,63,166,155,196,63,40,126,204,62,229,97,225,62,88,168,213,62,16,88,169,63,199,75,167,63,14,45,178,63,51,51,179,63,252,169,177,63,100,59,175,63,203,161,213,63,57,180,232,63,131,192,234,63,241,99,140,62,47,221,100,62,204,93,75,62,55,137,145,63,193,202,145,63,94,186,153,63,213,120,169,63,174,71,177,63,8,172,172,63,113,61,186,63,213,120,201,63,172,28,186,63,133,124,0,63,240,167,166,62,229,208,130,62,252,169,177,63,98,16,184,63,102,102,166,63,152,110,178,63,8,172,172,63,166,155,180,63,193,202,209,63,113,61,202,63,2,43,215,63,57,180,200,62,146,203,127,62,170,96,180,62,43,135,166,63,186,73,156,63,225,122,164,63,57,180,168,63,168,198,171,63,100,59,191,63,225,122,244,63,61,10,215,63,246,40,188,63,255,178,27,63,121,233,6,63,88,168,213,62,215,163,160,63,86,14,189,63,78,98,192,63,199,75,231,63,219,249,222,63,190,193,39,63,0,0,0,64,166,155,4,64,150,67,3,64,80,97,30,0,108,0,0,0,0,0,0,0,100,66,52,0,40,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,66,0,0,160,66,0,0,28,66,0,0,142,66,0,0,4,66,0,0,0,0,8,189,172,185,216,29,35,0,8,36,33,0,190,170,184,222,160,1,32,0,200,41,31,0,190,170,184,223,184,122,30,0,200,41,31,0,190,170,185,172,40,236,29,0,104,127,29,0,8,187,186,188,232,37,29,0,152,214,28,0,8,187,186,178,248,208,35,0,104,129,35,0,8,186,177,188,248,35,35,0,200,221,34,0,187,176,185,223,112,161,34,0,0,101,34,0,187,167,182,171,192,45,34,0,160,254,33,0,187,167,171,223,112,209,33,0,80,171,33,0,8,185,182,179,152,140,33,0,208,105,33,0,183,177,187,190,48,40,33,0,16,3,33,0,8,178,170,167,88,232,32,0,144,205,32,0,8,176,175,171,192,178,32,0,152,157,32,0,176,190,168,186,136,131,32,0,160,106,32,0,8,175,173,176,64,85,32,0,8,60,32,0,8,172,171,173,32,5,32,0,24,237,31,0,171,177,180,177,88,216,31,0,120,198,31,0,88,80,77,212,216,175,31,0,160,157,31,0,0,0,0,0,80,0,100,0,100,0,100,0,110,0,120,0,140,0,150,0,160,0,190,0,210,0,240,0,24,1,64,1,124,1,194,1,38,2,188,2,132,3,76,4,20,5,8,7,196,9,172,13,148,17,0,0,0,0,0,0,96,201,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,56,153,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,32,129,32,0,136,102,32,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,32,129,32,0,112,82,32,0,40,48,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,8,255,31,0,72,233,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,152,213,31,0,120,194,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,144,172,31,0,168,154,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,88,137,31,0,136,237,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,72,106,31,0,136,237,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,96,181,30,0,120,155,30,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,48,121,30,0,120,155,30,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,41,31,0,108,0,0,0,184,118,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,12,4,0,0,8,8,0,0,4,12,0,0,12,0,4,0,9,3,3,1,6,6,2,2,3,9,1,3,8,0,8,0,6,2,6,2,4,4,4,4,2,6,2,6,4,0,12,0,3,1,9,3,2,2,6,6,1,3,3,9,232,130,32,0,112,84,32,0,208,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,12,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,6,0,62,0,28,0,29,0,7,0,8,0,9,0,10,0,11,0,12,0,0,0,1,0,2,0,13,0,30,0,126,0,254,0,254,1,252,7,253,7,252,15,253,15,254,15,255,15,254,3,254,0,62,0,28,0,29,0,12,0,0,0,1,0,2,0,3,0,4,0,5,0,13,0,30,0,126,0,254,1,254,7,254,15,254,31,252,127,253,127,254,127,254,255,255,255,254,15,254,3,254,0,62,0,28,0,6,0,7,0,8,0,9,0,10,0,11,0,0,0,1,0,2,0,12,0,13,0,29,0,30,0,126,0,254,1,254,7,254,31,254,63,255,63,252,31,254,3,252,1,253,1,124,0,125,0,28,0,29,0,10,0,0,0,1,0,2,0,3,0,4,0,11,0,12,0,13,0,30,0,126,0,254,1,254,7,253,31,254,31,255,31,254,15,254,31,254,3,254,0,60,0,61,0,26,0,27,0,10,0,11,0,0,0,1,0,2,0,3,0,4,0,12,0,28,0,29,0,62,0,126,0,254,1,254,7,254,63,255,63,254,15,254,7,254,1,252,0,253,0,124,0,28,0,10,0,11,0,0,0,1,0,2,0,3,0,4,0,12,0,13,0,29,0,30,0,125,0,254,0,254,3,254,31,254,63,255,63,252,127,252,255,253,127,254,15,254,3,254,0,62,0,28,0,12,0,2,0,3,0,4,0,0,0,5,0,13,0,29,0,30,0,126,0,254,1,254,7,254,31,253,255,254,255,255,255,252,63,253,63,254,7,254,3,252,1,124,0,125,0,28,0,29,0,12,0,2,0,3,0,0,0,4,0,5,0,13,0,30,0,126,0,253,1,254,1,254,15,254,63,254,127,255,127,252,1,253,1,254,1,252,0,124,0,60,0,28,0,12,0,0,0,1,0,2,0,3,0,4,0,5,0,13,0,29,0,61,0,125,0,253,0,254,3,254,7,254,15,254,31,255,31,252,63,254,15,254,3,252,0,60,0,61,0,28,0,12,0,0,0,1,0,2,0,3,0,4,0,5,0,13,0,29,0,62,0,253,0,254,0,254,1,254,7,253,63,254,63,255,63,254,31,254,3,252,1,252,0,60,0,61,0,28,0,10,0,11,0,12,0,2,0,3,0,0,0,4,0,13,0,29,0,62,0,253,0,253,1,254,1,254,7,254,15,254,63,255,63,252,255,254,31,254,15,254,7,254,1,62,0,28,0,29,0,10,0,11,0,12,0,2,0,0,0,3,0,4,0,13,0,30,0,126,0,254,0,254,3,254,63,253,255,254,255,255,255,252,31,250,63,251,63,252,63,254,3,254,0,124,0,125,0,28,0,12,0,2,0,3,0,0,0,4,0,5,0,13,0,29,0,30,0,126,0,254,1,254,7,253,63,254,63,255,63,4,6,5,5,4,4,4,4,4,4,3,3,3,4,5,7,8,9,11,11,12,12,12,12,10,8,6,5,5,4,3,3,3,3,3,3,4,5,7,9,11,12,13,15,15,15,16,16,12,10,8,6,5,4,4,4,4,4,4,3,3,3,4,4,5,5,7,9,11,13,14,14,13,10,9,9,7,7,5,5,4,3,3,3,3,3,4,4,4,5,7,9,11,13,13,13,12,13,10,8,6,6,5,5,4,4,3,3,3,3,3,4,5,5,6,7,9,11,14,14,12,11,9,8,8,7,5,4,4,3,3,3,3,3,4,4,5,5,7,8,10,13,14,14,15,16,15,12,10,8,6,5,4,3,3,3,2,3,4,5,5,7,9,11,13,16,16,16,14,14,11,10,9,7,7,5,5,4,3,3,2,3,3,4,5,7,9,9,12,14,15,15,9,9,9,8,7,6,5,4,3,3,3,3,3,3,4,5,6,7,8,10,11,12,13,13,14,12,10,8,6,6,5,4,3,3,3,3,3,3,4,5,6,8,8,9,11,14,14,14,13,10,9,8,6,6,5,4,4,4,3,3,2,3,4,5,6,8,9,9,11,12,14,14,16,13,12,11,9,6,5,5,4,4,4,3,2,3,3,4,5,7,8,10,14,16,16,16,13,14,14,14,10,8,7,7,5,4,3,3,2,3,3,4,5,5,7,9,11,14,14,14,205,204,76,62,154,153,153,62,205,204,204,62,0,0,0,63,92,143,66,62,123,20,174,62,225,122,20,63,123,20,46,63,0,0,4,66,0,0,4,66,0,0,4,66,0,0,230,65,0,0,240,65,0,0,16,66,0,0,4,66,0,0,16,66,255,255,255,255,1,0,0,0,254,255,255,255,2,0,0,0,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,0,0,0,0,0,0,0,0,15,0,0,0,1,0,0,0,235,0,0,0,1,0,0,0,128,0,0,0,1,0,0,0,240,0,0,0,1,0,0,0,128,0,0,0,1,0,0,0,240,0,0,0,1,0,0,0,0,0,64,16,0,0,79,16,0,0,42,203,0,0,37,203,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,0,0,0,0,48,130,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,33,0,96,3,32,0,32,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,120,43,31,0,96,3,32,0,32,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,160,123,30,0,16,237,29,0,12,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,136,128,29,0,16,237,29,0,12,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,176,38,29,0,104,215,28,0,8,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,168,209,35,0,104,215,28,0,8,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,130,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,134,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,21,33,0,108,0,0,0,24,127,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,237,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,38,33,0,208,3,32,0,24,0,0,0,3,0,0,0,25,25,25,25,25,25,201,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,16,44,31,0,16,124,30,0,16,0,0,0,3,0,0,0,20,20,20,20,20,20,180,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,237,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,1,0,0,0,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,24,33,0,108,0,0,0,136,129,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,223,69,26,6,0,0,0,0,0,0,0,0,0,0,0,64,131,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,66,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,243,66,0,0,1,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,242,66,0,0,1,0,0,0,0,0,0,0,16,0,0,0,4,0,0,0,0,0,0,0,130,66,0,0,3,0,0,0,0,0,0,0,24,0,0,0,32,192,29,0,0,0,0,0,133,66,0,0,1,0,0,0,0,0,0,0,32,0,0,0,1,0,0,0,0,0,0,0,134,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,229,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,229,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,86,31,0,108,0,0,0,8,155,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,129,30,0,108,0,0,0,144,109,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,6,0,0,0,0,0,0,0,0,240,0,0,0,204,1,0,0,136,1,0,0,0,0,0,0,0,0,0,0,48,255,255,255,36,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,4,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,11,0,0,0,0,0,0,0,255,255,255,255,253,255,255,255,252,255,255,255,16,39,0,0,194,76,0,0,42,163,0,0,62,72,1,0,40,148,2,0,224,41,5,0,36,84,10,0,40,165,20,0,80,74,41,0,232,136,82,0,252,78,0,0,210,155,0,0,94,70,1,0,160,153,2,0,172,58,5,0,220,120,10,0,72,243,20,0,144,230,41,0,80,197,83,0,0,0,0,0,252,78,0,0,210,155,0,0,94,70,1,0,160,153,2,0,172,58,5,0,220,120,10,0,72,243,20,0,144,230,41,0,80,197,83,0,0,0,0,0,64,81,0,0,250,150,0,0,126,68,1,0,24,159,2,0,220,75,5,0,92,158,10,0,104,65,21,0,208,130,42,0,160,5,85,0,0,0,0,0,16,39,0,0,152,58,0,0,108,107,0,0,246,209,0,0,48,161,1,0,152,65,3,0,204,130,6,0,52,5,13,0,248,11,26,0,8,20,52,0,140,40,0,0,48,62,0,0,6,114,0,0,198,222,0,0,148,186,1,0,96,116,3,0,148,231,6,0,96,206,13,0,104,154,27,0,0,0,0,0,140,40,0,0,48,62,0,0,6,114,0,0,198,222,0,0,148,186,1,0,96,116,3,0,148,231,6,0,96,206,13,0,104,154,27,0,0,0,0,0,18,28,0,0,2,36,0,0,244,61,0,0,222,118,0,0,30,235,0,0,36,213,1,0,128,169,3,0,212,81,7,0,68,163,14,0,0,0,0,0,0,0,0,0,255,0,0,0,0,255,0,0,0,0,255,0,0,255,255,0,255,0,255,0,255,255,0,0,255,255,255,0,0,128,128,0,255,128,128,0,128,0,128,0,128,255,128,0,128,128,0,0,128,128,255,0,85,85,85,0,170,170,170,0,216,233,35,0,108,0,0,0,128,134,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,8,35,0,108,0,0,0,96,73,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,34,51,68,85,102,119,136,153,170,187,204,221,238,255,0,0,2,0,83,236,3,0,83,236,3,0,13,178,3,0,7,217,3,0,13,178,3,0,147,153,3,0,224,159,3,0,224,159,3,0,147,153,3,0,0,128,3,0,222,135,3,0,10,106,3,0,222,135,3,0,0,128,3,0,215,102,3,0,201,110,3,0,109,83,3,0,109,83,3,0,201,110,3,0,215,102,3,0,188,15,3,0,28,86,3,0,204,59,3,0,101,61,3,0,204,59,3,0,28,86,3,0,188,15,3,0,67,226,2,0,173,0,3,0,141,36,3,0,97,38,3,0,97,38,3,0,141,36,3,0,173,0,3,0,67,226,2,0,20,212,2,0,20,212,2,0,188,15,3,0,0,16,3,0,188,15,3,0,20,212,2,0,20,212,2,0,17,170,2,0,88,193,2,0,252,249,2,0,252,249,2,0,88,193,2,0,17,170,2,0,107,152,2,0,197,173,2,0,151,228,2,0,197,173,2,0,107,152,2,0,251,133,2,0,131,154,2,0,131,154,2,0,251,133,2,0,215,115,2,0,216,87,2,0,215,115,2,0,11,53,2,0,11,53,2,0,66,20,2,0,0,0,2,0,13,178,3,0,83,236,3,0,224,159,3,0,0,128,3,0,188,15,3,0,13,178,3,0,10,106,3,0,201,110,3,0,173,0,3,0,0,0,4,0,13,178,3,0,0,128,3,0,188,15,3,0,83,236,3,0,224,159,3,0,204,59,3,0,20,212,2,0,147,153,3,0,109,83,3,0,0,128,3,0,204,59,3,0,97,38,3,0,88,193,2,0,13,178,3,0,10,106,3,0,201,110,3,0,173,0,3,0,204,59,3,0,20,212,2,0,147,153,3,0,109,83,3,0,0,16,3,0,197,173,2,0,215,102,3,0,141,36,3,0,188,15,3,0,20,212,2,0,252,249,2,0,131,154,2,0,0,128,3,0,204,59,3,0,97,38,3,0,88,193,2,0,0,16,3,0,197,173,2,0,215,102,3,0,141,36,3,0,197,173,2,0,216,87,2,0,67,226,2,0,17,170,2,0,251,133,2,0,11,53,2,0,188,15,3,0,20,212,2,0,252,249,2,0,131,154,2,0,197,173,2,0,216,87,2,0,67,226,2,0,17,170,2,0,251,133,2,0,11,53,2,0,0,0,0,0,0,0,0,0,192,212,1,0,10,0,0,0,1,0,0,0,233,3,0,0,48,117,0,0,30,0,0,0,224,1,0,0,208,2,0,0,8,0,0,0,9,0,0,0,32,0,0,0,27,0,0,0,120,39,38,0,200,147,128,0,7,0,0,0,6,0,0,0,184,163,25,0,90,0,0,0,44,6,0,0,172,5,0,0,29,4,0,0,64,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,176,143,20,0,1,0,0,0,0,0,0,0,128,50,2,0,12,0,0,0,1,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,64,2,0,0,208,2,0,0,16,0,0,0,15,0,0,0,64,0,0,0,45,0,0,0,72,24,38,0,200,147,128,0,0,0,0,0,6,0,0,0,184,163,25,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,64,143,20,0,1,0,0,0,0,0,0,0,128,50,2,0,12,0,0,0,1,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,64,2,0,0,208,2,0,0,16,0,0,0,15,0,0,0,64,0,0,0,45,0,0,0,24,9,38,0,200,147,128,0,7,0,0,0,6,0,0,0,184,163,25,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,64,143,20,0,0,0,0,0,4,0,0,0,128,169,3,0,10,0,0,0,2,0,0,0,233,3,0,0,48,117,0,0,30,0,0,0,224,1,0,0,208,2,0,0,8,0,0,0,9,0,0,0,32,0,0,0,27,0,0,0,200,239,37,0,200,147,128,0,4,0,0,0,6,0,0,0,184,163,25,0,90,0,0,0,44,6,0,0,172,5,0,0,29,4,0,0,64,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,176,143,20,0,1,0,0,0,4,0,0,0,0,101,4,0,12,0,0,0,2,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,64,2,0,0,208,2,0,0,16,0,0,0,15,0,0,0,64,0,0,0,45,0,0,0,104,209,37,0,200,147,128,0,4,0,0,0,6,0,0,0,184,163,25,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,64,143,20,0,0,0,0,0,20,0,0,0,0,83,7,0,10,0,0,0,4,0,0,0,233,3,0,0,48,117,0,0,30,0,0,0,56,4,0,0,0,5,0,0,1,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,144,168,38,0,200,107,129,0,4,0,0,0,8,0,0,0,192,163,25,0,90,0,0,0,44,6,0,0,172,5,0,0,29,4,0,0,64,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,176,143,20,0,1,0,0,0,20,0,0,0,0,202,8,0,12,0,0,0,4,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,56,4,0,0,160,5,0,0,1,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,128,82,38,0,200,107,129,0,4,0,0,0,8,0,0,0,192,163,25,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,64,143,20,0,0,0,0,0,24,0,0,0,128,169,3,0,10,0,0,0,2,0,0,0,233,3,0,0,96,234,0,0,60,0,0,0,208,2,0,0,192,3,0,0,1,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,64,143,38,0,200,235,128,0,4,0,0,0,8,0,0,0,192,163,25,0,90,0,0,0,44,6,0,0,172,5,0,0,29,4,0,0,64,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,176,143,20,0,1,0,0,0,24,0,0,0,0,101,4,0,12,0,0,0,2,0,0,0,1,0,0,0,50,0,0,0,50,0,0,0,208,2,0,0,192,3,0,0,1,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,32,52,38,0,200,235,128,0,4,0,0,0,8,0,0,0,192,163,25,0,90,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,64,143,20,0,1,0,0,0,1,0,0,0,128,50,2,0,12,0,0,0,1,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,64,2,0,0,208,2,0,0,16,0,0,0,15,0,0,0,64,0,0,0,45,0,0,0,72,24,38,0,200,147,128,0,0,0,0,0,6,0,0,0,184,163,25,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,64,143,20,0,255,255,255,255,255,255,255,255,255,0,0,0,255,255,0,0,15,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,0,0,0,0,18,9,27,0,36,0,0,0,24,12,36,0,48,0,0,0,36,18,54,0,72,0,0,0,0,1,2,3,4,5,5,4,3,2,1,0,0,1,2,3,4,5,5,4,3,2,1,0,0,1,2,3,4,5,0,0,0,1,2,2,1,0,0,1,2,2,1,0,0,1,2,2,1,0,0,1,2,2,1,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,10,0,10,1,10,2,10,3,20,0,20,1,20,2,20,3,30,0,30,1,30,2,30,3,40,0,40,1,40,2,40,3,50,0,50,1,50,2,50,3,60,0,60,1,60,2,60,3,70,0,70,1,70,2,70,3,0,64,0,65,0,66,10,64,10,65,10,66,20,64,20,65,20,66,30,64,30,65,30,66,40,64,40,65,40,66,50,64,50,65,50,66,60,64,60,65,60,66,70,64,70,65,70,66,0,67,20,67,40,67,60,67,2,6,8,0,4,0,0,0,9,4,13,0,18,0,0,0,0,4,9,13,18,22,27,31,36,40,0,0,0,0,0,0,0,36,72,26,62,98,16,52,88,6,42,78,32,68,104,22,58,94,12,48,84,2,38,74,28,64,100,18,54,90,8,44,80,34,70,106,24,60,96,14,50,86,4,40,76,30,66,102,20,56,92,10,46,82,1,37,73,27,63,99,17,53,89,7,43,79,33,69,105,23,59,95,13,49,85,3,39,75,29,65,101,19,55,91,9,45,81,35,71,107,25,61,97,15,51,87,5,41,77,31,67,103,21,57,93,11,47,83,0,0,0,0,0,30,60,20,50,80,10,40,70,6,36,66,26,56,86,16,46,76,12,42,72,2,32,62,22,52,82,18,48,78,8,38,68,28,58,88,24,54,84,14,44,74,4,34,64,1,31,61,21,51,81,11,41,71,7,37,67,27,57,87,17,47,77,13,43,73,3,33,63,23,53,83,19,49,79,9,39,69,29,59,89,25,55,85,15,45,75,5,35,65,0,0,0,0,0,0,128,187,0,0,68,172,0,0,0,125,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,1,1,2,3,4,5,6,7,8,16,18,20,22,24,28,52,0,240,210,71,0,0,0,0,0,0,32,65,0,0,0,0,168,3,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,46,31,0,208,125,30,0,44,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,64,129,29,0,240,39,29,0,48,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,24,216,28,0,112,210,35,0,52,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,88,131,35,0,112,210,35,0,52,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,152,37,35,0,120,223,34,0,56,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,80,162,34,0,120,223,34,0,56,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,24,102,34,0,216,46,34,0,24,0,0,0,5,0,0,0,192,255,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,240,209,33,0,216,46,34,0,24,0,0,0,5,0,0,0,192,255,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,48,172,33,0,64,141,33,0,60,0,0,0,5,0,0,0,128,106,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,192,40,33,0,64,141,33,0,60,0,0,0,5,0,0,0,128,106,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1338466);
/* memory initializer */ allocate([168,3,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,0,0,0,0,0,0,0,0,0,0,0,156,9,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,43,33,0,108,0,0,0,104,146,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,3,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,46,31,0,88,176,31,0,44,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,64,129,29,0,8,158,31,0,48,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,24,216,28,0,112,139,31,0,52,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,88,131,35,0,112,139,31,0,52,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,152,37,35,0,16,123,31,0,56,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,80,162,34,0,16,123,31,0,56,0,0,0,5,0,0,0,32,238,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,24,102,34,0,96,108,31,0,24,0,0,0,5,0,0,0,192,255,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,240,209,33,0,96,108,31,0,24,0,0,0,5,0,0,0,192,255,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,48,172,33,0,112,87,31,0,60,0,0,0,5,0,0,0,8,46,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,192,40,33,0,112,87,31,0,60,0,0,0,5,0,0,0,8,46,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,3,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,3,0,0,0,0,0,0,0,0,0,0,156,9,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,57,33,0,108,0,0,0,152,149,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,1,0,0,0,6,0,0,0,5,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,7,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,1,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,1,0,0,0,5,0,0,0,125,96,55,103,106,79,95,97,127,111,0,0,0,0,0,0,1,0,0,0,0,0,0,0,9,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,9,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,0,2,128,1,0,0,0,0,0,1,2,0,0,1,2,0,0,2,128,1,0,0,0,216,204,32,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,180,34,0,24,119,34,0,0,0,0,0,0,0,0,0,0,0,2,128,2,0,0,0,0,0,2,128,1,0,0,0,248,47,35,0,108,0,0,0,224,134,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,33,32,32,32,32,32,32,32,34,32,32,32,32,32,32,33,37,32,32,32,32,32,32,36,39,32,32,32,32,32,34,39,44,32,37,32,32,35,40,43,49,32,33,36,36,40,43,50,60,34,37,39,44,51,56,61,70,0,32,34,35,36,36,36,37,36,37,39,40,41,40,40,40,41,41,42,41,41,43,44,44,45,46,48,55,60,57,52,50,49,49,52,52,53,55,58,62,65,73,82,82,80,78,73,68,71,82,90,90,88,87,90,95,100,107,103,97,95,93,99,99,0,12,13,1,2,3,4,5,14,30,62,63,0,0,0,0,3,4,4,3,3,3,3,3,4,5,6,6,0,0,0,0,0,32,35,36,37,37,38,40,42,46,49,50,50,49,49,53,56,56,57,58,60,62,64,65,63,64,64,65,66,65,67,71,72,74,74,74,74,77,81,78,72,73,82,85,89,88,84,80,90,100,90,90,88,87,90,95,114,128,125,129,134,125,116,116,3,3,5,7,5,0,9,11,13,15,7,17,19,21,23,25,27,29,9,11,31,33,35,37,13,39,41,43,45,47,49,15,17,51,53,55,57,59,61,63,65,19,21,67,69,71,73,75,77,79,81,83,23,25,27,85,87,89,91,93,95,97,99,101,103,105,107,29,31,33,109,111,113,115,117,119,121,123,125,127,129,3,5,7,35,37,39,41,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,43,45,47,49,51,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,0,2,2,0,0,0,0,2,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,12,0,26,0,27,0,56,0,57,0,58,0,118,0,119,0,120,0,242,0,243,0,244,0,245,0,246,0,247,0,240,1,241,1,242,1,243,1,244,1,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,228,7,229,7,230,7,231,7,232,7,233,7,234,7,235,7,236,7,237,7,220,15,221,15,222,15,223,15,224,15,225,15,226,15,227,15,228,15,229,15,230,15,231,15,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,221,31,222,31,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,160,127,161,127,162,127,163,127,164,127,165,127,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,110,255,111,255,112,255,113,255,114,255,115,255,116,255,117,255,118,255,119,255,120,255,121,255,122,255,123,255,124,255,125,255,126,255,127,255,128,255,129,255,130,255,131,255,132,255,133,255,134,255,135,255,136,255,137,255,138,255,139,255,140,255,141,255,142,255,143,255,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,4,5,5,6,6,6,7,7,7,8,8,8,8,8,8,9,9,9,9,9,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,4,0,5,0,12,0,26,0,27,0,28,0,58,0,118,0,119,0,120,0,242,0,230,1,231,1,208,3,209,3,210,3,211,3,212,3,213,3,214,3,215,3,216,3,217,3,218,3,219,3,220,3,221,3,222,3,223,3,224,3,225,3,226,3,227,3,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,242,3,243,3,244,3,245,3,246,3,247,3,248,3,249,3,250,3,251,3,252,3,253,3,254,3,255,3,0,0,0,0,1,3,3,4,5,5,5,6,7,7,7,8,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,0,0,0,32,32,34,34,34,34,35,35,35,36,37,36,36,35,36,38,38,38,38,38,38,38,38,38,38,39,41,44,43,41,40,40,40,40,39,40,41,40,39,40,43,46,46,44,44,44,42,41,43,46,48,50,55,58,53,48,50,55,58,61,62,62,62,0,12,13,1,2,3,4,5,14,30,62,63,0,0,0,0,3,4,4,3,3,3,3,3,4,5,6,6,0,0,0,0,0,32,35,36,36,35,36,39,41,43,45,44,41,39,40,42,43,43,45,48,48,48,50,50,50,51,51,51,51,52,53,54,51,49,51,52,52,56,57,55,54,54,55,56,55,58,58,58,60,61,62,62,59,57,58,58,61,59,59,59,61,62,62,62,3,3,5,7,0,9,11,5,13,15,17,7,19,21,23,9,25,27,29,31,33,11,35,37,39,41,43,13,45,47,49,51,53,55,57,59,15,17,61,63,65,67,69,71,73,75,77,79,81,19,21,23,83,85,87,89,91,93,95,97,99,101,103,105,25,27,29,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,31,33,35,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,37,39,41,43,45,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,47,49,51,53,55,57,119,121,123,125,127,129,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,116,0,117,0,118,0,119,0,240,0,241,0,242,0,243,0,244,0,245,0,236,1,237,1,238,1,239,1,240,1,241,1,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,220,7,221,7,222,7,223,7,224,7,225,7,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,212,15,213,15,214,15,215,15,216,15,217,15,218,15,219,15,220,15,221,15,222,15,223,15,224,15,225,15,226,15,198,31,199,31,200,31,201,31,202,31,203,31,204,31,205,31,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,186,63,187,63,188,63,189,63,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,208,63,209,63,210,63,211,63,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,194,127,195,127,196,127,197,127,198,127,199,127,200,127,201,127,202,127,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,4,0,5,0,12,0,26,0,27,0,28,0,58,0,118,0,119,0,120,0,242,0,230,1,231,1,208,3,209,3,210,3,211,3,212,3,213,3,214,3,215,3,216,3,217,3,218,3,219,3,220,3,221,3,222,3,223,3,224,3,225,3,226,3,227,3,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,242,3,243,3,244,3,245,3,246,3,247,3,248,3,249,3,250,3,251,3,252,3,253,3,254,3,255,3,0,0,0,0,1,3,3,4,5,5,5,6,7,7,7,8,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,0,0,0,32,32,33,34,35,35,35,34,34,35,36,36,36,36,36,37,38,38,38,38,38,39,39,38,38,39,41,43,43,42,41,40,40,39,40,41,41,39,39,40,42,47,50,47,45,46,46,44,45,46,47,49,54,58,54,48,49,54,57,60,62,63,63,10,62,11,12,13,0,1,2,3,4,14,30,126,127,0,0,4,6,4,4,4,3,3,3,3,3,4,5,7,7,0,0,0,32,35,36,36,35,36,39,41,43,45,44,41,39,40,42,43,43,45,48,49,51,52,50,50,51,51,51,51,52,53,54,51,49,51,52,52,56,57,55,54,54,55,56,55,58,58,58,60,61,62,62,59,57,58,58,61,59,59,59,60,62,63,63,3,3,5,7,0,9,11,5,13,15,17,7,19,21,23,9,25,27,29,31,33,11,35,37,39,41,43,45,13,47,49,51,53,55,57,59,15,17,61,63,65,67,69,71,73,75,77,79,19,21,81,83,85,87,89,91,93,95,97,99,101,103,105,23,25,27,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,29,31,33,35,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,37,39,41,43,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,111,113,45,47,49,51,53,55,109,115,117,119,121,123,125,127,129,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,116,0,117,0,118,0,119,0,240,0,241,0,242,0,243,0,244,0,245,0,236,1,237,1,238,1,239,1,240,1,241,1,242,1,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,222,7,223,7,224,7,225,7,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,212,15,213,15,214,15,215,15,216,15,217,15,218,15,219,15,220,15,221,15,222,15,223,15,224,15,225,15,226,15,227,15,200,31,201,31,202,31,203,31,204,31,205,31,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,186,63,187,63,188,63,189,63,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,208,63,209,63,210,63,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,194,127,195,127,196,127,197,127,198,127,199,127,200,127,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,33,33,35,35,35,35,35,35,35,34,35,38,40,39,37,37,37,36,35,36,38,40,41,42,44,45,44,42,41,40,38,36,36,37,38,40,43,44,45,45,45,45,45,45,41,39,41,45,47,47,48,48,48,46,44,45,47,47,48,47,47,0,32,36,37,36,37,39,39,41,43,43,42,41,41,41,42,43,43,43,44,44,44,46,47,46,45,45,45,45,46,44,44,45,44,42,41,43,46,45,44,45,45,45,46,46,46,45,44,45,44,45,47,47,48,49,48,46,45,46,47,47,48,47,47,0,32,33,33,34,35,36,35,33,33,35,36,37,37,38,37,37,37,36,37,37,37,38,39,37,36,37,40,42,45,46,44,41,42,44,45,47,49,50,48,46,48,49,50,52,52,50,49,47,48,50,50,51,51,50,49,49,51,52,51,49,47,47,47,0,32,37,42,45,45,45,44,38,37,40,42,44,49,51,47,41,40,43,44,46,48,51,54,51,47,47,45,47,50,51,49,46,47,49,47,50,55,55,51,48,49,51,51,52,52,54,54,49,49,52,53,54,54,53,53,55,59,63,62,60,60,60,60,0,32,33,34,34,35,36,37,36,37,38,38,38,39,39,40,40,38,38,39,38,37,39,41,41,42,43,45,45,46,47,46,45,43,39,37,37,40,44,45,45,46,46,46,47,47,46,44,42,43,45,47,48,49,50,49,48,46,47,48,48,49,49,49,0,32,36,38,37,37,40,41,40,40,42,42,41,41,41,41,42,43,44,44,45,46,46,45,44,45,45,45,45,46,47,46,45,44,42,41,43,45,45,47,48,48,48,46,47,47,46,47,46,45,45,47,48,49,50,49,48,46,48,49,48,49,49,49,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,20,21,17,18,19,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,0,0,0,32,32,33,34,33,33,33,33,33,33,33,33,35,37,37,36,36,35,36,38,38,36,35,36,37,38,41,42,41,39,38,38,38,39,41,42,41,39,39,40,41,43,44,44,44,44,44,45,47,47,47,49,50,51,51,51,53,55,57,58,59,57,57,0,12,13,1,2,3,4,5,14,30,62,63,0,0,0,0,3,4,4,3,3,3,3,3,4,5,6,6,0,0,0,0,0,32,35,35,35,34,34,35,39,43,45,45,41,39,40,41,42,44,48,55,59,63,65,59,53,52,52,55,61,62,58,58,63,66,66,65,70,74,70,66,65,68,75,77,74,74,77,76,73,73,73,73,76,80,89,90,82,77,80,86,84,82,82,82,3,3,5,7,0,9,11,5,13,15,17,7,19,21,23,9,25,27,29,31,33,11,35,37,39,41,43,45,13,15,47,49,51,53,55,57,59,17,19,61,63,65,67,69,71,73,75,21,23,77,79,81,83,85,87,89,91,93,95,97,25,27,29,99,101,103,105,107,109,111,113,115,117,119,121,123,31,33,35,37,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,39,41,43,45,47,49,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,81,51,53,55,57,59,61,77,79,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,116,0,117,0,118,0,119,0,240,0,241,0,242,0,243,0,244,0,245,0,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,234,7,235,7,216,15,217,15,218,15,219,15,220,15,221,15,222,15,223,15,224,15,225,15,226,15,227,15,228,15,229,15,204,31,205,31,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,186,63,187,63,188,63,189,63,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,208,63,209,63,210,63,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,132,255,133,255,134,255,135,255,136,255,137,255,138,255,139,255,140,255,141,255,142,255,143,255,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,58,0,118,0,119,0,240,0,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,222,3,223,3,224,3,225,3,226,3,227,3,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,242,3,243,3,244,3,245,3,246,3,247,3,248,3,249,3,250,3,251,3,252,3,253,3,254,3,255,3,0,0,0,0,1,3,4,4,5,5,5,6,6,6,6,6,7,7,8,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,53,57,58,59,60,61,62,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,54,55,56,0,0,0,32,33,34,34,36,37,36,36,37,38,38,38,39,41,44,43,41,40,41,46,49,47,46,47,49,51,54,60,62,59,55,54,56,58,61,65,66,64,63,66,73,78,79,80,79,78,78,82,87,89,90,93,95,96,97,97,100,104,102,98,98,99,99,0,12,13,1,2,3,4,5,14,30,62,63,0,0,0,0,3,4,4,3,3,3,3,3,4,5,6,6,0,0,0,0,0,32,36,39,39,38,39,41,45,51,57,58,53,48,47,51,55,58,66,75,81,83,82,78,73,72,74,77,83,85,83,82,89,99,96,90,94,97,99,105,109,105,95,89,92,95,94,93,92,88,89,90,93,95,96,97,97,100,104,102,98,98,99,99,3,3,5,0,7,9,5,11,13,15,7,17,19,21,23,25,9,11,27,29,31,33,13,35,37,39,41,43,15,45,47,49,51,53,55,17,19,57,59,61,63,65,67,69,21,23,25,71,73,75,77,79,81,83,27,29,31,33,85,87,89,91,93,95,97,99,101,103,105,35,37,39,41,43,107,109,111,113,115,117,119,121,123,129,3,45,47,49,51,53,55,125,127,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,2,0,0,0,2,0,0,0,0,0,2,2,0,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,1,2,2,2,2,2,2,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,5,0,12,0,26,0,27,0,56,0,57,0,58,0,59,0,120,0,121,0,244,0,245,0,246,0,247,0,248,0,242,1,243,1,244,1,245,1,246,1,238,3,239,3,240,3,241,3,242,3,243,3,232,7,233,7,234,7,235,7,236,7,237,7,238,7,239,7,224,15,225,15,226,15,227,15,228,15,229,15,230,15,231,15,232,15,233,15,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,221,31,222,31,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,156,127,157,127,158,127,159,127,160,127,161,127,162,127,163,127,164,127,165,127,166,127,167,127,168,127,169,127,170,127,171,127,172,127,90,255,91,255,92,255,93,255,94,255,95,255,96,255,97,255,98,255,99,255,100,255,101,255,102,255,103,255,104,255,105,255,106,255,107,255,108,255,109,255,110,255,111,255,112,255,113,255,114,255,115,255,116,255,117,255,118,255,119,255,120,255,121,255,122,255,123,255,124,255,125,255,126,255,127,255,128,255,129,255,130,255,131,255,132,255,133,255,134,255,135,255,136,255,137,255,138,255,139,255,140,255,141,255,142,255,143,255,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,3,4,5,5,6,6,6,6,7,7,8,8,8,8,8,9,9,9,9,9,10,10,10,10,10,10,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,33,32,32,32,32,31,32,33,33,33,33,35,36,36,34,34,36,37,37,36,36,35,36,38,39,39,37,36,37,37,39,41,42,41,39,39,40,41,42,43,42,42,41,41,41,44,47,46,46,48,51,51,50,50,53,55,55,56,60,60,0,32,33,34,34,33,34,35,37,40,43,42,39,38,39,41,43,44,47,50,55,61,63,56,48,46,49,54,59,58,55,58,63,65,67,74,84,82,75,72,70,74,84,87,87,94,93,81,75,78,83,89,91,86,82,85,90,90,85,79,73,73,73,73,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,18,20,17,19,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,0,0,10,62,11,12,13,0,1,2,3,4,14,30,126,127,0,0,4,6,4,4,4,3,3,3,3,3,4,5,7,7,0,0,3,3,5,7,0,9,11,5,13,15,17,7,19,21,23,9,25,27,29,31,33,11,35,37,39,41,43,13,15,45,47,49,51,53,55,57,59,17,19,61,63,65,67,69,71,73,75,77,21,23,79,81,83,85,87,89,91,93,95,97,99,101,25,27], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1348720);
/* memory initializer */ allocate([29,31,103,105,107,109,111,113,115,117,119,121,123,125,127,3,33,35,37,39,129,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,41,43,45,47,49,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,51,53,55,57,59,61,63,65,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,2,2,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,116,0,117,0,118,0,119,0,240,0,241,0,242,0,243,0,244,0,245,0,236,1,237,1,238,1,239,1,240,1,241,1,242,1,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,224,7,225,7,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,234,7,214,15,215,15,216,15,217,15,218,15,219,15,220,15,221,15,222,15,223,15,224,15,225,15,226,15,227,15,228,15,229,15,204,31,205,31,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,221,31,188,63,189,63,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,208,63,209,63,164,127,165,127,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,194,127,195,127,196,127,138,255,139,255,140,255,141,255,142,255,143,255,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,4,0,10,0,11,0,24,0,25,0,26,0,27,0,56,0,57,0,58,0,59,0,120,0,242,0,230,1,231,1,232,1,233,1,212,3,213,3,214,3,215,3,216,3,217,3,218,3,219,3,220,3,221,3,222,3,223,3,224,3,225,3,226,3,227,3,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,242,3,243,3,244,3,245,3,246,3,247,3,248,3,249,3,250,3,251,3,252,3,253,3,254,3,255,3,0,0,0,0,1,3,4,4,5,5,5,5,6,6,6,6,7,8,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,0,0,56,16,130,0,56,12,130,0,0,0,0,0,56,236,129,0,184,16,130,0,56,14,130,0,0,0,0,0,56,252,129,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,2,2,3,3,3,3,3,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,10,10,11,11,11,11,11,11,12,12,12,12,12,12,13,13,13,13,13,13,14,14,14,14,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,1,2,1,2,1,2,1,2,3,0,3,0,3,0,3,0,1,2,1,2,1,2,1,2,3,0,3,0,3,0,3,0,1,2,1,2,1,2,1,2,3,0,3,0,3,0,3,0,1,2,1,2,1,2,1,2,3,0,3,0,3,0,3,0,2,4,3,5,2,4,3,5,6,0,7,1,6,0,7,1,3,5,2,4,3,5,2,4,7,1,6,0,7,1,6,0,2,4,3,5,2,4,3,5,6,0,7,1,6,0,7,1,3,5,2,4,3,5,2,4,7,1,6,0,7,1,6,0,4,8,7,11,4,8,7,11,12,0,15,3,12,0,15,3,6,10,5,9,6,10,5,9,14,2,13,1,14,2,13,1,4,8,7,11,4,8,7,11,12,0,15,3,12,0,15,3,6,10,5,9,6,10,5,9,14,2,13,1,14,2,13,1,9,17,15,23,8,16,14,22,25,1,31,7,24,0,30,6,13,21,11,19,12,20,10,18,29,5,27,3,28,4,26,2,8,16,14,22,9,17,15,23,24,0,30,6,25,1,31,7,12,20,10,18,13,21,11,19,28,4,26,2,29,5,27,3,18,34,30,46,17,33,29,45,50,2,62,14,49,1,61,13,26,42,22,38,25,41,21,37,58,10,54,6,57,9,53,5,16,32,28,44,19,35,31,47,48,0,60,12,51,3,63,15,24,40,20,36,27,43,23,39,56,8,52,4,59,11,55,7,18,34,30,46,17,33,29,45,50,2,62,14,49,1,61,13,26,42,22,38,25,41,21,37,58,10,54,6,57,9,53,5,16,32,28,44,19,35,31,47,48,0,60,12,51,3,63,15,24,40,20,36,27,43,23,39,56,8,52,4,59,11,55,7,36,68,60,92,34,66,58,90,100,4,124,28,98,2,122,26,52,84,44,76,50,82,42,74,116,20,108,12,114,18,106,10,32,64,56,88,38,70,62,94,96,0,120,24,102,6,126,30,48,80,40,72,54,86,46,78,112,16,104,8,118,22,110,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,5,53,62,0,0,128,62,247,4,53,63,0,0,128,63,0,0,0,0,2,0,3,0,3,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,2,0,3,0,7,0,7,0,13,0,13,0,25,0,25,0,25,0,25,0,25,0,25,0,25,0,25,0,25,0,25,0,3,0,3,0,4,0,15,0,15,0,29,0,57,0,57,0,57,0,113,0,113,0,113,0,113,0,113,0,113,0,113,0,3,0,4,0,4,0,5,0,31,0,31,0,61,0,121,0,241,0,241,0,241,0,241,0,225,1,225,1,225,1,225,1,3,0,4,0,5,0,5,0,6,0,63,0,63,0,125,0,249,0,241,1,225,3,225,3,225,3,225,3,225,3,193,7,3,0,5,0,6,0,6,0,6,0,7,0,127,0,127,0,253,0,249,1,241,3,225,7,193,15,193,15,193,15,193,15,3,0,5,0,6,0,7,0,7,0,7,0,8,0,255,0,255,0,253,1,249,3,241,7,225,15,193,31,129,63,129,63,3,0,5,0,6,0,8,0,8,0,8,0,8,0,9,0,255,1,255,1,253,3,249,7,241,15,225,31,193,63,129,127,3,0,5,0,7,0,8,0,9,0,9,0,9,0,9,0,10,0,255,3,255,3,253,7,249,15,241,31,225,63,193,127,3,0,5,0,7,0,8,0,10,0,10,0,10,0,10,0,10,0,11,0,255,7,255,7,253,15,249,31,241,63,225,127,3,0,5,0,7,0,8,0,10,0,11,0,11,0,11,0,11,0,11,0,12,0,255,15,255,15,253,31,249,63,241,127,3,0,5,0,7,0,9,0,10,0,12,0,12,0,12,0,12,0,12,0,12,0,13,0,255,31,255,31,253,63,249,127,3,0,5,0,7,0,9,0,10,0,12,0,13,0,13,0,13,0,13,0,13,0,13,0,14,0,255,63,255,63,253,127,3,0,5,0,7,0,9,0,10,0,12,0,14,0,14,0,14,0,14,0,14,0,14,0,14,0,15,0,255,127,255,127,3,0,5,0,7,0,9,0,11,0,12,0,14,0,15,0,15,0,15,0,15,0,15,0,15,0,15,0,16,0,255,255,0,0,96,0,24,0,120,0,6,0,102,0,30,0,126,0,64,0,32,0,88,0,56,0,70,0,38,0,94,0,62,0,16,0,112,0,8,0,104,0,22,0,118,0,14,0,110,0,80,0,48,0,72,0,40,0,86,0,54,0,78,0,46,0,4,0,100,0,28,0,124,0,2,0,98,0,26,0,122,0,68,0,36,0,92,0,60,0,66,0,34,0,90,0,58,0,20,0,116,0,12,0,108,0,18,0,114,0,10,0,106,0,84,0,52,0,76,0,44,0,82,0,50,0,74,0,42,0,4,8,12,16,0,0,0,0,4,12,16,24,0,0,0,0,128,2,0,0,224,1,0,0,2,0,0,1,1,0,128,2,224,1,0,0,0,0,1,0,176,0,0,0,120,0,0,0,2,0,0,9,2,0,176,0,120,0,0,0,0,0,1,1,176,0,0,0,144,0,0,0,2,0,1,10,3,0,176,0,144,0,0,0,0,0,1,2,96,1,0,0,240,0,0,0,2,0,0,9,2,0,96,1,240,0,0,0,0,0,1,1,96,1,0,0,32,1,0,0,2,0,1,10,3,0,96,1,32,1,0,0,0,0,1,2,192,2,0,0,224,1,0,0,2,0,0,9,2,0,192,2,224,1,0,0,0,0,1,1,192,2,0,0,64,2,0,0,2,0,1,10,3,0,192,2,64,2,0,0,0,0,1,2,208,2,0,0,224,1,0,0,1,1,0,4,2,0,192,2,224,1,8,0,0,0,3,1,208,2,0,0,64,2,0,0,1,1,1,3,3,0,192,2,64,2,8,0,0,0,3,2,0,5,0,0,208,2,0,0,1,0,1,7,1,0,0,5,208,2,0,0,0,0,3,3,0,5,0,0,208,2,0,0,1,0,1,6,1,0,0,5,208,2,0,0,0,0,3,3,128,7,0,0,56,4,0,0,1,1,1,4,1,0,128,7,56,4,0,0,0,0,3,3,128,7,0,0,56,4,0,0,1,1,1,3,1,0,128,7,56,4,0,0,0,0,3,3,128,7,0,0,56,4,0,0,1,0,1,7,1,0,128,7,56,4,0,0,0,0,3,3,128,7,0,0,56,4,0,0,1,0,1,6,1,0,128,7,56,4,0,0,0,0,3,3,0,8,0,0,56,4,0,0,0,0,1,2,1,0,0,8,56,4,0,0,0,0,4,4,0,16,0,0,112,8,0,0,0,0,1,2,1,0,0,16,112,8,0,0,0,0,4,4,0,15,0,0,112,8,0,0,1,0,1,7,1,0,0,15,112,8,0,0,0,0,3,3,0,15,0,0,112,8,0,0,1,0,1,6,1,0,0,15,112,8,0,0,0,0,3,3,0,30,0,0,224,16,0,0,1,0,1,7,1,0,0,15,112,8,0,0,0,0,3,3,0,30,0,0,224,16,0,0,1,0,1,6,1,0,0,15,112,8,0,0,0,0,3,3,1,0,0,0,6,0,0,0,5,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,16,0,0,0,11,0,0,0,4,0,0,0,3,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,152,58,0,0,233,3,0,0,25,0,0,0,2,0,0,0,232,204,32,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,6,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,5,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,77,5,33,5,112,4,16,3,182,1,181,0,145,0,124,2,136,2,155,2,56,2,186,1,217,0,106,1,171,1,184,1,162,2,12,2,76,1,117,0,95,254,121,0,39,1,212,1,209,1,230,0,44,0,35,255,109,255,16,255,149,0,80,0,134,1,22,1,106,0,94,254,212,253,40,2,255,1,235,0,144,0,161,255,43,0,193,0,18,1,150,0,67,0,34,0,239,254,213,255,130,255,171,0,160,1,26,1,63,0,158,254,140,254,170,255,168,254,148,255,162,255,74,255,167,255,168,253,184,252,56,255,209,1,2,1,245,255,3,255,208,255,73,1,97,0,222,254,225,253,229,252,158,254,198,253,139,255,187,0,10,0,123,255,96,254,180,255,150,253,127,255,9,255,141,254,45,0,180,255,21,1,2,252,201,251,126,0,218,1,254,0,127,0,52,0,231,254,76,0,89,255,151,254,229,254,217,253,229,254,137,255,204,255,255,255,134,0,224,255,52,255,97,254,40,4,59,3,125,2,172,2,208,1,209,0,12,0,226,1,160,1,193,1,115,1,79,1,38,1,194,0,207,2,64,2,109,1,135,0,113,0,91,0,57,255,42,1,176,0,237,1,110,1,194,0,163,0,36,0,221,255,20,255,253,254,220,255,252,255,99,0,152,0,158,255,206,254,229,255,228,0,90,0,111,0,170,255,91,0,13,0,45,255,254,254,150,255,86,0,192,255,73,0,221,255,199,255,225,255,162,0,35,0,64,255,147,255,177,254,139,253,190,255,195,255,128,255,66,1,17,254,99,253,40,253,193,0,31,0,36,255,122,0,68,1,95,0,167,255,165,255,103,254,58,253,102,255,0,0,22,255,92,0,33,0,169,254,159,253,36,255,169,254,104,254,36,254,113,253,103,255,82,0,222,0,22,254,23,253,1,255,49,0,208,255,135,0,129,255,119,0,189,255,184,254,122,254,240,254,223,253,200,255,199,255,126,255,246,255,249,255,92,255,209,255,234,255,216,3,40,4,193,3,56,2,210,0,229,255,16,0,43,3,179,2,242,2,2,2,224,0,221,255,166,0,150,2,192,2,106,2,130,1,57,0,45,255,255,254,254,1,103,1,162,1,137,1,91,0,112,255,238,255,63,255,225,255,229,255,223,0,89,0,113,255,24,0,144,255,158,255,215,1,63,1,185,0,3,0,175,0,252,0,146,0,209,255,16,1,48,0,45,255,22,255,146,0,69,0,203,0,108,1,68,0,204,255,51,0,253,254,34,254,71,253,163,254,10,253,11,254,63,0,11,254,255,252,223,254,79,0,201,254,15,254,150,255,251,0,53,0,21,255,43,254,129,252,140,252,145,0,96,254,217,253,140,0,123,255,245,253,249,252,44,0,186,254,89,254,55,253,15,254,170,255,81,254,99,0,11,253,252,252,96,255,180,255,210,255,224,255,123,1,85,0,221,255,56,255,111,254,105,253,240,251,9,255,76,255,182,254,164,255,136,254,27,0,73,255,146,255,255,4,62,4,13,3,246,1,68,1,164,0,157,0,170,2,210,1,193,1,21,1,146,0,28,0,153,1,123,2,216,1,134,1,107,0,24,255,230,253,117,255,196,0,140,1,76,1,213,0,209,0,227,255,175,255,150,0,161,255,200,254,76,0,179,255,192,254,206,255,46,0,9,0,47,0,175,0,139,0,30,0,128,1,218,0,206,0,232,255,6,255,160,255,236,254,73,255,26,0,119,0,38,0,14,0,252,255,123,255,204,255,35,254,154,253,37,252,53,253,137,253,211,252,200,0,24,253,15,252,215,251,23,253,137,253,85,255,18,0,119,255,5,255,29,254,155,253,44,252,77,251,12,0,163,253,1,253,206,253,82,253,192,251,253,253,58,0,54,255,84,254,242,252,208,251,160,255,22,255,77,255,32,254,59,253,210,251,127,252,125,255,164,255,65,1,111,255,63,255,0,254,39,253,196,253,3,253,46,255,181,254,183,253,243,253,137,253,231,254,48,255,209,254,141,4,80,4,171,3,60,3,204,2,170,1,155,0,6,0,147,255,52,3,10,3,159,1,113,0,229,255,125,1,83,1,58,1,9,1,121,0,247,255,38,254,139,254,47,0,72,2,186,1,99,0,25,255,143,255,16,254,218,255,227,254,6,1,49,1,170,0,4,0,181,253,212,253,69,0,66,0,215,1,98,1,13,0,118,255,70,0,238,255,106,0,67,0,167,0,210,254,67,254,115,255,185,0,191,0,151,0,83,0,123,255,255,254,247,253,48,253,58,255,134,0,210,255,74,255,205,252,112,251,247,252,0,2,103,1,95,0,143,255,137,0,254,255,182,255,118,255,111,254,142,255,141,254,14,255,46,254,204,0,223,0,225,255,44,255,64,255,236,253,131,253,46,254,82,253,0,1,21,1,117,255,139,251,36,251,131,254,181,255,202,255,14,0,88,0,201,254,115,0,113,255,13,254,169,254,124,0,96,254,152,253,109,255,121,255,43,0,252,255,121,0,143,254,67,3,15,3,129,2,134,1,99,1,94,1,64,0,72,0,194,0,187,1,211,1,180,1,219,0,116,1,208,1,113,1,192,0,4,0,100,255,184,255,30,255,57,0,206,0,47,1,205,0,188,0,101,0,9,1,216,255,51,255,24,254,72,255,20,1,64,0,230,255,39,255,79,254,215,254,137,0,72,1,52,1,223,254,122,1,81,0,204,254,47,254,57,0,219,255,227,0,156,255,24,0,220,255,105,255,199,0,8,0,143,0,86,254,71,253,221,251,123,255,132,1,161,0,65,1,124,253,1,252,9,251,39,0,66,0,133,255,70,0,116,1,177,0,83,255,212,253,215,253,208,254,67,255,139,255,143,254,87,254,134,255,50,254,104,255,183,255,119,253,174,252,91,251,1,253,241,1,104,1,222,0,226,252,141,251,81,250,66,255,174,1,234,0,179,0,42,0,162,255,107,254,76,253,38,0,54,255,10,255,87,255,146,254,222,254,168,255,192,255,32,0,220,254,242,3,155,3,170,3,198,2,209,1,230,0,86,1,217,0,44,1,30,4,163,2,68,0,54,254,77,255,78,0,197,1,60,1,18,0,19,255,16,254,13,255,167,0,21,0,168,1,215,0,165,255,209,254,86,255,222,254,175,255,186,255,189,255,40,0,54,0,197,255,159,254,85,254,166,255,53,0,94,0,9,0,54,0,228,255,62,1,27,1,15,0,16,255,198,255,79,0,181,255,135,255,229,0,35,0,58,0,6,0,123,255,161,254,254,253,24,253,190,252,63,253,119,255,164,0,156,251,148,250,225,251,26,255,183,255,40,0,36,0,93,255,23,255,236,253,239,252,110,251,71,253,96,0,236,252,65,252,10,255,82,254,144,253,91,255,248,255,168,252,228,253,138,253,117,252,175,254,186,255,76,0,87,252,238,251,109,253,35,253,48,255,199,0,230,255,245,253,78,0,158,255,11,254,155,252,134,252,175,255,144,253,65,253,211,255,164,254,231,255,87,0,70,255,237,3,55,3,34,2,249,0,90,0,234,255,207,0,42,1,141,1,125,1,63,1,200,0,62,0,47,1,217,1,123,1,133,0,9,255,136,253,71,254,75,0,28,1,208,0,135,1,115,0,231,255,44,0,95,0,184,255,79,0,161,255,193,255,127,255,219,254,203,0,92,255,163,254,115,0,122,0,69,0,255,255,122,1,92,1,170,0,99,0,58,0,77,255,210,254,188,0,66,255,254,255,150,0,23,0,205,255,245,255,216,0,153,253,161,252,190,251,109,250,222,252,208,255,250,255,63,252,4,251,244,249,41,253,198,255,56,0,223,0,132,255,1,255,207,253,36,252,3,251,108,255,174,255,32,254,108,253,133,252,89,251,197,250,187,254,20,0,147,253,107,252,240,250,186,250,8,1,33,1,50,0,180,252,2,252,191,250,207,250,219,254,46,0,22,1,252,254,44,254,195,252,104,251,235,253,208,253,178,255,41,255,28,254,202,252,47,251,233,252,15,0,118,255,21,5,37,5,238,4,24,4,204,2,101,1,192,255,66,2,56,3,157,3,34,3,118,2,106,1,102,0,214,1,157,3,255,2,2,2,71,1,190,0,144,255,225,0,236,1,239,1,181,1,86,2,128,1,211,255,43,0,82,0,214,255,175,0,7,2,86,1,192,255,208,254,102,255,159,0,64,2,147,1,221,0,71,1,214,0,244,0,122,0,194,255,56,1,92,0,96,255,218,0,208,0,54,1,12,1,50,1,67,1,57,255,227,254,243,254,177,255,132,255,113,255,103,255,236,0,51,255,128,254,86,254,88,1,59,0,71,255,72,255,240,254,247,0,126,0,46,255,250,253,44,254,78,0,157,255,136,255,246,1,160,0,232,254,211,253,48,1,89,254,239,255,229,254,69,254,215,0,212,0,116,255,204,253,84,253,28,255,254,1,105,1,130,0,67,1,84,254,79,1,98,0,191,255,36,0,41,255,10,255,150,254,51,0,108,1,240,255,22,255,150,0,91,255,146,3,115,3,239,2,141,2,164,2,208,1,103,255,119,2,33,2,23,2,208,2,84,2,104,1,175,255,15,3,200,2,0,2,183,1,85,1,251,0,121,254,241,1,161,1,249,0,116,1,39,1,173,0,63,255,128,0,146,255,127,254,93,0,39,0,173,0,25,255,216,0,197,255,3,255,206,1,133,1,154,0,69,0,199,1,14,1,252,255,175,254,207,255,233,0,190,254,51,1,143,0,53,0,218,0,128,0,236,0,100,255,219,255,70,255,16,255,101,254,146,255,9,0,143,1,116,255,147,254,140,253,2,1,124,1,214,0,21,1,131,0,198,1,177,0,227,254,248,253,108,0,42,255,77,0,115,255,201,0,133,255,22,254,125,255,60,0,242,255,62,255,247,253,27,253,17,1,106,1,223,255,150,254,202,253,225,254,28,255,161,0,237,0,61,1,243,254,195,0,181,255,137,254,52,255,11,0,77,0,128,255,248,254,100,255,33,255,37,254,9,1,27,0,214,4,123,4,148,3,177,2,176,1,210,0,232,254,32,3,152,2,111,3,214,2,155,1,160,0,92,255,198,1,174,2,24,2,19,1,147,0,46,0,111,0,47,1,230,1,0,2,99,1,241,0,181,0,187,255,79,0,92,0,29,0,147,0,233,0,52,0,17,0,85,255,33,1,131,0,183,1,15,1,3,0,246,255,157,1,241,0,144,0,174,0,155,0,254,255,14,0,58,0,217,0,247,0,219,0,149,0,175,0,238,255,228,0,248,255,16,255,50,255,255,253,65,255,202,0,160,255,240,254,58,254,33,0,212,254,193,253,46,0,246,255,148,255,10,255,165,254,254,252,233,253,9,0,186,254,82,254,195,255,191,254,64,253,213,254,201,0,255,255,232,254,165,253,93,254,71,255,18,0,220,255,252,253,246,253,133,254,221,254,75,255,159,255,27,0,97,255,199,254,243,253,32,255,2,254,193,252,59,255,220,254,53,254,197,255,202,254,206,253,113,255,161,254,42,4,144,3,119,2,133,1,207,0,86,0,32,255,84,2,0,2,84,2,249,1,58,1,122,0,208,255,19,3,93,3,185,1,163,255,209,254,33,0,66,255,1,1,213,1,81,1,51,0,15,0,42,1,163,255,39,1,73,0,137,255,25,0,36,0,23,0,108,0,228,255,253,255,224,255,114,0,21,0,185,0,107,0,226,1,49,1,15,0,233,254,193,254,52,0,96,0,226,0,46,0,115,0,72,0,120,255,133,0,131,255,18,0,49,255,209,253,178,253,9,254,30,254,65,1,197,253,235,252,73,252,84,255,71,254,230,253,113,0,181,0,14,0,202,254,127,253,23,252,54,255,159,0,120,255,119,254,79,254,255,253,113,252,112,255,234,255,72,0,247,254,62,253,70,252,97,255,53,0,76,1,174,254,177,253,172,252,129,254,117,254,56,0,44,0,43,0,98,255,48,254,127,252,137,253,99,255,218,254,95,255,128,255,184,254,195,253,29,254,131,255,11,0,249,3,138,3,27,4,237,3,167,2,85,1,154,255,103,1,78,1,31,6,34,5,211,2,105,0,10,0,191,255,214,2,17,2,45,1,220,0,43,0,239,254,2,254,180,1,207,2,54,2,102,1,179,0,114,0,208,253,42,1,133,0,136,255,86,1,225,0,14,0,125,252,155,255,217,0,105,2,144,1,146,0,198,255,215,255,96,1,82,0,60,255,39,0,121,0,89,255,44,255,59,0,191,1,28,1,167,1,250,0,87,255,141,254,28,254,172,253,30,0,215,255,249,0,22,0,140,254,118,253,230,252,221,1,189,1,216,0,177,255,160,254,19,1,17,0,69,254,95,252,92,0,19,0,69,253,72,253,175,1,8,1,207,255,202,254,182,0,46,252,39,255,82,254,112,254,101,0,5,1,72,0,95,252,135,252,155,254,243,255,207,1,122,1,236,0,198,252,56,0,30,0,213,254,152,254,128,255,205,255,146,252,213,254,145,255,75,0,65,0,36,0,3,0,49,3,112,1,231,255,98,1,185,2,79,2,83,255,53,1,212,0,222,0,239,2,228,1,140,0,200,255,81,2,123,1,70,0,248,255,2,1,180,0,110,0,165,0,210,255,255,0,41,1,219,0,17,1,105,0,160,0,186,255,154,254,75,255,123,1,74,1,63,1,18,255,143,254,58,255,228,2,68,2,63,1,113,255,201,0,109,0,54,255,56,254,72,1,20,1,115,255,203,0,170,0,111,0,42,0,207,0,104,1,188,0,167,254,113,254,255,253,23,255,138,2,166,1,81,0,133,253,63,252,60,251,207,1,27,2,204,0,209,0,202,0,231,255,62,255,14,254,237,252,193,0,113,255,63,254,230,253,195,0,150,255,181,254,68,0,62,0,28,255,35,254,184,252,192,253,61,1,128,0,27,1,97,253,87,252,217,252,142,255,135,1,79,1,194,255,246,0,2,0,198,254,89,253,209,254,180,0,168,255,149,255,240,254,90,0,58,255,228,255,34,1,144,255,117,3,125,4,253,3,200,2,240,1,25,1,173,255,13,1,236,1,19,3,131,2,91,1,70,0,124,0,80,1,124,2,243,1,92,0,27,255,77,255,191,0,26,0,146,1,52,2,84,1,149,0,245,255,135,0,72,254,49,2,214,1,204,0,184,255,70,255,140,0,48,253,14,0,99,1,229,0,68,0,123,255,209,1,110,0,54,1,103,0,12,0,106,0,29,0,158,0,78,255,113,0,161,0,142,0,121,0,115,0,27,0,117,253,98,254,123,253,104,255,92,255,243,255,83,254,129,253,80,252,87,253,152,255,175,255,52,0,67,255,105,253,92,255,196,254,85,253,70,252,51,255,173,255,159,253,99,253,84,255,251,253,74,253,27,1,176,255,122,253,104,255,129,254,90,253,10,255,216,255,113,255,21,253,228,252,23,253,122,254,158,255,43,0,19,1,169,253,57,255,114,254,79,254,76,254,230,253,31,0,173,251,200,253,136,254,247,254,130,255,235,255,1,0,79,3,61,2,52,1,136,1,49,1,101,0,55,0,17,1,37,1,201,0,11,1,90,1,201,0,123,0,215,2,224,1,226,0,2,0,191,255,118,255,164,0,17,1,208,0,173,0,36,1,12,0,253,0,174,0,84,1,207,0,180,0,88,0,116,0,46,0,219,1,52,254,90,255,226,255,13,0,110,0,173,0,140,1,137,0,88,0,43,0,119,255,162,255,34,0,28,1,96,0,242,255,226,0,40,0,63,0,70,0,130,0,45,254,33,253,12,252,106,251,205,254,49,1,189,255,156,253,104,252,134,251,201,253,248,255,92,0,231,255,74,255,241,254,20,254,14,253,167,252,31,1,181,255,18,254,237,252,79,253,85,253,59,253,137,0,186,254,224,254,218,253,121,252,175,251,78,1,65,1,194,255,158,254,115,253,190,252,67,254,1,0,121,1,104,255,94,255,206,254,160,253,87,252,215,254,247,0,64,255,22,255,35,254,12,255,24,254,246,254,86,1,180,254,169,0,142,0,137,255,115,0,206,0,236,255,94,0,226,0,150,255,57,1,235,255,16,0,194,255,161,0,71,0,255,0,167,255,101,0,71,255,125,0,72,0,226,255,55,255,88,1,254,254,33,0,248,255,81,0,152,255,102,255,72,0,40,1,144,0,188,255,244,254,231,255,81,0,178,255,169,255,106,0,22,0,155,0,70,255,137,255,210,255,228,255,27,0,91,0,142,255,219,255,81,255,223,255,162,255,34,255,67,255,122,0,124,255,137,255,65,255,242,254,84,255,83,255,18,0,213,255,23,1,135,0,214,255,128,255,187,0,170,255,229,0,118,255,159,0,240,0,140,0,46,0,69,0,25,0,227,0,77,0,21,0,115,0,13,0,8,0,68,0,8,255,126,0,81,0,106,255,137,0,207,0,247,255,102,255,123,255,33,1,67,0,143,0,219,255,170,255,186,254,180,0,224,255,19,0,233,255,26,0,168,0,116,0,23,255,224,255,230,255,118,0,178,255,3,0,248,255,211,255,141,255,57,0,41,255,202,255,173,255,47,255,112,0,234,255,89,255,165,255,105,255,168,0,250,254,177,255,167,255,252,255,85,255,77,0,45,255,160,0,63,255,98,0,120,0,153,255,67,1,32,0,234,255,127,255,72,0,78,0,244,254,182,0,180,255,190,255,53,1,99,0,111,255,27,255,99,255,172,255,129,254,98,0,185,255,166,255,160,254,12,0,228,254,78,255,178,0,191,255,131,255,90,255,169,255,81,255,161,254,42,0,58,255,208,255,154,0,116,255,13,255,179,255,18,0,108,0,217,255,99,1,91,0,87,0,8,0,155,0,252,255,158,0,239,0,128,0,95,0,202,255,7,0,246,0,132,255,2,1,15,0,89,0,206,0,216,0,98,0,55,255,9,0,18,0,200,254,233,0,204,0,217,255,82,255,155,0,112,255,247,255,28,1,199,255,70,0,187,255,99,255,187,0,18,0,54,0,226,255,23,0,24,0,135,0,55,0,81,0,238,255,68,0,229,255,134,255,232,254,252,255,45,0,79,255,209,0,226,255,120,255,182,255,131,0,212,255,101,0,181,255,168,255,208,255,119,255,202,255,11,255,228,255,63,0,238,255,144,255,153,255,58,0,177,255,250,255,220,0,191,255,114,0,221,255,206,255,109,0,191,255,143,0,142,255,129,0,76,0,125,0,166,0,90,0,195,255,14,255,186,0,182,255,213,255,210,255,164,255,49,0,29,255,24,0,101,255,39,0,67,0,85,0,99,0,214,255,53,0,72,255,231,254,142,0,134,255,0,0,21,0,114,255,241,255,239,255,223,0,92,0,235,255,208,255,174,255,242,255,89,255,51,0,219,255,13,255,226,255,166,255,18,0,200,255,54,0,105,0,74,0,86,0,69,0,13,0,155,255,196,0,72,0,167,255,43,0,65,0,19,0,39,0,121,0,34,0,131,0,174,255,25,0,213,0,100,255,101,0,154,255,120,255,235,255,57,0,214,0,22,0,36,0,132,255,205,0,204,0,58,0,100,255,173,255,83,0,139,255,137,0,137,0,85,0,116,0,44,0,164,255,108,255,188,255,11,0,154,255,59,255,36,255,180,255,71,255,198,255,132,0,230,255,73,255,85,0,249,255,225,255,254,255,23,0,205,0,105,255,10,0,229,255,219,255,251,255,238,255,36,1,131,0,1,0,117,0,88,255,9,0,163,255,80,0,197,255,131,255,74,255,12,255,98,0,232,255,135,0,234,255,94,0,221,0,97,0,106,0,42,0,43,0,96,255,83,0,25,0,192,255,235,255,6,0,14,0,241,255,154,0,126,0,15,0,116,255,150,0,246,255,49,255,142,255,79,0,193,255,45,255,186,255,228,255,39,255,165,0,46,0,38,0,234,255,25,1,132,0,194,255,109,0,112,0,54,0,144,255,163,255,208,0,27,0,40,1,115,0,10,0,109,255,41,0,216,0,42,0,236,254,50,0,141,255,2,255,167,0,117,0,254,255,61,0,17,0,144,0,34,0,184,255,70,255,106,255,16,1,227,255,190,255,167,255,161,255,107,255,129,0,251,0,122,0,0,0,206,255,22,255,165,255,36,0,26,0,151,255,154,255,168,255,135,255,20,255,249,255,245,255,52,255,109,0,5,0,65,255,105,0,241,255,163,0,176,255,32,0,232,255,47,255,41,0,38,1,70,0,150,255,162,255,52,255,138,255,120,0,206,255,219,255,174,255,15,255,46,0,125,255,227,255,150,0,201,255,33,0,155,0,120,0,167,255,248,255,7,0,62,0,213,0,82,0,61,0,18,0,95,255,144,0,152,0,30,0,131,0,65,0,169,255,1,255,239,255,149,255,248,255,85,0,192,255,51,0,94,255,223,0,203,255,122,255,5,1,69,0,200,255,218,0,72,0,145,255,2,0,155,0,143,255,169,255,49,0,85,0,228,255,93,255,42,0,255,255,60,255,7,0,39,0,11,255,14,0,119,255,177,255,11,0,96,255,202,0,219,254,162,255,33,0,208,0,100,0,56,0,212,255,70,1,178,255,215,255,232,0,13,0,114,255,227,0,80,0,240,255,169,255,201,0,33,0,123,255,15,0,73,255,198,255,64,255,209,255,184,0,128,255,133,0,99,0,51,255,11,0,101,255,78,0,52,0,72,0,141,0,10,255,26,0,99,0,151,0,59,0,115,0,192,255,177,255,209,255,240,255,242,255,6,0,47,0,213,255,184,255,78,255,229,255,162,0,112,0,43,0,82,255,81,255,238,0,186,0,71,0,202,255,68,255,180,255,31,255,233,0,39,0,217,255,98,255,122,0,44,0,230,255,43,0,84,0,130,0,163,255,205,255,22,0,3,0,92,0,106,255,136,0,74,255,199,255,97,0,125,255,179,0,178,255,80,0,91,0,91,255,90,0,254,255,148,0,15,0,130,0,65,0,175,0,117,0,118,255,114,0,119,255,132,0,3,0,246,255,70,255,140,0,252,255,219,255,254,0,194,255,92,0,147,255,246,255,151,0,103,1,136,0,42,1,223,0,255,0,152,255,34,1,167,1,6,0,183,0,242,254,243,254,158,255,204,255,174,255,13,0,174,255,238,254,159,255,90,0,10,255,184,255,213,254,186,255,165,1,168,255,109,1,174,1,187,0,194,254,125,1,124,1,37,0,232,1,139,254,196,254,79,0,204,254,155,255,5,0,121,255,61,254,8,0,72,0,91,254,102,255,180,0,170,0,135,255,62,0,177,0,216,255,70,1,80,0,151,255,248,0,7,1,251,255,88,255,75,255,35,255,254,255,233,255,98,255,242,255,107,255,135,255,119,0,165,255,109,255,119,0,76,1,103,255,49,0,47,1,34,0,186,1,201,255,187,255,217,0,198,1,58,0,153,254,69,255,137,254,214,255,50,0,238,254,248,255,245,254,7,255,85,0,170,255,166,254,179,255,216,255,89,1,89,0,134,0,219,0,156,0,176,255,160,0,108,0,40,0,116,0,98,255,50,255,29,0,5,0,224,255,175,0,191,255,98,255,146,0,55,0,178,255,73,0,142,255,34,255,97,1,209,255,81,0,211,0,49,0,105,255,12,1,105,0,4,0,46,1,249,254,124,255,183,0,105,255,228,255,201,0,79,255,205,254,166,0,101,0,35,255,130,0,74,0,58,0,158,255,32,0,44,0,13,0,194,0,30,0,114,255,170,0,96,0,8,0,120,255,137,255,165,255,191,255,8,0,201,255,3,0,68,255,12,0,45,0,193,255,207,255,149,0,235,255,237,255,24,0,144,0,95,0,254,0,234,255,60,0,161,0,196,0,96,0,98,255,195,255,48,0,186,255,33,0,82,0,233,255,191,254,58,0,155,0,109,255,5,0,148,254,72,1,77,0,235,255,197,1,173,0,148,255,82,0,118,2,111,1,7,1,208,0,212,254,194,255,80,255,51,255,143,0,98,255,87,255,102,254,248,254,1,1,243,254,156,255,132,253,33,1,254,255,220,254,115,2,173,0,130,254,149,254,131,1,248,0,12,2,191,1,247,253,145,255,149,255,117,254,118,0,238,254,169,254,88,253,131,255,84,255,65,254,105,253,75,0,148,0,145,254,177,255,7,1,162,255,249,0,148,0,226,254,124,1,15,1,94,255,114,255,252,255,70,255,199,255,111,0,131,255,221,255,148,255,2,255,100,0,29,0,14,255,176,255,47,1,248,254,178,255,208,1,199,255,248,0,234,255,18,254,149,2,150,2,44,0,63,255,216,255,182,254,78,255,145,0,175,254,166,255,57,255,112,254,216,255,233,255,14,254,64,255,114,0,59,1,215,255,244,0,190,0,88,0,159,255,229,1,241,0,80,0,212,0,10,255,40,0,87,0,100,255,147,0,134,0,254,255,178,254,239,0,52,1,53,255,110,0,53,254,251,0,166,1,38,255,54,1,228,0,170,255,166,254,142,2,184,0,175,0,169,1,31,254,193,255,169,0,163,254,117,0,188,0,131,255,208,253,54,1,158,0,96,254,94,0,46,0,171,0,64,255,193,255,157,0,14,0,0,1,221,255,241,254,66,1,123,0,53,0,42,255,4,0,180,255,100,255,86,0,238,255,128,0,59,255,24,255,9,1,166,255,158,255,204,254,76,1,111,255,125,255,52,1,58,0,253,1,59,0,173,254,50,2,196,0,242,255,134,254,100,0,209,255,22,255,202,0,1,0,104,0,242,254,19,254,63,1,46,255,187,254,214,254,250,255,95,0,31,0,43,255,169,255,134,255,5,1,4,0,207,255,208,0,14,0,127,255,146,255,30,0,118,0,42,255,2,1,110,0,21,255,215,255,238,255,130,255,120,0,103,0,65,0,127,0,219,255,126,0,220,255,232,255,25,0,118,255,189,255,234,254,70,255,92,255,62,255,55,255,78,0,45,255,169,255,205,255,35,255,82,255,177,255,162,255,217,255,23,0,250,255,99,255,16,255,22,0,146,255,103,255,188,255,148,0,251,255,254,255,107,255,255,255,121,255,217,255,77,255,68,0,104,1,139,255,241,255,137,0,47,0,234,254,146,0,136,0,4,1,135,0,65,0,61,0,116,0,211,255,97,0,231,0,123,1,87,0,136,255,82,1,177,0,240,254,3,0,10,1,156,0,28,0,187,255,4,1,84,0,171,255,86,0,246,254,154,0,0,255,74,255,239,255,191,255,208,254,250,255,216,255,175,0,105,255,76,255,229,255,27,0,169,255,193,255,121,0,114,0,90,255,43,254,159,0,190,255,189,254,25,255,214,0,152,0,115,255,44,255,137,0,36,0,72,255,205,255,230,254,19,255,40,0,10,0,208,255,21,255,219,255,251,0,202,255,189,254,136,0,29,0,168,255,82,255,213,0,198,0,122,254,99,0,193,255,137,254,107,0,87,255,92,255,168,1,69,0,145,255,141,0,89,255,74,0,127,255,65,0,144,0,159,254,49,255,51,255,147,255,96,255,126,254,157,254,98,0,80,255,19,254,236,255,113,255,4,255,80,254,254,255,216,0,166,255,82,255,88,255,101,254,13,0,228,254,27,255,96,255,169,255,233,254,34,0,5,255,181,255,249,254,198,255,214,255,164,1,53,0,45,255,154,254,128,1,221,255,138,254,140,1,68,0,28,255,67,1,254,255,167,0,205,254,192,0,194,0,203,1,73,1,251,255,180,254,119,1,79,0,249,255,57,1,26,1,132,255,200,0,164,255,15,1,94,255,186,255,180,0,99,255,214,254,254,253,203,254,58,0,93,255,222,253,18,0,124,0,148,254,167,0,18,255,83,0,101,254,139,255,96,0,140,0,144,255,124,254,144,253,3,1,123,255,195,254,41,0,163,0,126,255,192,255,178,254,226,0,91,255,132,255,146,255,46,254,195,255,6,0,229,0,103,255,205,0,111,255,242,0,97,255,48,0,195,0,148,0,198,255,28,0,31,0,23,1,209,254,185,0,23,1,252,255,195,255,197,0,59,0,86,0,142,255,123,0,168,0,204,255,35,0,36,0,100,0,126,0,105,254,102,0,179,255,216,255,174,254,255,255,170,254,156,0,77,255,105,0,222,255,159,255,71,255,84,0,221,255,108,0,123,255,107,0,165,255,155,254,76,255,54,0,27,255,24,0,212,255,47,0,47,0,74,255,190,255,13,0,45,0,4,0,173,254,251,0,64,0,226,0,214,255,101,0,162,254,19,1,157,255,142,1,142,0,121,0,111,0,12,0,154,255,4,1,0,0,249,1,4,1,162,255,161,0,29,1,160,255,224,0,252,255,206,0,58,1,33,0,167,0,139,0,88,0,204,0,21,255,60,1,196,255,231,255,248,255,106,255,200,254,201,0,220,255,36,1,61,0,152,255,216,255,174,0,94,255,42,0,235,255,146,1,227,255,161,254,21,0,152,0,152,254,163,255,57,0,191,0,212,0,60,255,76,0,158,0,235,255,187,255,184,254,71,255,75,1,119,0,203,255,29,1,56,0,81,1,149,255,232,255,149,1,29,0,238,255,137,0,16,1,21,1,1,255,22,0,173,0,65,255,39,1,66,1,69,1,46,1,21,0,229,255,76,1,78,255,119,0,13,0,15,1,129,0,57,254,76,255,116,0,65,255,29,255,62,0,108,255,12,2,80,255,225,254,26,1,99,255,13,255,13,0,199,0,174,1,197,255,207,255,115,0,147,254,72,0,84,255,119,255,93,0,118,255,130,255,141,0,172,255,5,0,132,255,38,0,236,255,254,254,55,1,89,2,213,0,94,0,130,0,195,255,246,1,255,255,99,255,229,1,57,1,146,0,182,255,158,0,89,1,20,1,135,0,24,1,199,255,234,1,252,0,99,0,43,0,11,1,182,255,173,1,105,0,22,1,233,255,119,0,94,0,226,253,232,1,1,1,141,255,172,255,12,255,74,254,222,1,143,255,223,253,131,1,101,0,161,255,206,254,111,0,242,1,95,0,166,0,22,0,211,254,164,1,241,255,198,255,178,255,14,1,29,0,122,0,230,254,160,0,16,255,50,0,218,255,129,255,54,1,42,0,14,255,197,0,5,0,105,255,84,0,239,255,42,255,127,0,107,255,9,255,125,255,159,0,244,254,245,254,161,255,39,255,1,0,177,255,241,254,176,255,71,255,211,255,180,1,159,0,165,0,199,0,135,1,223,255,81], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1358960);
/* memory initializer */ allocate([187,0,190,255,214,255,99,1,214,254,199,255,87,1,148,255,231,253,226,0,112,255,233,255,193,0,176,0,110,254,87,0,53,0,40,1,25,0,172,255,253,0,152,255,198,255,105,0,130,255,87,255,174,0,198,254,208,255,44,0,218,254,92,255,95,254,14,255,117,255,3,0,62,255,101,255,49,255,45,255,119,0,66,1,213,0,77,1,50,0,124,1,237,0,247,0,254,255,210,1,240,255,201,0,238,0,1,255,149,255,67,0,72,254,107,255,122,0,168,255,117,255,88,0,9,255,183,255,215,255,231,0,167,0,194,255,155,0,16,0,191,255,16,0,77,0,188,255,254,255,193,255,105,255,212,254,160,0,238,255,179,254,54,0,200,255,162,255,5,0,2,0,66,255,14,0,92,0,148,0,209,0,108,0,9,0,16,1,108,0,35,0,110,0,142,0,171,255,145,0,47,0,99,255,23,1,3,0,192,254,246,0,43,0,184,255,68,0,86,0,39,255,135,0,36,0,140,0,79,0,56,0,175,0,207,255,26,0,45,0,3,0,73,0,55,0,155,255,109,0,73,255,14,255,252,255,229,254,14,255,48,0,188,255,208,255,250,255,103,255,134,255,161,0,196,0,96,0,232,0,80,0,190,0,165,0,97,0,11,0,2,1,225,255,71,0,11,1,179,255,165,255,55,1,47,255,87,0,152,0,242,255,234,255,150,0,107,255,9,0,188,254,45,2,187,0,128,254,51,1,46,0,5,255,27,0,77,0,147,254,77,0,204,255,30,254,172,255,160,0,88,254,253,253,192,255,218,254,136,255,252,255,36,254,140,255,147,255,159,255,62,1,109,1,106,0,115,2,189,1,66,255,120,0,31,1,110,255,65,0,107,2,85,254,242,0,107,1,151,254,141,254,176,1,165,254,102,0,168,0,139,253,195,0,242,255,191,255,220,1,209,255,215,254,64,1,88,255,201,255,100,1,248,254,121,254,82,0,226,254,205,255,225,255,212,253,78,255,113,254,182,253,51,255,207,255,152,254,169,254,18,255,175,254,220,0,201,1,58,0,49,2,211,1,3,1,84,1,14,1,88,255,194,1,77,0,232,254,60,0,167,0,99,254,133,0,4,255,20,254,216,0,157,0,222,254,26,1,0,0,17,254,30,255,37,1,183,0,99,255,135,0,122,0,98,255,197,255,39,0,123,255,138,255,159,255,180,254,203,254,113,0,96,255,87,254,250,255,107,255,45,255,24,0,176,255,235,254,166,255,245,255,125,0,82,1,130,0,185,255,209,1,5,0,211,255,184,0,237,0,161,255,253,0,117,255,59,255,41,1,237,255,212,254,255,1,193,255,104,255,139,0,250,0,223,254,80,1,124,0,83,1,106,255,34,0,176,0,48,255,171,0,166,0,140,255,94,0,38,0,27,255,75,0,191,255,173,254,178,255,51,255,127,254,0,0,226,255,93,255,200,255,146,255,14,255,65,1,244,0,194,0,249,1,238,0,255,255,61,1,116,0,65,0,53,1,88,0,182,255,196,1,205,255,206,255,78,1,39,255,222,254,211,0,41,0,104,255,238,0,201,255,252,254,204,255,160,255,212,0,59,1,183,255,82,0,52,255,107,1,136,0,59,255,130,255,181,254,183,0,218,0,143,0,207,255,215,255,45,2,230,0,72,0,2,0,183,255,163,0,121,1,221,0,133,0,111,0,22,1,215,0,146,255,154,255,236,255,28,1,113,0,17,1,84,0,63,1,34,1,18,0,85,0,231,255,251,255,125,0,132,0,52,255,218,255,251,255,30,1,247,255,156,254,116,255,0,255,92,0,117,0,67,255,112,255,191,0,57,1,51,0,158,255,167,0,246,255,44,0,247,0,36,0,125,1,197,0,238,0,74,0,6,0,38,0,104,254,29,0,253,255,171,255,92,0,10,1,157,0,231,255,56,255,161,0,135,255,70,0,84,0,116,255,240,255,170,255,112,0,162,255,67,255,243,254,242,254,95,1,107,0,232,255,188,255,189,255,236,1,153,255,101,255,203,255,125,255,62,0,122,0,10,0,135,0,84,0,27,1,201,255,136,255,244,255,37,255,75,1,175,255,167,0,220,0,120,255,147,0,84,255,214,255,140,0,161,255,147,255,168,255,62,255,0,0,254,255,252,255,223,255,131,254,190,255,39,255,152,0,70,255,110,254,244,0,108,0,156,0,116,255,117,254,113,0,120,255,60,255,110,0,232,255,214,0,118,0,11,0,192,255,125,255,146,255,226,254,250,255,180,254,16,0,94,0,97,0,79,0,221,254,51,255,251,255,217,255,236,255,252,0,160,255,76,0,174,0,101,0,163,0,61,0,187,255,17,255,201,255,143,1,6,0,141,255,63,1,164,0,19,1,196,0,241,255,36,0,209,255,75,1,121,0,226,0,209,0,15,1,69,1,184,0,13,0,176,255,38,255,215,1,97,1,32,1,122,1,16,0,205,255,251,0,174,0,116,0,52,0,149,0,233,254,235,0,20,1,39,0,120,0,208,255,0,0,148,255,148,255,241,0,173,254,163,255,22,2,45,0,33,0,169,255,194,0,149,0,185,255,149,1,212,255,153,1,114,1,81,0,70,255,102,255,25,0,154,255,64,254,124,0,83,255,22,0,152,1,146,255,202,254,42,255,230,255,23,0,173,255,114,0,14,0,146,255,164,0,52,0,223,0,174,255,37,0,231,255,249,254,50,1,241,255,46,254,159,1,36,1,165,0,238,255,29,0,237,255,85,255,155,0,182,0,179,0,144,0,229,255,231,0,2,1,153,255,9,255,116,254,238,0,113,0,119,1,102,255,147,255,252,255,156,0,98,0,85,0,220,254,251,255,132,255,116,0,139,0,140,255,158,255,218,254,242,255,173,255,234,254,139,255,134,254,106,0,33,0,150,255,168,254,28,254,119,0,17,0,100,254,138,0,166,0,128,1,101,0,52,255,88,0,100,255,135,255,228,254,212,254,255,255,90,255,24,1,33,0,104,255,199,254,175,255,219,255,22,0,229,0,153,0,37,0,196,255,173,255,236,0,248,255,215,255,87,255,28,255,126,0,236,255,107,1,21,255,17,0,108,1,100,255,156,0,231,255,226,255,72,0,144,0,156,0,153,0,230,255,0,1,97,0,144,0,235,255,219,255,48,0,191,255,250,0,63,0,77,0,17,1,128,255,124,0,127,255,230,255,40,0,9,0,141,255,250,255,82,0,38,0,166,255,74,255,176,254,243,255,28,0,158,0,91,0,226,255,241,0,137,0,86,255,239,255,146,0,14,0,245,255,33,0,61,0,192,0,197,0,54,0,172,255,85,0,23,0,56,255,178,255,227,255,140,0,122,0,237,0,106,0,171,254,136,0,199,255,114,255,171,255,240,255,182,255,197,255,166,255,248,255,69,255,236,255,45,255,245,254,216,0,77,255,146,255,206,255,249,255,220,0,245,254,186,255,199,255,214,255,239,255,241,255,71,0,32,0,21,0,63,0,119,255,33,0,119,255,81,255,104,0,188,255,97,0,189,255,213,255,133,0,211,254,221,0,140,255,56,255,175,255,164,255,240,254,192,255,215,255,202,255,12,255,36,255,225,254,14,255,206,255,169,255,167,255,11,255,236,0,102,0,90,255,217,254,66,0,24,0,94,255,185,255,95,0,66,0,136,0,166,255,36,255,220,255,158,255,95,255,34,255,68,255,29,0,238,255,18,0,237,255,97,254,9,0,49,0,61,0,100,0,39,0,200,255,145,255,82,0,135,0,225,255,52,0,166,255,103,255,163,255,189,0,182,0,42,255,39,1,119,0,182,255,28,1,2,0,137,0,37,0,47,0,182,0,92,0,117,0,184,0,203,255,117,1,235,255,242,255,221,255,136,0,135,1,146,0,129,0,92,255,228,255,77,1,92,0,80,0,172,255,100,0,122,255,248,255,217,0,224,255,3,0,209,255,105,255,251,0,41,255,142,0,92,0,32,255,54,1,84,255,237,254,98,0,159,0,155,0,79,255,112,0,53,0,205,0,27,0,8,0,16,255,192,0,169,0,120,0,193,254,55,255,106,0,11,0,36,0,170,255,19,255,199,1,147,255,102,255,93,255,174,0,201,255,218,255,32,0,155,255,178,255,197,255,51,255,191,254,159,255,69,0,79,0,202,254,44,0,18,0,71,255,34,0,141,255,236,255,108,255,217,255,203,0,227,255,154,0,226,255,98,255,166,0,211,255,125,255,195,254,232,255,107,1,91,255,51,255,144,255,34,255,9,1,224,255,212,255,106,255,54,0,63,255,250,255,218,255,1,255,87,255,141,255,246,254,87,0,67,255,220,255,87,255,196,255,169,255,246,254,76,254,86,255,188,255,175,255,234,254,24,0,38,0,233,255,237,255,101,255,0,255,141,0,195,255,30,255,203,253,81,255,71,0,9,0,227,255,19,255,253,253,7,1,73,1,153,1,249,0,223,255,249,1,160,0,227,255,242,255,70,2,250,254,127,0,98,1,145,0,237,0,175,0,104,255,245,0,122,0,27,0,42,0,84,1,172,255,163,255,55,1,29,1,222,0,100,255,47,0,213,255,8,254,234,0,121,0,129,1,104,0,195,254,45,0,176,0,195,0,8,0,104,0,197,255,162,255,177,0,53,0,192,0,222,255,129,255,152,0,58,2,21,1,222,255,189,255,183,254,129,253,99,255,240,254,206,1,79,255,50,254,198,0,66,1,179,0,115,0,126,254,171,0,19,0,19,0,244,255,195,0,136,255,4,255,201,0,48,1,36,0,176,254,128,255,35,255,132,254,171,0,71,255,40,1,14,255,200,254,23,0,198,0,39,0,16,0,253,255,79,255,145,255,111,0,163,255,76,0,164,255,33,255,4,0,177,0,150,1,212,255,88,255,124,1,107,255,252,255,17,1,75,1,92,254,1,2,21,1,21,0,247,0,47,0,198,255,131,0,254,255,253,255,134,0,180,0,111,255,40,0,175,0,189,0,74,0,111,255,229,255,211,255,187,254,114,1,142,255,235,255,173,255,97,254,83,255,77,0,95,0,205,255,216,255,226,255,189,255,71,0,88,0,86,0,221,255,158,255,14,0,69,0,197,0,178,254,60,255,79,0,25,255,164,254,119,255,218,0,160,254,167,255,171,255,47,0,201,0,126,255,91,255,37,0,241,255,213,255,3,0,86,0,95,255,148,255,79,0,83,0,21,0,19,255,175,255,107,255,18,255,150,0,70,255,5,255,70,255,7,255,94,255,237,255,66,0,117,255,230,255,206,255,75,255,24,0,11,0,0,0,126,255,151,255,158,255,67,2,57,4,11,4,134,1,3,0,249,254,58,255,174,255,38,0,18,0,188,255,244,255,57,1,249,2,149,1,249,0,111,0,180,255,228,2,239,4,12,5,238,3,229,3,251,3,249,3,208,3,155,3,165,255,59,3,180,3,136,2,101,2,23,2,10,2,234,1,165,1,41,0,212,255,231,254,40,254,140,2,22,2,193,0,135,0,166,255,41,0,135,255,156,254,196,255,151,2,51,1,61,0,208,255,168,254,45,2,178,3,25,4,99,3,78,3,222,3,88,4,238,4,217,4,138,255,52,255,72,1,0,2,102,3,25,3,98,2,146,1,186,0,156,0,37,1,74,0,174,254,37,254,127,252,174,253,95,255,15,254,226,0,131,0,118,255,51,1,169,0,241,254,92,255,125,254,144,253,62,0,224,255,195,255,4,255,227,253,196,252,253,251,245,253,106,253,102,0,195,255,141,0,112,0,242,254,5,255,227,253,25,0,106,255,6,0,124,255,156,254,82,253,160,255,190,254,246,253,225,255,186,254,220,255,47,255,247,253,27,255,51,1,124,255,251,255,157,255,128,254,60,0,205,255,19,255,100,253,51,252,105,254,60,253,181,255,84,255,26,0,118,255,246,254,111,0,210,254,43,0,234,254,156,254,153,254,58,2,54,3,240,1,102,255,200,254,164,255,137,0,23,1,115,1,110,255,112,1,153,1,68,0,6,0,77,0,167,0,202,0,162,0,121,2,130,3,228,3,244,2,150,2,171,2,15,3,141,3,228,3,153,255,38,1,95,2,159,1,227,1,206,1,224,1,175,1,152,1,136,255,174,254,156,253,244,253,72,2,75,1,92,0,177,1,20,1,78,255,219,254,102,255,215,255,13,1,100,0,247,255,213,0,160,0,62,3,224,2,22,1,52,3,230,4,174,2,200,2,15,4,217,1,38,255,208,254,207,1,198,1,141,1,17,1,202,0,30,1,17,1,24,255,7,0,6,0,124,254,40,254,85,254,134,254,89,255,156,255,218,254,73,255,134,0,209,255,101,0,168,255,172,255,139,255,253,255,57,0,17,0,54,255,134,253,35,252,161,251,235,253,176,0,220,255,120,0,228,255,23,0,111,0,193,254,62,1,234,255,179,255,10,1,241,254,48,254,78,254,110,253,128,253,127,254,127,254,157,255,187,255,58,255,253,254,246,254,212,255,217,255,117,255,119,255,171,0,66,0,9,0,111,255,135,254,178,252,24,252,145,255,187,254,86,1,135,0,175,255,226,254,132,254,192,0,199,255,51,1,76,0,232,255,116,255,165,2,190,2,247,0,56,0,249,0,141,0,151,255,20,255,157,255,36,0,217,255,187,255,92,1,198,0,163,255,66,1,91,0,184,255,247,1,117,3,228,5,27,5,2,5,148,4,95,4,185,4,37,4,160,1,207,2,221,3,203,4,233,3,28,4,186,3,229,2,20,4,129,255,136,254,111,253,139,0,111,2,223,0,245,1,50,1,220,0,143,255,128,254,228,252,248,1,182,1,85,0,213,0,173,255,62,255,73,2,108,4,209,4,67,4,223,4,153,5,232,5,168,5,34,5,82,255,90,254,7,0,131,4,65,4,158,4,235,3,177,3,38,3,8,0,130,255,195,254,153,255,161,254,73,253,158,255,244,254,231,253,33,0,153,255,222,254,167,0,217,255,105,254,44,0,48,255,137,254,104,0,233,255,192,255,221,254,131,253,173,252,196,251,195,255,144,255,181,255,206,254,78,254,218,0,108,255,158,254,88,253,123,255,40,255,135,255,135,254,50,253,159,255,126,255,151,254,100,255,133,254,169,253,200,255,2,255,182,253,235,0,157,0,42,255,11,0,252,254,107,255,132,255,245,254,115,254,188,253,175,253,241,253,219,252,127,254,90,1,63,255,72,254,60,253,161,254,115,255,1,255,13,254,109,255,71,255,192,1,148,2,238,1,208,0,253,1,205,1,82,1,35,1,149,0,33,255,88,0,79,1,159,0,212,0,191,0,30,1,52,1,205,0,225,255,213,1,35,3,147,2,107,2,146,2,75,3,219,3,89,4,85,255,14,255,2,2,106,1,39,1,12,2,40,2,182,2,73,2,192,255,204,254,64,254,235,255,28,1,18,3,190,1,33,1,92,0,38,255,122,254,249,255,169,0,206,0,74,1,96,1,152,1,102,1,220,255,190,2,191,3,91,3,93,3,91,4,245,4,77,5,25,5,123,255,171,254,191,255,166,2,161,1,184,1,230,1,6,2,12,3,33,0,212,255,65,255,168,254,51,254,13,253,55,255,217,0,225,255,159,254,221,253,212,255,123,0,195,255,188,255,177,255,29,0,60,0,73,0,199,255,106,254,2,253,37,251,77,251,240,0,144,1,165,0,183,255,230,254,167,253,43,255,85,255,137,254,76,1,35,0,153,255,227,255,49,255,215,253,36,254,130,253,116,252,172,0,234,255,121,255,64,255,17,255,92,255,153,255,145,255,209,255,153,0,125,0,110,0,255,255,53,255,198,253,250,251,112,250,233,253,155,0,1,0,147,0,179,254,115,253,159,252,59,255,98,255,235,255,212,255,95,0,108,0,133,1,76,2,234,1,33,0,19,255,244,253,140,253,120,255,252,254,40,0,79,255,50,254,197,1,94,3,124,1,131,0,126,255,107,254,74,3,142,6,49,7,13,6,194,5,232,4,58,4,137,3,230,2,114,1,192,4,232,6,97,6,188,4,124,2,22,0,182,254,71,0,180,255,231,254,27,253,26,253,130,3,107,2,21,1,71,0,34,255,224,255,247,254,212,253,231,255,226,3,170,2,49,1,126,0,91,255,73,0,226,2,125,3,200,3,225,3,232,6,225,8,48,7,111,5,187,255,163,254,183,253,234,0,134,4,135,3,114,2,254,1,251,0,255,255,157,255,240,254,46,255,165,253,161,254,228,253,213,252,129,254,240,255,26,255,8,254,154,1,149,0,51,255,169,254,117,253,129,253,103,0,247,255,29,255,51,255,206,253,243,252,201,251,72,251,100,255,143,0,63,0,121,255,189,255,195,254,166,253,240,252,126,251,128,253,112,255,121,254,94,253,146,253,56,255,2,255,108,253,77,252,117,254,216,255,6,255,143,253,27,0,31,2,94,0,125,255,126,254,95,253,133,255,141,254,11,253,61,254,204,253,154,253,97,254,57,253,221,255,140,255,203,254,175,253,244,254,239,0,223,255,174,254,118,253,121,255,94,0,251,0,42,2,57,0,200,254,89,254,102,255,199,255,235,0,244,254,185,255,125,1,114,0,212,255,169,255,125,0,173,0,133,0,233,5,178,6,214,4,22,2,20,1,59,1,205,1,203,1,252,1,125,255,237,255,125,4,158,2,230,1,100,1,53,1,113,1,40,1,33,255,11,254,125,252,46,253,186,255,6,0,131,0,54,1,138,1,157,255,209,254,251,253,249,0,64,0,203,255,135,0,245,255,197,1,109,255,113,254,38,253,111,254,49,3,226,2,34,3,237,2,63,2,102,255,77,254,29,253,32,3,81,2,110,1,17,2,62,1,70,1,32,255,45,0,217,255,125,254,253,253,250,253,160,253,128,254,191,254,197,254,135,254,143,0,155,255,143,255,135,254,79,255,112,255,244,255,117,0,40,0,17,255,117,253,229,251,187,253,31,253,34,252,184,254,26,0,206,255,99,255,233,255,59,254,229,254,237,253,222,253,192,0,4,255,11,254,25,253,179,253,141,253,13,254,184,254,138,255,184,255,188,254,18,254,12,255,206,254,112,255,79,255,250,254,121,255,178,255,220,255,22,255,249,253,63,252,246,250,198,254,33,254,141,254,211,255,161,255,220,254,233,253,248,255,212,254,112,0,92,255,235,254,198,0,157,255,128,255,112,3,68,3,67,2,95,1,23,0,161,255,39,255,229,255,254,254,124,0,243,3,85,2,169,1,144,0,7,0,183,255,165,1,13,5,104,6,87,6,206,6,81,6,219,5,4,5,238,3,161,255,240,2,144,6,33,6,82,6,156,5,176,4,212,3,200,2,187,255,212,254,85,253,77,254,108,4,131,3,248,1,76,1,109,0,182,255,189,254,131,253,51,2,50,4,96,2,115,1,105,0,207,255,178,255,63,3,170,4,86,4,98,5,201,5,212,5,85,5,193,4,253,254,135,255,160,5,54,5,92,6,210,5,158,5,199,4,165,3,174,255,206,254,155,253,34,255,134,254,93,253,223,253,97,253,179,252,53,0,132,255,165,254,166,1,52,0,131,255,242,254,239,253,9,0,79,0,167,255,192,254,106,253,25,252,81,251,37,251,92,253,215,254,188,255,239,254,157,253,137,0,110,255,115,254,141,253,179,252,36,255,144,255,166,254,227,252,198,252,234,0,124,255,68,255,234,254,246,253,97,255,107,254,34,253,93,254,37,1,74,0,89,255,89,255,184,0,103,255,75,254,191,252,200,251,176,254,40,254,207,253,172,254,3,255,87,255,89,254,204,252,120,252,125,255,237,255,166,254,164,253,31,0,33,0,225,255,56,1,62,0,108,255,49,0,197,255,52,2,230,1,206,254,179,254,194,0,212,255,67,0,72,0,147,0,205,0,243,0,49,255,207,255,80,5,215,3,201,3,223,3,246,3,86,4,205,3,45,255,84,255,115,3,115,2,199,2,162,2,193,2,30,3,234,2,168,255,187,254,5,253,50,252,175,2,140,3,2,2,126,1,172,0,220,254,156,253,219,252,63,0,131,0,14,1,3,1,96,1,92,1,21,255,172,255,187,3,50,3,96,4,9,5,23,6,200,5,5,5,76,255,51,254,154,253,145,2,179,2,233,2,86,3,15,3,201,2,159,255,203,254,35,254,154,253,247,252,34,253,0,253,242,253,40,254,168,254,36,254,221,255,87,255,49,0,179,255,106,255,16,255,115,255,204,255,244,254,129,253,105,252,2,251,167,251,170,254,179,254,105,255,188,255,14,255,183,253,183,255,47,255,34,254,97,255,83,254,133,0,59,255,13,254,19,252,12,251,240,254,32,255,151,255,189,255,17,0,149,254,150,253,98,254,140,255,194,255,20,0,10,0,116,0,108,0,61,255,37,254,118,252,20,251,133,252,71,254,235,254,114,255,228,255,30,255,249,253,74,252,68,253,237,254,246,254,140,255,151,255,82,0,148,1,255,1,8,2,71,1,17,0,62,255,179,254,232,253,182,253,142,255,126,255,20,1,237,0,204,0,86,1,135,0,240,255,145,255,158,2,184,4,144,4,92,3,230,2,89,2,16,2,147,1,53,1,141,1,109,2,198,3,240,2,67,2,142,1,144,1,73,1,252,0,191,0,180,0,119,255,45,254,16,1,106,0,161,255,17,0,64,255,176,255,222,254,142,253,194,0,86,2,196,0,21,0,231,254,77,0,254,1,96,3,84,4,39,3,171,3,134,3,157,3,205,2,225,1,137,0,111,1,22,2,252,2,158,2,126,1,40,1,153,0,84,0,47,1,241,1,144,0,171,255,131,255,229,253,30,254,48,254,4,253,233,0,91,1,68,0,109,255,169,0,46,255,14,255,30,255,30,254,51,1,166,1,154,0,81,255,126,254,46,253,44,253,120,252,9,252,53,1,52,1,160,0,196,255,42,254,92,254,170,253,233,252,37,255,68,0,121,0,119,255,208,253,110,255,66,254,253,253,18,254,39,253,130,0,53,0,29,255,46,0,218,1,32,0,95,255,64,255,22,254,213,0,164,0,185,255,47,254,148,252,95,255,56,254,181,253,208,255,218,0,117,0,39,0,177,0,62,255,168,255,30,255,94,254,50,0,210,0,35,2,57,2,23,1,121,0,212,255,206,255,10,0,172,255,58,0,140,0,182,0,251,255,11,1,117,0,106,0,211,0,198,0,27,2,67,3,145,3,207,2,105,2,32,2,79,2,53,2,130,2,153,0,47,2,104,3,204,1,222,0,108,0,188,0,180,0,183,0,158,0,119,0,28,1,103,255,241,254,229,0,87,0,110,0,199,255,73,255,82,0,118,0,21,0,13,0,40,0,118,0,191,0,185,0,162,0,121,3,142,2,108,0,222,255,244,0,232,1,49,2,20,2,163,0,56,0,97,2,85,1,50,0,73,1,68,0,10,1,218,0,100,0,206,0,18,0,208,254,149,255,76,254,25,254,191,255,206,254,170,255,154,0,134,0,226,255,211,255,183,255,152,255,176,255,160,255,245,0,74,1,10,0,72,254,175,252,198,251,79,0,40,0,247,254,196,0,116,1,16,1,75,255,19,254,123,254,19,1,80,0,197,255,2,0,244,255,10,255,7,254,156,255,76,254,21,0,69,255,81,254,35,255,208,255,36,0,241,254,70,255,109,255,147,255,26,0,71,0,213,0,140,0,72,0,161,254,148,253,172,255,149,254,69,0,46,0,91,0,167,0,253,255,161,255,157,255,151,255,208,255,114,0,147,0,3,1,249,0,172,0,95,2,150,1,52,0,59,0,67,255,192,254,115,0,171,255,202,255,62,2,128,0,226,0,197,255,3,255,130,0,194,255,9,4,28,5,11,4,103,4,74,4,5,4,193,3,55,3,39,0,108,1,245,2,172,3,216,2,148,2,147,2,71,2,2,3,141,255,174,254,8,253,41,254,138,1,37,0,185,1,178,0,6,0,199,255,207,254,243,253,28,3,197,1,188,0,252,255,142,255,248,0,71,0,188,1,29,3,219,2,72,4,133,4,198,4,5,4,43,3,135,0,103,1,39,2,169,1,237,2,47,3,106,3,192,2,246,1,132,0,247,0,0,0,50,255,63,254,18,253,254,254,254,253,135,253,248,0,249,0,91,0,121,0,61,255,13,254,166,255,230,254,77,254,78,0,20,0,235,254,145,253,41,252,56,251,97,254,54,254,129,253,91,1,253,1,208,0,77,255,48,254,40,253,180,255,19,255,26,254,153,255,169,254,12,253,55,253,247,254,159,253,65,255,114,254,132,253,135,255,129,254,19,253,55,2,252,0,220,255,158,254,95,254,206,255,204,0,100,0,107,255,118,253,199,251,209,255,249,255,249,254,111,0,210,255,76,255,245,254,188,254,206,253,118,254,76,253,142,1,36,1,226,1,158,2,171,2,112,2,186,1,165,0,116,0,36,0,107,255,108,0,247,0,35,1,247,0,99,1,122,0,109,0,224,0,40,1,242,255,177,3,222,3,33,3,243,2,47,3,79,3,145,3,124,3,36,1,93,1,213,2,226,1,132,1,73,1,173,1,108,2,155,2,222,255,197,0,213,0,129,255,84,0,238,1,108,2,63,2,119,1,126,0,207,0,172,0,167,0,106,1,202,0,40,1,139,1,199,1,250,255,250,0,27,2,211,1,124,2,33,3,125,4,7,5,94,4,27,0,240,0,113,1,24,1,184,1,155,1,122,2,124,3,185,3,159,0,170,0,198,255,117,254,227,252,78,253,77,0,45,255,178,254,251,255,228,255,243,255,182,255,177,254,165,253,44,1,88,0,51,255,82,0,223,255,148,254,70,253,77,251,127,251,110,0,110,255,223,254,113,0,1,0,13,255,180,253,30,252,16,254,158,1,160,0,42,0,200,255,9,255,72,254,75,253,28,252,33,254,11,0,78,255,155,254,105,255,159,254,185,254,45,255,172,254,141,0,65,0,169,1,197,1,34,0,87,255,57,254,92,252,65,251,138,0,243,1,0,1,68,1,68,0,139,0,241,255,221,253,34,254,17,0,50,1,246,1,225,1,224,255,122,255,189,1,129,0,113,255,12,255,9,254,5,254,169,253,61,0,116,255,167,254,240,1,202,1,254,255,20,0,29,255,254,253,138,1,229,6,130,6,59,5,93,4,38,3,130,2,223,1,124,1,215,0,7,2,152,3,29,4,66,4,23,3,16,2,34,1,155,0,202,255,23,255,121,253,166,253,127,2,38,1,254,255,89,255,70,254,178,255,197,254,233,252,143,255,52,3,147,1,158,0,140,255,156,254,17,2,59,7,211,7,204,4,110,2,215,255,96,254,88,1,51,3,151,255,133,254,20,255,200,4,125,3,237,2,56,2,100,1,214,0,239,255,57,255,112,255,50,0,229,254,9,255,190,253,178,252,193,251,69,0,245,255,131,254,50,255,209,0,228,254,125,254,96,254,52,253,39,0,251,255,111,255,138,254,86,253,115,252,206,251,111,251,214,251,31,1,226,0,67,0,35,255,106,253,85,255,91,254,126,253,61,253,124,255,164,254,230,253,64,254,236,255,252,255,158,254,20,253,91,252,4,0,181,255,223,254,170,253,61,1,52,0,48,255,215,254,209,253,168,255,248,254,154,254,179,253,137,253,8,255,245,253,202,252,209,251,70,0,248,255,54,0,198,254,253,253,92,0,110,255,238,254,19,254,199,0,62,0,135,1,158,0,115,255,71,0,37,255,53,255,49,255,152,0,40,0,73,1,162,0,227,255,48,0,107,255,108,0,127,0,123,2,34,4,115,3,236,1,116,1,56,1,61,1,18,1,241,0,11,1,210,2,232,4,114,3,113,2,248,0,8,0,175,255,196,255,198,255,118,255,221,254,168,253,244,255,254,255,217,255,147,0,117,0,149,255,167,254,255,253,203,1,76,0,92,0,240,254,132,1,6,1,106,1,4,2,203,0,103,254,52,253,193,252,181,254,185,0,209,0,139,255,121,254,214,254,159,2,36,1,26,2,1,1,166,0,218,255,154,255,193,254,62,255,229,254,195,253,250,254,189,253,37,255,68,254,21,255,78,0,11,0,88,255,155,255,27,255,249,254,191,254,133,255,70,0,50,0,86,255,169,253,28,252,180,253,249,254,252,253,57,254,138,1,107,1,229,0,120,255,230,253,21,0,73,255,164,254,55,255,132,255,144,254,128,253,145,252,177,252,47,255,103,254,18,254,253,253,129,255,171,254,227,253,87,254,2,254,246,255,4,255,39,254,221,254,84,0,187,255,55,255,92,253,156,252,103,0,201,254,124,255,192,254,5,0,83,255,68,255,215,254,140,253,197,0,199,255,7,0,245,255,49,0,96,255,56,0,46,2,111,0,33,0,201,254,72,254,49,254,255,255,10,255,205,254,94,3,197,1,139,0,86,255,157,254,24,255,23,1,198,3,106,6,198,5,183,5,99,4,27,3,13,2,83,1,59,255,218,255,166,6,51,5,228,4,182,3,180,2,248,1,170,1,148,255,168,254,163,252,108,251,188,1,98,1,88,0,210,255,36,255,203,255,191,254,18,254,89,4,232,2,108,1,198,0,222,255,181,255,201,1,187,3,153,4,190,4,147,5,177,5,65,5,149,3,27,2,187,255,199,0,129,3,116,4,63,5,159,4,209,3,230,2,10,2,122,0,44,0,243,254,27,0,101,255,206,253,205,254,178,253,251,252,154,0,42,0,96,255,252,0,127,255,207,254,41,254,35,253,141,254,135,0,185,0,174,255,96,254,46,253,111,252,8,254,25,253,144,252,149,0,214,0,172,255,183,254,88,253,189,252,86,254,107,253,175,255,128,255,132,254,33,253,26,252,175,254,17,0,74,255,45,254,71,253,172,255,222,254,2,254,176,253,13,0,184,1,154,0,218,255,233,254,70,0,195,255,10,255,41,253,233,251,176,255,131,254,233,253,64,253,178,0,254,255,110,255,98,253,86,252,226,1,138,0,63,0,65,0,245,255,15,0,4,3,187,1,142,0,236,255,47,255,130,255,95,255,224,255,7,255,95,0,40,2,124,0,30,0,169,254,82,0,170,255,148,0,239,2,235,5,81,4,99,3,94,2,218,1,192,1,143,1,93,255,255,254,131,3,73,4,138,3,239,2,246,1,134,1,38,1,205,255,254,254,65,254,218,252,144,254,251,2,208,1,108,1,183,0,90,255,138,254,145,254,87,0,35,0,143,1,162,1,88,3,65,3,51,255,202,254,76,2,10,3,17,3,41,4,94,4,221,4,133,4,83,255,200,254,107,0,89,1,144,1,22,3,102,3,89,4,233,3,249,255,136,255,125,254,102,254,154,253,81,252,30,255,128,254,21,254,53,255,224,254,205,255,181,254,166,255,78,255,104,254,195,253,174,254,56,0,227,255,239,254,141,253,239,251,226,252,9,255,45,254,148,0,66,0,254,255,51,255,51,255,193,253,163,254,199,255,160,254,198,255,211,255,31,255,41,254,100,252,15,254,77,0,224,255,44,0,121,255,235,254,21,254,15,254,10,254,88,254,54,255,119,255,77,0,96,0,26,0,77,255,43,254,16,252,20,251,6,1,221,255,124,255,253,254,190,255,24,255,65,254,235,253,235,252,65,255,156,255,245,254,108,1,0,2,5,9,14,20,27,35,1,4,8,13,19,26,34,42,3,7,12,18,25,33,41,48,6,11,17,24,32,40,47,53,10,16,23,31,39,46,52,57,15,22,30,38,45,51,56,60,21,29,37,44,50,55,59,62,28,36,43,49,54,58,61,63,0,2,5,9,1,4,8,12,3,7,11,14,6,10,13,15,0,2,1,3,0,0,0,0,24,88,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,130,29,0,8,41,29,0,80,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,24,217,28,0,0,212,35,0,84,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,208,9,32,0,136,132,35,0,72,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,104,38,35,0,72,224,34,0,76,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,184,162,34,0,8,41,29,0,8,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,64,16,0,1,0,0,0,0,0,160,102,34,0,0,212,35,0,12,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,64,16,0,1,0,0,0,0,0,104,47,34,0,56,0,34,0,16,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,104,47,34,0,56,210,33,0,184,172,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,104,47,34,0,176,141,33,0,48,107,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,104,47,34,0,104,41,33,0,240,3,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,104,47,34,0,48,233,32,0,136,206,32,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,104,47,34,0,144,179,32,0,32,158,32,0,20,0,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,96,64,16,0,1,0,0,0,0,0,48,132,32,0,72,107,32,0,24,0,0,0,1,0,0,0,125,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,168,85,32,0,24,61,32,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,184,5,32,0,136,237,31,0,224,216,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,184,5,32,0,224,198,31,0,136,176,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,184,5,32,0,56,158,31,0,160,139,31,0,88,5,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,80,123,31,0,120,108,31,0,92,5,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,88,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,3,0,0,0,0,0,0,0,0,0,0,254,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,86,33,0,108,0,0,0,136,0,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,15,13,19,24,31,28,17,17,23,25,31,36,63,45,21,18,24,27,37,52,59,49,20,16,28,34,40,60,80,51,20,18,31,48,66,68,86,56,21,19,38,56,59,64,64,48,20,27,48,55,55,56,51,35,15,20,35,34,32,31,22,15,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,205,0,0,0,154,0,0,0,102,0,0,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,0,0,0,102,0,0,0,154,0,0,0,205,0,0,0,0,1,0,0,238,0,0,0,219,0,0,0,201,0,0,0,183,0,0,0,165,0,0,0,146,0,0,0,128,0,0,0,110,0,0,0,91,0,0,0,73,0,0,0,55,0,0,0,37,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,37,0,0,0,55,0,0,0,73,0,0,0,91,0,0,0,110,0,0,0,128,0,0,0,146,0,0,0,165,0,0,0,183,0,0,0,201,0,0,0,219,0,0,0,238,0,0,0,0,1,0,0,228,0,0,0,199,0,0,0,171,0,0,0,142,0,0,0,114,0,0,0,85,0,0,0,57,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,0,0,0,85,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,0,0,0,171,0,0,0,0,1,0,0,171,0,0,0,85,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,0,0,0,171,0,0,0,0,1,0,0,219,0,0,0,183,0,0,0,146,0,0,0,110,0,0,0,73,0,0,0,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,0,0,0,73,0,0,0,110,0,0,0,146,0,0,0,183,0,0,0,219,0,0,0,0,1,0,0,228,0,0,0,199,0,0,0,171,0,0,0,142,0,0,0,114,0,0,0,85,0,0,0,57,0,0,0,28], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1369200);
/* memory initializer */ allocate([28,0,0,0,57,0,0,0,85,0,0,0,114,0,0,0,142,0,0,0,171,0,0,0,199,0,0,0,228,0,0,0,0,1,0,0,213,0,0,0,171,0,0,0,128,0,0,0,85,0,0,0,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,0,0,0,85,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,0,0,0,171,0,0,0,0,1,0,0,192,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,205,0,0,0,154,0,0,0,102,0,0,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,0,0,0,102,0,0,0,154,0,0,0,205,0,0,0,0,1,0,0,213,0,0,0,171,0,0,0,128,0,0,0,85,0,0,0,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,0,0,0,85,0,0,0,128,0,0,0,171,0,0,0,213,0,0,0,0,1,0,0,213,0,0,0,171,0,0,0,128,0,0,0,85,0,0,0,43,0,0,0,14,14,14,14,14,14,14,14,13,13,13,13,13,13,13,13,13,12,12,12,12,12,12,12,11,11,11,11,11,11,11,11,11,10,10,10,10,10,10,10,10,9,9,9,9,9,9,9,9,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,0,128,221,140,56,152,255,165,5,181,103,197,141,216,8,236,164,128,150,139,56,152,255,165,97,180,103,197,69,215,29,234,255,255,150,139,56,152,81,166,5,181,185,197,243,214,193,234,41,128,150,139,56,152,214,165,46,181,144,197,69,215,152,234,255,255,150,139,56,152,255,165,240,180,83,197,69,215,172,234,255,255,160,139,56,152,255,165,5,181,103,197,59,215,183,234,255,255,150,139,61,152,4,166,5,181,103,197,69,215,193,234,3,128,150,139,53,152,1,166,5,181,103,197,69,215,195,234,0,1,64,0,32,0,32,0,3,217,76,0,56,96,117,63,0,253,65,181,0,247,87,63,203,180,79,23,32,132,79,63,156,18,208,170,91,142,82,63,134,237,4,145,168,170,229,191,147,158,42,93,17,202,200,191,11,217,146,148,88,238,186,191,11,70,69,218,202,21,199,191,31,133,107,191,0,0,0,0,31,133,107,63,10,215,99,191,0,0,0,0,10,215,99,63,0,3,4,3,3,1,5,1,4,5,2,5,3,1,5,1,20,18,32,19,25,24,22,19,35,21,28,26,26,23,42,24,33,31,28,25,45,26,35,33,32,28,51,30,40,38,36,32,58,34,46,43,0,0,0,0,10,13,16,11,14,18,13,16,20,14,18,23,16,20,25,18,23,29,0,0,0,0,0,0,56,176,29,0,108,0,0,0,176,74,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,78,30,0,108,0,0,0,128,86,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,210,30,0,108,0,0,0,80,89,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,101,31,0,200,58,31,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,254,253,253,253,6,6,6,6,250,249,249,249,12,12,12,12,244,243,243,243,20,20,20,20,236,235,235,235,32,32,32,32,224,223,223,223,46,46,46,46,210,209,209,209,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,254,253,6,6,250,249,12,12,244,243,20,20,236,235,32,32,224,223,46,46,210,209,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,252,251,4,4,0,0,252,251,255,255,4,4,4,4,252,251,251,251,12,12,12,12,244,243,243,243,0,0,12,12,0,0,244,243,12,12,0,0,244,243,255,255,248,247,7,8,8,8,248,247,8,8,240,239,248,247,15,16,0,0,232,231,0,0,24,24,232,231,247,247,24,24,248,247,232,231,7,8,24,24,8,8,20,20,240,239,236,235,15,16,228,227,255,255,28,28,0,0,240,239,231,231,16,16,232,231,240,239,23,24,16,16,24,24,0,0,224,223,0,0,32,32,228,227,239,239,28,28,240,239,228,227,15,16,28,28,16,16,248,247,223,223,8,8,224,223,224,223,247,247,32,32,248,247,224,223,7,8,32,32,8,8,248,247,31,32,8,8,32,32,24,24,24,24,232,231,231,231,24,24,232,231,232,231,23,24,236,235,223,223,20,20,32,32,216,215,255,255,40,40,0,0,216,215,239,239,40,40,16,16,0,0,212,211,0,0,212,211,212,211,255,255,44,44,0,0,0,0,44,44,0,0,44,44,224,223,223,223,32,32,32,32,240,239,211,211,16,16,44,44,232,231,211,211,212,211,231,231,44,44,24,24,24,24,44,44,208,207,239,239,48,48,16,16,220,219,219,219,220,219,219,219,36,36,36,36,36,36,36,36,236,235,203,203,40,40,40,40,216,215,215,215,224,223,203,203,0,0,0,0,0,0,0,4,0,252,4,0,252,255,4,4,252,251,12,12,244,243,0,12,0,244,12,0,244,255,248,7,8,248,8,240,248,15,0,232,0,24,232,247,24,248,232,7,24,8,20,240,236,15,228,255,28,0,240,231,16,232,240,23,16,24,0,224,0,32,228,239,28,240,228,15,28,16,248,223,8,224,224,247,32,248,224,7,32,8,248,31,8,32,24,24,232,231,24,232,232,23,236,223,20,32,216,255,40,0,216,239,40,16,0,212,0,212,212,255,44,0,0,44,0,44,224,223,32,32,240,211,16,44,232,211,212,231,44,24,24,44,208,239,48,16,220,219,220,219,36,36,36,36,236,203,40,40,216,215,224,203,0,0,0,0,0,0,0,0,2,2,0,0,254,253,2,2,0,0,254,253,255,255,4,4,4,4,252,251,251,251,10,10,10,10,246,245,245,245,0,0,10,10,0,0,246,245,10,10,0,0,246,245,255,255,250,249,5,6,6,6,250,249,14,14,248,247,242,241,7,8,238,237,255,255,18,18,0,0,10,10,240,239,246,245,15,16,0,0,232,231,0,0,24,24,232,231,247,247,24,24,248,247,232,231,7,8,24,24,8,8,18,18,18,18,238,237,237,237,20,20,240,239,236,235,15,16,242,241,229,229,14,14,230,229,242,241,25,26,14,14,26,26,226,225,255,255,30,30,0,0,0,0,222,221,0,0,34,34,222,221,247,247,34,34,248,247,222,221,7,8,34,34,8,8,226,225,237,237,30,30,238,237,226,225,17,18,30,30,18,18,246,245,221,221,10,10,222,221,246,245,33,34,10,10,34,34,236,235,221,221,20,20,34,34,216,215,255,255,40,40,0,0,30,30,30,30,226,225,225,225,216,215,237,237,40,40,18,18,0,0,212,211,0,0,44,44,240,239,211,211,16,16,44,44,220,219,219,219,220,219,219,219,36,36,36,36,230,229,211,211,26,26,44,44,210,209,229,229,46,46,26,26,204,203,237,237,52,52,18,18,236,235,201,201,212,211,211,211,44,44,44,44,224,223,201,201,210,209,209,209,210,209,209,209,46,46,46,46,0,0,0,0,0,0,0,2,0,254,2,0,254,255,4,4,252,251,10,10,246,245,0,10,0,246,10,0,246,255,250,5,6,250,14,248,242,7,238,255,18,0,10,240,246,15,0,232,0,24,232,247,24,248,232,7,24,8,18,18,238,237,20,240,236,15,242,229,14,230,242,25,14,26,226,255,30,0,0,222,0,34,222,247,34,248,222,7,34,8,226,237,30,238,226,17,30,18,246,221,10,222,246,33,10,34,236,221,20,34,216,255,40,0,30,30,226,225,216,237,40,18,0,212,0,44,240,211,16,44,220,219,220,219,36,36,230,211,26,44,210,229,46,26,204,237,52,18,236,201,212,211,44,44,224,201,210,209,210,209,46,46,0,0,0,0,0,0,0,0,2,2,0,0,254,253,2,2,0,0,254,253,255,255,2,2,2,2,254,253,253,253,6,6,6,6,250,249,249,249,0,0,6,6,0,0,250,249,6,6,0,0,250,249,255,255,252,251,3,4,4,4,252,251,10,10,250,249,246,245,5,6,0,0,244,243,0,0,12,12,250,249,243,243,6,6,244,243,250,249,11,12,6,6,12,12,242,241,255,255,14,14,0,0,12,12,12,12,244,243,243,243,0,0,238,237,0,0,18,18,14,14,244,243,242,241,11,12,238,237,249,249,18,18,250,249,238,237,5,6,18,18,6,6,246,245,237,237,10,10,238,237,246,245,17,18,10,10,18,18,234,233,255,255,22,22,0,0,0,0,232,231,0,0,24,24,234,233,243,243,22,22,244,243,234,233,11,12,22,22,12,12,248,247,231,231,8,8,232,231,248,247,23,24,8,8,24,24,230,229,249,249,26,26,250,249,230,229,5,6,26,26,6,6,228,227,255,255,28,28,0,0,20,20,20,20,236,235,235,235,242,241,229,229,14,14,26,26,226,225,243,243,30,30,12,12,246,245,223,223,10,10,32,32,238,237,223,223,18,18,32,32,230,229,229,229,26,26,26,26,222,221,235,235,34,34,20,20,218,217,243,243,38,38,12,12,224,223,223,223,32,32,32,32,32,32,32,32,234,233,215,215,222,221,221,221,34,34,34,34,0,0,0,0,0,0,0,2,0,254,2,0,254,255,2,2,254,253,6,6,250,249,0,6,0,250,6,0,250,255,252,3,4,252,10,250,246,5,0,244,0,12,250,243,6,244,250,11,6,12,242,255,14,0,12,12,244,243,0,238,0,18,14,244,242,11,238,249,18,250,238,5,18,6,246,237,10,238,246,17,10,18,234,255,22,0,0,232,0,24,234,243,22,244,234,11,22,12,248,231,8,232,248,23,8,24,230,249,26,250,230,5,26,6,228,255,28,0,20,20,236,235,242,229,14,26,226,243,30,12,246,223,10,32,238,223,18,32,230,229,26,26,222,235,34,20,218,243,38,12,224,223,32,32,32,32,234,215,222,221,34,34,0,0,0,0,0,0,2,2,2,2,254,253,253,253,0,0,3,3,0,0,253,252,3,3,0,0,253,252,255,255,6,6,6,6,250,249,249,249,0,0,7,7,0,0,249,248,7,7,0,0,249,248,255,255,251,250,4,5,5,5,251,250,5,5,251,250,251,250,4,5,6,6,11,11,250,249,244,244,11,11,6,6,245,244,249,249,0,0,8,8,0,0,248,247,8,8,0,0,248,247,255,255,11,11,11,11,245,244,244,244,0,0,12,12,0,0,244,243,12,12,0,0,244,243,255,255,12,12,17,17,244,243,238,238,17,17,12,12,239,238,243,243,17,17,17,17,239,238,238,238,6,6,18,18,250,249,237,237,18,18,6,6,238,237,249,249,248,247,10,11,8,8,245,244,11,11,248,247,245,244,7,8,0,0,15,15,0,0,241,240,15,15,0,0,241,240,255,255,0,0,20,20,0,0,236,235,20,20,0,0,236,235,255,255,18,18,25,25,238,237,230,230,25,25,18,18,231,230,237,237,11,11,25,25,245,244,230,230,25,25,11,11,231,230,244,244,25,25,25,25,231,230,230,230,242,241,13,14,14,14,242,241,14,14,242,241,242,241,13,14,0,0,26,26,0,0,230,229,26,26,0,0,230,229,255,255,245,244,17,18,11,11,238,237,18,18,245,244,238,237,10,11,249,248,21,22,7,7,234,233,22,22,249,248,234,233,6,7,26,26,34,34,230,229,221,221,34,34,26,26,222,221,229,229,18,18,34,34,238,237,221,221,34,34,18,18,222,221,237,237,34,34,34,34,222,221,221,221,11,11,35,35,245,244,220,220,35,35,11,11,221,220,244,244,0,0,29,29,0,0,227,226,29,29,0,0,227,226,255,255,237,236,21,22,19,19,234,233,22,22,237,236,234,233,18,19,241,240,25,26,15,15,230,229,26,26,241,240,230,229,14,15,0,0,37,37,0,0,219,218,37,37,0,0,219,218,255,255,27,27,44,44,229,228,211,211,44,44,27,27,212,211,228,228,36,36,44,44,220,219,211,211,44,44,36,36,212,211,219,219,18,18,44,44,238,237,211,211,44,44,18,18,212,211,237,237,246,245,32,33,10,10,223,222,33,33,246,245,223,222,9,10,45,45,45,45,211,210,210,210,0,0,0,0,0,0,2,2,254,253,0,3,0,253,3,0,253,255,6,6,250,249,0,7,0,249,7,0,249,255,251,4,5,251,5,251,251,4,6,11,250,244,11,6,245,249,0,8,0,248,8,0,248,255,11,11,245,244,0,12,0,244,12,0,244,255,12,17,244,238,17,12,239,243,17,17,239,238,6,18,250,237,18,6,238,249,248,10,8,245,11,248,245,7,0,15,0,241,15,0,241,255,0,20,0,236,20,0,236,255,18,25,238,230,25,18,231,237,11,25,245,230,25,11,231,244,25,25,231,230,242,13,14,242,14,242,242,13,0,26,0,230,26,0,230,255,245,17,11,238,18,245,238,10,249,21,7,234,22,249,234,6,26,34,230,221,34,26,222,229,18,34,238,221,34,18,222,237,34,34,222,221,11,35,245,220,35,11,221,244,0,29,0,227,29,0,227,255,237,21,19,234,22,237,234,18,241,25,15,230,26,241,230,14,0,37,0,219,37,0,219,255,27,44,229,211,44,27,212,228,36,44,220,211,44,36,212,219,18,44,238,211,44,18,212,237,246,32,10,223,33,246,223,9,45,45,211,210,0,0,0,0,0,0,9,9,9,9,247,246,246,246,0,0,9,9,0,0,247,246,9,9,0,0,247,246,255,255,18,18,18,18,238,237,237,237,9,9,27,27,247,246,228,228,27,27,9,9,229,228,246,246,238,237,17,18,18,18,238,237,247,246,26,27,9,9,229,228,27,27,247,246,229,228,8,9,18,18,36,36,238,237,219,219,36,36,18,18,220,219,237,237,36,36,36,36,220,219,219,219,0,0,45,45,0,0,211,210,45,45,0,0,211,210,255,255,229,228,35,36,27,27,220,219,36,36,229,228,220,219,26,27,45,45,72,72,211,210,183,183,72,72,45,45,184,183,210,210,238,237,53,54,18,18,202,201,54,54,238,237,202,201,17,18,18,18,72,72,238,237,183,183,72,72,18,18,184,183,237,237,72,72,72,72,184,183,183,183,0,0,81,81,0,0,175,174,81,81,0,0,175,174,255,255,202,201,53,54,54,54,202,201,220,219,71,72,36,36,184,183,72,72,220,219,184,183,35,36,45,45,117,117,211,210,138,138,117,117,45,45,139,138,210,210,81,81,126,126,175,174,129,129,126,126,81,81,130,129,174,174,229,228,98,99,27,27,157,156,99,99,229,228,157,156,26,27,175,174,98,99,81,81,157,156,99,99,175,174,157,156,80,81,54,54,54,54,202,201,201,201,108,108,108,108,148,147,147,147,0,0,0,0,0,0,9,9,247,246,0,9,0,247,9,0,247,255,18,18,238,237,9,27,247,228,27,9,229,246,238,17,18,238,247,26,9,229,27,247,229,8,18,36,238,219,36,18,220,237,36,36,220,219,0,45,0,211,45,0,211,255,229,35,27,220,36,229,220,26,45,72,211,183,72,45,184,210,238,53,18,202,54,238,202,17,18,72,238,183,72,18,184,237,72,72,184,183,0,81,0,175,81,0,175,255,202,53,54,202,220,71,36,184,72,220,184,35,45,117,211,138,117,45,139,210,81,126,175,129,126,81,130,174,229,98,27,157,99,229,157,26,175,98,81,157,99,175,157,80,54,54,202,201,108,108,148,147,0,0,0,0,0,0,0,0,0,0,8,8,8,8,248,247,247,247,0,0,8,8,0,0,248,247,8,8,0,0,248,247,255,255,16,16,16,16,240,239,239,239,8,8,16,16,248,247,239,239,16,16,8,8,240,239,247,247,240,239,15,16,16,16,240,239,248,247,23,24,8,8,232,231,24,24,248,247,232,231,7,8,16,16,32,32,240,239,223,223,32,32,16,16,224,223,239,239,32,32,32,32,224,223,223,223,0,0,40,40,0,0,216,215,40,40,0,0,216,215,255,255,232,231,31,32,24,24,224,223,32,32,232,231,224,223,23,24,40,40,64,64,216,215,191,191,64,64,40,40,192,191,215,215,240,239,47,48,16,16,208,207,48,48,240,239,208,207,15,16,16,16,64,64,240,239,191,191,64,64,16,16,192,191,239,239,64,64,64,64,192,191,191,191,0,0,72,72,0,0,184,183,72,72,0,0,184,183,255,255,208,207,47,48,48,48,208,207,224,223,63,64,32,32,192,191,64,64,224,223,192,191,31,32,40,40,104,104,216,215,151,151,104,104,40,40,152,151,215,215,72,72,112,112,184,183,143,143,112,112,72,72,144,143,183,183,232,231,87,88,24,24,168,167,88,88,232,231,168,167,23,24,16,16,112,112,240,239,143,143,112,112,16,16,144,143,239,239,120,120,120,120,136,135,135,135,184,183,87,88,72,72,168,167,88,88,184,183,168,167,71,72,200,199,119,120,56,56,136,135,120,120,200,199,136,135,55,56,48,48,48,48,208,207,207,207,88,88,88,88,168,167,167,167,0,0,0,0,0,0,8,8,248,247,0,8,0,248,8,0,248,255,16,16,240,239,8,16,248,239,16,8,240,247,240,15,16,240,248,23,8,232,24,248,232,7,16,32,240,223,32,16,224,239,32,32,224,223,0,40,0,216,40,0,216,255,232,31,24,224,32,232,224,23,40,64,216,191,64,40,192,215,240,47,16,208,48,240,208,15,16,64,240,191,64,16,192,239,64,64,192,191,0,72,0,184,72,0,184,255,208,47,48,208,224,63,32,192,64,224,192,31,40,104,216,151,104,40,152,215,72,112,184,143,112,72,144,183,232,87,24,168,88,232,168,23,16,112,240,143,112,16,144,239,120,120,136,135,184,87,72,168,88,184,168,71,200,119,56,136,120,200,136,55,48,48,208,207,88,88,168,167,0,0,0,0,0,0,7,7,7,7,249,248,248,248,0,0,7,7,0,0,249,248,7,7,0,0,249,248,255,255,14,14,14,14,242,241,241,241,7,7,21,21,249,248,234,234,21,21,7,7,235,234,248,248,242,241,13,14,14,14,242,241,249,248,20,21,7,7,235,234,21,21,249,248,235,234,6,7,14,14,28,28,242,241,227,227,28,28,14,14,228,227,241,241,28,28,28,28,228,227,227,227,0,0,35,35,0,0,221,220,35,35,0,0,221,220,255,255,235,234,27,28,21,21,228,227,28,28,235,234,228,227,20,21,35,35,56,56,221,220,199,199,56,56,35,35,200,199,220,220,242,241,41,42,14,14,214,213,42,42,242,241,214,213,13,14,14,14,56,56,242,241,199,199,56,56,14,14,200,199,241,241,56,56,56,56,200,199,199,199,0,0,63,63,0,0,193,192,63,63,0,0,193,192,255,255,214,213,41,42,42,42,214,213,228,227,55,56,28,28,200,199,56,56,228,227,200,199,27,28,35,35,91,91,221,220,164,164,91,91,35,35,165,164,220,220,63,63,98,98,193,192,157,157,98,98,63,63,158,157,192,192,235,234,76,77,21,21,179,178,77,77,235,234,179,178,20,21,14,14,98,98,242,241,157,157,98,98,14,14,158,157,241,241,105,105,105,105,151,150,150,150,249,248,118,119,7,7,137,136,119,119,249,248,137,136,6,7,193,192,76,77,63,63,179,178,77,77,193,192,179,178,62,63,207,206,104,105,49,49,151,150,105,105,207,206,151,150,48,49,137,136,118,119,119,119,137,136,42,42,42,42,214,213,213,213,77,77,77,77,179,178,178,178,0,0,0,0,0,0,7,7,249,248,0,7,0,249,7,0,249,255,14,14,242,241,7,21,249,234,21,7,235,248,242,13,14,242,249,20,7,235,21,249,235,6,14,28,242,227,28,14,228,241,28,28,228,227,0,35,0,221,35,0,221,255,235,27,21,228,28,235,228,20,35,56,221,199,56,35,200,220,242,41,14,214,42,242,214,13,14,56,242,199,56,14,200,241,56,56,200,199,0,63,0,193,63,0,193,255,214,41,42,214,228,55,28,200,56,228,200,27,35,91,221,164,91,35,165,220,63,98,193,157,98,63,158,192,235,76,21,179,77,235,179,20,14,98,242,157,98,14,158,241,105,105,151,150,249,118,7,137,119,249,137,6,193,76,63,179,77,193,179,62,207,104,49,151,105,207,151,48,137,118,119,137,42,42,214,213,77,77,179,178,0,0,0,0,0,0,0,0,0,0,6,6,6,6,250,249,249,249,0,0,6,6,0,0,250,249,6,6,0,0,250,249,255,255,12,12,12,12,244,243,243,243,6,6,12,12,250,249,243,243,12,12,6,6,244,243,249,249,244,243,11,12,12,12,244,243,250,249,17,18,6,6,238,237,18,18,250,249,238,237,5,6,12,12,24,24,244,243,231,231,24,24,12,12,232,231,243,243,24,24,24,24,232,231,231,231,0,0,30,30,0,0,226,225,30,30,0,0,226,225,255,255,238,237,23,24,18,18,232,231,24,24,238,237,232,231,17,18,30,30,48,48,226,225,207,207,48,48,30,30,208,207,225,225,250,249,35,36,6,6,220,219,36,36,250,249,220,219,5,6,12,12,48,48,244,243,207,207,48,48,12,12,208,207,243,243,48,48,48,48,208,207,207,207,0,0,54,54,0,0,202,201,54,54,0,0,202,201,255,255,220,219,35,36,36,36,220,219,232,231,47,48,24,24,208,207,48,48,232,231,208,207,23,24,30,30,78,78,226,225,177,177,78,78,30,30,178,177,225,225,54,54,84,84,202,201,171,171,84,84,54,54,172,171,201,201,238,237,65,66,18,18,190,189,66,66,238,237,190,189,17,18,12,12,84,84,244,243,171,171,84,84,12,12,172,171,243,243,90,90,90,90,166,165,165,165,250,249,95,96,6,6,160,159,96,96,250,249,160,159,5,6,202,201,65,66,54,54,190,189,66,66,202,201,190,189,53,54,214,213,89,90,42,42,166,165,90,90,214,213,166,165,41,42,226,225,125,126,30,30,130,129,126,126,226,225,130,129,29,30,154,153,101,102,102,102,154,153,172,171,125,126,84,84,130,129,126,126,172,171,130,129,83,84,36,36,36,36,220,219,219,219,66,66,66,66,190,189,189,189,0,0,0,0,0,0,6,6,250,249,0,6,0,250,6,0,250,255,12,12,244,243,6,12,250,243,12,6,244,249,244,11,12,244,250,17,6,238,18,250,238,5,12,24,244,231,24,12,232,243,24,24,232,231,0,30,0,226,30,0,226,255,238,23,18,232,24,238,232,17,30,48,226,207,48,30,208,225,250,35,6,220,36,250,220,5,12,48,244,207,48,12,208,243,48,48,208,207,0,54,0,202,54,0,202,255,220,35,36,220,232,47,24,208,48,232,208,23,30,78,226,177,78,30,178,225,54,84,202,171,84,54,172,201,238,65,18,190,66,238,190,17,12,84,244,171,84,12,172,243,90,90,166,165,250,95,6,160,96,250,160,5,202,65,54,190,66,202,190,53,214,89,42,166,90,214,166,41,226,125,30,130,126,226,130,29,154,101,102,154,172,125,84,130,126,172,130,83,36,36,220,219,66,66,190,189,0,0,0,0,0,0,0,0,0,0,5,5,5,5,251,250,250,250,0,0,5,5,0,0,251,250,5,5,0,0,251,250,255,255,10,10,10,10,246,245,245,245,5,5,15,15,251,250,240,240,15,15,5,5,241,240,250,250,246,245,9,10,10,10,246,245,251,250,14,15,5,5,241,240,15,15,251,250,241,240,4,5,10,10,20,20,246,245,235,235,20,20,10,10,236,235,245,245,20,20,20,20,236,235,235,235,0,0,25,25,0,0,231,230,25,25,0,0,231,230,255,255,241,240,19,20,15,15,236,235,20,20,241,240,236,235,14,15,25,25,40,40,231,230,215,215,40,40,25,25,216,215,230,230,246,245,29,30,10,10,226,225,30,30,246,245,226,225,9,10,10,10,40,40,246,245,215,215,40,40,10,10,216,215,245,245,40,40,40,40,216,215,215,215,0,0,45,45,0,0,211,210,45,45,0,0,211,210,255,255,226,225,29,30,30,30,226,225,236,235,39,40,20,20,216,215,40,40,236,235,216,215,19,20,25,25,65,65,231,230,190,190,65,65,25,25,191,190,230,230,45,45,70,70,211,210,185,185,70,70,45,45,186,185,210,210,241,240,54,55,15,15,201,200,55,55,241,240,201,200,14,15,10,10,70,70,246,245,185,185,70,70,10,10,186,185,245,245,75,75,75,75,181,180,180,180,251,250,84,85,5,5,171,170,85,85,251,250,171,170,4,5,211,210,54,55,45,45,201,200,55,55,211,210,201,200,44,45,221,220,74,75,35,35,181,180,75,75,221,220,181,180,34,35,55,55,115,115,201,200,140,140,115,115,55,55,141,140,200,200,30,30,115,115,226,225,140,140,115,115,30,30,141,140,225,225,90,90,120,120,166,165,135,135,120,120,90,90,136,135,165,165,226,225,104,105,30,30,151,150,105,105,226,225,151,150,29,30,171,170,84,85,85,85,171,170,186,185,104,105,70,70,151,150,105,105,186,185,151,150,69,70,30,30,30,30,226,225,225,225,60,60,60,60,196,195,195,195,105,105,105,105,151,150,150,150,0,0,0,0,0,0,5,5,251,250,0,5,0,251,5,0,251,255,10,10,246,245,5,15,251,240,15,5,241,250,246,9,10,246,251,14,5,241,15,251,241,4,10,20,246,235,20,10,236,245,20,20,236,235,0,25,0,231,25,0,231,255,241,19,15,236,20,241,236,14,25,40,231,215,40,25,216,230,246,29,10,226,30,246,226,9,10,40,246,215,40,10,216,245,40,40,216,215,0,45,0,211,45,0,211,255,226,29,30,226,236,39,20,216,40,236,216,19,25,65,231,190,65,25,191,230,45,70,211,185,70,45,186,210,241,54,15,201,55,241,201,14,10,70,246,185,70,10,186,245,75,75,181,180,251,84,5,171,85,251,171,4,211,54,45,201,55,211,201,44,221,74,35,181,75,221,181,34,55,115,201,140,115,55,141,200,30,115,226,140,115,30,141,225,90,120,166,135,120,90,136,165,226,104,30,151,105,226,151,29,171,84,85,171,186,104,70,151,105,186,151,69,30,30,226,225,60,60,196,195,105,105,151,150,0,0,0,0,0,0,4,4,4,4,252,251,251,251,0,0,4,4,0,0,252,251,4,4,0,0,252,251,255,255,4,4,8,8,252,251,247,247,8,8,4,4,248,247,251,251,8,8,8,8,248,247,247,247,248,247,7,8,8,8,248,247,252,251,11,12,4,4,244,243,12,12,252,251,244,243,3,4,8,8,16,16,248,247,239,239,16,16,8,8,240,239,247,247,16,16,16,16,240,239,239,239,0,0,20,20,0,0,236,235,20,20,0,0,236,235,255,255,244,243,15,16,12,12,240,239,16,16,244,243,240,239,11,12,252,251,23,24,4,4,232,231,24,24,252,251,232,231,3,4,16,16,32,32,240,239,223,223,32,32,16,16,224,223,239,239,8,8,32,32,248,247,223,223,32,32,8,8,224,223,247,247,32,32,32,32,224,223,223,223,0,0,36,36,0,0,220,219,36,36,0,0,220,219,255,255,232,231,23,24,24,24,232,231,240,239,31,32,16,16,224,223,32,32,240,239,224,223,15,16,20,20,52,52,236,235,203,203,52,52,20,20,204,203,235,235,36,36,56,56,220,219,199,199,56,56,36,36,200,199,219,219,244,243,43,44,12,12,212,211,44,44,244,243,212,211,11,12,8,8,56,56,248,247,199,199,56,56,8,8,200,199,247,247,60,60,60,60,196,195,195,195,252,251,63,64,4,4,192,191,64,64,252,251,192,191,3,4,220,219,43,44,36,36,212,211,44,44,220,219,212,211,35,36,228,227,59,60,28,28,196,195,60,60,228,227,196,195,27,28,44,44,92,92,212,211,163,163,92,92,44,44,164,163,211,211,24,24,92,92,232,231,163,163,92,92,24,24,164,163,231,231,72,72,96,96,184,183,159,159,96,96,72,72,160,159,183,183,236,235,83,84,20,20,172,171,84,84,236,235,172,171,19,20,8,8,100,100,248,247,155,155,100,100,8,8,156,155,247,247,108,108,108,108,148,147,147,147,188,187,67,68,68,68,188,187,200,199,83,84,56,56,172,171,84,84,200,199,172,171,55,56,244,243,119,120,12,12,136,135,120,120,244,243,136,135,11,12,208,207,107,108,48,48,148,147,108,108,208,207,148,147,47,48,152,151,123,124,104,104,132,131,124,124,152,151,132,131,103,104,24,24,24,24,232,231,231,231,44,44,44,44,212,211,211,211,84,84,84,84,172,171,171,171,0,0,0,0,0,0,4,4,252,251,0,4,0,252,4,0,252,255,4,8,252,247,8,4,248,251,8,8,248,247,248,7,8,248,252,11,4,244,12,252,244,3,8,16,248,239,16,8,240,247,16,16,240,239,0,20,0,236,20,0,236,255,244,15,12,240,16,244,240,11,252,23,4,232,24,252,232,3,16,32,240,223,32,16,224,239,8,32,248,223,32,8,224,247,32,32,224,223,0,36,0,220,36,0,220,255,232,23,24,232,240,31,16,224,32,240,224,15,20,52,236,203,52,20,204,235,36,56,220,199,56,36,200,219,244,43,12,212,44,244,212,11,8,56,248,199,56,8,200,247,60,60,196,195,252,63,4,192,64,252,192,3,220,43,36,212,44,220,212,35,228,59,28,196,60,228,196,27,44,92,212,163,92,44,164,211,24,92,232,163,92,24,164,231,72,96,184,159,96,72,160,183,236,83,20,172,84,236,172,19,8,100,248,155,100,8,156,247,108,108,148,147,188,67,68,188,200,83,56,172,84,200,172,55,244,119,12,136,120,244,136,11,208,107,48,148,108,208,148,47,152,123,104,132,124,152,132,103,24,24,232,231,44,44,212,211,84,84,172,171,0,0,0,0,0,0,0,0,0,0,3,3,3,3,253,252,252,252,0,0,3,3,0,0,253,252,3,3,0,0,253,252,255,255,6,6,6,6,250,249,249,249,3,3,9,9,253,252,246,246,9,9,3,3,247,246,252,252,253,252,8,9,3,3,247,246,9,9,253,252,247,246,2,3,250,249,5,6,6,6,250,249,6,6,12,12,250,249,243,243,12,12,6,6,244,243,249,249,12,12,12,12,244,243,243,243,0,0,15,15,0,0,241,240,15,15,0,0,241,240,255,255,247,246,11,12,9,9,244,243,12,12,247,246,244,243,8,9,15,15,24,24,241,240,231,231,24,24,15,15,232,231,240,240,250,249,17,18,6,6,238,237,18,18,250,249,238,237,5,6,6,6,24,24,250,249,231,231,24,24,6,6,232,231,249,249,24,24,24,24,232,231,231,231,0,0,27,27,0,0,229,228,27,27,0,0,229,228,255,255,238,237,17,18,18,18,238,237,244,243,23,24,12,12,232,231,24,24,244,243,232,231,11,12,15,15,39,39,241,240,216,216,39,39,15,15,217,216,240,240,27,27,42,42,229,228,213,213,42,42,27,27,214,213,228,228,247,246,32,33,9,9,223,222,33,33,247,246,223,222,8,9,6,6,42,42,250,249,213,213,42,42,6,6,214,213,249,249,45,45,45,45,211,210,210,210,253,252,50,51,3,3,205,204,51,51,253,252,205,204,2,3,229,228,32,33,27,27,223,222,33,33,229,228,223,222,26,27,235,234,44,45,21,21,211,210,45,45,235,234,211,210,20,21,33,33,69,69,223,222,186,186,69,69,33,33,187,186,222,222,18,18,69,69,238,237,186,186,69,69,18,18,187,186,237,237,54,54,72,72,202,201,183,183,72,72,54,54,184,183,201,201,238,237,62,63,18,18,193,192,63,63,238,237,193,192,17,18,6,6,78,78,250,249,177,177,78,78,6,6,178,177,249,249,81,81,81,81,175,174,174,174,205,204,50,51,51,51,205,204,214,213,62,63,42,42,193,192,63,63,214,213,193,192,41,42,247,246,89,90,9,9,166,165,90,90,247,246,166,165,8,9,42,42,114,114,214,213,141,141,114,114,42,42,142,141,213,213,63,63,117,117,193,192,138,138,117,117,63,63,139,138,192,192,220,219,80,81,36,36,175,174,81,81,220,219,175,174,35,36,21,21,120,120,235,234,135,135,120,120,21,21,136,135,234,234,96,96,123,123,160,159,132,132,123,123,96,96,133,132,159,159,226,225,110,111,30,30,145,144,111,111,226,225,145,144,29,30,178,177,92,93,78,78,163,162,93,93,178,177,163,162,77,78,187,186,113,114,69,69,142,141,114,114,187,186,142,141,68,69,18,18,18,18,238,237,237,237,33,33,33,33,223,222,222,222,63,63,63,63,193,192,192,192,108,108,108,108,148,147,147,147,0,0,0,0,0,0,3,3,253,252,0,3,0,253,3,0,253,255,6,6,250,249,3,9,253,246,9,3,247,252,253,8,3,247,9,253,247,2,250,5,6,250,6,12,250,243,12,6,244,249,12,12,244,243,0,15,0,241,15,0,241,255,247,11,9,244,12,247,244,8,15,24,241,231,24,15,232,240,250,17,6,238,18,250,238,5,6,24,250,231,24,6,232,249,24,24,232,231,0,27,0,229,27,0,229,255,238,17,18,238,244,23,12,232,24,244,232,11,15,39,241,216,39,15,217,240,27,42,229,213,42,27,214,228,247,32,9,223,33,247,223,8,6,42,250,213,42,6,214,249,45,45,211,210,253,50,3,205,51,253,205,2,229,32,27,223,33,229,223,26,235,44,21,211,45,235,211,20,33,69,223,186,69,33,187,222,18,69,238,186,69,18,187,237,54,72,202,183,72,54,184,201,238,62,18,193,63,238,193,17,6,78,250,177,78,6,178,249,81,81,175,174,205,50,51,205,214,62,42,193,63,214,193,41,247,89,9,166,90,247,166,8,42,114,214,141,114,42,142,213,63,117,193,138,117,63,139,192,220,80,36,175,81,220,175,35,21,120,235,135,120,21,136,234,96,123,160,132,123,96,133,159,226,110,30,145,111,226,145,29,178,92,78,163,93,178,163,77,187,113,69,142,114,187,142,68,18,18,238,237,33,33,223,222,63,63,193,192,108,108,148,147,0,0,0,0,0,0,2,2,2,2,254,253,253,253,0,0,2,2,0,0,254,253,2,2,0,0,254,253,255,255,4,4,4,4,252,251,251,251,0,0,4,4,0,0,252,251,4,4,0,0,252,251,255,255,252,251,3,4,4,4,252,251,254,253,5,6,2,2,250,249,6,6,254,253,250,249,1,2,4,4,8,8,252,251,247,247,8,8,4,4,248,247,251,251,8,8,8,8,248,247,247,247,0,0,10,10,0,0,246,245,10,10,0,0,246,245,255,255,252,251,7,8,4,4,248,247,8,8,252,251,248,247,3,4,8,8,14,14,248,247,241,241,14,14,8,8,242,241,247,247,254,253,11,12,2,2,244,243,12,12,254,253,244,243,1,2,4,4,16,16,252,251,239,239,16,16,4,4,240,239,251,251,16,16,16,16,240,239,239,239,0,0,18,18,0,0,238,237,18,18,0,0,238,237,255,255,244,243,11,12,12,12,244,243,248,247,15,16,8,8,240,239,16,16,248,247,240,239,7,8,10,10,26,26,246,245,229,229,26,26,10,10,230,229,245,245,18,18,28,28,238,237,227,227,28,28,18,18,228,227,237,237,250,249,21,22,6,6,234,233,22,22,250,249,234,233,5,6,4,4,28,28,252,251,227,227,28,28,4,4,228,227,251,251,30,30,30,30,226,225,225,225,254,253,31,32,2,2,224,223,32,32,254,253,224,223,1,2,238,237,21,22,18,18,234,233,22,22,238,237,234,233,17,18,242,241,29,30,14,14,226,225,30,30,242,241,226,225,13,14,22,22,46,46,234,233,209,209,46,46,22,22,210,209,233,233,12,12,46,46,244,243,209,209,46,46,12,12,210,209,243,243,34,34,48,48,222,221,207,207,48,48,34,34,208,207,221,221,246,245,39,40,10,10,216,215,40,40,246,245,216,215,9,10,4,4,50,50,252,251,205,205,50,50,4,4,206,205,251,251,54,54,54,54,202,201,201,201,222,221,33,34,34,34,222,221,228,227,41,42,28,28,214,213,42,42,228,227,214,213,27,28,250,249,59,60,6,6,196,195,60,60,250,249,196,195,5,6,26,26,76,76,230,229,179,179,76,76,26,26,180,179,229,229,42,42,76,76,214,213,179,179,76,76,42,42,180,179,213,213,232,231,53,54,24,24,202,201,54,54,232,231,202,201,23,24,14,14,78,78,242,241,177,177,78,78,14,14,178,177,241,241,62,62,82,82,194,193,173,173,82,82,62,62,174,173,193,193,236,235,73,74,20,20,182,181,74,74,236,235,182,181,19,20,2,2,88,88,254,253,167,167,88,88,2,2,168,167,253,253,92,92,92,92,164,163,163,163,204,203,59,60,52,52,196,195,60,60,204,203,196,195,51,52,52,52,118,118,204,203,137,137,118,118,52,52,138,137,203,203,212,211,73,74,44,44,182,181,74,74,212,211,182,181,43,44,74,74,118,118,182,181,137,137,118,118,74,74,138,137,181,181,32,32,118,118,224,223,137,137,118,118,32,32,138,137,223,223,244,243,101,102], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1379512);
/* memory initializer */ allocate([12,12,154,153,102,102,244,243,154,153,11,12,216,215,95,96,40,40,160,159,96,96,216,215,160,159,39,40,222,221,117,118,34,34,138,137,118,118,222,221,138,137,33,34,168,167,87,88,88,88,168,167,178,177,103,104,78,78,152,151,104,104,178,177,152,151,77,78,12,12,12,12,244,243,243,243,22,22,22,22,234,233,233,233,42,42,42,42,214,213,213,213,72,72,72,72,184,183,183,183,0,0,0,0,0,0,2,2,254,253,0,2,0,254,2,0,254,255,4,4,252,251,0,4,0,252,4,0,252,255,252,3,4,252,254,5,2,250,6,254,250,1,4,8,252,247,8,4,248,251,8,8,248,247,0,10,0,246,10,0,246,255,252,7,4,248,8,252,248,3,8,14,248,241,14,8,242,247,254,11,2,244,12,254,244,1,4,16,252,239,16,4,240,251,16,16,240,239,0,18,0,238,18,0,238,255,244,11,12,244,248,15,8,240,16,248,240,7,10,26,246,229,26,10,230,245,18,28,238,227,28,18,228,237,250,21,6,234,22,250,234,5,4,28,252,227,28,4,228,251,30,30,226,225,254,31,2,224,32,254,224,1,238,21,18,234,22,238,234,17,242,29,14,226,30,242,226,13,22,46,234,209,46,22,210,233,12,46,244,209,46,12,210,243,34,48,222,207,48,34,208,221,246,39,10,216,40,246,216,9,4,50,252,205,50,4,206,251,54,54,202,201,222,33,34,222,228,41,28,214,42,228,214,27,250,59,6,196,60,250,196,5,26,76,230,179,76,26,180,229,42,76,214,179,76,42,180,213,232,53,24,202,54,232,202,23,14,78,242,177,78,14,178,241,62,82,194,173,82,62,174,193,236,73,20,182,74,236,182,19,2,88,254,167,88,2,168,253,92,92,164,163,204,59,52,196,60,204,196,51,52,118,204,137,118,52,138,203,212,73,44,182,74,212,182,43,74,118,182,137,118,74,138,181,32,118,224,137,118,32,138,223,244,101,12,154,102,244,154,11,216,95,40,160,96,216,160,39,222,117,34,138,118,222,138,33,168,87,88,168,178,103,78,152,104,178,152,77,12,12,244,243,22,22,234,233,42,42,214,213,72,72,184,183,0,0,0,0,0,0,9,9,9,9,247,246,246,246,253,252,11,12,3,3,244,243,12,12,253,252,244,243,2,3,20,20,20,20,236,235,235,235,6,6,23,23,250,249,232,232,23,23,6,6,233,232,249,249,239,238,16,17,17,17,239,238,249,248,26,27,7,7,229,228,27,27,249,248,229,228,6,7,19,19,39,39,237,236,216,216,39,39,19,19,217,216,236,236,39,39,39,39,217,216,216,216,3,3,43,43,253,252,212,212,43,43,3,3,213,212,252,252,232,231,35,36,24,24,220,219,36,36,232,231,220,219,23,24,42,42,69,69,214,213,186,186,69,69,42,42,187,186,213,213,242,241,52,53,14,14,203,202,53,53,242,241,203,202,13,14,19,19,71,71,237,236,184,184,71,71,19,19,185,184,236,236,73,73,73,73,183,182,182,182,254,253,79,80,2,2,176,175,80,80,254,253,176,175,1,2,204,203,51,52,52,52,204,203,217,216,69,70,39,39,186,185,70,70,217,216,186,185,38,39,48,48,121,121,208,207,134,134,121,121,48,48,135,134,207,207,84,84,124,124,172,171,131,131,124,124,84,84,132,131,171,171,229,228,99,100,27,27,156,155,100,100,229,228,156,155,26,27,175,174,101,102,81,81,154,153,102,102,175,174,154,153,80,81,55,55,55,55,201,200,200,200,104,104,104,104,152,151,151,151,0,0,0,0,0,0,9,9,247,246,253,11,3,244,12,253,244,2,20,20,236,235,6,23,250,232,23,6,233,249,239,16,17,239,249,26,7,229,27,249,229,6,19,39,237,216,39,19,217,236,39,39,217,216,3,43,253,212,43,3,213,252,232,35,24,220,36,232,220,23,42,69,214,186,69,42,187,213,242,52,14,203,53,242,203,13,19,71,237,184,71,19,185,236,73,73,183,182,254,79,2,176,80,254,176,1,204,51,52,204,217,69,39,186,70,217,186,38,48,121,208,134,121,48,135,207,84,124,172,131,124,84,132,171,229,99,27,156,100,229,156,26,175,101,81,154,102,175,154,80,55,55,201,200,104,104,152,151,0,0,0,0,0,0,0,0,0,0,8,8,8,8,248,247,247,247,253,252,10,11,3,3,245,244,11,11,253,252,245,244,2,3,18,18,18,18,238,237,237,237,5,5,20,20,251,250,235,235,20,20,5,5,236,235,250,250,241,240,14,15,15,15,241,240,249,248,23,24,7,7,232,231,24,24,249,248,232,231,6,7,17,17,35,35,239,238,220,220,35,35,17,17,221,220,238,238,34,34,34,34,222,221,221,221,3,3,38,38,253,252,217,217,38,38,3,3,218,217,252,252,234,233,31,32,22,22,224,223,32,32,234,233,224,223,21,22,37,37,61,61,219,218,194,194,61,61,37,37,195,194,218,218,243,242,46,47,13,13,209,208,47,47,243,242,209,208,12,13,17,17,63,63,239,238,192,192,63,63,17,17,193,192,238,238,65,65,65,65,191,190,190,190,255,254,71,72,1,1,184,183,72,72,255,254,184,183,0,1,210,209,45,46,46,46,210,209,221,220,62,63,35,35,193,192,63,63,221,220,193,192,34,35,43,43,107,107,213,212,148,148,107,107,43,43,149,148,212,212,75,75,110,110,181,180,145,145,110,110,75,75,146,145,180,180,232,231,88,89,24,24,167,166,89,89,232,231,167,166,23,24,17,17,114,114,239,238,141,141,114,114,17,17,142,141,238,238,121,121,121,121,135,134,134,134,184,183,90,91,72,72,165,164,91,91,184,183,165,164,71,72,198,197,119,120,58,58,136,135,120,120,198,197,136,135,57,58,49,49,49,49,207,206,206,206,92,92,92,92,164,163,163,163,0,0,0,0,0,0,8,8,248,247,253,10,3,245,11,253,245,2,18,18,238,237,5,20,251,235,20,5,236,250,241,14,15,241,249,23,7,232,24,249,232,6,17,35,239,220,35,17,221,238,34,34,222,221,3,38,253,217,38,3,218,252,234,31,22,224,32,234,224,21,37,61,219,194,61,37,195,218,243,46,13,209,47,243,209,12,17,63,239,192,63,17,193,238,65,65,191,190,255,71,1,184,72,255,184,0,210,45,46,210,221,62,35,193,63,221,193,34,43,107,213,148,107,43,149,212,75,110,181,145,110,75,146,180,232,88,24,167,89,232,167,23,17,114,239,141,114,17,142,238,121,121,135,134,184,90,72,165,91,184,165,71,198,119,58,136,120,198,136,57,49,49,207,206,92,92,164,163,0,0,0,0,0,0,7,7,7,7,249,248,248,248,253,252,9,10,3,3,246,245,10,10,253,252,246,245,2,3,16,16,16,16,240,239,239,239,5,5,18,18,251,250,237,237,18,18,5,5,238,237,250,250,243,242,12,13,13,13,243,242,250,249,20,21,6,6,235,234,21,21,250,249,235,234,5,6,15,15,30,30,241,240,225,225,30,30,15,15,226,225,240,240,30,30,30,30,226,225,225,225,2,2,34,34,254,253,221,221,34,34,2,2,222,221,253,253,237,236,27,28,19,19,228,227,28,28,237,236,228,227,18,19,32,32,54,54,224,223,201,201,54,54,32,32,202,201,223,223,245,244,40,41,11,11,215,214,41,41,245,244,215,214,10,11,15,15,55,55,241,240,200,200,55,55,15,15,201,200,240,240,57,57,57,57,199,198,198,198,255,254,62,63,1,1,193,192,63,63,255,254,193,192,0,1,216,215,39,40,40,40,216,215,226,225,54,55,30,30,201,200,55,55,226,225,201,200,29,30,37,37,94,94,219,218,161,161,94,94,37,37,162,161,218,218,65,65,96,96,191,190,159,159,96,96,65,65,160,159,190,190,235,234,77,78,21,21,178,177,78,78,235,234,178,177,20,21,15,15,100,100,241,240,155,155,100,100,15,15,156,155,240,240,106,106,106,106,150,149,149,149,248,247,115,116,8,8,140,139,116,116,248,247,140,139,7,8,193,192,78,79,63,63,177,176,79,79,193,192,177,176,62,63,205,204,104,105,51,51,151,150,105,105,205,204,151,150,50,51,136,135,119,120,120,120,136,135,43,43,43,43,213,212,212,212,80,80,80,80,176,175,175,175,0,0,0,0,0,0,7,7,249,248,253,9,3,246,10,253,246,2,16,16,240,239,5,18,251,237,18,5,238,250,243,12,13,243,250,20,6,235,21,250,235,5,15,30,241,225,30,15,226,240,30,30,226,225,2,34,254,221,34,2,222,253,237,27,19,228,28,237,228,18,32,54,224,201,54,32,202,223,245,40,11,215,41,245,215,10,15,55,241,200,55,15,201,240,57,57,199,198,255,62,1,193,63,255,193,0,216,39,40,216,226,54,30,201,55,226,201,29,37,94,219,161,94,37,162,218,65,96,191,159,96,65,160,190,235,77,21,178,78,235,178,20,15,100,241,155,100,15,156,240,106,106,150,149,248,115,8,140,116,248,140,7,193,78,63,177,79,193,177,62,205,104,51,151,105,205,151,50,136,119,120,136,43,43,213,212,80,80,176,175,0,0,0,0,0,0,0,0,0,0,6,6,6,6,250,249,249,249,254,253,7,8,2,2,248,247,8,8,254,253,248,247,1,2,13,13,13,13,243,242,242,242,4,4,15,15,252,251,240,240,15,15,4,4,241,240,251,251,245,244,10,11,11,11,245,244,251,250,17,18,5,5,238,237,18,18,251,250,238,237,4,5,13,13,26,26,243,242,229,229,26,26,13,13,230,229,242,242,26,26,26,26,230,229,229,229,2,2,29,29,254,253,226,226,29,29,2,2,227,226,253,253,240,239,23,24,16,16,232,231,24,24,240,239,232,231,15,16,28,28,46,46,228,227,209,209,46,46,28,28,210,209,227,227,247,246,34,35,9,9,221,220,35,35,247,246,221,220,8,9,13,13,47,47,243,242,208,208,47,47,13,13,209,208,242,242,49,49,49,49,207,206,206,206,255,254,53,54,1,1,202,201,54,54,255,254,202,201,0,1,221,220,34,35,35,35,221,220,230,229,46,47,26,26,209,208,47,47,230,229,209,208,25,26,32,32,81,81,224,223,174,174,81,81,32,32,175,174,223,223,56,56,83,83,200,199,172,172,83,83,56,56,173,172,199,199,238,237,66,67,18,18,189,188,67,67,238,237,189,188,17,18,13,13,86,86,243,242,169,169,86,86,13,13,170,169,242,242,91,91,91,91,165,164,164,164,249,248,98,99,7,7,157,156,99,99,249,248,157,156,6,7,202,201,67,68,54,54,188,187,68,68,202,201,188,187,53,54,212,211,89,90,44,44,166,165,90,90,212,211,166,165,43,44,223,222,123,124,33,33,132,131,124,124,223,222,132,131,32,33,153,152,102,103,103,103,153,152,170,169,126,127,86,86,129,128,127,127,170,169,129,128,85,86,37,37,37,37,219,218,218,218,69,69,69,69,187,186,186,186,0,0,0,0,0,0,6,6,250,249,254,7,2,248,8,254,248,1,13,13,243,242,4,15,252,240,15,4,241,251,245,10,11,245,251,17,5,238,18,251,238,4,13,26,243,229,26,13,230,242,26,26,230,229,2,29,254,226,29,2,227,253,240,23,16,232,24,240,232,15,28,46,228,209,46,28,210,227,247,34,9,221,35,247,221,8,13,47,243,208,47,13,209,242,49,49,207,206,255,53,1,202,54,255,202,0,221,34,35,221,230,46,26,209,47,230,209,25,32,81,224,174,81,32,175,223,56,83,200,172,83,56,173,199,238,66,18,189,67,238,189,17,13,86,243,169,86,13,170,242,91,91,165,164,249,98,7,157,99,249,157,6,202,67,54,188,68,202,188,53,212,89,44,166,90,212,166,43,223,123,33,132,124,223,132,32,153,102,103,153,170,126,86,129,127,170,129,85,37,37,219,218,69,69,187,186,0,0,0,0,0,0,0,0,0,0,5,5,5,5,251,250,250,250,254,253,6,7,2,2,249,248,7,7,254,253,249,248,1,2,11,11,11,11,245,244,244,244,3,3,13,13,253,252,242,242,13,13,3,3,243,242,252,252,247,246,8,9,9,9,247,246,252,251,14,15,4,4,241,240,15,15,252,251,241,240,3,4,11,11,22,22,245,244,233,233,22,22,11,11,234,233,244,244,21,21,21,21,235,234,234,234,2,2,24,24,254,253,231,231,24,24,2,2,232,231,253,253,242,241,19,20,14,14,236,235,20,20,242,241,236,235,13,14,23,23,38,38,233,232,217,217,38,38,23,23,218,217,232,232,248,247,28,29,8,8,227,226,29,29,248,247,227,226,7,8,11,11,39,39,245,244,216,216,39,39,11,11,217,216,244,244,41,41,41,41,215,214,214,214,255,254,44,45,1,1,211,210,45,45,255,254,211,210,0,1,227,226,28,29,29,29,227,226,234,233,38,39,22,22,217,216,39,39,234,233,217,216,21,22,27,27,67,67,229,228,188,188,67,67,27,27,189,188,228,228,47,47,69,69,209,208,186,186,69,69,47,47,187,186,208,208,241,240,55,56,15,15,200,199,56,56,241,240,200,199,14,15,11,11,71,71,245,244,184,184,71,71,11,11,185,184,244,244,76,76,76,76,180,179,179,179,250,249,82,83,6,6,173,172,83,83,250,249,173,172,5,6,211,210,56,57,45,45,199,198,57,57,211,210,199,198,44,45,220,219,74,75,36,36,181,180,75,75,220,219,181,180,35,36,56,56,115,115,200,199,140,140,115,115,56,56,141,140,199,199,31,31,117,117,225,224,138,138,117,117,31,31,139,138,224,224,88,88,122,122,168,167,133,133,122,122,88,88,134,133,167,167,228,227,103,104,28,28,152,151,104,104,228,227,152,151,27,28,171,170,84,85,85,85,171,170,184,183,105,106,72,72,150,149,106,106,184,183,150,149,71,72,30,30,30,30,226,225,225,225,58,58,58,58,198,197,197,197,105,105,105,105,151,150,150,150,0,0,0,0,0,0,5,5,251,250,254,6,2,249,7,254,249,1,11,11,245,244,3,13,253,242,13,3,243,252,247,8,9,247,252,14,4,241,15,252,241,3,11,22,245,233,22,11,234,244,21,21,235,234,2,24,254,231,24,2,232,253,242,19,14,236,20,242,236,13,23,38,233,217,38,23,218,232,248,28,8,227,29,248,227,7,11,39,245,216,39,11,217,244,41,41,215,214,255,44,1,211,45,255,211,0,227,28,29,227,234,38,22,217,39,234,217,21,27,67,229,188,67,27,189,228,47,69,209,186,69,47,187,208,241,55,15,200,56,241,200,14,11,71,245,184,71,11,185,244,76,76,180,179,250,82,6,173,83,250,173,5,211,56,45,199,57,211,199,44,220,74,36,181,75,220,181,35,56,115,200,140,115,56,141,199,31,117,225,138,117,31,139,224,88,122,168,133,122,88,134,167,228,103,28,152,104,228,152,27,171,84,85,171,184,105,72,150,106,184,150,71,30,30,226,225,58,58,198,197,105,105,151,150,0,0,0,0,0,0,4,4,4,4,252,251,251,251,255,254,4,5,1,1,251,250,5,5,255,254,251,250,0,1,3,3,10,10,253,252,245,245,10,10,3,3,246,245,252,252,9,9,9,9,247,246,246,246,249,248,6,7,7,7,249,248,253,252,11,12,3,3,244,243,12,12,253,252,244,243,2,3,8,8,17,17,248,247,238,238,17,17,8,8,239,238,247,247,17,17,17,17,239,238,238,238,1,1,19,19,255,254,236,236,19,19,1,1,237,236,254,254,245,244,15,16,11,11,240,239,16,16,245,244,240,239,10,11,250,249,22,23,6,6,233,232,23,23,250,249,233,232,5,6,18,18,31,31,238,237,224,224,31,31,18,18,225,224,237,237,8,8,32,32,248,247,223,223,32,32,8,8,224,223,247,247,33,33,33,33,223,222,222,222,255,254,35,36,1,1,220,219,36,36,255,254,220,219,0,1,233,232,22,23,23,23,233,232,239,238,30,31,17,17,225,224,31,31,239,238,225,224,16,17,21,21,54,54,235,234,201,201,54,54,21,21,202,201,234,234,37,37,55,55,219,218,200,200,55,55,37,37,201,200,218,218,244,243,43,44,12,12,212,211,44,44,244,243,212,211,11,12,8,8,57,57,248,247,198,198,57,57,8,8,199,198,247,247,61,61,61,61,195,194,194,194,251,250,65,66,5,5,190,189,66,66,251,250,190,189,4,5,220,219,44,45,36,36,211,210,45,45,220,219,211,210,35,36,227,226,59,60,29,29,196,195,60,60,227,226,196,195,28,29,45,45,92,92,211,210,163,163,92,92,45,45,164,163,210,210,25,25,93,93,231,230,162,162,93,93,25,25,163,162,230,230,71,71,97,97,185,184,158,158,97,97,71,71,159,158,184,184,234,233,82,83,22,22,173,172,83,83,234,233,173,172,21,22,7,7,102,102,249,248,153,153,102,102,7,7,154,153,248,248,109,109,109,109,147,146,146,146,188,187,67,68,68,68,188,187,199,198,84,85,57,57,171,170,85,85,199,198,171,170,56,57,243,242,119,120,13,13,136,135,120,120,243,242,136,135,12,13,207,206,109,110,49,49,146,145,110,110,207,206,146,145,48,49,152,151,122,123,104,104,133,132,123,123,152,151,133,132,103,104,24,24,24,24,232,231,231,231,46,46,46,46,210,209,209,209,84,84,84,84,172,171,171,171,0,0,0,0,0,0,4,4,252,251,255,4,1,251,5,255,251,0,3,10,253,245,10,3,246,252,9,9,247,246,249,6,7,249,253,11,3,244,12,253,244,2,8,17,248,238,17,8,239,247,17,17,239,238,1,19,255,236,19,1,237,254,245,15,11,240,16,245,240,10,250,22,6,233,23,250,233,5,18,31,238,224,31,18,225,237,8,32,248,223,32,8,224,247,33,33,223,222,255,35,1,220,36,255,220,0,233,22,23,233,239,30,17,225,31,239,225,16,21,54,235,201,54,21,202,234,37,55,219,200,55,37,201,218,244,43,12,212,44,244,212,11,8,57,248,198,57,8,199,247,61,61,195,194,251,65,5,190,66,251,190,4,220,44,36,211,45,220,211,35,227,59,29,196,60,227,196,28,45,92,211,163,92,45,164,210,25,93,231,162,93,25,163,230,71,97,185,158,97,71,159,184,234,82,22,173,83,234,173,21,7,102,249,153,102,7,154,248,109,109,147,146,188,67,68,188,199,84,57,171,85,199,171,56,243,119,13,136,120,243,136,12,207,109,49,146,110,207,146,48,152,122,104,133,123,152,133,103,24,24,232,231,46,46,210,209,84,84,172,171,0,0,0,0,0,0,0,0,0,0,3,3,3,3,253,252,252,252,255,254,3,4,1,1,252,251,4,4,255,254,252,251,0,1,7,7,7,7,249,248,248,248,2,2,8,8,254,253,247,247,8,8,2,2,248,247,253,253,254,253,8,9,2,2,247,246,9,9,254,253,247,246,1,2,250,249,5,6,6,6,250,249,6,6,13,13,250,249,242,242,13,13,6,6,243,242,249,249,13,13,13,13,243,242,242,242,1,1,14,14,255,254,241,241,14,14,1,1,242,241,254,254,248,247,11,12,8,8,244,243,12,12,248,247,244,243,7,8,14,14,23,23,242,241,232,232,23,23,14,14,233,232,241,241,251,250,17,18,5,5,238,237,18,18,251,250,238,237,4,5,6,6,24,24,250,249,231,231,24,24,6,6,232,231,249,249,24,24,24,24,232,231,231,231,255,254,26,27,1,1,229,228,27,27,255,254,229,228,0,1,239,238,16,17,17,17,239,238,243,242,22,23,13,13,233,232,23,23,243,242,233,232,12,13,16,16,40,40,240,239,215,215,40,40,16,16,216,215,239,239,28,28,41,41,228,227,214,214,41,41,28,28,215,214,227,227,247,246,32,33,9,9,223,222,33,33,247,246,223,222,8,9,6,6,43,43,250,249,212,212,43,43,6,6,213,212,249,249,46,46,46,46,210,209,209,209,252,251,49,50,4,4,206,205,50,50,252,251,206,205,3,4,229,228,33,34,27,27,222,221,34,34,229,228,222,221,26,27,234,233,44,45,22,22,211,210,45,45,234,233,211,210,21,22,34,34,69,69,222,221,186,186,69,69,34,34,187,186,221,221,19,19,70,70,237,236,185,185,70,70,19,19,186,185,236,236,53,53,73,73,203,202,182,182,73,73,53,53,183,182,202,202,239,238,61,62,17,17,194,193,62,62,239,238,194,193,16,17,5,5,77,77,251,250,178,178,77,77,5,5,179,178,250,250,82,82,82,82,174,173,173,173,205,204,50,51,51,51,205,204,213,212,63,64,43,43,192,191,64,64,213,212,192,191,42,43,246,245,89,90,10,10,166,165,90,90,246,245,166,165,9,10,41,41,114,114,215,214,141,141,114,114,41,41,142,141,214,214,64,64,116,116,192,191,139,139,116,116,64,64,140,139,191,191,219,218,81,82,37,37,174,173,82,82,219,218,174,173,36,37,22,22,119,119,234,233,136,136,119,119,22,22,137,136,233,233,95,95,124,124,161,160,131,131,124,124,95,95,132,131,160,160,226,225,110,111,30,30,145,144,111,111,226,225,145,144,29,30,178,177,91,92,78,78,164,163,92,92,178,177,164,163,77,78,188,187,112,113,68,68,143,142,113,113,188,187,143,142,67,68,18,18,18,18,238,237,237,237,34,34,34,34,222,221,221,221,63,63,63,63,193,192,192,192,109,109,109,109,147,146,146,146,0,0,0,0,0,0,3,3,253,252,255,3,1,252,4,255,252,0,7,7,249,248,2,8,254,247,8,2,248,253,254,8,2,247,9,254,247,1,250,5,6,250,6,13,250,242,13,6,243,249,13,13,243,242,1,14,255,241,14,1,242,254,248,11,8,244,12,248,244,7,14,23,242,232,23,14,233,241,251,17,5,238,18,251,238,4,6,24,250,231,24,6,232,249,24,24,232,231,255,26,1,229,27,255,229,0,239,16,17,239,243,22,13,233,23,243,233,12,16,40,240,215,40,16,216,239,28,41,228,214,41,28,215,227,247,32,9,223,33,247,223,8,6,43,250,212,43,6,213,249,46,46,210,209,252,49,4,206,50,252,206,3,229,33,27,222,34,229,222,26,234,44,22,211,45,234,211,21,34,69,222,186,69,34,187,221,19,70,237,185,70,19,186,236,53,73,203,182,73,53,183,202,239,61,17,194,62,239,194,16,5,77,251,178,77,5,179,250,82,82,174,173,205,50,51,205,213,63,43,192,64,213,192,42,246,89,10,166,90,246,166,9,41,114,215,141,114,41,142,214,64,116,192,139,116,64,140,191,219,81,37,174,82,219,174,36,22,119,234,136,119,22,137,233,95,124,161,131,124,95,132,160,226,110,30,145,111,226,145,29,178,91,78,164,92,178,164,77,188,112,68,143,113,188,143,67,18,18,238,237,34,34,222,221,63,63,193,192,109,109,147,146,0,0,0,0,0,0,2,2,2,2,254,253,253,253,255,254,2,3,1,1,253,252,3,3,255,254,253,252,0,1,4,4,4,4,252,251,251,251,1,1,5,5,255,254,250,250,5,5,1,1,251,250,254,254,252,251,3,4,4,4,252,251,254,253,5,6,2,2,250,249,6,6,254,253,250,249,1,2,4,4,9,9,252,251,246,246,9,9,4,4,247,246,251,251,9,9,9,9,247,246,246,246,1,1,10,10,255,254,245,245,10,10,1,1,246,245,254,254,251,250,7,8,5,5,248,247,8,8,251,250,248,247,4,5,9,9,15,15,247,246,240,240,15,15,9,9,241,240,246,246,253,252,11,12,3,3,244,243,12,12,253,252,244,243,2,3,4,4,16,16,252,251,239,239,16,16,4,4,240,239,251,251,16,16,16,16,240,239,239,239,0,0,18,18,0,0,238,237,18,18,0,0,238,237,255,255,244,243,11,12,12,12,244,243,247,246,15,16,9,9,240,239,16,16,247,246,240,239,8,9,11,11,27,27,245,244,228,228,27,27,11,11,229,228,244,244,19,19,28,28,237,236,227,227,28,28,19,19,228,227,236,236,250,249,21,22,6,6,234,233,22,22,250,249,234,233,5,6,4,4,29,29,252,251,226,226,29,29,4,4,227,226,251,251,30,30,30,30,226,225,225,225,254,253,32,33,2,2,223,222,33,33,254,253,223,222,1,2,238,237,22,23,18,18,233,232,23,23,238,237,233,232,17,18,241,240,29,30,15,15,226,225,30,30,241,240,226,225,14,15,22,22,46,46,234,233,209,209,46,46,22,22,210,209,233,233,13,13,47,47,243,242,208,208,47,47,13,13,209,208,242,242,35,35,49,49,221,220,206,206,49,49,35,35,207,206,220,220,245,244,40,41,11,11,215,214,41,41,245,244,215,214,10,11,4,4,51,51,252,251,204,204,51,51,4,4,205,204,251,251,54,54,54,54,202,201,201,201,222,221,33,34,34,34,222,221,227,226,41,42,29,29,214,213,42,42,227,226,214,213,28,29,250,249,59,60,6,6,196,195,60,60,250,249,196,195,5,6,27,27,76,76,229,228,179,179,76,76,27,27,180,179,228,228,43,43,77,77,213,212,178,178,77,77,43,43,179,178,212,212,232,231,54,55,24,24,201,200,55,55,232,231,201,200,23,24,14,14,79,79,242,241,176,176,79,79,14,14,177,176,241,241,63,63,83,83,193,192,172,172,83,83,63,63,173,172,192,192,236,235,73,74,20,20,182,181,74,74,236,235,182,181,19,20,2,2,88,88,254,253,167,167,88,88,2,2,168,167,253,253,93,93,93,93,163,162,162,162,204,203,60,61,52,52,195,194,61,61,204,203,195,194,51,52,52,52,120,120,204,203,135,135,120,120,52,52,136,135,203,203,211,210,74,75,45,45,181,180,75,75,211,210,181,180,44,45,75,75,125,125,181,180,130,130,125,125,75,75,131,130,180,180,33,33,122,122,223,222,133,133,122,122,33,33,134,133,222,222,243,242,102,103,13,13,153,152,103,103,243,242,153,152,12,13,216,215,95,96,40,40,160,159,96,96,216,215,160,159,39,40,222,221,126,127,34,34,129,128,127,127,222,221,129,128,33,34,167,166,88,89,89,89,167,166,178,177,104,105,78,78,151,150,105,105,178,177,151,150,77,78,12,12,12,12,244,243,243,243,23,23,23,23,233,232,232,232,42,42,42,42,214,213,213,213,73,73,73,73,183,182,182,182,0,0,0,0,0,0,2,2,254,253,255,2,1,253,3,255,253,0,4,4,252,251,1,5,255,250,5,1,251,254,252,3,4,252,254,5,2,250,6,254,250,1,4,9,252,246,9,4,247,251,9,9,247,246,1,10,255,245,10,1,246,254,251,7,5,248,8,251,248,4,9,15,247,240,15,9,241,246,253,11,3,244,12,253,244,2,4,16,252,239,16,4,240,251,16,16,240,239,0,18,0,238,18,0,238,255,244,11,12,244,247,15,9,240,16,247,240,8,11,27,245,228,27,11,229,244,19,28,237,227,28,19,228,236,250,21,6,234,22,250,234,5,4,29,252,226,29,4,227,251,30,30,226,225,254,32,2,223,33,254,223,1,238,22,18,233,23,238,233,17,241,29,15,226,30,241,226,14,22,46,234,209,46,22,210,233,13,47,243,208,47,13,209,242,35,49,221,206,49,35,207,220,245,40,11,215,41,245,215,10,4,51,252,204,51,4,205,251,54,54,202,201,222,33,34,222,227,41,29,214,42,227,214,28,250,59,6,196,60,250,196,5,27,76,229,179,76,27,180,228,43,77,213,178,77,43,179,212,232,54,24,201,55,232,201,23,14,79,242,176,79,14,177,241,63,83,193,172,83,63,173,192,236,73,20,182,74,236,182,19,2,88,254,167,88,2,168,253,93,93,163,162,204,60,52,195,61,204,195,51,52,120,204,135,120,52,136,203,211,74,45,181,75,211,181,44,75,125,181,130,125,75,131,180,33,122,223,133,122,33,134,222,243,102,13,153,103,243,153,12,216,95,40,160,96,216,160,39,222,126,34,129,127,222,129,33,167,88,89,167,178,104,78,151,105,178,151,77,12,12,244,243,23,23,233,232,42,42,214,213,73,73,183,182,0,0,168,50,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,50,33,0,224,10,32,0,36,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,110,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,50,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,90,33,0,108,0,0,0,232,77,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,57,35,0,240,240,34,0,0,0,0,0,0,0,0,0,104,60,35,0,56,243,34,0,0,0,0,0,0,0,0,0,1,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,255,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,18,18,254,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,254,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,255,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,17,2,253,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,17,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,255,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,255,2,18,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,2,1,7,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,253,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,2,3,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,1,4,6,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,17,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,2,1,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,255,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,255,17,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,2,3,255,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,5,254,18,18,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,255,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,4,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,18,2,2,18,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,2,1,7,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,253,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,17,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,2,3,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,17,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,3,5,4,7,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,254,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,4,3,1,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,18,17,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,2,254,18,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,255,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,2,1,7,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,18,254,2,18,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,18,18,254,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,3,4,5,7,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,255,2,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,2,3,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,4,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,4,18,18,254,2,18,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,2,1,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,1,4,6,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,3,6,255,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,17,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,253,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,18,253,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,17,2,253,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,5,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,255,2,254,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,17,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,4,3,18,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,255,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,18,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,254,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,17,2,254,18,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,4,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,18,2,2,18,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,254,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,2,18,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,18,2,254,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,254,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,18,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,18,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,17,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,255,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,254,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,255,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,18,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,17,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,254,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,17,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,3,18,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,17,2,253,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,18,2,4,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,18,3,254,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,18,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,254,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,255,255,2,17], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1389752);
/* memory initializer */ allocate([1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,2,3,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,2,254,18,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,3,5,4,7,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,254,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,18,2,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,18,3,254,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,17,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,254,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,253,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,253,2,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,17,1,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,4,3,1,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,253,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,3,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,254,18,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,17,1,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,255,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,51,51,0,102,102,102,0,153,153,153,0,204,204,204,0,255,255,255,0,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,0,0,51,51,0,0,102,102,0,0,153,153,0,0,204,204,0,0,255,255,0,51,51,0,0,102,102,0,0,153,153,0,0,204,204,0,0,255,255,0,0,51,0,51,0,102,0,102,0,153,0,153,0,204,0,204,0,255,0,255,0,51,255,255,0,102,255,255,0,153,255,255,0,204,255,255,0,255,51,255,0,255,102,255,0,255,153,255,0,255,204,255,0,255,255,51,0,255,255,102,0,255,255,153,0,255,255,204,0,51,204,204,0,102,204,204,0,153,204,204,0,255,204,204,0,204,51,204,0,204,102,204,0,204,153,204,0,204,255,204,0,204,204,51,0,204,204,102,0,204,204,153,0,204,204,255,0,51,153,153,0,102,153,153,0,204,153,153,0,255,153,153,0,153,51,153,0,153,102,153,0,153,204,153,0,153,255,153,0,153,153,51,0,153,153,102,0,153,153,204,0,153,153,255,0,51,102,102,0,153,102,102,0,204,102,102,0,255,102,102,0,102,51,102,0,102,153,102,0,102,204,102,0,102,255,102,0,102,102,51,0,102,102,153,0,102,102,204,0,102,102,255,0,102,51,51,0,153,51,51,0,204,51,51,0,255,51,51,0,51,102,51,0,51,153,51,0,51,204,51,0,51,255,51,0,51,51,102,0,51,51,153,0,51,51,204,0,51,51,255,0,102,51,0,0,0,102,51,0,51,0,102,0,51,102,0,0,102,0,51,0,0,51,102,0,153,102,51,0,51,153,102,0,102,51,153,0,102,153,51,0,153,51,102,0,51,102,153,0,204,153,102,0,102,204,153,0,153,102,204,0,153,204,102,0,204,102,153,0,102,153,204,0,255,204,153,0,153,255,204,0,204,153,255,0,204,255,153,0,255,153,204,0,153,204,255,0,17,17,17,0,34,34,34,0,68,68,68,0,85,85,85,0,170,170,170,0,187,187,187,0,221,221,221,0,238,238,238,0,16,16,16,16,17,18,21,24,16,16,16,16,17,19,22,25,16,16,17,18,20,22,25,29,16,16,18,21,24,27,31,36,17,17,20,24,30,35,41,47,18,19,22,27,35,44,54,65,21,22,25,31,41,54,70,88,24,25,29,36,47,65,88,115,16,16,16,16,17,18,20,24,16,16,16,17,18,20,24,25,16,16,17,18,20,24,25,28,16,17,18,20,24,25,28,33,17,18,20,24,25,28,33,41,18,20,24,25,28,33,41,54,20,24,25,28,33,41,54,71,24,25,28,33,41,54,71,91,6,10,13,16,18,23,25,27,10,11,16,18,23,25,27,29,13,16,18,23,25,27,29,31,16,18,23,25,27,29,31,33,18,23,25,27,29,31,33,36,23,25,27,29,31,33,36,38,25,27,29,31,33,36,38,40,27,29,31,33,36,38,40,42,9,13,15,17,19,21,22,24,13,13,17,19,21,22,24,25,15,17,19,21,22,24,25,27,17,19,21,22,24,25,27,28,19,21,22,24,25,27,28,30,21,22,24,25,27,28,30,32,22,24,25,27,28,30,32,33,24,25,27,28,30,32,33,35,6,13,20,28,13,20,28,32,20,28,32,37,28,32,37,42,10,14,20,24,14,20,24,27,20,24,27,30,24,27,30,34,5,3,3,0,0,4,4,1,0,5,5,2,0,6,6,3,4,2,2,0,0,4,4,2,0,5,5,3,0,7,7,5,5,3,3,0,0,4,4,1,0,5,5,2,0,6,6,3,8,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,8,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,8,0,8,8,12,0,13,13,17,0,17,17,21,3,1,1,0,0,4,4,2,0,6,6,5,0,9,9,7,0,0,128,63,252,255,52,63,252,255,52,191,252,255,52,63,252,255,52,63,0,0,20,63,252,255,52,63,248,255,209,62,0,0,20,63,252,255,52,191,248,255,209,62,0,0,20,63,0,0,0,0,252,255,80,191,0,0,0,63,4,0,39,63,0,0,0,63,248,255,137,62,0,0,0,63,248,255,137,62,0,0,0,191,4,0,39,191,0,0,0,63,248,255,137,190,0,0,0,191,4,0,39,63,0,0,0,63,4,0,39,191,0,0,0,63,248,255,137,190,239,255,227,62,248,255,25,63,4,0,3,63,8,0,190,62,222,255,71,62,239,255,227,62,8,0,190,62,222,255,71,190,248,255,25,191,4,0,3,191,239,255,227,62,0,0,0,0,248,255,33,191,0,0,0,0,248,255,33,63,239,255,227,62,8,0,190,190,222,255,71,190,248,255,25,63,4,0,3,191,239,255,227,62,248,255,25,191,4,0,3,63,8,0,190,190,222,255,71,62,248,255,209,62,4,0,15,63,0,0,0,63,248,255,209,62,239,255,147,62,34,0,24,62,248,255,209,62,248,255,209,62,0,0,0,0,248,255,209,190,0,0,20,191,248,255,209,190,248,255,209,62,34,0,24,62,0,0,0,191,248,255,209,190,239,255,147,62,4,0,15,63,248,255,209,62,34,0,24,190,0,0,0,191,248,255,209,62,239,255,147,62,4,0,15,191,248,255,209,62,248,255,209,190,0,0,0,0,248,255,209,62,0,0,20,191,248,255,209,62,248,255,209,62,4,0,15,191,0,0,0,63,248,255,209,190,239,255,147,62,34,0,24,190,0,0,0,0,0,0,0,0,160,101,21,0,164,101,21,0,180,101,21,0,216,101,21,0,24,102,21,0,124,102,21,0,0,0,0,0,0,0,0,4,0,1,0,8,0,2,0,8,0,3,0,8,0,0,0,3,0,1,0,8,0,2,0,8,0,3,0,8,0,0,0,4,0,3,0,8,0,2,0,8,0,1,0,8,0,0,0,4,0,17,0,8,0,1,0,8,0,2,0,8,0,0,0,4,0,17,0,8,0,3,0,8,0,2,0,8,168,7,20,0,16,79,21,0,80,102,14,0,176,22,2,0,0,1,0,1,0,1,0,1,2,5,10,16,0,0,0,0,96,57,35,0,108,0,0,0,112,126,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,2,0,0,130,1,0,0,190,0,0,0,70,2,0,0,2,1,0,0,46,0,0,0,164,0,0,0,138,2,0,0,0,0,0,0,3,0,0,0,6,0,0,0,12,0,0,0,24,0,0,0,48,0,0,0,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,3,3,3,3,2,2,2,1,1,1,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,3,3,3,3,2,2,2,1,1,1,0,0,0,0,0,0,0,8,0,8,12,8,12,14,12,14,15,14,15,0,0,0,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,2,2,1,3,5,5,5,5,5,5,5,5,5,5,2,2,1,3,5,5,5,5,5,5,5,5,5,5,1,1,0,3,5,5,5,5,5,5,5,5,5,5,3,3,3,4,0,0,0,0,0,0,8,8,8,12,12,12,14,14,14,15,15,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,2,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,64,0,0,64,64,0,0,128,64,0,0,160,64,0,0,192,64,0,0,224,64,0,0,0,65,0,0,16,65,0,0,32,65,0,0,48,65,0,0,64,65,0,0,80,65,0,0,96,65,0,0,112,65,1,0,2,0,3,0,4,0,3,0,3,0,0,0,0,0,1,0,2,0,3,0,4,0,11,0,43,0,0,0,0,0,1,0,2,0,3,0,4,0,11,0,235,0,0,0,0,0,1,0,2,0,3,0,4,0,11,0,235,3,0,0,0,0,0,1,2,3,4,5,5,4,4,3,3,4,4,4,5,5,4,4,4,4,3,3,6,7,7,7,8,9,10,9,8,7,7,6,11,12,13,11,6,7,8,9,14,10,9,8,6,11,12,13,11,6,9,14,10,9,11,12,13,11,14,10,12,0,1,1,2,2,3,3,4,5,6,7,7,7,8,4,5,6,9,10,10,8,11,12,11,9,9,10,10,8,11,12,11,9,9,10,10,8,11,12,11,9,9,10,10,8,13,13,9,9,10,10,8,13,13,9,9,10,10,14,14,14,14,14,0,0,105,0,0,0,120,0,0,0,134,0,0,0,149,0,0,0,152,0,0,0,146,1,0,0,228,1,0,0,243,1,0,0,1,2,0,0,148,2,0,0,16,2,0,0,31,2,0,0,45,2,0,0,206,2,0,0,21,1,0,0,36,1,0,0,50,1,0,0,65,1,0,0,68,1,0,0,180,1,0,0,8,3,0,0,23,3,0,0,37,3,0,0,163,2,0,0,52,3,0,0,67,3,0,0,81,3,0,0,221,2,0,0,0,0,1,1,2,2,2,0,166,0,0,0,181,0,0,0,195,0,0,0,210,0,0,0,213,0,0,0,161,1,0,0,60,2,0,0,75,2,0,0,89,2,0,0,178,2,0,0,104,2,0,0,119,2,0,0,133,2,0,0,236,2,0,0,82,1,0,0,97,1,0,0,111,1,0,0,126,1,0,0,129,1,0,0,195,1,0,0,96,3,0,0,111,3,0,0,125,3,0,0,187,2,0,0,140,3,0,0,155,3,0,0,169,3,0,0,245,2,0,0,5,5,5,5,6,7,8,9,5,5,5,5,6,7,8,8,1,2,3,3,4,5,6,7,4,4,4,4,5,6,7,7,227,0,0,0,237,0,0,0,247,0,0,0,1,1,0,0,10,1,0,0,170,1,0,0,184,3,0,0,194,3,0,0,204,3,0,0,196,2,0,0,214,3,0,0,224,3,0,0,234,3,0,0,254,2,0,0,1,2,3,4,0,0,0,0,55,197,17,242,242,55,197,17,17,242,55,197,197,17,242,55,0,180,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,8,0,0,20,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,39,35,0,56,225,34,0,80,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,57,64,16,0,1,0,0,0,0,0,136,163,34,0,128,103,34,0,88,0,0,0,3,0,0,0,154,153,153,153,153,153,241,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,24,48,34,0,200,0,34,0,96,0,0,0,3,0,0,0,0,0,0,0,0,0,46,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,184,210,33,0,80,173,33,0,120,0,0,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,24,142,33,0,0,108,33,0,124,0,0,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,48,43,33,0,120,4,33,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,120,233,32,0,8,207,32,0,132,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,122,33,0,108,0,0,0,120,108,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,112,137,0,255,9,47,15,10,0,0,0,100,0,0,0,232,3,0,0,16,39,0,0,160,134,1,0,64,66,15,0,128,150,152,0,0,225,245,5,56,135,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,16,32,0,216,53,31,0,32,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,16,0,1,0,0,0,0,0,200,131,30,0,216,53,31,0,32,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,16,0,1,0,0,0,0,0,112,243,29,0,112,133,29,0,108,0,0,0,1,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,64,16,0,1,0,0,0,0,0,72,43,29,0,64,219,28,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,16,214,35,0,64,219,28,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,135,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,0,0,0,0,150,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,128,33,0,108,0,0,0,200,110,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,128,2,0,3,2,5,2,7,132,9,8,12,186,14,102,17,244,20,252,20,4,21,12,21,16,21,20,21,36,21,44,21,52,21,84,21,116,21,132,21,196,21,228,21,36,22,164,22,228,22,4,23,12,25,12,26,140,26,140,28,140,29,140,30,140,31,172,33,172,35,172,36,182,38,182,39,184,41,188,43,206,45,208,47,208,49,242,51,242,53,246,55,248,57,140,60,150,62,156,64,6,67,14,69,88,71,108,73,152,75,214,77,244,79,224,83,126,87,230,89,70,92,0,0,0,0,0,0,1,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,0,0,128,63,0,0,144,63,0,0,160,63,0,0,184,63,1,2,2,2,2,3,2,3,2,3,2,3,1,3,2,3,0,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,4,0,0,0,12,0,0,0,255,255,255,255,255,255,255,255,2,0,0,0,255,255,255,255,111,18,131,58,37,206,138,58,19,16,147,58,56,216,155,58,8,5,165,58,157,217,174,58,106,52,185,58,110,21,196,58,198,191,207,58,228,17,220,58,200,11,233,58,141,240,246,58,140,190,2,59,66,122,10,59,48,188,18,59,199,98,27,59,94,160,36,59,44,100,46,59,50,174,56,59,253,159,67,59,143,57,79,59,172,139,91,59,144,133,104,59,199,72,118,59,12,115,130,59,195,46,138,59,233,95,146,59,229,14,155,59,180,59,164,59,31,247,173,59,37,65,184,59,240,50,195,59,30,196,206,59,17,253,218,59,245,246,231,59,44,186,245,59,91,35,2,60,224,218,9,60,213,7,18,60,109,174,26,60,10,215,35,60,67,142,45,60,23,212,55,60,78,185,66,60,24,66,78,60,11,123,90,60,139,108,103,60,45,35,117,60,195,213,129,60,253,134,137,60,167,173,145,60,244,77,154,60,121,116,163,60,79,35,173,60,241,100,183,60,221,67,194,60,92,198,205,60,236,246,217,60,34,226,230,60,96,144,244,60,30,135,1,61,244,78,5,61,38,52,9,61,168,53,13,61,134,84,17,61,218,146,21,61,174,241,25,61,248,111,30,61,220,16,35,61,78,211,39,61,115,186,44,61,63,197,49,61,203,245,54,61,47,78,60,61,96,205,65,61,129,118,71,61,149,73,77,61,166,71,83,61,205,114,89,61,37,205,95,61,159,85,102,61,98,15,109,61,122,251,115,61,0,28,123,61,122,56,129,61,55,254,132,61,68,224,136,61,173,223,140,61,248,252,144,61,172,56,149,61,213,147,153,61,6,16,158,61,197,173,162,61,152,109,167,61,152,81,172,61,62,89,177,61,43,135,182,61,228,219,187,61,239,87,193,61,101,253,198,61,205,204,204,61,185,199,210,61,53,239,216,61,212,68,223,61,42,202,229,61,187,127,236,61,161,103,243,61,111,131,250,61,24,234,0,62,188,173,4,62,109,141,8,62,55,138,12,62,227,164,16,62,248,221,20,62,9,55,25,62,87,176,29,62,241,74,34,62,37,8,39,62,188,232,43,62,7,238,48,62,139,24,54,62,90,188,56,62,219,105,59,62,83,33,62,62,193,226,64,62,104,174,67,62,140,132,70,62,44,101,73,62,139,80,76,62,170,70,79,62,15,72,82,62,51,84,85,62,223,107,88,62,210,142,91,62,144,189,94,62,26,248,97,62,180,62,101,62,92,145,104,62,86,240,107,62,230,91,111,62,11,212,114,62,75,89,118,62,100,235,121,62,219,138,125,62,216,155,128,62,20,121,130,62,32,93,132,62,98,72,134,62,184,58,136,62,34,52,138,62,5,53,140,62,62,61,142,62,18,77,144,62,161,100,146,62,203,131,148,62,243,170,150,62,249,217,152,62,65,17,155,62,169,80,157,62,82,152,159,62,163,232,161,62,120,65,164,62,245,162,166,62,57,13,169,62,136,128,171,62,5,253,173,62,174,130,176,62,165,17,179,62,13,170,181,62,39,76,184,62,22,248,186,62,218,173,189,62,181,109,192,62,202,55,195,62,57,12,198,62,37,235,200,62,174,212,203,62,25,201,206,62,101,200,209,62,212,210,212,62,171,232,215,62,200,9,219,62,143,54,222,62,34,111,225,62,196,179,228,62,83,4,232,62,86,97,235,62,205,202,238,62,217,64,242,62,223,195,245,62,223,83,249,62,250,240,252,62,203,77,0,63,233,41,2,63,233,12,4,63,236,246,5,63,4,232,7,63,97,224,9,63,5,224,11,63,16,231,13,63,148,245,15,63,212,11,18,63,191,41,20,63,135,79,22,63,78,125,24,63,37,179,26,63,61,241,28,63,151,55,31,63,102,134,33,63,202,221,35,63,230,61,38,63,202,166,40,63,152,24,43,63,129,147,45,63,152,23,48,63,13,165,50,63,247,4,53,63,123,220,55,63,182,134,58,63,231,58,61,63,14,249,63,63,110,193,66,63,41,148,69,63,80,113,72,63,20,89,75,63,169,75,78,63,48,73,81,63,202,81,84,63,170,101,87,63,241,132,90,63,209,175,93,63,125,230,96,63,7,41,100,63,175,119,103,63,154,210,106,63,247,57,110,63,251,173,113,63,199,46,117,63,157,188,120,63,159,87,124,63,0,0,128,63,0,0,0,0,247,4,53,63,247,4,53,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,77,0,63,203,77,0,63,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,203,77,0,63,203,77,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,77,0,63,203,77,0,63,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,203,77,0,63,203,77,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,203,77,0,63,0,0,0,0,0,0,0,0,203,77,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,77,0,63,203,77,0,63,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,203,77,0,63,0,0,0,0,0,0,0,0,203,77,0,63,0,0,0,0,0,0,0,0,16,203,30,0,108,0,0,0,64,135,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,7,1,0,0,0,0,0,0,3,6,0,0,0,0,0,0,7,6,0,0,0,0,0,0,195,6,0,0,0,0,0,0,55,1,0,0,0,0,0,0,244,1,0,0,0,0,0,0,199,6,0,0,0,0,0,0,243,6,0,0,0,0,0,0,199,7,0,0,0,0,0,0,1,2,2,2,2,3,3,4,4,5,6,6,6,7,8,8,0,1,255,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,2,0,1,3,255,255,255,255,255,0,1,2,3,255,255,255,255,255,2,0,1,3,4,255,255,255,255,0,1,3,4,2,255,255,255,255,2,0,1,4,5,3,255,255,255,2,3,0,1,5,6,4,255,255,2,0,1,3,4,5,6,255,255,0,5,3,4,1,2,6,255,255,3,2,4,0,1,6,7,5,255,4,5,0,1,7,2,8,3,6,3,2,4,0,1,5,8,7,6,0,255,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,2,0,1,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,2,0,1,3,255,255,255,255,255,0,1,2,3,255,255,255,255,255,2,0,1,3,4,255,255,255,255,2,3,0,1,4,5,255,255,255,2,0,1,3,4,5,255,255,255,0,5,3,4,1,2,255,255,255,3,2,4,0,1,5,6,255,255,4,5,0,1,6,2,7,3,255,3,2,4,0,1,5,7,6,255,0,2,255,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,2,0,1,4,255,255,255,255,255,0,1,3,4,255,255,255,255,255,2,0,1,4,5,255,255,255,255,0,1,4,5,3,255,255,255,255,2,0,1,5,6,4,255,255,255,3,4,0,1,6,7,5,255,255,2,0,1,4,5,6,7,255,255,0,6,4,5,2,3,7,255,255,4,2,5,0,1,7,8,6,255,5,6,0,1,8,3,9,4,7,4,2,5,0,1,6,9,8,7,0,255,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,2,0,1,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,2,0,1,4,255,255,255,255,255,0,1,3,4,255,255,255,255,255,2,0,1,4,5,255,255,255,255,3,4,0,1,5,6,255,255,255,2,0,1,4,5,6,255,255,255,0,6,4,5,2,3,255,255,255,4,2,5,0,1,6,7,255,255,5,6,0,1,7,3,8,4,255,4,2,5,0,1,6,8,7,255,0,125,0,0,192,218,0,0,0,250,0,0,0,119,1,0,128,181,1,0,0,244,1,0,0,238,2,0,0,107,3,0,0,232,3,0,0,226,4,0,0,220,5,0,0,214,6,0,0,208,7,0,0,202,8,0,0,196,9,0,0,184,11,0,0,172,13,0,0,160,15,0,0,148,17,0,0,136,19,0,0,130,20,0,0,124,21,0,128,136,21,0,0,118,22,0,0,112,23,0,0,76,29,0,0,64,31,0,0,224,46,0,0,152,58,0,1,0,0,0,2,0,0,0,3,0,0,0,0,125,0,0,192,218,0,0,0,250,0,0,0,119,1,0,128,181,1,0,0,244,1,0,0,238,2,0,0,107,3,0,0,232,3,0,0,226,4,0,0,220,5,0,0,214,6,0,0,208,7,0,0,202,8,0,0,196,9,0,0,184,11,0,0,172,13,0,0,160,15,0,0,148,17,0,0,136,19,0,0,130,20,0,0,124,21,0,128,136,21,0,0,118,22,0,0,112,23,0,0,76,29,0,0,64,31,0,0,224,46,0,0,152,58,0,1,0,0,0,2,0,0,0,3,0,0,0,59,12,113,18,10,30,54,42,48,54,111,64,40,77,244,86,140,99,70,108,0,0,0,0,0,1,2,3,4,5,7,9,13,17,25,33,49,65,97,129,193,0,0,0,0,0,0,0,4,40,40,77,77,112,112,0,4,40,40,77,77,112,112,0,45,0,6,0,38,0,7,0,102,1,9,0,78,0,8,0,206,2,10,0,158,5,11,0,125,2,11,0,8,0,5,0,249,4,12,0,15,0,4,0,14,0,4,0,27,0,5,0,6,0,4,0,8,0,4,0,5,0,4,0,26,0,5,0,21,0,5,0,7,0,4,0,12,0,4,0,1,0,3,0,0,0,3,0,9,0,4,0,23,0,5,0,41,0,6,0,40,0,6,0,178,0,8,0,248,4,12,0,159,5,11,0,158,0,9,0,63,1,10,0,18,0,6,0,88,0,7,0,16,0,5,0,71,0,7,0,255,1,9,0,140,0,8,0,252,3,10,0,106,4,11,0,105,4,11,0,34,0,6,0,161,17,13,0,14,0,4,0,13,0,4,0,4,0,4,0,5,0,4,0,9,0,4,0,6,0,4,0,30,0,5,0,22,0,5,0,7,0,4,0,12,0,4,0,1,0,3,0,0,0,3,0,10,0,4,0,23,0,5,0,125,0,7,0,126,0,7,0,27,1,9,0,209,8,12,0,253,3,10,0,107,4,11,0,160,17,13,0,124,0,7,0,254,0,8,0,22,0,5,0,32,0,6,0,134,0,8,0,135,0,8,0,103,3,10,0,204,6,11,0,203,6,11,0,110,0,7,0,109,54,14,0,15,0,4,0,14,0,4,0,4,0,4,0,5,0,4,0,10,0,4,0,6,0,4,0,26,0,5,0,17,0,5,0,7,0,4,0,12,0,4,0,1,0,3,0,0,0,3,0,9,0,4,0,23,0,5,0,111,0,7,0,109,0,7,0,100,3,10,0,154,13,12,0,202,6,11,0,55,27,13,0,108,54,14,0,66,0,7,0,216,0,8,0,0,0,4,0,45,0,6,0,247,0,8,0,88,0,7,0,103,1,9,0,203,2,10,0,202,2,10,0,14,0,6,0,97,22,13,0,3,0,3,0,2,0,3,0,8,0,4,0,9,0,4,0,13,0,4,0,2,0,4,0,31,0,5,0,23,0,5,0,1,0,4,0,12,0,4,0,14,0,4,0,10,0,4,0,6,0,5,0,120,0,7,0,15,0,6,0,122,0,7,0,100,1,9,0,153,5,11,0,205,2,10,0,49,11,12,0,96,22,13,0,121,0,7,0,246,0,8,0,3,0,4,0,60,0,6,0,15,0,7,0,122,0,7,0,29,0,8,0,32,0,9,0,114,0,10,0,6,0,6,0,153,3,13,0,4,0,3,0,5,0,3,0,5,0,4,0,6,0,4,0,14,0,4,0,4,0,4,0,0,0,4,0,25,0,5,0,2,0,4,0,13,0,4,0,7,0,4,0,31,0,5,0,48,0,6,0,17,0,8,0,49,0,6,0,5,0,6,0,33,0,9,0,231,0,11,0,56,0,9,0,205,1,12,0,152,3,13,0,123,0,7,0,9,0,7,0,9,0,4,0,2,0,5,0,116,0,7,0,7,0,6,0,236,0,8,0,209,0,9,0,166,1,10,0,6,0,6,0,33,13,13,0,5,0,3,0,6,0,3,0,8,0,4,0,7,0,4,0,15,0,4,0,4,0,4,0,0,0,4,0,28,0,5,0,2,0,4,0,5,0,4,0,3,0,4,0,12,0,5,0,53,0,7,0,167,1,10,0,27,0,6,0,119,0,7,0,165,1,10,0,73,3,11,0,208,0,9,0,145,6,12,0,32,13,13,0,117,0,7,0,237,0,8,0,10,0,4,0,12,0,5,0,18,0,6,0,27,0,6,0,183,0,8,0,108,1,9,0,153,0,9,0,90,0,7,0,216,22,13,0,7,0,3,0,6,0,3,0,9,0,4,0,8,0,4,0,0,0,3,0,5,0,4,0,23,0,5,0,14,0,5,0,2,0,4,0,3,0,4,0,15,0,5,0,26,0,6,0,77,0,8,0,179,45,14,0,44,0,6,0,17,0,6,0,218,2,10,0,183,5,11,0,152,0,9,0,109,11,12,0,178,45,14,0,16,0,6,0,39,0,7,0,13,0,4,0,15,0,5,0,29,0,6,0,8,0,5,0,81,0,7,0,86,0,8,0,175,0,9,0,42,0,7,0,138,20,13,0,7,0,3,0,0,0,2,0,8,0,4,0,9,0,4,0,12,0,4,0,6,0,4,0,23,0,5,0,11,0,5,0,22,0,5,0,21,0,5,0,9,0,5,0,80,0,7,0,174,0,9,0,23,41,14,0,28,0,6,0,20,0,6,0,144,2,10,0,35,5,11,0,73,1,9,0,68,10,12,0,22,41,14,0,83,0,7,0,165,0,8,0,1,0,4,0,29,0,6,0,245,0,8,0,244,0,8,0,77,2,10,0,153,4,11,0,152,4,11,0,1,0,5,0,33,0,6,0,6,0,3,0,5,0,3,0,6,0,4,0,5,0,4,0,2,0,4,0,7,0,5,0,37,0,6,0,123,0,7,0,28,0,6,0,32,0,6,0,13,0,6,0,72,0,7,0,146,0,8,0,39,1,9,0,14,0,4,0,4,0,4,0,17,0,5,0,12,0,6,0,60,0,6,0,15,0,5,0,0,0,5,0,31,0,5,0,19,0,5,0,5,0,4,0,60,0,6,0,64,0,7,0,13,0,7,0,49,0,9,0,97,0,10,0,96,0,10,0,2,0,5,0,245,0,8,0,6,0,3,0,5,0,3,0,7,0,4,0,6,0,4,0,2,0,4,0,9,0,5,0,37,0,6,0,7,0,6,0,33,0,6,0,36,0,6,0,16,0,6,0,65,0,7,0,244,0,8,0,25,0,8,0,14,0,4,0,3,0,4,0,17,0,5,0,17,0,6,0,63,0,6,0,62,0,6,0,123,0,7,0,0,0,4,0,19,0,5,0,10,0,4,0,7,0,5,0,1,0,6,0,9,0,6,0,49,1,9,0,97,2,10,0,96,2,10,0,21,0,6,0,1,0,7,0,7,0,3,0,6,0,3,0,8,0,4,0,7,0,4,0,6,0,4,0,18,0,5,0,47,0,6,0,20,0,6,0,39,0,6,0,45,0,6,0,22,0,6,0,77,0,7,0,153,0,8,0,0,0,7,0,4,0,4,0,1,0,4,0,5,0,5,0,23,0,6,0,46,0,6,0,44,0,6,0,8,0,6,0,6,0,5,0,1,0,5,0,0,0,3,0,14,0,5,0,23,0,6,0,42,0,6,0,16,0,7,0,249,0,10,0,248,0,10,0,30,0,7,0,63,0,8,0,7,0,3,0,6,0,3,0,9,0,4,0,8,0,4,0,6,0,4,0,15,0,5,0,5,0,5,0,22,0,6,0,41,0,6,0,43,0,6,0,21,0,6,0,80,0,7,0,17,0,7,0,125,0,9,0,4,0,4,0,23,0,5,0,6,0,5,0,20,0,6,0,44,0,6,0,45,0,6,0,14,0,6,0,9,0,6,0,81,0,7,0,2,0,3,0,24,0,5,0,47,0,6,0,13,0,5,0,83,0,7,0,149,2,10,0,148,2,10,0,164,0,8,0,124,0,8,0,0,0,2,0,7,0,3,0,9,0,4,0,8,0,4,0,27,0,5,0,12,0,5,0,40,0,6,0,106,0,7,0,30,0,6,0,29,0,6,0,105,0,7,0,215,0,8,0,125,0,8,0,75,1,9,0,25,0,5,0,22,0,5,0,46,0,6,0,28,0,6,0,43,0,6,0,42,0,6,0,104,0,7,0,63,0,7,0,214,0,8,0,2,0,3,0,27,0,5,0,12,0,5,0,24,0,5,0,41,0,6,0,127,0,8,0,240,2,10,0,152,1,9,0,121,1,9,0,0,0,2,0,7,0,3,0,9,0,4,0,8,0,4,0,26,0,5,0,13,0,5,0,42,0,6,0,100,0,7,0,30,0,6,0,103,0,7,0,95,0,7,0,205,0,8,0,126,0,8,0,241,2,10,0,22,0,5,0,14,0,5,0,46,0,6,0,101,0,7,0,43,0,6,0,40,0,6,0,62,0,7,0,189,0,8,0,153,1,9,0,2,0,3,0,7,0,4,0,22,0,5,0,6,0,4,0,54,0,6,0,92,0,7,0,93,1,9,0,92,1,9,0,191,2,10,0,0,0,2,0,7,0,3,0,9,0,4,0,8,0,4,0,24,0,5,0,52,0,6,0,42,0,6,0,94,0,7,0,106,0,7,0,100,0,7,0,93,0,7,0,203,0,8,0,173,0,8,0,190,2,10,0,20,0,5,0,51,0,6,0,110,0,7,0,95,0,7,0,111,0,7,0,107,0,7,0,202,0,8,0,172,0,8,0,94,1,9,0,15,0,4,0,29,0,5,0,24,0,5,0,11,0,4,0,25,0,5,0,41,0,6,0,214,0,8,0,81,5,11,0,161,10,12,0,1,0,2,0,0,0,2,0,9,0,4,0,8,0,4,0,27,0,5,0,56,0,6,0,40,0,6,0,87,0,7,0,106,0,7,0,104,0,7,0,86,0,7,0,229,0,8,0,85,1,9,0,160,10,12,0,115,0,7,0,105,0,7,0,215,0,8,0,171,0,8,0,228,0,8,0,169,0,8,0,81,1,9,0,80,1,9,0,169,2,10,0,255,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,17,18,19,20,21,22,23,24,25,26,27,28,29,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,22,23,24,25,26,27,28,29,30,31,32,32,188,154,16,255,0,0,0,0,1,86,1,1,1,0,1,52,2,6,0,0,1,24,3,9,0,0,193,10,4,12,0,0,33,5,5,29,0,0,33,2,38,33,0,0,1,86,7,6,1,0,1,84,8,14,0,0,1,72,9,14,0,0,1,56,10,14,0,0,1,48,11,17,0,0,1,36,12,18,0,0,1,28,13,20,0,0,1,22,29,21,0,0,1,86,15,14,1,0,1,84,16,14,0,0,1,81,17,15,0,0,1,72,18,16,0,0,1,56,19,17,0,0,1,52,20,18,0,0,1,48,21,19,0,0,1,40,22,19,0,0,1,36,23,20,0,0,1,34,24,21,0,0,1,28,25], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1400003);
/* memory initializer */ allocate([22,0,0,1,24,26,23,0,0,1,22,27,24,0,0,1,20,28,25,0,0,1,18,29,26,0,0,1,17,30,27,0,0,193,10,31,28,0,0,193,9,32,29,0,0,161,8,33,30,0,0,33,5,34,31,0,0,65,4,35,32,0,0,161,2,36,33,0,0,33,2,37,34,0,0,65,1,38,35,0,0,17,1,39,36,0,0,133,0,40,37,0,0,73,0,41,38,0,0,37,0,42,39,0,0,21,0,43,40,0,0,9,0,44,41,0,0,5,0,45,42,0,0,1,0,45,43,0,0,1,86,46,46,0,0,0,0,0,0,0,0,0,0,8,0,9,0,52,0,10,0,53,0,54,0,246,0,11,0,55,0,56,0,247,0,57,0,250,1,248,0,252,3,12,0,58,0,122,0,249,0,59,0,251,1,250,0,254,7,60,0,252,1,251,0,253,3,252,0,254,3,253,1,255,7,0,0,4,0,240,0,5,0,18,0,240,1,241,1,232,3,206,63,6,0,48,0,222,7,19,0,49,0,210,15,233,3,223,7,176,127,242,1,224,7,177,127,234,3,210,31,178,127,207,63,179,127,49,0,7,0,50,0,211,15,51,0,112,0,212,15,213,15,214,15,180,127,20,0,113,0,211,31,52,0,114,0,212,31,215,15,213,31,181,127,235,3,216,15,182,127,225,7,214,31,183,127,184,127,185,127,114,0,241,0,215,31,186,127,226,7,217,15,187,127,188,127,189,127,112,0,236,3,216,31,190,127,218,15,191,127,192,127,193,127,194,127,114,0,195,127,196,127,113,0,197,127,198,127,114,0,52,0,114,0,114,0,8,0,21,0,227,7,22,0,115,0,219,15,228,7,220,15,199,127,53,0,116,0,217,31,117,0,242,0,208,63,221,15,209,63,200,127,229,7,218,31,201,127,222,15,219,31,202,127,203,127,204,127,242,0,23,0,54,0,220,31,118,0,243,0,205,127,223,15,210,63,206,127,55,0,244,0,211,63,119,0,245,0,207,127,212,63,208,127,209,127,224,15,225,15,210,127,226,15,221,31,211,127,212,127,213,127,245,0,243,1,222,31,214,127,227,15,223,31,215,127,216,127,217,127,243,0,230,7,224,31,218,127,225,31,226,31,219,127,220,127,221,127,245,0,213,63,222,127,244,0,223,127,224,127,245,0,119,0,245,0,245,0,246,0,237,3,225,127,231,7,228,15,226,127,227,127,228,127,115,0,238,3,229,15,229,127,230,15,227,31,230,127,231,127,232,127,242,0,214,63,233,127,116,0,234,127,235,127,242,0,117,0,242,0,242,0,247,0,231,15,236,127,232,15,228,31,237,127,238,127,239,127,243,0,232,7,229,31,240,127,230,31,241,127,242,127,243,127,244,127,245,0,245,127,246,127,244,0,247,127,248,127,245,0,119,0,245,0,245,0,215,63,249,127,54,0,250,127,251,127,243,0,118,0,243,0,243,0,252,127,253,127,0,0,254,127,255,127,0,0,0,0,0,0,4,0,108,0,230,3,5,0,18,0,109,0,231,3,110,0,232,0,232,3,196,63,224,7,225,7,164,127,165,127,6,0,19,0,226,1,218,15,20,0,21,0,233,0,219,15,234,0,111,0,233,3,166,127,226,7,227,7,167,127,168,127,112,0,227,1,220,15,169,127,235,0,236,0,221,15,170,127,234,3,235,3,214,31,171,127,197,63,198,63,172,127,214,31,228,7,215,31,173,127,174,127,229,7,216,31,175,127,176,127,199,63,177,127,178,127,214,31,179,127,180,127,214,31,214,31,7,0,22,0,228,1,217,31,23,0,50,0,229,1,218,31,230,1,231,1,230,7,181,127,200,63,219,31,182,127,183,127,8,0,51,0,232,1,222,15,24,0,52,0,233,1,220,31,234,1,237,0,231,7,184,127,221,31,223,15,185,127,186,127,113,0,235,1,224,15,187,127,114,0,238,0,232,7,188,127,236,3,237,3,201,63,189,127,202,63,190,127,191,127,201,63,238,3,225,15,192,127,193,127,233,7,222,31,194,127,195,127,196,127,197,127,198,127,201,63,199,127,200,127,201,63,201,63,53,0,236,1,223,31,203,63,239,0,237,1,226,15,201,127,227,15,228,15,202,127,203,127,204,127,205,127,206,127,202,127,115,0,238,1,224,31,207,127,240,0,239,1,229,15,208,127,234,7,230,15,209,127,210,127,211,127,212,127,213,127,209,127,240,1,235,7,214,127,215,127,241,1,236,7,216,127,217,127,204,63,205,63,218,127,218,127,219,127,220,127,218,127,218,127,206,63,221,127,222,127,214,127,207,63,223,127,224,127,216,127,225,127,226,127,218,127,218,127,204,63,205,63,218,127,218,127,242,1,231,15,227,127,228,127,232,15,225,31,229,127,230,127,231,127,232,127,233,127,202,127,234,127,235,127,202,127,202,127,239,3,233,15,236,127,237,127,234,15,208,63,238,127,239,127,240,127,241,127,242,127,209,127,243,127,244,127,209,127,209,127,209,63,245,127,246,127,214,127,247,127,248,127,249,127,216,127,250,127,251,127,218,127,218,127,204,63,205,63,218,127,218,127,252,127,253,127,214,127,214,127,254,127,255,127,0,0,0,0,0,0,4,0,34,0,198,0,176,3,12,0,13,0,35,0,199,0,177,3,92,0,200,0,201,0,178,3,164,15,194,1,195,1,179,3,165,15,114,127,180,3,178,7,154,31,36,255,37,255,14,0,36,0,202,0,181,3,179,7,15,0,37,0,203,0,182,3,166,15,93,0,94,0,204,0,183,3,155,31,196,1,197,1,184,3,167,15,115,127,168,15,180,7,156,31,38,255,39,255,95,0,198,1,185,3,169,15,116,127,96,0,205,0,186,3,170,15,157,31,199,1,200,1,181,7,158,31,40,255,182,7,183,7,171,15,162,63,41,255,172,15,173,15,163,63,42,255,162,63,201,1,184,7,174,15,43,255,44,255,202,1,187,3,159,31,117,127,45,255,188,3,185,7,175,15,46,255,47,255,160,31,161,31,48,255,49,255,50,255,51,255,52,255,118,127,53,255,49,255,186,7,162,31,54,255,55,255,119,127,187,7,163,31,120,127,56,255,57,255,164,31,165,31,58,255,59,255,46,255,164,63,60,255,61,255,62,255,49,255,63,255,64,255,48,255,49,255,49,255,5,0,38,0,206,0,189,3,166,31,39,0,40,0,207,0,190,3,167,31,203,1,208,0,191,3,176,15,65,255,192,3,193,3,188,7,121,127,66,255,168,31,177,15,165,63,67,255,68,255,16,0,41,0,209,0,189,7,169,31,42,0,43,0,210,0,194,3,170,31,211,0,212,0,204,1,190,7,166,63,195,3,196,3,178,15,179,15,69,255,171,31,180,15,172,31,122,127,70,255,97,0,213,0,205,1,181,15,71,255,98,0,214,0,197,3,182,15,167,63,206,1,207,1,198,3,173,31,72,255,191,7,199,3,183,15,123,127,73,255,174,31,175,31,74,255,75,255,123,127,208,1,192,7,176,31,76,255,77,255,209,1,200,3,184,15,124,127,78,255,201,3,193,7,177,31,79,255,80,255,178,31,185,15,81,255,82,255,83,255,84,255,85,255,86,255,87,255,82,255,194,7,179,31,88,255,89,255,90,255,195,7,180,31,91,255,92,255,93,255,186,15,181,31,125,127,94,255,79,255,95,255,96,255,97,255,98,255,82,255,99,255,100,255,81,255,82,255,82,255,44,0,215,0,196,7,182,31,101,255,216,0,217,0,202,3,187,15,102,255,197,7,203,3,198,7,183,31,103,255,188,15,184,31,185,31,126,127,104,255,105,255,106,255,168,63,107,255,126,127,45,0,218,0,204,3,186,31,108,255,219,0,220,0,205,3,189,15,109,255,206,3,207,3,199,7,187,31,110,255,188,31,190,15,189,31,111,255,112,255,169,63,170,63,171,63,113,255,111,255,221,0,210,1,200,7,190,31,114,255,222,0,211,1,201,7,115,255,172,63,208,3,209,3,191,15,127,127,116,255,192,15,193,15,191,31,117,255,118,255,128,127,119,255,120,255,121,255,117,255,210,3,194,15,129,127,122,255,123,255,211,3,195,15,196,15,173,63,124,255,197,15,198,15,192,31,125,255,126,255,174,63,130,127,127,255,128,255,128,255,129,255,130,255,131,255,128,255,128,255,199,15,131,127,132,127,132,255,122,255,193,31,194,31,133,255,134,255,173,63,175,63,135,255,136,255,137,255,125,255,138,255,139,255,140,255,128,255,128,255,174,63,130,127,127,255,128,255,128,255,223,0,212,3,195,31,133,127,141,255,213,3,202,7,196,31,142,255,143,255,197,31,198,31,176,63,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,149,255,224,0,214,3,203,7,134,127,155,255,212,1,215,3,200,15,156,255,157,255,201,15,202,15,135,127,158,255,159,255,160,255,177,63,161,255,162,255,163,255,164,255,165,255,166,255,167,255,162,255,213,1,204,7,178,63,168,255,169,255,216,3,205,7,199,31,170,255,171,255,179,63,200,31,180,63,172,255,173,255,174,255,136,127,137,127,175,255,175,255,176,255,177,255,178,255,175,255,175,255,206,7,201,31,179,255,180,255,181,255,207,7,202,31,138,127,182,255,183,255,203,31,184,255,185,255,186,255,186,255,187,255,188,255,189,255,190,255,190,255,191,255,192,255,189,255,190,255,190,255,139,127,193,255,194,255,195,255,180,255,181,63,196,255,197,255,198,255,182,255,199,255,200,255,201,255,186,255,186,255,202,255,203,255,189,255,190,255,190,255,187,255,188,255,189,255,190,255,190,255,214,1,204,31,204,255,205,255,206,255,208,7,205,31,207,255,208,255,209,255,182,63,140,127,210,255,211,255,144,255,141,127,212,255,213,255,214,255,149,255,215,255,216,255,148,255,149,255,149,255,215,1,206,31,142,127,143,127,217,255,203,15,207,31,183,63,218,255,219,255,220,255,144,127,221,255,222,255,158,255,223,255,224,255,225,255,226,255,162,255,227,255,228,255,161,255,162,255,162,255,209,7,208,31,145,127,229,255,168,255,204,15,184,63,230,255,231,255,170,255,232,255,233,255,234,255,235,255,172,255,236,255,237,255,238,255,175,255,175,255,174,255,136,127,137,127,175,255,175,255,239,255,240,255,241,255,242,255,180,255,243,255,244,255,245,255,246,255,182,255,247,255,248,255,249,255,186,255,186,255,250,255,251,255,189,255,190,255,190,255,187,255,188,255,189,255,190,255,190,255,252,255,253,255,179,255,180,255,180,255,254,255,255,255,0,0,0,0,10,0,24,0,116,0,242,0,244,1,246,3,4,0,11,0,25,0,117,0,243,0,245,1,247,3,26,0,27,0,56,0,118,0,244,0,248,3,249,3,119,0,57,0,120,0,245,0,246,1,250,3,252,15,246,0,247,0,248,0,247,1,251,3,253,15,254,63,249,0,248,1,249,1,252,3,252,7,254,127,254,255,250,1,253,3,253,7,254,15,254,31,255,255,0,0,8,0,20,0,48,0,106,0,226,0,227,0,228,1,236,3,237,3,9,0,21,0,49,0,107,0,108,0,228,0,229,0,229,1,230,1,240,7,22,0,23,0,50,0,109,0,230,0,231,0,231,1,232,1,238,3,241,7,51,0,52,0,110,0,232,0,233,0,233,1,234,1,239,3,242,7,246,15,111,0,112,0,234,0,235,0,235,1,236,1,240,3,243,7,244,7,250,31,236,0,237,0,238,0,237,1,238,1,241,3,242,3,245,7,247,15,250,63,239,0,240,0,241,0,239,1,243,3,246,7,247,7,248,15,251,31,254,127,240,1,241,1,242,1,244,3,248,7,249,15,250,15,251,63,252,63,0,0,243,1,244,1,245,1,245,3,249,7,251,15,253,63,254,255,0,0,0,0,246,3,247,3,250,7,252,15,252,31,254,63,255,255,0,0,0,0,0,0,0,0,8,0,44,0,45,0,98,0,99,0,212,0,213,0,214,0,198,1,199,1,202,3,214,7,215,7,9,0,20,0,46,0,100,0,101,0,215,0,216,0,200,1,201,1,202,1,203,1,203,3,216,7,217,7,21,0,47,0,102,0,217,0,218,0,204,1,205,1,206,1,207,1,204,3,205,3,206,3,218,7,228,15,48,0,103,0,219,0,208,1,209,1,210,1,211,1,207,3,208,3,209,3,210,3,219,7,229,15,234,31,104,0,105,0,220,0,212,1,213,1,214,1,211,3,212,3,213,3,214,3,220,7,221,7,230,15,235,31,221,0,222,0,215,1,216,1,217,1,215,3,216,3,217,3,218,3,222,7,223,7,231,15,236,31,242,63,223,0,224,0,218,1,219,1,219,3,220,3,224,7,225,7,226,7,232,15,233,15,237,31,238,31,244,127,225,0,226,0,220,1,221,1,221,3,222,3,227,7,228,7,229,7,234,15,235,15,239,31,243,63,245,127,222,1,223,1,224,1,223,3,224,3,225,3,230,7,231,7,236,15,240,31,237,15,244,63,246,127,248,255,225,1,226,1,226,3,227,3,228,3,229,3,232,7,238,15,239,15,245,63,246,63,249,255,250,255,250,255,227,1,228,1,230,3,231,3,233,7,234,7,240,15,241,31,242,31,247,63,248,63,247,127,247,127,250,255,232,3,233,3,234,3,235,7,236,7,241,15,242,15,243,31,248,127,249,127,251,255,248,63,247,127,247,127,237,7,238,7,239,7,243,15,244,31,245,31,246,31,250,127,252,255,253,255,251,255,251,255,248,63,247,127,240,7,241,7,244,15,247,31,248,31,249,63,251,127,254,255,255,255,0,0,64,143,21,0,120,142,21,0,24,142,21,0,88,137,21,0,104,135,21,0,152,133,21,0,88,133,21,0,0,0,0,0,1,4,4,6,4,6,6,8,4,6,6,8,6,9,8,10,4,6,7,8,6,9,8,11,6,9,8,10,8,10,9,11,2,4,8,4,5,9,9,10,14,4,6,11,5,6,12,10,11,15,9,11,15,10,13,15,14,15,0,4,6,12,6,7,12,12,12,15,5,7,13,6,7,13,12,13,15,10,12,15,11,13,15,15,15,0,8,13,15,11,12,15,15,15,0,10,13,15,12,15,15,15,15,0,15,15,0,15,15,0,0,0,0,4,5,11,5,7,12,11,12,15,6,7,13,7,8,14,12,14,15,11,13,15,12,13,15,15,15,0,5,6,13,7,8,15,12,14,15,6,8,14,7,8,15,14,15,15,12,12,15,12,13,15,15,15,0,9,13,15,12,13,15,15,15,0,11,13,15,13,13,15,15,15,0,14,15,0,15,15,0,0,0,0,8,10,15,11,12,15,15,15,0,10,12,15,12,13,15,15,15,0,14,15,0,15,15,0,0,0,0,8,12,15,12,13,15,15,15,0,11,13,15,13,15,15,15,15,0,15,15,0,15,15,0,0,0,0,14,15,0,15,15,0,0,0,0,15,15,0,15,15,0,0,2,4,7,10,4,5,7,10,7,8,10,14,11,11,15,15,4,5,9,12,5,5,8,12,8,7,10,15,11,11,15,15,7,9,12,15,8,8,12,15,10,10,13,15,14,14,15,0,11,13,15,15,11,13,15,15,14,15,15,0,15,15,0,0,4,5,9,13,5,6,9,13,9,9,11,15,14,13,15,15,4,6,9,12,5,6,9,13,9,8,11,15,13,12,15,15,7,9,12,15,7,8,11,15,10,10,14,15,14,15,15,0,10,12,15,15,11,13,15,15,15,15,15,0,15,15,0,0,6,9,13,14,8,9,12,15,12,12,15,15,15,15,15,0,7,9,13,15,8,9,12,15,11,12,15,15,15,15,15,0,9,11,15,15,9,11,15,15,14,14,15,0,15,15,0,0,14,15,15,0,14,15,15,0,15,15,0,0,0,0,0,0,9,12,15,15,12,13,15,15,15,15,15,0,15,15,0,0,10,12,15,15,12,14,15,15,15,15,15,0,15,15,0,0,14,15,15,0,15,15,15,0,15,15,0,0,0,0,0,0,15,15,0,0,15,15,0,0,2,4,6,8,10,5,5,6,8,10,7,8,8,10,12,9,9,10,12,15,10,11,13,16,16,5,6,8,10,11,5,6,8,10,12,7,7,8,10,13,9,9,10,12,15,12,11,13,16,16,7,9,10,12,15,7,8,10,12,13,9,9,11,13,16,11,11,12,14,16,12,12,14,16,0,9,11,12,16,16,9,10,13,15,16,10,11,12,16,16,13,13,16,16,16,16,16,15,16,0,11,13,16,16,15,11,13,15,16,16,13,13,16,16,0,14,16,16,16,0,16,16,0,0,0,4,6,8,10,13,6,6,8,10,13,9,8,10,12,16,10,10,11,15,16,13,12,14,16,16,5,6,8,11,13,6,6,8,10,13,8,8,9,11,14,10,10,12,12,16,13,12,13,15,16,7,8,9,12,16,7,8,10,12,14,9,9,10,13,16,11,10,12,15,16,13,13,16,16,0,9,11,13,16,16,9,10,12,15,16,10,11,13,16,16,13,12,16,16,16,16,16,16,16,0,11,13,16,16,16,11,13,16,16,16,12,13,15,16,0,16,16,16,16,0,16,16,0,0,0,6,8,11,13,16,8,8,10,12,16,11,10,11,13,16,12,13,13,15,16,16,16,14,16,0,6,8,10,13,16,8,8,10,12,16,10,10,11,13,16,13,12,13,16,16,14,14,14,16,0,8,9,11,13,16,8,9,11,16,14,10,10,12,15,16,12,12,13,16,16,15,16,16,16,0,10,12,15,16,16,10,12,12,14,16,12,12,13,16,16,14,15,16,16,0,16,16,16,0,0,12,15,15,16,0,13,13,16,16,0,14,16,16,16,0,16,16,16,0,0,0,0,0,0,0,8,10,13,15,16,10,11,13,16,16,13,13,14,16,16,16,16,16,16,16,16,16,16,16,0,8,10,11,15,16,9,10,12,16,16,12,12,15,16,16,16,14,16,16,16,16,16,16,16,0,9,11,14,16,16,10,11,13,16,16,14,13,14,16,16,16,15,15,16,0,16,16,16,0,0,11,13,16,16,16,11,13,15,16,16,13,16,16,16,0,16,16,16,16,0,16,16,0,0,0,15,16,16,16,0,14,16,16,16,0,16,16,16,0,0,16,16,0,0,0,0,0,0,0,0,9,13,16,16,16,11,13,16,16,16,14,15,16,16,0,15,16,16,16,0,16,16,0,0,0,9,13,15,15,16,12,13,14,16,16,16,15,16,16,0,16,16,16,16,0,16,16,0,0,0,11,13,15,16,0,12,14,16,16,0,16,16,16,16,0,16,16,16,0,0,0,0,0,0,0,16,16,16,16,0,16,16,16,16,0,16,16,16,0,0,16,16,0,0,0,0,0,0,0,0,16,16,0,0,0,16,16,0,1,4,5,7,8,9,10,3,4,5,7,8,9,10,5,5,6,7,8,10,10,7,6,7,8,9,10,12,8,8,8,9,10,12,14,8,9,9,10,11,15,16,9,10,11,12,13,16,1,4,5,6,7,8,8,9,10,10,4,5,6,7,7,8,8,9,9,11,5,5,6,7,8,8,9,9,10,11,6,6,7,8,8,9,9,10,11,12,7,7,8,8,9,9,10,11,11,13,8,8,8,9,9,10,10,11,12,14,8,8,8,9,10,11,11,12,13,15,9,9,9,10,11,12,12,14,14,0,9,9,9,10,11,12,14,16,0,0,10,10,11,12,13,14,16,0,0,0,0,0,0,0,1,4,6,6,7,7,8,8,8,9,9,10,11,11,4,5,6,7,7,8,8,9,9,9,9,10,11,11,5,6,7,8,8,9,9,9,9,10,10,10,11,12,6,7,8,9,9,9,9,10,10,10,10,11,12,13,7,7,8,9,9,9,10,10,10,10,11,11,12,13,8,8,9,9,9,10,10,10,10,11,11,12,13,14,8,8,9,9,10,10,11,11,11,12,12,13,13,15,8,8,9,9,10,10,11,11,11,12,12,13,14,15,9,9,9,10,10,10,11,11,12,13,12,14,15,16,9,9,10,10,10,10,11,12,12,14,14,16,16,0,9,9,10,10,11,11,12,13,13,14,14,15,0,0,10,10,10,11,11,12,12,13,15,15,16,0,0,0,11,11,11,12,13,13,13,15,16,16,0,0,0,0,11,11,12,13,13,14,15,16,16,0,216,149,21,0,112,149,21,0,64,149,21,0,224,146,21,0,232,145,21,0,0,145,21,0,224,144,21,0,0,0,0,0,2,0,0,0,16,0,0,0,16,0,0,0,40,166,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,8,0,0,0,8,0,0,0,32,166,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,1,0,0,0,1,0,0,216,154,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,64,0,0,0,64,0,0,0,176,148,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,128,0,0,0,128,0,0,0,48,148,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,32,0,0,0,32,0,0,0,16,148,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,96,0,0,0,96,0,0,0,176,147,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,32,0,0,0,32,0,0,0,144,147,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,96,0,0,0,96,0,0,0,48,147,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,17,0,0,0,17,0,0,0,24,147,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,32,0,0,0,32,0,0,0,0,166,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,78,0,0,0,78,0,0,0,176,165,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,17,0,0,0,17,0,0,0,152,165,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,32,0,0,0,32,0,0,0,120,165,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,78,0,0,0,78,0,0,0,40,165,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,100,0,0,0,100,0,0,0,192,164,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,105,6,0,0,161,25,0,0,80,158,22,0,1,0,0,0,0,0,128,191,0,0,128,63,176,253,35,0,4,0,0,0,187,1,0,0,113,2,0,0,144,156,22,0,1,0,0,0,0,0,0,192,0,0,128,63,208,252,35,0,4,0,0,0,105,0,0,0,113,2,0,0,32,156,22,0,1,0,0,0,0,0,0,192,0,0,128,63,200,251,35,0,2,0,0,0,68,0,0,0,81,0,0,0,216,155,22,0,1,0,0,0,0,0,128,192,0,0,128,63,144,251,35,0,2,0,0,0,81,0,0,0,81,0,0,0,128,154,22,0,1,0,0,0,0,0,128,192,0,0,128,63,168,250,35,0,2,0,0,0,33,1,0,0,33,1,0,0,88,153,22,0,1,0,0,0,0,0,0,193,0,0,128,63,144,249,35,0,4,0,0,0,81,0,0,0,81,0,0,0,0,153,22,0,1,0,0,0,0,0,48,193,0,0,48,65,32,249,35,0,2,0,0,0,121,0,0,0,121,0,0,0,128,152,22,0,1,0,0,0,0,0,160,192,0,0,128,63,16,249,35,0,2,0,0,0,169,0,0,0,169,0,0,0,208,151,22,0,1,0,0,0,0,0,240,193,0,0,160,64,240,248,35,0,2,0,0,0,25,0,0,0,25,0,0,0,176,151,22,0,1,0,0,0,0,0,0,192,0,0,128,63,224,248,35,0,2,0,0,0,169,0,0,0,169,0,0,0,0,151,22,0,1,0,0,0,0,64,191,196,0,0,127,67,208,248,35,0,2,0,0,0,225,0,0,0,225,0,0,0,24,150,22,0,1,0,0,0,0,0,238,194,0,0,136,65,192,248,35,0,2,0,0,0,33,1,0,0,33,1,0,0,240,148,22,0,1,0,0,0,0,0,0,193,0,0,128,63,152,248,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,106,34,0,224,49,34,0,128,2,34,0,0,0,0,0,120,212,33,0,32,176,33,0,160,143,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,109,33,0,0,0,0,0,0,0,0,0,0,0,0,0,16,45,33,0,0,0,0,0,0,0,0,0,0,0,0,0,208,5,33,0,0,0,0,0,0,0,0,0,0,0,0,0,216,234,32,0,0,0,0,0,0,0,0,0,0,0,0,0,112,208,32,0,0,0,0,0,0,0,0,0,0,0,0,0,88,181,32,0,0,0,0,0,0,0,0,0,0,0,0,0,8,160,32,0,232,133,32,0,160,108,32,0,248,86,32,0,0,0,0,0,88,229,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,238,31,0,56,218,31,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,64,16,0,1,0,32,200,31,0,16,178,31,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,88,159,31,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,96,141,31,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,40,124,31,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,184,109,31,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,24,90,31,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,192,47,31,0,0,0,0,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,240,28,31,0,0,0,0,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,0,17,31,0,0,0,0,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,192,1,31,0,0,0,0,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,216,241,30,0,0,0,0,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,32,200,31,0,152,227,30,0,184,214,30,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,144,199,30,0,184,214,30,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,96,184,30,0,184,166,30,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,126,30,0,184,166,30,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,111,30,0,72,98,30,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,84,30,0,72,98,30,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,8,68,30,0,216,56,30,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,16,46,30,0,216,56,30,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,8,36,30,0,112,28,30,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,32,17,30,0,160,238,29,0,28,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,229,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,0,0,0,0,216,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,148,33,0,108,0,0,0,128,155,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,0,0,0,0,176,64,33,0,248,22,32,0,64,0,0,0,5,0,0,0,16,59,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,248,136,30,0,248,22,32,0,64,0,0,0,5,0,0,0,16,59,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,56,248,29,0,16,138,29,0,68,0,0,0,5,0,0,0,248,46,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,144,222,28,0,16,138,29,0,68,0,0,0,5,0,0,0,248,46,29,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,232,217,35,0,72,139,35,0,56,0,0,0,5,0,0,0,200,43,35,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,48,230,34,0,8,167,34,0,60,0,0,0,5,0,0,0,32,107,34,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,224,50,34,0,120,3,34,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,160,33,0,108,0,0,0,160,160,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,0,200,0,44,1,144,1,254,1,118,2,2,3,152,3,56,4,246,4,200,5,184,6,208,7,16,9,140,10,78,12,116,14,48,17,180,20,0,25,20,30,28,37,224,46,140,60,195,80,159,111,159,161,131,249,255,255,255,255,255,255,255,255,255,255,16,255,255,255,255,255,255,255,17,255,255,255,255,255,255,255,18,255,255,255,255,255,255,255,19,255,255,255,255,255,255,255,20,255,255,255,255,255,255,255,21,255,255,255,255,255,22,23,255,255,255,255,255,255,24,25,255,255,255,255,255,255,26,27,28,255,255,255,255,255,93,0,0,0,23,0,0,0,116,1,0,0,6,0,0,0,46,0,0,0,186,0,0,0,238,2,0,0,14,0,0,0,33,0,0,0,65,0,0,0,130,0,0,0,4,1,0,0,44,2,0,0,3,0,0,0,10,0,0,0,18,0,0,0,28,0,0,0,39,0,0,0,55,0,0,0,79,0,0,0,111,0,0,0,158,0,0,0,220,0,0,0,56,1,0,0,208,1,0,0,138,2,0,0,82,3,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,81,125,127,63,243,115,126,63,2,101,125,63,48,80,124,63,39,53,123,63,139,19,122,63,243,234,120,63,239,186,119,63,1,131,118,63,158,66,117,63,41,249,115,63,243,165,114,63,55,72,113,63,19,223,111,63,135,105,110,63,107,230,108,63,103,84,107,63,233,177,105,63,18,253,103,63,166,51,102,63,237,82,100,63,138,87,98,63,62,61,96,63,146,254,93,63,64,148,91,63,71,244,88,63,51,16,86,63,197,209,82,63,110,19,79,63,179,139,74,63,50,124,68,63,243,4,53,63,53,26,36,63,135,143,28,63,135,132,22,63,96,58,17,63,23,103,12,63,147,228,7,63,253,155,3,63,114,252,254,62,18,1,247,62,176,53,239,62,136,141,231,62,15,254,223,62,56,126,216,62,235,5,209,62,164,141,201,62,34,14,194,62,36,128,186,62,37,220,178,62,15,26,171,62,234,48,163,62,108,22,155,62,96,190,146,62,212,25,138,62,204,21,129,62,98,50,111,62,123,2,91,62,167,53,69,62,15,41,45,62,3,185,17,62,72,208,224,61,248,68,129,61,0,0,0,0,0,0,0,0,0,0,128,63,8,245,126,63,244,205,124,63,209,141,122,63,135,49,120,63,79,181,117,63,123,20,115,63,39,73,112,63,176,75,109,63,240,17,106,63,233,141,102,63,87,171,98,63,255,74,94,63,2,56,89,63,175,10,83,63,152,181,74,63,243,4,53,63,69,89,28,63,158,231,16,63,53,120,7,63,145,241,253,62,116,247,237,62,133,137,222,62,96,86,207,62,185,28,192,62,5,159,176,62,169,153,160,62,235,182,143,62,73,243,122,62,246,23,82,62,1,74,33,62,14,171,184,61,0,0,0,0,0,0,0,0,0,0,128,63,19,210,125,63,217,38,121,63,41,249,115,63,59,29,110,63,182,72,103,63,57,233,94,63,144,128,83,63,243,4,53,63,89,59,16,63,101,196,251,62,208,124,219,62,116,4,188,62,108,22,155,62,88,68,107,62,56,85,5,62,0,0,0,0,0,0,0,0,0,0,128,63,39,53,123,63,19,223,111,63,62,61,96,63,243,4,53,63,18,1,247,62,37,220,178,62,167,53,69,62,0,0,0,0,0,0,0,0,0,0,128,63,41,249,115,63,243,4,53,63,108,22,155,62,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,0,0,0,0,122,76,198,64,225,47,226,30,224,17,62,9,146,4,24,2,5,1,119,0,65,0,31,0,19,0,10,0,6,0,3,0,3,0,2,0,1,0,1,0,1,0,0,0,0,0,0,0,232,57,88,52,116,43,59,33,251,23,81,16,195,10,220,6,80,4,165,2,159,1,248,0,150,0,89,0,54,0,31,0,19,0,11,0,7,0,4,0,2,0,0,0,0,0,0,0,0,0,122,76,64,141,33,189,3,220,227,237,33,247,179,251,203,253,208,254,71,255,136,255,167,255,186,255,196,255,202,255,205,255,208,255,210,255,211,255,212,255,213,255,0,0,0,0,0,0,232,57,64,110,180,153,239,186,234,210,59,227,254,237,218,244,42,249,207,251,110,253,102,254,252,254,85,255,139,255,170,255,189,255,200,255,207,255,211,255,213,255,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,69,69,0,0,61,167,0,0,64,65,0,0,13,72,1,0,50,115,0,0,248,76,0,0,79,64,0,0,242,140,2,0,226,100,0,0,203,82,0,0,145,72,0,0,196,135,0,0,121,220,0,0,225,66,0,0,82,24,5,0,96,86,0,0,176,149,0,0,249,67,0,0,101,7,1,0,157,74,0,0,111,107,0,0,179,64,0,0,44,180,1,0,174,79,0,0,125,124,0,0,250,65,0,0,249,189,0,0,204,70,0,0,76,95,0,0,19,64,0,0,69,69,0,0,61,167,0,0,64,65,0,0,13,72,1,0,50,115,0,0,248,76,0,0,79,64,0,0,242,140,2,0,226,100,0,0,203,82,0,0,145,72,0,0,196,135,0,0,121,220,0,0,225,66,0,0,82,24,5,0,96,86,0,0,176,149,0,0,249,67,0,0,101,7,1,0,157,74,0,0,111,107,0,0,179,64,0,0,44,180,1,0,174,79,0,0,125,124,0,0,250,65,0,0,249,189,0,0,204,70,0,0,76,95,0,0,19,64,0,0,0,64,255,63,251,63,245,63,236,63,225,63,212,63,196,63,177,63,156,63,133,63,107,63,79,63,48,63,15,63,235,62,197,62,157,62,114,62,69,62,21,62,227,61,175,61,120,61,63,61,3,61,197,60,133,60,66,60,253,59,182,59,109,59,33,59,211,58,130,58,48,58,219,57,132,57,43,57,207,56,113,56,18,56,176,55,75,55,229,54,125,54,18,54,165,53,55,53,198,52,83,52,223,51,104,51,239,50,116,50,248,49,121,49,249,48,118,48,242,47,108,47,228,46,90,46,207,45,65,45,178,44,33,44,143,43,251,42,101,42,206,41,53,41,154,40,254,39,96,39,193,38,32,38,126,37,218,36,53,36,142,35,231,34,61,34,147,33,231,32,58,32,140,31,220,30,43,30,121,29,198,28,18,28,93,27,167,26,239,25,55,25,126,24,196,23,9,23,76,22,144,21,210,20,19,20,84,19,148,18,211,17,18,17,80,16,141,15,202,14,6,14,65,13,124,12,183,11,241,10,43,10,100,9,157,8,214,7,14,7,70,6,126,5,181,4,237,3,36,3,91,2,146,1,201,0,0,0,55,255,110,254,165,253,220,252,19,252,75,251,130,250,186,249,242,248,42,248,99,247,156,246,213,245,15,245,73,244,132,243,191,242,250,241,54,241,115,240,176,239,238,238,45,238,108,237,172,236,237,235,46,235,112,234,180,233,247,232,60,232,130,231,201,230,17,230,89,229,163,228,238,227,58,227,135,226,213,225,36,225,116,224,198,223,25,223,109,222,195,221,25,221,114,220,203,219,38,219,130,218,224,217,63,217,160,216,2,216,102,215,203,214,50,214,155,213,5,213,113,212,223,211,78,211,191,210,49,210,166,209,28,209,148,208,14,208,138,207,7,207,135,206,8,206,140,205,17,205,152,204,33,204,173,203,58,203,201,202,91,202,238,201,131,201,27,201,181,200,80,200,238,199,143,199,49,199,213,198,124,198,37,198,208,197,126,197,45,197,223,196,147,196,74,196,3,196,190,195,123,195,59,195,253,194,193,194,136,194,81,194,29,194,235,193,187,193,142,193,99,193,59,193,21,193,241,192,208,192,177,192,149,192,123,192,100,192,79,192,60,192,44,192,31,192,20,192,11,192,5,192,1,192,0,192,1,192,5,192,11,192,20,192,31,192,44,192,60,192,79,192,100,192,123,192,149,192,177,192,208,192,241,192,21,193,59,193,99,193,142,193,187,193,235,193,29,194,81,194,136,194,193,194,253,194,59,195,123,195,190,195,3,196,74,196,147,196,223,196,45,197,126,197,208,197,37,198,124,198,213,198,49,199,143,199,238,199,80,200,181,200,27,201,131,201,238,201,91,202,201,202,58,203,173,203,33,204,152,204,17,205,140,205,8,206,135,206,7,207,138,207,14,208,148,208,28,209,166,209,49,210,191,210,78,211,223,211,113,212,5,213,155,213,50,214,203,214,102,215,2,216,160,216,63,217,224,217,130,218,38,219,203,219,114,220,25,221,195,221,109,222,25,223,198,223,116,224,36,225,213,225,135,226,58,227,238,227,163,228,89,229,17,230,201,230,130,231,60,232,247,232,180,233,112,234,46,235,237,235,172,236,108,237,45,238,238,238,176,239,115,240,54,241,250,241,191,242,132,243,73,244,15,245,213,245,156,246,99,247,42,248,242,248,186,249,130,250,75,251,19,252,220,252,165,253,110,254,55,255,0,0,201,0,146,1,91,2,36,3,237,3,181,4,126,5,70,6,14,7,214,7,157,8,100,9,43,10,241,10,183,11,124,12,65,13,6,14,202,14,141,15,80,16,18,17,211,17,148,18,84,19,19,20,210,20,144,21,76,22,9,23,196,23,126,24,55,25,239,25,167,26,93,27,18,28,198,28,121,29,43,30,220,30,140,31,58,32,231,32,147,33,61,34,231,34,142,35,53,36,218,36,126,37,32,38,193,38,96,39,254,39,154,40,53,41,206,41,101,42,251,42,143,43,33,44,178,44,65,45,207,45,90,46,228,46,108,47,242,47,118,48,249,48,121,49,248,49,116,50,239,50,104,51,223,51,83,52,198,52,55,53,165,53,18,54,125,54,229,54,75,55,176,55,18,56,113,56,207,56,43,57,132,57,219,57,48,58,130,58,211,58,33,59,109,59,182,59,253,59,66,60,133,60,197,60,3,61,63,61,120,61,175,61,227,61,21,62,69,62,114,62,157,62,197,62,235,62,15,63,48,63,79,63,107,63,133,63,156,63,177,63,196,63,212,63,225,63,236,63,245,63,251,63,255,63,0,64,0,0,0,0,0,0,255,255,255,255,0,0,0,0,156,0,0,0,0,1,0,0,38,1,0,0,152,0,0,0,244,0,0,0,12,1,0,0,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,72,164,30,0,0,0,0,0,105,87,20,139,10,191,5,64,48,125,30,0,0,0,0,0,24,45,68,84,251,33,9,64,56,110,30,0,0,0,0,0,168,244,151,155,119,227,249,63,24,45,68,84,251,33,9,64,105,87,20,139,10,191,5,64,0,0,0,0,0,128,93,64,0,0,0,0,0,0,0,0,224,201,28], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1410243);
/* memory initializer */ allocate([0,80,195,28,0,80,190,28,0,0,0,0,0,88,190,34,0,104,129,34,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,88,72,34,0,120,22,34,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,136,227,33,0,144,191,33,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,224,155,33,0,0,128,33,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,35,34,0,108,0,0,0,48,88,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,247,28,0,108,0,0,0,216,172,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,56,166,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,1,0,0,58,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,229,32,0,168,214,31,0,8,0,0,0,5,0,0,0,24,14,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,176,95,30,0,88,219,29,0,12,0,0,0,5,0,0,0,64,112,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,16,26,29,0,80,201,28,0,16,0,0,0,5,0,0,0,152,197,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,168,112,35,0,72,23,35,0,48,0,0,0,3,0,0,0,123,20,174,71,225,122,132,63,123,20,174,71,225,122,132,63,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,160,210,34,0,72,151,34,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,72,91,34,0,144,37,34,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,56,245,33,0,112,204,33,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,166,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,25,31,0,108,0,0,0,184,175,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,227,207,1,0,232,127,1,0,90,59,1,0,244,0,1,0,138,207,0,0,8,166,0,0,113,131,0,0,222,102,0,0,125,79,0,0,144,60,0,0,108,45,0,0,120,33,0,0,44,24,0,0,16,17,0,0,187,11,0,0,210,7,0,0,7,5,0,0,24,3,0,0,206,1,0,0,252,0,0,0,126,0,0,0,56,0,0,0,21,0,0,0,6,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,199,92,0,0,251,79,0,0,142,68,0,0,102,58,0,0,106,49,0,0,130,41,0,0,151,34,0,0,147,28,0,0,97,23,0,0,237,18,0,0,36,15,0,0,244,11,0,0,76,9,0,0,28,7,0,0,85,5,0,0,233,3,0,0,203,2,0,0,239,1,0,0,74,1,0,0,210,0,0,0,126,0,0,0,70,0,0,0,35,0,0,0,15,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,14,0,0,204,12,0,0,109,11,0,0,40,10,0,0,252,8,0,0,232,7,0,0,235,6,0,0,4,6,0,0,50,5,0,0,116,4,0,0,201,3,0,0,48,3,0,0,168,2,0,0,48,2,0,0,199,1,0,0,108,1,0,0,30,1,0,0,220,0,0,0,165,0,0,0,120,0,0,0,84,0,0,0,56,0,0,0,35,0,0,0,20,0,0,0,10,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,1,0,0,122,1,0,0,95,1,0,0,69,1,0,0,44,1,0,0,20,1,0,0,253,0,0,0,231,0,0,0,210,0,0,0,190,0,0,0,171,0,0,0,153,0,0,0,136,0,0,0,120,0,0,0,105,0,0,0,91,0,0,0,78,0,0,0,66,0,0,0,55,0,0,0,45,0,0,0,36,0,0,0,28,0,0,0,21,0,0,0,15,0,0,0,10,0,0,0,6,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,29,0,0,0,28,0,0,0,27,0,0,0,26,0,0,0,25,0,0,0,24,0,0,0,23,0,0,0,22,0,0,0,21,0,0,0,20,0,0,0,19,0,0,0,18,0,0,0,17,0,0,0,16,0,0,0,15,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,224,218,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,67,33,0,216,24,32,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,248,60,31,0,24,138,30,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,64,249,29,0,104,139,29,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,120,47,29,0,144,223,28,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,72,219,35,0,104,140,35,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,8,45,35,0,216,230,34,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,88,168,34,0,8,108,34,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,216,51,34,0,240,3,34,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,16,214,33,0,184,177,33,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,32,145,33,0,128,111,33,0,80,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,88,46,33,0,96,6,33,0,88,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,216,235,32,0,64,209,32,0,96,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,8,182,32,0,160,160,32,0,104,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,200,134,32,0,168,109,32,0,112,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,184,87,32,0,24,64,32,0,120,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,80,8,32,0,144,239,31,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,218,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,170,33,0,108,0,0,0,40,181,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,145,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,69,33,0,224,25,32,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,232,61,31,0,96,139,30,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,24,250,29,0,136,140,29,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,88,48,29,0,152,224,28,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,16,220,35,0,72,141,35,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,120,45,35,0,176,231,34,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,216,168,34,0,168,108,34,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,168,52,34,0,136,4,34,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,144,214,33,0,80,178,33,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,145,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,190,33,0,108,0,0,0,120,185,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,100,34,0,240,248,255,0,112,45,34,0,250,235,215,0,128,254,33,0,0,255,255,0,72,209,33,0,127,255,212,0,248,170,33,0,240,255,255,0,96,140,33,0,245,245,220,0,240,104,33,0,255,228,196,0,16,40,33,0,0,0,0,0,232,2,33,0,255,235,205,0,16,232,32,0,0,0,255,0,40,205,32,0,138,43,226,0,168,178,32,0,165,42,42,0,112,157,32,0,222,184,135,0,96,131,32,0,95,158,160,0,128,106,32,0,127,255,0,0,248,84,32,0,210,105,30,0,32,59,32,0,255,127,80,0,248,4,32,0,100,149,237,0,232,236,31,0,255,248,220,0,72,216,31,0,220,20,60,0,48,198,31,0,0,255,255,0,120,175,31,0,0,0,139,0,120,157,31,0,0,139,139,0,16,139,31,0,184,134,11,0,136,122,31,0,169,169,169,0,240,107,31,0,0,100,0,0,72,86,31,0,189,183,107,0,120,45,31,0,139,0,139,0,216,27,31,0,85,107,47,0,96,15,31,0,255,140,0,0,128,0,31,0,153,50,204,0,240,239,30,0,139,0,0,0,104,226,30,0,233,150,122,0,8,213,30,0,143,188,143,0,56,198,30,0,72,61,139,0,184,182,30,0,47,79,79,0,208,163,30,0,0,206,209,0,0,125,30,0,148,0,211,0,24,110,30,0,255,20,147,0,56,97,30,0,0,191,255,0,120,83,30,0,105,105,105,0,240,66,30,0,30,144,255,0,208,55,30,0,178,34,34,0,240,44,30,0,255,250,240,0,248,34,30,0,34,139,34,0,184,27,30,0,255,0,255,0,48,15,30,0,220,220,220,0,176,237,29,0,248,248,255,0,120,228,29,0,255,215,0,0,64,220,29,0,218,165,32,0,104,211,29,0,128,128,128,0,144,202,29,0,0,128,0,0,16,194,29,0,173,255,47,0,104,186,29,0,240,255,240,0,0,179,29,0,255,105,180,0,56,171,29,0,205,92,92,0,88,159,29,0,75,0,130,0,216,128,29,0,255,255,240,0,128,120,29,0,240,230,140,0,48,113,29,0,230,230,250,0,64,106,29,0,255,240,245,0,136,99,29,0,124,252,0,0,240,93,29,0,255,250,205,0,128,87,29,0,173,216,230,0,8,81,29,0,240,128,128,0,216,73,29,0,224,255,255,0,56,64,29,0,250,250,210,0,104,39,29,0,144,238,144,0,112,32,29,0,211,211,211,0,120,26,29,0,255,182,193,0,80,20,29,0,255,160,122,0,160,13,29,0,32,178,170,0,152,7,29,0,135,206,250,0,104,3,29,0,119,136,153,0,168,253,28,0,176,196,222,0,24,248,28,0,255,255,224,0,176,239,28,0,0,255,0,0,200,215,28,0,50,205,50,0,0,209,28,0,250,240,230,0,216,201,28,0,255,0,255,0,72,195,28,0,128,0,0,0,40,190,28,0,102,205,170,0,224,185,28,0,0,0,205,0,0,181,28,0,186,85,211,0,32,175,28,0,147,112,216,0,240,241,35,0,60,179,113,0,160,233,35,0,123,104,238,0,232,209,35,0,0,250,154,0,8,204,35,0,72,209,204,0,40,198,35,0,199,21,133,0,160,192,35,0,25,25,112,0,88,187,35,0,245,255,250,0,136,182,35,0,255,228,225,0,216,177,35,0,255,228,181,0,64,172,35,0,255,222,173,0,200,166,35,0,0,0,128,0,72,155,35,0,253,245,230,0,24,131,35,0,128,128,0,0,88,120,35,0,107,142,35,0,104,113,35,0,255,165,0,0,80,105,35,0,255,69,0,0,72,98,35,0,218,112,214,0,136,92,35,0,238,232,170,0,48,83,35,0,152,251,152,0,120,78,35,0,175,238,238,0,0,70,35,0,216,112,147,0,56,59,35,0,255,239,213,0,16,37,35,0,255,218,185,0,16,30,35,0,205,133,63,0,216,23,35,0,255,192,203,0,64,18,35,0,221,160,221,0,88,12,35,0,176,224,230,0,128,7,35,0,128,0,128,0,112,2,35,0,255,0,0,0,8,254,34,0,188,143,143,0,40,248,34,0,65,105,225,0,120,242,34,0,139,69,19,0,8,223,34,0,250,128,114,0,24,217,34,0,244,164,96,0,120,211,34,0,46,139,87,0,192,206,34,0,255,245,238,0,248,201,34,0,160,82,45,0,104,198,34,0,192,192,192,0,88,194,34,0,135,206,235,0,128,189,34,0,106,90,205,0,216,185,34,0,112,128,144,0,152,180,34,0,255,250,250,0,64,162,34,0,0,255,127,0,0,157,34,0,70,130,180,0,8,152,34,0,210,180,140,0,104,147,34,0,0,128,128,0,184,142,34,0,216,191,216,0,144,138,34,0,255,99,71,0,248,132,34,0,64,224,208,0,136,128,34,0,238,130,238,0,136,124,34,0,245,222,179,0,240,118,34,0,255,255,255,0,8,102,34,0,245,245,245,0,184,96,34,0,255,255,0,0,48,92,34,0,154,205,50,0,5,0,0,0,43,1,0,0,14,0,0,0,255,255,255,255,208,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,157,31,0,176,106,31,0,140,0,0,0,82,76,79,67,24,79,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,24,121,31,0,176,106,31,0,140,0,0,0,82,76,79,67,24,79,31,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,80,167,33,0,216,137,33,0,4,0,0,0,69,90,73,83,112,96,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,96,34,33,0,216,137,33,0,4,0,0,0,69,90,73,83,112,96,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,255,32,0,120,229,32,0,24,0,0,0,84,65,82,86,40,202,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,176,32,0,120,229,32,0,24,0,0,0,84,65,82,86,40,202,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,154,32,0,200,129,32,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,96,103,32,0,200,129,32,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,240,82,32,0,160,50,32,0,48,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,157,31,0,108,0,0,0,232,192,21,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,196,52,0,65,208,0,0,17,196,0,0,3,226,0,0,9,253,0,0,2,40,0,0,2,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,250,0,0,21,219,0,0,5,201,0,0,21,213,0,0,5,207,0,0,22,51,0,0,6,39,0,0,18,155,0,0,20,192,0,0,20,153,0,0,20,147,0,0,0,0,0,0,0,8,1,2,9,16,24,17,10,3,4,11,18,25,32,40,33,26,19,12,5,6,13,20,27,34,41,48,56,49,42,35,28,21,14,7,15,22,29,36,43,50,57,58,51,44,37,30,23,31,38,45,52,59,39,46,53,60,61,54,47,55,62,63,1,0,0,0,6,2,0,0,8,6,3,0,9,8,7,5,10,9,8,6,11,10,9,7,13,11,10,8,13,13,11,9,13,13,13,10,14,14,13,11,14,14,14,13,15,15,14,14,15,15,15,14,16,15,15,15,16,16,16,15,16,16,16,16,16,16,16,16,2,0,0,0,6,2,0,0,6,5,3,0,7,6,6,4,8,6,6,4,8,7,7,5,9,8,8,6,11,9,9,6,11,11,11,7,12,11,11,9,12,12,12,11,12,12,12,11,13,13,13,12,13,13,13,13,13,14,13,13,14,14,14,13,14,14,14,14,4,0,0,0,6,4,0,0,6,5,4,0,6,5,5,4,7,5,5,4,7,5,5,4,7,6,6,4,7,6,6,4,8,7,7,5,8,8,7,6,9,8,8,7,9,9,8,8,9,9,9,8,10,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,6,0,0,0,6,6,0,0,6,6,6,0,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,1,0,0,0,5,1,0,0,7,4,1,0,7,6,5,3,7,6,5,3,7,6,5,4,15,6,5,4,11,14,5,4,8,10,13,4,15,14,9,4,11,10,13,12,15,14,9,12,11,10,13,8,15,1,9,12,11,14,13,8,7,10,9,12,4,6,5,8,3,0,0,0,11,2,0,0,7,7,3,0,7,10,9,5,7,6,5,4,4,6,5,6,7,6,5,8,15,6,5,4,11,14,13,4,15,10,9,4,11,14,13,12,8,10,9,8,15,14,13,12,11,10,9,12,7,11,6,8,9,8,10,1,7,6,5,4,15,0,0,0,15,14,0,0,11,15,13,0,8,12,14,12,15,10,11,11,11,8,9,10,9,14,13,9,8,10,9,8,15,14,13,13,11,14,10,12,15,10,13,12,11,14,9,12,8,10,13,8,13,7,9,12,9,12,11,10,5,8,7,6,1,4,3,2,3,0,0,0,0,1,0,0,4,5,6,0,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,234,133,0,40,234,133,0,72,198,21,0,144,207,21,0,136,207,21,0,128,207,21,0,120,207,21,0,112,207,21,0,104,207,21,0,96,207,21,0,88,207,21,0,72,207,21,0,40,207,21,0,232,206,21,0,104,206,21,0,104,198,21,0,96,198,21,0,96,198,21,0,96,198,21,0,96,198,21,0,96,198,21,0,96,198,21,0,96,198,21,0,88,198,21,0,80,198,21,0,1,0,0,0,0,0,0,0,2,0,3,0,254,255,253,255,2,0,3,0,254,255,253,255,1,0,255,255,0,0,0,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,112,0,113,0,114,0,115,0,116,0,117,0,118,0,119,0,120,0,121,0,122,0,123,0,124,0,125,0,126,0,127,0,128,0,129,0,130,0,131,0,132,0,133,0,134,0,135,0,136,0,137,0,138,0,139,0,140,0,141,0,142,0,143,0,144,0,145,0,146,0,147,0,148,0,149,0,150,0,151,0,152,0,153,0,154,0,155,0,156,0,157,0,158,0,159,0,160,0,161,0,162,0,163,0,164,0,165,0,166,0,167,0,168,0,169,0,170,0,171,0,172,0,173,0,174,0,175,0,176,0,177,0,178,0,179,0,180,0,181,0,182,0,183,0,184,0,185,0,186,0,187,0,188,0,189,0,190,0,191,0,192,0,193,0,194,0,195,0,196,0,197,0,198,0,199,0,200,0,201,0,202,0,203,0,204,0,205,0,206,0,207,0,208,0,209,0,210,0,211,0,212,0,213,0,214,0,215,0,216,0,217,0,218,0,219,0,220,0,221,0,222,0,223,0,224,0,225,0,226,0,227,0,228,0,229,0,230,0,231,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,239,0,240,0,241,0,242,0,243,0,244,0,245,0,246,0,247,0,248,0,249,0,250,0,251,0,252,0,253,0,254,0,255,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,44,1,45,1,46,1,47,1,48,1,49,1,50,1,51,1,52,1,53,1,54,1,55,1,56,1,57,1,58,1,59,1,60,1,61,1,62,1,63,1,64,1,65,1,66,1,67,1,68,1,69,1,70,1,71,1,72,1,73,1,74,1,75,1,76,1,77,1,78,1,79,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,115,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,123,1,124,1,125,1,126,1,127,1,128,1,129,1,130,1,131,1,132,1,133,1,134,1,135,1,136,1,137,1,138,1,139,1,140,1,141,1,142,1,143,1,144,1,145,1,146,1,147,1,148,1,149,1,150,1,151,1,152,1,153,1,154,1,155,1,156,1,157,1,158,1,159,1,160,1,161,1,162,1,163,1,164,1,165,1,166,1,167,1,168,1,169,1,170,1,171,1,172,1,173,1,174,1,175,1,176,1,177,1,178,1,179,1,180,1,181,1,182,1,183,1,184,1,185,1,186,1,187,1,188,1,189,1,190,1,191,1,192,1,193,1,194,1,195,1,196,1,197,1,198,1,199,1,200,1,201,1,202,1,203,1,204,1,205,1,206,1,207,1,208,1,209,1,210,1,211,1,212,1,213,1,214,1,215,1,216,1,217,1,218,1,219,1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,1,246,1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,1,255,1,0,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,2,9,2,10,2,11,2,12,2,13,2,14,2,15,2,16,2,17,2,18,2,19,2,20,2,21,2,22,2,23,2,24,2,25,2,26,2,27,2,28,2,29,2,30,2,31,2,32,2,33,2,34,2,35,2,36,2,37,2,38,2,39,2,40,2,41,2,42,2,43,2,44,2,45,2,46,2,47,2,48,2,49,2,50,2,51,2,52,2,53,2,54,2,55,2,56,2,57,2,58,2,59,2,60,2,61,2,62,2,63,2,64,2,65,2,66,2,67,2,68,2,187,255,186,255,185,255,184,255,183,255,182,255,181,255,180,255,179,255,178,255,177,255,176,255,175,255,174,255,173,255,172,255,171,255,170,255,169,255,168,255,167,255,166,255,165,255,164,255,163,255,162,255,161,255,160,255,159,255,158,255,157,255,156,255,155,255,154,255,153,255,152,255,151,255,150,255,149,255,148,255,147,255,146,255,145,255,144,255,143,255,142,255,141,255,140,255,139,255,138,255,137,255,136,255,135,255,134,255,133,255,132,255,131,255,130,255,129,255,128,255,127,255,126,255,125,255,124,255,123,255,122,255,121,255,120,255,119,255,118,255,117,255,116,255,115,255,114,255,113,255,112,255,111,255,110,255,109,255,108,255,107,255,106,255,105,255,104,255,103,255,102,255,101,255,100,255,99,255,98,255,97,255,96,255,95,255,94,255,93,255,92,255,91,255,90,255,89,255,88,255,87,255,86,255,85,255,84,255,83,255,82,255,81,255,80,255,79,255,78,255,77,255,76,255,75,255,74,255,73,255,72,255,71,255,70,255,69,255,68,255,67,255,66,255,65,255,64,255,63,255,62,255,61,255,60,255,59,255,58,255,57,255,56,255,55,255,54,255,53,255,52,255,51,255,50,255,49,255,48,255,47,255,46,255,45,255,44,255,43,255,42,255,41,255,40,255,39,255,38,255,37,255,36,255,35,255,34,255,33,255,32,255,31,255,30,255,29,255,28,255,27,255,26,255,25,255,24,255,23,255,22,255,21,255,20,255,19,255,18,255,17,255,16,255,15,255,14,255,13,255,12,255,11,255,10,255,9,255,8,255,7,255,6,255,5,255,4,255,3,255,2,255,1,255,0,255,255,254,254,254,253,254,252,254,251,254,250,254,249,254,248,254,247,254,246,254,245,254,244,254,243,254,242,254,241,254,240,254,239,254,238,254,237,254,236,254,235,254,234,254,233,254,232,254,231,254,230,254,229,254,228,254,227,254,226,254,225,254,224,254,223,254,222,254,221,254,220,254,219,254,218,254,217,254,216,254,215,254,214,254,213,254,212,254,211,254,210,254,209,254,208,254,207,254,206,254,205,254,204,254,203,254,202,254,201,254,200,254,199,254,198,254,197,254,196,254,195,254,194,254,193,254,192,254,191,254,190,254,189,254,188,254,187,254,186,254,185,254,184,254,183,254,182,254,181,254,180,254,179,254,178,254,177,254,176,254,175,254,174,254,173,254,172,254,171,254,170,254,169,254,168,254,167,254,166,254,165,254,164,254,163,254,162,254,161,254,160,254,159,254,158,254,157,254,156,254,155,254,154,254,153,254,152,254,151,254,150,254,149,254,148,254,147,254,146,254,145,254,144,254,143,254,142,254,141,254,140,254,139,254,138,254,137,254,136,254,135,254,134,254,133,254,132,254,131,254,130,254,129,254,128,254,127,254,126,254,125,254,124,254,123,254,122,254,121,254,120,254,119,254,118,254,117,254,116,254,115,254,114,254,113,254,112,254,111,254,110,254,109,254,108,254,107,254,106,254,105,254,104,254,103,254,102,254,101,254,100,254,99,254,98,254,97,254,96,254,95,254,94,254,93,254,92,254,91,254,90,254,89,254,88,254,87,254,86,254,85,254,84,254,83,254,82,254,81,254,80,254,79,254,78,254,77,254,76,254,75,254,74,254,73,254,72,254,71,254,70,254,69,254,68,254,67,254,66,254,65,254,64,254,63,254,62,254,61,254,60,254,59,254,58,254,57,254,56,254,55,254,54,254,53,254,52,254,51,254,50,254,49,254,48,254,47,254,46,254,45,254,44,254,43,254,42,254,41,254,40,254,39,254,38,254,37,254,36,254,35,254,34,254,33,254,32,254,31,254,30,254,29,254,28,254,27,254,26,254,25,254,24,254,23,254,22,254,21,254,20,254,19,254,18,254,17,254,16,254,15,254,14,254,13,254,12,254,11,254,10,254,9,254,8,254,7,254,6,254,5,254,4,254,3,254,2,254,1,254,0,254,255,253,254,253,253,253,252,253,251,253,250,253,249,253,248,253,247,253,246,253,245,253,244,253,243,253,242,253,241,253,240,253,239,253,238,253,237,253,236,253,235,253,234,253,233,253,232,253,231,253,230,253,229,253,228,253,227,253,226,253,225,253,224,253,223,253,222,253,221,253,220,253,219,253,218,253,217,253,216,253,215,253,214,253,213,253,212,253,211,253,210,253,209,253,208,253,207,253,206,253,205,253,204,253,203,253,202,253,201,253,200,253,199,253,198,253,197,253,196,253,195,253,194,253,193,253,192,253,191,253,190,253,189,253,188,253,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,219,255,218,255,217,255,216,255,215,255,214,255,213,255,212,255,211,255,210,255,209,255,208,255,207,255,206,255,205,255,204,255,203,255,202,255,201,255,200,255,199,255,198,255,197,255,196,255,195,255,194,255,193,255,192,255,191,255,190,255,189,255,188,255,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,235,255,234,255,233,255,232,255,231,255,230,255,229,255,228,255,227,255,226,255,225,255,224,255,223,255,222,255,221,255,220,255,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,243,255,242,255,241,255,240,255,239,255,238,255,237,255,236,255,9,0,10,0,11,0,12,0,247,255,246,255,245,255,244,255,7,0,8,0,249,255,248,255,6,0,250,255,0,0,0,0,5,0,251,255,0,0,0,0,4,0,252,255,0,0,0,0,3,0,253,255,0,0,0,0,254,255,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,0,1,2,2,2,3,3,3,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,0,1,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,1,2,2,3,3,4,4,4,4,4,4,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,0,1,2,3,4,4,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,10,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,154,2,0,0,60,0,0,0,120,50,22,0,240,61,22,0,160,17,13,0,43,2,0,0,40,0,0,0,0,28,22,0,168,37,22,0,80,17,13,0,56,5,0,0,84,1,0,0,96,248,21,0,64,13,22,0,168,14,13,0,48,4,0,0,180,0,0,0,112,227,21,0,48,244,21,0,64,13,13,0,220,1,0,0,70,0,0,0,32,218,21,0,144,225,21,0,176,12,13,0,179,1,0,0,40,0,0,0,152,209,21,0,104,216,21,0,96,12,13,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,88,249,255,255,168,134,0,0,168,134,0,0,88,249,255,255,0,240,255,255,0,32,0,0,0,240,255,255,0,0,0,0,0,0,0,0,240,7,0,0,78,226,255,255,132,43,0,0,78,226,255,255,240,7,0,0,71,3,0,0,11,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,4,0,0,0,16,0,0,0,21,0,0,0,31,0,0,0,11,0,0,0,35,0,0,0,38,0,0,0,41,0,0,0,53,0,0,0,55,0,0,0,1,0,0,0,21,0,0,0,26,0,0,0,29,0,0,0,28,0,0,0,30,0,0,0,78,0,0,0,73,0,0,0,81,0,0,0,120,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,13,0,0,0,123,0,0,0,5,0,0,0,50,0,0,0,149,0,0,0,145,0,0,0,150,0,0,0,161,0,0,0,217,0,0,0,3,0,0,0,25,0,0,0,97,0,0,0,102,0,0,0,96,0,0,0,23,0,0,0,14,0,0,0,99,0,0,0,160,1,0,0,183,1,0,0,230,1,0,0,231,1,0,0,182,1,0,0,24,0,0,0,232,1,0,0,56,0,0,0,49,0,0,0,5,0,0,0,61,0,0,0,39,0,0,0,234,1,0,0,26,0,0,0,197,0,0,0,249,0,0,0,255,0,0,0,219,0,0,0,80,2,0,0,252,0,0,0,92,2,0,0,8,0,0,0,117,0,0,0,215,3,0,0,211,3,0,0,176,1,0,0,124,0,0,0,202,3,0,0,54,0,0,0,137,1,0,0,166,4,0,0,162,4,0,0,251,4,0,0,192,0,0,0,127,0,0,0,154,0,0,0,17,3,0,0,110,0,0,0,155,0,0,0,140,6,0,0,192,6,0,0,132,4,0,0,18,0,0,0,195,0,0,0,79,9,0,0,121,9,0,0,249,9,0,0,9,13,0,0,166,13,0,0,168,13,0,0,1,9,0,0,193,0,0,0,115,3,0,0,8,13,0,0,250,9,0,0,139,13,0,0,133,13,0,0,134,13,0,0,223,0,0,0,226,6,0,0,206,0,0,0,36,15,0,0,254,9,0,0,247,1,0,0,193,7,0,0,207,0,0,0,252,9,0,0,255,9,0,0,137,13,0,0,169,13,0,0,253,9,0,0,248,1,0,0,54,26,0,0,140,18,0,0,157,18,0,0,55,26,0,0,150,1,0,0,234,3,0,0,139,15,0,0,147,13,0,0,69,30,0,0,88,30,0,0,75,30,0,0,89,30,0,0,241,19,0,0,9,3,0,0,101,2,0,0,8,3,0,0,58,36,0,0,225,39,0,0,137,15,0,0,36,3,0,0,188,60,0,0,134,60,0,0,149,54,0,0,60,36,0,0,59,36,0,0,62,36,0,0,74,30,0,0,165,3,0,0,104,52,0,0,40,52,0,0,132,60,0,0,224,39,0,0,226,37,0,0,128,24,0,0,151,1,0,0,37,3,0,0,183,60,0,0,30,121,0,0,236,7,0,0,117,108,0,0,200,4,0,0,199,75,0,0,198,4,0,0,131,9,0,0,30,72,0,0,83,27,0,0,27,37,0,0,88,27,0,0,132,9,0,0,168,79,0,0,187,60,0,0,138,15,0,0,34,3,0,0,106,52,0,0,61,36,0,0,38,3,0,0,105,52,0,0,31,72,0,0,29,72,0,0,70,7,0,0,50,144,0,0,80,27,0,0,19,29,0,0,228,216,0,0,27,72,0,0,116,108,0,0,107,121,0,0,105,121,0,0,133,9,0,0,227,216,0,0,134,9,0,0,162,15,0,0,1,19,0,0,124,108,0,0,135,9,0,0,184,60,0,0,175,244,0,0,136,14,0,0,192,177,1,0,206,15,0,0,235,51,0,0,106,63,0,0,105,63,0,0,207,15,0,0,31,121,0,0,201,4,0,0,113,72,0,0,205,15], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1420483);
/* memory initializer */ allocate([130,9,0,0,204,15,0,0,163,15,0,0,18,29,0,0,108,121,0,0,71,27,0,0,33,3,0,0,106,121,0,0,226,216,0,0,114,72,0,0,115,72,0,0,14,0,0,0,20,0,0,0,10,0,0,0,160,0,0,0,18,0,0,0,125,0,0,0,162,1,0,0,59,0,0,0,95,2,0,0,221,0,0,0,124,2,0,0,67,3,0,0,104,3,0,0,107,3,0,0,62,0,0,0,250,1,0,0,133,4,0,0,179,1,0,0,127,0,0,0,177,1,0,0,158,1,0,0,186,4,0,0,173,7,0,0,57,3,0,0,102,0,0,0,164,7,0,0,147,7,0,0,198,6,0,0,126,0,0,0,241,0,0,0,114,3,0,0,251,9,0,0,131,13,0,0,138,13,0,0,71,9,0,0,244,9,0,0,208,1,0,0,9,27,0,0,75,27,0,0,236,7,0,0,225,3,0,0,202,0,0,0,236,3,0,0,57,37,0,0,169,79,0,0,87,27,0,0,41,52,0,0,42,61,0,0,151,13,0,0,167,3,0,0,192,13,0,0,150,13,0,0,193,13,0,0,235,7,0,0,186,60,0,0,67,12,0,0,65,12,0,0,82,27,0,0,239,7,0,0,35,3,0,0,185,60,0,0,131,60,0,0,208,7,0,0,237,7,0,0,127,108,0,0,51,144,0,0,108,63,0,0,131,99,3,0,93,233,1,0,120,108,0,0,71,7,0,0,81,27,0,0,34,0,0,0,22,0,0,0,57,0,0,0,82,2,0,0,121,0,0,0,134,4,0,0,56,3,0,0,105,3,0,0,136,13,0,0,38,0,0,0,135,13,0,0,75,15,0,0,130,13,0,0,39,0,0,0,225,1,0,0,21,26,0,0,199,7,0,0,240,18,0,0,224,1,0,0,208,6,0,0,22,26,0,0,68,30,0,0,95,30,0,0,144,54,0,0,144,13,0,0,66,12,0,0,175,13,0,0,146,13,0,0,128,15,0,0,251,12,0,0,47,52,0,0,127,72,0,0,70,27,0,0,104,121,0,0,149,13,0,0,145,13,0,0,85,27,0,0,104,63,0,0,198,75,0,0,189,60,0,0,129,15,0,0,32,3,0,0,105,0,0,0,254,0,0,0,213,6,0,0,63,3,0,0,222,0,0,0,198,7,0,0,64,30,0,0,148,13,0,0,136,15,0,0,142,60,0,0,148,54,0,0,174,13,0,0,173,13,0,0,103,2,0,0,166,3,0,0,39,3,0,0,126,72,0,0,238,7,0,0,73,7,0,0,199,4,0,0,146,54,0,0,86,27,0,0,209,15,0,0,86,122,0,0,119,108,0,0,49,144,0,0,72,7,0,0,122,108,0,0,109,121,0,0,234,51,0,0,118,108,0,0,208,15,0,0,130,99,3,0,23,228,1,0,69,7,0,0,175,79,0,0,225,216,0,0,107,63,0,0,92,233,1,0,173,79,0,0,158,0,0,0,189,4,0,0,124,6,0,0,8,27,0,0,235,3,0,0,69,27,0,0,145,54,0,0,229,216,0,0,4,121,0,0,129,9,0,0,234,7,0,0,244,25,0,0,125,108,0,0,171,79,0,0,172,79,0,0,126,108,0,0,0,19,0,0,123,108,0,0,111,0,0,0,247,3,0,0,133,60,0,0,196,4,0,0,30,0,0,0,225,6,0,0,147,54,0,0,68,27,0,0,65,2,0,0,70,30,0,0,157,1,0,0,102,2,0,0,187,4,0,0,56,37,0,0,172,7,0,0,84,27,0,0,2,9,0,0,112,72,0,0,167,13,0,0,0,9,0,0,133,1,0,0,121,108,0,0,227,6,0,0,233,3,0,0,148,30,0,0,237,3,0,0,242,3,0,0,46,52,0,0,107,52,0,0,26,37,0,0,197,4,0,0,129,24,0,0,28,72,0,0,89,27,0,0,135,60,0,0,174,79,0,0,233,7,0,0,109,63,0,0,10,242,0,0,48,144,0,0,170,79,0,0,230,216,0,0,111,63,0,0,26,72,0,0,110,63,0,0,22,228,1,0,231,216,0,0,0,0,0,0,10,4,2,4,4,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,8,8,8,8,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,10,9,10,10,10,10,10,9,10,10,10,10,10,10,10,10,11,11,10,10,11,11,10,11,11,11,11,11,12,12,12,12,12,12,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,12,12,13,13,13,12,12,12,12,12,13,13,13,13,13,14,14,14,14,13,13,13,13,13,14,14,14,14,14,14,15,14,14,14,14,14,14,13,14,14,14,14,14,14,15,14,15,14,15,15,15,15,15,15,16,15,15,14,15,16,15,14,14,15,14,14,15,14,15,15,15,16,15,17,16,15,15,15,15,16,16,16,16,17,15,16,14,16,16,17,16,16,16,16,16,15,15,15,16,16,16,16,17,15,15,15,15,16,15,15,4,7,8,8,9,9,9,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,12,12,11,11,11,12,12,12,12,12,12,12,12,13,13,13,13,12,13,14,14,15,15,14,14,14,14,14,14,14,15,14,14,14,15,15,15,14,14,15,15,15,16,16,18,17,15,15,15,6,9,10,10,11,11,12,12,12,13,12,12,12,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,15,15,15,14,14,15,16,15,14,14,15,7,10,11,12,13,13,13,14,14,14,14,14,14,14,14,15,15,15,15,15,14,15,16,15,15,16,15,15,15,16,15,16,18,17,15,15,16,16,17,15,8,11,13,13,14,15,14,16,15,16,15,15,15,15,15,15,17,15,9,12,14,15,10,13,14,15,10,13,11,14,11,14,11,15,12,15,12,12,13,15,13,14,13,14,14,14,14,14,15,15,15,15,14,15,15,16,16,16,15,16,16,15,16,17,16,0,0,0,0,0,1,15,0,0,30,0,0,0,0,0,0,0,4,0,0,0,6,0,0,0,13,0,0,0,10,0,0,0,23,0,0,0,29,0,0,0,23,0,0,0,44,0,0,0,49,0,0,0,57,0,0,0,62,0,0,0,57,0,0,0,90,0,0,0,102,0,0,0,112,0,0,0,123,0,0,0,112,0,0,0,119,0,0,0,175,0,0,0,201,0,0,0,242,0,0,0,244,0,0,0,178,0,0,0,227,0,0,0,91,1,0,0,93,1,0,0,129,1,0,0,157,1,0,0,227,1,0,0,197,1,0,0,181,2,0,0,219,2,0,0,56,3,0,0,195,3,0,0,204,3,0,0,240,3,0,0,205,2,0,0,250,3,0,0,161,3,0,0,180,5,0,0,87,6,0,0,171,7,0,0,77,7,0,0,76,7,0,0,193,10,0,0,197,10,0,0,107,7,0,0,168,12,0,0,4,15,0,0,0,15,0,0,227,15,0,0,60,15,0,0,16,15,0,0,57,15,0,0,230,15,0,0,38,14,0,0,144,14,0,0,197,22,0,0,39,24,0,0,84,25,0,0,197,21,0,0,88,25,0,0,138,31,0,0,74,28,0,0,15,43,0,0,65,43,0,0,14,43,0,0,198,51,0,0,80,48,0,0,79,28,0,0,136,45,0,0,92,48,0,0,24,60,0,0,79,43,0,0,194,44,0,0,71,58,0,0,128,86,0,0,157,86,0,0,66,100,0,0,67,100,0,0,70,100,0,0,110,101,0,0,68,100,0,0,32,113,0,0,138,116,0,0,186,193,0,0,34,126,0,0,166,122,0,0,37,127,0,0,167,122,0,0,32,126,0,0,27,193,0,0,24,193,0,0,165,122,0,0,10,173,0,0,137,243,0,0,187,158,1,0,173,202,0,0,66,254,0,0,64,254,0,0,52,108,1,0,229,180,2,0,101,61,3,0,48,108,1,0,174,231,1,0,92,226,1,0,112,131,1,0,3,231,1,0,186,158,1,0,55,108,1,0,52,226,0,0,110,108,1,0,4,0,0,0,42,0,0,0,97,0,0,0,117,0,0,0,203,0,0,0,255,0,0,0,144,1,0,0,235,1,0,0,209,1,0,0,185,2,0,0,7,3,0,0,57,3,0,0,63,3,0,0,251,3,0,0,180,3,0,0,12,6,0,0,121,6,0,0,69,6,0,0,125,6,0,0,138,7,0,0,227,7,0,0,73,7,0,0,196,10,0,0,210,10,0,0,227,10,0,0,16,12,0,0,22,12,0,0,209,10,0,0,244,12,0,0,226,15,0,0,134,21,0,0,157,14,0,0,241,25,0,0,100,22,0,0,38,30,0,0,56,29,0,0,77,43,0,0,197,51,0,0,194,31,0,0,195,31,0,0,40,29,0,0,29,60,0,0,142,89,0,0,148,240,0,0,164,122,0,0,56,173,0,0,12,172,0,0,26,193,0,0,234,121,0,0,129,200,0,0,68,254,0,0,53,182,0,0,13,172,0,0,30,182,0,0,135,89,0,0,33,113,0,0,130,243,0,0,135,243,0,0,55,226,0,0,71,254,0,0,131,243,0,0,145,240,0,0,133,243,0,0,51,226,0,0,238,130,1,0,184,158,1,0,62,102,1,0,147,240,0,0,20,0,0,0,88,0,0,0,89,1,0,0,103,1,0,0,0,3,0,0,212,3,0,0,181,5,0,0,157,7,0,0,106,7,0,0,103,11,0,0,96,11,0,0,5,15,0,0,240,12,0,0,23,15,0,0,149,14,0,0,34,24,0,0,19,25,0,0,194,22,0,0,47,24,0,0,89,25,0,0,203,31,0,0,39,30,0,0,64,28,0,0,199,51,0,0,123,30,0,0,73,28,0,0,137,45,0,0,35,30,0,0,96,22,0,0,18,63,0,0,198,44,0,0,225,51,0,0,52,91,0,0,154,96,0,0,105,101,0,0,136,116,0,0,33,126,0,0,95,207,0,0,44,113,0,0,157,56,0,0,207,103,0,0,40,127,0,0,63,102,1,0,103,61,3,0,61,102,1,0,93,226,1,0,171,193,3,0,68,92,1,0,54,108,1,0,31,0,0,0,236,0,0,0,35,3,0,0,178,5,0,0,159,7,0,0,194,10,0,0,22,15,0,0,158,14,0,0,86,25,0,0,15,30,0,0,234,25,0,0,102,22,0,0,137,43,0,0,2,43,0,0,140,45,0,0,27,60,0,0,25,60,0,0,181,50,0,0,156,63,0,0,207,44,0,0,151,56,0,0,53,91,0,0,2,173,0,0,41,127,0,0,65,100,0,0,132,56,0,0,136,120,0,0,78,120,0,0,104,101,0,0,187,193,0,0,134,89,0,0,204,103,0,0,73,254,0,0,72,254,0,0,188,193,0,0,65,254,0,0,113,131,1,0,60,102,1,0,49,226,0,0,30,113,0,0,9,173,0,0,146,240,0,0,45,0,0,0,219,1,0,0,129,7,0,0,26,12,0,0,85,15,0,0,128,21,0,0,168,30,0,0,155,45,0,0,175,50,0,0,22,63,0,0,28,60,0,0,52,120,0,0,69,60,0,0,156,56,0,0,206,103,0,0,69,100,0,0,185,193,0,0,137,120,0,0,58,127,0,0,79,120,0,0,43,127,0,0,11,173,0,0,144,240,0,0,29,193,0,0,78,233,0,0,31,113,0,0,241,233,0,0,142,243,0,0,233,121,0,0,3,173,0,0,155,240,0,0,174,202,0,0,70,254,0,0,230,180,2,0,240,233,0,0,182,158,1,0,193,122,6,0,192,122,6,0,102,61,3,0,136,243,0,0,113,0,0,0,160,3,0,0,169,12,0,0,41,24,0,0,57,29,0,0,67,43,0,0,196,44,0,0,84,101,0,0,154,240,0,0,31,182,0,0,205,103,0,0,28,113,0,0,54,182,0,0,42,127,0,0,52,182,0,0,31,193,0,0,94,207,0,0,29,182,0,0,107,240,0,0,171,202,0,0,190,193,0,0,76,233,0,0,153,240,0,0,237,130,1,0,79,233,0,0,25,193,0,0,50,226,0,0,228,180,2,0,138,243,0,0,180,158,1,0,95,226,1,0,77,233,0,0,183,0,0,0,133,7,0,0,204,22,0,0,81,48,0,0,196,51,0,0,111,101,0,0,145,56,0,0,29,113,0,0,175,202,0,0,151,240,0,0,137,116,0,0,152,240,0,0,128,200,0,0,170,202,0,0,134,243,0,0,183,158,1,0,111,108,1,0,132,243,0,0,232,130,1,0,233,130,1,0,48,226,0,0,0,231,1,0,98,61,3,0,99,61,3,0,100,61,3,0,51,108,1,0,22,226,0,0,253,0,0,0,21,12,0,0,101,22,0,0,74,60,0,0,59,127,0,0,150,120,0,0,28,193,0,0,21,226,0,0,50,108,1,0,139,243,0,0,141,243,0,0,234,130,1,0,1,231,1,0,223,18,7,0,70,92,1,0,148,1,0,0,224,15,0,0,19,63,0,0,139,116,0,0,150,240,0,0,128,207,0,0,94,226,1,0,189,37,14,0,97,61,3,0,49,108,1,0,249,1,0,0,18,25,0,0,16,87,0,0,208,243,0,0,191,193,0,0,1,3,0,0,36,30,0,0,8,173,0,0,205,3,0,0,65,28,0,0,189,193,0,0,99,5,0,0,82,58,0,0,209,243,0,0,112,5,0,0,206,44,0,0,23,226,0,0,123,6,0,0,93,101,0,0,75,7,0,0,71,100,0,0,18,12,0,0,251,116,0,0,8,15,0,0,28,182,0,0,34,14,0,0,67,254,0,0,199,22,0,0,54,24,0,0,242,25,0,0,67,28,0,0,63,29,0,0,207,31,0,0,76,43,0,0,76,48,0,0,182,50,0,0,70,58,0,0,7,86,0,0,23,63,0,0,197,44,0,0,155,96,0,0,92,101,0,0,35,126,0,0,193,103,0,0,38,127,0,0,39,127,0,0,149,240,0,0,243,233,0,0,129,207,0,0,30,193,0,0,172,202,0,0,143,243,0,0,242,233,0,0,250,116,0,0,54,226,0,0,69,254,0,0,40,196,1,0,53,226,0,0,239,130,1,0,181,158,1,0,214,243,0,0,236,130,1,0,53,108,1,0,140,243,0,0,231,180,2,0,71,92,1,0,188,37,14,0,2,231,1,0,182,196,1,0,90,226,0,0,170,193,3,0,69,92,1,0,41,196,1,0,185,158,1,0,175,231,1,0,235,130,1,0,212,224,1,0,110,137,3,0,12,6,2,3,4,4,5,5,5,6,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,10,10,10,11,10,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,16,16,16,15,15,15,15,15,16,16,15,16,16,17,16,16,16,17,18,18,17,17,17,17,17,17,17,17,17,4,6,7,8,8,8,9,9,10,10,10,10,10,10,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,13,13,13,14,13,14,14,14,13,13,14,14,16,16,15,16,16,16,15,16,16,16,16,16,16,16,16,16,17,16,16,16,16,17,17,17,18,16,5,8,9,10,10,10,11,11,12,12,12,12,12,12,13,13,13,13,13,13,13,13,14,14,13,14,14,13,14,14,15,14,15,15,15,16,15,16,16,15,15,15,18,18,18,17,18,17,17,6,9,10,11,11,12,12,13,13,13,13,14,14,14,14,14,14,14,14,15,15,15,16,15,15,15,15,15,15,16,16,15,16,16,16,16,17,18,17,16,16,16,7,10,11,12,12,13,13,14,14,14,14,15,14,15,15,15,16,15,15,15,15,16,16,16,17,16,17,16,15,16,16,16,16,18,17,17,19,19,18,16,7,11,12,13,14,14,15,15,16,16,15,16,16,15,16,16,16,16,16,16,16,17,16,17,17,16,17,18,16,17,17,17,8,11,13,14,14,15,15,16,16,16,16,16,16,16,16,17,17,16,17,17,17,17,18,18,18,17,17,8,12,14,14,15,15,16,17,17,16,16,17,17,20,17,9,12,14,16,16,16,17,21,18,17,9,13,15,16,16,10,13,16,10,14,16,11,15,16,11,15,17,11,15,12,15,12,16,12,16,13,16,13,13,13,14,14,13,14,14,14,15,15,14,15,15,15,15,15,15,15,16,17,16,16,16,16,17,16,17,16,18,17,17,17,16,17,17,16,18,17,21,17,18,17,18,17,18,17,17,17,17,19,0,0,0,0,178,1,0,0,105,0,0,0,0,0,0,0,4,0,0,0,6,0,0,0,14,0,0,0,20,0,0,0,25,0,0,0,22,0,0,0,43,0,0,0,48,0,0,0,61,0,0,0,60,0,0,0,90,0,0,0,95,0,0,0,109,0,0,0,126,0,0,0,95,0,0,0,127,0,0,0,182,0,0,0,188,0,0,0,216,0,0,0,242,0,0,0,254,0,0,0,188,0,0,0,252,0,0,0,97,1,0,0,110,1,0,0,116,1,0,0,118,1,0,0,162,1,0,0,227,1,0,0,243,1,0,0,116,1,0,0,122,1,0,0,234,1,0,0,168,2,0,0,196,2,0,0,230,2,0,0,20,3,0,0,70,3,0,0,103,3,0,0,233,3,0,0,229,2,0,0,238,2,0,0,214,3,0,0,85,5,0,0,84,5,0,0,87,5,0,0,195,5,0,0,214,5,0,0,224,6,0,0,47,6,0,0,226,6,0,0,153,7,0,0,137,7,0,0,250,7,0,0,206,5,0,0,254,7,0,0,236,5,0,0,204,7,0,0,175,7,0,0,167,10,0,0,25,11,0,0,148,11,0,0,133,11,0,0,159,11,0,0,72,12,0,0,69,12,0,0,216,13,0,0,76,12,0,0,75,12,0,0,153,13,0,0,31,13,0,0,194,13,0,0,149,15,0,0,162,15,0,0,181,11,0,0,159,11,0,0,93,15,0,0,191,11,0,0,71,15,0,0,74,21,0,0,213,15,0,0,69,15,0,0,127,15,0,0,13,22,0,0,137,24,0,0,87,23,0,0,34,23,0,0,179,24,0,0,45,23,0,0,57,26,0,0,24,26,0,0,179,27,0,0,48,27,0,0,99,30,0,0,60,23,0,0,53,27,0,0,35,23,0,0,128,30,0,0,238,31,0,0,97,23,0,0,252,31,0,0,127,31,0,0,124,44,0,0,161,31,0,0,123,23,0,0,85,23,0,0,90,23,0,0,166,31,0,0,171,46,0,0,10,49,0,0,105,44,0,0,105,54,0,0,39,49,0,0,3,49,0,0,67,46,0,0,98,54,0,0,101,49,0,0,36,49,0,0,59,49,0,0,17,49,0,0,104,54,0,0,59,52,0,0,82,60,0,0,252,62,0,0,108,46,0,0,218,63,0,0,248,62,0,0,123,46,0,0,226,62,0,0,197,60,0,0,114,61,0,0,192,88,0,0,248,61,0,0,169,46,0,0,126,62,0,0,109,85,0,0,130,92,0,0,113,61,0,0,123,62,0,0,66,60,0,0,215,88,0,0,78,63,0,0,0,98,0,0,112,61,0,0,178,92,0,0,150,92,0,0,176,92,0,0,69,63,0,0,177,92,0,0,109,46,0,0,16,49,0,0,104,47,0,0,144,92,0,0,166,124,0,0,136,124,0,0,4,98,0,0,200,98,0,0,166,120,0,0,134,121,0,0,213,121,0,0,173,177,0,0,137,121,0,0,121,176,0,0,221,92,0,0,212,170,0,0,232,93,0,0,205,125,0,0,135,121,0,0,103,93,0,0,153,93,0,0,29,185,0,0,241,124,0,0,155,93,0,0,215,121,0,0,123,176,0,0,133,92,0,0,154,93,0,0,204,125,0,0,191,126,0,0,206,125,0,0,251,125,0,0,192,126,0,0,26,125,0,0,7,122,0,0,132,92,0,0,113,196,0,0,242,124,0,0,239,186,0,0,210,185,0,0,235,93,0,0,214,123,0,0,69,184,0,0,152,93,0,0,26,185,0,0,232,186,0,0,224,196,0,0,49,220,0,0,61,249,0,0,206,187,0,0,210,209,0,0,169,247,0,0,185,217,0,0,203,187,0,0,0,185,0,0,215,170,0,0,189,186,0,0,225,196,0,0,111,244,0,0,136,197,0,0,139,197,0,0,230,96,1,0,207,187,0,0,195,186,0,0,69,249,0,0,163,247,0,0,193,209,0,0,142,251,0,0,164,247,0,0,140,251,0,0,12,244,0,0,115,196,0,0,114,253,0,0,205,187,0,0,250,255,0,0,64,249,0,0,201,187,0,0,168,247,0,0,237,161,1,0,197,187,0,0,111,242,1,0,253,99,1,0,199,96,1,0,245,161,1,0,71,249,0,0,252,99,1,0,179,84,1,0,246,255,0,0,246,99,1,0,233,96,1,0,240,161,1,0,185,186,0,0,186,186,0,0,134,112,1,0,3,185,0,0,117,253,0,0,8,243,0,0,243,118,1,0,255,99,1,0,125,253,0,0,120,187,1,0,251,99,1,0,219,136,1,0,247,161,1,0,178,84,1,0,253,114,1,0,244,99,1,0,115,187,1,0,255,114,1,0,188,186,0,0,125,249,0,0,243,161,1,0,109,187,1,0,213,255,1,0,244,161,1,0,114,242,1,0,128,115,1,0,130,115,1,0,231,255,1,0,200,186,0,0,196,187,0,0,211,136,1,0,224,96,1,0,123,253,0,0,95,114,1,0,245,114,1,0,121,187,1,0,217,250,1,0,105,242,1,0,208,136,1,0,196,186,0,0,197,186,0,0,133,17,3,0,210,136,1,0,204,136,1,0,135,17,3,0,254,231,3,0,209,136,1,0,108,187,1,0,104,242,1,0,210,250,1,0,217,255,1,0,234,161,1,0,104,187,1,0,203,250,1,0,178,253,3,0,26,232,1,0,206,136,1,0,251,114,1,0,239,161,1,0,206,250,1,0,112,187,1,0,193,186,0,0,107,187,1,0,248,114,1,0,102,187,1,0,223,255,1,0,106,187,1,0,215,255,1,0,102,242,1,0,248,118,1,0,83,118,3,0,126,250,1,0,130,17,3,0,200,250,1,0,227,199,2,0,238,112,3,0,236,118,1,0,233,118,1,0,188,228,2,0,197,96,1,0,90,118,3,0,156,206,3,0,115,115,1,0,232,118,1,0,212,136,1,0,241,118,1,0,239,118,1,0,89,118,3,0,124,187,1,0,222,255,1,0,242,118,1,0,139,17,3,0,212,199,2,0,81,118,3,0,159,206,5,0,80,118,3,0,145,17,3,0,246,244,3,0,245,244,3,0,108,160,7,0,193,250,1,0,123,201,5,0,224,199,2,0,58,157,7,0,253,231,3,0,223,199,2,0,240,244,3,0,109,160,7,0,193,118,3,0,59,157,7,0,4,0,0,0,20,0,0,0,89,0,0,0,171,0,0,0,184,0,0,0,119,1,0,0,245,1,0,0,242,1,0,0,21,3,0,0,252,3,0,0,189,5,0,0,45,6,0,0,232,6,0,0,221,7,0,0,4,11,0,0,205,7,0,0,30,11,0,0,30,13,0,0,21,15,0,0,59,15,0,0,65,15,0,0,72,21,0,0,176,24,0,0,59,23,0,0,132,24,0,0,28,26,0,0,180,27,0,0,37,31,0,0,181,23,0,0,109,23,0,0,248,30,0,0,115,46,0,0,7,49,0,0,37,49,0,0,5,49,0,0,73,46,0,0,232,60,0,0,249,62,0,0,94,62,0,0,114,46,0,0,113,52,0,0,217,63,0,0,63,98,0,0,160,120,0,0,103,104,0,0,179,92,0,0,114,98,0,0,236,104,0,0,154,110,0,0,212,121,0,0,152,110,0,0,170,177,0,0,26,110,0,0,133,121,0,0,238,104,0,0,155,110,0,0,136,92,0,0,172,177,0,0,250,125,0,0,101,93,0,0,240,124,0,0,191,124,0,0,117,196,0,0,235,96,1,0,126,187,1,0,166,247,0,0,221,254,1,0,227,96,1,0,251,255,0,0,141,251,0,0,249,255,0,0,192,209,0,0,140,197,0,0,233,161,1,0,184,186,0,0,207,245,0,0,245,255,0,0,197,118,3,0,236,161,1,0,237,96,1,0,222,254,1,0,201,250,1,0,235,161,1,0,36,242,1,0,238,118,1,0,121,253,0,0,128,112,1,0,135,115,1,0,122,187,1,0,233,255,1,0,247,118,1,0,133,115,1,0,129,119,1,0,213,199,2,0,133,119,1,0,227,255,1,0,245,99,1,0,194,250,1,0,249,231,3,0,141,17,3,0,177,253,3,0,226,255,1,0,38,242,1,0,138,17,3,0,217,199,2,0,144,17,3,0,140,17,3,0,243,244,3,0,127,187,1,0,114,187,1,0,132,17,3,0,244,146,11,0,251,231,3,0,217,225,6,0,202,250,1,0,0,35,6,0,184,253,3,0,55,208,3,0,252,231,3,0,1,35,6,0,242,244,3,0,106,242,1,0,14,0,0,0,99,0,0,0,248,0,0,0,238,1,0,0,119,3,0,0,247,3,0,0,227,6,0,0,204,5,0,0,5,11,0,0,210,13,0,0,212,15,0,0,46,23,0,0,42,23,0,0,35,30,0,0,45,31,0,0,99,23,0,0,105,23,0,0,108,23,0,0,117,46,0,0,4,49,0,0,193,46,0,0,88,62,0,0,63,88,0,0,98,63,0,0,68,63,0,0,197,88,0,0,60,98,0,0,244,92,0,0,215,123,0,0,157,93,0,0,210,170,0,0,102,93,0,0,169,177,0,0,120,176,0,0,254,124,0,0,24,185,0,0,111,196,0,0,25,185,0,0,71,184,0,0,27,110,0,0,75,184,0,0,216,170,0,0,116,253,0,0,244,114,1,0,129,112,1,0,124,249,0,0,115,242,1,0,160,247,0,0,124,253,0,0,247,114,1,0,122,253,0,0,119,187,1,0,254,114,1,0,112,242,1,0,115,253,0,0,123,187,1,0,188,161,1,0,125,187,1,0,195,187,0,0,246,114,1,0,235,186,0,0,143,251,0,0,244,244,3,0,180,253,3,0,200,118,3,0,250,231,3,0,208,255,1,0,3,35,6,0,245,146,11,0,97,242,1,0,137,17,3,0,181,253,3,0,219,199,2,0,201,118,3,0,214,250,1,0,209,250,1,0,21,0,0,0,240,0,0,0,224,2,0,0,142,5,0,0,215,5,0,0,77,12,0,0,161,15,0,0,219,11,0,0,86,23,0,0,112,31,0,0,25,44,0,0,60,49,0,0,15,55,0,0,192,60,0,0,168,46,0,0,198,88,0,0,199,88,0,0,183,46,0,0,208,88,0,0,24,125,0,0,88,170,0,0,72,184,0,0,158,93,0,0,108,93,0,0,76,184,0,0,137,197,0,0,1,185,0,0,248,99,1,0,201,186,0,0,197,185,0,0,60,249,0,0,216,136,1,0,199,187,0,0,236,96,1,0,111,253,0,0,217,136,1,0,234,96,1,0,167,247,0,0,68,249,0,0,171,186,0,0,58,220,0,0,207,136,1,0,251,118,1,0,216,199,2,0,215,199,2,0,117,187,1,0,158,206,5,0,2,35,6,0,237,112,3,0,244,118,1,0,209,255,1,0,239,112,3,0,248,244,3,0,199,118,3,0,225,255,1,0,198,118,3,0,255,118,1,0,216,225,6,0,246,118,1,0,135,112,1,0,205,245,0,0,53,0,0,0,160,1,0,0,139,5,0,0,172,10,0,0,154,11,0,0,95,23,0,0,34,30,0,0,140,30,0,0,178,31,0,0,11,49,0,0,209,88,0,0,46,85,0,0,39,92,0,0,110,104,0,0,167,124,0,0,116,196,0,0,51,220,0,0,242,123,0,0,233,93,0,0,53,122,0,0,170,186,0,0,235,185,0,0,149,251,0,0,184,185,0,0,129,115,1,0,98,242,1,0,205,136,1,0,136,112,1,0,250,114,1,0,162,247,0,0,211,250,1,0,192,186,0,0,92,118,3,0,223,254,1,0,37,242,1,0,212,250,1,0,218,199,2,0,157,206,5,0,248,231,3,0,3,226,1,0,215,136,1,0,84,0,0,0,192,2,0,0,161,7,0,0,120,15,0,0,54,27,0,0,163,31,0,0,58,49,0,0,54,52,0,0,58,52,0,0,29,125,0,0,216,123,0,0,223,92,0,0,70,184,0,0,137,177,0,0,184,217,0,0,248,255,0,0,190,217,0,0,138,197,0,0,234,93,0,0,211,209,0,0,228,96,1,0,107,242,1,0,218,136,1,0,2,226,1,0,210,199,2,0,254,99,1,0,147,17,3,0,130,119,1,0,194,118,3,0,209,199,2,0,176,253,3,0,93,118,3,0,208,199,2,0,208,250,1,0,1,226,1,0,221,136,1,0,226,199,2,0,87,118,3,0,85,118,3,0,196,118,3,0,192,118,3,0,234,118,1,0,111,0,0,0,207,3,0,0,213,13,0,0,35,31,0,0,97,44,0,0,208,46,0,0,84,93,0,0,45,85,0,0,131,120,0,0,168,177,0,0,28,185,0,0,191,186,0,0,2,185,0,0,170,247,0,0,165,247,0,0,232,161,1,0,214,255,1,0,190,186,0,0,191,161,1,0,243,99,1,0,216,255,1,0,215,250,1,0,117,242,1,0,220,255,1,0,125,0,0,0,188,5,0,0,73,21,0,0,153,42,0,0,239,61,0,0,115,98,0,0,214,121,0,0,27,125,0,0,211,170,0,0,252,208,0,0,221,199,2,0,214,136,1,0,194,186,0,0,225,199,2,0,118,187,1,0,189,161,1,0,134,17,3,0,120,253,0,0,190,161,1,0,131,17,3,0,182,253,3,0,241,244,3,0,82,118,3,0,213,250,1,0,249,244,3,0,255,231,3,0,156,206,5,0,91,118,3,0,136,17,3,0,114,115,1,0,189,0,0,0,139,7,0,0,33,31,0,0,67,60,0,0,237,61,0,0,214,170,0,0,193,126,0,0,66,249,0,0,134,92,0,0,137,112,1,0,187,186,0,0,232,255,1,0,222,199,2,0,110,242,1,0,196,250,1,0,247,244,3,0,86,118,3,0,125,250,1,0,195,118,3,0,179,253,3,0,143,17,3,0,198,250,1,0,248,0,0,0,237,7,0,0,253,30,0,0,122,62,0,0,145,92,0,0,217,170,0,0,236,186,0,0,50,220,0,0,110,244,0,0,0,226,1,0,250,118,1,0,94,118,3,0,183,253,3,0,214,199,2,0,185,253,3,0,84,118,3,0,88,118,3,0,142,17,3,0,219,255,1,0,246,0,0,0,67,12,0,0,6,49,0,0,239,104,0,0,77,184,0,0,136,177,0,0,204,187,0,0,100,242,1,0,105,187,1,0,134,115,1,0,192,250,1,0,113,1,0,0,57,15,0,0,65,62,0,0,237,104,0,0,188,217,0,0,161,247,0,0,103,187,1,0,221,255,1,0,249,118,1,0,185,1,0,0,125,15,0,0,99,63,0,0,253,208,0,0,234,185,0,0,220,136,1,0,195,250,1,0,242,161,1,0,146,17,3,0,228,255,1,0,246,1,0,0,84,23,0,0,101,104,0,0,9,243,0,0,229,96,1,0,245,118,1,0,95,118,3,0,204,250,1,0,233,1,0,0,26,26,0,0,1,98,0,0,5,241,0,0,240,118,1,0,223,2,0,0,86,23,0,0,109,93,0,0,250,99,1,0,237,118,1,0,66,3,0,0,64,46,0,0,255,208,0,0,130,112,1,0,205,3,0,0,152,42,0,0,252,255,0,0,220,199,2,0,127,250,1,0,254,3,0,0,100,55,0,0,253,255,0,0,252,118,1,0,197,250,1,0,247,2,0,0,209,46,0,0,151,251,0,0,138,5,0,0,220,46,0,0,200,187,0,0,212,5,0,0,61,98,0,0,232,96,1,0,46,6,0,0,48,88,0,0,249,99,1,0,235,6,0,0,5,98,0,0,116,242,1,0,222,7,0,0,201,98,0,0,101,242,1,0,201,5,0,0,222,92,0,0,211,255,1,0,212,5,0,0,136,121,0,0,206,7,0,0,73,184,0,0,27,11,0,0,137,92,0,0,199,250,1,0,147,11,0,0,131,92,0,0,158,11,0,0,79,241,0,0,74,12,0,0,199,185,0,0,212,13,0,0,112,196,0,0,113,242,1,0,56,15,0,0,150,251,0,0,235,118,1,0,160,15,0,0,247,99,1,0,178,11,0,0,27,185,0,0,190,11,0,0,2,241,0,0,68,15,0,0,70,249,0,0,205,250,1,0,121,15,0,0,189,217,0,0,77,21,0,0,198,187,0,0,210,15,0,0,231,96,1,0,43,23,0,0,203,136,1,0,94,23,0,0,118,253,0,0,92,23,0,0,113,187,1,0,159,24,0,0,238,161,1,0,36,31,0,0,246,161,1,0,167,27,0,0,202,187,0,0,125,31,0,0,255,255,0,0,46,31,0,0,101,187,1,0,181,27,0,0,249,114,1,0,239,31,0,0,108,242,1,0,62,31,0,0,119,253,0,0,98,23,0,0,110,187,1,0,249,30,0,0,252,114,1,0,160,31,0,0,183,42,0,0,74,46,0,0,103,242,1,0,179,31,0,0,218,255,1,0,66,46,0,0,1,49,0,0,128,119,1,0,61,49,0,0,117,52,0,0,132,119,1,0,38,49,0,0,207,250,1,0,81,60,0,0,131,119,1,0,64,62,0,0,229,255,1,0,99,54,0,0,224,255,1,0,143,62,0,0,109,242,1,0,60,52,0,0,193,60,0,0,253,118,1,0,69,62,0,0,192,46,0,0,97,63,0,0,238,61,0,0,216,63,0,0,62,88,0,0,69,46,0,0,89,62,0,0,2,61,0,0,232,92,0,0,104,85,0,0,254,118,1,0,105,47,0,0,216,250,1,0,193,88,0,0,131,92,0,0,230,255,1,0,113,98,0,0,28,110,0,0,199,98,0,0,225,104,0,0,47,85,0,0,100,104,0,0,102,104,0,0,153,110,0,0,188,92,0,0,165,124,0,0,161,120,0,0,130,92,0,0,207,125,0,0,59,98,0,0,62,98,0,0,232,104,0,0,54,122,0,0,156,93,0,0,119,176,0,0,243,124,0,0,52,122,0,0,164,124,0,0,25,125,0,0,210,121,0,0,28,125,0,0,217,123,0,0,74,184,0,0,148,251,0,0,213,170,0,0,48,220,0,0,243,123,0,0,238,186,0,0,122,176,0,0,114,196,0,0,30,185,0,0,186,217,0,0,159,93,0,0,254,208,0,0,198,185,0,0,135,92,0,0,78,241,0,0,237,186,0,0,46,185,0,0,3,241,0,0,196,185,0,0,145,251,0,0,187,217,0,0,171,177,0,0,141,197,0,0,254,255,0,0,59,249,0,0,65,249,0,0,234,186,0,0,31,185,0,0,204,245,0,0,191,217,0,0,67,249,0,0,4,241,0,0,96,242,1,0,146,251,0,0,63,249,0,0,166,243,0,0,199,186,0,0,171,247,0,0,198,186,0,0,131,115,1,0,109,253,0,0,233,186,0,0,110,253,0,0,79,231,1,0,202,136,1,0,39,242,1,0,147,251,0,0,144,251,0,0,247,255,0,0,133,112,1,0,131,112,1,0,225,96,1,0,132,112,1,0,62,249,0,0,226,96,1,0,198,96,1,0,241,161,1,0,111,187,1,0,132,115,1,0,112,253,0,0,99,242,1,0,213,136,1,0,166,115,1,0,206,245,0,0,242,99,1,0,113,253,0,0,210,255,1,0,196,96,1,0,212,255,1,0,211,199,2,0,116,187,1,0,9,7,2,3,4,4,5,5,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,13,14,14,13,14,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,14,14,15,14,14,15,15,15,15,15,15,15,15,15,14,15,15,15,15,15,15,15,15,15,15,14,15,15,15,15,15,15,15,15,15,16,15,16,16,16,16,15,15,16,16,16,16,16,15,16,16,16,15,16,15,15,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,16,17,16,17,17,16,17,16,17,16,16,17,17,17,16,17,16,16,17,16,17,16,17,17,16,16,17,17,17,17,17,17,17,17,16,17,17,16,17,17,17,17,17,17,17,17,16,18,17,17,17,17,17,17,17,17,17,17,17,17,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,18,17,17,17,17,18,17,17,18,19,17,17,17,18,17,17,17,18,18,18,17,17,17,18,17,17,17,17,17,17,17,17,17,18,18,18,18,18,18,18,18,18,18,17,18,18,18,18,17,18,18,18,17,17,18,18,18,18,19,18,18,19,19,20,18,19,18,19,19,18,19,20,18,19,4,6,7,8,9,9,9,10,10,10,11,11,11,11,12,12,12,12,12,12,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,16,15,15,15,15,16,16,15,16,16,15,16,17,17,17,17,17,16,16,16,16,16,17,17,17,16,18,17,17,17,18,17,17,18,17,17,17,17,17,18,17,18,18,18,17,17,18,19,18,18,17,17,18,18,18,18,19,17,17,18,20,19,19,18,19,18,19,19,19,19,17,5,7,9,10,10,11,11,12,12,12,13,13,13,13,13,14,14,14,14,14,15,14,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,15,16,16,17,17,17,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,16,16,19,18,18,19,17,19,20,17,18,18,18,18,18,18,6,8,10,11,12,12,12,13,13,13,14,14,14,14,15,15,15,15,15,15,16,16,16,16,16,16,17,17,17,16,16,17,17,17,17,17,17,17,16,16,16,17,18,18,18,17,19,19,18,18,17,18,19,18,17,18,18,19,18,17,17,6,9,11,12,13,13,13,14,14,14,15,15,15,15,15,16,16,16,16,16,16,17,16,17,17,17,17,17,17,17,18,17,18,17,17,18,18,19,19,17,17,7,10,12,13,13,14,14,14,14,15,16,16,16,16,16,16,16,16,16,16,17,17,17,17,18,17,18,18,18,18,18,18,18,18,17,17,18,18,18,18,18,18,7,10,12,13,14,15,15,15,15,16,16,17,17,17,17,17,17,17,17,17,17,18,17,17,8,11,13,14,15,15,15,15,16,16,18,17,17,18,17,17,18,17,17,18,18,19,18,18,19,19,19,18,18,18,8,11,13,14,15,16,16,16,16,17,17,17,18,17,18,19,18,18,18,18,18,18,8,12,14,15,15,16,16,16,17,17,18,18,18,18,18,18,18,18,17,9,12,14,15,16,16,17,17,17,17,18,9,12,14,15,16,17,17,17,18,9,13,15,16,17,17,18,17,18,17,9,13,15,16,17,18,18,18,10,13,15,16,18,10,14,16,17,18,10,14,16,17,10,14,16,18,18,10,14,16,18,18,11,15,16,11,15,17,11,15,17,11,15,17,11,15,17,11,15,17,12,16,17,12,15,12,16,12,16,18,12,16,12,16,12,16,12,16,17,12,16,18,12,17,13,16,13,16,13,16,18,13,16,13,17,13,17,13,17,13,17,13,17,13,17,13,17,13,17,13,16,13,17,13,17,13,17,14,17,14,17,14,17,14,14,14,17,14,17,14,14,18,14,14,18,14,18,14,18,14,17,14,17,14,17,14,14,18,14,15,15,15,14,15,15,14,15,15,15,18,15,18,15,15,17,15,15,15,15,15,15,15,15,15,15,15,16,15,15,15,15,16,16,16,16,16,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,16,16,16,17,16,16,16,17,17,17,17,17,16,17,17,17,17,16,16,16,17,17,17,17,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,18,17,230,3,0,0,246,0,0,0,0,0,0,0,2,0,0,0,6,0,0,0,15,0,0,0,27,0,0,0,40,0,0,0,57,0,0,0,63,0,0,0,107,0,0,0,118,0,0,0,183,0,0,0,232,0,0,0,239,0,0,0,105,1,0,0,167,1,0,0,212,1,0,0,220,1,0,0,196,2,0,0,73,3,0,0,85,3,0,0,145,3,0,0,220,3,0,0,129,5,0,0,178,5,0,0,152,6,0,0,12,7,0,0,85,7,0,0,58,7,0,0,116,7,0,0,207,7,0,0,10,11,0,0,102,11,0,0,46,13,0,0,94,13,0,0,27,14,0,0,172,14,0,0,90,14,0,0,126,15,0,0,161,15,0,0,62,22,0,0,55,26,0,0,82,26,0,0,57,28,0,0,179,26,0,0,95,29,0,0,182,28,0,0,82,31,0,0,217,29,0,0,4,44,0,0,46,44,0,0,45,44,0,0,35,44,0,0,103,52,0,0,163,52,0,0,27,53,0,0,1,53,0,0,93,58,0,0,28,53,0,0,117,56,0,0,234,61,0,0,123,57,0,0,219,57,0,0,241,61,0,0,216,57,0,0,180,59,0,0,10,88,0,0,77,88,0,0,66,88,0,0,19,91,0,0,234,88,0,0,125,105,0,0,6,106,0,0,204,104,0,0,199,106,0,0,150,106,0,0,244,114,0,0,67,117,0,0,180,114,0,0,32,125,0,0,3,176,0,0,181,115,0,0,230,123,0,0,128,209,0,0,209,123,0,0,184,124,0,0,6,125,0,0,37,125,0,0,242,210,0,0,154,209,0,0,52,211,0,0,220,225,0,0,41,213,0,0,132,213,0,0,210,225,0,0,227,229,0,0,196,238,0,0,100,229,0,0,73,250,0,0,1,96,1,0,220,238,0,0,250,247,0,0,44,163,1,0,49,97,1,0,3,96,1,0,200,249,0,0,128,239,1,0,160,210,1,0,75,170,1,0,206,247,0,0,254,171,1,0,80,170,1,0,88,164,1,0,22,168,1,0,228,202,1,0,254,210,1,0,46,213,1,0,76,170,1,0,69,194,2,0,161,210,1,0,93,163,1,0,27,202,1,0,216,213,1,0,49,245,1,0,28,202,1,0,137,243,1,0,175,244,1,0,231,165,3,0,251,81,3,0,75,194,2,0,206,75,3,0,77,194,2,0,73,194,2,0,74,194,2,0,252,45,7,0,239,87,3,0,2,80,3,0,230,165,3,0,49,148,3,0,59,132,5,0,119,74,3,0,49,132,5,0,243,165,3,0,221,165,3,0,229,229,3,0,189,86,3,0,110,151,3,0,210,163,6,0,13,80,3,0,196,148,6,0,189,128,5,0,232,229,3,0,149,75,7,0,110,74,3,0,124,151,3,0,50,148,3,0,210,176,5,0,216,163,6,0,184,128,5,0,203,176,5,0,215,176,5,0,238,45,7,0,237,45,7,0,236,45,7,0,156,75,7,0,127,151,3,0,234,45,7,0,158,75,7,0,125,190,7,0,191,128,5,0,213,176,5,0,168,203,7,0,145,75,7,0,221,229,3,0,113,97,11,0,179,70,13,0,185,70,13,0,161,203,7,0,159,75,7,0,225,45,7,0,245,89,14,0,235,229,3,0,4,0,0,0,21,0,0,0,56,0,0,0,117,0,0,0,232,0,0,0,211,1,0,0,71,3,0,0,156,3,0,0,144,6,0,0,74,7,0,0,96,11,0,0,147,14,0,0,116,15,0,0,61,22,0,0,90,26,0,0,36,29,0,0,190,28,0,0,75,31,0,0,104,52,0,0,98,53,0,0,71,57,0,0,130,62,0,0,4,88,0,0,18,91,0,0,3,88,0,0,109,105,0,0,158,106,0,0,124,105,0,0,120,105,0,0,251,106,0,0,178,116,0,0,245,114,0,0,192,115,0,0,65,117,0,0,68,105,0,0,183,116,0,0,211,112,0,0,169,123,0,0,177,176,0,0,175,209,0,0,221,225,0,0,226,229,0,0,163,225,0,0,195,238,0,0,47,97,1,0,97,233,0,0,218,238,0,0,142,231,0,0,72,250,0,0,44,97,1,0,17,229,0,0,101,229,0,0,83,233,0,0,74,170,1,0,157,229,0,0,44,213,1,0,17,168,1,0,231,202,1,0,252,171,1,0,45,213,1,0,207,202,1,0,5,207,1,0,84,194,2,0,114,74,3,0,172,244,1,0,107,151,3,0,113,74,3,0,217,198,2,0,115,216,2,0,106,74,3,0,231,87,3,0,76,70,3,0,245,229,3,0,51,132,5,0,58,245,1,0,10,80,3,0,234,87,3,0,115,74,3,0,47,148,3,0,229,87,3,0,117,151,3,0,205,148,6,0,114,151,3,0,165,203,7,0,239,163,6,0,131,84,3,0,152,75,7,0,193,176,5,0,112,151,3,0,215,165,3,0,51,148,3,0,52,148,3,0,206,148,6,0,190,128,5,0,255,229,3,0,236,163,6,0,111,97,11,0,177,70,13,0,209,163,6,0,229,45,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1430724);
/* memory initializer */ allocate([110,75,7,0,233,45,7,0,0,231,3,0,182,70,13,0,233,163,6,0,105,75,7,0,117,86,14,0,184,70,13,0,170,203,7,0,209,165,3,0,12,0,0,0,60,0,0,0,235,0,0,0,241,1,0,0,164,3,0,0,168,6,0,0,213,7,0,0,67,13,0,0,119,14,0,0,197,22,0,0,177,28,0,0,93,44,0,0,85,58,0,0,86,58,0,0,81,62,0,0,181,59,0,0,10,91,0,0,159,106,0,0,184,116,0,0,40,125,0,0,135,209,0,0,14,212,0,0,46,213,0,0,37,212,0,0,227,234,0,0,211,225,0,0,46,97,1,0,158,229,0,0,194,238,0,0,120,229,0,0,26,229,0,0,121,229,0,0,21,229,0,0,96,233,0,0,131,209,0,0,32,210,0,0,203,210,0,0,18,229,0,0,62,108,1,0,2,96,1,0,66,108,1,0,233,202,1,0,26,70,3,0,250,210,1,0,8,163,1,0,73,168,1,0,7,207,1,0,143,243,1,0,101,75,3,0,83,194,2,0,158,239,1,0,195,203,1,0,193,203,1,0,85,194,2,0,132,243,1,0,53,132,5,0,205,197,2,0,247,165,3,0,82,194,2,0,156,149,3,0,216,198,2,0,211,165,3,0,120,173,6,0,242,163,6,0,169,203,7,0,118,97,11,0,235,45,7,0,100,151,3,0,246,229,3,0,216,165,3,0,140,74,7,0,230,163,6,0,209,148,6,0,121,173,6,0,146,69,26,0,251,89,14,0,179,203,7,0,205,176,5,0,23,0,0,0,181,0,0,0,195,2,0,0,183,5,0,0,28,11,0,0,92,14,0,0,63,22,0,0,178,26,0,0,250,30,0,0,138,52,0,0,110,57,0,0,218,88,0,0,99,105,0,0,48,106,0,0,205,114,0,0,207,115,0,0,231,124,0,0,202,210,0,0,216,210,0,0,100,231,0,0,148,231,0,0,8,96,1,0,103,97,1,0,126,97,1,0,73,170,1,0,11,163,1,0,19,168,1,0,218,198,2,0,128,165,1,0,194,203,1,0,202,249,0,0,127,97,1,0,254,210,1,0,252,247,0,0,64,108,1,0,19,229,0,0,197,238,0,0,195,247,0,0,8,213,1,0,30,168,1,0,253,210,1,0,48,148,3,0,134,84,3,0,253,229,3,0,76,194,2,0,90,199,2,0,116,74,3,0,244,165,3,0,77,70,3,0,202,148,6,0,241,165,3,0,9,213,1,0,192,213,1,0,72,70,3,0,78,70,3,0,213,163,6,0,232,163,6,0,231,163,6,0,195,176,5,0,72,194,2,0,138,243,1,0,242,165,3,0,229,163,6,0,41,0,0,0,104,1,0,0,140,5,0,0,103,11,0,0,157,15,0,0,61,28,0,0,191,28,0,0,32,44,0,0,29,53,0,0,246,61,0,0,249,106,0,0,181,114,0,0,215,177,0,0,178,176,0,0,10,212,0,0,43,213,0,0,82,233,0,0,151,231,0,0,195,99,1,0,160,195,1,0,134,243,1,0,33,202,1,0,85,70,3,0,71,194,2,0,59,245,1,0,80,194,2,0,79,194,2,0,133,243,1,0,93,239,1,0,21,207,1,0,234,202,1,0,10,171,1,0,25,207,1,0,61,245,1,0,194,213,1,0,251,210,1,0,88,239,1,0,120,74,3,0,236,87,3,0,51,245,1,0,225,165,3,0,210,148,6,0,130,132,5,0,238,165,3,0,220,198,2,0,235,87,3,0,196,176,5,0,120,151,3,0,225,163,6,0,180,203,7,0,225,165,3,0,104,75,7,0,239,165,3,0,210,165,3,0,36,148,3,0,226,45,7,0,246,89,14,0,247,89,14,0,2,231,3,0,236,229,3,0,139,243,1,0,59,0,0,0,240,1,0,0,119,7,0,0,168,15,0,0,178,28,0,0,132,45,0,0,87,58,0,0,214,61,0,0,23,105,0,0,17,106,0,0,7,125,0,0,226,234,0,0,150,231,0,0,201,249,0,0,251,247,0,0,102,97,1,0,96,97,1,0,27,171,1,0,250,171,1,0,123,216,2,0,247,210,1,0,104,151,3,0,140,243,1,0,83,70,3,0,81,70,3,0,217,163,6,0,1,80,3,0,189,171,3,0,66,135,3,0,38,148,3,0,118,74,3,0,236,165,3,0,117,74,3,0,0,80,3,0,136,84,3,0,16,207,1,0,219,198,2,0,237,87,3,0,232,87,3,0,233,87,3,0,240,165,3,0,194,148,6,0,120,97,11,0,245,45,7,0,37,148,3,0,43,148,3,0,109,75,7,0,111,75,7,0,119,97,11,0,121,97,11,0,106,75,7,0,114,97,11,0,135,132,5,0,238,229,3,0,237,229,3,0,242,45,7,0,244,45,7,0,174,203,7,0,202,163,6,0,134,14,7,0,207,75,3,0,200,163,6,0,89,0,0,0,132,3,0,0,91,13,0,0,56,28,0,0,96,53,0,0,91,57,0,0,78,88,0,0,100,105,0,0,205,115,0,0,231,177,0,0,152,231,0,0,141,231,0,0,67,250,0,0,72,168,1,0,47,163,1,0,78,170,1,0,74,70,3,0,171,244,1,0,141,243,1,0,235,165,3,0,212,165,3,0,138,84,3,0,199,163,6,0,208,176,5,0,197,163,6,0,176,203,7,0,203,148,6,0,229,165,3,0,226,229,3,0,44,148,3,0,114,216,2,0,174,244,1,0,213,165,3,0,211,148,6,0,129,132,5,0,9,80,3,0,116,151,3,0,50,132,5,0,108,97,11,0,219,176,5,0,139,84,3,0,116,97,11,0,149,93,29,0,76,0,11,0,178,203,7,0,229,165,3,0,143,74,7,0,249,89,14,0,246,45,7,0,253,89,14,0,173,203,7,0,125,66,13,0,255,44,7,0,122,151,3,0,217,176,5,0,109,97,11,0,107,97,11,0,147,69,26,0,175,203,7,0,218,176,5,0,113,0,0,0,235,3,0,0,3,22,0,0,108,44,0,0,97,57,0,0,200,104,0,0,49,106,0,0,189,114,0,0,194,210,0,0,27,229,0,0,230,229,0,0,251,171,1,0,255,210,1,0,229,202,1,0,92,239,1,0,94,239,1,0,19,207,1,0,109,74,3,0,109,151,3,0,106,97,11,0,242,229,3,0,196,163,6,0,105,97,11,0,220,229,3,0,185,128,5,0,153,75,7,0,100,87,7,0,52,132,5,0,217,165,3,0,90,148,6,0,89,148,6,0,140,84,3,0,233,165,3,0,87,148,6,0,241,45,7,0,94,148,6,0,94,163,6,0,1,231,3,0,104,97,11,0,221,176,5,0,222,165,3,0,194,163,6,0,120,66,13,0,204,163,6,0,253,45,7,0,101,97,11,0,154,0,22,0,177,203,7,0,124,66,13,0,98,97,11,0,94,118,14,0,190,236,28,0,182,203,7,0,84,148,6,0,96,97,11,0,122,66,13,0,150,93,29,0,109,29,11,0,244,89,14,0,232,45,7,0,219,165,3,0,122,0,0,0,174,6,0,0,60,28,0,0,186,58,0,0,233,88,0,0,204,114,0,0,221,210,0,0,45,210,0,0,193,238,0,0,219,238,0,0,162,210,1,0,91,239,1,0,226,87,3,0,191,171,3,0,249,210,1,0,4,80,3,0,220,165,3,0,252,81,3,0,108,151,3,0,198,163,6,0,203,163,6,0,234,229,3,0,243,89,14,0,206,163,6,0,82,148,6,0,240,89,14,0,144,75,7,0,121,66,13,0,123,66,13,0,181,203,7,0,197,176,5,0,227,165,3,0,226,165,3,0,208,0,0,0,117,7,0,0,254,30,0,0,213,61,0,0,140,114,0,0,185,124,0,0,162,225,0,0,133,234,0,0,216,238,0,0,10,163,1,0,79,170,1,0,223,165,3,0,8,80,3,0,224,165,3,0,244,229,3,0,247,229,3,0,108,29,11,0,62,132,5,0,112,74,3,0,248,45,7,0,107,75,7,0,127,66,13,0,240,45,7,0,191,176,5,0,192,176,5,0,176,70,13,0,239,45,7,0,248,89,14,0,100,46,22,0,111,29,11,0,224,165,3,0,39,148,3,0,102,145,6,0,226,163,6,0,227,163,6,0,141,74,7,0,126,66,13,0,151,93,29,0,180,70,13,0,216,176,5,0,211,163,6,0,224,0,0,0,99,11,0,0,204,52,0,0,51,106,0,0,201,115,0,0,160,225,0,0,253,247,0,0,204,249,0,0,125,97,1,0,235,202,1,0,169,244,1,0,179,171,3,0,80,148,6,0,32,148,3,0,119,151,3,0,224,229,3,0,212,163,6,0,237,163,6,0,102,97,11,0,241,89,14,0,110,29,11,0,118,86,14,0,234,163,6,0,116,86,14,0,99,97,11,0,183,70,13,0,166,203,7,0,186,70,13,0,148,93,29,0,100,97,11,0,241,163,6,0,162,203,7,0,81,148,6,0,250,45,7,0,187,70,13,0,247,45,7,0,148,75,7,0,191,236,28,0,250,89,14,0,155,0,22,0,228,163,6,0,230,0,0,0,148,14,0,0,118,56,0,0,239,112,0,0,42,213,0,0,21,96,1,0,20,96,1,0,249,171,1,0,23,207,1,0,121,74,3,0,80,70,3,0,5,231,3,0,208,163,6,0,48,132,5,0,157,75,7,0,126,190,7,0,190,176,5,0,115,151,3,0,222,163,6,0,251,0,0,0,123,15,0,0,215,61,0,0,208,123,0,0,156,229,0,0,205,249,0,0,24,207,1,0,255,210,1,0,122,74,3,0,41,148,3,0,12,80,3,0,224,45,7,0,86,148,6,0,124,190,7,0,181,70,13,0,178,70,13,0,221,163,6,0,162,1,0,0,59,22,0,0,19,105,0,0,22,176,0,0,66,250,0,0,45,163,1,0,6,207,1,0,124,74,3,0,125,74,3,0,97,97,11,0,129,84,3,0,250,229,3,0,160,203,7,0,127,190,7,0,163,203,7,0,167,203,7,0,211,176,5,0,230,45,7,0,220,163,6,0,169,1,0,0,180,26,0,0,52,106,0,0,106,212,0,0,48,97,1,0,95,239,1,0,50,245,1,0,54,245,1,0,46,148,3,0,54,132,5,0,219,163,6,0,91,148,6,0,201,1,0,0,160,28,0,0,139,114,0,0,217,238,0,0,57,245,1,0,29,202,1,0,101,151,3,0,102,151,3,0,57,132,5,0,93,148,6,0,103,151,3,0,211,1,0,0,44,31,0,0,252,123,0,0,97,97,1,0,82,70,3,0,237,165,3,0,141,84,3,0,56,132,5,0,218,163,6,0,193,2,0,0,94,44,0,0,53,211,0,0,26,171,1,0,116,216,2,0,6,80,3,0,132,84,3,0,204,176,5,0,154,75,7,0,243,45,7,0,214,163,6,0,218,2,0,0,179,52,0,0,174,213,0,0,238,202,1,0,113,216,2,0,227,87,3,0,151,75,7,0,249,45,7,0,186,128,5,0,212,176,5,0,77,3,0,0,78,53,0,0,80,247,0,0,192,203,1,0,231,165,3,0,228,165,3,0,133,3,0,0,88,58,0,0,65,108,1,0,207,197,2,0,225,229,3,0,108,75,7,0,119,86,14,0,223,163,6,0,144,3,0,0,80,62,0,0,194,99,1,0,118,216,2,0,130,84,3,0,214,176,5,0,58,132,5,0,159,3,0,0,94,88,0,0,131,165,1,0,15,80,3,0,147,75,7,0,113,151,3,0,228,3,0,0,18,105,0,0,67,108,1,0,225,87,3,0,138,5,0,0,111,105,0,0,56,245,1,0,201,176,5,0,207,163,6,0,182,5,0,0,248,106,0,0,52,245,1,0,131,132,5,0,224,163,6,0,149,6,0,0,2,125,0,0,232,202,1,0,133,132,5,0,162,6,0,0,74,117,0,0,238,87,3,0,123,151,3,0,72,7,0,0,178,116,0,0,123,74,3,0,41,7,0,0,224,177,0,0,73,70,3,0,227,229,3,0,61,7,0,0,196,210,0,0,230,229,3,0,187,7,0,0,153,176,0,0,98,151,3,0,206,176,5,0,95,148,6,0,209,7,0,0,171,213,0,0,121,151,3,0,211,7,0,0,47,213,0,0,99,151,3,0,92,148,6,0,26,11,0,0,197,210,0,0,137,84,3,0,35,13,0,0,237,234,0,0,248,229,3,0,50,13,0,0,22,96,1,0,251,229,3,0,65,13,0,0,104,231,0,0,237,165,3,0,31,14,0,0,23,96,1,0,39,128,5,0,173,14,0,0,7,250,0,0,85,148,6,0,84,14,0,0,43,97,1,0,85,14,0,0,129,165,1,0,120,15,0,0,43,163,1,0,188,128,5,0,238,163,6,0,121,15,0,0,253,171,1,0,149,15,0,0,24,171,1,0,240,163,6,0,55,22,0,0,77,170,1,0,45,22,0,0,60,245,1,0,243,163,6,0,49,26,0,0,16,168,1,0,105,151,3,0,80,26,0,0,239,202,1,0,54,26,0,0,46,163,1,0,103,26,0,0,142,243,1,0,133,26,0,0,89,239,1,0,166,26,0,0,131,239,1,0,81,29,0,0,18,192,2,0,83,29,0,0,121,216,2,0,94,29,0,0,5,80,3,0,186,28,0,0,4,207,1,0,83,148,6,0,45,29,0,0,255,81,3,0,45,31,0,0,111,216,2,0,41,31,0,0,7,80,3,0,34,44,0,0,250,81,3,0,3,44,0,0,236,165,3,0,95,44,0,0,235,165,3,0,88,44,0,0,107,74,3,0,105,52,0,0,190,86,3,0,89,44,0,0,108,74,3,0,106,52,0,0,234,165,3,0,189,52,0,0,191,52,0,0,191,86,3,0,106,56,0,0,185,58,0,0,63,132,5,0,107,56,0,0,245,165,3,0,75,58,0,0,33,148,3,0,164,58,0,0,233,165,3,0,90,58,0,0,96,57,0,0,126,151,3,0,233,61,0,0,88,57,0,0,247,61,0,0,225,57,0,0,228,229,3,0,95,57,0,0,88,148,6,0,145,62,0,0,242,61,0,0,40,148,3,0,242,88,0,0,128,62,0,0,195,163,6,0,147,62,0,0,192,148,6,0,184,88,0,0,202,176,5,0,79,88,0,0,193,148,6,0,241,88,0,0,214,104,0,0,16,106,0,0,195,106,0,0,50,106,0,0,210,112,0,0,17,105,0,0,177,116,0,0,148,116,0,0,212,106,0,0,214,106,0,0,184,114,0,0,250,106,0,0,179,116,0,0,64,117,0,0,206,115,0,0,5,176,0,0,179,116,0,0,149,116,0,0,185,116,0,0,54,211,0,0,255,123,0,0,99,119,0,0,200,115,0,0,41,125,0,0,34,182,0,0,33,210,0,0,129,209,0,0,209,177,0,0,184,116,0,0,208,177,0,0,155,209,0,0,195,210,0,0,114,177,0,0,220,210,0,0,35,182,0,0,170,213,0,0,38,212,0,0,130,209,0,0,149,231,0,0,209,225,0,0,55,211,0,0,108,233,0,0,228,229,0,0,20,229,0,0,238,234,0,0,0,96,1,0,103,231,0,0,161,225,0,0,143,231,0,0,4,96,1,0,194,247,0,0,153,231,0,0,231,229,0,0,102,229,0,0,105,231,0,0,81,247,0,0,222,238,0,0,6,250,0,0,5,96,1,0,159,250,0,0,230,165,1,0,102,231,0,0,111,99,1,0,221,238,0,0,192,238,0,0,9,163,1,0,202,206,1,0,205,99,1,0,203,249,0,0,223,238,0,0,130,165,1,0,45,97,1,0,229,229,0,0,248,171,1,0,12,163,1,0,31,202,1,0,204,99,1,0,92,163,1,0,30,202,1,0,81,170,1,0,172,99,1,0,78,168,1,0,63,165,1,0,22,207,1,0,252,210,1,0,179,165,1,0,25,171,1,0,31,168,1,0,195,213,1,0,63,108,1,0,193,213,1,0,252,210,1,0,170,244,1,0,18,168,1,0,53,245,1,0,18,207,1,0,23,168,1,0,124,97,1,0,11,171,1,0,248,210,1,0,130,239,1,0,122,216,2,0,47,213,1,0,48,245,1,0,72,170,1,0,135,84,3,0,253,210,1,0,173,244,1,0,17,207,1,0,27,70,3,0,133,84,3,0,32,202,1,0,237,202,1,0,230,202,1,0,255,171,1,0,79,70,3,0,111,74,3,0,129,239,1,0,75,70,3,0,150,157,3,0,131,243,1,0,55,245,1,0,20,207,1,0,206,197,2,0,14,80,3,0,81,194,2,0,236,202,1,0,135,243,1,0,84,70,3,0,228,87,3,0,120,216,2,0,11,80,3,0,128,84,3,0,232,165,3,0,142,84,3,0,100,75,3,0,168,244,1,0,3,80,3,0,223,229,3,0,112,216,2,0,230,87,3,0,240,229,3,0,90,239,1,0,234,165,3,0,136,243,1,0,3,231,3,0,78,194,2,0,226,165,3,0,253,81,3,0,221,198,2,0,4,231,3,0,254,81,3,0,117,216,2,0,199,176,5,0,106,151,3,0,230,165,3,0,35,148,3,0,128,132,5,0,70,194,2,0,227,165,3,0,119,216,2,0,241,229,3,0,190,171,3,0,137,132,5,0,249,229,3,0,224,87,3,0,188,171,3,0,198,176,5,0,103,145,6,0,101,145,6,0,233,229,3,0,34,148,3,0,111,151,3,0,125,151,3,0,222,229,3,0,201,163,6,0,152,139,5,0,246,165,3,0,208,165,3,0,134,132,5,0,193,163,6,0,252,229,3,0,220,176,5,0,143,84,3,0,45,148,3,0,201,148,6,0,132,132,5,0,232,165,3,0,155,75,7,0,150,75,7,0,208,148,6,0,136,132,5,0,228,165,3,0,42,148,3,0,194,46,7,0,118,151,3,0,209,176,5,0,207,176,5,0,214,165,3,0,252,89,14,0,200,176,5,0,231,229,3,0,183,203,7,0,135,14,7,0,171,203,7,0,194,176,5,0,195,148,6,0,142,74,7,0,243,229,3,0,205,163,6,0,254,45,7,0,46,59,7,0,192,46,7,0,197,148,6,0,55,132,5,0,200,148,6,0,255,45,7,0,53,148,3,0,61,132,5,0,215,163,6,0,193,46,7,0,200,34,13,0,207,148,6,0,115,97,11,0,254,229,3,0,187,128,5,0,242,89,14,0,110,97,11,0,117,97,11,0,218,165,3,0,189,176,5,0,204,148,6,0,60,132,5,0,199,148,6,0,146,75,7,0,195,46,7,0,198,148,6,0,112,97,11,0,172,203,7,0,51,23,11,0,164,203,7,0,103,97,11,0,231,45,7,0,228,45,7,0,192,163,6,0,239,229,3,0,101,46,22,0,227,45,7,0,251,45,7,0,95,163,6,0,235,163,6,0,11,9,2,3,4,4,5,6,6,7,7,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,17,17,17,18,17,17,17,17,17,17,17,18,18,17,17,18,17,17,18,17,18,18,18,18,19,18,18,18,18,18,18,20,18,18,18,19,19,18,19,18,19,19,18,19,19,18,19,19,19,19,18,19,19,19,19,19,19,19,20,20,20,19,19,20,19,20,19,19,20,19,19,20,20,20,20,19,20,21,19,3,5,7,8,9,9,10,11,11,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,16,16,15,15,15,15,16,16,16,16,17,16,17,17,16,17,17,17,17,17,17,16,17,17,17,17,18,17,17,18,18,18,18,18,19,18,18,18,18,18,18,19,19,18,18,18,18,19,18,19,19,19,20,19,18,19,19,19,19,19,19,19,19,19,19,20,20,19,20,19,20,19,20,19,19,21,20,20,19,4,7,8,10,11,11,12,12,13,13,14,14,14,14,15,15,15,15,15,16,16,16,16,16,16,16,17,17,17,17,17,17,17,16,16,16,16,17,17,17,17,18,18,18,17,17,18,18,18,18,18,18,18,18,18,19,18,18,18,19,18,19,19,19,20,20,20,19,19,19,19,19,19,19,21,21,20,19,5,8,10,11,12,13,13,13,14,14,15,15,15,15,16,16,16,16,16,17,17,17,17,17,17,17,17,18,17,18,17,17,17,17,17,17,17,17,17,17,17,19,18,19,18,18,18,18,18,19,18,17,17,18,18,19,19,19,19,18,18,18,19,6,9,11,12,13,13,14,14,14,15,15,16,16,16,16,16,16,17,17,17,18,18,18,18,18,18,18,18,18,18,18,17,18,18,17,18,18,18,18,18,18,19,19,18,18,18,19,19,19,20,19,19,18,19,19,20,21,21,19,19,18,6,10,12,13,14,14,14,15,15,15,16,16,17,17,17,17,17,17,17,18,18,19,18,18,18,19,18,18,18,19,18,18,18,18,18,18,18,18,18,18,18,19,20,20,19,19,19,19,20,20,19,20,19,19,19,20,20,20,19,19,18,19,7,10,12,13,14,15,15,15,16,16,17,17,17,17,17,17,18,18,18,18,19,18,19,19,19,20,19,18,19,19,18,18,19,19,19,18,19,19,20,19,18,20,21,20,20,19,19,21,20,21,20,20,20,19,19,20,20,21,20,19,7,11,13,14,15,15,15,16,16,17,17,17,17,18,18,18,18,18,19,20,19,19,20,19,19,19,19,19,19,19,19,18,18,19,20,19,19,19,20,19,19,19,20,19,20,20,21,20,20,20,21,22,20,19,20,20,21,20,21,20,19,8,11,13,14,15,16,16,16,17,17,17,18,18,18,18,18,19,18,19,19,19,19,21,19,19,21,19,20,20,20,19,18,18,8,12,14,15,16,16,16,16,17,17,17,19,18,18,19,19,20,19,18,20,19,20,20,19,19,20,20,21,21,20,19,19,19,19,19,19,20,21,20,19,19,8,12,14,15,16,16,17,17,17,18,18,18,19,19,19,19,19,19,20,21,20,21,19,21,20,20,20,20,21,20,19,20,19,20,20,20,19,22,21,21,19,9,12,14,15,16,17,17,17,18,18,18,19,19,19,19,20,19,19,19,9,13,15,16,17,17,18,18,18,19,18,20,19,20,20,20,19,9,13,15,16,17,17,18,18,18,20,18,19,20,20,20,20,19,20,19,9,13,15,16,17,18,18,18,19,19,19,19,10,14,16,17,18,18,19,19,19,19,19,10,14,16,17,18,18,18,19,19,10,14,16,17,18,18,18,19,19,20,19,10,14,16,18,18,18,19,20,19,19,10,14,17,18,18,18,10,15,17,18,19,19,21,19,11,15,17,18,18,19,19,11,15,17,18,19,19,11,15,17,18,11,15,18,19,19,11,15,18,19,19,11,16,18,19,11,15,18,19,11,16,18,12,16,18,19,12,16,19,12,16,19,19,19,12,16,19,12,16,19,19,12,16,18,12,16,19,12,17,19,12,17,19,12,17,19,12,17,19,13,17,13,17,13,17,19,19,13,17,13,17,19,13,17,13,18,19,13,17,19,13,18,13,17,13,18,13,18,13,18,13,18,13,18,13,18,14,18,19,14,18,14,18,14,18,14,18,14,19,14,19,14,18,14,18,14,18,14,19,14,14,18,14,14,19,14,18,14,19,14,19,14,15,19,15,15,15,15,19,15,19,15,15,19,15,15,19,15,19,15,19,15,19,15,15,15,15,15,15,15,15,15,15,15,16,15,15,15,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,16,16,16,17,17,16,17,17,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,18,17,17,17,17,17,17,17,17,18,17,17,18,17,17,17,17,18,18,17,17,17,17,17,17,17,18,17,18,18,17,17,17,18,18,18,17,18,17,18,18,18,18,18,18,18,18,18,17,18,18,18,18,19,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,19,18,18,19,18,18,18,19,18,19,18,18,19,18,18,19,19,19,19,19,18,19,18,19,18,19,19,18,18,19,19,19,19,19,19,19,19,19,19,18,19,19,19,19,19,18,19,19,19,19,19,19,19,19,19,19,20,19,19,19,19,21,19,19,20,19,20,19,19,19,19,19,20,20,20,19,19,19,20,19,19,19,20,20,19,20,19,19,21,20,20,19,19,19,19,19,19,20,19,20,20,20,20,20,20,20,19,19,21,20,20,19,19,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,0,0,1,0,2,0,3,0,4,0,5,0,0,0,1,0,2,0,0,0,1,0,2,0,0,0,1,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,160,64,0,0,160,64,0,0,160,64,0,0,192,64,0,0,192,64,0,0,192,64,0,0,224,64,0,0,224,64,0,0,224,64,0,0,0,65,0,0,0,65,0,0,16,65,0,0,16,65,0,0,32,65,0,0,32,65,0,0,48,65,0,0,48,65,0,0,64,65,0,0,64,65,0,0,80,65,0,0,80,65,0,0,96,65,0,0,96,65,0,0,112,65,0,0,112,65,0,0,128,65,0,0,128,65,0,0,136,65,0,0,136,65,0,0,144,65,0,0,144,65,0,0,152,65,0,0,152,65,0,0,160,65,0,0,160,65,0,0,168,65,0,0,168,65,0,0,176,65,0,0,176,65,0,0,184,65,0,0,184,65,0,0,192,65,0,0,192,65,0,0,200,65,0,0,200,65,0,0,208,65,0,0,208,65,0,0,216,65,0,0,216,65,0,0,224,65,0,0,224,65,0,0,232,65,0,0,232,65,0,0,240,65,0,0,240,65,0,0,248,65,0,0,248,65,0,0,0,66,0,0,0,66,0,0,4,66,0,0,4,66,0,0,8,66,0,0,8,66,0,0,12,66,0,0,12,66,0,0,16,66,0,0,16,66,0,0,20,66,0,0,20,66,0,0,24,66,0,0,24,66,0,0,28,66,0,0,28,66,0,0,32,66,0,0,32,66,0,0,36,66,0,0,36,66,0,0,40,66,0,0,40,66,0,0,44,66,0,0,44,66,0,0,48,66,0,0,48,66,0,0,52,66,0,0,52,66,0,0,56,66,0,0,56,66,0,0,60,66,0,0,60,66,0,0,64,66,0,0,64,66,0,0,68,66,0,0,68,66,0,0,72,66,0,0,76,66,0,0,80,66,226,1,0,0,127,0,0,0,0,0,0,0,2,0,0,0,8,0,0,0,14,0,0,0,25,0,0,0,47,0,0,0,55,0,0,0,96,0,0,0,108,0,0,0,149,0,0,0,198,0,0,0,240,0,0,0,46,1,0,0,137,1,0,0,165,1,0,0,248,1,0,0,83,2,0,0,10,3,0,0,68,3,0,0,77,3,0,0,242,3,0,0,189,4,0,0,215,5,0,0,42,6,0,0,139,6,0,0,147,6,0,0,151,7,0,0,125,9,0,0,171,11,0,0,82,12,0,0,94,12,0,0,33,13,0,0,32,13,0,0,26,15,0,0,206,15,0,0,209,15,0,0,241,18,0,0,89,23,0,0,172,24,0,0,167,24,0,0,191,24,0,0,43,26,0,0,82,30,0,0,80,30,0,0,49,30,0,0,184,31,0,0,230,37,0,0,231,37,0,0,180,46,0,0,183,46,0,0,105,49,0,0,91,49,0,0,124,49,0,0,108,49,0,0,202,52,0,0,141,52,0,0,64,63,0,0,162,60,0,0,118,63,0,0,195,75,0,0,229,75,0,0,115,63,0,0,248,75,0,0,249,75,0,0,49,97,0,0,139,98,0,0,137,98,0,0,218,98,0,0,138,98,0,0,212,98,0,0,151,105,0,0,180,98,0,0,24,105,0,0,77,121,0,0,123,126,0,0,135,126,0,0,234,126,0,0,78,121,0,0,157,105,0,0,103,121,0,0,159,105,0,0,219,98,0,0,122,126,0,0,235,126,0,0,192,186,0,0,201,151,0,0,55,197,0,0,171,197,0,0,51,210,0,0,56,211,0,0,193,186,0,0,61,210,0,0,145,47,1,0,57,211,0,0,200,253,0,0,60,210,0,0,220,253,0,0,201,253,0,0,221,253,0,0,60,211,0,0,3,0,0,0,22,0,0,0,62,0,0,0,195,0,0,0,161,1,0,0,71,3,0,0,46,6,0,0,170,11,0,0,45,15,0,0,42,26,0,0,88,30,0,0,155,48,0,0,163,60,0,0,106,93,0,0,154,98,0,0,150,105,0,0,79,121,0,0,229,126,0,0,215,186,0,0,170,197,0,0,244,197,0,0,223,253,0,0,222,253,0,0,32,138,1,0,109,138,1,0,123,166,1,0,100,164,1,0,33,95,2,0,226,249,1,0,227,249,1,0,10,0,0,0,61,0,0,0,40,1,0,0,199,3,0,0,36,12,0,0,163,24,0,0,177,46,0,0,178,60,0,0,31,105,0,0,121,126,0,0,19,0,0,0,187,0,0,0,78,3,0,0,20,13,0,0,253,37,0,0,231,75,0,0,36,0,0,0,136,1,0,0,239,7,0,0,53,0,0,0,8,3,0,0,242,18,0,0,92,0,0,0,246,3,0,0,224,37,0,0,109,0,0,0,152,6,0,0,150,0,0,0,37,12,0,0,199,0,0,0,27,15,0,0,243,0,0,0,255,18,0,0,116,1,0,0,102,26,0,0,160,1,0,0,153,48,0,0,228,1,0,0,107,49,0,0,82,2,0,0,49,63,0,0,11,3,0,0,230,75,0,0,70,3,0,0,251,98,0,0,79,3,0,0,102,121,0,0,245,3,0,0,134,126,0,0,212,5,0,0,17,197,0,0,44,6,0,0,245,197,0,0,146,6,0,0,153,242,0,0,149,7,0,0,152,242,0,0,233,7,0,0,33,138,1,0,126,9,0,0,173,117,1,0,39,12,0,0,122,166,1,0,87,12,0,0,89,235,2,0,34,13,0,0,217,20,3,0,25,15,0,0,194,243,3,0,205,15,0,0,203,72,3,0,248,18,0,0,65,190,4,0,160,24,0,0,193,243,3,0,161,24,0,0,64,190,4,0,183,24,0,0,176,41,6,0,100,26,0,0,41,35,13,0,48,30,0,0,195,243,3,0,159,31,0,0,98,173,11,0,153,31,0,0,0,207,15,0,154,48,0,0,177,41,6,0,182,46,0,0,195,90,23,0,76,49,0,0,149,145,6,0,104,49,0,0,99,173,11,0,142,52,0,0,193,90,23,0,48,63,0,0,129,231,7,0,65,63,0,0,40,35,13,0,66,63,0,0,3,158,31,0,194,75,0,0,194,90,23,0,116,63,0,0,192,90,23,0,97,93,0,0,5,60,63,0,48,97,0,0,4,60,63,0,181,98,0,0,21,1,0,0,2,0,0,0,1,0,0,0,0,0,0,0,13,0,0,0,7,0,0,0,19,0,0,0,29,0,0,0,8,0,0,0,12,0,0,0,35,0,0,0,43,0,0,0,63,0,0,0,23,0,0,0,27,0,0,0,67,0,0,0,73,0,0,0,80,0,0,0,85,0,0,0,84,0,0,0,103,0,0,0,100,0,0,0,123,0,0,0,45,0,0,0,40,0,0,0,42,0,0,0,133,0,0,0,137,0,0,0,43,0,0,0,53,0,0,0,144,0,0,0,145,0,0,0,148,0,0,0,136,0,0,0,193,0,0,0,198,0,0,0,242,0,0,0,227,0,0,0,197,0,0,0,226,0,0,0,54,0,0,0,240,0,0,0,167,0,0,0,205,0,0,0,251,0,0,0,89,0,0,0,22,1,0,0,3,1,0,0,8,1,0,0,43,1,0,0,45,1,0,0,136,1,0,0,46,1,0,0,76,1,0,0,195,1,0,0,135,1,0,0,231,1,0,0,111,0,0,0,148,0,0,0,105,0,0,0,230,1,0,0,202,1,0,0,71,1,0,0,149,1,0,0,167,0,0,0,19,2,0,0,9,2,0,0,3,3,0,0,149,2,0,0,137,2,0,0,140,2,0,0,141,2,0,0,18,3,0,0,48,3,0,0,155,2,0,0,8,3,0,0,40,3,0,0,154,2,0,0,94,2,0,0,197,3,0,0,132,3,0,0,159,3,0,0,151,3,0,0,150,2,0,0,46,3,0,0,50,3,0,0,198,3,0,0,230,3,0,0,45,1,0,0,209,0,0,0,2,4,0,0,221,0,0,0,97,1,0,0,43,1,0,0,39,1,0,0,93,4,0,0,1,6,0,0,171,4,0,0,95,4,0,0,16,4,0,0,191,4,0,0,40,5,0,0,92,4,0,0,36,4,0,0,0,4,0,0,17,5,0,0,24,6,0,0,61,7,0,0,58,6,0,0,20,6,0,0,60,7,0,0,192,7,0,0,207,7,0,0,2,8,0,0,102,9,0,0,100,9,0,0,81,9,0,0,160,8,0,0,70,3,0,0,3,8,0,0,82,10,0,0,74,2,0,0,193,7,0,0,63,6,0,0,38,1,0,0,6,4,0,0,137,7,0,0,162,8,0,0,96,9,0,0,103,9,0,0,5,12,0,0,112,12,0,0,121,12,0,0,93,10,0,0,38,12,0,0,77,12,0,0,114,3,0,0,165,8,0,0,8,12,0,0,197,2,0,0,17,15,0,0,196,12,0,0,142,15,0,0,22,14,0,0,150,4,0,0,119,14,0,0,156,15,0,0,37,12,0,0,30,15,0,0,39,12,0,0,31,15,0,0,23,14,0,0,205,12,0,0,85,3,0,0,9,12,0,0,120,12,0,0,144,15,0,0,33,5,0,0,87,3,0,0,86,3,0,0,142,6,0,0,157,15,0,0,4,12,0,0,88,14,0,0,32,10,0,0,44,10,0,0,76,12,0,0,47,5,0,0,141,15,0,0,120,17,0,0,83,16,0,0,151,16,0,0,15,24,0,0,13,24,0,0,251,18,0,0,170,18,0,0,42,32,0,0,64,10,0,0,237,24,0,0,235,28,0,0,85,20,0,0,227,24,0,0,161,18,0,0,84,3,0,0,83,3,0,0,28,15,0,0,123,12,0,0,55,12,0,0,29,16,0,0,203,18,0,0,66,17,0,0,125,25,0,0,149,16,0,0,59,30,0,0,107,24,0,0,136,5,0,0,42,28,0,0,184,20,0,0,58,30,0,0,236,24,0,0,70,31,0,0,250,18,0,0,83,10,0,0,232,28,0,0,85,10,0,0,41,28,0,0,123,17,0,0,82,16,0,0,160,18,0,0,137,5,0,0,80,9,0,0,43,28,0,0,80,10,0,0,139,32,0,0,14,24,0,0,39,32,0,0,86,37,0,0,32,30,0,0,231,6,0,0,40,28,0,0,122,25,0,0,132,6,0,0,162,32,0,0,34,31,0,0,24,48,0,0,207,57,0,0,37,62,0,0,87,37,0,0,76,41,0,0,166,40,0,0,17,13,0,0,169,40,0,0,121,41,0,0,70,13,0,0,86,10,0,0,206,57,0,0,204,48,0,0,154,50,0,0,157,20,0,0,15,81,0,0,28,69,0,0,40,32,0,0,153,50,0,0,237,28,0,0,185,20,0,0,133,15,0,0,122,12,0,0,0,24,0,0,65,3,0,0,202,18,0,0,200,57,0,0,157,50,0,0,13,13,0,0,32,62,0,0,68,81,0,0,69,13,0,0,208,48,0,0,109,24,0,0,213,48,0,0,15,13,0,0,64,13,0,0,20,65,0,0,161,32,0,0,127,41,0,0,36,62,0,0,241,50,0,0,71,64,0,0,212,48,0,0,168,40,0,0,14,13,0,0,29,69,0,0,68,64,0,0,126,41,0,0,66,64,0,0,210,48,0,0,207,48,0,0,33,62,0,0,38,62,0,0,165,40,0,0,26,69,0,0,72,13,0,0,22,26,0,0,68,13,0,0,24,69,0,0,155,20,0,0,202,57,0,0,152,20,0,0,61,64,0,0,27,69,0,0,156,20,0,0,243,50,0,0,203,48,0,0,115,128,0,0,34,62,0,0,154,82,0,0,170,32,0,0,204,57,0,0,138,115,0,0,48,101,0,0,137,115,0,0,147,97,0,0,113,128,0,0,67,64,0,0,206,48,0,0,71,81,0,0,136,115,0,0,69,81,0,0,114,128,0,0,33,69,0,0,71,13,0,0,124,41,0,0,205,48,0,0,202,48,0,0,11,0,0,0,12,0,0,0,131,0,0,0,228,0,0,0,72,0,0,0,2,1,0,0,204,1,0,0,245,1,0,0,151,0,0,0,11,2,0,0,36,1,0,0,83,4,0,0,39,6,0,0,57,6,0,0,5,6,0,0,23,5,0,0,184,1,0,0,99,6,0,0,103,6,0,0,195,7,0,0,35,8,0,0,97,9,0,0,99,9,0,0,90,14,0,0,89,14,0,0,43,10,0,0,191,12,0,0,146,2,0,0,45,10,0,0,208,7,0,0,83,9,0,0,197,12,0,0,132,15,0,0,171,4,0,0,167,20,0,0,138,6,0,0,122,17,0,0,46,5,0,0,66,20,0,0,44,5,0,0,119,12,0,0,143,15,0,0,170,4,0,0,148,16,0,0,1,24,0,0,196,18,0,0,123,41,0,0,82,9,0,0,25,31,0,0,165,6,0,0,73,17,0,0,197,18,0,0,3,24,0,0,242,34,0,0,155,50,0,0,32,69,0,0,158,20,0,0,19,13,0,0,22,31,0,0,233,28,0,0,28,16,0,0,230,6,0,0,201,57,0,0,145,97,0,0,142,124,0,0,146,97,0,0,99,202,0,0,205,57,0,0,144,97,0,0,132,104,0,0,133,104,0,0,130,115,0,0,73,13,0,0,65,13,0,0,12,69,0,0,154,20,0,0,209,48,0,0,119,128,0,0,35,62,0,0,21,26,0,0,1,231,0,0,2,231,0,0,121,128,0,0,42,130,0,0,24,162,0,0,135,120,0,0,63,64,0,0,11,82,0,0,155,82,0,0,0,231,0,0,25,69,0,0,7,0,0,0,224,0,0,0,208,0,0,0,155,3,0,0,229,3,0,0,99,1,0,0,62,6,0,0,201,7,0,0,6,8,0,0,84,9,0,0,68,16,0,0,68,31,0,0,124,25,0,0,69,31,0,0,81,10,0,0,71,31,0,0,81,9,0,0,45,5,0,0,145,34,0,0,47,9,0,0,84,10,0,0,18,13,0,0,125,41,0,0,12,13,0,0,153,20,0,0,158,50,0,0,240,50,0,0,37,32,0,0,198,57,0,0,87,10,0,0,70,62,0,0,66,13,0,0,139,115,0,0,70,81,0,0,70,64,0,0,120,128,0,0,14,81,0,0,134,120,0,0,4,41,0,0,86,65,0,0,87,65,0,0,50,96,0,0,211,48,0,0,206,139,0,0,64,64,0,0,62,64,0,0,20,164,0,0,87,4,1,0,117,128,0,0,135,104,0,0,143,124,0,0,199,57,0,0,135,115,0,0,112,128,0,0,207,139,0,0,42,72,1,0,86,4,1,0,43,72,1,0,23,26,0,0,134,104,0,0,13,69,0,0,19,0,0,0,107,0,0,0,21,6,0,0,11,8,0,0,43,8,0,0,82,9,0,0,91,14,0,0,226,24,0,0,108,24,0,0,24,31,0,0,159,50,0,0,67,13,0,0,41,62,0,0,64,81,0,0,65,81,0,0,98,202,0,0,51,96,0,0,66,60,0,0,40,62,0,0,15,69,0,0,26,162,0,0,132,115,0,0,25,162,0,0,3,231,0,0,27,162,0,0,20,26,0,0,131,115,0,0,230,69,0,0,122,0,0,0,44,1,0,0,204,12,0,0,143,6,0,0,2,24,0,0,82,10,0,0,83,9,0,0,69,64,0,0,32,26,0,0,31,69,0,0,164,0,0,0,53,7,0,0,236,28,0,0,41,32,0,0,163,32,0,0,30,69,0,0,105,0,0,0,36,12,0,0,36,32,0,0,242,50,0,0,66,81,0,0,150,1,0,0,35,5,0,0,166,0,0,0,123,25,0,0,11,3,0,0,46,9,0,0,233,3,0,0,39,62,0,0,96,1,0,0,67,81,0,0,82,6,0,0,65,64,0,0,52,7,0,0,167,40,0,0,15,8,0,0,131,20,0,0,124,9,0,0,64,3,0,0,139,6,0,0,34,5,0,0,84,16,0,0,150,16,0,0,23,31,0,0,43,32,0,0,234,28,0,0,160,32,0,0,120,41,0,0,38,32,0,0,122,41,0,0,203,57,0,0,43,62,0,0,159,20,0,0,156,50,0,0,133,115,0,0,116,128,0,0,14,69,0,0,42,62,0,0,73,81,0,0,118,128,0,0,134,115,0,0,72,81,0,0,0,0,0,0,9,7,2,3,4,4,5,6,6,7,7,8,8,8,9,9,9,9,10,10,10,10,10,11,11,11,11,11], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1440964);
/* memory initializer */ allocate([11,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,17,16,16,16,16,16,16,16,3,5,6,8,9,10,11,12,12,13,13,14,14,15,15,15,15,15,16,16,16,16,16,17,17,17,17,18,17,17,4,6,9,10,12,13,14,14,15,15,5,8,10,12,14,15,6,9,11,6,10,13,7,10,14,7,11,8,12,8,12,8,13,9,13,9,14,9,14,10,14,10,15,10,15,10,15,10,15,11,16,11,16,11,16,11,16,11,17,12,17,12,17,12,18,12,18,12,18,12,18,13,19,13,18,13,19,13,19,13,20,13,18,13,20,13,20,14,19,14,21,14,19,14,20,14,21,14,19,14,20,14,21,15,21,14,21,15,22,15,22,15,0,0,0,0,9,5,2,4,4,5,5,5,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,11,11,11,11,11,12,12,12,12,12,12,12,12,12,13,12,12,12,12,12,12,12,13,12,12,12,12,12,12,12,12,13,12,12,12,13,13,13,13,12,12,12,12,12,12,13,12,13,13,13,13,13,13,13,14,14,13,13,13,13,13,13,13,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,13,14,13,13,13,13,13,14,13,14,14,13,14,14,13,14,13,13,14,14,13,14,14,14,14,14,14,14,14,14,15,14,14,14,14,15,15,15,14,14,13,13,12,12,13,13,13,14,14,15,14,15,15,14,13,14,15,15,15,14,14,14,14,15,14,14,15,15,15,14,15,14,14,14,14,14,15,15,16,15,15,15,14,15,15,15,15,14,14,16,14,15,14,14,15,15,15,15,16,15,14,15,15,15,16,15,15,14,14,14,4,7,8,8,9,9,9,9,10,10,11,11,11,11,11,11,12,11,11,11,12,12,12,12,12,12,12,12,12,11,12,12,12,13,13,13,13,13,13,13,12,12,13,13,13,13,14,14,13,14,13,13,13,14,14,15,15,14,13,13,13,14,14,15,15,15,16,14,15,17,17,15,15,15,15,15,14,16,14,16,16,16,16,16,16,15,15,17,15,16,15,6,8,10,10,10,11,11,11,12,12,13,13,13,13,14,13,14,13,14,14,14,14,14,15,15,14,14,14,14,14,14,15,15,15,15,16,15,15,16,15,15,15,14,16,15,15,18,17,16,17,15,14,15,16,16,19,17,19,16,17,15,7,10,11,12,12,12,12,13,13,13,14,15,14,15,15,16,15,14,14,15,16,15,16,16,16,16,15,15,7,11,12,13,13,14,14,15,15,15,8,11,13,14,14,15,9,12,14,14,15,9,13,10,13,10,14,10,14,11,15,11,15,11,14,12,15,12,13,13,13,13,13,13,14,13,14,14,14,14,14,14,15,14,15,16,15,14,15,16,15,15,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,112,0,113,0,114,0,115,0,116,0,117,0,118,0,119,0,120,0,121,0,122,0,123,0,124,0,125,0,126,0,127,0,128,0,129,0,130,0,131,0,132,0,133,0,134,0,135,0,136,0,137,0,138,0,139,0,140,0,141,0,142,0,143,0,144,0,145,0,146,0,147,0,148,0,149,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,0,0,1,0,2,0,3,0,4,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,160,64,0,0,160,64,0,0,160,64,0,0,160,64,0,0,160,64,0,0,192,64,0,0,192,64,0,0,224,64,0,0,224,64,0,0,0,65,0,0,0,65,0,0,16,65,0,0,16,65,0,0,32,65,0,0,32,65,0,0,48,65,0,0,48,65,0,0,64,65,0,0,64,65,0,0,80,65,0,0,80,65,0,0,96,65,0,0,96,65,0,0,112,65,0,0,112,65,0,0,128,65,0,0,128,65,0,0,136,65,0,0,136,65,0,0,144,65,0,0,144,65,0,0,152,65,0,0,152,65,0,0,160,65,0,0,160,65,0,0,168,65,0,0,168,65,0,0,176,65,0,0,176,65,0,0,184,65,0,0,184,65,0,0,192,65,0,0,192,65,0,0,200,65,0,0,200,65,0,0,208,65,0,0,208,65,0,0,216,65,0,0,216,65,0,0,224,65,74,0,0,0,43,0,0,0,0,0,0,0,3,0,0,0,6,0,0,0,9,0,0,0,15,0,0,0,16,0,0,0,22,0,0,0,17,0,0,0,22,0,0,0,40,0,0,0,47,0,0,0,38,0,0,0,41,0,0,0,69,0,0,0,85,0,0,0,93,0,0,0,66,0,0,0,78,0,0,0,81,0,0,0,94,0,0,0,141,0,0,0,168,0,0,0,173,0,0,0,128,0,0,0,150,0,0,0,159,0,0,0,170,0,0,0,190,0,0,0,28,1,0,0,83,1,0,0,88,1,0,0,112,1,0,0,4,1,0,0,13,1,0,0,5,1,0,0,3,1,0,0,47,1,0,0,119,1,0,0,117,1,0,0,87,1,0,0,116,1,0,0,37,2,0,0,59,2,0,0,13,2,0,0,31,2,0,0,129,2,0,0,123,2,0,0,130,2,0,0,172,2,0,0,253,2,0,0,79,4,0,0,120,4,0,0,77,4,0,0,236,2,0,0,78,4,0,0,100,5,0,0,9,4,0,0,11,4,0,0,1,5,0,0,69,5,0,0,243,4,0,0,65,5,0,0,59,4,0,0,241,4,0,0,244,4,0,0,253,8,0,0,148,10,0,0,17,8,0,0,136,11,0,0,145,11,0,0,147,11,0,0,234,8,0,0,153,8,0,0,138,11,0,0,114,9,0,0,229,9,0,0,143,10,0,0,132,10,0,0,142,10,0,0,0,10,0,0,48,8,0,0,232,8,0,0,149,11,0,0,113,8,0,0,58,8,0,0,20,8,0,0,115,8,0,0,254,11,0,0,40,23,0,0,149,21,0,0,18,23,0,0,42,16,0,0,33,16,0,0,41,23,0,0,46,21,0,0,195,19,0,0,33,23,0,0,151,21,0,0,27,21,0,0,242,16,0,0,3,20,0,0,3,23,0,0,3,21,0,0,8,23,0,0,193,19,0,0,14,23,0,0,12,23,0,0,225,16,0,0,234,17,0,0,32,16,0,0,0,21,0,0,250,23,0,0,4,23,0,0,5,23,0,0,240,23,0,0,251,23,0,0,230,33,0,0,45,43,0,0,198,32,0,0,41,43,0,0,74,46,0,0,172,35,0,0,25,21,0,0,243,35,0,0,44,43,0,0,192,33,0,0,254,23,0,0,215,35,0,0,249,23,0,0,231,18,0,0,192,19,0,0,97,34,0,0,211,35,0,0,87,32,0,0,86,32,0,0,210,33,0,0,199,32,0,0,210,35,0,0,236,32,0,0,192,68,0,0,226,47,0,0,91,71,0,0,3,42,0,0,227,47,0,0,226,33,0,0,208,33,0,0,49,42,0,0,19,46,0,0,5,46,0,0,229,71,0,0,14,0,0,0,36,0,0,0,136,0,0,0,185,0,0,0,12,1,0,0,36,2,0,0,179,2,0,0,131,2,0,0,237,2,0,0,123,4,0,0,30,4,0,0,61,4,0,0,245,4,0,0,253,5,0,0,146,10,0,0,150,11,0,0,56,8,0,0,113,9,0,0,131,11,0,0,128,11,0,0,249,11,0,0,211,17,0,0,232,17,0,0,215,17,0,0,39,21,0,0,248,17,0,0,115,16,0,0,240,16,0,0,228,16,0,0,248,23,0,0,98,16,0,0,2,20,0,0,227,23,0,0,26,21,0,0,119,16,0,0,43,21,0,0,13,23,0,0,211,33,0,0,65,46,0,0,194,19,0,0,41,0,0,0,169,0,0,0,93,2,0,0,25,4,0,0,68,5,0,0,139,11,0,0,228,9,0,0,210,17,0,0,38,21,0,0,36,23,0,0,230,18,0,0,11,21,0,0,255,23,0,0,38,46,0,0,75,46,0,0,40,43,0,0,227,33,0,0,20,42,0,0,90,71,0,0,18,46,0,0,87,0,0,0,62,2,0,0,144,10,0,0,240,11,0,0,114,16,0,0,2,21,0,0,214,35,0,0,237,32,0,0,48,42,0,0,199,68,0,0,140,0,0,0,127,4,0,0,42,21,0,0,98,34,0,0,4,46,0,0,161,0,0,0,249,5,0,0,115,1,0,0,117,8,0,0,113,1,0,0,45,21,0,0,227,2,0,0,226,23,0,0,173,2,0,0,193,33,0,0,121,4,0,0,231,33,0,0,31,4,0,0,78,92,0,0,67,5,0,0,79,92,0,0,145,10,0,0,141,137,0,0,151,11,0,0,70,135,0,0,112,9,0,0,69,135,0,0,133,11,0,0,86,168,0,0,47,21,0,0,142,14,1,0,229,16,0,0,87,168,0,0,15,23,0,0,17,29,2,0,88,42,0,0,143,14,1,0,64,46,0,0,19,29,2,0,89,42,0,0,37,58,4,0,2,42,0,0,33,58,4,0,193,68,0,0,72,116,8,0,228,71,0,0,32,58,4,0,42,84,0,0,73,116,8,0,140,137,0,0,88,2,0,0,61,0,0,0,0,0,0,0,5,0,0,0,8,0,0,0,8,0,0,0,12,0,0,0,27,0,0,0,31,0,0,0,21,0,0,0,36,0,0,0,50,0,0,0,58,0,0,0,38,0,0,0,44,0,0,0,47,0,0,0,74,0,0,0,77,0,0,0,97,0,0,0,112,0,0,0,115,0,0,0,72,0,0,0,82,0,0,0,90,0,0,0,93,0,0,0,110,0,0,0,153,0,0,0,158,0,0,0,193,0,0,0,206,0,0,0,228,0,0,0,240,0,0,0,147,0,0,0,158,0,0,0,162,0,0,0,161,0,0,0,184,0,0,0,210,0,0,0,211,0,0,0,46,1,0,0,48,1,0,0,222,0,0,0,45,1,0,0,155,1,0,0,228,1,0,0,57,1,0,0,58,1,0,0,63,1,0,0,79,1,0,0,109,1,0,0,162,1,0,0,124,2,0,0,126,2,0,0,50,3,0,0,60,3,0,0,63,3,0,0,139,3,0,0,150,3,0,0,197,3,0,0,112,2,0,0,124,2,0,0,90,2,0,0,149,3,0,0,72,2,0,0,189,4,0,0,251,4,0,0,98,6,0,0,97,6,0,0,27,7,0,0,230,4,0,0,255,4,0,0,102,6,0,0,28,7,0,0,26,7,0,0,31,7,0,0,148,7,0,0,54,5,0,0,226,4,0,0,142,7,0,0,238,4,0,0,24,5,0,0,53,5,0,0,251,4,0,0,141,7,0,0,48,5,0,0,128,6,0,0,143,6,0,0,203,5,0,0,101,9,0,0,166,6,0,0,103,9,0,0,127,9,0,0,130,6,0,0,174,6,0,0,208,12,0,0,40,14,0,0,19,15,0,0,31,15,0,0,245,9,0,0,211,12,0,0,17,15,0,0,38,9,0,0,100,9,0,0,50,15,0,0,18,15,0,0,48,15,0,0,102,9,0,0,11,13,0,0,104,10,0,0,145,11,0,0,199,9,0,0,115,11,0,0,250,18,0,0,29,19,0,0,249,19,0,0,160,28,0,0,156,25,0,0,122,28,0,0,140,25,0,0,72,18,0,0,116,28,0,0,100,28,0,0,158,19,0,0,253,18,0,0,119,10,0,0,252,18,0,0,123,28,0,0,202,18,0,0,204,20,0,0,210,20,0,0,227,20,0,0,220,20,0,0,220,18,0,0,68,51,0,0,152,37,0,0,60,38,0,0,59,51,0,0,230,37,0,0,28,26,0,0,60,30,0,0,226,20,0,0,212,51,0,0,17,26,0,0,73,51,0,0,206,60,0,0,225,20,0,0,52,26,0,0,62,39,0,0,39,38,0,0,63,39,0,0,238,56,0,0,113,57,0,0,103,60,0,0,97,60,0,0,61,51,0,0,194,56,0,0,63,38,0,0,205,56,0,0,56,38,0,0,65,46,0,0,31,53,0,0,72,51,0,0,102,60,0,0,98,53,0,0,137,41,0,0,213,39,0,0,60,51,0,0,79,46,0,0,59,52,0,0,223,45,0,0,200,75,0,0,192,41,0,0,87,46,0,0,114,76,0,0,183,37,0,0,71,53,0,0,64,53,0,0,211,41,0,0,69,76,0,0,187,37,0,0,0,102,0,0,115,76,0,0,206,75,0,0,123,53,0,0,166,41,0,0,210,41,0,0,62,38,0,0,138,41,0,0,131,113,0,0,2,102,0,0,88,121,0,0,102,75,0,0,125,83,0,0,117,83,0,0,233,79,0,0,103,75,0,0,159,121,0,0,201,75,0,0,254,81,0,0,59,106,0,0,182,91,0,0,168,79,0,0,143,114,0,0,118,83,0,0,44,73,0,0,126,83,0,0,90,121,0,0,60,106,0,0,21,229,0,0,135,120,0,0,58,104,0,0,249,81,0,0,253,81,0,0,106,204,0,0,138,106,0,0,109,204,0,0,179,91,0,0,59,104,0,0,252,81,0,0,120,83,0,0,142,114,0,0,134,120,0,0,183,91,0,0,164,242,0,0,91,121,0,0,60,104,0,0,193,159,0,0,61,104,0,0,82,183,0,0,120,150,0,0,232,163,0,0,199,106,0,0,240,81,0,0,89,183,0,0,243,106,0,0,107,75,0,0,160,242,0,0,173,242,0,0,195,150,0,0,24,229,0,0,92,183,0,0,88,212,0,0,107,204,0,0,124,83,0,0,170,103,0,0,234,79,0,0,58,52,0,0,113,204,0,0,127,150,0,0,196,159,0,0,194,150,0,0,22,229,0,0,161,242,0,0,92,212,0,0,93,212,0,0,94,212,0,0,185,47,1,0,126,150,0,0,47,152,1,0,131,152,0,0,196,150,0,0,83,183,0,0,184,47,1,0,168,242,0,0,33,202,1,0,197,150,0,0,26,229,0,0,39,202,1,0,60,47,1,0,113,212,0,0,170,242,0,0,91,183,0,0,187,47,1,0,169,242,0,0,172,242,0,0,90,212,0,0,79,183,0,0,200,150,0,0,145,110,1,0,202,150,0,0,191,47,1,0,167,208,0,0,3,49,1,0,22,213,0,0,153,110,1,0,189,44,1,0,234,163,0,0,41,152,1,0,85,183,0,0,167,155,2,0,40,202,1,0,165,155,2,0,147,110,1,0,44,152,1,0,40,152,1,0,148,89,2,0,235,163,0,0,41,202,1,0,144,110,1,0,37,202,1,0,45,152,1,0,38,202,1,0,155,110,1,0,86,183,0,0,124,150,0,0,151,89,2,0,95,183,0,0,211,152,1,0,87,183,0,0,42,154,1,0,91,212,0,0,23,229,0,0,36,202,1,0,35,202,1,0,34,202,1,0,88,183,0,0,151,110,1,0,20,205,0,0,0,49,1,0,7,0,0,0,59,0,0,0,107,0,0,0,151,0,0,0,56,1,0,0,37,1,0,0,115,1,0,0,88,2,0,0,53,3,0,0,142,2,0,0,198,4,0,0,21,7,0,0,41,7,0,0,239,4,0,0,25,5,0,0,237,4,0,0,50,5,0,0,140,6,0,0,134,6,0,0,120,9,0,0,93,14,0,0,49,14,0,0,244,9,0,0,146,11,0,0,248,18,0,0,6,13,0,0,103,10,0,0,68,13,0,0,118,10,0,0,89,13,0,0,205,18,0,0,120,28,0,0,117,28,0,0,159,25,0,0,143,25,0,0,103,28,0,0,198,20,0,0,121,28,0,0,118,28,0,0,148,11,0,0,27,13,0,0,50,30,0,0,49,30,0,0,176,26,0,0,5,26,0,0,161,26,0,0,58,51,0,0,229,37,0,0,38,38,0,0,65,53,0,0,68,53,0,0,33,52,0,0,70,53,0,0,85,46,0,0,86,46,0,0,45,73,0,0,222,45,0,0,155,41,0,0,220,45,0,0,122,53,0,0,156,36,0,0,139,102,0,0,127,199,1,0,32,202,1,0,95,212,0,0,134,152,0,0,154,110,1,0,167,242,0,0,81,183,0,0,238,163,0,0,89,207,0,0,87,207,0,0,84,183,0,0,166,208,0,0,152,110,1,0,96,183,0,0,198,106,0,0,240,163,0,0,190,47,1,0,4,49,1,0,165,242,0,0,239,163,0,0,114,212,0,0,186,44,1,0,46,152,1,0,156,110,1,0,126,199,1,0,208,152,1,0,5,49,1,0,146,110,1,0,93,183,0,0,89,212,0,0,26,0,0,0,192,0,0,0,108,1,0,0,205,3,0,0,80,3,0,0,123,6,0,0,30,5,0,0,169,6,0,0,244,9,0,0,114,11,0,0,9,13,0,0,73,18,0,0,61,30,0,0,161,28,0,0,31,26,0,0,33,23,0,0,138,26,0,0,232,22,0,0,71,51,0,0,53,26,0,0,157,36,0,0,154,41,0,0,150,37,0,0,78,46,0,0,139,41,0,0,130,113,0,0,70,76,0,0,186,37,0,0,64,46,0,0,214,39,0,0,232,79,0,0,7,102,0,0,16,83,0,0,132,152,0,0,225,114,0,0,61,106,0,0,106,75,0,0,122,76,0,0,3,102,0,0,123,76,0,0,40,52,0,0,5,102,0,0,100,150,0,0,192,159,0,0,222,113,0,0,1,102,0,0,178,91,0,0,133,152,0,0,226,163,0,0,31,198,1,0,187,44,1,0,80,183,0,0,88,207,0,0,125,150,0,0,149,89,2,0,173,104,6,0,90,183,0,0,194,159,0,0,127,83,0,0,94,183,0,0,174,63,1,0,188,47,1,0,49,0,0,0,196,1,0,0,197,4,0,0,184,5,0,0,244,12,0,0,111,9,0,0,70,13,0,0,87,30,0,0,4,26,0,0,37,38,0,0,70,51,0,0,249,40,0,0,71,76,0,0,224,114,0,0,105,75,0,0,32,52,0,0,87,121,0,0,57,102,0,0,158,121,0,0,89,121,0,0,129,120,0,0,104,75,0,0,195,159,0,0,214,159,0,0,112,204,0,0,241,163,0,0,190,44,1,0,14,227,0,0,27,229,0,0,242,106,0,0,188,44,1,0,125,199,1,0,171,242,0,0,189,47,1,0,47,170,1,0,236,163,0,0,115,212,0,0,119,83,0,0,233,163,0,0,43,152,1,0,0,227,0,0,63,47,1,0,95,207,0,0,192,150,0,0,60,140,3,0,148,110,1,0,149,110,1,0,61,47,1,0,164,155,2,0,166,155,2,0,124,199,1,0,186,168,6,0,92,84,3,0,87,52,3,0,172,104,6,0,187,168,6,0,157,110,1,0,25,229,0,0,150,89,2,0,62,47,1,0,54,0,0,0,62,3,0,0,173,6,0,0,3,13,0,0,200,18,0,0,74,18,0,0,66,60,0,0,205,60,0,0,6,102,0,0,128,120,0,0,82,104,0,0,58,106,0,0,180,91,0,0,162,242,0,0,199,159,0,0,185,44,1,0,108,204,0,0,232,166,0,0,193,150,0,0,74,0,0,0,85,3,0,0,249,18,0,0,232,20,0,0,190,26,0,0,182,37,0,0,46,73,0,0,198,159,0,0,255,81,0,0,111,204,0,0,203,150,0,0,113,208,0,0,209,152,1,0,184,44,1,0,61,140,3,0,175,63,1,0,201,150,0,0,157,0,0,0,57,5,0,0,206,18,0,0,31,52,0,0,193,41,0,0,51,75,0,0,227,163,0,0,112,208,0,0,150,110,1,0,99,183,0,0,160,0,0,0,206,9,0,0,204,56,0,0,61,52,0,0,250,81,0,0,136,152,0,0,186,47,1,0,223,0,0,0,117,10,0,0,167,41,0,0,197,159,0,0,1,227,0,0,123,150,0,0,231,1,0,0,201,18,0,0,251,81,0,0,137,152,0,0,166,242,0,0,111,1,0,0,185,28,0,0,90,207,0,0,191,44,1,0,121,150,0,0,114,2,0,0,21,26,0,0,122,150,0,0,203,3,0,0,246,37,0,0,98,183,0,0,141,2,0,0,96,60,0,0,94,207,0,0,82,3,0,0,204,60,0,0,47,7,0,0,134,113,0,0,236,4,0,0,121,83,0,0,142,6,0,0,135,152,0,0,167,6,0,0,241,106,0,0,41,14,0,0,91,207,0,0,49,15,0,0,112,212,0,0,198,9,0,0,251,19,0,0,2,49,1,0,165,25,0,0,1,49,1,0,131,25,0,0,101,28,0,0,79,18,0,0,199,20,0,0,38,23,0,0,191,26,0,0,4,51,0,0,36,38,0,0,65,60,0,0,215,39,0,0,221,45,0,0,84,46,0,0,60,52,0,0,4,102,0,0,129,113,0,0,58,102,0,0,169,79,0,0,59,102,0,0,17,83,0,0,122,83,0,0,57,104,0,0,181,91,0,0,47,73,0,0,240,106,0,0,199,150,0,0,110,204,0,0,123,83,0,0,92,207,0,0,86,207,0,0,210,152,1,0,93,207,0,0,237,163,0,0,163,242,0,0,42,152,1,0,97,183,0,0,198,150,0,0,8,7,2,3,3,4,4,5,5,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,13,12,12,12,12,12,12,13,13,13,13,13,13,13,12,12,13,13,13,13,13,13,13,13,14,14,13,13,14,13,13,14,14,14,14,14,14,14,14,14,14,13,14,14,14,14,14,14,14,15,14,15,14,14,14,14,14,14,15,14,14,14,14,14,14,14,15,15,15,15,14,15,15,15,15,15,15,15,15,15,15,15,15,4,7,8,9,10,10,10,11,11,11,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,13,14,15,14,14,6,9,11,12,12,12,13,13,13,13,14,14,14,14,14,14,15,15,15,15,7,10,12,13,14,14,14,15,15,15,8,11,13,14,15,9,12,9,13,10,13,10,14,11,15,11,15,12,15,12,15,12,16,12,17,13,17,13,17,13,18,14,17,14,19,14,18,14,19,14,20,15,20,15,21,15,20,16,21,16,11,6,2,3,4,5,5,5,5,6,6,6,6,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,10,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,11,12,12,12,12,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,14,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,14,14,15,15,15,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,14,15,15,15,15,16,16,16,15,16,15,15,16,16,16,16,15,16,16,16,15,16,16,15,16,16,16,16,16,16,16,16,16,16,15,15,16,16,15,16,16,16,17,17,17,16,16,17,16,16,16,16,17,16,17,17,16,16,15,15,15,16,17,16,17,16,16,17,17,17,17,17,17,16,17,17,17,16,17,17,16,17,17,17,16,17,17,16,16,17,17,17,18,17,17,17,17,17,18,18,17,17,17,19,17,19,18,17,17,18,17,17,18,17,17,17,18,17,17,18,17,17,17,17,17,16,17,17,17,17,18,16,17,4,6,8,9,9,10,10,10,10,11,11,11,11,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,13,13,13,13,13,13,14,14,14,14,14,14,15,15,15,15,15,15,16,15,15,15,15,15,15,17,17,17,16,18,16,17,17,16,16,17,17,18,17,16,17,17,17,16,17,17,18,17,18,17,17,17,18,17,17,5,8,10,10,11,11,12,12,12,13,13,14,13,13,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,16,16,15,16,16,15,15,15,15,15,16,16,15,15,16,16,17,17,18,17,16,17,18,19,17,16,16,17,17,17,6,9,11,12,12,13,13,13,14,14,14,15,15,15,16,15,15,15,15,15,15,16,16,16,16,17,18,16,16,16,18,17,16,17,18,17,17,16,17,17,16,17,16,17,18,18,18,17,19,19,17,20,19,18,19,20,18,16,18,17,7,10,12,13,13,14,14,14,15,15,16,16,16,16,16,18,16,17,17,8,11,13,14,14,15,16,16,16,16,17,17,17,18,18,17,17,8,12,14,15,15,15,17,17,18,17,9,12,14,15,16,16,17,9,13,15,16,16,17,9,13,16,16,16,10,13,16,18,17,10,14,17,10,14,17,11,14,16,11,14,11,15,12,16,12,16,12,16,12,16,12,17,13,13,17,13,17,13,13,14,14,14,14,14,14,14,15,15,15,15,15,15,15,16,15,16,16,16,16,16,16,17,16,16,16,16,17,16,17,16,17,17,17,0,0,0,0,0,0,170,153,172,185,189,170,122,168,168,168,121,121,119,168,151,121,137,119,135,135,104,120,102,134,135,103,104,102,118,118,87,103,85,117,101,86,86,85,101,101,86,69,85,84,85,85,69,85,84,85,85,69,86,100,102,118,87,103,119,119,152,136,157,191,186,236,252,186,239,252,0,0,207,155,175,255,255,171,138,152,184,249,120,137,119,249,247,121,137,119,151,151,104,104,102,166,135,119,104,102,117,118,103,86,101,117,117,86,86,85,101,101,86,86,85,84,85,85,69,85,83,85,101,53,103,100,102,102,86,120,134,136,168,251,175,255,175,255,255,255,255,255,0,0,220,173,204,202,207,254,223,255,233,255,153,121,151,151,151,121,121,119,151,151,121,121,119,134,135,104,104,118,118,118,103,87,102,101,118,102,86,85,100,101,85,69,85,84,85,85,53,85,83,85,101,53,103,100,103,135,87,138,134,139,186,154,205,170,175,252,255,255,223,255,0,0,34,30,24,24,16,16,16,16,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,34,30,24,24,16,16,16,16,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,34,30,30,30,24,24,16,16,16,16,16,16,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,34,34,30,30,24,24,24,24,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,10,10,10,10,10,10,10,34,34,30,30,30,30,30,30,24,24,24,24,24,24,24,24,24,24,24,24,16,16,16,16,16,16,16,16,16,16,0,0,156,2,122,244,26,251,2,249,7,246,88,236,31,238,235,251,92,11,246,12,253,244,139,245,76,252,247,244,158,238,233,229,172,254,202,5,4,251,238,4,206,253,155,229,1,5,179,0,6,251,48,246,38,228,195,236,1,27,107,9,82,246,100,255,75,18,223,240,0,0,240,223,92,8,34,254,31,245,21,2,97,7,199,10,101,5,213,228,231,232,218,19,100,246,110,233,5,7,56,2,96,247,19,243,85,238,164,231,175,226,97,245,6,17,84,244,131,251,104,10,235,4,227,3,151,10,96,246,106,215,186,6,111,226,74,245,123,8,231,246,8,4,235,2,166,252,246,224,213,205,34,12,248,18,159,239,19,246,11,4,70,7,64,252,28,230,154,1,250,22,67,246,188,245,96,240,196,255,34,28,144,245,166,5,0,6,9,241,209,4,74,235,0,27,53,6,165,239,81,14,128,242,22,224,227,225,104,5,90,18,165,237,191,231,88,212,168,31,190,65,162,3,92,27,245,4,239,220,7,10,41,18,28,46,113,13,231,233,175,4,238,9,73,255,101,221,216,224,158,12,200,244,37,248,15,218,63,223,183,50,14,12,92,8,160,241,85,218,176,244,71,226,115,25,21,247,38,246,188,24,251,242,12,234,86,220,133,212,167,21,105,254,191,229,198,187,183,244,48,45,108,14,140,26,250,254,162,213,192,248,107,28,92,52,83,244,157,214,72,19,244,0,85,247,96,10,192,14,220,234,53,240,210,232,83,8,95,3,206,244,26,243,207,6,42,248,128,255,252,247,39,231,14,13,209,249,235,255,118,4,3,241,217,248,253,24,241,9,224,244,140,219,128,230,189,20,194,7,59,247,118,238,236,2,143,7,45,244,19,254,217,219,246,20,121,12,115,238,248,6,176,18,142,254,74,7,33,4,159,248,174,28,126,245,239,245,164,2,157,253,10,254,187,8,198,248,15,249,255,247,243,3,40,15,95,246,161,8,104,255,32,10,13,11,212,21,23,11,118,227,23,244,202,236,67,23,241,35,161,238,185,2,68,15,166,22,157,238,220,237,183,247,68,21,246,245,65,1,78,251,30,11,218,247,204,13,54,2,60,253,73,239,182,3,116,19,165,14,196,1,76,246,174,13,183,6,86,255,238,0,149,242,7,1,66,8,43,248,57,9,86,227,72,251,131,36,64,251,83,240,70,203,73,254,92,31,120,239,105,1,111,241,57,21,212,7,137,237,21,251,110,240,63,30,237,32,149,241,37,252,78,20,89,254,126,4,255,250,48,3,241,28,13,16,147,240,130,10,30,0,222,4,239,11,221,255,166,250,10,255,47,250,3,22,90,253,189,245,98,12,222,18,23,238,216,7,218,251,31,3,127,255,205,2,242,17,89,58,210,41,161,1,199,10,58,7,63,236,127,251,209,240,193,28,120,233,189,16,154,2,163,5,86,252,20,0,185,247,95,249,128,241,182,242,92,247,110,0,88,8,120,244,12,0,224,249,84,242,193,248,221,250,61,249,136,4,210,253,173,6,88,0,39,238,194,0,58,254,115,244,233,244,126,249,239,254,36,8,101,255,67,255,184,246,127,6,240,251,111,246,230,244,167,250,124,2,8,255,139,245,237,5,79,0,59,244,171,241,51,252,121,7,67,246,64,235,19,253,247,4,169,244,4,243,84,241,150,241,219,248,159,244,245,249,56,245,130,250,100,4,52,7,214,248,200,1,194,2,80,239,211,1,96,239,139,248,241,5,110,4,129,255,30,252,131,253,45,250,162,230,105,3,3,248,12,241,24,245,190,253,7,9,231,248,72,10,20,244,176,7,129,2,170,4,101,7,11,16,198,24,211,255,174,4,112,8,87,250,155,8,44,248,177,6,190,13,92,10,155,16,120,11,128,240,0,5,131,0,60,250,11,11,8,0,120,248,98,10,185,13,127,12,208,252,127,10,51,249,129,250,132,11,189,15,138,1,3,255,18,5,190,16,51,0,101,238,224,255,109,253,63,15,14,22,44,234,224,245,75,22,162,253,210,4,185,249,189,235,152,2,243,253,36,14,112,247,33,246,171,6,201,16,77,243,21,247,44,3,40,247,133,22,16,2,41,243,72,5,136,6,175,10,217,4,177,251,55,243,177,242,193,15,112,6,107,244,106,251,164,5,74,0,150,3,207,7,147,3,254,251,64,246,187,249,242,7,134,11,229,0,136,247,245,7,15,0,16,251,48,255,32,242,250,5,69,2,211,5,194,3,203,245,222,246,37,14,48,250,119,247,45,249,81,0,162,21,152,5,47,247,5,252,99,3,214,0,20,247,26,250,108,249,0,11,27,255,247,9,147,250,147,10,248,1,223,1,223,10,15,252,213,9,49,250,196,249,109,2,137,7,108,255,158,8,64,239,12,5,135,250,241,253,219,4,85,245,117,7,0,5,101,8,35,250,104,14,98,2,17,238,234,12,215,242,83,7,52,14,63,251,14,10,209,9,169,5,254,243,141,236,46,3,34,7,63,246,138,16,19,240,128,6,36,255,90,13,234,3,91,4,13,3,122,6,79,15,242,23,68,12,124,4,225,15,236,5,47,3,199,0,167,4,185,9,1,10,117,9,139,9,2,3,229,232,139,21,144,254,129,243,166,4,23,4,158,14,15,27,215,247,36,1,27,12,212,16,10,253,105,246,11,2,81,15,204,15,106,5,85,0,15,17,238,3,28,251,70,250,153,250,12,15,43,6,179,255,16,8,100,3,245,19,103,11,54,255,103,1,3,254,66,14,134,12,255,8,157,6,16,5,89,11,189,240,229,0,84,251,228,246,89,23,255,241,37,3,241,14,190,243,162,14,162,253,53,0,243,254,27,243,94,2,226,7,220,250,224,15,142,1,0,0,5,0,55,0,231,0,222,1,206,3,217,3,200,7,205,7,200,15,221,15,228,31,236,31,4,0,12,0,53,0,114,0,234,0,237,0,226,1,209,3,211,3,224,3,216,7,207,15,213,15,54,0,52,0,113,0,232,0,236,0,225,1,207,3,221,3,219,3,208,7,199,15,212,15,228,15,230,0,112,0,233,0,221,1,227,1,210,3,220,3,204,7,202,7,222,7,216,15,234,15,219,31,223,1,235,0,220,1,230,1,213,3,222,3,203,7,221,7,220,7,205,15,226,15,231,15,225,31,208,3,224,1,228,1,214,3,197,7,209,7,219,7,210,15,224,7,217,15,235,15,227,31,233,31,196,7,229,1,215,3,198,7,207,7,218,7,203,15,218,15,227,15,233,15,230,31,243,31,247,31,211,7,216,3,225,3,212,7,217,7,211,15,222,15,221,31,217,31,226,31,234,31,241,31,246,31,210,7,212,3,218,3,199,7,215,7,226,7,206,15,219,15,216,31,238,31,240,63,244,31,242,63,225,7,223,3,201,7,214,7,202,15,208,15,229,15,230,15,235,31,239,31,243,63,244,63,245,63,224,15,206,7,213,7,198,15,209,15,225,15,224,31,232,31,240,31,241,63,248,63,246,63,252,127,232,15,223,7,201,15,215,15,220,15,220,31,223,31,237,31,245,31,249,63,251,63,253,127,254,127,231,31,204,15,214,15,223,15,222,31,218,31,229,31,242,31,250,63,247,63,252,63,253,63,255,127,0,0,0,0,0,0,14,0,5,0,16,0,48,0,111,0,241,0,250,1,254,3,3,0,0,0,4,0,18,0,44,0,106,0,117,0,248,0,15,0,2,0,6,0,20,0,46,0,105,0,114,0,245,0,47,0,17,0,19,0,42,0,50,0,108,0,236,0,250,0,113,0,43,0,45,0,49,0,109,0,112,0,242,0,249,1,239,0,104,0,51,0,107,0,110,0,238,0,249,0,252,3,248,1,116,0,115,0,237,0,240,0,246,0,246,1,253,1,253,3,243,0,244,0,247,0,247,1,251,1,252,1,255,3,0,0,5,0,55,0,116,0,242,0,235,1,237,3,247,7,4,0,12,0,53,0,113,0,236,0,238,0,238,1,245,1,54,0,52,0,114,0,234,0,241,0,233,1,243,1,245,3,115,0,112,0,235,0,240,0,241,1,240,1,236,3,250,3,243,0,237,0,232,1,239,1,239,3,241,3,249,3,251,7,237,1,239,0,234,1,242,1,243,3,248,3,249,7,252,7,238,3,236,1,244,1,244,3,247,3,248,7,253,15,254,15,246,7,240,3,242,3,246,3,250,7,253,7,252,15,255,15,254,7,253,3,241,1,235,1,244,1,234,1,240,1,252,3,253,7,246,3,229,1,234,0,108,0,113,0,104,0,240,0,230,1,247,3,243,1,239,0,50,0,39,0,40,0,38,0,49,0,235,0,247,1,232,1,111,0,46,0,8,0,4,0,6,0,41,0,107,0,238,1,239,1,114,0,45,0,2,0,0,0,3,0,47,0,115,0,250,1,231,1,110,0,43,0,7,0,1,0,5,0,44,0,109,0,236,1,249,1,238,0,48,0,36,0,42,0,37,0,51,0,236,0,242,1,248,3,228,1,237,0,106,0,112,0,105,0,116,0,241,0,250,3,255,7,249,3,246,1,237,1,248,1,233,1,245,1,251,3,252,7,0,0,0,0,0,0,255,31,247,15,244,7,232,7,241,3,238,7,249,7,248,15,253,31,253,15,241,7,232,3,232,1,240,0,236,1,238,3,242,7,250,15,244,15,239,3,242,1,232,0,112,0,236,0,240,1,234,3,243,7,235,7,235,1,234,0,26,0,8,0,25,0,238,0,239,1,237,7,240,3,242,0,115,0,11,0,0,0,10,0,113,0,243,0,233,7,239,7,238,1,239,0,24,0,9,0,27,0,235,0,233,1,236,7,246,7,235,3,243,1,237,0,114,0,233,0,241,1,237,3,247,7,246,15,240,7,233,3,237,1,241,0,234,1,236,3,248,7,249,15,252,31,252,15,245,15,234,7,243,3,242,3,245,7,251,15,254,31,0,0,0,0,0,0,7,0,22,0,246,0,24,0,8,0,239,0,239,1,243,0,248,7,25,0,23,0,237,0,21,0,1,0,226,0,240,0,112,0,240,3,238,1,241,0,250,7,238,0,228,0,242,3,246,7,239,3,253,7,5,0,20,0,242,0,9,0,4,0,229,0,244,0,232,0,244,3,6,0,2,0,231,0,3,0,0,0,107,0,227,0,105,0,243,1,235,0,230,0,246,3,110,0,106,0,244,1,236,3,240,1,249,3,245,0,236,0,251,7,234,0,111,0,247,3,249,7,243,3,255,15,233,0,109,0,248,3,108,0,104,0,245,1,238,3,242,1,244,7,247,7,241,3,254,15,237,3,241,1,245,7,254,7,245,3,252,7,0,0,0,0,0,0,0,0,9,0,239,0,11,0,25,0,240,0,235,1,230,1,242,3,10,0,53,0,239,1,52,0,55,0,233,1,237,1,231,1,243,3,238,1,237,3,250,31,236,1,242,1,249,7,248,7,248,3,248,15,8,0,56,0,246,3,54,0,117,0,241,3,235,3,236,3,244,15,24,0,118,0,244,7,57,0,116,0,239,3,243,1,244,1,246,7,232,1,234,3,252,31,242,0,241,1,251,15,245,3,243,7,252,15,238,0,247,3,254,127,240,1,245,7,253,127,251,31,250,63,255,255,241,0,240,3,252,63,234,1,238,3,251,63,246,15,250,15,252,127,242,7,245,15,254,255,244,3,247,7,251,127,247,15,249,15,250,127,0,0,0,0,0,0,243,1,111,0,253,1,235,0,35,0,234,0,247,1,232,0,250,1,242,0,45,0,112,0,32,0,6,0,43,0,110,0,40,0,233,0,249,1,102,0,248,0,231,0,27,0,241,0,244,1,107,0,245,1,236,0,42,0,108,0,44,0,10,0,39,0,103,0,26,0,245,0,36,0,8,0,31,0,9,0,0,0,7,0,29,0,11,0,48,0,239,0,28,0,100,0,30,0,12,0,41,0,243,0,47,0,240,0,252,1,113,0,242,1,244,0,33,0,230,0,247,0,104,0,248,1,238,0,34,0,101,0,49,0,2,0,38,0,237,0,37,0,106,0,251,1,114,0,254,1,105,0,46,0,246,0,255,1,109,0,246,1,0,0,0,0,0,0,0,0,6,0,25,0,61,0,156,0,198,0,167,1,144,3,194,3,223,3,230,7,243,7,251,15,236,7,250,15,254,15,142,3,5,0,1,0,8,0,20,0,55], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1451204);
/* memory initializer */ allocate([66,0,146,0,175,0,145,1,165,1,181,1,158,3,192,3,162,3,205,3,214,7,174,0,23,0,7,0,9,0,24,0,57,0,64,0,142,0,163,0,184,0,153,1,172,1,193,1,177,3,150,3,190,3,202,3,157,0,60,0,21,0,22,0,26,0,59,0,68,0,145,0,165,0,190,0,150,1,174,1,185,1,161,3,145,3,165,3,213,3,148,0,154,0,54,0,56,0,58,0,65,0,140,0,155,0,176,0,195,0,158,1,171,1,188,1,159,3,143,3,169,3,207,3,147,0,191,0,62,0,63,0,67,0,69,0,158,0,167,0,185,0,148,1,162,1,186,1,195,1,166,3,167,3,187,3,212,3,159,0,160,1,143,0,141,0,144,0,152,0,166,0,182,0,196,0,159,1,175,1,191,1,153,3,191,3,180,3,201,3,231,3,168,0,182,1,171,0,164,0,170,0,178,0,194,0,197,0,152,1,164,1,184,1,140,3,164,3,196,3,198,3,221,3,232,3,173,0,175,3,146,1,189,0,188,0,142,1,151,1,154,1,163,1,177,1,141,3,152,3,183,3,211,3,209,3,219,3,221,7,180,0,222,3,169,1,155,1,156,1,161,1,170,1,173,1,179,1,139,3,178,3,184,3,206,3,225,3,224,3,210,7,229,7,183,0,227,7,187,1,168,1,166,1,176,1,178,1,183,1,155,3,154,3,186,3,181,3,214,3,215,7,228,3,216,7,234,7,186,0,232,7,160,3,189,1,180,1,138,3,196,1,146,3,170,3,176,3,188,3,215,3,212,7,220,7,219,7,213,7,240,7,193,0,251,7,200,3,163,3,149,3,157,3,172,3,174,3,197,3,216,3,226,3,230,3,228,7,231,7,224,7,233,7,247,7,144,1,242,7,147,3,190,1,192,1,148,3,151,3,173,3,195,3,193,3,210,3,218,7,217,7,223,7,235,7,244,7,250,7,149,1,248,7,189,3,156,3,171,3,168,3,179,3,185,3,208,3,227,3,229,3,226,7,222,7,237,7,241,7,249,7,252,7,147,1,253,15,220,3,182,3,199,3,204,3,203,3,217,3,218,3,211,7,225,7,238,7,239,7,245,7,246,7,252,15,255,15,157,1,194,1,181,0,161,0,150,0,151,0,149,0,153,0,160,0,162,0,172,0,169,0,177,0,179,0,187,0,192,0,143,1,4,0,0,0,0,0,0,0,34,0,8,0,29,0,38,0,95,0,211,0,207,1,208,3,215,3,237,3,240,7,246,7,253,15,7,0,0,0,1,0,9,0,32,0,84,0,96,0,213,0,220,0,212,1,205,3,222,3,231,7,28,0,2,0,6,0,12,0,30,0,40,0,91,0,205,0,217,0,206,1,220,1,217,3,241,3,37,0,11,0,10,0,13,0,36,0,87,0,97,0,204,0,221,0,204,1,222,1,211,3,231,3,93,0,33,0,31,0,35,0,39,0,89,0,100,0,216,0,223,0,210,1,226,1,221,3,238,3,209,0,85,0,41,0,86,0,88,0,98,0,206,0,224,0,226,0,218,1,212,3,227,3,235,7,201,1,94,0,90,0,92,0,99,0,202,0,218,0,199,1,202,1,224,1,219,3,232,3,236,7,227,1,210,0,203,0,208,0,215,0,219,0,198,1,213,1,216,1,202,3,218,3,234,7,241,7,225,1,212,0,207,0,214,0,222,0,225,0,208,1,214,1,209,3,213,3,242,3,238,7,251,7,233,3,205,1,200,1,203,1,209,1,215,1,223,1,207,3,224,3,239,3,230,7,248,7,250,15,235,3,221,1,211,1,217,1,219,1,210,3,204,3,220,3,234,3,237,7,243,7,249,7,249,15,242,7,206,3,228,1,203,3,216,3,214,3,226,3,229,3,232,7,244,7,245,7,247,7,251,15,250,7,236,3,223,3,225,3,228,3,230,3,240,3,233,7,239,7,248,15,254,15,252,15,255,15,0,0,0,0,0,0,248,7,241,1,253,7,245,3,104,0,240,3,247,7,236,1,245,7,241,3,114,0,244,3,116,0,17,0,118,0,235,1,108,0,246,3,252,7,225,1,241,7,240,1,97,0,246,1,242,7,234,1,251,7,242,1,105,0,237,1,119,0,23,0,111,0,230,1,100,0,229,1,103,0,21,0,98,0,18,0,0,0,20,0,101,0,22,0,109,0,233,1,99,0,228,1,107,0,19,0,113,0,227,1,112,0,243,1,254,7,231,1,243,7,239,1,96,0,238,1,240,7,226,1,250,7,243,3,106,0,232,1,117,0,16,0,115,0,244,1,110,0,247,3,246,7,224,1,249,7,242,3,102,0,245,1,255,7,247,1,244,7,0,0,0,0,0,0,86,88,48,51,6,0,0,0,1,0,0,0,64,31,0,0,86,88,48,52,12,0,0,0,2,0,0,0,64,31,0,0,86,79,88,105,8,0,0,0,1,0,0,0,64,31,0,0,86,79,88,106,10,0,0,0,1,0,0,0,17,43,0,0,86,79,88,107,16,0,0,0,1,0,0,0,128,62,0,0,86,79,88,76,24,0,0,0,1,0,0,0,34,86,0,0,86,79,88,113,32,0,0,0,1,0,0,0,68,172,0,0,86,79,88,114,40,0,0,0,1,0,0,0,68,172,0,0,86,79,88,115,48,0,0,0,1,0,0,0,68,172,0,0,86,79,88,116,16,0,0,0,2,0,0,0,64,31,0,0,86,79,88,117,20,0,0,0,2,0,0,0,17,43,0,0,86,79,88,118,32,0,0,0,2,0,0,0,128,62,0,0,86,79,88,119,48,0,0,0,2,0,0,0,34,86,0,0,86,79,88,120,64,0,0,0,2,0,0,0,68,172,0,0,86,79,88,121,80,0,0,0,2,0,0,0,68,172,0,0,86,79,88,122,96,0,0,0,2,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,97,118,99,49,13,0,0,0,109,112,52,118,2,80,1,0,109,112,52,97,16,80,1,0,97,108,97,99,3,80,1,0,97,99,45,51,5,112,1,0,116,120,51,103,5,112,1,0,116,101,120,116,0,0,0,0,0,0,0,0,1,80,1,0,46,109,112,51,2,80,1,0,109,112,52,97,28,0,0,0,97,118,99,49,107,0,0,0,86,80,54,65,93,0,0,0,86,80,54,70,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,48,119,35,0,56,151,35,0,2,0,0,0,2,0,0,0,0,0,0,0,192,116,33,0,104,68,32,0,2,0,0,0,3,0,0,0,0,0,0,0,16,94,31,0,80,170,30,0,2,0,0,0,4,0,0,0,0,0,0,0,32,19,30,0,64,163,29,0,2,0,0,0,5,0,0,0,0,0,0,0,224,67,29,0,224,242,28,0,2,0,0,0,6,0,0,0,0,0,0,0,200,237,35,0,248,157,35,0,2,0,0,0,7,0,0,0,0,0,0,0,128,61,35,0,248,243,34,0,2,0,0,0,8,0,0,0,0,0,0,0,240,181,34,0,136,120,34,0,3,0,0,0,9,0,0,0,0,0,0,0,248,63,34,0,112,15,34,0,3,0,0,0,10,0,0,0,0,0,0,0,216,222,33,0,208,186,33,0,5,0,0,0,11,0,0,0,0,0,0,0,120,152,33,0,200,120,33,0,3,0,0,0,12,0,0,0,0,0,0,0,16,56,33,0,248,13,33,0,7,0,0,0,13,0,0,0,0,0,0,0,0,244,32,0,112,216,32,0,2,0,0,0,14,0,0,0,0,0,0,0,200,189,32,0,88,166,32,0,5,0,0,0,15,0,0,0,0,0,0,0,144,141,32,0,144,116,32,0,2,0,0,0,16,0,0,0,0,0,0,0,160,93,32,0,24,71,32,0,2,0,0,0,17,0,0,0,0,0,0,0,144,14,32,0,0,244,31,0,2,0,0,0,18,0,0,0,0,0,0,0,224,223,31,0,216,204,31,0,2,0,0,0,19,0,0,0,0,0,0,0,144,183,31,0,128,164,31,0,2,0,0,0,20,0,0,0,0,0,0,0,192,146,31,0,160,128,31,0,2,0,0,0,21,0,0,0,0,0,0,0,80,113,31,0,216,95,31,0,2,0,0,0,22,0,0,0,0,0,0,0,16,53,31,0,96,33,31,0,2,0,0,0,23,0,0,0,0,0,0,0,56,20,31,0,240,5,31,0,2,0,0,0,24,0,0,0,0,0,0,0,200,245,30,0,72,231,30,0,2,0,0,0,25,0,0,0,0,0,0,0,240,217,30,0,72,203,30,0,3,0,0,0,26,0,0,0,0,0,0,0,72,187,30,0,64,172,30,0,5,0,0,0,27,0,0,0,0,0,0,0,128,130,30,0,168,113,30,0,3,0,0,0,28,0,0,0,0,0,0,0,240,100,30,0,80,87,30,0,6,0,0,0,29,0,0,0,0,0,0,0,72,70,30,0,192,59,30,0,2,0,0,0,30,0,0,0,0,0,0,0,200,48,30,0,136,38,30,0,2,0,0,0,31,0,0,0,0,0,0,0,16,30,30,0,208,20,30,0,2,0,0,0,32,0,0,0,0,0,0,0,192,242,29,0,96,231,29,0,3,0,0,0,33,0,0,0,0,0,0,0,24,223,29,0,160,213,29,0,3,0,0,0,34,0,0,0,0,0,0,0,104,205,29,0,48,196,29,0,4,0,0,0,35,0,0,0,0,0,0,0,248,188,29,0,16,181,29,0,2,0,0,0,36,0,0,0,0,0,0,0,240,172,29,0,208,164,29,0,3,0,0,0,37,0,0,0,0,0,0,0,168,132,29,0,16,122,29,0,3,0,0,0,38,0,0,0,0,0,0,0,16,115,29,0,32,108,29,0,3,0,0,0,39,0,0,0,0,0,0,0,128,101,29,0,80,95,29,0,2,0,0,0,40,0,0,0,0,0,0,0,40,89,29,0,152,82,29,0,2,0,0,0,41,0,0,0,0,0,0,0,0,75,29,0,240,68,29,0,2,0,0,0,42,0,0,0,0,0,0,0,152,42,29,0,248,33,29,0,2,0,0,0,43,0,0,0,0,0,0,0,32,28,29,0,168,21,29,0,2,0,0,0,44,0,0,0,0,0,0,0,200,14,29,0,224,8,29,0,2,0,0,0,45,0,0,0,0,0,0,0,96,4,29,0,0,255,28,0,2,0,0,0,46,0,0,0,0,0,0,0,144,250,28,0,240,243,28,0,4,0,0,0,47,0,0,0,0,0,0,0,168,218,28,0,40,210,28,0,2,0,0,0,48,0,0,0,0,0,0,0,72,203,28,0,192,196,28,0,2,0,0,0,49,0,0,0,0,0,0,0,112,191,28,0,8,187,28,0,5,0,0,0,50,0,0,0,0,0,0,0,16,182,28,0,24,177,28,0,2,0,0,0,51,0,0,0,0,0,0,0,208,242,35,0,136,238,35,0,4,0,0,0,52,0,0,0,0,0,0,0,176,213,35,0,112,205,35,0,2,0,0,0,53,0,0,0,0,0,0,0,208,199,35,0,40,194,35,0,2,0,0,0,54,0,0,0,0,0,0,0,168,188,35,0,104,184,35,0,5,0,0,0,55,0,0,0,0,0,0,0,8,179,35,0,8,174,35,0,5,0,0,0,56,0,0,0,0,0,0,0,0,169,35,0,24,159,35,0,4,0,0,0,87,79,78,83,0,0,0,0,240,134,35,0,160,121,35,0,6,0,0,0,57,0,0,0,0,0,0,0,128,114,35,0,16,106,35,0,4,0,0,0,58,0,0,0,0,0,0,0,168,99,35,0,184,93,35,0,2,0,0,0,59,0,0,0,0,0,0,0,192,84,35,0,208,79,35,0,5,0,0,0,60,0,0,0,0,0,0,0,48,71,35,0,8,62,35,0,3,0,0,0,61,0,0,0,0,0,0,0,152,39,35,0,192,30,35,0,2,0,0,0,62,0,0,0,0,0,0,0,160,24,35,0,144,19,35,0,4,0,0,0,63,0,0,0,0,0,0,0,176,13,35,0,192,8,35,0,5,0,0,0,64,0,0,0,0,0,0,0,136,3,35,0,16,255,34,0,5,0,0,0,65,0,0,0,0,0,0,0,16,249,34,0,192,244,34,0,5,0,0,0,66,0,0,0,0,0,0,0,248,225,34,0,248,217,34,0,5,0,0,0,67,0,0,0,0,0,0,0,192,212,34,0,120,207,34,0,5,0,0,0,68,0,0,0,0,0,0,0,96,203,34,0,56,199,34,0,5,0,0,0,69,0,0,0,0,0,0,0,0,195,34,0,144,190,34,0,2,0,0,0,70,0,0,0,0,0,0,0,104,186,34,0,96,182,34,0,2,0,0,0,71,0,0,0,0,0,0,0,192,163,34,0,184,157,34,0,2,0,0,0,72,0,0,0,0,0,0,0,32,153,34,0,248,147,34,0,2,0,0,0,73,0,0,0,0,0,0,0,144,143,34,0,112,139,34,0,5,0,0,0,74,0,0,0,0,0,0,0,240,133,34,0,184,129,34,0,3,0,0,0,75,0,0,0,0,0,0,0,0,125,34,0,64,121,34,0,4,0,0,0,76,0,0,0,0,0,0,0,0,104,34,0,112,97,34,0,2,0,0,0,77,0,0,0,0,0,0,0,16,93,34,0,0,89,34,0,4,0,0,0,78,0,0,0,0,0,0,0,48,85,34,0,232,80,34,0,2,0,0,0,79,0,0,0,0,0,0,0,208,76,34,0,208,72,34,0,5,0,0,0,80,0,0,0,0,0,0,0,8,68,34,0,80,64,34,0,4,0,0,0,81,0,0,0,0,0,0,0,112,48,34,0,128,41,34,0,2,0,0,0,82,0,0,0,0,0,0,0,128,38,34,0,160,35,34,0,4,0,0,0,83,0,0,0,0,0,0,0,40,32,34,0,112,29,34,0,2,0,0,0,84,0,0,0,0,0,0,0,120,26,34,0,192,22,34,0,2,0,0,0,85,0,0,0,0,0,0,0,8,19,34,0,232,15,34,0,2,0,0,0,86,0,0,0,0,0,0,0,104,1,34,0,144,249,33,0,2,0,0,0,87,0,0,0,0,0,0,0,120,246,33,0,208,241,33,0,4,0,0,0,88,0,0,0,0,0,0,0,24,238,33,0,80,234,33,0,2,0,0,0,89,0,0,0,0,0,0,0,224,229,33,0,184,227,33,0,7,0,0,0,90,0,0,0,0,0,0,0,80,225,33,0,0,223,33,0,4,0,0,0,91,0,0,0,0,0,0,0,48,211,33,0,8,208,33,0,2,0,0,0,92,0,0,0,0,0,0,0,96,205,33,0,64,203,33,0,2,0,0,0,93,0,0,0,0,0,0,0,208,200,33,0,160,197,33,0,2,0,0,0,94,0,0,0,0,0,0,0,104,193,33,0,232,191,33,0,5,0,0,0,95,0,0,0,0,0,0,0,176,189,33,0,240,186,33,0,2,0,0,0,96,0,0,0,0,0,0,0,72,174,33,0,168,168,33,0,2,0,0,0,97,0,0,0,0,0,0,0,192,166,33,0,48,165,33,0,5,0,0,0,98,0,0,0,0,0,0,0,232,163,33,0,216,160,33,0,4,0,0,0,99,0,0,0,0,0,0,0,80,158,33,0,24,156,33,0,4,0,0,0,100,0,0,0,0,0,0,0,48,154,33,0,152,152,33,0,3,0,0,0,101,0,0,0,0,0,0,0,104,142,33,0,232,138,33,0,3,0,0,0,102,0,0,0,0,0,0,0,64,137,33,0,200,135,33,0,5,0,0,0,82,73,71,83,0,0,0,0,16,134,33,0,208,131,33,0,5,0,0,0,103,0,0,0,0,0,0,0,240,129,33,0,72,128,33,0,2,0,0,0,104,0,0,0,0,0,0,0,144,126,33,0,64,121,33,0,2,0,0,0,105,0,0,0,0,0,0,0,8,109,33,0,40,99,33,0,3,0,0,0,106,0,0,0,0,0,0,0,32,94,33,0,168,88,33,0,3,0,0,0,107,0,0,0,0,0,0,0,128,85,33,0,160,81,33,0,2,0,0,0,108,0,0,0,0,0,0,0,160,73,33,0,32,69,33,0,3,0,0,0,109,0,0,0,0,0,0,0,32,63,33,0,32,56,33,0,2,0,0,0,110,0,0,0,0,0,0,0,176,43,33,0,152,36,33,0,5,0,0,0,111,0,0,0,0,0,0,0,144,33,33,0,24,29,33,0,5,0,0,0,112,0,0,0,0,0,0,0,40,25,33,0,112,23,33,0,2,0,0,0,113,0,0,0,0,0,0,0,32,21,33,0,224,18,33,0,2,0,0,0,114,0,0,0,0,0,0,0,48,15,33,0,16,14,33,0,2,0,0,0,115,0,0,0,0,0,0,0,32,5,33,0,96,1,33,0,3,0,0,0,116,0,0,0,0,0,0,0,192,254,32,0,232,252,32,0,2,0,0,0,117,0,0,0,0,0,0,0,128,251,32,0,40,250,32,0,6,0,0,0,118,0,0,0,0,0,0,0,136,248,32,0,184,246,32,0,2,0,0,0,119,0,0,0,0,0,0,0,128,245,32,0,8,244,32,0,2,0,0,0,120,0,0,0,0,0,0,0,208,233,32,0,232,230,32,0,2,0,0,0,121,0,0,0,0,0,0,0,16,229,32,0,224,226,32,0,2,0,0,0,122,0,0,0,0,0,0,0,88,225,32,0,184,223,32,0,2,0,0,0,123,0,0,0,0,0,0,0,24,222,32,0,112,220,32,0,2,0,0,0,124,0,0,0,0,0,0,0,184,218,32,0,0,217,32,0,3,0,0,0,125,0,0,0,0,0,0,0,160,207,32,0,176,203,32,0,3,0,0,0,126,0,0,0,0,0,0,0,200,201,32,0,0,0,0,0,5,0,0,0,127,0,0,0,0,0,0,0,216,199,32,0,0,198,32,0,3,0,0,0,128,0,0,0,0,0,0,0,48,196,32,0,8,194,32,0,5,0,0,0,129,0,0,0,0,0,0,0,64,192,32,0,232,190,32,0,5,0,0,0,130,0,0,0,0,0,0,0,0,190,32,0,120,180,32,0,2,0,0,0,131,0,0,0,0,0,0,0,48,177,32,0,0,176,32,0,5,0,0,0,132,0,0,0,0,0,0,0,112,174,32,0,248,172,32,0,2,0,0,0,133,0,0,0,0,0,0,0,32,171,32,0,184,169,32,0,2,0,0,0,134,0,0,0,0,0,0,0,216,168,32,0,216,167,32,0,5,0,0,0,135,0,0,0,0,0,0,0,144,166,32,0,72,159,32,0,2,0,0,0,136,0,0,0,0,0,0,0,168,155,32,0,96,153,32,0,2,0,0,0,137,0,0,0,0,0,0,0,40,151,32,0,208,149,32,0,2,0,0,0,138,0,0,0,0,0,0,0,88,148,32,0,160,145,32,0,2,0,0,0,139,0,0,0,0,0,0,0,184,143,32,0,88,142,32,0,2,0,0,0,140,0,0,0,0,0,0,0,192,141,32,0,72,133,32,0,2,0,0,0,141,0,0,0,0,0,0,0,200,130,32,0,88,129,32,0,2,0,0,0,169,0,0,0,0,0,0,0,72,127,32,0,224,125,32,0,2,0,0,0,142,0,0,0,0,0,0,0,104,123,32,0,96,121,32,0,3,0,0,0,143,0,0,0,0,0,0,0,248,119,32,0,24,118,32,0,2,0,0,0,144,0,0,0,0,0,0,0,200,116,32,0,40,108,32,0,3,0,0,0,145,0,0,0,0,0,0,0,88,105,32,0,200,102,32,0,3,0,0,0,146,0,0,0,0,0,0,0,232,101,32,0,0,101,32,0,5,0,0,0,49,67,86,77,0,0,0,0,72,99,32,0,216,97,32,0,3,0,0,0,50,67,86,77,0,0,0,0,0,96,32,0,56,94,32,0,3,0,0,0,147,0,0,0,0,0,0,0,184,93,32,0,104,86,32,0,2,0,0,0,148,0,0,0,0,0,0,0,48,84,32,0,144,82,32,0,5,0,0,0,149,0,0,0,0,0,0,0,112,81,32,0,176,80,32,0,3,0,0,0,150,0,0,0,0,0,0,0,176,79,32,0,216,77,32,0,3,0,0,0,151,0,0,0,0,0,0,0,152,76,32,0,112,75,32,0,2,0,0,0,152,0,0,0,0,0,0,0,120,71,32,0,128,62,32,0,2,0,0,0,153,0,0,0,0,0,0,0,120,53,32,0,200,48,32,0,2,0,0,0,154,0,0,0,0,0,0,0,24,43,32,0,200,40,32,0,5,0,0,0,155,0,0,0,0,0,0,0,240,36,32,0,144,28,32,0,4,0,0,0,156,0,0,0,0,0,0,0,216,25,32,0,32,21,32,0,5,0,0,0,157,0,0,0,0,0,0,0,0,15,32,0,208,6,32,0,5,0,0,0,158,0,0,0,0,0,0,0,32,2,32,0,88,255,31,0,5,0,0,0,159,0,0,0,0,0,0,0,184,253,31,0,128,252,31,0,5,0,0,0,160,0,0,0,0,0,0,0,200,250,31,0,136,248,31,0,3,0,0,0,161,0,0,0,0,0,0,0,224,246,31,0,176,245,31,0,5,0,0,0,162,0,0,0,0,0,0,0,152,244,31,0,96,238,31,0,4,0,0,0,163,0,0,0,0,0,0,0,32,235,31,0,136,233,31,0,2,0,0,0,164,0,0,0,0,0,0,0,88,232,31,0,32,231,31,0,2,0,0,0,165,0,0,0,0,0,0,0,88,229,31,0,56,227,31,0,2,0,0,0,166,0,0,0,0,0,0,0,224,225,31,0,160,224,31,0,2,0,0,0,167,0,0,0,0,0,0,0,248,223,31,0,248,217,31,0,5,0,0,0,168,0,0,0,0,0,0,0,80,215,31,0,232,213,31,0,3,0,0,0,170,0,0,0,0,0,0,0,152,212,31,0,80,211,31,0,3,0,0,0,80,49,52,89,0,0,0,0,240,209,31,0,96,208,31,0,1,0,0,0,48,51,49,69,0,0,0,0,40,207,31,0,240,205,31,0,2,0,0,0,82,88,69,48,0,0,0,0,0,205,31,0,216,199,31,0,7,0,0,0,80,82,86,65,0,0,0,0,184,196,31,0,8,195,31,0,1,0,0,0,86,50,49,48,0,0,0,0,24,193,31,0,8,194,32,0,1,0,0,0,73,85,86,65,0,0,0,0,168,191,31,0,160,189,31,0,1,0,0,0,86,85,89,65,0,0,0,0,216,187,31,0,136,186,31,0,1,0,0,0,54,49,50,84,0,0,0,0,152,184,31,0,176,183,31,0,1,0,0,0,56,48,51,86,0,0,0,0,128,177,31,0,152,173,31,0,1,0,0,0,56,48,52,86,0,0,0,0,184,172,31,0,192,171,31,0,1,0,0,0,52,86,85,89,0,0,0,0,208,170,31,0,184,169,31,0,1,0,0,0,77,78,65,83,0,0,0,0,200,168,31,0,136,167,31,0,2,0,0,0,86,70,65,80,0,0,0,0,184,165,31,0,160,164,31,0,2,0,0,0,110,82,86,65,0,0,0,0,192,158,31,0,40,156,31,0,0,0,0,0,65,73,80,67,0,0,0,0,8,155,31,0,232,153,31,0,0,0,0,0,67,65,70,88,0,0,0,0,8,153,31,0,192,151,31,0,3,0,0,0,88,73,80,66,0,0,0,0,120,150,31,0,8,149,31,0,5,0,0,0,74,86,77,83,0,0,0,0,184,147,31,0,208,146,31,0,0,0,0,0,77,50,71,0,0,0,0,0,192,140,31,0,120,138,31,0,2,0,0,0,80,66,69,87,0,0,0,0,168,137,31,0,80,136,31,0,7,0,0,0,174,0,0,0,0,0,0,0,72,135,31,0,64,134,31,0,2,0,0,0,53,54,50,72,0,0,0,0,112,132,31,0,128,131,31,0,2,0,0,0,176,0,0,0,0,0,0,0,224,129,31,0,232,128,31,0,2,0,0,0,0,0,1,0,1,0,0,0,224,123,31,0,152,121,31,0,4,0,0,0,1,0,1,0,1,0,0,0,208,120,31,0,192,119,31,0,4,0,0,0,2,0,1,0,1,0,0,0,72,119,31,0,144,117,31,0,4,0,0,0,3,0,1,0,1,0,0,0,184,116,31,0,80,115,31,0,4,0,0,0,4,0,1,0,1,0,0,0,216,113,31,0,104,113,31,0,4,0,0,0,5,0,1,0,1,0,0,0,96,109,31,0,40,107,31,0,4,0,0,0,6,0,1,0,1,0,0,0,144,106,31,0,224,105,31,0,2,0,0,0,7,0,1,0,1,0,0,0,96,105,31,0,104,104,31,0,2,0,0,0,8,0,1,0,1,0,0,0,136,103,31,0,168,102,31,0,4,0,0,0,9,0,1,0,1,0,0,0,184,100,31,0,72,96,31,0,4,0,0,0,10,0,1,0,1,0,0,0,104,89,31,0,88,81,31,0,4,0,0,0,11,0,1,0,1,0,0,0,184,77,31,0,240,73,31,0,4,0,0,0,12,0,1,0,1,0,0,0,240,71,31,0,24,69,31,0,4,0,0,0,13,0,1,0,1,0,0,0,216,63,31,0,200,61,31,0,4,0,0,0,14,0,1,0,1,0,0,0,232,57,31,0,48,53,31,0,4,0,0,0,15,0,1,0,1,0,0,0,8,47,31,0,128,42,31,0,4,0,0,0,16,0,1,0,1,0,0,0,24,40,31,0,24,39,31,0,4,0,0,0,17,0,1,0,1,0,0,0,192,37,31,0,0,37,31,0,2,0,0,0,16,80,83,80,1,0,0,0,32,36,31,0,24,35,31,0,4,0,0,0,18,0,1,0,1,0,0,0,152,34,31,0,192,33,31,0,4,0,0,0,80,83,80,24,1,0,0,0,168,28,31,0,208,26,31,0,4,0,0,0,80,83,80,32,1,0,0,0,8,26,31,0,64,25,31,0,4,0,0,0,19,0,1,0,1,0,0,0,136,24,31,0,160,23,31,0,4,0,0,0,20,0,1,0,1,0,0,0,216,22,31,0,216,21,31,0,4,0,0,0,21,0,1,0,1,0,0,0,224,20,31,0,64,20,31,0,4,0,0,0,22,0,1,0,1,0,0,0,176,16,31,0,192,14,31,0,4,0,0,0,23,0,1,0,1,0,0,0,208,13,31,0,200,12,31,0,4,0,0,0,24,0,1,0,1,0,0,0,0,12,31,0,112,10,31,0,4,0,0,0,25,0,1,0,1,0,0,0,144,9,31,0,248,7,31,0,4,0,0,0,26,0,1,0,1,0,0,0,32,7,31,0,40,6,31,0,4,0,0,0,27,0,1,0,1,0,0,0,80,1,31,0,80,255,30,0,4,0,0,0,0,16,1,0,1,0,0,0,48,254,30,0,224,252,30,0,2,0,0,0,1,16,1,0,1,0,0,0,184,251,30,0,48,250,30,0,2,0,0,0,2,16,1,0,1,0,0,0,0,249,30,0,160,247,30,0,2,0,0,0,3,16,1,0,1,0,0,0,200,246,30,0,208,245,30,0,2,0,0,0,4,16,1,0,1,0,0,0,232,240,30,0,48,239,30,0,2,0,0,0,5,16,1,0,1,0,0,0,192,237,30,0,232,236,30,0,2,0,0,0,6,16,1,0,1,0,0,0,24,236,30,0,224,234,30,0,2,0,0,0,7,16,1,0,1,0,0,0,32,234,30,0,64,233,30,0,2,0,0,0,8,16,1,0,1,0,0,0,128,232,30,0,128,231,30,0,2,0,0,0,9,16,1,0,1,0,0,0,80,227,30,0,88,225,30,0,2,0,0,0,10,16,1,0,1,0,0,0,96,224,30,0,80,223,30,0,2,0,0,0,11,16,1,0,1,0,0,0,128,222,30,0,112,221,30,0,2,0,0,0,12,16,1,0,1,0,0,0,56,220,30,0,16,219,30,0,2,0,0,0,13,16,1,0,1,0,0,0,136,218,30,0,248,217,30,0,2,0,0,0,14,16,1,0,1,0,0,0,104,214,30,0,144,212,30,0,2,0,0,0,15,16,1,0,1,0,0,0,224,211,30,0,168,210,30,0,2,0,0,0,16,16,1,0,1,0,0,0,192,209,30,0,48,208,30,0,2,0,0,0,17,16,1,0,1,0,0,0,112,207,30,0,56,206,30,0,2,0,0,0,18,16,1,0,1,0,0,0,240,204,30,0,96,203,30,0,2,0,0,0,19,16,1,0,1,0,0,0,104,199,30,0,72,197,30,0,2,0,0,0,20,16,1,0,1,0,0,0,120,196,30,0,240,194,30,0,2,0,0,0,21,16,1,0,1,0,0,0,120,193,30,0,208,191,30,0,2,0,0,0,22,16,1,0,1,0,0,0,152,190,30,0,72,189,30,0,2,0,0,0,23,16,1,0,1,0,0,0,16,188,30,0,80,187,30,0,2,0,0,0,24,16,1,0,1,0,0,0,64,184,30,0,40,182,30,0,2,0,0,0,25,16,1,0,1,0,0,0,168,181,30,0,152,180,30,0,2,0,0,0,26,16,1,0,1,0,0,0,232,179,30,0,0,179,30,0,2,0,0,0,27,16,1,0,1,0,0,0,16,178,30,0,32,177,30,0,2,0,0,0,28,16,1,0,1,0,0,0,128,176,30,0,104,172,30,0,2,0,0,0,29,16,1,0,1,0,0,0,136,166,30,0,128,159,30,0,2,0,0,0,32,67,70,65,1,0,0,0,72,156,30,0,64,152,30,0,2,0,0,0,32,73,75,79,1,0,0,0,128,149,30,0,8,147,30,0,2,0,0,0,32,75,84,68,1,0,0,0,160,141,30,0,64,139,30,0,2,0,0,0,32,68,65,82,1,0,0,0,232,135,30,0,136,130,30,0,2,0,0,0,71,55,50,54,1,0,0,0,88,126,30,0,8,123,30,0,2,0,0,0,0,32,1,0,1,0,0,0,120,121,30,0,80,120,30,0,2,0,0,0,1,32,1,0,1,0,0,0,120,119,30,0,192,117,30,0,2,0,0,0,0,48,1,0,1,0,0,0,64,116,30,0,80,115,30,0,2,0,0,0,1,48,1,0,1,0,0,0,168,114,30,0,192,113,30,0,2,0,0,0,0,64,1,0,1,0,0,0,40,111,30,0,64,109,30,0,2,0,0,0,1,64,1,0,1,0,0,0,112,108,30,0,208,107,30,0,2,0,0,0,2,64,1,0,1,0,0,0,0,107,30,0,168,105,30,0,2,0,0,0,3,64,1,0,1,0,0,0,40,104,30,0,80,103,30,0,2,0,0,0,0,80,1,0,1,0,0,0,40,102,30,0,248,100,30,0,2,0,0,0,1,80,1,0,1,0,0,0,16,98,30,0,120,96,30,0,2,0,0,0,2,80,1,0,1,0,0,0,80,95,30,0,208,93,30,0,2,0,0,0,3,80,1,0,1,0,0,0,32,93,30,0,224,91,30,0,2,0,0,0,4,80,1,0,1,0,0,0,152,90,30,0,104,89,30,0,6,0,0,0,5,80,1,0,1,0,0,0,144,88,30,0,128,87,30,0,2,0,0,0,6,80,1,0,1,0,0,0,136,84,30,0,0,0,0,0,2,0,0,0,7,80,1,0,1,0,0,0,56,82,30,0,72,81,30,0,2,0,0,0,8,80,1,0,1,0,0,0,88,80,30,0,248,78,30,0,2,0,0,0,9,80,1,0,1,0,0,0,104,77,30,0,0,76,30,0,2,0,0,0,10,80,1,0,1,0,0,0,160,74,30,0,72,71,30,0,2,0,0,0,11,80,1,0,1,0,0,0,80,70,30,0,208,67,30,0,2,0,0,0,12,80,1,0,1,0,0,0,64,66,30,0,200,65,30,0,4,0,0,0,13,80,1,0,1,0,0,0,80,65,30,0,128,64,30,0,2,0,0,0,14,80,1,0,1,0,0,0,176,63,30,0,232,62,30,0,2,0,0,0,15,80,1,0,1,0,0,0,88,62,30,0,136,61,30,0,4,0,0,0,16,80,1,0,1,0,0,0,208,59,30,0,152,56,30,0,4,0,0,0,17,80,1,0,1,0,0,0,0,55,30,0,80,54,30,0,2,0,0,0,18,80,1,0,1,0,0,0,136,53,30,0,32,53,30,0,2,0,0,0,19,80,1,0,1,0,0,0,8,52,30,0,184,50,30,0,2,0,0,0,20,80,1,0,1,0,0,0,232,49,30,0,96,49,30,0,2,0,0,0,21,80,1,0,1,0,0,0,208,48,30,0,216,45,30,0,2,0,0,0,22,80,1,0,1,0,0,0,128,44,30,0,240,43,30,0,4,0,0,0,23,80,1,0,1,0,0,0,0,43,30,0,88,42,30,0,2,0,0,0,24,80,1,0,1,0,0,0,152,41,30,0,216,40,30,0,2,0,0,0,25,80,1,0,1,0,0,0,128,40,30,0,144,39,30,0,6,0,0,0,26,80,1,0,1,0,0,0,168,38,30,0,64,36,30,0,2,0,0,0,27,80,1,0,1,0,0,0,136,34,30,0,0,34,30,0,2,0,0,0,28,80,1,0,1,0,0,0,184,33,30,0,112,33,30,0,2,0,0,0,29,80,1,0,1,0,0,0,112,32,30,0,200,31,30,0,4,0,0,0,30,80,1,0,1,0,0,0,16,31,30,0,112,30,30,0,2,0,0,0,31,80,1,0,1,0,0,0,56,30,30,0,160,28,30,0,2,0,0,0,32,80,1,0,1,0,0,0,144,27,30,0,72,27,30,0,2,0,0,0,33,80,1,0,1,0,0,0,240,26,30,0,184,26,30,0,4,0,0,0,34,80,1,0,1,0,0,0,40,26,30,0,192,25,30,0,2,0,0,0,35,80,1,0,1,0,0,0,72,25,30,0,248,24,30,0,2,0,0,0,36,80,1,0,1,0,0,0,176,21,30,0,80,17,30,0,2,0,0,0,37,80,1,0,1,0,0,0,80,12,30,0,64,9,30,0,2,0,0,0,38,80,1,0,1,0,0,0,16,6,30,0,152,3,30,0,2,0,0,0,39,80,1,0,1,0,0,0,24,1,30,0,16,252,29,0,4,0,0,0,40,80,1,0,1,0,0,0,32,250,29,0,160,247,29,0,2,0,0,0,41,80,1,0,1,0,0,0,104,243,29,0,192,238,29,0,2,0,0,0,42,80,1,0,1,0,0,0,176,236,29,0,112,235,29,0,2,0,0,0,43,80,1,0,1,0,0,0,232,234,29,0,72,234,29,0,2,0,0,0,44,80,1,0,1,0,0,0,104,233,29,0,208,232,29,0,2,0,0,0,45,80,1,0,1,0,0,0,48,232,29,0,232,231,29,0,4,0,0,0,46,80,1,0,1,0,0,0,168,231,29,0,96,229,29,0,4,0,0,0,47,80,1,0,1,0,0,0,32,228,29,0,152,227,29,0,2,0,0,0,48,80,1,0,1,0,0,0,80,227,29,0,248,226,29,0,2,0,0,0,49,80,1,0,1,0,0,0,32,226,29,0,96,225,29,0,2,0,0,0,50,80,1,0,1,0,0,0,160,224,29,0,200,223,29,0,2,0,0,0,51,80,1,0,1,0,0,0,72,223,29,0,32,221,29,0,2,0,0,0,52,80,1,0,1,0,0,0,16,220,29,0,40,219,29,0,2,0,0,0,53,80,1,0,1,0,0,0,56,218,29,0,224,217,29,0,2,0,0,0,54,80,1,0,1,0,0,0,240,216,29,0,56,216,29,0,2,0,0,0,55,80,1,0,1,0,0,0,56,215,29,0,128,214,29,0,2,0,0,0,56,80,1,0,1,0,0,0,200,213,29,0,40,212,29,0,2,0,0,0,57,80,1,0,1,0,0,0,0,211,29,0,216,209,29,0,2,0,0,0,58,80,1,0,1,0,0,0,128,209,29,0,16,209,29,0,4,0,0,0,59,80,1,0,1,0,0,0,240,207,29,0,48,207,29,0,2,0,0,0,60,80,1,0,1,0,0,0,136,206,29,0,8,206,29,0,2,0,0,0,65,77,73,86,1,0,0,0,152,205,29,0,104,203,29,0,2,0,0,0,83,87,70,70,1,0,0,0,64,202,29,0,80,201,29,0,0,0,0,0,67,78,79,83,1,0,0,0,232,200,29,0,88,200,29,0,0,0,0,0,76,78,79,83,1,0,0,0,88,199,29,0,200,198,29,0,0,0,0,0,65,70,65,80,1,0,0,0,64,198,29,0,0,197,29,0,2,0,0,0,83,85,80,79,1,0,0,0,120,196,29,0,168,194,29,0,2,0,0,0,62,80,1,0,1,0,0,0,144,193,29,0,240,192,29,0,2,0,0,0,75,97,66,116,1,0,0,0,184,192,29,0,64,192,29,0,4,0,0,0,64,80,1,0,1,0,0,0,144,191,29,0,128,190,29,0,2,0,0,0,99,118,101,115,1,0,0,0,192,189,29,0,96,189,29,0,2,0,0,0,118,109,115,115,1,0,0,0,184,147,31,0,32,189,29,0,2,0,0,0,0,112,1,0,3,0,0,0,96,187,29,0,248,185,29,0,0,0,1,0,1,112,1,0,3,0,0,0,184,185,29,0,0,185,29,0,0,0,1,0,2,112,1,0,3,0,0,0,80,184,29,0,88,183,29,0,0,0,2,0,3,112,1,0,3,0,0,0,208,182,29,0,112,182,29,0,0,0,1,0,32,83,83,65,3,0,0,0,168,181,29,0,72,181,29,0,0,0,2,0,4,112,1,0,3,0,0,0,176,179,29,0,144,178,29,0,0,0,2,0,5,112,1,0,3,0,0,0,32,178,29,0,232,177,29,0,0,0,2,0,6,112,1,0,3,0,0,0,160,177,29,0,96,176,29,0,0,0,1,0,7,112,1,0,3,0,0,0,72,175,29,0,96,174,29,0,0,0,0,0,8,112,1,0,3,0,0,0,96,173,29,0,24,173,29,0,0,0,2,0,112,105,82,83,3,0,0,0,216,171,29,0,0,171,29,0,0,0,2,0,68,86,68,109,3,0,0,0,200,170,29,0,128,170,29,0,0,0,2,0,50,76,80,77,3,0,0,0,72,170,29,0,112,169,29,0,0,0,2,0,56,48,54,99,3,0,0,0,216,168,29,0,120,168,29,0,0,0,0,0,66,85,83,74,3,0,0,0,24,168,29,0,152,165,29,0,0,0,2,0,83,74,104,80,3,0,0,0,56,161,29,0,0,157,29,0,0,0,2,0,73,77,65,83,3,0,0,0,48,154,29,0,112,151,29,0,0,0,2,0,84,88,84,82,3,0,0,0,240,149,29,0,248,146,29,0,0,0,2,0,49,86,98,83,3,0,0,0,120,142,29,0,160,140,29,0,0,0,2,0,86,98,117,83,3,0,0,0,192,137,29,0,64,133,29,0,0,0,2,0,114,108,80,86,3,0,0,0,184,129,29,0,224,127,29,0,0,0,2,0,84,84,86,87,3,0,0,0,208,126,29,0,48,126,29,0,0,0,2,0,84,88,84,66,0,0,0,0,104,125,29,0,168,124,29,0,1,0,0,0,78,73,66,88,0,0,0,0,224,123,29,0,8,123,29,0,1,0,0,0,70,68,73,0,0,0,0,0,192,122,29,0,88,122,29,0,1,0,0,0,65,86,76,75,2,0,0,0,248,120,29,0,8,120,29,0,0,0,0,0,86,65,78,68,2,0,0,0,104,119,29,0,240,118,29,0,0,0,0,0,51,68,73,84,2,0,0,0,40,118,29,0,40,117,29,0,0,0,0,0,0,0,0,0,6,0,1,0,1,0,0,0,4,0,1,0,2,0,0,0,1,0,1,0,3,0,0,0,13,0,1,0,4,0,0,0,9,0,1,0,5,0,0,0,20,0,1,0,6,0,0,0,22,0,1,0,7,0,0,0,71,55,50,54,23,0,0,0,28,16,1,0,24,0,0,0,71,55,50,54,25,0,0,0,71,55,50,54,26,0,0,0,7,0,1,0,27,0,0,0,71,55,50,54,50,54,50,55,0,0,0,0,0,0,0,0,13,0,0,0,77,52,83,50,13,0,0,0,77,80,52,83,17,0,0,0,77,80,52,51,0,0,0,0,0,0,0,0,5,0,0,0,115,50,54,51,28,0,0,0,97,118,99,49,13,0,0,0,109,112,52,118,2,80,1,0,109,112,52,97,0,32,1,0,115,97,109,114,1,32,1,0,115,97,119,98,5,112,1,0,116,120,51,103,0,0,0,0,0,0,0,0,0,0,16,1,32,1,48,1,64,1,80,1,96,1,112,1,128,1,144,1,160,1,176,1,192,1,1,17,17,2,33,2,49,2,65,2,81,2,97,2,113,2,129,2,145,2,161,2,177,2,193,2,2,17,18,2,34,2,50,2,66,2,82,2,98,2,114,2,130,2,146,2,162,2,178,2,194,2,3,17,19,2,35,2,51,2,67,2,83,2,99,2,115,2,131,2,147,2,163,2,179,2,195,2,4,17,20,2,36,2,52,2,68,2,84,2,100,2,116,2,132,2,148,2,164,2,180,2,196,2,5,17,21,2,37,2,53,2,69,2,85,2,101,2,117,2,133,2,149,2,165,2,181,2,197,2,6,17,22,2,38,2,54,2,70,2,86,2,102,2,118,2,134,2,150,2,166,2,182,2,198,2,7,17,23,2,39,2,55,2,71,2,87,2,103,2,119,2,135,2,151,2,167,2,183,2,199,2,8,17,24,2,40,2,56,2,72,2,88,2,104,2,120,2,136,2,152,2,168,2,184,2,200,2,9,17,25,2,41,2,57,2,73,2,89,2,105,2,121,2,137,2,153,2,169,2,185,2,201,2,10,17,26,2,42,2,58,2,74,2,90,2,106,2,122,2,138,2,154,2,170,2,186,2,202,2,11,17,27,2,43,2,59,2,75,2,91,2,107,2,123,2,139,2,155,2,171,2,187,2,203,2,12,17,28,2,44,2,60,2,76,2,92,2,108,2,124,2,140,2,156,2,172,2,188,2,204,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,186,116,138,64,0,0,0,0,245,47,203,64,0,0,0,0,79,204,8,65,0,0,0,0,142,113,46,65,0,0,0,0,144,63,86,65,0,0,0,0,0,0,128,65,0,0,0,0,27,196,149,65,0,0,0,0,211,90,172,65,0,0,0,0,211,181,195,65,0,0,0,0,255,200,219,65,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,186,116,138,64,0,0,128,63,245,47,203,64,0,0,128,63,79,204,8,65,0,0,128,63,142,113,46,65,0,0,128,63,144,63,86,65,0,0,128,63,0,0,128,65,0,0,128,63,27,196,149,65,0,0,128,63,211,90,172,65,0,0,128,63,211,181,195,65,0,0,128,63,255,200,219,65,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,186,116,138,64,24,69,33,64,245,47,203,64,24,69,33,64,79,204,8,65,24,69,33,64,142,113,46,65,24,69,33,64,144,63,86,65,24,69,33,64,0,0,128,65,24,69,33,64,27,196,149,65,24,69,33,64,211,90,172,65,24,69,33,64,211,181,195,65,24,69,33,64,255,200,219,65,186,116,138,64,0,0,0,0,186,116,138,64,0,0,128,63,186,116,138,64,24,69,33,64,186,116,138,64,186,116,138,64,186,116,138,64,245,47,203,64,186,116,138,64,79,204,8,65,186,116,138,64,142,113,46,65,186,116,138,64,144,63,86,65,186,116,138,64,0,0,128,65,186,116,138,64,27,196,149,65,186,116,138,64,211,90,172,65,186,116,138,64,211,181,195,65,186,116,138,64,255,200,219,65,245,47,203,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,64,245,47,203,64,245,47,203,64,79,204,8,65,245,47,203,64,142,113,46,65,245,47,203,64,144,63,86,65,245,47,203,64,0,0,128,65,245,47,203,64,27,196,149,65,245,47,203,64,211,90,172,65,245,47,203,64,211,181,195,65,245,47,203,64,255,200,219,65,79,204,8,65,0,0,0,0,79,204,8,65,0,0,128,63,79,204,8,65,24,69,33,64,79,204,8,65,186,116,138,64,79,204,8,65,245,47,203,64,79,204,8,65,79,204,8,65,79,204,8,65,142,113,46,65,79,204,8,65,144,63,86,65,79,204,8,65,0,0,128,65,79,204,8,65,27,196,149,65,79,204,8,65,211,90,172,65,79,204,8,65,211,181,195,65,79,204,8,65,255,200,219,65,142,113,46,65,0,0,0,0,142,113,46,65,0,0,128,63,142,113,46,65,24,69,33,64,142,113,46,65,186,116,138,64,142,113,46,65,245,47,203,64,142,113,46,65,79,204,8,65,142,113,46,65,142,113,46,65,142,113,46,65,144,63,86,65,142,113,46,65,0,0,128,65,142,113,46,65,27,196,149,65,142,113,46,65,211,90,172,65,142,113,46,65,211,181,195,65,142,113,46,65,255,200,219,65,144,63,86,65,0,0,0,0,144,63,86,65,0,0,128,63,144,63,86,65,24,69,33,64,144,63,86,65,186,116,138,64,144,63,86,65,245,47,203,64,144,63,86,65,79,204,8,65,144,63,86,65,142,113,46,65,144,63,86,65,144,63,86,65,144,63,86,65,0,0,128,65,144,63,86,65,27,196,149,65,144,63,86,65,211,90,172,65,144,63,86,65,211,181,195,65,144,63,86,65], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1461444);
/* memory initializer */ allocate([255,200,219,65,0,0,128,65,0,0,0,0,0,0,128,65,0,0,128,63,0,0,128,65,24,69,33,64,0,0,128,65,186,116,138,64,0,0,128,65,245,47,203,64,0,0,128,65,79,204,8,65,0,0,128,65,142,113,46,65,0,0,128,65,144,63,86,65,0,0,128,65,0,0,128,65,0,0,128,65,27,196,149,65,0,0,128,65,211,90,172,65,0,0,128,65,211,181,195,65,0,0,128,65,255,200,219,65,27,196,149,65,0,0,0,0,27,196,149,65,0,0,128,63,27,196,149,65,24,69,33,64,27,196,149,65,186,116,138,64,27,196,149,65,245,47,203,64,27,196,149,65,79,204,8,65,27,196,149,65,142,113,46,65,27,196,149,65,144,63,86,65,27,196,149,65,0,0,128,65,27,196,149,65,27,196,149,65,27,196,149,65,211,90,172,65,27,196,149,65,211,181,195,65,27,196,149,65,255,200,219,65,211,90,172,65,0,0,0,0,211,90,172,65,0,0,128,63,211,90,172,65,24,69,33,64,211,90,172,65,186,116,138,64,211,90,172,65,245,47,203,64,211,90,172,65,79,204,8,65,211,90,172,65,142,113,46,65,211,90,172,65,144,63,86,65,211,90,172,65,0,0,128,65,211,90,172,65,27,196,149,65,211,90,172,65,211,90,172,65,211,90,172,65,211,181,195,65,211,90,172,65,255,200,219,65,211,181,195,65,0,0,0,0,211,181,195,65,0,0,128,63,211,181,195,65,24,69,33,64,211,181,195,65,186,116,138,64,211,181,195,65,245,47,203,64,211,181,195,65,79,204,8,65,211,181,195,65,142,113,46,65,211,181,195,65,144,63,86,65,211,181,195,65,0,0,128,65,211,181,195,65,27,196,149,65,211,181,195,65,211,90,172,65,211,181,195,65,211,181,195,65,211,181,195,65,255,200,219,65,255,200,219,65,0,0,0,0,255,200,219,65,0,0,128,63,255,200,219,65,24,69,33,64,255,200,219,65,186,116,138,64,255,200,219,65,245,47,203,64,255,200,219,65,79,204,8,65,255,200,219,65,142,113,46,65,255,200,219,65,144,63,86,65,255,200,219,65,0,0,128,65,255,200,219,65,27,196,149,65,255,200,219,65,211,90,172,65,255,200,219,65,211,181,195,65,255,200,219,65,255,200,219,65,0,0,16,1,32,1,48,1,64,1,80,1,96,1,112,1,1,17,17,2,33,2,49,2,65,2,81,2,97,2,113,2,2,17,18,2,34,2,50,2,66,2,82,2,98,2,114,2,3,17,19,2,35,2,51,2,67,2,83,2,99,2,115,2,4,17,20,2,36,2,52,2,68,2,84,2,100,2,116,2,5,17,21,2,37,2,53,2,69,2,85,2,101,2,117,2,6,17,22,2,38,2,54,2,70,2,86,2,102,2,118,2,7,17,23,2,39,2,55,2,71,2,87,2,103,2,119,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,186,116,138,64,0,0,0,0,245,47,203,64,0,0,0,0,79,204,8,65,0,0,0,0,142,113,46,65,0,0,0,0,144,63,86,65,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,186,116,138,64,0,0,128,63,245,47,203,64,0,0,128,63,79,204,8,65,0,0,128,63,142,113,46,65,0,0,128,63,144,63,86,65,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,186,116,138,64,24,69,33,64,245,47,203,64,24,69,33,64,79,204,8,65,24,69,33,64,142,113,46,65,24,69,33,64,144,63,86,65,186,116,138,64,0,0,0,0,186,116,138,64,0,0,128,63,186,116,138,64,24,69,33,64,186,116,138,64,186,116,138,64,186,116,138,64,245,47,203,64,186,116,138,64,79,204,8,65,186,116,138,64,142,113,46,65,186,116,138,64,144,63,86,65,245,47,203,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,64,245,47,203,64,245,47,203,64,79,204,8,65,245,47,203,64,142,113,46,65,245,47,203,64,144,63,86,65,79,204,8,65,0,0,0,0,79,204,8,65,0,0,128,63,79,204,8,65,24,69,33,64,79,204,8,65,186,116,138,64,79,204,8,65,245,47,203,64,79,204,8,65,79,204,8,65,79,204,8,65,142,113,46,65,79,204,8,65,144,63,86,65,142,113,46,65,0,0,0,0,142,113,46,65,0,0,128,63,142,113,46,65,24,69,33,64,142,113,46,65,186,116,138,64,142,113,46,65,245,47,203,64,142,113,46,65,79,204,8,65,142,113,46,65,142,113,46,65,142,113,46,65,144,63,86,65,144,63,86,65,0,0,0,0,144,63,86,65,0,0,128,63,144,63,86,65,24,69,33,64,144,63,86,65,186,116,138,64,144,63,86,65,245,47,203,64,144,63,86,65,79,204,8,65,144,63,86,65,142,113,46,65,144,63,86,65,144,63,86,65,245,47,203,192,186,116,138,192,24,69,33,192,0,0,128,191,0,0,0,0,0,0,128,63,24,69,33,64,186,116,138,64,245,47,203,64,0,0,0,0,0,0,16,0,32,0,48,0,64,0,80,0,96,0,112,0,128,0,1,0,17,0,33,0,49,0,65,0,81,0,97,0,113,0,129,0,2,0,18,0,34,0,50,0,66,0,82,0,98,0,114,0,130,0,3,0,19,0,35,0,51,0,67,0,83,0,99,0,115,0,131,0,4,0,20,0,36,0,52,0,68,0,84,0,100,0,116,0,132,0,5,0,21,0,37,0,53,0,69,0,85,0,101,0,117,0,133,0,6,0,22,0,38,0,54,0,70,0,86,0,102,0,118,0,134,0,7,0,23,0,39,0,55,0,71,0,87,0,103,0,119,0,135,0,8,0,24,0,40,0,56,0,72,0,88,0,104,0,120,0,136,0,0,0,0,0,0,0,245,47,203,192,245,47,203,192,245,47,203,192,186,116,138,192,245,47,203,192,24,69,33,192,245,47,203,192,0,0,128,191,245,47,203,192,0,0,0,0,245,47,203,192,0,0,128,63,245,47,203,192,24,69,33,64,245,47,203,192,186,116,138,64,245,47,203,192,245,47,203,64,186,116,138,192,245,47,203,192,186,116,138,192,186,116,138,192,186,116,138,192,24,69,33,192,186,116,138,192,0,0,128,191,186,116,138,192,0,0,0,0,186,116,138,192,0,0,128,63,186,116,138,192,24,69,33,64,186,116,138,192,186,116,138,64,186,116,138,192,245,47,203,64,24,69,33,192,245,47,203,192,24,69,33,192,186,116,138,192,24,69,33,192,24,69,33,192,24,69,33,192,0,0,128,191,24,69,33,192,0,0,0,0,24,69,33,192,0,0,128,63,24,69,33,192,24,69,33,64,24,69,33,192,186,116,138,64,24,69,33,192,245,47,203,64,0,0,128,191,245,47,203,192,0,0,128,191,186,116,138,192,0,0,128,191,24,69,33,192,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,24,69,33,64,0,0,128,191,186,116,138,64,0,0,128,191,245,47,203,64,0,0,0,0,245,47,203,192,0,0,0,0,186,116,138,192,0,0,0,0,24,69,33,192,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,186,116,138,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,192,0,0,128,63,186,116,138,192,0,0,128,63,24,69,33,192,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,186,116,138,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,192,24,69,33,64,186,116,138,192,24,69,33,64,24,69,33,192,24,69,33,64,0,0,128,191,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,186,116,138,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,192,186,116,138,64,186,116,138,192,186,116,138,64,24,69,33,192,186,116,138,64,0,0,128,191,186,116,138,64,0,0,0,0,186,116,138,64,0,0,128,63,186,116,138,64,24,69,33,64,186,116,138,64,186,116,138,64,186,116,138,64,245,47,203,64,245,47,203,64,245,47,203,192,245,47,203,64,186,116,138,192,245,47,203,64,24,69,33,192,245,47,203,64,0,0,128,191,245,47,203,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,64,245,47,203,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,24,69,33,64,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,24,69,33,64,0,0,0,0,0,0,0,0,24,69,33,64,0,0,0,0,0,0,0,0,0,0,0,0,24,69,33,64,0,0,128,63,0,0,0,0,0,0,0,0,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,0,0,0,0,0,0,0,0,0,0,128,63,24,69,33,64,0,0,128,63,0,0,0,0,0,0,128,63,24,69,33,64,24,69,33,64,0,0,0,0,24,69,33,64,0,0,0,0,0,0,0,0,0,0,0,0,24,69,33,64,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,0,0,0,0,0,0,0,0,24,69,33,64,0,0,128,63,0,0,128,63,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,0,0,0,0,24,69,33,64,24,69,33,64,0,0,0,0,0,0,0,0,24,69,33,64,24,69,33,64,0,0,128,63,0,0,0,0,24,69,33,64,24,69,33,64,24,69,33,64,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,24,69,33,64,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,24,69,33,64,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,128,63,0,0,128,63,0,0,0,0,24,69,33,64,24,69,33,64,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,24,69,33,64,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,0,0,128,63,24,69,33,64,0,0,0,0,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,24,69,33,64,0,0,128,63,24,69,33,64,0,0,0,0,0,0,0,0,0,0,128,63,24,69,33,64,0,0,0,0,0,0,128,63,0,0,128,63,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,0,0,128,63,0,0,0,0,0,0,128,63,24,69,33,64,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,24,69,33,64,0,0,128,63,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,24,69,33,64,0,0,0,0,0,0,0,0,0,0,0,0,24,69,33,64,0,0,0,0,0,0,0,0,0,0,128,63,24,69,33,64,0,0,0,0,0,0,0,0,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,0,0,128,63,0,0,128,63,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,24,69,33,64,0,0,0,0,24,69,33,64,0,0,0,0,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,0,0,0,0,24,69,33,64,24,69,33,64,24,69,33,64,0,0,128,63,0,0,0,0,0,0,0,0,24,69,33,64,0,0,128,63,0,0,0,0,0,0,128,63,24,69,33,64,0,0,128,63,0,0,0,0,24,69,33,64,24,69,33,64,0,0,128,63,0,0,128,63,0,0,0,0,24,69,33,64,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,0,0,128,63,24,69,33,64,24,69,33,64,0,0,128,63,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,0,0,128,63,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,24,69,33,64,0,0,0,0,0,0,0,0,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,24,69,33,64,0,0,0,0,24,69,33,64,24,69,33,64,24,69,33,64,0,0,128,63,0,0,0,0,24,69,33,64,24,69,33,64,0,0,128,63,0,0,128,63,24,69,33,64,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,24,69,33,64,0,0,0,0,24,69,33,64,24,69,33,64,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,186,116,138,64,245,47,203,64,79,204,8,65,142,113,46,65,144,63,86,65,0,0,128,65,27,196,149,65,211,90,172,65,211,181,195,65,255,200,219,65,239,137,244,65,205,247,6,66,4,249,19,66,0,0,16,16,32,16,48,16,64,16,80,16,96,16,112,16,128,16,144,16,160,16,176,16,192,16,208,16,224,16,240,16,0,18,1,16,17,32,33,32,49,32,65,32,81,32,97,32,113,32,129,32,145,32,161,32,177,32,193,32,209,32,225,32,241,32,1,34,2,16,18,32,34,32,50,32,66,32,82,32,98,32,114,32,130,32,146,32,162,32,178,32,194,32,210,32,226,32,242,32,2,34,3,16,19,32,35,32,51,32,67,32,83,32,99,32,115,32,131,32,147,32,163,32,179,32,195,32,211,32,227,32,243,32,3,34,4,16,20,32,36,32,52,32,68,32,84,32,100,32,116,32,132,32,148,32,164,32,180,32,196,32,212,32,228,32,244,32,4,34,5,16,21,32,37,32,53,32,69,32,85,32,101,32,117,32,133,32,149,32,165,32,181,32,197,32,213,32,229,32,245,32,5,34,6,16,22,32,38,32,54,32,70,32,86,32,102,32,118,32,134,32,150,32,166,32,182,32,198,32,214,32,230,32,246,32,6,34,7,16,23,32,39,32,55,32,71,32,87,32,103,32,119,32,135,32,151,32,167,32,183,32,199,32,215,32,231,32,247,32,7,34,8,16,24,32,40,32,56,32,72,32,88,32,104,32,120,32,136,32,152,32,168,32,184,32,200,32,216,32,232,32,248,32,8,34,9,16,25,32,41,32,57,32,73,32,89,32,105,32,121,32,137,32,153,32,169,32,185,32,201,32,217,32,233,32,249,32,9,34,10,16,26,32,42,32,58,32,74,32,90,32,106,32,122,32,138,32,154,32,170,32,186,32,202,32,218,32,234,32,250,32,10,34,11,16,27,32,43,32,59,32,75,32,91,32,107,32,123,32,139,32,155,32,171,32,187,32,203,32,219,32,235,32,251,32,11,34,12,16,28,32,44,32,60,32,76,32,92,32,108,32,124,32,140,32,156,32,172,32,188,32,204,32,220,32,236,32,252,32,12,34,13,16,29,32,45,32,61,32,77,32,93,32,109,32,125,32,141,32,157,32,173,32,189,32,205,32,221,32,237,32,253,32,13,34,14,16,30,32,46,32,62,32,78,32,94,32,110,32,126,32,142,32,158,32,174,32,190,32,206,32,222,32,238,32,254,32,14,34,15,16,31,32,47,32,63,32,79,32,95,32,111,32,127,32,143,32,159,32,175,32,191,32,207,32,223,32,239,32,255,32,15,34,0,17,16,33,32,33,48,33,64,33,80,33,96,33,112,33,128,33,144,33,160,33,176,33,192,33,208,33,224,33,240,33,0,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,186,116,138,64,0,0,0,0,245,47,203,64,0,0,0,0,79,204,8,65,0,0,0,0,142,113,46,65,0,0,0,0,144,63,86,65,0,0,0,0,0,0,128,65,0,0,0,0,27,196,149,65,0,0,0,0,211,90,172,65,0,0,0,0,211,181,195,65,0,0,0,0,255,200,219,65,0,0,0,0,239,137,244,65,0,0,0,0,205,247,6,66,0,0,0,0,4,249,19,66,0,0,0,0,0,0,128,66,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,186,116,138,64,0,0,128,63,245,47,203,64,0,0,128,63,79,204,8,65,0,0,128,63,142,113,46,65,0,0,128,63,144,63,86,65,0,0,128,63,0,0,128,65,0,0,128,63,27,196,149,65,0,0,128,63,211,90,172,65,0,0,128,63,211,181,195,65,0,0,128,63,255,200,219,65,0,0,128,63,239,137,244,65,0,0,128,63,205,247,6,66,0,0,128,63,4,249,19,66,0,0,128,63,0,0,128,66,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,186,116,138,64,24,69,33,64,245,47,203,64,24,69,33,64,79,204,8,65,24,69,33,64,142,113,46,65,24,69,33,64,144,63,86,65,24,69,33,64,0,0,128,65,24,69,33,64,27,196,149,65,24,69,33,64,211,90,172,65,24,69,33,64,211,181,195,65,24,69,33,64,255,200,219,65,24,69,33,64,239,137,244,65,24,69,33,64,205,247,6,66,24,69,33,64,4,249,19,66,24,69,33,64,0,0,128,66,186,116,138,64,0,0,0,0,186,116,138,64,0,0,128,63,186,116,138,64,24,69,33,64,186,116,138,64,186,116,138,64,186,116,138,64,245,47,203,64,186,116,138,64,79,204,8,65,186,116,138,64,142,113,46,65,186,116,138,64,144,63,86,65,186,116,138,64,0,0,128,65,186,116,138,64,27,196,149,65,186,116,138,64,211,90,172,65,186,116,138,64,211,181,195,65,186,116,138,64,255,200,219,65,186,116,138,64,239,137,244,65,186,116,138,64,205,247,6,66,186,116,138,64,4,249,19,66,186,116,138,64,0,0,128,66,245,47,203,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,64,245,47,203,64,245,47,203,64,79,204,8,65,245,47,203,64,142,113,46,65,245,47,203,64,144,63,86,65,245,47,203,64,0,0,128,65,245,47,203,64,27,196,149,65,245,47,203,64,211,90,172,65,245,47,203,64,211,181,195,65,245,47,203,64,255,200,219,65,245,47,203,64,239,137,244,65,245,47,203,64,205,247,6,66,245,47,203,64,4,249,19,66,245,47,203,64,0,0,128,66,79,204,8,65,0,0,0,0,79,204,8,65,0,0,128,63,79,204,8,65,24,69,33,64,79,204,8,65,186,116,138,64,79,204,8,65,245,47,203,64,79,204,8,65,79,204,8,65,79,204,8,65,142,113,46,65,79,204,8,65,144,63,86,65,79,204,8,65,0,0,128,65,79,204,8,65,27,196,149,65,79,204,8,65,211,90,172,65,79,204,8,65,211,181,195,65,79,204,8,65,255,200,219,65,79,204,8,65,239,137,244,65,79,204,8,65,205,247,6,66,79,204,8,65,4,249,19,66,79,204,8,65,0,0,128,66,142,113,46,65,0,0,0,0,142,113,46,65,0,0,128,63,142,113,46,65,24,69,33,64,142,113,46,65,186,116,138,64,142,113,46,65,245,47,203,64,142,113,46,65,79,204,8,65,142,113,46,65,142,113,46,65,142,113,46,65,144,63,86,65,142,113,46,65,0,0,128,65,142,113,46,65,27,196,149,65,142,113,46,65,211,90,172,65,142,113,46,65,211,181,195,65,142,113,46,65,255,200,219,65,142,113,46,65,239,137,244,65,142,113,46,65,205,247,6,66,142,113,46,65,4,249,19,66,142,113,46,65,0,0,128,66,144,63,86,65,0,0,0,0,144,63,86,65,0,0,128,63,144,63,86,65,24,69,33,64,144,63,86,65,186,116,138,64,144,63,86,65,245,47,203,64,144,63,86,65,79,204,8,65,144,63,86,65,142,113,46,65,144,63,86,65,144,63,86,65,144,63,86,65,0,0,128,65,144,63,86,65,27,196,149,65,144,63,86,65,211,90,172,65,144,63,86,65,211,181,195,65,144,63,86,65,255,200,219,65,144,63,86,65,239,137,244,65,144,63,86,65,205,247,6,66,144,63,86,65,4,249,19,66,144,63,86,65,0,0,128,66,0,0,128,65,0,0,0,0,0,0,128,65,0,0,128,63,0,0,128,65,24,69,33,64,0,0,128,65,186,116,138,64,0,0,128,65,245,47,203,64,0,0,128,65,79,204,8,65,0,0,128,65,142,113,46,65,0,0,128,65,144,63,86,65,0,0,128,65,0,0,128,65,0,0,128,65,27,196,149,65,0,0,128,65,211,90,172,65,0,0,128,65,211,181,195,65,0,0,128,65,255,200,219,65,0,0,128,65,239,137,244,65,0,0,128,65,205,247,6,66,0,0,128,65,4,249,19,66,0,0,128,65,0,0,128,66,27,196,149,65,0,0,0,0,27,196,149,65,0,0,128,63,27,196,149,65,24,69,33,64,27,196,149,65,186,116,138,64,27,196,149,65,245,47,203,64,27,196,149,65,79,204,8,65,27,196,149,65,142,113,46,65,27,196,149,65,144,63,86,65,27,196,149,65,0,0,128,65,27,196,149,65,27,196,149,65,27,196,149,65,211,90,172,65,27,196,149,65,211,181,195,65,27,196,149,65,255,200,219,65,27,196,149,65,239,137,244,65,27,196,149,65,205,247,6,66,27,196,149,65,4,249,19,66,27,196,149,65,0,0,128,66,211,90,172,65,0,0,0,0,211,90,172,65,0,0,128,63,211,90,172,65,24,69,33,64,211,90,172,65,186,116,138,64,211,90,172,65,245,47,203,64,211,90,172,65,79,204,8,65,211,90,172,65,142,113,46,65,211,90,172,65,144,63,86,65,211,90,172,65,0,0,128,65,211,90,172,65,27,196,149,65,211,90,172,65,211,90,172,65,211,90,172,65,211,181,195,65,211,90,172,65,255,200,219,65,211,90,172,65,239,137,244,65,211,90,172,65,205,247,6,66,211,90,172,65,4,249,19,66,211,90,172,65,0,0,128,66,211,181,195,65,0,0,0,0,211,181,195,65,0,0,128,63,211,181,195,65,24,69,33,64,211,181,195,65,186,116,138,64,211,181,195,65,245,47,203,64,211,181,195,65,79,204,8,65,211,181,195,65,142,113,46,65,211,181,195,65,144,63,86,65,211,181,195,65,0,0,128,65,211,181,195,65,27,196,149,65,211,181,195,65,211,90,172,65,211,181,195,65,211,181,195,65,211,181,195,65,255,200,219,65,211,181,195,65,239,137,244,65,211,181,195,65,205,247,6,66,211,181,195,65,4,249,19,66,211,181,195,65,0,0,128,66,255,200,219,65,0,0,0,0,255,200,219,65,0,0,128,63,255,200,219,65,24,69,33,64,255,200,219,65,186,116,138,64,255,200,219,65,245,47,203,64,255,200,219,65,79,204,8,65,255,200,219,65,142,113,46,65,255,200,219,65,144,63,86,65,255,200,219,65,0,0,128,65,255,200,219,65,27,196,149,65,255,200,219,65,211,90,172,65,255,200,219,65,211,181,195,65,255,200,219,65,255,200,219,65,255,200,219,65,239,137,244,65,255,200,219,65,205,247,6,66,255,200,219,65,4,249,19,66,255,200,219,65,0,0,128,66,239,137,244,65,0,0,0,0,239,137,244,65,0,0,128,63,239,137,244,65,24,69,33,64,239,137,244,65,186,116,138,64,239,137,244,65,245,47,203,64,239,137,244,65,79,204,8,65,239,137,244,65,142,113,46,65,239,137,244,65,144,63,86,65,239,137,244,65,0,0,128,65,239,137,244,65,27,196,149,65,239,137,244,65,211,90,172,65,239,137,244,65,211,181,195,65,239,137,244,65,255,200,219,65,239,137,244,65,239,137,244,65,239,137,244,65,205,247,6,66,239,137,244,65,4,249,19,66,239,137,244,65,0,0,128,66,205,247,6,66,0,0,0,0,205,247,6,66,0,0,128,63,205,247,6,66,24,69,33,64,205,247,6,66,186,116,138,64,205,247,6,66,245,47,203,64,205,247,6,66,79,204,8,65,205,247,6,66,142,113,46,65,205,247,6,66,144,63,86,65,205,247,6,66,0,0,128,65,205,247,6,66,27,196,149,65,205,247,6,66,211,90,172,65,205,247,6,66,211,181,195,65,205,247,6,66,255,200,219,65,205,247,6,66,239,137,244,65,205,247,6,66,205,247,6,66,205,247,6,66,4,249,19,66,205,247,6,66,0,0,128,66,4,249,19,66,0,0,0,0,4,249,19,66,0,0,128,63,4,249,19,66,24,69,33,64,4,249,19,66,186,116,138,64,4,249,19,66,245,47,203,64,4,249,19,66,79,204,8,65,4,249,19,66,142,113,46,65,4,249,19,66,144,63,86,65,4,249,19,66,0,0,128,65,4,249,19,66,27,196,149,65,4,249,19,66,211,90,172,65,4,249,19,66,211,181,195,65,4,249,19,66,255,200,219,65,4,249,19,66,239,137,244,65,4,249,19,66,205,247,6,66,4,249,19,66,4,249,19,66,4,249,19,66,0,0,128,66,0,0,128,66,0,0,0,0,0,0,128,66,0,0,128,63,0,0,128,66,24,69,33,64,0,0,128,66,186,116,138,64,0,0,128,66,245,47,203,64,0,0,128,66,79,204,8,65,0,0,128,66,142,113,46,65,0,0,128,66,144,63,86,65,0,0,128,66,0,0,128,65,0,0,128,66,27,196,149,65,0,0,128,66,211,90,172,65,0,0,128,66,211,181,195,65,0,0,128,66,255,200,219,65,0,0,128,66,239,137,244,65,0,0,128,66,205,247,6,66,0,0,128,66,4,249,19,66,0,0,128,66,0,0,128,66,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,64,129,128,129,16,65,80,194,144,194,32,65,96,194,160,194,4,33,68,162,132,162,20,98,84,227,148,227,36,98,100,227,164,227,8,33,72,162,136,162,24,98,88,227,152,227,40,98,104,227,168,227,1,17,65,146,129,146,17,82,81,211,145,211,33,82,97,211,161,211,5,50,69,179,133,179,21,115,85,244,149,244,37,115,101,244,165,244,9,50,73,179,137,179,25,115,89,244,153,244,41,115,105,244,169,244,2,17,66,146,130,146,18,82,82,211,146,211,34,82,98,211,162,211,6,50,70,179,134,179,22,115,86,244,150,244,38,115,102,244,166,244,10,50,74,179,138,179,26,115,90,244,154,244,42,115,106,244,170,244,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,4,5,4,5,3,5,3,5,3,5,4,4,4,4,5,5,5,0,0,0,0,0,0,0,4,3,4,3,4,4,5,4,5,4,5,5,6,5,6,5,7,5,7,6,7,6,8,7,8,7,8,7,9,8,9,9,9,9,10,10,10,11,9,12,9,12,9,15,10,14,9,13,10,13,10,12,10,12,10,13,10,12,11,13,11,14,12,13,13,14,14,13,14,15,14,16,13,13,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,15,1,5,5,5,5,5,5,5,6,5,6,5,6,5,6,5,6,6,7,7,7,7,8,7,8,8,9,8,10,9,10,9,8,5,8,4,9,4,9,4,9,4,9,4,9,4,9,4,9,4,9,4,9,4,8,4,8,4,9,5,9,5,9,5,9,5,9,6,10,6,10,7,10,8,11,9,11,11,12,13,12,14,13,15,13,15,14,16,14,17,15,17,15,15,16,16,15,16,16,16,15,18,16,15,17,17,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,2,5,5,4,5,4,5,4,5,4,6,5,6,5,6,5,6,5,7,5,7,6,8,6,8,6,8,6,9,6,9,6,5,5,5,5,6,5,6,5,6,5,6,5,6,5,6,5,6,5,6,5,6,5,6,5,7,5,7,5,7,5,7,5,8,6,8,6,8,6,9,6,9,6,10,6,10,6,11,6,11,7,11,7,12,7,12,7,12,7,12,7,12,7,12,7,12,7,12,8,13,8,12,8,12,8,13,8,13,9,13,9,13,9,13,9,12,10,12,10,13,10,14,11,14,12,14,13,14,13,14,14,15,16,15,15,15,14,15,17,21,22,22,21,22,22,22,22,22,22,21,21,21,21,21,21,21,21,21,21,2,3,7,13,4,4,7,15,8,6,9,17,21,16,15,21,2,5,7,11,5,5,7,14,9,7,10,16,17,15,16,21,4,7,10,17,7,7,9,15,11,9,11,16,21,18,15,21,18,21,21,21,15,17,17,19,21,19,18,20,21,21,21,20,2,5,5,6,6,7,7,7,7,7,7,8,8,8,8,8,8,10,6,6,7,7,8,7,8,8,8,8,8,9,9,9,9,9,10,6,6,7,7,7,7,8,8,8,8,9,9,9,9,9,9,10,7,7,7,7,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,7,7,8,8,8,9,9,9,9,9,9,9,9,9,11,11,11,8,8,8,8,9,9,9,9,9,9,9,9,9,9,10,10,10,8,8,8,8,9,9,9,9,9,9,9,9,9,9,10,10,10,8,9,9,9,9,9,9,9,9,9,9,9,10,9,10,10,10,11,11,9,9,9,9,9,9,9,9,9,9,9,9,11,10,11,11,11,9,9,9,9,9,9,10,10,9,9,10,9,11,10,11,11,11,9,9,9,9,9,9,9,9,10,10,10,9,11,11,11,11,11,9,9,9,9,10,10,9,9,9,9,10,9,11,11,11,11,11,11,11,9,9,9,9,9,9,10,10,10,10,11,11,11,11,11,11,11,10,9,10,10,9,10,9,9,10,9,11,10,10,11,11,11,11,9,10,9,9,9,9,10,10,10,10,11,11,11,11,11,11,10,10,10,9,9,10,9,10,9,10,10,10,10,11,11,11,11,11,11,11,9,9,9,9,9,10,10,10,0,0,0,0,0,0,0,1,4,4,6,6,7,7,8,7,9,9,10,10,10,10,6,5,5,7,7,8,8,10,8,11,10,12,12,13,13,6,5,5,7,7,8,8,10,9,11,11,12,12,13,12,18,8,8,8,8,9,9,10,9,11,10,12,12,13,13,18,8,8,8,8,9,9,10,10,11,11,13,12,14,13,18,11,11,9,9,10,10,11,11,11,12,13,12,13,14,18,11,11,9,8,11,10,11,11,11,11,12,12,14,13,18,18,18,10,11,10,11,12,12,12,12,13,12,14,13,18,18,18,10,11,11,9,12,11,12,12,12,13,13,13,18,18,17,14,14,11,11,12,12,13,12,14,12,14,13,18,18,18,14,14,11,10,12,9,12,13,13,13,13,13,18,18,17,16,18,13,13,12,12,13,11,14,12,14,14,17,18,18,17,18,13,12,13,10,12,11,14,14,14,14,17,18,18,18,18,15,16,12,12,13,10,14,12,14,15,18,18,18,16,17,16,14,12,11,13,10,13,13,14,15,0,0,0,0,0,0,0,1,4,4,12,12,12,12,12,12,12,12,12,12,4,9,8,12,12,12,12,12,12,12,12,12,12,2,9,7,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,0,0,0,0,0,0,0,2,4,4,5,5,6,5,5,5,5,6,4,5,5,5,6,5,5,5,5,6,6,6,5,5,0,0,0,0,0,0,0,1,4,4,6,6,7,7,8,8,9,9,10,10,6,5,5,7,7,8,8,8,8,9,9,10,10,7,5,5,7,7,8,8,8,8,9,9,11,10,0,8,8,8,8,9,9,9,9,10,10,11,11,0,8,8,8,8,9,9,9,9,10,10,11,11,0,12,12,9,9,10,10,10,10,11,11,11,12,0,13,13,9,9,10,10,10,10,11,11,12,12,0,0,0,10,10,10,10,11,11,12,12,12,12,0,0,0,10,10,10,10,11,11,12,12,12,12,0,0,0,14,14,11,11,11,11,12,12,13,13,0,0,0,14,14,11,11,11,11,12,12,13,13,0,0,0,0,0,12,12,12,12,13,13,14,13,0,0,0,0,0,13,13,12,12,13,12,14,13,0,0,0,0,0,0,0,2,4,4,6,6,7,7,7,7,8,8,10,5,5,6,6,7,7,8,8,8,8,10,5,5,6,6,7,7,8,8,8,8,10,6,6,7,7,8,8,8,8,8,8,10,10,10,7,7,8,7,8,8,8,8,10,10,10,8,8,8,8,8,8,8,8,10,10,10,7,8,8,8,8,8,8,8,10,10,10,8,8,8,8,8,8,8,8,10,10,10,10,10,8,8,8,8,8,8,10,10,10,10,10,9,9,8,8,9,8,10,10,10,10,10,8,8,8,8,8,8,0,0,0,0,0,0,0,1,4,4,7,6,6,7,6,6,4,7,7,10,9,9,11,9,9,4,7,7,10,9,9,11,9,9,7,10,10,11,11,10,12,11,11,6,9,9,11,10,10,11,10,10,6,9,9,11,10,10,11,10,10,7,11,11,11,11,11,12,11,11,6,9,9,11,10,10,11,10,10,6,9,9,11,10,10,11,10,10,0,0,0,0,0,0,0,2,3,3,6,6,7,7,8,8,8,8,9,9,10,10,11,10,0,5,5,7,7,8,8,9,9,9,9,10,10,10,10,11,11,0,5,5,7,7,8,8,9,9,9,9,10,10,10,10,11,11,0,6,6,7,7,8,8,9,9,9,9,10,10,11,11,11,11,0,0,0,7,7,8,8,9,9,9,9,10,10,11,11,11,12,0,0,0,8,8,8,8,9,9,9,9,10,10,11,11,12,12,0,0,0,8,8,8,8,9,9,9,9,10,10,11,11,12,12,0,0,0,9,9,9,9,10,10,10,10,11,10,11,11,12,12,0,0,0,0,0,9,9,10,10,10,10,11,11,11,11,12,12,0,0,0,0,0,9,8,9,9,10,10,11,11,12,12,12,12,0,0,0,0,0,8,8,9,9,10,10,11,11,12,11,12,12,0,0,0,0,0,9,10,10,10,11,11,11,11,12,12,13,13,0,0,0,0,0,0,0,10,10,10,10,11,11,12,12,13,13,0,0,0,0,0,0,0,11,11,11,11,12,12,12,12,13,13,0,0,0,0,0,0,0,11,11,11,11,12,12,12,12,13,13,0,0,0,0,0,0,0,11,11,12,12,12,12,13,13,13,13,0,0,0,0,0,0,0,0,0,12,12,12,12,13,13,13,13,0,0,0,0,0,0,0,1,3,4,6,6,7,7,9,9,0,5,5,7,7,7,8,9,9,0,5,5,7,7,8,8,9,9,0,7,7,8,8,8,8,10,10,0,0,0,8,8,8,8,10,10,0,0,0,9,9,9,9,10,10,0,0,0,9,9,9,9,10,10,0,0,0,10,10,10,10,11,11,0,0,0,0,0,10,10,11,11,0,0,0,0,0,0,0,1,5,7,21,5,8,9,21,10,9,12,20,20,16,20,20,4,8,9,20,6,8,9,20,11,11,13,20,20,15,17,20,9,11,14,20,8,10,15,20,11,13,15,20,20,20,20,20,20,20,20,20,13,20,20,20,18,18,20,20,20,20,20,20,3,6,8,20,6,7,9,20,10,9,12,20,20,20,20,20,5,7,9,20,6,6,9,20,10,9,12,20,20,20,20,20,8,10,13,20,8,9,12,20,11,10,12,20,20,20,20,20,18,20,20,20,15,17,18,20,18,17,18,20,20,20,20,20,7,10,12,20,8,9,11,20,14,13,14,20,20,20,20,20,6,9,12,20,7,8,11,20,12,11,13,20,20,20,20,20,9,11,15,20,8,10,14,20,12,11,14,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,11,16,18,20,15,15,17,20,20,17,20,20,20,20,20,20,9,14,16,20,12,12,15,20,17,15,18,20,20,20,20,20,16,19,18,20,15,16,20,20,17,17,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,2,3,3,6,6,0,0,0,0,0,4,4,6,6,0,0,0,0,0,4,4,6,6,0,0,0,0,0,5,5,6,6,0,0,0,0,0,0,0,6,6,0,0,0,0,0,0,0,7,8,0,0,0,0,0,0,0,7,7,0,0,0,0,0,0,0,9,9,0,0,0,0,2,4,3,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,4,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,4,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,6,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,7,9,9,0,0,0,0,0,0,0,2,5,5,0,0,0,5,5,0,0,0,5,5,0,0,0,7,8,0,0,0,0,0,0,0,5,6,6,0,0,0,7,7,0,0,0,7,7,0,0,0,10,10,0,0,0,0,0,0,0,5,6,6,0,0,0,7,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1471684);
/* memory initializer */ allocate([7,7,0,0,0,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,7,7,0,0,0,7,7,0,0,0,9,9,0,0,0,0,0,0,0,5,7,7,0,0,0,7,7,0,0,0,7,7,0,0,0,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,7,7,0,0,0,7,7,0,0,0,9,9,0,0,0,0,0,0,0,5,7,7,0,0,0,7,7,0,0,0,7,7,0,0,0,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,10,10,0,0,0,9,9,0,0,0,9,9,0,0,0,10,10,0,0,0,0,0,0,0,8,10,10,0,0,0,9,9,0,0,0,9,9,0,0,0,10,10,0,0,0,0,0,2,4,4,0,0,0,0,0,0,5,6,6,0,0,0,0,0,0,5,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,6,7,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,0,0,0,6,8,7,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,8,8,9,0,0,0,0,0,0,8,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,8,8,0,0,0,0,0,0,7,9,8,0,0,0,0,0,0,8,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,8,8,0,0,0,0,0,0,8,9,9,0,0,0,0,0,0,7,8,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,8,8,0,0,0,0,0,0,8,9,9,0,0,0,0,0,0,8,9,8,0,0,0,0,0,0,0,5,6,11,11,11,11,10,10,12,11,5,2,11,5,6,6,7,9,11,13,13,10,7,11,6,7,8,9,10,12,11,5,11,6,8,7,9,11,14,15,11,6,6,8,4,5,7,8,10,13,10,5,7,7,5,5,6,8,10,11,10,7,7,8,6,5,5,7,9,9,11,8,8,11,8,7,6,6,7,9,12,11,10,13,9,9,7,7,7,9,11,13,12,15,12,11,9,8,8,8,0,0,0,0,2,5,2,6,3,6,4,7,4,7,5,9,5,11,6,11,6,11,7,11,6,11,6,11,9,11,8,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,10,10,10,10,10,10,0,0,4,2,4,2,5,3,5,4,6,6,6,7,7,8,7,8,7,8,7,9,8,9,8,9,8,10,8,11,9,12,9,12,4,5,4,5,4,5,4,5,3,5,3,5,3,5,4,5,4,0,0,0,0,0,0,0,3,7,3,8,3,10,3,8,3,9,3,8,4,9,4,9,5,9,6,10,6,9,7,11,7,12,9,13,10,13,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,0,0,3,3,4,3,4,4,4,4,5,5,5,5,5,6,5,7,5,8,6,8,6,9,7,10,7,10,8,10,8,11,9,11,1,4,2,6,3,7,5,7,2,10,8,14,7,12,11,14,1,5,3,7,4,9,7,13,253,1,9,0,253,0,8,0,125,0,7,0,61,0,6,0,29,0,5,0,13,0,4,0,5,0,3,0,0,0,1,0,4,0,3,0,12,0,4,0,28,0,5,0,60,0,6,0,124,0,7,0,252,0,8,0,252,1,9,0,255,0,8,0,17,18,0,1,2,3,4,5,16,6,7,8,9,10,11,12,13,14,15,0,0,0,0,0,243,4,53,63,240,55,24,63,0,0,0,63,0,0,0,0,176,13,29,0,64,190,28,0,80,187,35,0,32,98,35,0,56,12,35,0,224,201,34,0,152,142,34,0,0,84,34,0,168,31,34,0,112,237,33,0,176,117,33,0,108,0,0,0,160,135,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,3,3,4,4,5,6,34,36,35,69,135,232,9,16,10,24,11,23,12,16,13,10,14,8,15,8,16,8,17,20,16,10,207,206,205,236,11,8,10,21,9,23,8,8,199,70,69,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,36,37,38,39,40,41,75,76,77,110,239,144,81,82,83,84,85,118,183,56,57,88,89,56,89,154,57,58,57,26,141,57,56,58,57,58,57,184,119,214,245,116,83,82,49,80,79,78,77,44,75,41,40,39,38,37,36,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,9,5,12,10,35,32,29,27,50,48,45,44,41,39,37,73,70,68,65,64,61,58,56,53,50,49,46,44,41,38,36,68,65,63,61,58,55,53,51,48,46,45,43,41,39,38,36,35,33,32,30,29,27,26,25,48,47,46,44,43,41,40,39,37,36,35,34,32,31,30,28,27,26,24,23,22,20,19,37,35,34,33,31,30,29,27,26,24,23,21,20,18,17,15,29,27,26,24,22,21,19,17,16,14,26,25,23,21,19,18,16,15,27,25,23,21,19,17,16,14,26,25,23,21,18,17,14,12,17,19,13,4,9,2,11,1,7,8,0,16,3,14,6,12,10,5,15,18,11,10,13,15,16,19,20,22,24,27,15,18,20,22,24,26,14,17,20,22,24,27,15,18,20,23,25,28,16,19,22,25,28,32,36,21,25,29,33,38,42,45,49,28,31,34,37,40,42,44,47,49,50,52,54,56,57,59,60,62,64,66,67,69,35,37,39,40,42,43,45,47,48,51,52,54,55,57,59,60,62,63,66,67,69,71,72,38,40,42,43,46,47,49,51,26,28,30,31,33,34,18,19,11,13,7,8,3,1,2,2,2,2,3,3,7,5,7,5,8,6,11,9,7,13,11,10,9,8,7,5,9,7,6,4,7,5,8,7,11,8,13,11,19,15,22,23,20,33,32,28,27,29,51,77,43,45,76,81,46,82,75,55,56,144,58,80,60,74,147,63,143,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,27,30,21,22,17,14,5,6,100,54,47,50,51,53,106,107,108,109,110,111,112,113,114,115,4,117,118,92,94,121,122,3,124,103,2,1,0,129,130,131,120,119,126,125,136,137,138,139,140,141,142,134,135,132,133,104,64,101,62,57,102,95,93,59,61,28,97,96,52,49,48,29,32,25,24,46,23,98,45,44,43,20,42,41,19,18,99,40,15,39,38,16,13,12,11,37,10,9,8,36,7,128,127,105,123,116,35,34,33,145,31,79,42,146,78,26,83,48,49,50,44,47,26,31,30,18,17,19,21,24,25,13,14,16,17,18,20,21,12,14,15,9,10,6,9,6,5,8,6,12,8,10,7,9,6,4,6,2,2,3,3,3,3,2,144,124,35,0,108,0,0,0,0,136,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,137,51,147,176,155,131,163,187,170,98,177,132,183,44,189,98,194,49,199,160,203,182,207,122,211,244,214,39,218,27,221,212,223,87,226,167,228,201,230,193,232,145,234,61,236,200,237,52,239,132,240,185,241,214,242,221,243,207,244,175,245,125,246,59,247,234,247,140,248,33,249,170,249,41,250,157,250,9,251,108,251,200,251,28,252,106,252,177,252,243,252,48,253,105,253,156,253,204,253,248,253,33,254,70,254,105,254,136,254,166,254,193,254,218,254,241,254,6,255,26,255,44,255,60,255,75,255,90,255,103,255,115,255,126,255,136,255,145,255,154,255,162,255,169,255,176,255,182,255,188,255,194,255,198,255,203,255,207,255,211,255,215,255,218,255,221,255,224,255,226,255,229,255,231,255,233,255,235,255,236,255,238,255,239,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,17,0,18,0,20,0,21,0,23,0,25,0,27,0,30,0,32,0,35,0,38,0,41,0,45,0,49,0,53,0,58,0,62,0,68,0,74,0,80,0,87,0,94,0,102,0,111,0,120,0,130,0,141,0,153,0,166,0,181,0,196,0,212,0,230,0,250,0,15,1,38,1,63,1,90,1,120,1,151,1,186,1,223,1,8,2,52,2,100,2,151,2,208,2,13,3,79,3,150,3,228,3,56,4,148,4,247,4,99,5,215,5,86,6,223,6,116,7,22,8,197,8,131,9,81,10,49,11,35,12,42,13,71,14,124,15,204,16,56,18,195,19,111,21,63,23,55,25,89,27,169,29,44,32,229,34,217,37,12,41,134,44,74,48,96,52,207,56,158,61,212,66,124,72,158,78,69,85,125,92,80,100,205,108,2,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,25,191,195,245,8,191,195,245,168,190,164,112,61,190,92,143,194,189,158,239,39,189,30,167,104,188,179,123,114,187,154,153,25,191,195,245,8,191,195,245,168,190,164,112,61,190,92,143,194,189,158,239,39,189,30,167,104,188,179,123,114,187,192,89,31,0,152,166,30,0,0,17,30,0,200,160,29,0,104,66,29,0,16,241,28,0,232,234,35,0,168,156,35,0,20,28,36,44,52,60,68,76,84,92,100,106,112,116,120,124,128,132,136,140,144,150,156,164,172,180,188,196,204,212,220,228,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,34,0,0,0,35,0,0,0,35,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,37,0,0,0,17,18,24,47,99,99,99,99,18,21,26,66,99,99,99,99,24,26,56,99,99,99,99,99,47,66,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,9,9,12,24,50,50,50,50,9,11,13,33,50,50,50,50,12,13,28,50,50,50,50,50,24,33,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,1,1,1,255,1,1,1,2,1,255,2,1,1,3,1,255,3,1,1,4,1,255,4,1,1,5,1,255,5,1,1,6,1,255,6,1,1,7,1,255,7,1,2,1,2,254,1,2,1,8,1,255,8,1,1,9,1,255,9,1,1,10,1,255,10,1,1,11,1,255,11,1,1,12,1,255,12,1,1,13,1,255,13,1,1,14,1,255,14,1,1,15,1,255,15,1,3,1,3,253,1,3,1,16,1,255,16,1,1,17,1,255,17,1,1,18,1,255,18,1,1,19,1,255,19,1,1,20,1,255,20,1,1,21,1,255,21,1,1,22,1,255,22,1,2,2,2,254,2,2,1,23,1,255,23,1,1,24,1,255,24,1,1,25,1,255,25,1,4,1,3,252,1,3,0,0,0,0,5,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,255,2,0,0,0,0,0,0,0,25,0,0,0,0,0,0,1,1,0,255,1,0,1,2,0,255,2,0,2,1,1,254,1,1,1,3,0,255,3,0,1,4,0,255,4,0,1,5,0,255,5,0,1,6,0,255,6,0,3,1,2,253,1,2,1,7,0,255,7,0,1,8,0,255,8,0,2,2,1,254,2,1,1,9,0,255,9,0,1,10,0,255,10,0,1,11,0,255,11,0,4,1,2,252,1,2,1,12,0,255,12,0,1,13,0,255,13,0,1,14,0,255,14,0,2,3,1,254,3,1,1,15,0,255,15,0,2,4,1,254,4,1,5,1,3,251,1,3,3,2,2,253,2,2,1,16,0,255,16,0,1,17,0,255,17,0,1,18,0,255,18,0,2,5,1,254,5,1,1,19,0,255,19,0,1,20,0,255,20,0,0,6,4,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,255,255,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,1,1,0,255,1,0,0,0,0,2,1,0,254,1,0,1,2,0,255,2,0,3,1,1,253,1,1,1,3,0,255,3,0,4,1,1,252,1,1,2,2,0,254,2,0,1,4,0,255,4,0,5,1,2,251,1,2,1,5,0,255,5,0,3,2,1,253,2,1,2,3,0,254,3,0,1,6,0,255,6,0,6,1,2,250,1,2,1,7,0,255,7,0,2,4,0,254,4,0,7,1,2,249,1,2,1,8,0,255,8,0,4,2,1,252,2,1,1,9,0,255,9,0,3,3,1,253,3,1,2,5,0,254,5,0,2,6,0,254,6,0,8,1,2,248,1,2,1,10,0,255,10,0,1,11,0,255,11,0,9,1,2,247,1,2,5,2,2,251,2,2,3,4,1,253,4,1,0,10,6,4,4,3,3,2,2,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,2,0,0,0,11,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,1,2,0,255,2,0,5,1,1,251,1,1,2,2,0,254,2,0,6,1,1,250,1,1,1,3,0,255,3,0,7,1,1,249,1,1,3,2,0,253,2,0,8,1,1,248,1,1,1,4,0,255,4,0,2,3,0,254,3,0,9,1,1,247,1,1,4,2,0,252,2,0,1,5,0,255,5,0,10,1,1,246,1,1,3,3,0,253,3,0,5,2,1,251,2,1,2,4,0,254,4,0,11,1,1,245,1,1,1,6,0,255,6,0,12,1,1,244,1,1,1,7,0,255,7,0,6,2,1,250,2,1,13,1,1,243,1,1,2,5,0,254,5,0,1,8,0,255,8,0,0,14,7,4,3,3,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,4,0,0,0,8,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,7,1,0,249,1,0,8,1,0,248,1,0,1,2,0,255,2,0,9,1,0,247,1,0,10,1,0,246,1,0,11,1,0,245,1,0,2,2,0,254,2,0,12,1,0,244,1,0,13,1,0,243,1,0,3,2,0,253,2,0,14,1,0,242,1,0,1,3,0,255,3,0,15,1,0,241,1,0,4,2,0,252,2,0,16,1,0,240,1,0,17,1,0,239,1,0,5,2,0,251,2,0,1,4,0,255,4,0,2,3,0,254,3,0,18,1,0,238,1,0,6,2,0,250,2,0,19,1,0,237,1,0,1,5,0,255,5,0,0,20,7,3,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,255,255,255,127,5,0,0,0,1,2,3,3,1,2,2,0,1,1,0,0,0,0,0,0,1,1,1,0,1,1,0,0,1,0,0,0,0,0,0,0,0,16,32,48,0,0,0,0,0,16,32,48,0,0,0,0,0,16,32,48,0,0,0,0,2,0,0,0,6,1,0,0,6,6,3,0,6,7,7,6,6,8,8,7,0,0,0,0,1,0,0,0,7,1,0,0,4,6,1,0,3,3,2,5,2,3,2,0,0,0,0,0,0,0,0,0,3,0,0,0,5,0,0,0,0,0,0,0,1,1,0,255,255,255,0,1,0,1,1,1,0,255,255,255,1,3,3,4,4,4,5,5,3,2,3,3,3,3,3,0,3,3,2,2,3,3,0,0,3,2,2,2,3,0,0,0,2,2,2,2,0,0,0,0,2,2,1,0,0,0,0,0,1,1,0,0,0,0,0,0,1,2,3,2,3,1,1,0,0,1,1,4,5,6,7,0,0,1,1,2,6,7,0,0,6,0,1,2,7,0,0,0,0,1,2,3,0,0,0,0,0,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,32,16,64,96,48,80,112,0,32,16,64,96,48,80,112,1,0,0,0,7,2,0,0,7,7,3,0,9,7,7,5,9,9,7,6,10,10,9,7,11,11,10,7,12,12,11,10,13,12,12,11,0,0,0,0,1,0,0,0,15,1,0,0,14,13,1,0,7,12,11,1,6,5,10,1,7,6,4,9,7,6,5,8,7,6,5,4,7,5,4,4,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,33,16,66,32,99,48,132,64,165,80,198,96,231,112,8,129,41,145,74,161,107,177,140,193,173,209,206,225,239,241,49,18,16,2,115,50,82,34,181,82,148,66,247,114,214,98,57,147,24,131,123,179,90,163,189,211,156,195,255,243,222,227,98,36,67,52,32,4,1,20,230,100,199,116,164,68,133,84,106,165,75,181,40,133,9,149,238,229,207,245,172,197,141,213,83,54,114,38,17,22,48,6,215,118,246,102,149,86,180,70,91,183,122,167,25,151,56,135,223,247,254,231,157,215,188,199,196,72,229,88,134,104,167,120,64,8,97,24,2,40,35,56,204,201,237,217,142,233,175,249,72,137,105,153,10,169,43,185,245,90,212,74,183,122,150,106,113,26,80,10,51,58,18,42,253,219,220,203,191,251,158,235,121,155,88,139,59,187,26,171,166,108,135,124,228,76,197,92,34,44,3,60,96,12,65,28,174,237,143,253,236,205,205,221,42,173,11,189,104,141,73,157,151,126,182,110,213,94,244,78,19,62,50,46,81,30,112,14,159,255,190,239,221,223,252,207,27,191,58,175,89,159,120,143,136,145,169,129,202,177,235,161,12,209,45,193,78,241,111,225,128,16,161,0,194,48,227,32,4,80,37,64,70,112,103,96,185,131,152,147,251,163,218,179,61,195,28,211,127,227,94,243,177,2,144,18,243,34,210,50,53,66,20,82,119,98,86,114,234,181,203,165,168,149,137,133,110,245,79,229,44,213,13,197,226,52,195,36,160,20,129,4,102,116,71,100,36,84,5,68,219,167,250,183,153,135,184,151,95,231,126,247,29,199,60,215,211,38,242,54,145,6,176,22,87,102,118,118,21,70,52,86,76,217,109,201,14,249,47,233,200,153,233,137,138,185,171,169,68,88,101,72,6,120,39,104,192,24,225,8,130,56,163,40,125,203,92,219,63,235,30,251,249,139,216,155,187,171,154,187,117,74,84,90,55,106,22,122,241,10,208,26,179,42,146,58,46,253,15,237,108,221,77,205,170,189,139,173,232,157,201,141,38,124,7,108,100,92,69,76,162,60,131,44,224,28,193,12,31,239,62,255,93,207,124,223,155,175,186,191,217,143,248,159,23,110,54,126,85,78,116,94,147,46,178,62,209,14,240,30,13,0,13,0,14,14,1,1,12,11,10,2,13,3,13,3,4,4,4,4,5,5,5,5,6,6,6,6,13,7,13,7,14,14,8,8,14,0,1,9,24,0,0,0,25,0,0,0,30,0,0,0,50,0,0,0,60,0,0,0,0,0,0,0,117,116,102,56,0,0,200,119,99,104,97,114,116,0,0,198,117,99,115,50,0,117,99,115,50,98,101,0,0,196,117,99,115,50,108,101,0,0,197,117,116,102,49,54,0,117,116,102,49,54,98,101,0,0,194,117,116,102,49,54,108,101,0,0,193,117,99,115,52,0,117,99,115,52,98,101,0,117,116,102,51,50,0,117,116,102,51,50,98,101,0,0,192,117,99,115,52,108,101,0,117,116,102,51,50,108,101,0,0,195,97,115,99,105,105,0,117,115,97,115,99,105,105,0,105,115,111,54,52,54,0,105,115,111,54,52,54,117,115,0,0,199,101,117,99,106,112,0,0,208,115,104,105,102,116,106,105,115,0,115,106,105,115,0,0,209,103,98,49,56,48,51,48,0,0,216,103,98,107,0,0,217,103,98,50,51,49,50,0,0,218,98,105,103,53,0,98,105,103,102,105,118,101,0,99,112,57,53,48,0,98,105,103,53,104,107,115,99,115,0,0,224,101,117,99,107,114,0,107,115,99,53,54,48,49,0,107,115,120,49,48,48,49,0,99,112,57,52,57,0,0,232,105,115,111,56,56,53,57,49,0,108,97,116,105,110,49,0,0,128,105,115,111,56,56,53,57,50,0,0,32,0,84,0,137,18,0,32,1,6,0,0,152,65,134,26,127,0,48,72,32,0,88,32,201,18,0,36,17,198,35,0,156,81,198,26,128,80,66,136,32,90,0,0,192,4,0,16,113,1,0,29,0,112,2,0,41,0,0,192,7,33,48,1,5,0,0,88,1,0,0,94,208,1,128,29,0,0,128,6,0,91,0,0,0,5,0,20,129,1,0,30,0,128,2,0,42,0,0,0,8,34,52,17,5,0,0,92,1,0,0,95,212,1,192,29,0,0,144,70,36,105,115,111,56,56,53,57,51,0,0,32,0,212,0,9,0,0,4,48,3,0,0,244,64,70,11,63,0,16,64,32,0,216,0,0,0,0,0,64,3,0,0,248,80,134,11,64,0,16,128,32,0,0,0,64,0,0,108,144,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,188,0,0,0,43,0,0,0,0,0,200,33,6,0,0,0,0,64,0,0,112,160,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,192,0,0,0,44,0,0,0,0,0,204,49,70,36,105,115,111,56,56,53,57,52,0,0,32,0,84,48,4,23,0,220,96,4,0,0,152,49,66,12,108,0,48,8,0,0,88,32,73,23,0,224,112,196,35,0,156,65,130,12,109,72,65,200,20,17,0,0,0,0,0,0,0,192,14,29,0,112,2,0,37,0,0,64,14,33,56,65,69,16,0,0,0,0,0,0,224,1,0,0,0,184,1,7,0,18,0,0,0,0,0,0,0,0,15,30,0,128,2,0,38,0,0,128,14,34,60,81,133,16,0,0,0,0,0,0,228,1,0,0,0,188,17,71,36,105,115,111,56,56,53,57,53,0,0,32,0,136,51,14,57,229,152,115,14,58,233,168,179,14,59,237,0,224,206,59,240,196,35,207,60,244,212,99,207,61,248,228,163,207,62,252,244,227,207,63,0,5,36,208,64,4,21,100,208,65,8,37,164,208,66,12,53,228,208,67,16,69,36,209,68,20,85,100,209,69,24,101,164,209,70,28,117,228,209,71,32,133,36,210,72,36,149,100,210,73,40,165,164,210,74,44,181,228,210,75,53,194,20,147,76,51,209,84,147,77,55,225,148,147,78,59,13,192,83,79,105,115,111,56,56,53,57,54,0,0,32,0,4,16,64,0,0,4,16,64,0,1,4,16,64,0,115,1,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,0,93,1,4,16,64,93,1,216,117,23,94,121,233,181,23,95,125,249,245,23,96,129,9,54,24,97,133,25,118,24,98,137,41,182,24,99,141,57,246,88,0,1,4,16,64,0,144,69,38,217,100,148,85,102,217,101,152,101,166,217,102,156,117,230,217,103,160,133,38,90,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,105,115,111,56,56,53,57,55,0,0,32,0,144,88,34,0,51,210,8,0,0,0,0,160,9,0,0,0,16,128,136,0,0,0,0,0,155,112,210,9,0,158,124,2,10,0,161,0,32,202,40,164,148,98,202,41,168,164,162,202,42,172,180,226,202,43,176,196,34,203,44,180,212,18,128,45,183,224,146,139,46,187,240,210,139,47,191,0,19,140,48,195,16,83,140,49,199,32,147,140,50,203,48,211,140,51,207,64,19,141,52,211,80,83,141,53,215,96,147,141,54,219,112,211,141,55,223,128,19,78,0,105,115,111,56,56,53,57,56,0,0,32,0,4,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,192,136,83,81,85,149,85,87,97,149,149,86,91,113,213,149,87,95,129,21,150,88,99,145,85,150,89,103,161,149,150,90,107,177,213,86,0,1,120,248,97,0,105,115,111,56,56,53,57,57,0,0,80,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,80,6,0,105,115,111,56,56,53,57,49,48,0,0,32,0,84,48,66,12,57,220,16,4,0,70,132,96,6,27,131,0,0,135,20,0,88,64,130,12,58,224,32,4,0,71,136,112,70,27,132,136,24,199,20,17,0,0,0,0,0,0,0,192,14,29,0,112,2,0,37,0,0,0,0,0,56,65,5,0,0,0,0,128,27,0,224,1,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,15,30,0,128,2,0,38,0,0,0,0,0,60,81,5,0,0,0,0,192,27,0,228,1,0,0,0,0,0,192,16,105,115,111,56,56,53,57,49,49,0,116,105,115,54,50,48,0,0,32,0,188,6,91,108,178,205,70,91,109,182,221,134,91,110,186,237,198,91,111,190,253,6,92,112,194,13,71,92,113,198,29,135,92,114,202,45,199,92,115,206,61,7,93,116,210,77,71,93,117,214,93,135,93,118,218,109,199,93,119,222,125,7,94,120,226,141,71,94,121,230,157,135,94,0,1,4,16,64,122,234,173,199,94,123,238,189,7,95,124,242,205,71,95,125,246,221,135,95,126,250,237,199,95,127,254,253,7,96,128,2,14,72,96,129,1,4,16,64,0,105,115,111,56,56,53,57,49,51,0,0,32,0,160,8,0,0,0,164,8,0,0,13,0,192,5,0,0,0,0,192,2,0,0,0,0,0,39,2,0,0,0,16,0,208,5,0,0,0,0,128,3,21,236,16,193,5,0,0,112,194,8,29,0,240,71,9,49,4,145,131,17,102,48,225,4,0,84,0,0,0,0,120,40,1,6,28,0,4,50,8,0,22,240,32,1,6,0,0,128,2,9,30,0,0,136,9,50,8,161,195,17,103,52,241,4,0,85,0,0,0,0,121,44,17,70,28,0,8,66,72,137,105,115,111,56,56,53,57,49,52,0,0,32,0,24,120,32,0,27,112,128,32,0,20,2,96,97,130,26,2,0,128,31,10,46,248,2,12,12,54,8,128,131,21,62,120,33,132,27,98,152,97,132,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,0,0,0,0,0,0,0,128,132,0,0,0,0,0,0,0,192,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,0,0,0,0,0,0,0,192,132,0,0,0,0,0,0,0,208,7,0,105,115,111,56,56,53,57,49,53,0,108,97,116,105,110,57,0,0,36,51,2,96,6,0,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,131,0,0,0,0,132,0,0,0,0,88,100,225,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,115,111,56,56,53,57,49,54,0,0,32,0,84,96,129,18,51,166,104,6,0,103,0,160,8,0,127,0,0,72,32,0,0,208,193,18,131,160,8,0,0,132,120,176,8,0,88,100,225,135,32,0,0,0,192,4,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,33,48,1,0,0,0,88,1,0,24,118,0,0,0,0,0,156,192,8,0,0,0,0,0,5,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,34,52,1,0,0,0,92,1,64,24,119,0,0,0,0,0,160,208,8,0,99,112,49,50,53,48,0,119,105,110,100,111,119,115,49,50,53,48,0,0,0,51,6,96,98,0,41,182,168,226,138,1,184,104,198,139,96,168,49,200,31,1,144,88,226,137,40,178,8,98,136,1,216,120,6,140,97,172,65,8,32,0,60,2,137,18,0,84,0,0,0,0,0,64,6,0,0,0,0,64,32,0,0,32,201,18,0,0,0,0,0,0,88,80,6,0,72,80,146,132,32,90,0,0,192,4,0,16,113,1,0,29,0,112,2,0,41,0,0,192,7,33,48,1,5,0,0,88,1,0,0,94,208,1,128,29,0,0,128,6,0,91,0,0,0,5,0,20,129,1,0,30,0,128,2,0,42,0,0,0,8,34,52,17,5,0,0,92,1,0,0,95,212,1,192,29,0,0,144,70,36,99,112,49,50,53,49,0,119,105,110,100,111,119,115,49,50,53,49,0,0,0,227,144,99,162,76,41,182,168,226,138,51,186,168,206,139,235,180,195,206,59,49,145,88,226,137,40,178,8,98,136,1,216,136,19,140,57,237,164,83,79,0,184,195,83,58,0,248,4,0,0,226,0,80,14,0,0,0,0,0,58,0,0,112,78,77,63,1,0,0,0,48,213,56,19,0,55,153,67,147,77,240,196,35,207,60,244,212,99,207,61,248,228,163,207,62,252,244,227,207,63,0,5,36,208,64,4,21,100,208,65,8,37,164,208,66,12,53,228,208,67,16,69,36,209,68,20,85,100,209,69,24,101,164,209,70,28,117,228,209,71,32,133,36,210,72,36,149,100,210,73,40,165,164,210,74,44,181,228,210,75,99,112,49,50,53,50,0,119,105,110,100,111,119,115,49,50,53,50,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,104,198,139,88,4,48,72,0,1,144,88,226,137,40,178,8,98,136,147,216,120,6,140,89,4,64,136,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,112,49,50,53,51,0,119,105,110,100,111,119,115,49,50,53,51,0,0,0,51,6,96,98,33,41,182,168,226,138,1,184,24,192,139,1,4,16,64,0,1,144,88,226,137,40,178,8,98,136,1,216,24,0,140,1,4,16,64,0,0,112,210,9,0,0,0,0,0,0,0,0,16,0,0,0,0,0,128,136,0,0,0,0,0,155,0,0,0,0,158,124,2,10,0,161,0,32,202,40,164,148,98,202,41,168,164,162,202,42,172,180,226,202,43,176,196,34,203,44,180,212,18,128,45,183,224,146,139,46,187,240,210,139,47,191,0,19,140,48,195,16,83,140,49,199,32,147,140,50,203,48,211,140,51,207,64,19,141,52,211,80,83,141,53,215,96,147,141,54,219,112,211,141,55,223,128,19,78,0,99,112,49,50,53,52,0,119,105,110,100,111,119,115,49,50,53,52,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,104,198,139,88,4,16,64,0,1,144,88,226,137,40,178,8,98,136,147,216,120,6,140,89,4,16,128,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,80,6,0,99,112,49,50,53,53,0,119,105,110,100,111,119,115,49,50,53,53,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,24,192,139,1,4,16,64,0,1,144,88,226,137,40,178,8,98,136,147,216,24,0,140,1,4,16,64,0,0,0,0,0,0,49,2,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,64,5,37,212,80,68,21,101,212,81,72,37,21,128,82,75,49,213,148,83,79,65,21,149,84,110,189,5,87,92,114,5,16,64,0,1,4,16,64,0,83,81,85,149,85,87,97,149,149,86,91,113,213,149,87,95,129,21,150,88,99,145,85,150,89,103,161,149,150,90,107,177,213,86,0,1,120,248,97,0,99,112,49,50,53,54,0,119,105,110,100,111,119,115,49,50,53,54,0,0,0,51,146,102,98,33,41,182,168,226,138,142,184,56,218,139,88,148,134,154,105,170,145,88,226,137,40,178,8,98,136,169,217,120,26,140,89,112,216,225,106,0,204,5,0,0,0,0,0,0,0,0,0,192,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,23,0,0,0,0,64,93,173,217,117,23,94,121,233,181,23,95,125,249,245,23,96,129,9,54,24,97,133,25,118,24,98,137,41,182,24,0,140,53,230,216,99,144,69,38,217,100,0,80,6,64,101,150,93,134,25,0,0,0,0,0,0,153,105,6,0,0,155,113,214,153,103,0,124,6,26,0,161,1,32,26,0,0,120,248,161,107,99,112,49,50,53,55,0,119,105,110,100,111,119,115,49,50,53,55,0,0,0,51,6,96,98,0,41,182,168,226,138,1,184,24,192,139,1,16,240,136,2,1,144,88,226,137,40,178,8,98,136,1,216,24,0,140,1,24,32,73,0,0,4,0,0,0,0,4,0,0,0,13,0,192,5,0,0,0,0,192,2,0,0,0,0,0,0,0,0,0,0,16,0,208,5,0,0,0,0,128,3,21,236,16,193,5,0,0,112,194,8,29,0,240,71,9,49,4,145,131,17,102,48,225,4,0,84,0,0,0,0,120,40,1,6,28,0,4,50,8,0,22,240,32,1,6,0,0,128,2,9,30,0,0,136,9,50,8,161,195,17,103,52,241,4,0,85,0,0,0,0,121,44,17,70,28,0,8,66,72,36,99,112,49,50,53,56,0,119,105,110,100,111,119,115,49,50,53,56,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,24,192,139,88,4,16,64,0,1,144,88,226,137,40,178,8,98,136,147,216,24,0,140,89,4,16,128,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,4,0,0,0,0,0,0,0,0,0,0,149,0,0,0,0,33,0,128,9,0,0,24,2,0,0,0,0,0,0,0,0,32,114,9,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,150,0,0,0,0,34,0,144,9,0,0,28,2,0,0,0,0,0,0,0,0,36,34,35,0,107,111,105,56,114,0,0,0,62,254,8,100,144,66,14,73,100,145,70,30,137,164,153,103,162,153,166,154,107,178,217,38,143,110,222,136,99,142,58,238,40,64,143,7,32,144,192,3,73,42,185,36,76,76,54,233,228,147,80,70,41,229,148,84,86,105,229,149,88,102,169,165,56,91,114,217,165,151,95,130,25,166,152,99,146,89,102,1,46,65,20,145,73,20,85,68,210,68,37,97,148,145,70,27,113,212,145,71,31,189,4,82,72,34,141,100,145,68,44,173,116,17,74,45,165,116,146,74,14,193,19,143,65,244,212,67,208,60,5,225,147,143,62,251,240,211,143,63,255,60,4,80,64,2,13,100,143,60,12,45,116,15,66,13,37,116,144,66,107,111,105,56,117,0,0,0,62,254,8,100,144,66,14,73,100,145,70,30,137,164,153,103,162,153,166,154,107,178,217,38,143,110,222,136,99,142,58,238,40,64,143,7,32,144,192,3,73,42,185,36,76,51,53,89,147,77,80,70,41,229,148,84,254,100,229,149,88,102,169,165,56,229,112,121,14,58,95,130,25,166,152,99,250,84,102,1,46,65,20,145,73,20,85,68,210,68,37,97,148,145,70,27,113,212,145,71,31,189,4,82,72,34,141,100,145,68,44,173,116,17,74,45,165], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1481925);
/* memory initializer */ allocate([116,146,74,14,193,19,143,65,244,212,67,208,60,5,225,147,143,62,251,240,211,143,63,255,60,4,80,64,2,13,100,143,60,12,45,116,15,66,13,37,116,144,66,0,0,0,0,0,0,0,0,232,214,31,0,32,14,31,0,16,0,0,0,5,0,0,0,192,95,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,26,31,0,108,0,0,0,0,197,22,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,201,28,0,168,197,35,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,184,112,35,0,96,23,35,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,99,104,97,110,110,101,108,32,109,97,112,10,0,0,0,0,112,29,31,0,108,0,0,0,144,197,22,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,30,0,104,236,29,0,160,127,29,0,24,38,29,0,176,214,28,0,16,209,35,0,128,129,35,0,16,36,35,0,248,221,34,0,120,161,34,0,32,101,34,0,240,45,34,0,208,254,33,0,136,209,33,0,136,171,33,0,184,140,33,0,24,106,33,0,72,40,33,0,104,3,33,0,104,232,32,0,176,205,32,0,224,178,32,0,176,157,32,0,152,131,32,0,208,106,32,0,88,85,32,0,64,60,32,0,56,5,32,0,48,237,31,0,96,216,31,0,144,198,31,0,240,175,31,0,184,157,31,0,64,139,31,0,168,122,31,0,16,108,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,87,31,0,168,45,31,0,248,27,31,0,136,15,31,0,160,0,31,0,24,240,30,0,144,226,30,0,64,213,30,0,96,198,30,0,248,182,30,0,120,164,30,0,56,125,30,0,64,110,30,0,88,97,30,0,152,83,30,0,1,0,0,0,4,0,0,0,0,0,0,0,40,67,30,0,2,0,0,0,3,0,0,0,0,0,0,0,232,55,30,0,3,0,0,0,11,0,0,0,0,0,0,0,8,45,30,0,3,0,0,0,7,0,0,0,0,0,0,0,16,35,30,0,3,0,0,0,3,1,0,0,0,0,0,0,200,27,30,0,4,0,0,0,7,1,0,0,0,0,0,0,200,15,30,0,4,0,0,0,51,0,0,0,0,0,0,0,208,237,29,0,4,0,0,0,3,6,0,0,0,0,0,0,136,228,29,0,4,0,0,0,15,0,0,0,0,0,0,0,88,220,29,0,5,0,0,0,55,0,0,0,0,0,0,0,120,211,29,0,5,0,0,0,7,6,0,0,0,0,0,0,176,202,29,0,5,0,0,0,15,1,0,0,0,0,0,0,48,194,29,0,6,0,0,0,63,0,0,0,0,0,0,0,128,186,29,0,6,0,0,0,15,6,0,0,0,0,0,0,16,179,29,0,6,0,0,0,7,7,0,0,0,0,0,0,80,171,29,0,6,0,0,0,195,6,0,0,0,0,0,0,208,159,29,0,6,0,0,0,55,1,0,0,0,0,0,0,8,129,29,0,7,0,0,0,15,7,0,0,0,0,0,0,8,129,29,0,7,0,0,0,63,1,0,0,0,0,0,0,152,120,29,0,7,0,0,0,203,6,0,0,0,0,0,0,72,113,29,0,7,0,0,0,55,6,0,0,0,0,0,0,88,106,29,0,7,0,0,0,199,6,0,0,0,0,0,0,200,99,29,0,8,0,0,0,63,6,0,0,0,0,0,0,16,94,29,0,8,0,0,0,255,0,0,0,0,0,0,0,152,87,29,0,8,0,0,0,207,6,0,0,0,0,0,0,24,81,29,0,8,0,0,0,55,7,0,0,0,0,0,0,232,73,29,0,2,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,2,0,3,0,0,2,0,3,0,0,2,0,4,3,0,2,0,6,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,2,0,3,0,0,2,0,3,0,0,2,0,4,3,0,2,0,6,4,3,0,0,4,0,3,0,7,0,7,1,7,6,15,6,63,6,0,0,4,0,3,0,7,0,7,1,7,6,15,6,63,6,3,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,192,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,192,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,6,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,1,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,48,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,1,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,3,5,7,0,2,4,6,0,3,4,7,0,11,13,15,0,10,12,14,0,11,12,15,0,64,59,63,118,62,177,61,237,60,41,60,101,59,161,58,221,57,26,57,87,56,150,55,213,54,21,54,85,53,151,52,217,51,27,51,94,50,162,49,230,48,44,48,114,47,186,46,2,46,77,45,152,44,229,43,51,43,130,42,210,41,36,41,118,40,200,39,26,39,110,38,194,37,25,37,112,36,203,35,39,35,133,34,227,33,69,33,167,32,13,32,115,31,221,30,71,30,178,29,29,29,140,28,251,27,110,27,226,26,89,26,209,25,76,25,199,24,70,24,197,23,72,23,203,22,80,22,213,21,90,21,223,20,103,20,239,19,123,19,8,19,153,18,42,18,190,17,83,17,236,16,133,16,34,16,191,15,96,15,1,15,163,14,69,14,235,13,145,13,59,13,230,12,148,12,66,12,243,11,164,11,89,11,14,11,199,10,128,10,59,10,246,9,177,9,108,9,41,9,230,8,167,8,104,8,44,8,240,7,182,7,125,7,71,7,17,7,222,6,171,6,123,6,75,6,28,6,237,5,193,5,149,5,107,5,66,5,27,5,244,4,206,4,169,4,134,4,99,4,66,4,34,4,2,4,226,3,194,3,162,3,131,3,101,3,73,3,45,3,18,3,248,2,223,2,198,2,175,2,152,2,131,2,110,2,90,2,70,2,50,2,31,2,13,2,251,1,234,1,217,1,201,1,186,1,171,1,156,1,142,1,129,1,117,1,105,1,93,1,81,1,69,1,57,1,45,1,34,1,23,1,13,1,3,1,249,0,240,0,231,0,222,0,214,0,206,0,199,0,192,0,185,0,178,0,171,0,165,0,159,0,153,0,148,0,143,0,138,0,133,0,128,0,123,0,119,0,115,0,111,0,107,0,103,0,99,0,95,0,91,0,87,0,83,0,80,0,77,0,74,0,71,0,68,0,65,0,63,0,61,0,59,0,57,0,55,0,53,0,51,0,49,0,47,0,45,0,43,0,41,0,40,0,39,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,31,0,30,0,29,0,28,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,67,63,134,62,201,61,13,61,81,60,149,59,217,58,30,58,100,57,170,56,241,55,56,55,128,54,200,53,17,53,90,52,163,51,237,50,57,50,133,49,211,48,33,48,112,47,191,46,16,46,97,45,180,44,7,44,92,43,178,42,10,42,98,41,186,40,18,40,107,39,197,38,33,38,126,37,222,36,62,36,160,35,3,35,105,34,207,33,56,33,162,32,15,32,124,31,234,30,89,30,203,29,61,29,179,28,41,28,162,27,27,27,151,26,20,26,148,25,20,25,152,24,28,24,162,23,40,23,174,22,52,22,188,21,68,21,208,20,92,20,236,19,124,19,15,19,163,18,59,18,211,17,110,17,10,17,169,16,73,16,233,15,138,15,46,15,211,14,123,14,35,14,207,13,123,13,41,13,216,12,138,12,61,12,243,11,169,11,97,11,25,11,209,10,137,10,67,10,253,9,186,9,120,9,56,9,249,8,189,8,129,8,71,8,14,8,215,7,161,7,109,7,57,7,6,7,212,6,164,6,116,6,71,6,26,6,239,5,196,5,155,5,114,5,75,5,37,5,1,5,221,4,186,4,151,4,116,4,81,4,47,4,13,4,237,3,205,3,175,3,145,3,117,3,89,3,62,3,36,3,11,3,242,2,219,2,196,2,173,2,151,2,130,2,109,2,89,2,69,2,51,2,33,2,16,2,255,1,239,1,223,1,207,1,192,1,177,1,163,1,149,1,135,1,121,1,108,1,95,1,82,1,70,1,58,1,46,1,35,1,24,1,14,1,4,1,251,0,242,0,234,0,226,0,218,0,210,0,202,0,195,0,188,0,181,0,174,0,168,0,162,0,156,0,150,0,144,0,139,0,134,0,129,0,124,0,119,0,114,0,109,0,104,0,100,0,96,0,92,0,88,0,84,0,80,0,77,0,74,0,71,0,68,0,65,0,62,0,59,0,56,0,54,0,52,0,50,0,48,0,46,0,44,0,42,0,40,0,38,0,36,0,34,0,33,0,32,0,31,0,30,0,29,0,28,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,75,63,150,62,226,61,46,61,122,60,198,59,18,59,94,58,171,57,248,56,70,56,148,55,227,54,50,54,130,53,210,52,35,52,116,51,198,50,24,50,108,49,192,48,22,48,108,47,195,46,27,46,117,45,207,44,43,44,135,43,228,42,65,42,158,41,251,40,90,40,185,39,27,39,125,38,225,37,70,37,173,36,20,36,126,35,232,34,85,34,194,33,50,33,163,32,20,32,134,31,251,30,112,30,232,29,96,29,220,28,88,28,214,27,84,27,214,26,88,26,221,25,98,25,233,24,112,24,247,23,126,23,7,23,144,22,28,22,169,21,57,21,201,20,92,20,240,19,135,19,31,19,185,18,84,18,242,17,144,17,48,17,208,16,115,16,22,16,188,15,99,15,13,15,183,14,100,14,17,14,193,13,113,13,36,13,215,12,140,12,65,12,246,11,171,11,99,11,27,11,213,10,144,10,78,10,12,10,204,9,141,9,80,9,20,9,218,8,160,8,105,8,50,8,252,7,198,7,147,7,96,7,47,7,255,6,209,6,163,6,119,6,75,6,33,6,247,5,207,5,168,5,129,5,90,5,51,5,12,5,231,4,194,4,159,4,124,4,91,4,58,4,27,4,252,3,222,3,192,3,164,3,136,3,110,3,84,3,58,3,33,3,9,3,241,2,219,2,197,2,175,2,154,2,133,2,113,2,93,2,74,2,55,2,38,2,21,2,4,2,243,1,226,1,209,1,193,1,177,1,162,1,147,1,133,1,119,1,106,1,93,1,81,1,69,1,58,1,47,1,37,1,27,1,17,1,7,1,254,0,245,0,236,0,227,0,219,0,211,0,204,0,197,0,190,0,183,0,177,0,171,0,165,0,159,0,153,0,147,0,141,0,135,0,130,0,125,0,120,0,115,0,110,0,105,0,101,0,97,0,93,0,89,0,85,0,81,0,77,0,74,0,71,0,68,0,65,0,62,0,59,0,56,0,53,0,51,0,49,0,47,0,45,0,43,0,41,0,39,0,37,0,35,0,33,0,31,0,29,0,27,0,25,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,82,63,164,62,247,61,74,61,157,60,240,59,68,59,152,58,236,57,64,57,149,56,234,55,65,55,152,54,240,53,72,53,160,52,248,51,81,51,170,50,4,50,95,49,187,48,24,48,117,47,211,46,51,46,147,45,244,44,85,44,184,43,27,43,126,42,225,41,69,41,170,40,17,40,120,39,225,38,74,38,182,37,34,37,143,36,253,35,110,35,223,34,83,34,199,33,60,33,177,32,41,32,161,31,28,31,151,30,20,30,146,29,18,29,147,28,22,28,153,27,31,27,165,26,45,26,181,25,61,25,197,24,79,24,217,23,102,23,244,22,132,22,21,22,169,21,61,21,211,20,106,20,4,20,158,19,60,19,218,18,121,18,24,18,186,17,92,17,1,17,166,16,78,16,247,15,162,15,77,15,251,14,169,14,90,14,11,14,190,13,113,13,36,13,215,12,140,12,66,12,250,11,179,11,110,11,42,11,232,10,166,10,102,10,39,10,234,9,174,9,116,9,58,9,1,9,201,8,147,8,93,8,41,8,245,7,196,7,147,7,99,7,52,7,7,7,218,6,175,6,132,6,90,6,48,6,6,6,220,5,179,5,138,5,100,5,62,5,25,5,245,4,210,4,175,4,142,4,109,4,78,4,47,4,17,4,244,3,215,3,186,3,158,3,131,3,104,3,79,3,54,3,30,3,6,3,239,2,216,2,195,2,174,2,154,2,134,2,115,2,96,2,77,2,58,2,40,2,22,2,5,2,244,1,228,1,212,1,197,1,182,1,168,1,154,1,141,1,128,1,116,1,104,1,92,1,80,1,69,1,58,1,47,1,37,1,27,1,17,1,8,1,255,0,246,0,237,0,229,0,221,0,213,0,205,0,197,0,189,0,181,0,174,0,167,0,160,0,154,0,148,0,142,0,136,0,131,0,126,0,121,0,116,0,111,0,106,0,101,0,97,0,93,0,89,0,85,0,81,0,77,0,73,0,70,0,67,0,64,0,61,0,58,0,55,0,52,0,49,0,46,0,43,0,40,0,37,0,35,0,33,0,31,0,29,0,27,0,25,0,23,0,21,0,19,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,90,63,180,62,14,62,104,61,194,60,29,60,120,59,211,58,47,58,139,57,231,56,67,56,160,55,253,54,91,54,185,53,23,53,117,52,213,51,53,51,150,50,247,49,89,49,188,48,32,48,132,47,233,46,78,46,181,45,28,45,132,44,236,43,84,43,188,42,38,42,144,41,252,40,104,40,214,39,68,39,180,38,36,38,150,37,9,37,126,36,243,35,106,35,225,34,89,34,209,33,76,33,199,32,69,32,195,31,67,31,195,30,69,30,200,29,78,29,212,28,92,28,228,27,110,27,248,26,130,26,12,26,151,25,35,25,178,24,65,24,211,23,101,23,249,22,141,22,36,22,187,21,85,21,239,20,140,20,41,20,199,19,101,19,7,19,169,18,78,18,243,17,154,17,65,17,235,16,149,16,66,16,239,15,159,15,79,15,1,15,179,14,101,14,23,14,202,13,126,13,52,13,235,12,164,12,94,12,25,12,213,11,147,11,81,11,18,11,211,10,150,10,90,10,31,10,228,9,171,9,114,9,59,9,5,9,209,8,157,8,107,8,57,8,9,8,217,7,171,7,126,7,81,7,36,7,247,6,202,6,158,6,114,6,71,6,29,6,244,5,204,5,165,5,127,5,89,5,53,5,17,5,239,4,205,4,173,4,141,4,110,4,79,4,49,4,19,4,247,3,219,3,192,3,165,3,139,3,114,3,90,3,66,3,43,3,20,3,254,2,232,2,210,2,188,2,167,2,146,2,126,2,106,2,87,2,69,2,51,2,33,2,16,2,255,1,239,1,224,1,209,1,195,1,181,1,167,1,154,1,141,1,128,1,116,1,104,1,92,1,81,1,70,1,59,1,49,1,39,1,29,1,19,1,9,1,255,0,245,0,236,0,227,0,219,0,211,0,203,0,195,0,188,0,181,0,174,0,167,0,161,0,155,0,149,0,143,0,137,0,131,0,126,0,121,0,116,0,111,0,106,0,101,0,97,0,93,0,89,0,85,0,81,0,77,0,73,0,69,0,65,0,61,0,58,0,55,0,52,0,49,0,46,0,43,0,40,0,37,0,34,0,32,0,30,0,28,0,26,0,24,0,22,0,20,0,18,0,16,0,14,0,12,0,10,0,8,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,0,0,0,0,0,0,64,232,62,209,61,186,60,164,59,143,58,122,57,103,56,84,55,67,54,52,53,38,52,25,51,15,50,5,49,255,47,249,46,245,45,241,44,242,43,244,42,250,41,1,41,14,40,27,39,44,38,62,37,87,36,112,35,144,34,176,33,214,32,252,31,34,31,72,30,115,29,159,28,211,27,7,27,68,26,129,25,195,24,6,24,82,23,158,22,242,21,70,21,162,20,255,19,93,19,187,18,34,18,138,17,249,16,105,16,225,15,89,15,214,14,85,14,219,13,97,13,238,12,124,12,14,12,160,11,50,11,196,10,90,10,241,9,143,9,46,9,212,8,122,8,37,8,208,7,129,7,51,7,234,6,162,6,96,6,30,6,221,5,156,5,96,5,36,5,237,4,183,4,133,4,84,4,37,4,247,3,205,3,163,3,125,3,87,3,51,3,15,3,235,2,199,2,165,2,132,2,102,2,72,2,45,2,18,2,249,1,224,1,202,1,180,1,160,1,140,1,122,1,104,1,87,1,70,1,54,1,39,1,25,1,11,1,255,0,243,0,232,0,221,0,211,0,201,0,192,0,183,0,174,0,166,0,158,0,150,0,142,0,134,0,126,0,119,0,112,0,106,0,100,0,95,0,90,0,85,0,80,0,76,0,72,0,69,0,66,0,63,0,60,0,57,0,54,0,51,0,48,0,46,0,44,0,42,0,40,0,38,0,36,0,34,0,33,0,32,0,31,0,30,0,29,0,28,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,244,62,233,61,222,60,212,59,202,58,193,57,185,56,177,55,171,54,166,53,164,52,162,51,163,50,164,49,169,48,174,47,180,46,186,45,196,44,207,43,223,42,239,41,4,41,25,40,50,39,75,38,107,37,139,36,176,35,213,34,255,33,41,33,83,32,125,31,173,30,221,29,20,29,76,28,139,27,202,26,15,26,84,25,161,24,239,23,68,23,153,22,246,21,83,21,178,20,17,20,119,19,222,18,76,18,187,17,49,17,167,16,35,16,159,15,34,15,166,14,48,14,187,13,73,13,215,12,101,12,243,11,133,11,24,11,177,10,75,10,235,9,140,9,50,9,216,8,133,8,50,8,228,7,151,7,80,7,9,7,195,6,125,6,60,6,252,5,192,5,132,5,77,5,23,5,227,4,176,4,129,4,82,4,39,4,252,3,211,3,170,3,129,3,88,3,50,3,12,3,234,2,200,2,169,2,138,2,109,2,80,2,54,2,28,2,5,2,238,1,217,1,196,1,175,1,154,1,135,1,117,1,100,1,84,1,69,1,54,1,40,1,26,1,14,1,2,1,247,0,236,0,225,0,214,0,203,0,192,0,182,0,172,0,162,0,153,0,144,0,136,0,128,0,121,0,114,0,108,0,102,0,97,0,92,0,87,0,82,0,77,0,73,0,69,0,65,0,62,0,59,0,56,0,53,0,50,0,47,0,45,0,43,0,41,0,39,0,37,0,35,0,33,0,31,0,29,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,0,63,0,62,1,61,2,60,3,59,5,58,8,57,11,56,16,55,22,54,29,53,38,52,49,51,60,50,74,49,88,48,103,47,118,46,137,45,157,44,181,43,205,42,234,41,7,41,39,40,72,39,110,38,148,37,191,36,235,35,27,35,75,34,123,33,171,32,223,31,19,31,78,30,137,29,203,28,14,28,85,27,156,26,235,25,59,25,145,24,232,23,69,23,163,22,2,22,97,21,199,20,45,20,154,19,7,19,124,18,241,17,106,17,228,16,101,16,231,15,111,15,247,14,130,14,13,14,152,13,35,13,178,12,66,12,216,11,111,11,12,11,169,10,75,10,237,9,149,9,62,9,236,8,154,8,78,8,2,8,183,7,108,7,38,7,225,6,161,6,97,6,38,6,235,5,179,5,123,5,71,5,20,5,228,4,181,4,136,4,91,4,46,4,1,4,214,3,171,3,131,3,92,3,56,3,21,3,244,2,211,2,181,2,151,2,124,2,97,2,72,2,47,2,23,2,255,1,233,1,211,1,191,1,171,1,153,1,135,1,118,1,102,1,87,1,72,1,57,1,44,1,31,1,18,1,5,1,248,0,235,0,223,0,211,0,200,0,189,0,179,0,169,0,160,0,151,0,143,0,135,0,128,0,121,0,115,0,109,0,103,0,97,0,92,0,87,0,82,0,77,0,73,0,69,0,65,0,61,0,58,0,55,0,52,0,49,0,46,0,43,0,40,0,37,0,35,0,33,0,31,0,29,0,27,0,25,0,23,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,11,63,22,62,33,61,45,60,58,59,71,58,85,57,99,56,115,55,131,54,149,53,167,52,187,51,208,50,231,49,254,48,22,48,47,47,75,46,103,45,135,44,168,43,204,42,241,41,25,41,65,40,110,39,155,38,205,37,255,36,52,36,105,35,158,34,211,33,11,33,68,32,131,31,194,30,8,30,78,29,153,28,228,27,53,27,134,26,221,25,52,25,146,24,240,23,80,23,176,22,23,22,127,21,236,20,89,20,205,19,65,19,186,18,52,18,180,17,52,17,186,16,64,16,201,15,82,15,219,14,100,14,240,13,124,13,15,13,162,12,59,12,213,11,115,11,17,11,181,10,89,10,3,10,173,9,92,9,12,9,188,8,109,8,35,8,217,7,148,7,79,7,15,7,207,6,147,6,87,6,31,6,231,5,179,5,127,5,77,5,27,5,233,4,183,4,135,4,87,4,43,4,255,3,215,3,175,3,137,3,100,3,66,3,32,3,1,3,226,2,197,2,169,2,141,2,113,2,88,2,63,2,40,2,17,2,252,1,231,1,210,1,191,1,172,1,154,1,136,1,120,1,104,1,88,1,72,1,57,1,42,1,27,1,12,1,255,0,242,0,230,0,218,0,207,0,196,0,186,0,176,0,167,0,158,0,150,0,142,0,135,0,128,0,121,0,114,0,108,0,102,0,97,0,92,0,87,0,82,0,78,0,74,0,70,0,66,0,62,0,58,0,54,0,50,0,47,0,44,0,41,0,38,0,35,0,32,0,30,0,28,0,26,0,24,0,22,0,20,0,18,0,16,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,21,63,43,62,65,61,87,60,110,59,133,58,157,57,181,56,206,55,231,54,3,54,31,53,61,52,91,51,123,50,155,49,188,48,221,47,2,47,39,46,79,45,119,44,163,43,207,42,254,41,45,41,97,40,149,39,205,38,5,38,64,37,123,36,182,35,241,34,47,34,109,33,177,32,245,31,62,31,136,30,214,29,36,29,120,28,204,27,38,27,129,26,225,25,65,25,162,24,3,24,107,23,211,22,65,22,175,21,35,21,151,20,15,20,136,19,7,19,134,18,10,18,143,17,22,17,157,16,36,16,171,15,53,15,191,14,79,14,224,13,118,13,12,13,167,12,66,12,227,11,132,11,42,11,208,10,124,10,40,10,212,9,129,9,51,9,230,8,157,8,85,8,17,8,205,7,140,7,75,7,15,7,211,6,154,6,98,6,44,6,246,5,192,5,138,5,86,5,34,5,242,4,194,4,150,4,106,4,64,4,23,4,241,3,203,3,168,3,133,3,100,3,68,3,36,3,4,3,231,2,202,2,173,2,146,2,119,2,94,2,70,2,47,2,24,2,3,2,238,1,219,1,200,1,181,1,162,1,143,1,124,1,106,1,88,1,72,1,56,1,41,1,27,1,14,1,1,1,245,0,233,0,222,0,211,0,201,0,191,0,181,0,172,0,163,0,155,0,147,0,139,0,132,0,125,0,119,0,113,0,107,0,101,0,96,0,91,0,86,0,81,0,76,0,71,0,66,0,62,0,58,0,54,0,50,0,46,0,43,0,40,0,37,0,34,0,31,0,28,0,26,0,24,0,22,0,20,0,18,0,16,0,14,0,12,0,10,0,8,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,31,63,62,62,93,61,125,60,157,59,190,58,224,57,2,57,37,56,72,55,109,54,146,53,185,52,224,51,9,51,50,50,92,49,134,48,179,47,224,46,15,46,63,45,114,44,165,43,219,42,17,42,75,41,133,40,195,39,1,39,65,38,129,37,193,36,1,36,69,35,138,34,210,33,27,33,105,32,184,31,10,31,93,30,180,29,11,29,103,28,196,27,38,27,136,26,234,25,77,25,182,24,31,24,141,23,251,22,110,22,226,21,90,21,210,20,79,20,204,19,79,19,210,18,88,18,222,17,100,17,234,16,115,16,253,15,139,15,26,15,175,14,68,14,221,13,118,13,20,13,178,12,85,12,249,11,161,11,73,11,242,10,156,10,74,10,249,9,172,9,95,9,22,9,206,8,137,8,69,8,4,8,195,7,134,7,74,7,16,7,214,6,156,6,98,6,42,6,242,5,190,5,138,5,89,5,41,5,251,4,205,4,163,4,121,4,81,4,42,4,3,4,223,3,187,3,151,3,115,3,82,3,49,3,18,3,244,2,216,2,188,2,162,2,136,2,112,2,88,2,66,2,44,2,22,2,0,2,234,1,212,1,191,1,170,1,151,1,132,1,115,1,98,1,82,1,66,1,51,1,37,1,24,1,11,1,255,0,243,0,231,0,219,0,209,0,199,0,189,0,179,0,170,0,161,0,153,0,145,0,138,0,131,0,124,0,117,0,111,0,105,0,99,0,93,0,87,0,81,0,76,0,71,0,66,0,61,0,57,0,53,0,49,0,45,0,42,0,39,0,36,0,33,0,30,0,27,0,24,0,21,0,19,0,17,0,15,0,13,0,11,0,9,0,7,0,5,0,3,0,1,0,0,0,0,64,41,63,82,62,123,61,164,60,206,59,248,58,35,58,78,57,122,56,166,55,211,54,0,54,46,53,93,52,142,51,191,50,241,49,35,49,88,48,141,47,196,46,252,45,54,45,113,44,174,43,235,42,43,42,107,41,174,40,242,39,56,39,126,38,196,37,10,37,83,36,156,35,233,34,55,34,137,33,219,32,49,32,135,31,226,30,61,30,156,29,251,28,95,28,195,27,40,27,141,26,247,25,97,25,209,24,65,24,182,23,43,23,164,22,29,22,155,21,25,21,155,20,30,20,163,19,40,19,173,18,50,18,186,17,67,17,208,16,94,16,241,15,132,15,27,15,178,14,78,14,234,13,139,13,44,13,209,12,119,12,29,12,196,11,112,11,28,11,204,10,124,10,48,10,229,9,156,9,83,9,14,9,202,8,137,8,73,8,11,8,205,7,143,7,81,7,21,7,218,6,162,6,106,6,52,6,255,5,203,5,153,5,104,5,58,5,12,5,225,4,182,4,141,4,101,4,61,4,21,4,240,3,203,3,169,3,135,3,103,3,72,3,42,3,12,3,240,2,212,2,186,2,160,2,135,2,110,2,85,2,60,2,36,2,12,2,246,1,224,1,204,1,184,1,165,1,147,1,130,1,113,1,97,1,81,1,67,1,53,1,39,1,25,1,12,1,255,0,243,0,231,0,220,0,209,0,199,0,189,0,180,0,171,0,163,0,155,0,147,0,139,0,131,0,123,0,116,0,109,0,102,0,95,0,89,0,83,0,77,0,72,0,67,0,62,0,57,0,52,0,48,0,44,0,40,0,36,0,32,0,28,0,25,0,22,0,19,0,16,0,13,0,10,0,8,0,6,0,4,0,2,0,0,0,0,64,49,63,98,62,148,61,198,60,249,59,44,59,96,58,148,57,201,56,254,55,52,55,106,54,161,53,217,52,18,52,75,51,133,50,191,49,251,48,55,48,118,47,181,46,246,45,56,45,124,44,192,43,7,43,78,42,151,41,225,40,45,40,121,39,197,38,17,38,96,37,175,36,2,36,85,35,172,34,3,34,93,33,183,32,21,32,115,31,214,30,57,30,159,29,5,29,109,28,213,27,65,27,174,26,31,26,144,25,6,25,124,24,245,23,110,23,236,22,106,22,236,21,111,21,244,20,121,20,254,19,131,19,11,19,147,18,32,18,173,17,62,17,208,16,102,16,252,15,150,15,48,15,206,14,109,14,16,14,179,13,87,13,251,12,163,12,75,12,248,11,165,11,86,11,7,11,186,10,110,10,34,10,218,9,146,9,78,9,10,9,200,8,134,8,68,8,2,8,195,7,132,7,72,7,12,7,212,6,156,6,102,6,49,6,254,5,204,5,157,5,110,5,66,5,22,5,234,4,191,4,150,4,109,4,71,4,33,4,253,3,218,3,184,3,150,3,119,3,88,3,59,3,30,3,2,3,230,2,202,2,174,2,147,2,120,2,95,2,70,2,47,2,24,2,2,2,236,1,216,1,196,1,177,1,159,1,142,1,125,1,108,1,92,1,77,1,62,1,48,1,34,1,21,1,8,1,252,0,240,0,229,0,218,0,208,0,198,0,188,0,178,0,168,0,158,0,149,0,140,0,132,0,124,0,116,0,108,0,101,0,94,0,87,0,81,0,75,0,69,0,64,0,59,0,54,0,49,0,44,0,39,0,35,0,31,0,27,0,23,0,19,0,15,0,12,0,9,0,6,0,3,0,0,0,0,64,194,62,132,61,71,60,10,59,207,57,149,56,93,55,37,54,240,52,187,51,139,50,91,49,48,48,6,47,225,45,188,44,153,43,118,42,90,41,63,40,43,39,23,38,11,37,255,35,249,34,244,33,248,32,253,31,10,31,24,30,48,29,72,28,96,27,120,26,154,25,189,24,234,23,24,23,79,22,136,21,200,20,8,20,83,19,158,18,243,17,73,17,168,16,8,16,106,15,204,14,56,14,165,13,27,13,146,12,18,12,147,11,26,11,161,10,49,10,194,9,91,9,244,8,148,8,52,8,212,7,116,7,28,7,196,6,115,6,34,6,217,5,144,5,75,5,7,5,199,4,137,4,76,4,20,4,220,3,170,3,120,3,71,3,22,3,234,2,190,2,150,2,111,2,76,2,41,2,8,2,232,1,203,1,175,1,149,1,124,1,101,1,78,1,55,1,32,1,12,1,248,0,230,0,213,0,197,0,182,0,168,0,154,0,142,0,130,0,119,0,108,0,99,0,90,0,81,0,72,0,64,0,56,0,49,0,42,0,36,0,30,0,25,0,20,0,15,0,11,0,7,0,3,0,0,0,0,64,208,62,160,61,113,60,66,59,20,58,231,56,188,55,146,54,106,53,66,52,30,51,250,49,217,48,186,47,160,46,134,45,109,44,84,43,66,42,48,41,36,40,24,39,21,38,18,37,20,36,22,35,33,34,44,33,64,32,84,31,112,30,140,29,168,28,196,27,232,26,13,26,59,25,105,24,162,23,220,22,28,22,92,21,166,20,240,19,67,19,152,18,246,17,84,17,179,16,19,16,125,15,232,14,90,14,206,13,75,13,200,12,75,12,207,11,91,11,232,10,124,10,17,10,172,9,71,9,226,8,125,8,31,8,194,7,105,7,18,7,188,6,109,6,31,6,213,5,139,5,71,5,4,5,198,4,137,4,81,4,26,4,227,3,173,3,123,3,74,3,29,3,241,2,201,2,161,2,124,2,87,2,54,2,21,2,247,1,217,1,190,1,163,1,136,1,109,1,84,1,60,1,38,1,16,1,253,0,234,0,216,0,199,0,184,0,169,0,155,0,142,0,130,0,118,0,106,0,95,0,85,0,75,0,66,0,57,0,49,0,41,0,34,0,27,0,21,0,15,0,10,0,5,0,0,0,0,64,220,62,185,61,150,60,115,59,82,58,49,57,19,56,245,54,217,53,189,52,163,51,138,50,117,49,96,48,80,47,65,46,51,45,37,44,29,43,21,42,18,41,16,40,21,39,26,38,36,37,47,36,65,35,83,34,109,33,135,32,167,31,199,30,231,29,7,29,47,28,88,27,136,26,185,25,243,24,46,24,110,23,175,22,249,21,69,21,152,20,236,19,73,19,166,18,5,18,100,17,205,16,54,16,167,15,25,15,147,14,13,14,141,13,13,13,146,12,27,12,165,11,53,11,198,10,92,10,242,9,136,9,30,9,186,8,86,8,249,7,157,7,72,7,243,6,163,6,84,6,11,6,194,5,127,5,60,5,254,4,193,4,133,4,73,4,19,4,221,3,172,3,123,3,78,3,33,3,247,2,206,2,168,2,131,2,97,2,63,2,31,2,255,1,223,1,191,1,162,1,133,1,107,1,81,1,58,1,35,1,14,1,249,0,230,0,212,0,195,0,179,0,164,0,149,0,135,0,121,0,108,0,96,0,85,0,74,0,64,0,54,0,45,0,36,0,28,0,20,0,13,0,6,0,0,0,0,0,56,225,22,0,58,226,22,0,60,227,22,0,40,213,22,0,170,214,22,0,44,216,22,0,174,217,22,0,48,219,22,0,178,220,22,0,52,222,22,0,182,223,22,0,24,203,22,0,26,205,22,0,28,207,22,0,30,209,22,0,32,211,22,0,132,0,177,0,253,0,29,1,61,1,109,1,141,1,205,1,221,1,40,0,0,0,0,0,4,5,6,5,0,0,0,0,24,173,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,6,0,0,208,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,28,0,192,202,35,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,118,35,0,192,202,35,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,56,28,35,0,160,215,34,0,100,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,248,155,34,0,160,215,34,0,100,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,104,95,34,0,0,40,34,0,56,0,0,0,84,65,82,86,0,248,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,248,206,33,0,0,40,34,0,56,0,0,0,84,65,82,86,0,248,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,16,252,32,0,144,167,33,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,24,138,33,0,144,167,33,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,216,96,33,0,200,34,33,0,40,0,0,0,1,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,232,255,32,0,160,229,32,0,64,0,0,0,3,0,0,0,79,233,47,55,239,198,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,160,202,32,0,160,229,32,0,64,0,0,0,3,0,0,0,79,233,47,55,239,198,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,168,176,32,0,128,154,32,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,72,130,32,0,128,154,32,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,88,104,32,0,16,83,32,0,80,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,24,51,32,0,56,0,32,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,88,234,31,0,56,0,32,0,84,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,214,31,0,232,195,31,0,76,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,188,31,0,108,0,0,0,24,229,22,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,3,3,0,0,24,212,29,0,152,109,140,0,4,0,0,0,1,0,0,0,17,43,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,176,20,29,0,152,109,140,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,84,30,0,108,0,0,0,176,232,22,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,233,22,0,168,233,22,0,152,233,22,0,136,233,22,0,0,0,0,0,0,0,0,0,0,0,254,255,2,0,248,255,8,0,238,255,18,0,216,255,0,0,252,255,3,0,240,255,20,0,224,255,36,0,224,255,0,0,255,255,1,0,254,255,3,0,252,255,5,0,252,255,4,0,5,0,5,0,6,0,6,0,7,0,7,0,7,0,7,0,8,0,8,0,8,0,8,0,9,0,9,0,9,0,9,0,10,0,10,0,10,0,10,0,10,0,11,0,11,0,11,0,11,0,12,0,13,0,14,0,14,0,16,0,0,0,10,0,24,0,25,0,54,0,55,0,116,0,117,0,118,0,119,0,244,0,245,0,246,0,247,0,245,1,246,1,247,1,248,1,246,3,247,3,248,3,249,3,250,3,250,7,251,7,252,7,253,7,253,15,253,31,253,63,254,63,255,255,0,0,248,3,249,3,250,3,251,3,248,1,249,1,248,0,249,0,120,0,121,0,56,0,57,0,24,0,25,0,4,0,0,0,5,0,26,0,27,0,58,0,59,0,122,0,123,0,250,0,251,0,250,1,251,1,252,3,253,3,254,3,255,3,0,0,252,0,253,0,124,0,60,0,28,0,12,0,4,0,0,0,5,0,13,0,29,0,61,0,125,0,254,0,255,0,0,0,62,0,30,0,2,0,0,0,6,0,14,0,63,0,0,0,2,0,0,0,3,0,0,0,168,234,22,0,152,234,22,0,120,234,22,0,56,234,22,0,184,233,22,0,0,0,0,0,16,15,14,13,12,11,11,11,11,10,10,10,10,9,9,9,9,9,8,8,8,8,7,7,7,7,6,6,5,5,3,1,4,5,5,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,10,11,11,11,11,12,13,14,14,16,0,10,10,10,10,9,9,8,8,7,7,6,6,5,5,3,1,3,5,5,6,6,7,7,8,8,9,9,10,10,10,10,0,8,8,7,6,5,4,3,1,3,4,5,6,7,8,8,0,6,5,2,1,3,4,6,0,2,1,2,0,0,0,0,0,64,235,22,0,56,235,22,0,40,235,22,0,8,235,22,0,200,234,22,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,128,0,192,0,0,1,64,1,128,1,192,1,0,2,64,2,128,2,192,2,0,3,64,3,128,3,192,3,0,4,64,4,128,4,192,4,0,5,64,5,128,5,192,5,0,6,64,6,128,6,192,6,0,7,64,7,128,7,192,7,0,8,64,8,128,8,192,8,0,9,64,9,128,9,192,9,0,10,4,3,7,6,3,1,3,6,7,7,9,0,0,0,0,0,1,1,2,2,2,1,3,3,3,1,1,0,0,0,0,0,8,6,4,4,4,4,4,4,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,5,5,6,7,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,6,9,11,11,11,12,12,12,12,12,12,12,12,12,12,10,3,2,2,3,4,4,5,6,6,7,7,7,8,8,9,10,10,10,11,11], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1492165);
/* memory initializer */ allocate([11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,10,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,11,11,11,12,12,12,12,12,12,12,12,12,12,53,7,7,8,11,12,14,15,19,20,7,8,8,3,52,53,42,43,39,12,8,23,3,4,40,43,19,36,24,2,3,26,27,18,19,20,21,22,23,40,41,42,43,44,45,4,5,10,11,82,83,84,85,36,37,88,89,90,91,74,75,50,51,52,27,18,23,55,54,55,100,101,104,103,204,205,210,211,212,213,214,215,216,217,218,219,152,153,154,24,155,8,12,13,18,19,20,21,22,23,28,29,30,31,55,2,3,2,3,3,2,3,5,4,4,5,7,4,7,24,23,24,8,103,104,108,55,40,23,24,202,203,204,205,104,105,106,107,210,211,212,213,214,215,108,109,218,219,84,85,86,87,100,101,82,83,36,55,56,39,40,88,89,43,44,90,102,103,15,200,201,91,51,52,53,108,109,74,75,76,77,114,115,116,117,118,119,82,83,84,85,90,91,100,101,8,12,13,18,19,20,21,22,23,28,29,30,31,194,149,139,63,240,55,152,63,243,4,181,63,0,0,0,64,63,0,15,15,31,63,47,31,0,16,14,32,13,47,11,13,7,14,5,11,10,12,8,5,12,10,61,7,4,48,55,3,1,2,2,8,59,4,3,1,62,61,9,55,6,59,29,62,45,29,51,27,23,23,39,19,27,30,46,28,53,9,30,6,43,60,37,21,60,44,16,26,21,51,28,35,19,18,35,20,42,24,26,53,44,17,32,37,58,39,24,45,20,58,17,43,18,42,48,46,22,36,33,33,25,34,49,40,40,52,36,49,34,50,50,56,52,25,54,22,41,54,56,57,38,41,57,38,58,67,16,62,229,63,55,63,132,64,217,61,16,62,61,60,248,57,237,60,242,35,152,28,132,26,58,30,234,31,218,31,152,34,114,34,174,32,96,33,118,30,255,32,13,32,101,32,190,31,29,33,255,32,255,33,83,35,156,33,249,56,157,71,60,77,192,67,42,64,75,64,51,59,116,59,171,62,92,61,229,32,149,35,215,35,5,35,74,35,97,35,61,34,71,34,146,35,225,33,106,27,21,28,214,29,139,28,20,29,211,28,126,27,44,27,18,27,212,26,96,21,126,19,14,20,57,20,126,20,21,20,86,20,231,19,222,18,27,20,216,15,215,11,54,10,208,11,100,11,153,10,237,12,165,12,41,11,145,13,53,30,200,30,252,31,239,31,55,32,42,33,189,33,153,33,167,32,145,29,114,16,215,11,248,9,145,13,36,15,13,15,88,16,58,16,69,15,128,15,142,12,138,7,33,5,95,8,189,9,81,9,195,10,146,10,238,9,103,11,208,11,56,6,172,3,95,6,187,6,43,6,242,7,36,8,121,7,41,10,77,254,209,252,26,253,9,4,250,253,70,2,79,251,61,3,86,0,129,1,191,252,133,252,207,1,248,255,29,251,170,5,72,0,25,255,96,3,149,2,3,252,231,0,206,254,65,1,36,255,93,255,242,253,14,253,159,249,11,1,57,0,58,255,173,254,223,255,68,250,61,2,28,3,87,255,137,253,48,3,171,0,162,254,38,1,124,6,197,1,7,2,35,1,159,0,128,253,240,250,67,253,182,252,198,255,182,3,124,3,13,6,203,2,15,2,54,253,63,255,72,2,31,0,223,254,100,1,179,254,55,254,100,2,229,254,155,250,27,253,147,255,216,252,231,0,77,0,169,255,168,254,61,5,63,4,114,253,199,253,165,252,212,4,38,2,86,3,202,2,225,253,40,249,61,255,158,255,236,254,147,252,70,252,32,251,213,254,212,0,21,255,40,253,181,3,237,5,127,3,179,255,88,1,148,253,251,2,157,1,246,1,150,254,64,252,29,254,106,5,198,254,205,254,0,255,20,251,83,254,194,1,46,254,148,255,242,3,175,8,199,2,181,2,9,2,138,2,25,5,228,255,134,254,232,2,19,252,240,0,144,255,241,254,12,254,178,3,197,6,15,1,241,255,141,3,253,254,152,6,63,2,246,255,44,254,57,255,77,4,13,252,69,2,203,255,21,253,110,3,145,0,227,254,0,251,114,254,36,0,14,254,159,250,18,0,68,254,203,5,147,251,189,252,70,5,4,5,161,255,247,3,34,255,187,1,116,1,158,254,77,250,43,251,160,1,43,255,210,1,157,2,147,2,104,6,164,3,22,2,241,255,66,0,212,1,251,3,20,253,105,5,74,255,117,252,47,253,250,254,174,254,148,0,165,5,75,0,8,253,57,2,223,4,81,1,160,1,135,255,133,1,239,0,32,6,213,3,113,0,113,1,21,252,5,254,181,253,120,252,200,254,158,255,181,3,31,0,80,4,72,0,115,255,185,5,63,0,239,252,103,4,72,2,67,3,21,1,121,251,208,0,45,1,142,252,117,0,108,254,27,2,142,255,88,3,19,254,223,0,112,252,111,2,180,255,20,1,72,254,149,8,33,9,244,4,158,2,48,1,245,254,243,253,140,0,114,3,117,255,196,249,38,2,33,3,56,254,200,255,71,253,97,3,36,4,157,1,190,1,130,4,81,2,179,255,213,4,225,255,69,2,243,251,129,252,157,2,41,1,141,1,46,2,203,0,227,252,105,252,3,0,180,2,220,254,26,4,14,3,78,1,195,5,120,2,176,255,48,0,219,251,28,254,106,1,171,253,172,252,223,253,182,254,83,254,88,253,109,4,98,251,24,253,60,5,6,1,63,0,40,5,59,3,114,254,192,253,85,1,250,252,29,254,33,251,186,255,98,0,93,255,162,2,245,255,138,252,19,2,155,251,247,254,14,255,212,2,166,3,206,5,120,8,167,14,114,35,102,47,120,54,63,70,229,74,198,82,60,85,194,6,80,10,122,13,6,19,238,23,196,30,28,61,153,69,70,79,142,85,32,6,208,8,16,12,10,19,55,43,81,52,131,71,93,75,117,82,237,84,197,6,208,9,29,13,100,18,65,27,56,40,128,66,36,70,201,74,126,79,208,6,132,9,236,12,27,34,192,40,231,46,254,60,255,64,111,83,153,85,250,6,65,9,44,13,169,17,139,26,163,50,10,69,44,74,119,81,136,84,95,6,129,9,33,13,184,24,213,41,237,46,221,51,80,54,241,75,96,82,209,5,60,9,219,12,106,24,11,36,163,40,19,54,174,59,57,69,203,83,77,7,229,9,147,13,13,17,192,35,177,56,36,62,126,66,131,80,163,83,22,8,209,11,237,16,222,22,125,30,15,36,101,41,175,62,141,78,74,85,118,7,113,10,91,13,165,16,160,43,7,59,193,64,183,68,110,75,41,79,117,4,23,7,64,10,15,18,95,25,116,37,144,54,44,64,151,75,38,83,144,8,99,12,99,18,176,22,152,42,212,48,82,55,48,61,132,82,29,85,6,5,115,7,244,9,125,13,102,37,188,46,106,62,192,67,235,76,223,87,129,7,160,10,252,17,28,26,239,44,192,50,14,56,158,59,101,66,55,81,4,8,199,10,57,15,126,20,238,25,27,40,218,61,174,65,229,70,171,84,6,7,193,9,241,21,185,44,133,51,119,57,154,66,19,71,83,79,190,82,241,3,111,6,73,11,77,22,69,37,66,48,127,59,62,72,230,81,17,86,200,11,210,14,30,21,45,29,200,48,160,54,224,59,206,63,240,77,55,81,155,8,224,11,212,14,66,21,211,46,200,52,83,58,242,63,192,69,115,73,96,11,196,16,52,31,100,37,42,45,188,51,220,56,145,64,36,78,81,82,45,11,23,14,35,23,122,27,18,36,22,47,161,53,136,70,38,79,238,81,253,11,215,16,79,23,199,28,218,44,155,49,229,55,105,63,157,71,228,74,130,9,77,14,2,19,166,22,143,40,202,45,249,50,52,61,174,73,119,77,228,7,45,10,20,15,25,36,219,51,52,57,138,62,203,66,68,75,27,79,85,7,249,10,6,14,99,18,48,43,153,48,6,61,16,67,73,73,195,77,59,8,57,11,89,14,167,22,11,53,95,57,66,62,181,66,202,73,119,77,76,6,236,8,128,11,244,13,27,32,135,54,52,62,87,67,160,72,149,78,116,9,84,12,142,25,231,39,29,47,222,52,201,59,68,64,29,73,168,77,131,6,52,10,206,13,117,20,17,41,176,45,140,50,158,65,138,70,178,75,84,9,201,11,231,18,117,36,149,44,186,49,176,58,120,63,41,68,245,72,83,7,226,10,135,16,176,24,246,33,165,39,9,46,117,66,176,72,248,77,167,2,131,5,46,18,70,31,182,44,193,51,147,61,207,70,137,79,63,84,46,7,36,10,250,13,0,18,18,22,10,44,19,56,14,62,99,80,250,84,23,5,163,7,91,9,250,12,247,46,196,53,11,62,157,70,212,78,240,82,158,5,54,8,103,10,134,13,136,32,122,40,195,53,96,67,20,77,72,87,92,3,112,7,210,23,95,30,87,38,231,46,229,57,69,65,75,77,140,82,137,6,163,10,120,14,237,23,244,29,231,36,115,53,107,56,58,80,227,84,222,4,57,7,86,11,156,17,53,28,166,49,243,57,186,63,135,75,192,88,245,5,212,8,22,15,27,22,174,28,228,45,58,52,106,56,124,70,86,83,172,4,54,7,32,12,151,27,220,42,105,50,222,57,141,66,210,77,108,88,99,8,34,12,123,17,111,25,35,32,37,38,232,42,129,47,27,74,52,83,49,6,101,9,178,11,196,15,217,44,121,51,183,56,71,60,255,77,27,83,242,6,128,10,30,14,72,18,249,36,56,43,185,48,192,63,30,77,64,81,70,7,26,10,164,13,63,26,188,45,212,50,28,56,0,63,154,76,201,79,115,5,108,8,109,10,58,13,111,41,93,47,46,53,65,65,32,74,119,83,164,5,69,8,214,12,89,24,207,36,181,50,150,58,237,61,36,67,97,85,212,7,79,11,199,14,33,19,24,24,129,28,65,49,61,64,97,75,217,83,215,5,47,11,216,24,164,31,135,44,191,55,30,62,47,69,255,79,45,86,180,9,42,12,86,22,185,27,208,32,72,49,249,54,255,57,55,80,148,83,120,9,205,12,176,20,140,24,26,44,103,50,150,62,100,68,133,75,59,79,5,10,194,14,240,20,77,27,78,34,188,40,54,56,126,61,106,69,230,84,167,10,56,13,213,25,38,36,46,41,204,47,59,57,71,61,106,78,110,82,124,7,137,11,130,24,152,31,238,37,173,42,104,48,50,64,42,78,191,82,56,13,14,17,229,20,243,29,172,43,61,49,97,54,220,59,189,77,18,81,3,12,187,16,63,23,195,29,132,37,2,43,96,48,182,54,178,80,249,83,215,6,151,9,27,20,238,38,101,45,120,51,147,57,86,64,52,81,252,84,162,5,140,8,2,13,157,26,225,34,103,47,140,56,202,59,179,76,64,80,246,8,79,11,230,15,99,31,201,47,104,52,170,57,215,67,8,74,232,76,145,7,99,10,250,17,41,26,111,35,63,50,117,55,126,59,175,62,189,73,23,8,103,10,120,16,229,36,135,42,4,48,125,54,61,58,36,75,117,79,204,6,187,9,160,13,202,31,184,37,145,43,150,51,96,57,160,81,147,85,151,8,65,11,67,18,79,33,67,39,144,44,99,56,103,60,38,67,117,80,151,7,172,11,81,16,151,23,54,29,88,33,101,55,191,60,214,68,75,84,33,7,103,12,150,27,90,38,24,50,90,60,154,71,144,77,70,85,140,87,160,9,230,11,214,18,89,23,16,30,38,60,90,65,238,68,108,80,72,83,246,9,65,13,185,20,8,27,251,39,3,55,223,70,251,74,201,80,88,83,187,11,215,14,201,20,37,25,239,30,123,45,194,61,206,65,199,70,36,74,127,13,61,16,182,26,7,32,149,38,26,48,33,62,186,65,237,77,156,81,236,11,185,14,27,19,178,22,65,27,142,39,196,57,118,62,61,77,168,81,87,14,4,17,195,22,85,27,12,33,52,47,74,55,91,58,47,75,199,79,156,10,100,14,126,20,30,26,15,33,17,39,106,48,51,55,22,63,64,77,153,7,78,10,34,16,59,31,2,56,216,60,161,66,30,71,1,79,5,82,0,9,112,11,26,16,216,18,8,22,83,51,209,61,42,66,140,78,62,82,8,7,212,9,22,13,99,20,94,52,76,62,210,68,108,72,51,80,4,83,156,5,176,8,193,10,194,17,185,37,237,43,73,59,189,63,81,68,191,74,15,9,83,11,116,19,24,27,212,32,177,52,194,60,153,63,46,79,175,81,139,8,103,11,2,18,243,22,222,28,12,49,209,54,154,65,6,82,9,85,187,8,107,11,1,20,115,24,163,31,21,53,236,59,212,63,7,70,191,78,229,6,78,10,167,14,98,22,203,30,124,39,65,53,59,60,168,65,142,72,132,13,109,22,124,37,222,45,77,56,208,62,253,70,146,74,109,81,97,84,151,14,74,17,55,24,195,28,34,36,153,56,163,62,130,66,161,77,140,81,193,13,170,18,231,26,232,33,173,49,242,55,78,62,130,70,198,78,153,82,93,8,152,11,209,26,115,31,26,39,103,51,221,57,245,61,120,68,223,72,52,16,240,23,68,35,119,42,142,49,181,54,104,62,56,67,131,76,115,80,51,17,247,20,234,25,179,32,179,39,79,45,115,58,203,63,62,70,80,73,251,15,10,21,196,26,66,34,43,45,234,51,112,61,34,66,112,74,134,78,186,10,41,14,179,20,80,29,22,40,168,44,116,51,130,60,235,65,106,68,200,8,228,13,91,33,94,41,121,49,104,57,131,64,160,69,44,79,255,82,255,4,168,7,80,15,113,30,169,39,161,57,6,65,219,70,199,80,218,83,136,9,147,13,81,26,206,33,158,47,252,56,223,66,5,70,166,74,11,78,87,7,210,9,145,17,148,29,33,39,100,58,13,63,1,66,221,71,176,75,244,10,104,14,66,29,102,39,210,43,167,49,179,63,62,68,109,78,134,82,231,7,122,10,33,15,76,32,15,40,125,45,83,59,206,66,21,74,76,77,7,11,21,14,183,22,147,33,101,39,205,44,184,64,54,68,66,73,164,77,35,11,97,14,160,20,224,29,213,35,98,40,113,58,20,63,151,68,42,72,68,5,85,10,194,22,81,34,124,41,31,50,127,63,143,71,141,82,58,88,93,8,220,11,197,16,194,23,169,29,133,41,6,67,113,70,218,83,68,86,72,6,71,9,56,13,222,26,242,38,219,43,32,66,242,68,217,78,128,82,214,10,32,14,150,19,157,25,108,30,255,34,172,66,126,71,81,76,62,80,142,7,205,18,60,24,44,28,19,35,145,45,117,62,147,69,202,79,199,84,240,8,179,13,173,19,185,26,86,32,166,37,218,58,97,64,149,84,198,86,135,11,187,14,14,19,154,29,56,35,58,40,154,56,138,59,255,78,254,81,184,12,183,18,201,25,97,29,196,33,235,37,86,52,206,62,158,74,25,79,35,7,54,10,158,13,151,23,117,47,255,53,63,63,130,67,175,83,25,86,232,3,168,6,186,11,191,24,23,33,4,41,30,58,83,66,58,78,155,87,110,6,238,8,37,12,77,28,229,44,247,49,184,65,3,69,37,74,254,78,172,6,197,9,243,12,81,26,25,34,196,38,217,62,201,66,198,71,205,77,63,10,182,13,126,17,13,22,134,38,107,43,115,59,147,70,127,76,158,79,214,9,106,13,120,18,244,24,146,31,69,36,106,51,207,71,107,77,72,80,190,6,79,9,250,15,159,24,125,30,45,50,20,57,200,68,69,75,213,78,44,11,151,14,230,18,156,23,86,28,210,32,207,54,253,63,117,70,210,75,151,16,105,23,16,31,64,38,54,48,61,57,119,68,86,73,95,81,195,84,174,13,211,15,48,22,149,26,210,31,169,46,9,65,36,68,166,79,60,84,79,12,29,19,11,23,30,28,154,44,17,51,20,59,9,69,40,80,101,85,120,15,240,18,38,23,91,28,107,34,33,41,45,61,176,64,20,71,215,78,147,17,204,25,100,31,35,36,52,42,83,49,8,62,104,68,52,78,54,82,155,16,165,21,254,25,126,32,172,38,166,45,252,58,197,66,92,80,183,84,185,14,207,20,185,30,144,36,188,41,42,46,92,53,6,60,45,73,170,77,11,12,129,15,104,24,185,31,70,38,242,42,105,48,118,53,224,69,161,74,171,10,62,18,151,27,241,35,82,44,167,53,235,65,109,73,51,81,88,87,163,4,179,8,129,18,46,28,150,37,89,49,44,60,48,70,38,79,237,91,119,7,173,9,75,15,114,39,96,45,155,50,95,63,242,66,70,75,249,80,228,6,215,9,47,15,32,27,190,35,46,49,130,63,88,66,4,70,3,72,120,5,90,14,219,27,14,34,192,41,220,48,92,61,47,69,8,77,76,82,18,9,1,12,191,16,172,31,191,36,132,41,246,61,53,65,2,77,226,83,70,10,11,13,150,18,168,32,34,40,69,44,80,50,222,67,21,75,224,77,185,6,17,10,177,21,27,28,203,33,190,41,221,58,57,66,15,73,217,77,22,20,80,2,147,67,69,7,16,24,91,9,240,62,64,13,58,3,213,7,29,74,47,23,202,7,0,0,74,60,237,0,77,41,150,11,28,59,50,19,49,45,172,4,114,55,94,6,155,31,253,18,57,59,196,55,160,35,13,2,204,51,184,12,0,0,79,16,76,42,210,107,39,64,108,61,126,17,156,28,148,15,0,0,51,40,121,44,180,46,239,41,196,30,141,30,170,12,221,38,15,6,121,9,118,10,26,106,129,7,75,36,39,7,158,19,1,0,236,5,100,1,164,57,57,0,28,21,217,22,0,0,99,12,64,36,33,14,91,26,123,19,22,87,113,11,54,4,180,23,205,23,209,36,171,10,75,15,72,50,75,25,196,255,162,0,42,0,185,255,50,0,171,255,234,254,242,255,196,255,203,255,132,0,28,0,191,255,185,255,194,255,6,0,119,0,195,0,116,255,28,0,37,0,165,253,164,236,222,254,188,2,15,255,11,0,211,254,41,1,15,252,212,1,117,3,192,0,40,0,239,1,78,3,228,255,201,0,1,255,159,3,124,253,120,9,66,11,174,255,28,249,53,4,59,1,178,3,75,3,143,1,176,0,55,2,34,2,121,1,27,1,165,9,233,248,191,255,12,0,166,1,144,254,129,253,19,254,26,234,84,0,122,0,241,0,11,1,248,255,255,254,233,255,36,255,138,255,139,0,210,249,38,255,124,246,235,9,242,254,146,0,250,254,23,254,15,6,92,2,31,255,107,1,234,0,146,255,90,255,34,4,38,9,158,7,43,0,58,9,91,251,236,1,172,0,216,254,159,0,82,254,201,254,121,255,74,255,77,0,68,254,53,248,169,252,32,8,55,254,133,1,104,3,245,9,167,3,128,255,7,2,138,254,54,1,96,0,119,0,249,254,189,7,5,252,140,253,212,0,83,255,12,247,42,4,63,248,86,254,115,0,22,253,147,0,3,0,94,0,195,0,30,249,177,6,175,254,92,7,133,255,32,254,95,0,9,3,49,4,69,8,55,252,16,0,11,0,123,0,118,1,118,254,117,250,61,3,121,6,14,5,46,245,30,1,45,3,222,254,141,255,111,0,56,1,53,0,44,0,128,3,34,0,16,247,141,242,251,247,98,0,37,1,173,1,88,255,74,0,198,255,221,0,129,254,100,0,63,0,133,7,73,251,199,0,94,0,162,255,244,11,33,7,99,2,36,1,115,255,126,1,141,0,105,0,105,255,0,0,168,5,245,254,206,0,164,3,86,253,251,0,73,255,56,4,161,0,238,16,115,254,13,2,165,255,127,0,152,255,153,3,22,247,238,254,210,251,131,1,200,254,100,5,209,10,214,253,221,5,103,252,102,0,73,255,152,255,190,255,136,249,1,8,122,0,33,247,84,0,236,254,52,255,97,1,124,1,98,254,35,249,245,251,194,254,126,255,246,255,163,0,41,254,121,9,48,11,156,248,38,1,49,3,242,2,21,1,227,255,42,255,217,255,200,254,199,255,202,255,218,3,238,8,194,253,34,0,127,253,199,14,214,0,113,254,101,255,38,0,108,255,214,255,167,255,97,0,239,255,112,247,217,2,16,1,144,4,247,241,150,0,96,0,39,254,211,0,196,255,136,0,230,255,142,0,227,254,93,0,154,2,47,254,75,255,224,7,174,254,118,247,208,245,63,254,107,0,238,255,45,0,24,0,245,0,137,255,244,0,186,1,229,5,158,0,242,0,169,0,240,255,35,255,104,0,115,0,16,0,39,255,23,0,231,255,130,0,236,15,150,2,197,254,252,11,221,255,36,0,225,10,33,255,240,253,99,255,43,0,186,0,254,253,16,255,15,0,11,255,8,2,146,255,243,252,127,253,38,1,236,255,64,0,212,255,144,1,147,255,148,18,54,5,91,254,61,255,130,0,122,247,64,0,127,252,113,250,9,12,245,253,122,1,92,255,200,3,81,2,64,255,71,0,114,0,113,255,246,255,169,7,187,243,101,12,217,255,146,255,199,255,144,0,188,255,83,254,30,0,246,255,211,1,159,0,40,0,67,0,4,1,46,3,88,255,188,252,49,4,22,242,250,6,75,251,108,255,151,255,94,0,5,0,143,0,138,0,18,0,152,250,20,0,123,2,130,255,185,255,169,255,192,254,105,254,47,2,105,255,32,5,213,238,13,253,249,254,179,255,121,6,187,2,170,1,213,1,43,254,253,0,176,255,61,1,185,255,12,1,8,14,253,247,48,1,157,0,43,0,80,7,210,14,255,249,202,4,97,255,177,254,84,1,127,254,3,255,61,255,21,0,106,0,225,255,69,255,193,255,45,245,190,1,60,253,202,0,70,255,36,2,64,3,221,6,6,251,210,4,12,253,96,255,76,0,174,255,64,0,121,8,13,0,175,252,244,0,74,246,166,247,76,3,78,255,14,1,41,1,150,0,202,0,215,255,68,255,121,0,8,251,115,1,193,254,32,11,43,254,245,247,10,5,55,254,132,254,178,2,148,0,205,255,172,254,113,0,57,0,21,251,116,254,132,250,80,1,1,254,64,2,89,17,124,0,143,0,29,254,85,0,138,0,196,0,38,0,68,255,153,4,4,253,237,247,52,3,248,254,218,0,212,254,11,254,26,255,31,246,69,5,186,249,57,255,92,0,201,255,212,250,66,253,30,8,11,251,158,1,206,255,29,0,12,0,87,0,175,253,217,0,174,255,94,0,168,246,52,1,11,9,140,8,0,3,177,251,179,255,67,2,170,6,198,252,32,255,215,254,145,0,128,253,58,2,146,0,57,255,163,4,152,252,71,1,202,254,134,255,233,255,243,255,40,3,117,255,183,238,98,253,156,1,252,255,186,255,94,255,224,251,173,2,200,254,67,252,83,1,125,3,4,255,200,15,151,255,76,0,225,3,25,1,177,255,117,255,168,0,214,254,27,3,173,251,139,1,130,1,244,253,28,4,219,246,233,9,218,1,214,2,252,251,155,254,204,255,115,0,247,255,69,5,64,247,17,3,191,10,77,0,154,3,129,1,229,253,108,255,154,1,251,0,186,255,199,0,51,0,192,6,50,255,157,4,158,4,108,5,233,252,121,0,253,255,8,0,109,255,161,255,101,0,118,3,148,246,19,0,97,9,140,255,206,2,176,253,35,255,212,2,223,255,178,2,76,255,100,3,254,242,121,1,176,254,128,0,11,1,229,247,32,11,178,11,212,254,3,0,103,255,41,0,56,254,38,0,225,255,53,1,150,255,164,255,242,255,96,0,160,2,122,2,207,0,20,6,182,1,157,247,26,1,139,9,130,249,255,1,201,1,253,254,7,254,173,0,52,255,166,252,139,255,191,10,84,3,220,0,0,254,240,245,6,6,101,1,179,255,252,255,165,0,193,255,189,0,46,1,69,253,4,253,233,249,25,0,23,255,149,1,173,0,186,2,183,255,212,254,94,250,149,244,210,250,231,255,98,0,60,255,157,244,111,251,192,242,179,2,97,1,60,255,96,0,41,0,180,0,198,0,24,1,207,0,98,255,237,255,20,6,223,3,245,253,232,254,193,249,88,5,81,243,28,252,159,0,120,255,43,254,208,255,0,0,30,0,95,0,3,253,33,0,180,25,76,255,60,1,80,255,105,0,235,255,247,255,166,0,148,0,204,255,207,255,42,0,2,0,62,1,201,255,165,255,75,250,62,250,242,243,12,253,199,5,227,255,100,253,1,255,205,255,241,0,249,0,44,255,132,0,127,255,102,254,113,0,17,0,45,1,185,0,96,0,10,0,188,0,38,0,252,252,32,20,243,255,246,255,247,5,38,3,233,255,177,255,78,4,179,255,73,1,157,255,108,254,228,8,151,252,135,245,3,253,71,0,20,0,112,246,221,252,35,7,91,4,96,255,241,255,32,1,210,255,61,2,100,0,42,253,74,253,106,254,32,1,61,0,88,247,120,252,77,0,89,244,62,252,98,250,41,3,218,255,177,255,95,0,52,0,25,255,6,2,115,0,41,0,140,3,12,3,37,3,49,255,143,247,42,2,200,3,39,12,133,0,98,255,243,255,222,255,74,255,196,255,105,0,206,2,35,251,227,0,206,252,160,4,135,3,91,2,36,252,169,245,55,7,141,0,49,3,175,254,131,0,137,1,117,6,71,3,251,254,210,1,209,1,215,254,160,5,81,254,10,8,191,248,120,250,54,1,46,253,202,255,203,0,246,254,186,14,172,0,175,253,183,255,4,254,195,255,86,4,237,4,19,1,145,6,191,1,109,255,161,255,33,0,1,5,209,243,24,0,204,254,110,1,44,254,232,0,102,1,155,2,82,252,184,2,100,252,245,247,194,255,151,0,202,247,76,1,2,1,70,255,132,253,173,2,214,0,154,243,37,251,61,2,236,254,9,0,250,254,236,255,158,0,82,255,235,255,81,2,202,231,246,254,242,254,193,255,53,255,63,0,116,254,156,255,191,0,212,0,85,0,120,0,233,252,37,0,209,255,60,8,140,2,7,2,90,1,106,0,208,248,250,245,205,253,14,0,10,1,10,0,214,0,248,1,11,251,50,0,164,0,120,0,151,255,222,253,44,255,177,255,41,0,85,255,163,2,4,255,21,17,240,255,95,249,45,250,252,241,181,253,111,2,67,0,13,1,228,1,231,255,43,4,68,2,170,253,195,0,47,0,239,255,136,245,195,9,184,254,164,8,8,5,199,255,41,253,76,0,46,255,38,255,41,0,169,254,230,255,218,255,43,0,94,2,149,253,237,253,222,247,87,0,153,251,2,5,233,255,224,8,232,248,104,0,225,255,85,0,234,255,60,0,13,5,138,0,126,1,176,1,233,1,140,254,143,249,7,245,4,246,158,255,24,255,23,255,169,0,186,0,79,0,133,4,65,8,82,252,124,2,109,3,167,253,229,8,131,5,141,4,5,4,155,253,164,254,218,255,237,255,45,0,38,5,68,248,12,0,202,10,239,5,184,0,188,7,207,255,242,254,105,1,84,255,167,253,60,255,186,0,189,255,132,255,223,5,13,252,7,1,223,0,128,254,153,0,235,255,217,251,17,255,147,4,83,242,0,2,94,255,76,255,139,0,88,253,97,2,129,248,153,11,239,246,73,255,194,0,210,253,26,0,91,0,84,1,231,255,225,255,127,0,150,2,182,0,191,0,103,247,213,245,204,8,245,253,21,1,50,0,99,1,39,1,191,255,99,1,207,0,82,0,23,254,113,255,38,255,89,0,154,2,153,254,156,10,250,246,136,248,161,1,144,1,43,0,110,0,163,255,114,255,61,0,72,244,198,1,103,255,0,0,99,254,213,1,83,1,62,1,59,255,75,0,176,255,78,11,127,255,82,0,151,5,159,4,173,1,236,249,197,250,219,249,164,255,113,252,26,255,244,255,252,255,111,255,124,254,93,254,251,255,15,255,208,27,165,0,131,255,134,255,126,0,106,255,109,0,110,255,195,255,207,255,47,0,70,0,213,255,40,0,75,7,193,5,2,251,205,4,48,247,166,255,10,0,24,253,172,4,147,255,146,1,2,1,178,2,182,255,26,0,14,5,201,251,142,0,176,246,188,254,96,249,75,245,65,1,66,0,83,0,129,255,125,255,156,0,166,0,135,0,20,7,139,242,10,0,23,2,221,253,225,1,61,247,31,1,177,254,218,0,195,0,255,255,231,255,162,255,195,0,153,5,108,250,92,250,8,2,219,0,35,13,124,254,217,252,58,254,227,255,60,1,125,0,159,0,112,255,100,255,195,254,240,2,0,1,216,0,84,1,232,1,147,0,226,233,55,0,146,255,131,1,154,255,45,255,190,255,230,255,104,14,84,255,194,246,12,255,251,255,97,1,11,0,247,1,88,0,227,0,69,0,16,255,69,255,198,255,123,254,9,249,109,250,20,0,150,253,32,2,199,250,116,2,148,243,196,2,230,253,89,254,115,0,49,0,95,255,184,0,86,253,33,255,177,2,19,5,133,252,207,251,52,251,207,254,47,0,83,247,233,249,86,2,132,254,166,0,143,0,146,254,31,1,74,8,253,1,117,2,235,0,243,5,84,11,128,253,87,254,50,254,25,255,203,255,229,255,249,254,42,8,156,248,133,251,214,255,98,3,3,247,205,1,198,251,143,253,171,255,148,0,229,0,231,255,85,0,53,0,3,1,175,255,24,240,17,10,244,255,249,255,79,1,105,255,77,253,119,255,98,0,116,1,219,255,64,255,239,255,246,12,210,253,16,8,140,1,2,1,213,251,229,0,98,4,42,1,231,255,40,0,27,0,122,255,90,255,9,255,38,248,72,254,42,4,136,250,130,242,223,254,172,1,117,2,98,255,126,0,129,0,183,0,244,255,85,255,136,255,165,1,67,254,66,0,124,252,96,14,47,6,193,7,25,0,229,0,233,253,255,255,45,0,207,0,202,255,226,255,45,6,86,252,65,253,149,1,110,3,114,254,211,251,212,6,229,245,117,250,137,254,71,254,25,254,109,0,21,0,137,250,136,2,241,254,67,253,123,2,115,0,118,255,54,254,168,253,157,248,73,2,164,1,132,248,111,4,7,0,48,6,142,3,171,16,48,5,23,1,139,1,221,255,157,255,88,255,247,1,216,0,130,255,211,0,212,0,193,0,99,247,235,1,184,2,41,0,27,1,137,2,159,242,25,252,200,0,113,2,251,254,134,254,209,255,241,255,226,255,18,251,164,6,113,247,196,0,19,249,5,255,84,0,242,1,251,254,150,0,195,1,41,0,80,1,27,0,200,255,50,2,170,255,255,255,207,251,181,5,100,8,111,244,186,254,255,254,184,1,214,255,208,255,192,254,122,0,94,0,13,251,194,252,250,10,162,255,55,255,222,3,111,9,28,253,90,255,245,254,99,255,68,0,45,1,34,1,65,0,163,3,177,7,86,255,6,0,149,0,240,254,151,255,30,2,245,255,208,240,105,0,49,1,77,1,242,255,217,255,152,7,116,251,88,0,245,14,90,251,233,253,124,253,182,254,253,1,163,255,198,254,28,255,218,254,170,254,230,255,119,4,189,246,112,254,74,0,101,0,188,255,185,253,189,251,39,13,122,4,130,253,76,254,136,0,41,0,164,255,238,5,2,11,90,247,4,248,124,2,254,255,79,0,4,254,164,2,73,254,154,254,58,255,187,255,15,1,59,0,102,6,212,1,97,0,8,1,248,255,224,235,104,255,152,0,252,0,145,1,137,254,239,255,124,255,51,0,63,0,121,2,76,255,111,1,111,0,238,255,15,0,204,255,128,0,202,255,11,0,96,0,134,255,230,255,167,227,214,255,59,251,80,253,197,0,149,255,39,255,141,0,223,254,141,0,13,1,183,1,21,253,97,241,50,8,226,0,137,0,26,0,147,249,57,249,176,255,43,0,40,255,245,0,32,2,157,0,40,0,238,0,237,0,35,252,123,1,88,0,127,2,201,250,6,6,123,4,2,254,240,3,122,255,142,253,184,2,38,244,78,1,79,253,115,0,88,255,39,0,214,6,119,253,23,255,157,255,25,255,3,2,112,0,245,255,94,255,123,255,118,255,26,254,215,239,204,0,154,255,99,3,250,251,219,0,2,255,29,245,128,255,193,3,235,244,30,254,61,255,179,2,86,255,78,255,164,0,202,255,40,248,140,255,74,0,142,1,160,255,40,254,151,1,27,0,31,1,116,2,97,0,111,250,173,240,6,0,117,0,199,251,162,3,140,1,196,1,87,0,71,254,101,255,30,253,65,4,80,8,195,243,235,255,146,253,208,255,129,255,250,1,217,3,56,255,33,13,184,0,246,253,41,0,247,1,209,0,14,0,160,255,23,3,239,4,33,1,155,255,64,249,207,251,251,253,60,16,83,253,214,0,47,253,160,253,154,255,217,254,142,255,126,0,172,254,109,0,88,0,204,249,82,0,219,253,136,254,76,0,84,0,46,255,59,0,126,255,65,1,166,2,96,18,52,2,255,255,100,0,69,1,216,254,0,1,88,252,138,252,192,251,65,255,220,1,156,241,79,5,12,0,115,254,186,255,239,255,58,0,57,2,97,1,53,3,179,255,253,0,153,0,65,22,85,255,181,0,3,0,166,255,99,254,247,254,142,0,62,0,191,3,151,0,153,255,77,3,172,254,232,254,35,253,176,253,12,255,230,9,17,12,167,3,119,254,151,255,145,0,102,253,207,244,4,250,205,2,51,11,206,0,224,252,131,255,222,255,67,255,118,255,42,0,189,0,115,255,107,0,42,244,45,241,18,254,108,0,107,255,126,1,248,2,114,255,81,1,180,252,228,0,124,0,232,0,233,255,255,255,250,8,238,2,124,2,159,254,157,0,164,2,65,255,44,3,106,13,247,2,31,2,239,255,43,255,161,255,60,1,75,253,164,253,221,251,32,0,16,254,250,242,240,254,152,255,17,254,126,255,115,2,136,254,74,0,169,253,55,0,119,247,56,252,5,2,169,254,21,0,7,255,61,252,12,1,11,13,239,0,3,3,122,255,42,0,231,0,75,0,97,6,75,1,131,255,98,254,201,1,196,254,111,0,37,254,107,1,81,253,247,239,213,1,187,1,113,0,72,0,218,5,150,1,147,3,27,255,52,2,135,254,89,0,137,0,39,0,2,0,227,255,96,254,107,255,14,14,3,255,12,0,9,252,200,11,148,3,42,253,18,247,157,255,195,251,18,255,178,2,212,255,205,255,141,255,25,0,56,0,119,252,22,244,159,251,232,255,144,247,112,250,241,3,76,255,88,254,188,0,95,254,190,255,170,255,74,0,228,255,31,255,87,252,166,255,251,0,198,248,147,7,51,7,65,3,169,248,64,255,194,254,103,0,149,254,234,255,199,255,239,244,138,255,235,254,158,255,171,255,17,254,150,252,211,11,115,255,46,250,84,255,246,254,224,255,190,0,244,255,148,254,132,254,197,247,249,0,39,255,150,2,184,253,89,0,205,253,129,4,237,243,112,253,207,1,144,0,230,255,214,30,181,254,127,1,212,253,63,0,141,254,233,255,73,0,46,0,111,255,105,0,43,0,57,255,204,255,171,255,171,255,13,0,235,255,26,255,211,28,12,1,13,255,52,254,251,0,73,0,12,0,115,0,238,255,9,255,177,1,166,255,250,253,194,3,0,0,64,252,184,0,207,254,45,248,20,1,160,6,114,9,14,1,164,247,41,255,234,253,123,254,109,254,84,242,160,1,55,2,119,254,73,255,253,0,156,255,227,254,149,255,100,0,25,1,241,253,128,244,170,255,92,10,55,1,239,252,213,252,229,254,169,1,179,255,137,1,136,0,170,0,10,5,3,253,108,0,164,2,43,255,54,251,42,254,171,1,171,13,104,2,69,251,30,255,219,255,88,0,24,245,95,1,78,0,97,244,99,0,192,0,110,5,174,254,47,0,248,255,58,0,1,255,50,0,221,0,207,255,236,252,49,255,182,247,89,255,76,253,123,1,89,243,59,252,70,253,49,254,211,255,34,0,249,6,2,4,173,251,113,0,124,0,254,254,235,254,54,253,204,10,78,255,56,255,139,3,211,255,43,255,241,245,238,253,144,255,32,14,128,255,76,0,146,254,121,255,234,255,205,255,125,0,156,255,177,255,142,0,54,0,107,0,87,0,237,1,222,255,35,255,64,254,13,255,226,3,77,3,208,237,151,255,25,254,41,0,144,255,93,1,24,239,184,255,1,2,144,255,83,253,42,254,118,255,227,253,84,1,31,250,232,255,37,0,169,0,107,254,78,254,78,244,214,255,96,254,121,248,15,6,48,250,164,1,179,0,190,255,14,0,92,0,147,0,141,0,241,1,148,1,100,254,253,8,80,1,195,244,203,248,76,252,240,252,6,1,45,255,6,0,114,249,78,254,103,250,41,253,230,4,30,2,106,250,210,254,22,6,107,0,105,2,191,252,143,254,78,255,146,6,247,245,48,251,236,249,169,255,78,255,144,1,78,255,85,254,132,255,193,255,142,0,35,255,33,0,64,11,29,255,156,254,46,254,222,242,114,254,89,255,164,0,126,0,59,0,255,255,5,0,212,0,25,0,14,8,50,254,223,255,210,255,45,0,55,255,55,3,244,254,210,254,39,14,133,1,126,1,136,0,226,255,192,255,2,0,168,253,42,12,160,10,17,1,180,253,21,255,199,254,115,255,37,0,228,255,99,1,184,0,79,254,146,255,192,253,200,255,134,0,145,253,241,254,31,246,63,245,179,3,39,5,254,255,108,2,36,0,100,254,62,248,221,0,108,254,2,2,151,12,150,255,217,5,144,254,89,255,114,255,146,254,131,255,16,0,142,0,77,254,96,255,29,11,103,255,214,1,131,1,45,12,181,255,137,254,146,2,3,1,243,2,253,255,160,14,251,253,90,250,101,253,92,5,100,249,117,0,160,255,195,0,55,255,122,255,180,255,179,0,97,0,71,0,95,7,161,0,109,1,228,0,153,4,235,0,190,252,208,255,131,6,157,251,169,8,47,255,100,0,37,255,38,245,81,0,189,253,93,13,186,254,20,254,23,255,78,0,32,0,117,0,182,255,176,255,85,0,230,254,197,1,244,1,209,2,32,3,83,0,144,253,232,3,165,0,236,255,252,253,159,239,178,254,107,0,197,4,29,250,246,255,11,2,85,0,212,255,21,0,34,0,199,0,150,255,71,247,13,2,90,8,40,0,201,255,193,255,13,224,70,1,77,1,104,255,229,255,137,0,212,0,130,0,246,255,76,0,195,255,143,255,224,253,77,255,69,255,0,0,68,235,66,1,186,254,1,2,159,1,119,1,164,255,158,254,69,0,77,0,65,0,93,0,160,254,91,255,211,248,254,6,146,3,236,254,167,8,118,250,87,1,25,1,4,0,27,1,46,17,159,6,8,255,153,0,90,255,239,2,54,3,106,254,56,254,5,255,185,0,5,255,34,255,87,255,246,254,77,231,249,0,216,255,211,255,53,255,47,0,173,255,147,253,82,255,71,1,30,0,114,0,227,255,7,254,32,255,12,7,46,6,12,247,54,8,22,253,91,254,170,0,182,1,85,255,153,0,84,0,99,255,135,244,133,255,175,255,29,255,158,255,7,1,203,13,36,0,105,0,33,254,162,255,155,254,234,255,132,255,23,1,140,255,31,2,201,0,119,254,30,255,49,247,123,255,77,6,133,255,127,10,70,0,191,0,240,0,28,252,92,253,94,2,35,251,206,254,157,1,240,254,229,253,229,1,255,13,32,255,176,1,133,1,31,0,136,252,62,1,107,255,28,255,252,2,86,254,72,6,160,245,254,0,111,247,252,0,228,1,166,255,139,255,255,254,94,247,100,255,41,2,47,2,168,2,42,1,240,255,249,253,148,4,124,8,8,5,143,255,186,0,57,255,121,250,173,255,64,248,155,2,11,252,88,1,113,254,73,11,105,251,116,252,186,0,185,0,234,255,184,254,60,12,114,251,209,0,43,255,130,1,92,8,40,2,255,3,207,2,17,2,87,255,165,1,196,0,76,0,203,7,20,2,181,255,12,8,242,253,140,1,158,11,248,254,164,254,149,0,74,2,22,0,97,0,175,254,4,255,101,1,103,0,252,246,238,245,212,248,235,254,90,1,198,254,35,252,185,0,198,254,102,0,56,0,195,14,247,254,251,251,244,255,130,255,81,254,100,1,67,246,170,255,172,0,116,0,61,0,110,255,84,247,211,0,91,255,233,0,185,254,73,0,249,255,152,255,222,253,253,0,154,246,105,1,204,8,230,1,163,2,79,255,83,10,91,2,44,1,99,4,126,253,105,1,172,2,153,247,57,2,10,252,120,0,206,255,65,1,102,12,8,12,35,253,85,254,43,1,169,0,133,255,116,255,243,255,197,254,21,0,136,255,232,255,174,0,65,255,162,254,94,225,111,255,87,255,93,254,241,255,150,0,126,255,183,255,162,0,247,255,38,0,225,254,109,0,134,1,147,0,151,0,115,7,109,239,7,0,49,255,109,255,26,255,169,254,139,255,145,255,107,0,132,0,177,5,168,255,248,255,67,254,80,255,84,255,249,248,211,252,230,1,126,4,46,244,88,255,196,245,184,253,178,0,225,253,180,248,153,254,143,255,9,249,214,0,105,253,217,1,98,3,120,255,169,0,4,243,127,255,180,242,7,255,234,0,166,1,251,0,84,1,169,254,231,0,134,0,214,255,32,0,64,0,47,255,12,0,236,0,245,254,93,254,1,0,4,1,147,255,108,25,105,0,7,0,239,254,133,255,149,255,104,255,238,254,99,255,75,0,74,0,55,255,46,0,37,0,82,1,235,255,76,255,208,0,239,230,26,3,250,0,175,255,183,253,4,0,137,255,198,254,17,2,219,0,159,0,124,255,235,254,76,0,155,253,69,19,15,0,213,0,157,9,30,1,30,2,177,0,207,10,133,1,136,0,238,2,47,2,30,252,172,2,244,255,223,247,222,253,167,255,107,241,36,2,148,253,163,2,118,0,135,255,190,0,204,255,19,0,237,255,25,0,56,251,88,1,22,12,237,247,7,0,17,1,12,251,137,254,215,254,55,255,15,1,65,255,123,0,6,0,252,254,236,8,204,254,10,244,242,0,156,2,35,255,122,4,194,4,217,1,123,255,82,0,57,0,112,0,115,249,78,0,27,255,98,1,49,254,251,2,92,6,195,8,106,5,94,6,111,255,255,0,196,255,228,0,195,0,160,252,235,9,46,254,217,3,253,243,2,0,118,0,221,0,117,254,62,254,0,255,98,255,224,255,11,241,220,7,206,255,47,254,146,0,189,251,194,254,15,1,244,255,84,2,160,0,120,0,92,0,47,255,177,254,104,0,228,255,177,2,49,1,220,253,175,252,81,6,93,2,185,0,98,254,59,15,239,254,51,0,182,0,64,255,121,0,104,2,195,4,158,1,65,252,133,239,39,5,60,0,246,0,44,254,224,255,225,0,82,1,217,255,211,4,225,247,202,8,114,2,121,0,40,1,119,255,173,254,178,248,209,255,115,254,124,0,6,236,166,0,239,252,123,2,240,253,154,255,13,1,236,1,71,255,154,253,122,0,132,255,85,0,145,0,14,1,102,255,39,0,220,9,58,0,199,255,119,0,5,0,87,1,57,11,234,254,237,252,137,0,62,0,87,255,1,8,196,5,187,254,130,0,66,253,66,11,237,255,54,1,254,254,121,255,88,0,244,254,69,0,69,0,183,2,113,248,47,3,166,2,44,0,13,12,22,1,181,253,210,250,104,1,145,0,239,255,66,0,85,246,174,253,132,0,102,1,150,1,143,254,19,255,35,13,73,1,88,254,52,0,49,0,35,1,20,255,228,246,251,254,49,0,229,255,170,0,72,14,42,255,165,253,8,1,60,0,169,255,145,0,116,0,179,0,190,0,167,2,83,1,172,254,200,12,129,2,185,245,228,1,159,0,49,1,34,1,208,0,226,0,68,0,102,0,111,255,156,254,153,0,135,2,2,248,169,3,126,249,69,4,227,255,119,251,237,2,200,246,171,0,119,247,73,3,130,250,223,251,28,249,212,254,51,255,196,1,120,8,42,255,103,255,35,1,150,255,79,0,181,6,236,255,21,249,30,1,46,254,174,2,167,0,137,0,5,0,43,0,51,4,215,245,5,1,170,255,179,254,44,253,162,0,186,0,4,0,178,254,100,254,203,254,120,3,142,255,19,2,41,1,188,16,41,1,97,249,44,255,75,0,249,254,247,246,102,0,78,254,96,1,235,248,40,254,114,0,71,255,6,0,66,0,125,31,158,1,191,253,160,2,104,255,152,0,1,0,38,0,190,255,48,0,221,255,62,0,158,255,237,255,78,241,98,0,242,0,114,0,103,1,94,255,115,0,34,244,84,1,253,0,242,253,112,255,14,0,109,255,28,0,160,254,30,233,46,0,171,253,120,254,226,0,202,255,186,255,209,255,211,255,16,0,53,0,137,0,172,0,55,244,234,255,93,255,245,254,39,243,225,255,82,255,110,0,26,3,169,1,67,0,58,0,184,255,100,255,97,15,183,253,68,8,99,0,165,251,255,254,33,3,14,1,183,254,255,254,238,255,122,0,143,254,108,247,210,6,207,254,87,2,32,3,237,2,186,5,213,254,17,250,1,255,23,255,217,0,139,255,0,255,45,1,7,255,185,254,154,21,86,0,135,0,240,252,119,255,98,2,249,255,55,0,93,0,150,255,206,255,11,1,27,255,230,255,210,251,13,0,181,255,197,6,113,11,126,255,55,253,15,0,160,247,104,0,194,254,26,1,248,255,227,254,44,254,132,255,59,0,8], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1502405);
/* memory initializer */ allocate([2,178,255,180,254,114,253,72,236,212,0,124,254,97,0,13,250,227,0,15,246,111,8,129,255,252,3,79,0,104,253,147,1,225,255,156,254,255,255,76,254,170,255,75,0,98,2,232,11,235,0,195,243,91,251,212,255,233,255,188,254,4,1,213,1,143,255,22,0,53,0,13,2,171,1,213,1,248,3,164,1,237,1,51,251,18,255,145,245,105,1,71,245,193,0,3,255,197,255,15,0,53,0,199,255,36,0,112,255,127,0,25,0,11,0,222,255,160,25,244,255,176,255,184,255,70,0,142,2,145,251,158,0,23,1,42,1,234,2,66,255,154,250,138,0,15,2,32,250,63,245,150,255,201,255,225,0,54,0,136,0,53,0,250,1,174,0,12,1,235,253,213,255,96,254,60,255,122,24,175,255,22,0,98,255,94,1,153,4,40,253,82,2,34,0,144,254,30,255,184,253,247,0,36,3,139,251,78,0,83,15,203,255,53,1,58,0,211,255,46,226,183,255,39,0,104,255,55,0,179,255,211,255,194,255,231,255,9,255,95,255,28,0,187,245,111,254,217,254,81,253,42,1,88,243,0,0,5,255,7,0,207,255,238,1,58,255,202,0,153,8,211,254,83,0,45,0,60,252,0,1,37,250,166,246,24,0,245,254,169,253,46,0,161,0,142,254,81,0,124,2,74,12,227,247,60,252,66,1,144,1,133,253,80,253,138,253,164,255,21,255,104,0,179,255,227,253,255,1,162,10,185,1,197,10,184,3,227,2,255,254,2,255,74,254,134,255,105,255,12,0,66,2,164,255,72,254,193,255,93,0,107,19,13,254,163,1,94,5,91,255,95,254,64,0,243,255,21,255,56,4,179,255,24,2,68,0,182,252,252,252,91,6,41,254,186,250,112,255,33,11,219,0,114,0,68,0,201,255,94,1,245,255,202,250,30,244,142,4,109,255,133,252,29,254,181,5,83,1,40,3,106,1,155,255,9,245,232,255,135,254,6,2,74,254,194,0,146,255,194,0,198,252,52,13,175,255,226,255,213,255,103,0,157,255,3,6,154,253,243,255,126,251,196,0,206,243,247,253,174,5,193,254,159,0,84,254,210,2,48,255,162,0,79,7,230,9,239,8,178,3,5,1,29,254,123,253,26,0,86,255,225,255,17,0,164,0,104,0,212,255,0,224,236,255,94,0,21,255,56,0,68,0,198,255,124,1,231,255,86,255,17,0,16,0,102,255,63,0,221,1,0,5,102,2,239,253,213,246,152,254,159,0,175,7,219,247,229,1,79,1,122,1,178,0,97,6,75,254,210,255,23,0,128,2,185,5,165,255,255,4,255,251,17,252,20,255,72,10,255,254,6,1,177,0,213,11,179,243,23,252,231,0,250,254,87,0,13,255,188,255,171,253,109,0,62,0,248,254,37,0,49,254,223,243,135,253,113,3,2,4,170,255,161,1,193,2,136,251,188,255,220,247,46,0,124,0,220,255,99,246,183,255,130,255,209,254,55,4,154,254,52,245,7,253,82,250,11,255,203,0,0,0,77,255,139,255,11,10,113,237,236,255,194,0,42,1,2,1,134,1,14,1,220,255,182,0,152,0,200,255,159,255,209,255,138,0,23,255,145,255,46,250,22,254,183,254,150,2,192,254,167,237,187,1,66,0,96,1,203,0,142,255,137,255,186,0,137,2,150,255,251,255,232,8,108,4,136,254,144,4,151,3,66,7,15,1,51,249,126,255,196,242,8,1,106,2,185,246,4,1,255,4,110,0,220,2,128,0,139,254,54,0,74,255,99,0,125,255,9,0,30,0,173,255,27,0,204,0,109,0,206,254,247,26,130,0,249,255,141,255,92,0,15,255,119,0,128,253,153,252,216,255,116,1,188,255,109,255,33,250,198,255,152,3,46,254,55,1,144,0,192,241,135,255,155,254,5,0,176,7,31,253,45,250,84,2,50,3,122,0,176,2,119,255,145,246,144,254,236,0,71,0,171,253,63,255,117,254,27,3,87,3,145,2,207,255,76,3,8,243,127,248,78,3,17,0,219,254,239,255,116,249,222,248,118,255,129,3,49,255,253,255,46,7,123,252,86,0,19,1,196,3,230,0,254,1,246,255,63,11,109,15,76,1,33,1,109,0,27,255,18,0,238,0,244,0,31,1,44,0,103,0,111,1,21,0,146,251,134,254,58,5,196,252,172,13,5,0,3,4,219,1,208,0,142,2,77,2,164,255,236,0,171,255,141,255,71,4,56,246,59,3,139,252,218,252,101,255,64,8,166,254,96,4,162,254,113,252,22,255,231,0,55,0,87,0,165,7,89,2,243,2,32,251,241,2,90,245,31,254,246,7,96,0,149,254,53,1,150,0,43,1,207,253,70,253,250,251,118,0,200,4,168,12,13,250,196,5,86,1,80,253,180,255,192,0,248,255,193,254,94,1,149,0,181,254,155,0,76,254,30,1,30,252,160,0,120,245,89,254,18,245,121,255,148,255,226,244,2,255,6,14,94,1,130,0,214,252,207,1,133,255,59,0,0,255,251,0,18,253,180,255,248,255,159,249,150,0,93,252,166,7,243,5,33,246,239,0,225,254,172,0,76,1,243,255,230,1,247,0,230,255,149,0,59,0,130,0,9,1,19,0,209,0,52,28,233,255,157,255,187,255,190,255,186,255,202,255,181,255,60,0,248,254,154,255,55,4,233,253,51,6,211,253,37,250,241,0,220,245,133,4,116,255,14,1,33,0,194,244,54,253,26,12,180,255,205,255,232,0,118,0,244,252,77,253,245,254,203,254,105,0,77,255,251,255,172,255,245,255,136,255,133,254,202,1,167,243,65,0,178,11,64,0,118,1,72,254,62,0,73,255,28,0,207,253,73,0,59,0,251,245,189,1,61,254,254,251,181,1,10,0,83,255,219,4,26,247,31,254,117,254,102,255,158,246,177,3,27,245,117,0,96,251,75,0,64,253,15,2,222,1,179,253,17,0,131,0,146,255,62,2,225,251,140,253,235,254,238,10,203,5,111,253,52,248,8,255,194,0,228,254,54,3,225,0,86,255,246,255,210,254,85,254,92,249,166,255,196,10,76,8,207,255,60,252,116,1,131,253,187,1,13,0,187,255,185,255,196,0,77,248,110,0,123,4,186,2,53,5,89,5,15,2,165,0,135,3,65,2,170,247,56,0,223,255,34,0,183,0,247,0,170,254,206,3,55,4,174,9,230,255,80,0,183,246,174,1,114,250,172,1,117,247,43,254,0,251,186,254,216,255,188,0,143,3,149,1,212,10,23,1,19,254,9,1,0,3,45,0,146,22,44,0,121,0,255,254,121,255,124,0,7,1,15,0,197,0,142,255,5,0,242,255,248,255,174,255,149,15,1,254,197,0,142,9,220,254,51,255,105,252,162,0,135,255,145,0,216,255,71,0,151,255,72,0,243,7,192,3,111,255,45,254,250,253,167,0,84,244,165,1,92,3,64,1,40,0,66,254,63,1,160,0,140,0,255,1,201,255,213,0,108,255,241,253,102,253,175,2,9,0,23,0,88,1,100,255,218,237,131,255,36,255,9,0,134,0,231,255,16,0,217,250,251,2,58,0,206,249,74,254,45,1,101,254,175,254,186,242,102,1,188,255,145,255,107,21,220,255,56,254,162,255,140,255,204,0,95,0,84,0,183,255,93,255,69,0,66,255,64,0,124,241,186,254,23,7,181,252,56,1,14,254,172,2,127,253,2,253,152,255,94,2,70,0,70,10,51,0,86,255,0,242,167,0,205,1,94,255,132,0,240,1,91,0,171,0,255,0,48,0,2,0,136,255,84,251,22,2,81,254,109,10,109,254,8,0,31,1,121,254,253,9,81,3,167,0,237,254,72,255,93,2,14,242,113,0,22,0,230,245,156,2,38,1,114,252,67,0,115,255,0,0,162,1,15,1,75,0,90,0,132,255,190,1,114,255,133,253,119,2,68,252,30,6,25,0,66,248,22,3,210,10,33,0,248,253,23,0,192,226,67,0,183,255,60,0,64,0,210,255,220,255,76,0,3,0,22,0,149,0,61,0,34,0,255,0,132,254,228,254,29,246,113,250,227,5,98,252,206,251,95,252,106,250,115,255,165,0,176,255,244,254,21,0,1,253,6,6,125,12,65,255,222,7,208,254,83,2,24,2,118,252,130,255,158,254,180,255,94,255,131,255,189,243,125,12,166,3,110,1,101,252,182,254,21,1,228,254,93,255,244,255,146,1,15,0,110,255,20,0,83,0,111,0,196,0,23,0,71,0,77,0,119,28,81,255,243,255,29,255,197,255,200,255,228,255,1,0,163,0,206,255,59,0,123,2,150,0,95,0,190,10,7,3,247,247,167,1,202,251,213,6,253,255,113,253,147,254,155,254,145,0,180,255,5,0,163,255,224,0,150,0,108,0,222,255,173,0,148,0,141,254,34,0,48,0,155,224,65,0,50,0,103,0,214,255,246,255,160,255,166,255,253,255,60,0,92,0,177,255,180,255,130,1,114,0,101,248,65,3,1,251,28,254,217,0,84,12,226,0,229,1,167,4,169,1,88,0,197,255,13,255,244,8,145,6,159,2,62,0,131,3,107,246,156,255,15,4,201,2,152,255,42,2,219,0,100,1,195,3,229,2,154,255,199,1,19,8,188,254,172,0,28,0,4,3,240,2,209,246,98,250,159,252,124,249,105,0,10,4,171,4,14,0,162,254,87,254,120,253,38,8,236,253,122,2,1,6,223,255,170,253,72,11,171,255,184,0,158,0,92,255,11,13,237,0,228,254,202,255,10,255,46,0,2,255,109,1,55,0,136,7,166,254,155,254,75,1,139,0,16,0,162,2,128,254,189,255,185,242,165,0,76,0,215,0,137,0,141,243,110,255,248,254,91,255,33,244,235,0,227,253,138,253,224,255,223,255,45,255,160,0,135,255,145,255,240,250,209,255,128,255,36,1,13,250,4,6,3,3,90,255,3,254,212,0,198,10,185,254,94,254,207,254,247,255,209,1,209,9,195,0,186,255,47,255,190,255,127,0,109,255,167,243,64,255,227,253,213,253,131,0,166,252,183,249,205,3,100,255,171,248,60,0,243,3,66,0,164,254,144,3,61,249,240,250,49,1,143,254,208,253,214,1,46,0,161,252,132,255,219,255,40,0,117,254,234,236,236,255,221,0,228,0,177,0,182,0,98,0,105,255,61,255,86,3,62,255,138,254,45,1,74,2,58,0,116,252,237,255,154,239,85,255,74,1,48,0,16,243,92,255,121,7,159,4,214,255,7,5,159,254,245,2,108,2,221,253,251,0,248,253,59,0,43,0,77,255,65,255,125,255,121,244,80,252,81,246,88,1,211,252,104,0,71,253,212,255,242,254,198,0,245,0,50,11,208,0,178,0,8,255,38,0,19,0,65,2,252,10,3,253,169,252,73,254,196,255,226,255,160,254,241,5,211,251,201,1,159,1,60,2,19,253,112,255,100,0,3,2,230,252,238,249,203,9,242,254,10,0,62,0,203,9,242,249,181,255,70,0,226,9,50,2,132,0,115,255,251,0,156,0,67,3,102,0,205,2,154,12,255,12,172,0,84,0,51,255,245,255,208,0,202,254,164,0,229,255,11,0,25,1,37,0,250,253,20,0,180,255,82,0,60,21,225,253,211,254,112,0,103,1,116,255,162,255,78,0,238,255,38,0,60,255,164,255,13,0,145,255,233,255,30,0,241,255,162,255,101,0,142,0,201,230,65,1,66,1,50,0,40,255,191,254,246,255,47,254,101,0,45,0,183,253,55,252,224,4,56,254,37,246,172,252,175,247,135,252,33,0,112,250,182,5,71,2,237,2,15,2,55,249,238,4,174,253,158,1,41,255,96,251,156,1,222,6,212,248,224,4,184,1,78,255,16,3,7,14,29,255,43,0,19,254,2,253,242,254,150,0,151,0,200,255,146,255,240,244,183,255,90,255,214,1,77,255,87,253,71,0,142,255,73,245,218,252,208,253,63,0,12,255,166,255,182,0,113,255,227,3,148,1,243,255,193,250,244,5,88,246,182,6,67,252,205,4,202,1,117,254,255,244,189,253,157,255,84,1,2,6,172,2,20,254,132,4,211,255,191,255,207,254,128,250,187,254,242,254,154,254,129,255,92,0,159,255,159,1,85,0,115,237,173,0,216,254,53,255,75,1,59,1,184,0,210,255,35,5,110,255,201,255,171,1,37,0,255,0,47,255,16,1,223,2,250,1,105,0,103,0,134,3,135,242,116,0,0,9,104,2,228,249,228,5,222,1,64,1,142,246,244,0,80,255,224,255,238,0,92,0,34,1,88,255,178,255,120,242,14,1,146,248,2,0,184,2,92,0,182,249,50,255,207,255,178,0,121,0,27,0,119,0,72,0,3,255,114,254,96,245,175,255,94,255,218,253,35,10,165,5,249,0,152,255,218,0,202,254,161,255,18,0,39,254,116,7,176,1,29,255,88,255,91,245,16,255,218,248,199,0,181,1,144,250,48,1,181,5,166,246,165,253,228,253,1,3,84,1,152,255,33,6,235,255,82,1,150,252,253,5,25,1,197,255,231,1,72,8,179,0,116,255,184,254,199,255,63,0,146,255,206,250,27,254,133,246,135,4,99,1,230,255,249,247,154,0,205,253,124,255,49,0,183,254,69,255,232,255,185,255,126,240,20,1,158,0,92,0,54,255,7,0,90,254,190,253,186,0,105,254,96,19,173,253,3,4,161,1,179,2,69,0,133,0,123,0,109,255,246,240,247,250,63,254,220,255,102,251,105,251,193,2,159,255,37,0,118,253,170,1,35,254,111,255,124,0,6,0,207,0,160,255,183,243,101,11,252,254,93,1,156,2,184,255,6,0,157,0,194,255,128,255,20,0,174,255,179,250,61,253,149,253,199,254,27,255,194,11,87,255,229,255,226,2,203,3,86,250,246,0,154,0,93,255,241,255,163,255,5,0,221,255,214,255,24,0,31,0,231,255,147,26,33,0,224,255,188,255,188,255,212,255,61,1,43,0,150,255,96,2,25,252,69,253,70,2,46,0,95,6,62,3,222,249,171,245,224,3,78,8,132,0,73,9,15,6,247,0,9,255,228,5,222,255,162,0,237,254,175,255,114,253,143,253,125,0,223,255,46,255,53,1,132,3,59,2,214,2,131,10,5,11,70,253,60,0,46,0,29,254,14,0,46,255,217,254,102,0,214,0,226,0,62,10,174,255,122,254,156,5,107,0,42,2,125,1,27,5,235,8,66,255,27,0,221,255,181,21,27,1,103,0,180,0,104,0,167,255,70,255,193,254,31,255,115,255,92,0,1,0,106,248,1,4,138,3,32,0,253,255,191,251,182,0,225,252,227,1,144,254,58,249,153,255,144,6,218,1,123,255,213,251,223,253,37,255,138,255,133,253,1,246,234,3,250,9,128,253,7,254,179,0,168,254,175,255,107,0,195,255,79,0,244,255,227,255,219,255,106,226,164,255,64,0,92,0,92,255,236,255,195,255,221,255,200,254,97,255,77,1,183,242,220,245,168,254,88,0,92,2,23,2,169,255,109,1,243,255,179,255,131,0,127,0,76,2,46,1,162,255,6,254,123,9,99,0,48,1,93,10,176,251,100,5,208,3,238,253,136,255,151,255,37,1,9,0,198,252,132,1,190,255,165,1,54,255,93,2,163,2,220,15,210,3,143,0,162,255,21,0,116,246,226,255,42,2,183,2,62,11,145,2,152,255,77,254,186,254,51,1,20,0,20,0,159,0,106,0,111,242,70,1,251,251,208,254,158,2,195,247,81,254,61,2,192,2,37,1,211,255,87,255,137,255,65,255,87,2,114,252,184,7,91,255,69,2,185,4,103,249,61,9,142,254,167,253,72,253,118,1,202,0,142,255,195,255,3,0,193,255,30,0,113,1,98,255,128,255,198,0,52,0,158,255,212,255,189,254,2,236,180,251,99,253,208,8,32,0,190,255,206,0,65,0,241,10,15,3,42,254,51,252,215,1,45,255,229,255,87,7,46,1,124,254,7,255,45,1,25,2,201,10,65,1,59,2,20,0,81,1,56,5,10,2,231,0,112,1,149,254,239,247,199,255,251,245,184,253,157,253,56,0,46,3,130,254,135,6,152,1,236,1,12,0,177,4,233,5,247,0,117,8,176,253,34,251,19,254,12,252,206,250,227,4,75,0,156,255,182,0,52,0,209,255,198,2,143,251,116,9,209,253,10,1,223,252,219,9,205,4,224,2,103,254,207,255,13,1,82,255,77,255,232,255,92,1,107,253,251,0,241,251,87,10,27,1,216,2,198,248,216,247,196,0,39,0,184,255,221,255,162,255,228,253,10,1,84,1,62,254,251,2,251,255,113,0,58,10,79,245,23,4,10,255,246,253,74,255,120,1,44,4,203,0,214,4,86,252,211,0,204,254,117,254,139,253,84,2,182,245,172,5,125,251,83,0,167,255,207,243,163,1,40,0,131,10,206,254,169,254,4,0,165,254,43,253,139,255,197,254,115,0,41,255,26,0,173,1,50,4,217,248,198,248,49,10,72,0,211,1,191,0,176,1,89,3,70,255,0,0,69,254,232,255,244,1,29,2,30,0,20,9,120,251,127,251,247,6,2,5,56,248,101,0,148,255,148,255,44,2,36,248,250,1,179,2,191,255,158,253,146,1,98,2,149,7,135,255,174,3,77,2,87,7,58,0,56,1,86,247,248,247,20,247,162,254,59,254,50,1,38,0,189,253,71,255,155,255,60,255,106,255,156,0,126,0,212,255,113,255,13,225,126,0,136,255,118,255,23,255,97,0,236,255,135,255,81,255,248,255,243,255,133,255,147,254,251,0,218,2,67,11,155,2,94,254,48,255,122,8,94,250,196,0,123,254,252,253,252,0,158,255,13,2,229,248,121,253,39,6,0,3,100,4,84,254,14,252,21,248,155,1,39,254,95,3,210,0,140,3,40,0,145,0,37,0,192,0,189,0,52,0,39,255,88,255,63,0,249,255,203,255,135,255,13,0,111,255,0,0,219,255,61,0,213,224,114,255,32,0,118,0,190,0,249,255,243,255,113,0,36,0,31,0,181,5,216,247,87,9,85,252,190,255,54,3,24,1,246,0,99,255,73,255,79,254,156,254,88,0,155,255,129,15,196,242,172,255,84,0,130,0,35,0,74,0,37,0,181,0,61,255,219,0,227,255,233,255,224,255,69,0,113,2,24,9,64,255,199,245,31,1,31,2,188,249,55,3,221,253,235,254,252,2,20,1,156,0,198,0,17,0,84,0,90,1,229,255,127,255,143,0,217,0,212,0,7,255,20,0,49,25,7,0,51,0,135,252,168,255,9,1,26,1,92,248,47,5,255,251,58,5,83,249,16,252,116,1,57,0,124,5,234,0,61,10,238,255,151,2,45,1,0,0,167,0,140,254,26,246,153,7,65,255,198,0,103,1,213,255,92,0,24,0,134,234,193,255,189,0,36,0,143,254,96,1,125,1,51,255,112,255,137,255,245,254,196,255,246,255,131,1,84,9,101,255,62,254,209,1,249,5,40,255,113,10,110,255,118,0,50,0,34,1,147,0,11,0,160,244,95,3,136,8,79,253,212,255,59,0,105,253,151,2,163,2,39,1,51,5,141,255,246,255,202,255,255,255,31,0,163,6,127,0,215,0,150,11,163,0,160,1,227,251,192,4,100,1,148,5,90,255,84,255,254,255,157,254,87,255,181,254,162,255,178,255,133,255,11,19,55,1,67,0,121,4,141,1,224,254,212,0,168,254,222,254,126,0,16,0,176,0,229,1,39,2,242,253,11,0,120,0,238,254,83,0,233,234,102,255,181,249,119,3,65,1,66,254,142,4,179,254,140,2,54,1,129,252,62,0,37,255,24,11,15,253,222,255,125,243,240,241,208,1,7,255,80,1,41,1,171,255,60,1,144,0,50,1,7,255,149,0,112,0,73,0,192,0,167,255,18,0,197,0,116,0,51,0,37,0,212,0,176,227,163,0,31,0,204,255,225,255,155,255,170,250,159,254,187,254,201,250,72,254,169,4,158,2,181,245,104,3,120,5,221,2,139,1,122,0,130,0,206,239,0,0,130,254,206,5,52,1,155,4,100,254,32,1,189,2,161,0,147,0,191,3,60,0,77,0,133,255,17,0,193,0,204,0,30,255,132,1,16,1,180,253,99,255,7,11,223,2,23,253,64,9,103,1,192,251,44,248,243,250,226,7,227,1,64,1,10,252,218,252,33,254,188,255,205,255,168,0,105,3,27,0,30,225,57,0,19,0,233,255,27,0,43,0,243,255,206,255,93,0,16,0,29,0,31,0,230,255,32,0,234,255,197,1,106,11,0,246,138,0,155,3,35,251,107,254,10,0,228,0,242,254,145,0,64,255,83,0,48,0,101,0,77,0,30,255,36,0,112,30,126,0,237,254,219,255,220,255,9,0,45,0,167,255,13,0,148,0,125,0,24,0,70,254,111,0,244,255,28,2,2,7,192,11,84,6,71,255,142,250,95,255,231,255,199,254,195,254,79,2,203,9,134,0,143,254,77,0,15,2,149,253,20,255,121,10,87,0,220,251,222,255,102,7,157,251,117,1,140,253,142,7,1,251,103,249,159,253,40,254,170,253,149,1,229,0,158,1,12,0,149,244,223,255,77,254,207,255,76,9,222,255,168,254,133,247,228,254,18,1,226,0,225,254,172,255,199,255,255,255,87,255,206,255,223,1,195,2,42,245,236,253,128,253,12,255,44,0,202,1,215,9,178,253,40,254,219,26,152,255,190,255,161,0,57,0,24,0,252,255,76,0,134,255,156,255,31,0,188,0,137,255,206,255,12,255,49,0,1,0,156,255,43,2,253,0,177,1,121,2,93,255,31,235,86,255,39,255,207,255,227,255,75,1,121,2,169,255,210,255,227,255,44,0,82,255,182,255,140,8,178,1,148,2,175,253,12,6,123,1,163,5,140,6,193,255,179,247,246,0,22,2,49,254,104,3,87,255,244,255,33,0,211,0,103,254,152,1,234,5,67,255,235,254,135,1,151,254,221,255,145,0,150,254,195,237,212,0,159,255,191,255,131,1,175,255,70,0,36,0,192,1,47,1,76,1,203,251,254,254,183,250,161,4,206,255,244,255,182,255,203,247,125,9,25,7,85,252,137,1,169,0,234,255,220,255,195,4,165,12,48,3,196,1,15,7,122,253,151,1,65,254,14,249,142,254,240,253,129,255,104,0,160,1,135,255,122,255,194,255,20,0,215,6,128,253,34,255,182,3,67,6,43,2,9,0,219,0,8,251,164,10,236,3,213,4,117,254,100,1,59,254,158,255,232,255,80,0,171,249,218,1,101,248,19,255,221,251,213,247,12,3,187,4,171,3,12,1,100,254,131,7,93,254,83,3,230,0,55,2,143,0,48,0,226,5,180,8,54,251,59,254,246,0,213,1,28,2,230,253,160,255,209,3,252,1,105,0,178,243,114,255,219,255,139,1,9,0,218,255,1,0,121,255,121,254,166,6,77,255,226,249,147,243,113,249,203,0,105,255,131,1,250,0,51,2,203,0,187,1,88,255,82,0,61,0,68,6,170,248,229,0,174,255,208,0,149,11,69,4,251,0,56,6,80,254,236,253,153,0,151,1,157,0,191,0,40,255,52,0,198,255,167,3,143,247,103,254,255,253,209,3,143,255,175,12,73,251,25,253,102,251,136,0,206,0,184,0,139,252,192,255,16,0,233,255,232,255,219,2,233,6,83,252,7,6,174,246,99,253,66,252,233,0,105,0,156,251,180,3,97,0,99,248,59,0,104,255,191,255,114,0,82,0,131,1,140,248,20,254,129,0,144,253,93,0,146,2,15,253,8,4,176,9,16,249,104,1,218,255,132,7,168,0,244,255,246,255,128,255,80,249,66,254,171,3,209,1,93,2,182,253,213,254,119,254,38,15,111,0,133,254,146,0,186,0,206,255,233,254,226,255,253,255,35,0,107,248,104,1,177,255,145,255,65,239,250,255,159,2,42,255,232,252,21,1,77,0,58,0,8,0,16,0,133,0,161,0,21,0,33,0,255,5,216,254,148,245,130,243,228,255,126,254,132,4,144,0,55,255,0,1,101,254,42,1,67,0,158,2,11,0,29,255,252,255,152,255,12,0,24,252,168,4,92,3,45,3,104,1,25,0,93,0,24,3,162,254,81,0,206,15,78,255,122,0,76,1,28,0,144,255,248,255,32,1,27,2,239,255,193,255,8,0,231,0,55,0,254,253,105,0,168,254,252,0,103,255,59,0,246,255,235,255,51,0,137,26,45,0,3,1,128,1,209,0,38,248,55,1,255,252,91,248,231,10,49,254,219,254,38,255,2,4,129,3,226,252,47,0,243,253,31,0,214,255,226,7,49,245,122,6,173,2,101,248,46,0,68,250,84,1,240,254,62,1,21,0,91,254,116,254,244,0,205,255,34,1,45,0,3,0,6,250,79,5,159,241,207,5,103,249,209,0,182,1,239,252,36,255,2,0,201,255,29,254,221,255,40,0,6,0,189,0,56,255,2,0,22,248,45,249,70,3,144,252,104,4,220,243,184,0,97,253,251,254,8,0,40,1,126,255,178,255,244,254,156,255,18,0,151,255,247,255,192,1,112,12,198,253,144,2,136,254,55,252,146,6,75,10,235,254,65,2,217,0,25,1,219,0,161,254,31,0,64,0,101,0,82,0,189,3,163,248,6,3,48,242,88,255,81,254,150,255,33,254,17,4,153,255,6,3,114,255,126,3,44,253,162,255,2,253,198,255,112,0,236,7,54,2,166,254,117,255,145,245,141,248,15,4,189,0,223,255,154,6,7,1,254,253,31,255,19,255,145,0,193,254,38,0,116,0,75,11,179,255,239,247,255,9,185,254,5,253,86,0,84,255,229,254,109,255,137,0,245,0,179,254,220,0,92,0,194,0,80,255,105,0,36,12,73,1,140,254,92,251,158,2,5,3,21,255,34,0,110,255,108,3,253,254,212,249,108,3,105,0,70,2,3,1,193,255,157,255,234,249,98,4,251,249,74,254,227,0,197,4,239,250,22,253,138,10,227,255,145,4,227,3,254,255,201,0,136,1,107,254,234,255,220,255,245,2,57,240,213,2,168,7,198,5,149,255,67,0,145,254,159,255,168,255,154,0,176,255,0,0,247,254,93,255,14,0,147,255,33,0,85,2,115,0,31,2,212,1,11,253,58,3,253,1,80,255,207,254,161,236,138,255,48,254,91,254,184,255,1,0,69,255,123,0,168,255,194,251,26,0,112,1,98,2,66,13,175,254,108,1,34,10,235,1,247,2,203,254,139,1,152,0,82,1,249,0,47,1,134,255,63,0,251,3,160,252,10,6,196,0,75,0,135,253,163,255,137,253,9,3,182,255,211,4,23,253,121,1,41,12,82,255,230,254,232,255,89,0,104,252,76,8,108,2,54,2,10,5,161,11,156,4,22,1,188,0,238,2,213,3,155,254,80,0,69,0,77,0,105,255,150,0,241,255,66,3,131,252,50,3,119,6,12,254,237,0,133,0,243,0,149,1,239,0,16,0,104,255,186,255,148,241,146,255,145,0,58,0,199,255,33,246,0,12,178,8,218,0,200,252,128,1,160,255,119,0,28,255,62,255,136,0,111,0,5,255,147,255,77,255,222,255,143,0,109,0,133,4,40,255,107,250,66,253,67,1,81,251,196,255,120,2,183,253,172,254,16,4,215,1,224,255,132,254,104,13,199,1,118,255,217,255,144,246,140,2,3,255,145,0,25,1,137,1,97,253,25,11,176,249,210,255,127,254,119,250,239,254,88,255,62,1,249,254,254,255,187,255,130,253,119,255,148,245,153,254,170,255,79,0,247,252,108,254,208,253,51,242,122,0,143,255,105,2,241,1,117,0,244,254,110,0,73,0,240,2,175,251,247,253,250,2,183,2,181,253,109,255,45,251,74,7,54,247,97,253,1,254,126,247,204,252,149,253,162,0,219,255,102,0,170,254,234,254,181,26,234,254,185,0,10,0,105,1,204,255,85,255,246,0,184,0,81,255,19,0,166,0,208,255,215,255,92,0,104,255,53,251,41,252,111,240,65,253,119,4,204,0,245,253,29,4,145,253,234,3,231,0,53,0,235,254,103,254,189,255,200,255,166,255,209,255,192,1,242,2,42,2,204,3,249,1,181,254,82,19,63,255,89,0,18,2,232,255,84,255,254,0,244,0,140,0,246,255,40,0,179,255,119,6,74,254,40,245,51,0,215,253,80,2,170,244,24,1,36,3,8,3,131,0,69,0,49,255,131,0,7,0,209,0,93,0,237,255,132,251,35,253,114,10,164,249,37,251,6,254,214,246,167,252,252,251,154,2,109,1,159,254,105,0,120,0,210,0,171,255,37,0,216,255,3,4,11,0,210,4,251,255,72,248,3,2,33,1,231,14,114,255,68,255,8,255,239,254,247,254,81,2,205,0,164,0,191,255,70,0,32,252,50,6,82,8,11,3,92,0,5,244,165,1,1,0,148,4,240,1,107,252,8,253,169,0,192,255,14,0,216,255,9,255,161,255,233,6,111,255,200,2,230,252,197,253,240,0,18,249,218,255,127,255,188,252,44,13,119,3,61,254,73,0,149,255,182,0,100,0,14,0,65,253,255,9,234,1,185,252,179,254,134,0,36,3,35,242,50,0,57,255,41,255,142,254,197,1,170,255,151,0,158,255,198,255,128,0,192,245,29,250,169,249,118,247,167,255,201,255,40,254,101,253,2,0,73,254,83,250,250,254,53,2,56,0,138,255,32,1,200,255,87,0,114,254,217,2,40,0,129,232,219,0,44,255,31,1,6,255,45,255,227,255,195,255,201,255,136,255,164,255,30,0,129,0,134,255,111,0,245,7,236,4,175,3,4,255,243,255,230,252,246,245,163,251,41,1,118,1,163,249,255,255,105,254,171,253,188,254,77,255,152,1,58,0,122,252,120,249,99,2,58,255,195,255,103,0,110,1,147,3,43,3,232,254,111,254,247,240,145,255,221,0,97,1,232,0,4,0,238,255,161,2,0,7,210,246,132,0,187,7,242,246,95,254,79,253,70,1,0,3,135,254,246,253,117,1,123,254,151,255,153,255,33,0,208,255,217,5,101,4,101,7,72,245,61,251,153,3,216,1,91,255,74,254,127,255,86,253,241,252,83,253,167,0,53,253,156,0,64,0,61,0,123,4,132,252,184,255,67,2,167,4,57,245,39,7,103,7,151,2,48,3,158,255,195,255,33,255,146,254,83,254,31,0,127,255,135,255,1,255,12,7,138,0,180,0,217,251,86,2,251,2,208,2,129,1,242,253,143,0,80,0,168,0,208,3,54,253,236,0,124,243,93,0,106,3,238,0,153,254,59,6,191,0,56,2,74,255,20,0,160,253,224,254,90,2,32,255,34,15,204,254,186,255,198,252,147,255,214,255,142,252,115,250,189,249,113,2,74,251,31,0,14,3,150,255,68,253,10,255,197,253,132,255,176,252,122,254,245,253,169,244,247,255,39,0,147,255,57,255,241,1,245,255,121,1,5,0,25,0,141,255,195,255,27,1,27,0,125,255,63,255,24,1,178,0,193,234,44,0,204,255,70,251,151,253,94,255,183,251,253,255,236,2,211,255,83,251,222,251,141,3,71,6,181,2,42,0,19,253,71,244,151,1,194,255,45,0,214,0,200,254,226,251,242,1,11,5,165,4,12,251,59,4,11,253,193,254,20,245,52,253,54,1,47,6,160,253,63,1,172,255,137,255,121,250,166,253,116,2,207,1,67,251,230,252,38,254,122,10,163,3,240,0,187,9,76,0,22,255,95,255,78,253,103,1,28,0,237,255,250,252,1,252,226,2,163,2,248,0,52,0,164,254,223,253,101,245,169,253,4,255,148,2,125,254,152,255,12,9,200,1,166,255,100,0,51,244,0,8,62,254,123,4,207,5,228,252,111,253,203,1,97,2,63,0,103,255,106,251,112,255,37,0,80,255,96,255,43,0,225,255,239,245,88,0,227,252,155,4,61,253,82,12,225,253,107,3,116,0,216,255,106,255,70,1,37,1,144,255,183,255,222,255,61,0,8,0,53,247,241,249,53,246,6,0,204,255,251,255,189,254,199,254,52,4,152,3,92,4,180,251,79,4,54,1,112,255,136,3,149,0,197,255,124,2,28,250,134,254,125,1,107,252,156,252,108,5,55,251,188,255,211,5,173,2,36,255,181,12,48,0,8,254,192,0,114,0,245,255,74,249,108,252,148,2,16,255,255,2,219,251,76,1,79,2,35,254,234,254,25,0,51,250,55,0,216,0,90,243,237,255,192,254,108,255,17,1,148,252,22,0,239,253,191,12,25,246,12,253,123,255,31,254,0,252,34,0,162,1,97,254,156,1,164,255,166,255,161,0,207,255,93,249,79,245,107,11,13,255,122,0,87,0,216,3,135,254,219,255,128,0,94,1,68,254,158,255,204,255,14,0,242,255,170,255,255,0,205,7,41,251,42,0,247,0,241,255,16,0,149,1,46,1,239,255,84,0,63,240,244,255,254,0,147,254,51,255,94,255,73,1,31,0,122,251,46,255,136,254,118,15,191,249,152,251,225,2,219,2,44,1,239,252,247,252,109,254,207,1,30,255,147,255,235,254,186,255,203,255,168,252,239,252,27,252,71,0,189,21,61,1,191,1,233,254,155,254,254,0,93,0,209,255,50,255,133,0,88,0,16,1,7,0,44,0,181,8,130,6,234,0,7,2,52,248,85,251,37,2,193,1,174,0,14,252,110,2,169,1,240,8,247,255,122,254,100,2,216,255,32,0,181,248,95,253,186,255,106,251,106,0,134,0,98,1,61,0,112,255,222,254,82,0,164,253,202,0,142,240,248,0,180,255,7,0,224,0,204,248,99,0,110,255,206,0,177,254,243,0,25,0,60,0,186,0,117,0,67,0,119,255,119,0,46,0,211,17,45,0,210,255,254,255,106,3,21,2,216,0,218,255,185,0,228,253,65,255,93,255,130,255,148,255,72,255,193,0,217,255,96,237,111,0,167,255,195,255,17,0,40,4,142,6,126,3,238,16,139,0,132,252,61,1,161,254,161,1,169,255,234,255,195,0,20,0,140,0,234,0,59,255,244,254,251,255,174,249,12,253,137,255,43,249,64,253,81,252,165,1,96,242,103,3,44,254,144,2,10,1,177,255,69,1,209,254,45,0,253,255,225,255,116,4,61,253,214,249,102,250,34,1,71,1,171,250,159,244,24,4,38,0,120,255,153,252,196,253,226,255,186,0,87,1,226,255,99,255,21,5,121,7,253,253,182,252,45,253,172,255,172,254,14,1,106,252,141,12,6,250,118,254,72,255,196,255,121,254,229,255,146,255,84,0,104,0,163,1,177,4,214,252,10,6,39,0,110,252,178,254,95,239,171,1,161,255,86,254,162,255,0,1,108,255,246,0,176,255,9,0,50,254,155,251,132,2,213,13,116,255,42,9,21,4,177,254,157,252,41,3,176,1,130,1,250,255,159,0,70,0,246,255,218,0,43,0,75,247,161,253,25,2,100,252,34,244,81,252,56,252,237,4,28,0,197,0,227,254,61,0,137,0,69,0,254,255,5,255,111,0,237,255,198,254,16,8,192,3,249,5,32,4,158,3,193,254,175,249,25,5,193,5,157,252,172,2,77,5,190,252,190,255,221,1,74,0,241,255,23,249,133,7,112,246,15,249,5,254,8,1,52,249,176,0,250,253,198,255,32,0,148,255,165,0,188,255,189,0,35,0,40,0,171,255,128,251,255,0,36,0,126,248,220,5,135,5,73,3,164,255,233,12,146,255,3,0,37,255,167,0,61,2,219,0,54,1,27,0,195,0,103,1,12,255,26,2,6,248,99,1,144,2,51,0,57,255,52,255,229,241,116,254,71,3,231,2,15,255,176,255,46,255,155,255,28,0,137,250,38,4,69,252,54,0,138,253,78,255,136,254,212,0,237,0,37,255,47,0,37,3,216,0,26,0,18,239,199,1,4,0,4,0,205,249,95,0,162,4,227,243,116,255,162,252,148,3,15,8,211,0,96,0,81,1,71,255,61,255,168,1,183,4,225,255,94,255,206,0,181,9,210,255,61,254,14,249,216,255,144,0,101,255,68,11,35,3,140,1,172,4,133,253,41,1,180,255,135,255,94,255,50,255,107,255,100,247,11,4,232,0,209,252,207,255,238,3,41,2,105,254,161,0,66,14,248,254,114,1,94,254,228,255,141,0,79,255,143,255,166,255,197,254,114,2,62,0,112,5,233,248,80,1,4,251,110,254,230,1,220,251,200,248,50,10,58,3,229,1,6,255,39,0,208,0,14,0,251,9,53,11,211,252,230,247,81,1,89,2,87,3,113,253,54,2,61,253,189,0,179,255,137,0,2,254,230,254,79,0,42,0,73,0,62,0,138,2,132,237,26,254,98,1,164,1,60,3,123,253,20,254,132,1,241,2,18,0,2,0,254,2,44,255,126,0,213,255,45,0,191,1,229,254,95,2,251,0,90,255,246,255,48,0,38,233,5,255,128,0,51,255,161,255,90,0,90,0,67,0,24,0,206,255,208,255,89,255,97,243,146,244,39,7,199,0,228,1,169,0,154,253,121,255,138,254,94,254,17,255,167,255,135,255,45,0,75,0,245,255,16,0,222,251,98,1,97,6,77,2,57,251,194,4,74,3,134,251,138,8,118,1,149,254,216,0,151,247,83,254,173,1,171,253,93,0,148,0,57,7,227,252,94,255,31,0,187,254,87,1,189,254,161,0,139,254,172,2,145,254,60,254,46,239,168,255,28,0,200,255,197,255,43,0,207,255,50,248,68,252,51,5,138,239,127,255,30,0,79,0,166,255,127,255,109,0,130,0,96,255,153,1,105,0,42,1,208,0,178,0,188,6,219,2,5,3,128,0,49,3,87,254,50,240,180,0,242,252,140,255,191,0,253,254,181,0,225,255,162,0,43,0,215,255,187,255,183,5,23,249,254,255,70,254,132,253,215,5,38,255,133,255,198,255,32,14,198,1,37,254,247,0,129,254,48,1,185,0,155,0,40,0,80,4,22,4,248,255,32,253,125,251,141,255,85,15,255,254,221,255,169,253,75,254,121,255,0,255,55,0,214,0,168,255,215,0,199,255,183,251,183,0,11,254,160,253,121,255,148,0,149,1,39,1,96,0,255,253,245,3,254,16,94,255,195,255,171,1,59,1,24,0,179,255,2,251,89,255,18,249,123,255,189,254,13,239,220,2,85,2,226,255,153,255,79,0,15,255,177,0,124,254,7,0,44,0,175,0,113,255,166,19,21,1,58,0,42,0,34,255,123,255,193,254,6,0,240,0,217,0,18,255,58,255,218,0,213,255,183,1,49,0,37,0,106,0,99,4,148,8,158,0,171,0,202,1,92,252,77,254,33,245,212,254,188,1,13,9,110,255,173,254,94,255,157,0,40,255,1,0,66,0,219,3,66,255,40,253,140,243,161,243,122,1,255,255,158,0,203,1,78,0,214,255,130,1,123,255,155,0,38,1,103,1,227,255,78,0,227,6,12,3,251,3,182,254,179,0,205,255,119,254,82,1,70,17,216,254,120,254,170,0,2,0,52,0,253,0,150,0,65,255,139,0,141,254,161,0,102,247,156,0,37,0,20,252,128,254,46,254,23,0,183,0,139,241,97,0,243,250,157,254,173,255,193,255,230,255,69,0,231,248,129,2,180,11,240,255,219,7,106,254,121,253,116,253,76,1,20,3,228,1,150,3,72,254,222,4,165,0,52,0,252,254,31,0,1,255,187,227,14,0,90,0,121,255,122,0,14,0,154,0,5,0,178,255,111,0,2,255,154,0,233,255,232,255,173,255,247,255,49,0,86,254,121,6,99,0,220,255,65,255,65,10,143,2,236,255,93,245,47,252,34,255,208,255,155,0,41,0,20,0,194,0,183,255,230,255,74,251,67,242,41,254,209,252,136,251,141,254,73,5,211,251,42,251,61,3,29,255,231,1,215,254,155,255,146,3,100,0,239,255,115,0,218,252,226,252,73,2,73,4,255,255,232,252,50,3,29,0,0,255,95,254,174,3,68,0,187,239,34,0,104,254,4,255,55,0,179,255,246,0,7,8,252,255,199,254,107,253,188,252,47,2,119,254,251,7,153,0,30,1,116,245,98,0,79,255,177,4,99,0,52,1,183,255,161,5,194,240,218,2,182,249,118,3,169,253,130,255,217,1,43,0,4,255,45,0,95,0,221,254,101,0,205,254,3,1,107,255,26,0,2,254,242,1,123,5,178,255,241,251,9,246,5,3,104,251,11,250,107,254,253,254,229,254,142,1,32,8,57,255,62,0,239,0,230,255,192,3,70,2,212,9,31,3,177,247,69,1,3,255,140,249,59,252,133,5,8,0,137,255,140,1,170,254,21,1,29,2,186,0,114,255,186,4,36,253,30,3,209,255,211,253,244,255,63,0,25,2,148,0,128,255,72,1,34,1,203,0,105,1,184,254,192,255,164,15,197,0,128,253,228,3,163,255,246,246,76,0,110,252,157,5,60,252,57,249,216,3,190,253,109,5,255,251,190,255,136,255,69,251,224,255,5,0,65,251,3,3,85,6,90,252,40,252,148,0,200,249,66,254,19,0,48,252,83,249,167,251,38,255,191,0,233,254,135,8,10,0,219,255,182,252,210,249,164,255,46,2,227,0,66,253,147,254,192,253,156,255,158,2,207,254,29,1,48,0,183,254,253,0,38,15,156,0,70,0,16,252,129,2,5,6,22,255,160,5,165,1,64,4,223,2,50,255,173,255,204,1,117,255,107,0,120,251,250,255,39,8,102,7,139,255,194,3,113,0,34,252,93,0,227,255,67,2,193,4,204,255,170,254,61,254,158,2,202,0,210,251,69,3,124,255,179,13,197,255,142,255,77,253,208,0,110,251,65,4,49,1,56,255,91,2,235,250,82,252,161,249,11,5,89,245,158,1,80,0,47,3,69,254,54,0,222,255,139,251,21,5,81,251,116,1,102,0,255,254,70,0,194,1,201,255,80,0,29,255,218,0,8,1,227,2,204,255,56,255,33,15,83,0,0,32,96,0,214,0,117,254,150,255,35,1,111,254,49,1,154,255,194,0,183,255,31,0,71,0,237,255,163,254,65,0,73,255,26,0,235,255,218,31,107,0,120,255,219,255,221,255,85,0,127,0,54,255,43,0,61,255,225,0,205,255,187,255,199,255,149,255,141,0,136,255,228,254,29,255,28,0,168,2,218,0,29,0,248,248,232,1,49,255,59,254,157,255,160,241,46,255,39,0,23,1,126,5,22,1,219,255,196,249,232,0,120,1,90,0,234,0,236,242,242,0,229,6,43,2,141,252,118,0,115,0,48,0,140,255,118,8,220,254,136,0,15,2,20,255,238,255,155,1,236,255,66,255,32,254,153,2,4,13,122,1,225,254,81,1,199,0,251,255,192,240,55,1,215,254,96,245,63,255,239,255,143,3,32,255,201,1,208,255,254,0,15,1,232,255,179,255,165,0,23,0,182,0,158,251,122,0,248,253,53,1,236,241,11,252,107,254,121,253,111,255,118,251,251,3,66,255,234,254,69,0,106,1,71,255,178,255,11,255,216,1,158,2,19,254,108,2,76,0,205,2,8,247,145,255,58,254,152,12,27,0,47,0,161,254,102,255,219,254,187,0,163,255,96,0,87,0,59,254,124,255,9,0,125,0,47,255,230,255,28,1,216,253,255,0,87,0,227,0,187,234,112,0,172,0,241,255,64,254,219,1,141,233,111,1,149,0,28,255,227,252,115,1,67,0,154,255,138,255,94,254,76,1,38,0,156,255,90,0,73,255,26,243,15,0,231,251,232,249,19,5,58,253,233,4,186,2,60,1,229,254,187,3,240,0,182,0,13,1,12,0,219,255,25,7,137,2,7,251,233,247,73,249,3,253,209,3,121,251,95,1,209,249,171,255,253,252,41,255,123,0,58,1,98,255,32,0,48,2,208,0,9,1,61,254,99,254,32,0,162,7,242,241,112,249,192,252,122,253,249,2,16,1,138,1,213,0,221,255,212,255,87,1,53,1,244,0,225,11,113,254,206,255,130,255,61,245,110,255,243,0,145,254,168,253,90,255,192,252,231,253,13,1,208,255,115,9,242,253,203,254,239,255,21,255,73,0,85,1,95,1,184,252,169,12,162,255,80,254,148,1,180,253,158,0,129,255,207,255,187,12,215,13,134,0,0,255,150,255,110,2,211,255,86,255,147,255,68,0,121,1,172,255,210,0,6,255,245,254,1,1,179,255,6,0,171,251,38,250,185,254,39,4,224,3,120,2,11,255,112,253,180,251,196,255,56,254,86,255,136,12,250,255,13,0,161,255,94,2,174,253,9,248,143,254,49,249,19,1,163,255,117,0,12,11,118,255,148,255,206,0,27,7,98,0,211,255,45,0,93,255,146,11,114,254,208,13,73,255,253,254,187,253,65,0,14,254,224,254,155,254,173,254,243,255,185,255,103,254,36,0,241,255,223,253,153,5,135,0,36,255,99,0,240,2,177,0,57,254,5,255,148,4,6,251,38,4,250,252,25,252,193,255,60,245,99,0,170,255,87,18,85,255,127,255,168,252,26,0,225,253,98,2,186,250,254,255,15,1,199,1,106,255,102,1,101,0,24,2,125,0,101,0,88,0,240,255,244,255,232,1,201,226,110,0,8,1,140,0,210,254,110,0,232,0,0,0,15,0,70,0,228,255,229,255,146,255,157,255,201,0,78,0,215,0,148,255,245,254,132,226,34,0,56,1,170,255,197,0,125,0,80,0,181,255,139,255,254,255,128,0,49,255,125,255,255,253,102,2,33,0,20,237,210,254,189,254,160,0,40,3,133,2,243,0,165,253,68,0,186,255,158,0,125,255,44,255,222,255,9,255,113,2,134,0,214,255,13], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1512645);
/* memory initializer */ allocate([2,167,255,31,0,116,0,255,255,252,1,157,19,139,1,111,0,170,255,84,255,153,5,142,255,130,255,108,255,175,254,252,254,233,0,33,254,19,1,9,255,216,233,130,1,146,255,157,255,114,255,85,255,102,255,154,254,30,0,4,4,178,255,63,2,11,2,182,253,29,253,50,6,52,4,41,246,36,6,88,250,55,255,166,0,202,255,137,0,244,4,133,4,101,254,167,244,195,0,233,1,28,253,154,0,10,2,228,8,164,253,194,0,168,251,192,0,144,1,241,254,250,0,157,1,17,1,158,0,213,254,150,252,28,255,106,246,162,0,51,3,201,1,73,13,177,2,48,255,214,254,51,254,152,254,186,255,171,247,142,255,132,255,81,0,28,255,113,2,197,13,141,3,254,0,22,255,36,5,251,252,19,2,226,255,240,255,92,255,172,255,56,9,148,248,95,1,93,244,33,2,141,2,160,1,17,1,177,255,199,252,149,255,71,0,239,1,223,0,80,255,129,0,40,0,168,1,91,6,207,0,47,0,248,255,239,254,53,253,60,0,27,251,221,5,81,251,8,255,39,0,43,11,80,254,89,0,43,1,180,3,208,245,128,252,140,13,84,0,255,1,55,0,151,0,221,2,14,1,158,254,214,1,37,255,141,255,151,255,91,0,253,254,149,7,7,3,12,0,204,10,228,1,45,2,240,8,138,255,38,1,224,255,207,2,194,255,192,255,217,254,174,255,111,255,227,254,20,254,87,0,121,255,158,255,194,0,224,254,248,255,7,1,37,254,203,255,124,254,245,21,41,0,228,255,34,0,189,254,138,0,143,7,242,248,71,255,84,1,100,5,48,0,226,253,107,244,173,254,88,0,42,2,41,0,4,0,105,255,182,0,217,255,63,255,229,242,200,254,34,12,53,255,186,1,146,255,61,1,243,254,225,0,31,0,194,255,235,254,163,0,2,253,104,254,210,0,198,255,128,0,161,0,236,12,249,12,118,255,234,254,107,255,216,0,134,0,3,255,121,255,102,255,133,255,254,0,200,0,254,255,133,0,205,254,147,231,54,1,250,255,191,3,26,0,191,0,59,1,16,2,181,255,26,255,53,255,153,0,247,254,162,255,195,255,254,255,201,10,241,237,159,254,237,255,102,0,117,255,54,0,182,1,11,1,183,255,191,1,226,0,71,0,237,255,75,0,216,255,224,255,174,252,12,254,166,1,213,4,80,253,101,1,170,243,44,254,62,254,233,254,74,253,171,251,222,2,190,249,139,255,122,0,5,1,211,3,236,255,129,1,143,244,86,1,164,243,110,255,252,0,152,255,62,0,213,1,33,1,249,0,42,255,218,255,73,0,83,0,249,255,18,0,118,254,251,255,116,255,245,254,75,1,109,255,140,25,139,1,153,255,109,255,241,254,236,255,191,0,73,0,101,255,197,0,71,0,247,1,19,0,138,0,127,255,79,1,209,0,75,0,193,231,140,0,80,255,251,255,35,0,216,255,195,255,110,255,56,4,58,0,71,1,207,255,182,252,151,5,83,2,133,13,1,0,142,0,209,7,41,1,240,255,87,254,132,4,155,255,202,255,36,4,34,255,217,254,170,3,68,251,186,246,73,0,240,254,10,243,248,255,50,253,114,0,102,255,85,0,247,255,72,0,86,0,206,250,226,0,122,250,247,253,89,12,192,248,133,0,240,0,13,254,141,254,23,253,11,3,49,254,6,254,207,1,27,255,30,255,133,1,135,0,215,239,104,1,223,2,194,254,9,3,81,2,209,3,82,255,30,1,187,0,161,255,166,249,245,0,97,0,9,0,21,1,43,1,32,6,42,4,119,1,62,5,122,254,116,3,15,1,185,0,254,254,180,251,65,8,149,255,65,254,131,248,198,255,227,255,57,4,57,254,244,253,60,255,77,7,91,253,20,242,163,5,29,0,87,254,228,255,142,254,170,254,228,255,30,0,138,255,58,0,95,2,198,1,45,0,136,255,232,0,20,0,21,0,81,255,144,255,20,255,236,1,155,1,42,0,214,255,201,15,39,0,237,245,235,0,110,255,122,0,24,0,21,5,123,0,51,254,64,243,60,1,168,255,47,255,140,0,131,1,82,254,78,0,252,1,149,0,252,241,83,4,52,3,116,255,142,2,44,3,202,253,238,245,109,254,184,255,120,0,99,1,120,255,135,255,209,0,240,0,116,0,231,0,94,6,208,0,78,255,168,243,155,8,204,255,195,1,84,0,202,254,81,251,84,2,69,0,29,1,242,0,15,0,49,0,85,1,102,255,18,247,182,4,147,255,24,4,121,253,103,4,98,0,16,251,216,252,208,6,195,249,13,0,26,0,40,255,7,1,204,12,120,12,151,255,122,254,225,255,164,2,73,0,9,1,31,0,101,0,223,1,187,255,123,0,232,255,207,255,32,0,115,253,205,8,49,0,166,254,196,5,28,7,140,1,127,2,37,255,24,3,192,6,147,0,3,253,116,255,157,4,98,0,153,0,158,255,13,253,169,9,196,1,231,0,239,7,164,9,96,254,75,2,212,2,148,0,244,1,91,252,27,255,55,0,102,0,74,0,92,255,140,2,87,254,100,0,132,245,78,5,90,6,162,254,32,2,211,254,203,249,207,254,14,251,11,0,243,0,131,255,182,254,38,1,191,5,150,244,45,6,222,253,70,2,231,0,129,250,147,252,90,2,219,0,94,1,106,4,170,255,214,0,200,255,201,0,75,255,164,247,84,4,237,1,200,1,226,253,143,255,172,252,111,6,105,7,72,3,102,251,143,254,20,3,232,1,0,1,110,1,250,8,143,4,51,255,0,1,73,2,213,253,36,1,55,10,236,2,9,255,178,251,110,249,226,0,159,1,20,0,27,0,100,0,9,0,180,1,46,249,61,10,47,6,45,255,191,252,185,1,54,0,97,251,198,252,108,252,61,253,52,2,24,255,242,255,147,0,197,1,70,0,70,4,121,252,175,254,194,1,246,249,106,253,233,251,215,246,213,252,243,251,96,0,48,2,101,5,137,255,129,254,208,230,197,255,42,1,109,253,197,255,73,1,199,253,141,1,32,255,128,0,40,255,153,0,156,255,63,1,203,255,166,255,50,0,241,12,4,0,41,255,149,1,0,255,78,0,74,11,69,255,55,252,195,0,2,252,137,255,214,0,254,0,152,254,34,255,39,0,91,8,91,0,222,254,17,2,183,255,240,255,194,254,128,0,164,254,53,2,90,251,202,0,71,255,22,255,170,13,48,0,68,0,131,248,158,6,212,0,35,254,239,0,27,243,23,254,168,1,162,1,174,255,195,255,87,2,250,5,56,255,4,255,162,0,13,255,43,0,234,253,121,245,255,0,61,1,233,1,23,1,9,13,246,0,163,254,107,255,128,255,110,255,0,1,57,254,137,0,181,255,68,3,209,0,163,254,166,13,255,0,100,248,36,253,111,1,93,5,45,255,96,2,89,1,239,255,43,0,102,0,19,0,37,255,173,0,199,246,130,0,162,252,125,2,153,255,179,253,219,0,19,251,18,255,32,246,107,6,205,249,78,253,90,255,7,0,199,255,197,4,70,1,103,0,194,252,96,2,196,0,135,241,79,4,56,2,190,249,31,2,103,255,96,254,74,0,185,0,156,0,34,0,49,5,226,252,42,255,253,253,121,0,227,252,237,2,90,1,117,2,159,253,147,252,196,255,184,0,99,255,250,0,193,0,33,17,113,1,75,255,65,255,204,254,198,254,117,254,83,255,168,255,124,254,213,255,46,0,9,0,89,255,189,0,64,255,198,23,30,255,253,248,126,0,83,252,89,254,141,1,124,1,205,1,63,1,108,1,62,255,177,1,190,4,125,241,238,254,9,0,185,254,212,0,137,254,130,0,107,252,193,255,96,4,117,253,45,255,149,0,152,251,9,1,183,255,234,237,237,1,173,255,236,255,198,254,165,255,142,3,147,255,253,255,95,254,147,255,118,1,101,1,43,245,253,0,22,255,206,254,12,244,6,253,53,0,220,1,213,254,167,255,120,246,110,253,173,255,170,252,186,14,118,1,40,2,194,1,51,0,90,1,119,3,49,254,189,0,254,0,182,0,15,0,219,255,65,243,34,10,121,253,173,255,148,1,2,3,179,2,114,253,211,254,81,0,243,255,230,2,115,1,54,0,31,0,173,255,197,255,100,16,141,2,0,1,205,251,229,253,60,4,203,251,214,4,3,1,20,0,65,255,86,3,179,0,209,255,255,251,67,255,25,1,252,9,229,6,106,0,177,255,64,1,6,244,228,0,12,254,1,0,73,255,210,255,220,0,23,255,206,255,158,255,251,254,172,255,231,255,230,238,84,254,141,250,186,253,149,253,187,1,80,250,119,1,144,0,224,255,100,1,58,254,28,0,136,0,5,0,247,0,223,251,197,2,150,254,37,1,12,12,33,2,12,245,143,253,16,0,28,255,18,255,164,0,55,255,142,255,107,255,58,0,182,255,203,0,15,1,206,1,13,4,159,0,140,249,177,253,178,252,90,255,56,243,198,2,5,3,56,3,142,251,118,2,242,255,209,0,92,1,196,5,66,1,141,254,241,0,37,16,147,252,36,254,121,254,90,2,235,4,76,251,96,1,90,0,39,254,43,0,104,255,73,254,125,255,39,255,233,249,91,236,70,255,17,255,212,255,238,2,33,0,89,255,45,255,189,255,165,255,113,255,124,0,32,0,240,255,0,32,68,0,154,255,163,0,225,255,202,1,38,0,249,0,21,0,157,0,193,255,36,0,49,0,234,255,89,0,9,0,153,0,46,0,60,0,110,255,243,255,174,226,152,255,101,0,115,255,25,0,165,0,172,255,219,0,53,0,74,255,162,255,46,0,222,250,141,254,214,254,241,253,6,0,93,248,52,0,54,253,51,254,174,0,170,5,214,254,107,0,149,11,250,0,191,255,46,0,85,255,40,1,239,252,240,252,35,0,36,0,29,0,147,3,133,252,121,254,168,0,253,1,179,14,13,251,118,255,132,0,168,1,203,255,99,253,45,250,97,252,200,2,130,253,72,254,213,254,10,2,57,6,189,1,162,12,35,2,242,1,184,1,145,0,121,255,68,255,216,254,56,4,212,1,77,0,176,0,197,254,221,0,176,18,102,253,18,1,250,2,214,255,218,0,170,255,239,254,116,0,46,3,235,255,146,1,246,254,120,254,87,254,102,4,188,255,142,0,101,1,23,20,107,1,32,255,58,255,115,0,35,255,250,254,32,253,42,245,60,255,48,255,155,253,163,0,184,2,21,3,132,0,114,0,121,0,190,243,164,0,172,0,67,255,232,0,53,0,54,1,206,255,105,254,183,4,38,254,249,0,218,252,21,0,20,0,72,0,234,253,101,0,209,255,33,255,40,238,128,255,227,255,114,252,2,255,105,0,91,12,137,255,121,255,209,6,208,6,81,4,35,1,179,254,234,254,71,254,148,2,141,0,221,254,58,1,149,0,142,0,135,255,58,225,16,255,52,255,189,0,120,1,3,0,127,255,59,0,46,0,170,0,82,0,106,255,222,255,67,0,146,255,123,2,148,0,0,1,133,244,157,0,3,254,159,5,90,246,26,3,214,254,151,1,212,3,37,3,93,1,208,0,221,255,241,3,156,4,142,255,8,3,173,254,248,252,250,0,159,7,211,253,172,0,117,254,27,3,253,243,164,254,150,255,122,0,209,255,247,255,55,0,40,0,186,11,165,1,26,2,255,255,235,254,10,244,241,255,168,0,205,1,9,2,243,253,157,1,60,255,159,0,14,243,171,255,215,3,53,2,215,243,38,0,79,0,84,255,20,0,28,255,248,253,90,1,47,0,229,1,79,255,51,0,175,0,188,1,147,13,168,242,175,255,118,0,8,1,94,255,20,0,64,255,37,255,145,255,199,255,31,255,159,0,38,255,117,0,228,255,106,255,180,251,87,253,188,1,202,255,245,255,195,237,40,255,129,251,90,3,168,0,217,255,52,0,131,1,74,0,217,255,102,255,207,10,51,1,124,255,19,2,175,0,138,3,14,0,127,255,49,0,195,242,220,1,129,255,183,254,223,1,118,0,171,255,209,0,4,0,227,0,154,0,254,255,18,255,7,1,232,255,41,2,25,255,78,0,2,0,73,255,31,0,45,23,117,0,86,0,130,1,103,1,153,0,101,0,240,252,215,253,243,255,0,1,165,254,225,250,88,252,192,255,182,6,68,254,168,0,178,253,76,243,62,255,13,255,243,254,48,8,30,252,199,251,53,1,235,3,34,1,190,255,50,1,89,243,231,255,188,2,109,1,254,252,144,0,4,0,3,1,71,255,213,5,98,255,214,2,148,243,109,249,137,255,45,0,19,254,51,255,64,249,54,251,21,255,169,255,168,255,169,255,174,7,8,0,142,0,240,1,239,0,60,3,30,0,251,253,78,12,218,8,146,1,197,254,74,0,200,254,98,254,240,255,202,1,125,1,120,1,7,5,69,4,102,254,57,252,80,0,126,1,150,255,67,17,189,1,37,1,229,254,26,1,68,1,176,255,231,255,115,0,125,249,12,253,101,7,44,245,139,1,3,0,163,254,138,0,70,4,150,1,176,1,214,0,208,250,120,2,124,255,156,255,135,0,91,6,38,4,2,4,195,250,24,0,232,242,83,255,241,4,93,3,203,252,169,255,145,254,22,1,151,0,155,255,224,255,161,0,131,1,146,22,204,253,236,1,83,0,68,1,29,0,89,254,91,0,124,255,190,0,202,254,55,254,194,255,157,255,171,0,42,255,97,255,60,246,75,253,254,249,201,254,240,252,138,246,14,254,245,6,86,1,45,254,178,255,210,1,4,255,241,0,197,0,186,0,241,251,66,255,90,1,167,248,16,255,191,255,158,5,233,3,63,244,204,255,221,0,22,254,200,4,193,255,217,255,53,0,169,0,130,0,86,0,200,255,166,255,116,0,4,0,186,27,251,255,61,0,84,255,191,255,160,0,162,255,226,255,145,255,14,1,115,253,9,2,86,254,60,4,111,251,122,251,72,2,61,246,190,9,191,254,183,2,55,3,83,254,35,0,17,2,232,254,211,255,226,254,181,11,207,0,135,253,97,247,172,6,214,254,99,254,161,2,7,252,36,1,237,1,76,0,120,255,147,254,191,255,10,1,84,3,0,2,23,3,127,255,84,5,215,251,91,5,127,1,244,253,249,1,175,3,147,0,229,0,39,0,103,244,70,0,217,254,66,0,199,10,240,255,77,254,38,254,222,251,250,2,54,0,255,254,48,2,161,243,196,253,94,254,34,254,114,1,72,0,236,255,40,1,54,0,133,245,38,2,241,255,101,255,98,8,113,255,136,251,207,1,139,255,102,249,131,248,42,0,249,0,234,254,193,254,255,253,32,2,15,248,195,254,93,248,170,245,65,5,247,2,12,1,207,0,219,4,0,1,224,255,211,255,18,253,45,255,72,255,93,9,217,1,12,10,23,254,4,1,133,1,19,255,90,2,49,254,57,2,137,6,80,255,29,255,196,3,203,0,130,0,243,254,66,255,59,5,46,252,205,3,194,7,121,4,234,4,16,1,243,6,76,254,230,250,140,2,39,3,62,2,121,5,53,0,73,255,76,6,196,252,234,243,174,255,37,4,18,4,56,255,133,252,130,255,181,0,212,250,37,2,43,2,252,255,156,252,79,0,157,0,3,250,18,0,230,0,184,251,177,254,99,253,90,255,61,7,202,254,172,254,249,0,70,252,174,253,143,244,159,1,5,0,135,0,221,250,19,255,76,7,19,3,120,7,180,251,115,4,177,251,39,255,130,254,114,253,30,8,16,2,133,0,141,255,200,255,215,255,49,255,69,0,205,1,209,1,116,254,189,6,26,5,69,254,48,253,192,249,152,4,140,2,27,252,206,254,240,251,210,8,181,255,15,244,171,252,140,12,178,254,5,0,224,0,63,0,6,255,167,254,154,255,223,254,141,255,75,0,157,255,206,0,248,255,19,0,96,0,2,255,250,245,78,1,213,10,136,0,199,0,204,251,91,1,69,255,225,1,192,255,142,2,247,255,186,251,196,0,40,0,161,255,5,0,163,0,121,255,253,0,227,251,60,1,25,255,24,0,253,246,200,5,252,247,238,255,53,254,218,253,188,248,241,255,98,0,130,250,190,255,6,255,21,0,241,1,108,254,202,255,28,255,173,9,219,7,111,255,91,248,86,254,118,252,96,2,15,0,173,5,218,0,177,255,132,253,19,252,180,254,48,1,34,9,76,5,81,0,79,251,86,255,130,255,103,251,148,249,234,251,16,0,182,0,184,254,165,254,90,1,79,2,162,1,111,2,146,255,170,254,29,255,10,0,65,236,101,254,128,0,153,255,87,0,228,255,123,255,196,0,77,1,249,6,33,254,70,254,180,244,197,1,12,247,237,255,129,254,212,255,77,254,63,255,247,1,130,0,4,0,144,0,136,8,11,255,249,255,202,1,82,0,180,255,236,11,137,254,19,5,180,255,108,1,111,255,116,1,36,0,59,0,217,255,48,0,129,1,26,255,204,10,140,11,27,253,140,254,172,1,8,254,36,255,203,252,209,255,207,255,97,2,194,255,56,0,6,0,216,0,120,1,7,2,0,254,54,0,194,254,73,255,45,238,41,1,27,3,74,255,108,0,234,0,148,1,218,0,133,255,239,255,64,255,170,0,93,1,134,0,165,255,43,0,121,255,232,255,250,255,224,255,231,229,50,0,118,255,167,255,238,255,15,0,24,0,96,254,100,1,55,1,83,0,245,254,81,0,209,0,101,255,144,254,140,1,102,1,232,0,88,18,165,254,212,2,112,0,10,0,75,1,102,1,197,0,54,0,56,3,134,2,42,255,113,0,183,238,184,0,245,255,101,0,199,254,186,0,253,0,169,0,78,0,52,0,186,255,148,255,133,6,234,255,238,255,216,245,229,255,246,10,32,1,150,255,250,1,176,0,104,2,213,254,58,0,226,255,1,0,36,255,144,1,79,255,106,3,70,0,220,255,238,254,117,255,124,4,116,1,40,0,236,0,249,1,107,2,94,240,161,255,208,255,218,244,114,0,187,255,11,245,111,254,247,255,203,0,13,252,216,1,214,251,156,1,36,255,245,0,73,255,229,255,35,0,6,253,56,1,119,255,220,254,14,255,128,3,172,0,167,254,106,0,118,238,250,1,57,2,245,255,160,254,148,255,78,1,91,255,85,9,129,252,201,10,211,1,201,0,150,0,252,253,39,0,175,251,4,0,75,2,104,255,4,253,72,255,241,255,119,255,226,255,244,255,7,0,126,1,51,254,41,6,191,13,83,255,90,5,80,0,243,1,88,1,253,252,123,0,243,255,32,1,233,0,111,0,88,246,112,15,3,3,216,0,7,254,66,254,19,2,26,255,103,0,184,255,34,0,61,0,249,0,81,255,97,1,83,0,51,0,169,0,159,255,196,255,147,30,95,0,75,0,243,255,201,0,229,255,103,0,245,255,1,0,3,0,121,0,183,255,228,255,7,0,92,11,47,255,37,252,127,255,171,254,24,11,121,3,109,255,247,253,123,0,95,0,17,255,40,2,30,253,23,1,190,255,0,0,16,0,116,0,211,255,228,255,213,255,218,255,53,226,30,0,204,255,47,255,25,1,210,255,23,0,232,255,56,0,231,255,233,255,26,246,149,255,210,255,163,255,207,255,238,0,231,255,96,0,156,254,155,13,53,254,98,254,205,0,102,0,202,0,106,255,140,255,249,6,119,5,25,3,31,2,173,2,235,244,255,0,106,1,160,255,154,1,158,3,44,4,160,1,46,2,87,255,246,0,138,0,88,8,39,0,160,255,163,253,23,1,126,255,75,245,179,251,89,252,236,255,29,255,197,1,237,4,103,0,19,1,102,1,43,0,197,0,233,255,5,255,66,1,234,255,233,0,0,10,42,255,2,0,155,255,133,2,48,11,31,1,33,254,136,3,191,255,73,0,224,0,114,9,161,255,172,1,90,253,234,254,71,0,223,253,197,253,202,253,75,255,44,255,125,244,222,0,12,3,147,254,124,0,113,245,58,255,187,255,10,255,16,244,72,255,170,253,181,255,111,255,78,253,124,1,194,0,229,1,214,0,28,254,54,0,163,0,107,1,100,252,148,6,201,0,34,0,236,0,229,253,70,9,106,255,22,254,223,250,195,255,61,1,75,8,59,1,217,253,230,255,184,254,207,0,253,0,57,244,166,0,109,0,106,253,162,9,99,255,28,253,239,2,254,0,236,252,143,254,250,255,100,0,45,255,107,0,203,254,217,255,209,255,23,1,130,255,165,255,97,0,63,253,235,0,25,255,182,0,27,1,23,236,188,255,29,1,49,0,50,0,125,2,111,0,39,0,126,254,155,3,223,0,115,0,102,6,190,4,128,253,136,247,226,1,76,247,89,3,172,0,15,0,97,247,167,255,79,1,238,255,39,1,206,2,68,252,26,0,92,2,76,254,40,11,149,251,98,0,14,253,243,0,9,0,29,0,68,240,67,249,51,249,176,1,45,255,196,255,233,253,201,0,239,254,111,0,188,1,95,2,6,255,122,0,98,0,159,0,97,0,25,1,255,11,100,254,223,244,47,253,242,255,192,3,213,255,26,3,85,254,41,1,222,1,123,1,209,255,234,255,69,0,196,255,226,255,36,253,152,9,170,0,142,0,6,0,216,9,124,253,55,255,240,255,66,6,236,255,219,254,30,2,61,254,89,255,247,255,14,0,28,4,147,10,164,11,139,255,223,1,54,255,164,255,36,0,136,3,190,255,192,251,225,255,75,0,194,255,146,255,227,255,112,0,154,255,97,20,171,255,14,0,65,255,54,255,81,255,185,255,182,0,25,255,19,1,144,0,255,255,54,255,243,255,227,255,237,255,70,0,39,0,46,0,56,0,72,226,203,255,152,255,195,255,44,0,23,0,1,0,99,255,42,0,12,0,38,0,37,0,75,1,159,253,44,246,82,255,69,246,2,1,0,255,98,252,215,3,100,0,83,0,173,0,59,252,138,2,208,254,159,255,98,0,90,255,22,2,10,10,157,253,237,1,103,0,158,255,148,0,9,12,125,255,29,1,13,0,145,254,205,0,203,255,41,0,29,0,102,255,159,245,205,255,200,254,134,0,50,0,22,250,122,2,155,1,187,244,121,254,109,1,139,254,202,255,182,255,105,255,80,0,152,0,165,255,192,255,47,255,110,4,151,244,60,1,73,252,100,4,201,2,2,0,92,247,31,0,164,0,252,254,103,0,36,0,229,0,111,0,233,255,191,255,219,255,36,255,148,255,226,255,86,0,17,0,87,0,205,0,163,0,63,0,125,233,254,0,178,0,238,255,224,6,132,254,173,5,177,243,198,2,106,0,66,0,131,1,235,0,207,1,217,254,176,2,132,255,66,1,63,255,82,0,244,3,15,248,112,253,82,5,37,3,21,253,223,9,214,1,43,0,23,252,100,0,173,255,161,0,74,0,152,251,205,254,174,255,59,255,162,234,226,0,185,254,137,0,125,255,215,1,80,254,240,255,243,0,224,0,168,0,92,255,198,255,125,0,23,0,254,255,64,245,12,1,164,255,46,254,60,11,106,3,182,0,28,2,105,254,174,254,116,254,50,2,136,254,24,2,31,255,160,0,44,0,35,250,10,255,218,251,134,254,190,1,112,246,132,255,243,1,7,247,159,254,131,253,139,1,86,2,21,253,162,1,17,254,5,0,10,252,90,8,33,1,181,255,45,1,176,3,66,0,55,254,53,254,3,255,254,255,166,2,111,1,116,0,171,244,180,1,17,255,209,254,51,252,128,1,242,245,6,0,31,255,92,255,72,254,115,2,132,1,254,243,249,254,156,0,219,252,125,1,247,255,144,255,55,250,24,2,57,253,186,14,16,254,140,3,227,1,218,1,42,1,88,254,231,252,53,255,178,254,134,0,165,255,208,0,183,255,64,21,196,254,208,254,249,0,255,255,158,255,42,255,190,0,242,0,199,255,218,255,244,0,37,255,30,0,32,255,66,0,226,255,22,0,24,0,24,0,147,255,86,226,141,255,90,0,109,255,173,255,21,0,255,254,204,255,134,0,207,255,92,0,139,255,30,0,248,255,132,253,15,6,159,8,190,255,86,248,212,0,55,2,201,3,197,249,206,253,99,1,45,254,163,252,169,3,108,255,15,0,188,255,20,250,186,247,197,5,9,3,178,5,208,3,10,2,69,1,189,3,126,255,124,255,106,252,192,1,64,4,102,0,142,0,124,253,228,254,175,2,103,253,124,255,178,248,107,5,221,2,172,255,152,3,4,254,53,0,121,247,254,0,53,2,8,8,97,0,57,0,219,0,176,2,168,254,147,2,241,7,195,3,75,249,222,254,90,252,185,247,57,0,84,250,24,0,129,253,29,253,24,255,170,0,28,0,103,1,200,254,54,1,153,255,213,251,71,252,57,4,167,252,134,7,84,5,73,249,161,252,40,7,18,3,55,0,166,0,127,1,163,250,165,254,174,6,116,252,91,0,233,4,221,7,176,253,199,250,151,5,166,255,105,2,37,2,156,254,188,255,134,0,208,255,123,255,80,255,238,255,191,255,23,0,84,0,233,255,220,255,252,255,230,0,41,1,52,255,106,255,86,0,155,236,230,2,40,0,32,0,210,251,149,0,38,0,46,1,183,254,126,254,199,255,45,0,170,249,145,5,25,7,32,6,154,8,7,0,88,251,55,255,214,255,194,255,86,255,224,255,139,255,218,255,229,0,44,0,30,255,155,0,70,0,235,2,3,1,251,254,136,255,216,241,17,254,158,0,10,255,239,253,211,252,177,2,248,1,241,253,88,247,58,255,189,254,78,253,177,253,175,0,6,1,243,0,164,241,88,10,38,252,166,0,243,0,45,1,68,253,68,1,188,254,13,0,106,1,222,0,42,254,30,0,20,0,210,255,109,255,210,15,159,255,208,253,28,1,61,1,181,249,143,2,96,254,210,249,93,253,133,1,132,255,150,0,229,255,69,1,172,255,48,0,50,29,97,0,105,0,19,0,38,0,133,0,19,0,28,0,25,0,40,0,34,0,197,255,22,0,11,0,27,0,21,0,5,0,196,249,84,254,183,1,97,1,240,8,238,255,101,1,238,254,22,10,130,255,166,255,71,0,247,255,64,253,205,0,22,0,44,0,136,255,213,255,5,2,49,3,90,5,103,8,2,11,42,254,90,0,139,1,37,251,167,254,191,3,19,0,255,255,123,0,148,255,91,1,25,0,118,255,15,0,119,0,139,255,110,255,142,0,183,0,2,255,236,254,82,255,92,23,27,1,195,254,70,0,51,0,241,255,113,246,177,255,234,0,224,2,216,245,127,253,118,251,120,1,191,3,6,255,189,2,216,255,154,255,204,0,218,255,232,255,131,252,125,254,83,1,58,5,165,255,113,253,160,252,78,0,43,1,228,0,84,245,234,0,203,7,215,250,117,255,244,1,196,254,116,255,2,0,176,255,186,0,11,0,16,0,187,255,146,226,85,0,249,254,189,0,249,255,255,255,189,255,188,255,3,0,24,0,135,1,29,243,120,244,135,255,119,254,103,0,196,255,143,255,141,0,185,0,137,255,240,0,14,1,120,254,151,255,9,0,217,255,225,9,239,255,97,1,150,11,169,252,18,4,14,5,132,0,255,254,255,254,16,254,112,0,77,255,168,1,230,1,193,255,77,0,19,1,58,255,234,7,121,6,145,3,1,255,109,255,44,249,251,255,162,1,100,1,230,7,159,3,217,254,194,0,165,0,28,0,109,0,13,0,209,0,123,255,14,245,164,1,175,248,120,253,53,1,108,251,223,248,220,255,72,3,24,1,44,0,138,255,128,0,34,0,241,0,19,252,136,4,209,254,62,1,214,2,76,249,65,10,74,252,185,252,23,251,123,252,18,255,99,4,131,0,252,0,1,0,184,1,175,5,242,255,238,254,51,254,87,0,253,253,5,247,160,3,205,244,220,252,41,255,168,2,147,0,80,0,215,0,15,0,59,5,141,0,161,255,134,0,221,255,122,0,53,0,173,1,168,0,220,1,211,255,233,2,236,0,133,16,62,1,247,0,55,255,140,254,241,8,161,0,175,1,81,1,61,253,0,252,121,0,19,249,229,252,93,251,111,254,138,1,105,250,246,5,221,255,176,1,113,11,90,0,88,7,116,2,18,5,216,253,14,254,207,0,159,255,105,250,81,4,29,0,29,253,200,255,62,0,94,0,25,2,36,253,231,4,2,253,200,0,147,254,30,11,91,8,179,1,92,0,58,253,0,254,104,1,173,254,253,3,218,1,124,255,149,1,72,254,107,13,75,0,2,255,117,246,144,252,69,1,87,1,29,1,230,0,81,254,65,255,215,0,201,0,69,254,93,0,175,255,125,255,165,11,86,244,235,3,181,1,178,1,126,254,17,0,222,0,70,0,173,0,218,253,11,1,135,255,213,255,114,0,245,255,229,252,49,2,109,255,187,0,58,255,151,236,50,0,59,0,162,2,171,252,163,0,71,0,51,255,228,254,206,255,228,255,124,250,151,255,6,1,16,1,53,2,200,252,227,253,53,13,174,1,175,255,228,0,86,254,210,3,218,254,166,1,230,253,13,0,9,0,174,1,180,0,25,9,204,253,198,251,204,6,84,4,37,248,11,0,87,1,100,3,211,2,218,252,86,1,83,1,115,255,83,255,186,0,50,0,41,1,193,2,15,3,175,253,73,6,212,0,16,2,13,246,161,252,103,246,148,252,164,0,162,0,109,1,68,0,30,0,11,0,48,0,47,0,227,254,192,255,166,0,235,255,32,229,65,255,30,255,89,0,255,255,22,0,163,255,250,255,44,0,26,1,52,0,38,1,78,253,109,255,116,1,199,8,36,3,131,253,54,0,81,9,249,248,59,1,95,252,180,2,191,255,202,255,218,0,16,253,249,253,123,8,177,0,139,3,22,0,246,252,160,245,62,0,94,254,78,254,51,1,114,7,232,254,196,0,76,0,58,0,210,255,70,0,145,254,189,255,50,0,125,0,77,0,221,253,225,254,159,255,246,255,172,255,241,254,8,237,10,0,234,1,208,253,235,255,66,0,91,246,190,254,253,3,168,3,113,2,40,246,120,4,139,254,14,1,36,3,91,2,165,255,6,1,147,2,9,0,188,254,50,0,56,253,145,10,56,244,82,2,87,0,168,255,185,2,51,255,225,252,128,255,37,0,248,1,59,0,238,254,143,2,160,2,236,255,14,5,35,255,118,244,198,0,162,2,116,249,95,3,68,1,200,3,219,2,101,4,215,255,107,255,209,254,223,0,90,5,189,255,62,255,255,255,62,255,251,0,53,254,217,255,125,17,113,0,182,255,126,254,214,0,184,255,179,255,199,249,255,1,51,254,240,2,209,253,36,254,204,0,46,253,26,4,32,8,164,9,102,255,48,255,196,3,103,0,198,255,134,1,185,248,142,3,205,254,209,0,224,255,151,2,103,0,123,255,191,243,89,254,3,1,163,253,14,255,139,0,121,254,24,254,77,0,246,254,98,249,141,1,109,253,237,0,20,8,253,255,157,252,102,3,111,6,133,2,56,7,68,0,126,1,199,1,217,253,169,255,157,255,146,244,116,1,134,9,114,251,250,255,9,2,61,255,235,4,94,255,149,3,140,0,19,1,239,254,133,0,62,1,231,255,252,0,137,255,124,255,48,12,141,1,142,1,92,254,220,6,154,2,128,8,115,255,15,1,205,255,22,0,18,254,220,255,57,0,52,1,222,0,1,14,16,0,247,254,68,10,232,255,162,0,13,0,16,255,160,255,108,2,75,1,63,254,198,2,133,255,151,255,23,0,86,255,20,0,0,1,148,235,142,1,70,255,16,1,129,0,175,0,86,2,240,255,10,254,11,0,41,255,28,0,146,255,242,13,68,0,199,0,25,246,91,252,13,3,6,253,69,1,18,0,74,254,193,254,217,1,91,253,176,0,34,1,0,0,67,0,250,255,100,255,31,0,35,0,125,255,129,255,24,0,156,255,86,229,139,255,203,255,216,255,99,0,206,255,163,255,31,0,34,0,5,255,186,0,231,1,53,255,106,253,74,255,160,255,239,0,52,1,82,1,170,255,249,236,8,1,208,255,58,1,190,255,100,0,68,255,151,0,24,0,198,0,4,0,182,19,209,255,114,253,213,255,41,0,109,0,103,0,250,254,93,0,138,255,193,255,58,0,40,8,80,1,192,254,22,9,36,2,214,252,221,250,160,252,205,1,171,0,76,0,171,251,26,250,150,252,148,253,97,0,88,0,40,0,252,255,129,227,128,255,217,255,23,0,156,255,247,255,182,255,112,0,105,255,67,0,21,0,53,0,2,0,227,255,223,255,52,0,215,12,126,247,114,2,83,1,207,252,93,1,93,251,218,253,122,254,57,0,215,255,39,1,244,2,185,0,41,255,17,0,3,0,78,29,122,255,134,255,225,255,203,255,91,0,86,255,185,255,133,0,222,255,57,0,144,255,251,255,190,255,17,0,1,0,24,9,130,14,214,0,133,255,185,252,9,0,194,255,54,0,70,0,238,255,49,3,186,0,195,255,4,255,37,0,98,0,9,0,218,7,226,2,141,249,124,248,82,4,144,253,143,0,220,253,79,3,58,255,116,255,77,253,222,1,10,253,56,0,54,0,249,255,209,0,151,245,109,0,129,255,122,255,51,8,77,1,166,253,87,247,25,253,90,1,74,0,216,0,67,2,223,0,61,0,226,255,57,0,94,0,224,0,221,245,202,253,173,252,246,0,58,1,65,0,41,11,114,0,8,253,77,0,157,253,119,0,181,0,4,0,4,246,127,0,138,0,92,255,37,255,140,255,157,0,185,243,197,0,158,255,240,251,235,0,180,254,88,254,104,255,174,254,223,255,36,255,207,0,254,0,93,21,154,255,122,254,131,255,92,254,113,0,23,255,73,1,222,255,109,0,85,255,103,0,50,0,58,0,96,0,12,254,243,246,253,254,130,8,109,0,18,248,247,2,244,252,192,1,166,2,128,254,241,254,213,0,78,1,241,254,23,0,159,251,124,2,177,251,30,254,13,244,80,251,136,4,109,0,24,255,29,2,236,252,130,0,90,255,212,254,152,2,233,0,159,255,227,255,226,254,33,0,248,4,214,254,130,254,14,255,57,255,47,0,223,1,224,0,31,249,144,248,244,6,159,5,87,253,75,248,138,255,166,255,108,255,247,0,10,253,144,7,182,0,93,5,42,9,120,0,10,253,36,254,253,6,153,4,99,2,118,254,242,255,217,255,30,252,94,253,25,4,215,255,68,3,121,254,174,3,240,251,99,250,96,5,132,248,105,4,6,252,115,253,4,5,184,255,90,255,65,1,194,0,114,255,105,255,179,255,251,0,94,255,220,2,234,252,107,0,220,254,93,253,104,239,205,255,170,255,213,254,17,254,157,1,128,255,57,254,151,255,182,252,113,3,20,254,217,4,104,250,240,250,204,255,82,254,229,9,27,249,70,3,84,0,232,255,226,252,84,254,102,255,110,253,37,0,124,254,177,253,93,252,79,254,211,248,83,5,85,253,51,253,43,12,104,0,0,0,80,4,208,0,148,0,148,1,101,0,18,0,217,0,58,0,49,0,4,0,207,255,61,255,187,0,17,255,235,255,38,1,118,255,40,21,33,255,133,255,156,0,223,255,185,0,112,255,148,255,57,255,188,255,220,255,11,0,37,0,124,0,211,254,58,0,235,255,155,0,99,0,246,255,178,255,230,255,186,255,168,243,243,251,98,0,155,0,139,254,66,3,140,2,235,254,83,254,239,253,153,255,154,254,187,0,137,4,99,255,147,0,112,254,205,1,156,0,237,0,225,1,189,255,99,0,171,3,155,4,109,253,57,5,66,2,23,254,31,254,85,254,146,253,131,0,34,7,34,253,29,252,251,255,51,254,2,2,173,255,241,254,144,244,170,255,130,254,51,255,123,255,126,254,61,255,189,255,252,1,74,2,95,2,114,252,75,255,2,248,188,4,77,255,23,0,152,1,119,248,252,7,112,8,145,252,74,0,179,0,72,0,92,255,47,0,162,0,217,5,58,3,162,11,112,252,198,1,150,253,141,248,11,254,18,254,213,254,96,0,118,255,142,255,205,255,85,255,189,1,120,4,69,255,217,0,224,0,146,1,13,0,42,0,198,255,100,249,66,16,248,4,202,3,234,254,71,1,88,0,225,255,74,255,23,1,158,253,78,0,80,254,109,255,114,255,43,253,239,255,161,255,132,1,133,0,195,255,28,0,171,250,161,5,94,2,155,1,155,3,180,254,51,7,142,7,85,250,254,253,229,254,0,3,172,3,84,254,31,0,81,4,248,0,178,255,59,250,145,254,148,1,68,0,78,255,17,0,179,2,247,254,151,255,145,6,36,254,229,250,150,242,92,249,244,253,153,252,216,1,85,255,237,0,104,0,114,255,25,255,220,254,227,254,10,1,253,254,90,255,159,255,80,254,163,15,196,4,156,254,62,8,36,255,47,254,208,255,117,0,78,255,34,1,235,255,205,0,237,255,65,1,169,254,184,254,199,255,215,0,167,254,48,1,2,0,10,0,233,247,185,0,177,1,212,0,115,251,112,0,242,0,218,254,94,255,83,4,152,4,116,254,120,5,216,245,78,254,128,253,201,1,100,0,244,254,41,3,128,0,20,255,190,255,162,255,182,252,82,0,163,0,227,0,175,245,27,254,35,1,186,254,42,0,234,0,120,253,75,5,200,11,133,250,185,255,188,0,24,3,15,0,240,255,246,253,181,255,106,0,200,252,109,4,179,3,221,1,126,253,237,253,216,252,4,16,222,255,105,254,133,0,33,0,15,0,63,0,72,0,33,255,241,255,21,254,38,0,47,0,2,1,20,255,192,0,92,6,173,0,188,247,175,2,39,1,182,255,73,255,95,0,17,2,149,0,140,254,182,0,37,5,21,0,112,250,172,243,145,255,160,255,68,2,28,1,238,254,41,0,145,0,34,5,79,0,38,7,6,1,187,254,240,255,169,0,11,255,10,248,167,7,124,3,178,3,47,1,85,255,80,254,115,3,34,0,18,255,159,9,218,254,25,0,24,0,150,255,211,255,253,1,102,255,240,1,109,0,115,0,169,0,190,2,140,1,159,255,145,2,5,255,144,255,142,255,112,255,26,255,5,2,66,255,21,19,211,255,104,255,247,255,86,255,27,248,29,2,119,252,33,248,28,10,88,252,236,255,212,254,128,1,177,1,133,255,119,0,7,254,130,255,39,1,14,2,184,250,194,1,142,0,130,255,141,255,1,0,116,255,34,253,160,2,109,255,108,253,21,253,140,2,161,0,93,255,51,0,152,253,74,248,133,5,183,243,154,3,247,250,215,0,182,0,186,252,85,255,107,0,179,254,34,0,216,0,205,254,153,254,240,1,169,254,187,254,8,246,219,249,76,2,71,254,16,5,253,243,119,0,125,255,54,0,206,0,22,1,106,0,156,255,112,0,220,0,207,255,176,255,27,255,27,4,199,12,236,250,68,1,225,255,255,251,123,6,246,5,95,255,157,2,200,255,174,1,201,0,233,253,130,255,247,255,132,254,222,0,212,0,167,254,230,254,195,0,215,255,45,251,175,253,175,253,21,6,71,0,255,3,193,252,33,2,149,252,161,0,252,252,99,0,66,255,80,6,82,1,5,255,55,255,224,243,250,252,4,0,135,255,178,0,176,255,140,2,6,252,71,254,169,254,20,255,16,255,12,255,230,255,144,8,75,0,188,250,187,14,234,255,174,252,5,255,60,1,132,0,235,255,63,0,104,0,152,0,185,0,216,255,19,1,180,250,226,1,9,12,59,2,31,254,149,250,47,3,5,5,160,254,158,255,215,255,61,2,205,254,169,248,171,1,196,0,169,0,230,255,24,255,158,255,101,254,25,255,14,248,55,252,15,1,141,5,51,250,105,254,124,5,169,254,93,3,120,3,245,255,202,0,11,255,115,254,104,0,229,0,53,1,59,245,59,1,160,1,137,1,194,0,80,255,105,253,90,255,27,255,244,0,104,255,183,0,24,0,51,255,97,0,1,255,213,254,123,0,244,255,53,0,102,0,150,254,115,1,223,0,46,0,132,0,199,235,157,0,164,255,166,251,228,255,135,0,193,252,115,2,84,254,164,251,165,1,249,2,202,1,184,12,89,255,99,1,253,7,113,0,234,0,102,255,20,0,217,255,61,0,175,255,63,0,98,0,85,255,191,6,87,251,55,8,160,1,91,254,193,253,132,253,142,255,188,2,252,254,74,6,176,254,9,2,31,10,30,253,43,0,103,0,193,255,177,254,168,0,110,0,41,0,203,7,226,13,163,5,203,255,50,255,224,3,255,2,140,254,141,0,232,255,173,0,60,0,19,255,69,0,83,255,183,255,137,0,167,0,92,255,97,255,56,1,105,255,178,255,107,2,64,255,177,2,187,255,11,245,253,254,224,254,25,255,28,0,110,249,12,9,250,8,176,254,125,255,59,0,30,2,38,255,231,254,42,255,215,255,116,0,138,0,8,0,215,254,211,255,41,255,89,255,51,6,219,251,72,248,67,254,145,1,168,246,214,255,69,2,249,253,26,255,181,5,30,2,113,0,134,253,240,6,76,1,191,0,5,0,174,0,147,7,230,255,14,255,120,0,230,0,38,252,173,13,155,251,167,255,3,0,188,253,37,255,1,255,37,0,137,255,94,0,239,255,215,254,80,255,78,254,22,255,55,0,193,255,113,251,20,254,39,249,187,242,185,0,230,252,177,2,51,3,224,255,188,252,79,1,123,255,212,2,213,254,194,254,168,1,46,2,114,253,119,0,65,254,140,0,156,255,72,0,152,252,104,250,53,255,216,255,242,255,197,255,38,2,85,0,203,255,143,19,2,1,145,1,72,255,199,254,86,255,66,0,71,255,174,255,195,255,210,0,48,0,52,255,160,255,130,0,206,253,92,249,243,251,170,240,140,252,91,4,250,255,156,255,74,3,62,254,109,3,76,0,56,2,145,253,27,0,73,0,61,255,72,1,41,0,232,255,124,0,179,255,219,5,28,2,216,251,165,17,234,255,221,255,71,3,208,255,253,0,253,254,96,0,153,1,90,0,26,0,79,255,109,1,208,255,188,254,230,255,233,255,173,255,179,255,176,255,63,6,206,5,10,1,147,2,236,0,231,0,240,255,103,1,93,255,199,1,25,252,111,251,149,9,169,253,79,252,4,0,194,247,82,255,32,253,88,1,232,0,142,0,32,0,157,255,251,2,133,0,187,254,200,255,99,6,73,254,75,3,2,0,88,249,243,255,3,3,96,14,167,255,182,0,4,0,42,0,138,1,148,1,82,0,56,1,91,0,141,0,215,249,229,6,69,12,113,2,241,254,182,247,167,1,97,1,233,1,94,2,222,254,66,255,230,1,125,255,118,0,236,0,248,0,47,255,254,255,94,255,161,255,95,0,170,0,22,1,71,247,37,2,34,0,178,252,11,14,189,1,112,254,191,255,131,0,242,255,240,255,99,2,140,255,13,5,98,0,88,253,189,0,217,0,241,255,219,253,131,0,8,0,0,253,198,251,73,3,166,254,129,0,223,255,246,252,66,1,52,246,176,247,153,248,27,248,229,255,214,255,205,255,232,253,239,0,255,255,78,0,105,0,48,0,79,0,207,0,166,1,75,255,18,0,162,255,104,255,75,255,108,236,69,255,253,255,138,255,115,254,172,255,207,255,129,0,236,254,188,0,45,0,110,255,21,255,147,255,83,0,32,0,177,255,247,7,152,253,1,1,217,249,36,249,196,246,222,0,195,0,142,251,222,254,58,0,127,253,4,255,245,255,146,1,225,255,240,251,176,253,164,2,138,255,25,255,94,0,133,255,106,6,124,5,178,254,40,253,159,242,126,1,111,0,62,255,165,2,177,0,74,255,178,1,92,3,2,252,84,0,190,4,35,253,44,1,254,255,253,254,140,0,35,0,96,0,140,4,60,250,11,253,182,255,239,0,53,255,4,7,183,4,196,6,43,244,158,253,146,2,234,1,47,254,136,0,56,0,154,253,156,253,133,255,93,0,105,255,162,0,56,0,246,1,98,6,223,248,45,0,9,4,18,6,180,246,79,6,37,5,18,3,131,1,1,255,89,254,212,255,10,255,43,255,107,255,107,0,182,255,162,255,45,0,52,255,13,0,89,248,168,3,231,7,232,3,7,4,112,0,62,2,67,1,163,0,179,3,111,253,236,1,192,245,212,255,227,2,207,254,225,255,247,0,14,1,213,0,210,255,166,255,43,0,32,250,163,3,195,255,205,15,161,252,133,1,126,254,126,255,138,254,185,253,224,252,124,252,158,0,57,254,169,0,134,0,92,255,54,0,139,255,71,255,166,255,53,255,215,255,213,252,222,247,169,0,31,1,134,254,241,255,231,0,83,0,89,0,69,255,198,0,18,0,178,0,238,255,15,2,216,255,94,0,54,0,79,0,252,238,248,0,162,0,162,255,105,250,225,255,0,248,139,2,207,4,4,254,191,251,25,251,254,2,137,6,101,1,13,0,211,252,157,246,179,0,42,254,65,0,173,254,154,0,9,0,56,0,246,0,66,0,252,246,163,5,77,252,24,253,87,246,32,251,143,255,249,3,160,253,149,0,74,255,41,0,244,253,16,0,29,1,244,254,243,252,199,255,166,254,194,0,0,1,205,255,107,0,28,254,66,255,131,255,123,253,231,1,58,1,74,0,213,253,12,252,69,1,76,0,233,0,51,255,67,255,208,255,15,238,134,255,10,0,121,0,165,255,108,0,207,255,254,0,130,249,196,9,87,0,252,249,56,255,31,1,183,254,206,255,111,254,182,0,236,250,177,2,147,3,32,255,0,253,215,1,173,254,133,0,151,1,168,254,99,0,96,0,111,0,200,4,105,250,21,8,230,254,127,0,141,1,137,255,52,5,237,250,232], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1522885);
/* memory initializer */ allocate([2,233,253,32,3,71,1,106,3,188,2,88,254,196,249,85,5,117,253,105,255,113,0,102,0,232,255,208,1,125,0,143,3,209,249,140,254,235,2,2,0,173,1,209,255,192,255,34,0,164,6,27,253,87,1,216,2,30,255,97,7,78,0,253,253,11,11,77,0,190,255,108,0,3,2,90,0,179,8,90,253,21,5,50,252,122,0,41,252,53,9,64,0,57,250,186,0,156,5,11,255,204,0,204,1,191,0,91,253,177,254,56,255,121,255,150,255,155,255,88,4,83,245,127,253,73,0,241,4,255,250,204,250,25,253,163,2,129,0,136,251,111,251,75,1,113,255,169,255,41,3,133,252,176,252,246,0,243,0,97,0,86,255,36,0,171,251,102,0,31,4,141,250,104,5,131,4,183,1,243,249,212,254,235,247,246,3,187,0,242,252,212,3,53,252,167,254,185,253,190,255,118,255,195,254,132,255,48,0,104,255,158,255,92,0,142,9,128,0,48,251,100,8,175,254,153,253,211,1,37,6,155,253,89,3,47,1,166,1,196,250,92,254,49,1,142,253,94,0,16,254,126,254,127,255,243,0,27,0,56,255,163,250,188,5,8,248,151,0,93,253,65,0,184,5,80,254,33,2,13,1,2,254,72,2,113,248,202,3,193,254,185,5,234,1,7,1,43,2,0,255,207,255,59,1,14,255,118,254,200,254,168,255,201,0,135,255,210,254,172,0,49,0,234,0,59,0,71,1,155,0,199,0,69,255,215,255,182,255,52,0,225,255,197,255,58,234,135,255,26,1,87,1,131,255,56,255,193,253,48,5,155,0,120,248,250,0,190,2,21,0,98,245,103,255,154,255,83,8,100,2,176,1,208,251,55,254,222,0,171,1,144,0,149,0,79,254,219,249,57,5,118,253,176,0,13,0,7,251,24,1,17,253,20,255,197,1,204,0,197,249,176,244,240,254,233,0,229,1,82,0,117,255,240,253,116,255,113,254,200,255,238,254,177,254,176,0,12,253,243,0,202,8,207,254,209,2,175,6,7,0,50,251,202,249,176,248,119,255,54,253,7,1,149,249,106,1,246,254,80,255,64,0,220,255,193,255,175,2,29,254,48,250,197,2,161,3,69,5,35,251,133,2,173,249,223,2,117,253,58,7,7,4,159,0,143,253,70,3,242,0,116,254,115,254,215,255,213,4,48,1,81,0,162,255,32,253,66,2,255,4,40,4,81,0,108,7,77,255,224,0,10,1,83,254,222,2,244,1,227,3,142,252,27,6,21,7,249,253,246,2,20,2,229,255,27,0,197,1,2,246,191,10,72,254,176,4,43,4,43,253,20,254,76,2,234,0,47,255,148,255,26,255,223,0,25,255,21,255,124,255,205,255,88,0,222,254,42,255,157,255,196,255,175,0,242,9,33,252,139,3,190,1,123,2,28,1,195,2,238,0,220,0,204,254,3,1,8,0,77,254,97,247,49,250,213,249,46,0,29,1,7,255,154,0,142,254,37,0,42,0,244,5,195,248,113,5,180,4,126,0,215,6,82,0,136,0,107,1,149,246,242,252,128,255,206,252,24,255,253,2,83,255,129,255,220,2,4,1,155,255,100,3,7,255,34,1,32,0,133,2,55,0,50,249,203,251,136,1,200,253,117,2,104,252,13,255,23,3,164,253,149,254,117,0,176,250,241,255,11,255,185,241,54,0,215,254,10,0,124,0,11,0,166,251,201,253,42,15,6,248,160,251,214,255,142,255,110,252,163,1,51,1,44,0,21,1,155,255,173,1,170,0,187,0,240,253,63,253,92,1,237,255,180,0,180,255,91,0,187,248,75,255,85,255,36,3,38,253,222,0,72,255,93,1,191,0,131,255,14,0,174,16,45,254,240,254,29,0,40,255,212,0,170,1,34,255,11,0,240,255,172,252,101,0,64,2,178,0,95,1,135,2,90,0,179,0,87,253,69,255,77,0,19,16,48,252,42,253,199,2,251,2,60,2,114,251,210,255,67,254,153,255,135,0,38,1,44,1,10,0,225,2,130,1,113,254,163,254,204,255,17,21,149,255,224,255,27,255,102,255,75,255,82,0,188,255,243,255,179,255,48,0,75,0,117,0,206,255,254,0,233,0,98,0,75,0,86,247,90,247,211,5,64,3,225,0,223,251,11,1,27,2,171,7,11,255,159,254,198,1,82,254,202,255,21,253,198,255,74,254,166,255,192,255,21,1,214,0,151,255,209,255,235,250,108,254,101,251,170,2,3,240,252,2,242,254,170,254,145,254,158,250,6,0,173,255,173,1,142,1,61,0,107,255,180,0,31,0,169,0,38,255,152,0,185,255,218,255,45,10,167,2,81,255,235,253,251,6,99,2,228,1,190,254,158,0,207,253,125,0,221,255,214,255,66,255,17,2,193,1,157,0,223,243,106,0,168,0,248,255,190,255,176,255,183,5,112,4,185,18,158,255,80,254,26,2,111,255,241,0,98,255,105,0,140,254,39,0,96,255,92,0,33,255,81,0,245,0,114,255,94,255,89,255,215,254,207,255,158,255,70,2,198,235,106,4,241,254,55,2,5,255,55,0,231,1,209,254,31,0,231,255,87,0,186,255,154,0,233,255,35,255,70,0,208,0,48,0,119,255,46,0,59,0,247,255,139,250,54,252,224,0,202,2,161,0,24,0,205,254,15,5,187,5,101,255,7,254,247,253,12,255,247,1,231,255,35,252,80,14,108,255,12,0,121,255,218,0,97,255,100,255,255,252,91,254,41,2,203,2,185,2,75,255,146,5,169,1,217,255,153,255,50,238,171,0,91,1,161,0,170,0,128,0,46,255,221,255,31,0,125,0,248,254,121,255,156,255,125,10,26,255,14,8,82,6,157,255,150,252,158,3,245,2,124,1,148,1,183,255,30,0,29,0,206,1,213,2,123,254,10,255,20,0,150,0,22,255,198,255,73,255,10,0,156,0,226,1,24,255,124,0,115,0,180,0,153,253,117,254,74,1,171,255,77,254,207,12,213,5,174,2,133,4,245,0,213,251,95,248,23,0,28,3,228,253,175,0,56,0,117,248,89,0,193,2,170,254,39,2,49,248,159,7,255,246,15,254,246,254,19,1,33,250,95,1,157,254,159,254,236,0,154,254,241,254,216,255,136,0,217,0,243,255,211,255,213,247,117,4,218,2,160,248,107,4,148,2,247,4,183,1,37,10,92,0,63,1,165,255,62,0,60,1,31,1,252,254,121,0,223,255,139,255,234,255,177,255,86,255,92,255,206,5,134,0,194,255,220,255,217,242,21,255,197,4,215,4,78,0,202,255,23,254,12,1,208,253,250,252,83,3,51,252,194,255,82,255,118,255,53,254,134,1,234,255,214,255,83,0,59,5,27,5,206,1,72,241,255,1,44,1,243,253,237,252,167,255,163,2,230,247,37,0,208,255,252,0,86,2,180,254,67,0,69,255,2,0,150,255,221,255,108,255,70,255,226,253,31,3,59,9,101,255,103,253,205,244,47,255,56,255,176,255,146,6,58,4,2,0,4,2,31,254,20,1,255,255,36,255,54,0,244,255,3,1,161,0,108,255,54,2,47,250,37,253,238,4,243,1,208,252,115,0,217,15,185,255,189,2,39,0,124,255,33,255,240,255,229,0,254,255,216,255,195,255,234,0,149,1,108,0,48,1,194,255,116,254,89,5,98,250,3,248,162,7,247,2,201,3,90,255,21,255,141,255,188,255,131,7,23,7,248,252,169,252,34,0,193,255,17,0,87,0,223,0,111,255,126,255,240,255,199,254,88,249,54,254,180,254,164,1,52,5,164,2,110,3,249,240,152,254,171,1,25,2,139,2,89,255,61,254,59,255,21,1,136,0,55,255,5,2,10,0,100,255,35,0,97,252,226,4,83,255,236,3,87,255,66,1,116,255,209,253,208,237,169,254,248,254,195,255,244,255,195,0,246,255,133,255,233,255,236,255,250,255,145,254,154,255,41,255,41,0,70,3,233,5,40,2,183,249,15,253,5,253,112,253,135,253,14,0,35,0,141,0,117,0,135,255,89,3,42,250,66,2,242,9,10,4,92,253,59,2,49,3,38,255,145,255,144,5,205,255,110,3,212,244,255,254,104,0,242,253,14,3,196,2,46,9,12,254,170,254,219,0,106,254,68,3,139,255,32,1,97,254,30,3,14,0,201,254,57,254,3,0,102,254,112,255,226,255,47,252,111,255,94,246,67,252,90,5,127,243,185,254,171,255,149,0,188,253,198,0,94,1,140,0,152,255,71,1,128,255,78,255,58,0,38,1,50,0,22,7,69,2,115,252,31,1,245,254,104,240,61,0,164,252,2,1,241,254,33,255,237,0,221,254,253,255,66,0,110,0,148,253,63,1,194,255,177,0,108,1,110,0,93,255,103,252,161,252,251,0,58,19,24,1,121,0,128,0,209,0,130,255,66,2,200,255,41,0,124,0,94,1,245,0,47,254,189,255,5,0,139,2,147,0,200,0,0,0,21,0,159,253,180,254,253,255,247,0,100,254,128,0,42,0,131,250,211,254,171,254,28,254,21,254,201,255,105,1,156,255,226,255,107,254,131,2,153,16,225,255,165,255,246,255,6,0,169,1,162,254,35,250,49,3,188,250,55,255,167,254,197,241,235,0,179,2,76,1,219,0,199,0,114,254,130,0,206,255,66,255,89,0,233,255,100,0,47,5,56,255,146,0,226,1,144,253,33,254,121,254,188,0,129,0,102,2,177,254,204,253,253,3,149,255,57,255,145,0,201,0,59,2,252,4,157,16,58,0,121,0,39,1,38,0,26,0,47,0,203,250,114,4,53,12,101,1,184,255,91,1,20,1,240,254,120,0,179,255,23,2,247,0,185,255,250,247,188,248,183,255,194,255,10,1,226,255,183,0,17,0,210,255,249,255,116,255,229,3,14,2,209,255,197,255,4,6,117,1,162,0,106,255,149,255,182,255,234,254,219,255,172,16,235,255,243,254,103,1,111,0,141,255,251,255,50,255,169,255,212,255,251,253,54,0,213,244,189,0,215,254,161,252,106,252,95,252,225,253,25,0,206,244,177,255,179,251,237,254,102,254,54,254,181,255,45,255,92,254,96,0,211,1,190,255,241,255,188,253,92,254,182,253,249,255,109,0,236,0,227,0,24,254,106,0,2,1,76,0,78,0,248,255,57,255,232,236,122,255,51,255,223,255,13,255,237,255,246,255,157,0,129,0,120,0,96,252,92,2,167,254,209,255,82,254,255,254,17,1,81,0,157,7,234,1,16,1,51,255,156,9,202,255,103,0,148,244,239,253,45,255,196,255,23,1,220,0,199,255,86,1,209,0,216,3,126,250,221,242,252,251,235,250,243,250,227,0,118,4,212,251,0,254,246,2,108,1,46,0,154,254,16,0,1,1,98,255,3,255,74,255,254,255,181,0,195,5,38,6,215,0,56,252,246,0,113,1,239,254,51,253,34,2,74,0,224,240,37,1,98,0,130,0,12,255,41,0,143,0,187,2,200,255,130,255,67,0,54,0,254,255,146,252,30,9,115,3,215,0,69,248,246,0,9,253,243,1,248,0,239,2,54,255,68,2,54,244,103,1,117,255,210,0,209,255,88,255,89,0,109,253,3,1,202,255,216,255,22,254,87,255,255,252,57,2,85,255,64,0,179,252,7,2,227,4,185,255,53,254,172,238,1,1,178,254,198,252,73,255,115,0,104,254,179,255,32,2,173,0,254,254,48,0,75,1,199,6,11,4,233,10,130,4,147,248,19,1,147,255,95,251,109,254,52,5,230,254,36,0,145,254,21,0,27,0,106,1,87,254,217,0,150,0,208,254,192,0,53,0,180,251,27,0,116,2,186,2,134,253,231,255,84,0,8,0,153,255,21,2,211,254,218,0,254,16,119,0,147,255,53,1,24,0,160,254,109,255,238,254,156,0,85,0,9,0,170,6,170,252,220,7,219,249,112,0,95,253,254,249,165,255,159,1,11,250,98,3,213,5,147,253,116,254,21,1,164,253,149,254,114,0,152,254,4,255,238,255,225,255,179,255,177,253,179,9,23,2,16,250,223,251,115,247,205,255,30,3,20,1,110,250,72,0,209,254,146,1,111,0,71,1,16,1,248,255,40,255,189,0,2,5,152,0,211,255,223,255,244,5,253,8,171,254,200,7,171,3,142,6,243,3,114,0,167,0,74,2,12,254,40,0,39,254,238,254,84,2,213,4,130,255,205,0,254,0,228,254,145,254,137,255,64,0,123,7,181,1,183,253,1,0,146,1,241,254,40,252,18,2,11,1,50,14,239,1,37,255,40,253,189,255,196,250,215,3,122,0,6,0,110,0,90,255,111,0,102,0,117,255,61,246,241,2,243,3,219,6,28,251,104,3,2,254,204,248,108,5,242,252,31,1,205,1,36,0,77,0,181,1,151,254,40,255,97,254,158,0,179,255,133,255,57,0,163,255,80,13,248,1,82,252,178,1,120,253,5,255,92,254,125,254,93,5,27,255,236,0,65,255,3,0,204,0,100,2,137,1,227,254,48,2,92,255,57,255,47,1,146,0,93,0,224,4,121,9,233,3,237,4,17,255,61,4,170,248,137,254,224,253,29,252,64,255,193,254,30,2,24,1,52,253,213,250,189,255,222,255,252,0,220,255,206,0,130,255,228,255,26,0,145,251,239,10,15,2,209,255,40,248,253,1,24,255,71,252,76,1,126,254,148,255,34,1,251,1,66,2,215,252,119,1,82,3,123,250,63,3,119,255,3,1,25,0,205,251,151,1,248,6,253,249,122,6,170,5,55,252,211,1,4,0,17,3,173,253,144,3,34,0,91,0,30,1,11,4,244,253,20,1,190,254,11,0,139,2,221,2,243,0,45,0,111,255,101,1,12,2,71,253,253,254,11,253,223,251,181,0,44,5,148,0,10,254,192,255,133,254,22,253,105,5,139,1,184,0,19,253,59,255,209,242,222,253,252,255,20,2,242,254,175,2,245,1,29,1,145,1,175,1,160,248,129,253,143,2,187,254,104,7,165,248,53,0,6,252,61,250,34,3,26,254,188,255,232,0,57,5,172,1,232,0,218,6,105,249,250,253,140,254,252,1,11,251,71,1,124,252,44,254,103,4,117,5,61,6,69,3,147,2,151,253,99,0,8,1,52,254,40,1,44,0,217,254,47,255,82,255,81,4,128,3,41,4,82,255,5,0,77,3,31,5,90,5,12,246,95,1,108,253,232,255,191,251,237,252,224,250,234,255,183,253,59,255,237,2,37,1,144,255,87,255,233,255,3,0,127,4,17,2,149,4,224,0,19,250,162,3,204,255,12,1,254,250,209,253,210,1,240,253,226,5,25,255,175,254,225,3,222,250,6,255,30,244,57,0,19,0,15,0,20,7,185,2,123,254,55,255,135,2,45,253,182,251,79,255,31,255,122,245,17,254,81,254,18,255,132,1,61,249,229,3,227,0,3,253,34,255,94,0,157,253,35,0,187,0,89,252,66,250,245,3,27,4,134,254,55,1,58,253,202,253,236,253,143,254,193,249,41,2,167,0,194,1,212,251,18,11,131,255,89,2,143,255,9,254,40,0,14,0,220,255,36,255,249,249,99,3,156,253,214,248,120,3,1,249,16,5,27,255,175,253,8,253,59,255,172,1,246,250,124,3,194,255,89,4,52,251,59,252,166,255,212,254,32,1,123,255,11,3,69,251,141,253,12,1,180,0,145,3,182,8,99,254,110,255,39,255,170,0,123,251,241,249,109,3,75,0,248,6,82,255,26,255,11,253,219,4,113,2,207,255,114,0,38,255,103,254,195,0,115,251,212,5,213,0,76,4,155,255,67,252,248,3,151,2,64,253,49,3,94,0,233,254,0,255,213,1,181,255,133,255,118,244,180,3,105,254,19,1,143,29,17,1,12,1,182,255,201,0,18,1,107,255,110,255,250,254,243,0,239,254,63,0,129,255,135,0,96,255,231,0,120,0,209,0,165,255,38,255,218,255,74,251,44,254,97,255,22,1,24,2,29,252,196,255,22,0,17,4,218,253,135,255,15,255,104,253,171,1,96,254,141,250,36,253,152,0,175,12,189,255,102,255,130,246,165,1,107,254,210,253,183,255,185,244,240,254,196,255,109,1,233,2,31,1,146,253,177,251,156,1,10,1,82,0,61,0,132,247,133,254,17,2,131,255,54,250,63,1,131,2,222,0,4,254,147,9,54,252,71,0,237,0,232,254,202,0,215,3,33,255,205,254,126,255,217,0,137,12,49,0,226,255,19,1,244,255,252,254,137,240,195,4,152,255,116,245,55,255,54,0,83,3,178,253,179,2,2,255,152,1,40,1,208,255,148,254,216,0,16,0,220,0,97,254,218,0,83,0,43,0,64,240,177,250,25,0,15,0,233,254,212,247,26,3,79,254,61,255,94,255,94,2,166,0,87,0,196,254,252,1,242,0,153,254,175,2,78,255,14,0,103,244,12,254,239,251,162,12,167,2,170,0,233,252,129,255,138,253,240,255,237,255,181,0,254,255,71,255,84,255,168,255,138,255,89,255,128,0,121,0,239,0,65,1,131,255,217,0,164,227,99,255,95,255,165,254,255,254,102,0,99,251,71,0,133,254,51,255,244,254,144,0,82,255,150,255,49,1,23,0,209,255,202,0,146,255,148,2,54,0,109,244,137,255,165,250,249,244,147,4,42,253,178,2,22,2,161,0,77,254,241,2,58,0,227,0,241,0,138,0,180,255,217,1,193,0,122,248,121,247,34,246,108,250,28,1,10,251,80,1,78,250,208,0,41,0,156,254,89,1,153,0,239,254,90,255,244,1,42,0,120,0,221,255,175,255,56,0,211,6,22,244,19,248,4,253,77,252,120,3,166,1,118,1,143,0,194,254,31,255,92,2,87,1,165,255,90,6,75,0,45,255,160,0,101,253,61,255,38,0,66,254,11,251,148,255,65,252,152,253,238,253,42,2,49,11,100,255,154,254,83,254,251,254,23,0,255,1,84,1,220,253,43,9,105,0,12,0,224,255,164,0,170,0,88,255,12,1,27,10,183,13,100,2,73,1,159,0,200,1,17,1,60,254,168,0,118,254,31,3,198,255,160,0,32,254,255,254,242,0,167,0,46,0,103,250,161,249,50,0,84,3,253,1,96,3,131,254,206,254,70,253,5,1,66,253,237,255,17,16,218,255,103,255,245,255,149,1,71,254,136,255,139,0,247,254,225,0,86,1,199,0,37,8,237,0,22,1,252,0,1,6,119,0,182,0,82,255,63,255,182,9,87,0,87,11,201,254,208,254,17,1,39,255,0,255,248,254,93,253,205,252,68,255,153,253,97,251,239,1,102,255,81,253,119,9,197,0,193,255,110,255,127,4,128,3,151,251,198,255,90,4,148,249,195,4,120,253,185,255,126,255,173,245,21,2,38,255,102,15,173,255,208,0,44,253,198,0,125,253,78,2,80,252,200,255,92,254,115,0,23,0,98,254,112,255,39,1,219,0,220,255,137,1,82,255,91,0,34,1,102,228,158,0,237,254,186,255,137,255,255,255,46,1,250,254,183,255,195,255,110,0,60,255,231,255,87,0,66,254,97,255,250,255,149,255,115,0,118,226,5,0,223,255,28,1,150,255,34,0,116,255,160,0,208,254,240,254,87,255,25,0,93,0,51,255,28,0,169,0,91,255,222,255,206,255,87,1,156,8,160,5,49,3,127,248,178,253,241,253,81,0,148,254,158,254,163,0,222,251,185,7,244,0,181,255,177,4,49,255,37,1,223,254,151,255,135,255,4,14,157,3,254,255,55,255,164,252,149,3,100,0,9,1,56,255,212,255,239,253,95,1,189,253,153,255,186,0,218,241,52,0,181,0,253,254,101,254,252,255,184,254,124,1,5,2,50,1,57,0,84,1,191,255,249,254,201,254,238,1,70,1,8,232,235,2,115,255,40,1,217,0,254,255,131,255,8,0,168,255,254,0,138,244,253,254,178,3,119,252,141,2,180,1,65,13,109,255,99,255,27,0,166,0,43,1,8,0,240,255,131,2,114,0,217,0,57,0,235,255,214,254,19,0,129,0,185,6,122,255,33,9,13,3,29,254,20,253,118,0,182,254,30,255,78,241,222,0,95,254,102,255,232,255,243,255,114,4,210,0,101,1,134,255,1,1,143,254,95,3,13,0,192,254,73,254,79,254,141,13,155,252,116,0,44,245,202,0,41,4,126,255,225,254,142,0,224,254,54,0,62,1,131,0,240,255,84,0,238,0,151,254,166,3,61,5,37,0,130,0,100,254,146,0,44,253,253,255,201,252,251,9,17,251,11,0,109,255,92,12,173,255,217,255,129,255,2,1,26,0,99,251,11,13,92,253,226,255,200,255,179,2,99,3,203,2,121,252,37,1,51,255,120,254,234,255,17,2,180,255,153,8,177,1,134,0,58,5,238,255,85,0,56,12,33,0,156,3,1,1,126,6,255,252,65,1,63,254,138,254,198,255,171,253,122,249,97,0,222,0,26,252,148,1,101,255,133,0,102,1,6,255,131,255,163,0,139,23,28,255,140,255,195,255,146,252,75,253,198,2,252,253,65,255,229,255,187,1,83,0,82,255,73,253,139,255,149,255,203,255,114,255,92,0,111,255,142,255,194,255,58,253,136,243,152,252,212,12,247,253,220,255,76,252,252,0,3,255,113,255,4,1,109,0,232,255,6,1,87,255,60,255,195,0,105,0,27,0,121,255,186,6,70,7,255,253,242,254,112,255,98,254,197,255,91,0,224,254,160,255,200,255,52,255,17,1,170,0,85,255,194,255,127,236,131,255,189,255,206,255,226,0,237,254,88,2,105,0,39,255,62,254,169,255,236,255,159,254,24,0,182,255,167,0,89,7,92,239,112,255,48,0,92,0,187,0,63,1,85,1,22,0,252,255,149,1,147,0,237,0,136,255,122,0,19,255,56,0,253,253,103,255,77,1,66,3,145,1,210,0,116,234,7,0,127,0,147,0,116,255,33,254,230,255,123,249,235,255,109,255,60,0,131,1,53,2,116,255,61,233,243,254,161,251,188,254,118,0,57,255,245,255,105,0,207,255,150,0,108,255,178,0,182,0,162,0,150,0,68,0,29,255,3,0,221,0,182,254,233,255,65,0,118,24,71,0,48,0,215,255,246,255,255,255,212,255,1,255,206,255,118,255,147,255,202,255,225,255,236,1,42,255,239,0,62,255,35,0,52,231,108,255,9,0,25,0,133,255,84,0,64,254,241,0,148,0,221,255,52,0,35,0,7,0,99,0,240,255,57,0,213,255,0,255,8,13,117,1,211,0,255,253,24,9,86,0,238,254,130,1,74,0,82,255,112,2,243,251,126,251,36,0,47,255,252,251,155,255,100,254,153,255,245,254,149,255,130,255,163,0,118,254,183,251,156,255,217,249,226,253,254,12,155,247,35,2,114,2,234,254,98,254,243,252,230,1,70,255,97,255,138,0,69,255,203,252,163,1,137,1,86,239,60,3,175,1,86,0,233,2,33,5,204,5,4,1,52,0,163,0,57,254,209,251,186,0,10,2,32,1,165,1,18,0,97,0,243,4,200,0,77,10,67,255,217,2,234,2,203,0,129,253,181,252,116,8,159,2,84,0,176,246,174,1,95,255,148,1,166,0,223,255,239,255,79,2,29,255,247,240,43,6,175,0,50,253,99,0,102,254,180,252,17,255,32,0,212,0,163,0,224,1,75,3,133,254,147,253,195,254,88,254,113,0,250,254,44,0,163,255,17,2,144,0,38,255,140,0,185,12,193,253,119,245,144,0,173,255,70,255,212,255,209,3,153,0,26,255,6,250,234,0,212,0,212,0,75,1,156,1,131,255,253,255,166,1,183,254,123,247,126,5,107,1,166,255,170,255,73,1,245,254,146,238,67,255,169,255,154,0,66,0,56,255,37,0,80,0,147,255,57,255,125,0,191,7,4,1,74,254,143,246,187,12,50,252,197,1,41,0,179,255,230,253,99,4,119,0,120,0,254,0,17,255,122,255,33,0,128,254,105,254,27,0,209,1,18,7,114,252,212,3,241,255,229,250,105,252,88,7,185,254,209,254,58,255,149,0,157,1,128,8,221,8,61,253,87,1,104,1,169,0,148,0,182,0,104,0,163,0,89,3,35,1,103,255,47,1,89,253,126,254,156,252,235,8,192,254,167,0,185,12,205,6,82,1,211,1,209,0,207,0,66,3,30,255,33,254,136,255,138,6,195,255,184,2,163,255,209,250,128,8,204,2,146,1,152,6,171,8,173,254,11,3,110,1,102,1,241,0,73,253,240,254,120,255,208,255,36,0,243,254,94,3,152,253,138,255,20,248,142,6,179,7,115,0,34,1,71,0,3,253,31,0,198,244,122,0,13,0,88,254,231,254,192,254,233,0,248,251,40,0,70,255,184,4,18,1,250,246,198,249,33,1,230,0,240,4,194,3,202,254,23,0,220,253,12,0,218,255,82,245,152,2,37,0,90,1,148,253,10,1,158,255,82,0,65,9,195,3,145,250,61,254,65,3,82,0,175,0,192,1,82,7,89,1,72,254,155,0,130,0,94,0,70,1,151,12,234,0,93,255,128,254,158,254,229,253,59,3,247,255,18,2,30,255,235,255,76,1,6,247,149,12,190,5,230,254,224,252,231,0,58,1,26,252,229,251,120,253,78,254,231,2,184,255,119,0,91,0,158,1,123,1,90,5,131,253,26,252,83,3,168,244,246,254,140,249,180,250,197,250,113,249,75,255,245,0,219,2,25,255,254,255,221,0,74,255,187,254,101,254,90,1,246,0,187,245,200,6,151,254,24,0,229,0,144,4,235,2,53,1,169,1,128,255,192,254,16,254,109,0,216,5,186,255,227,252,37,0,241,254,217,255,138,3,194,255,62,255,217,6,55,1,177,2,74,5,245,251,51,252,74,254,142,4,149,8,157,255,132,254,238,254,227,249,191,1,100,0,93,1,229,1,141,2,232,2,50,0,186,253,133,255,140,250,156,0,229,255,93,1,213,251,154,250,108,5,219,251,214,253,126,3,176,255,241,252,36,250,32,253,129,3,134,4,150,250,216,255,232,254,205,252,96,253,129,252,226,3,204,254,46,254,190,253,199,1,0,250,111,3,64,254,30,2,228,5,82,3,95,246,48,3,129,2,85,254,54,1,88,255,215,255,116,252,210,254,233,5,227,255,136,251,76,2,89,249,120,4,63,10,90,0,28,1,98,3,79,1,161,254,163,1,23,253,111,3,73,255,200,252,79,249,222,255,241,255,111,252,37,0,52,254,10,3,82,8,111,255,103,255,225,6,140,5,13,255,224,255,147,252,140,0,68,253,100,2,251,247,65,1,178,255,91,255,200,0,14,2,22,252,128,8,2,252,156,5,42,1,235,255,158,250,3,2,48,1,206,3,186,6,6,8,149,2,169,1,26,1,215,1,182,1,70,0,169,0,51,6,228,247,216,255,66,253,8,1,110,255,37,250,161,252,17,249,221,251,22,254,92,0,119,2,86,251,249,251,79,1,1,1,237,250,241,0,242,254,187,254,190,254,219,255,0,0,83,253,129,3,216,3,115,252,20,6,1,5,87,5,11,251,201,249,159,1,124,251,138,254,146,255,16,6,73,253,74,0,89,255,39,254,141,5,157,253,175,0,241,5,42,5,180,1,177,7,237,252,17,4,38,253,170,253,188,0,230,252,237,253,106,247,195,254,245,255,248,255,105,254,198,0,100,251,117,249,174,0,213,3,211,1,107,255,134,252,7,1,6,4,135,255,99,8,121,255,183,7,134,253,175,1,18,255,73,253,58,5,84,255,110,0,147,0,178,254,42,253,65,0,151,252,155,2,229,3,162,251,173,254,144,0,68,253,23,5,49,255,159,253,175,249,3,253,71,3,249,1,220,255,198,255,178,244,226,0,12,232,250,254,239,254,30,251,191,253,216,3,82,254,102,254,48,254,65,2,190,253,78,255,224,255,113,1,144,253,11,1,188,255,218,1,32,254,31,255,166,0,103,254,181,1,25,18,98,0,232,249,48,254,155,252,103,0,193,0,205,1,72,0,36,1,11,255,78,4,161,1,187,254,205,1,74,0,43,0,136,255,43,255,77,1,160,0,44,254,44,255,31,0,175,255,116,25,182,0,201,0,44,255,190,255,207,255,246,254,148,0,148,255,98,0,210,255,245,255,197,255,236,255,236,255,28,9,218,254,208,253,198,0,121,253,209,255,130,253,219,240,11,0,66,3,35,2,47,0,237,9,130,255,251,255,146,254,83,1,3,0,2,0,190,255,60,0,242,253,146,3,65,1,110,253,21,14,59,0,168,246,113,253,128,1,7,3,110,1,71,1,100,1,130,1,239,2,137,254,38,0,51,255,241,255,70,254,44,255,39,251,121,7,91,254,13,253,45,0,155,249,220,255,125,246,224,5,32,251,5,253,104,253,133,0,133,255,46,3,241,0,13,255,66,254,66,0,125,255,43,255,244,7,14,5,166,247,165,2,238,251,253,252,38,1,115,1,218,1,85,0,123,5,198,245,34,254,231,253,19,1,198,252,93,1,84,0,8,1,240,254,195,255,63,253,175,0,52,252,100,3,25,0,87,16,113,3,129,253,191,252,11,253,217,251,33,252,255,254,119,255,149,253,227,254,58,254,77,0,87,255,60,1,211,255,10,17,53,255,172,247,88,254,204,252,9,254,84,1,84,1,156,253,136,2,2,0,170,254,81,0,118,2,18,250,235,0,216,0,210,0,153,2,231,0,130,0,145,252,38,0,163,2,120,255,208,255,28,2,22,255,104,255,87,255,143,233,218,254,232,255,8,0,127,255,248,255,52,1,242,255,240,255,147,0,62,0,70,0,248,0,34,248,76,0,66,255,184,254,149,248,159,254,116,255,68,3,147,254,144,255,151,240,32,253,211,1,254,254,89,2,105,2,74,0,62,0,138,1,180,0,127,4,214,252,36,0,201,1,150,1,75,0,248,255,116,236,31,9,148,255,133,255,43,1,177,254,112,0,13,254,244,254,71,255,205,1,208,0,218,255,92,255,252,2,8,254,16,1,245,18,140,1,9,1,147,251,79,254,1,3,54,254,237,3,133,2,81,0,84,255,129,1,200,255,126,255,119,254,128,0,183,255,31,0,246,7,127,0,76,254,123,0,35,246,26,1,64,254,23,254,217,254,242,255,85,0,50,254,207,255,6,1,163,255,238,0,108,255,143,240,98,254,253,254,33,0,132,252,203,1,118,247,60,0,188,1,158,253,76,3,26,254,213,254,219,0,79,254,19,0,97,251,20,1,227,255,132,1,255,12,102,0,110,252,35,255,230,1,132,252,218,253,190,0,151,0,115,255,176,254,194,0,14,255,32,255,149,1,111,3,64,6,93,1,222,247,218,255,254,253,18,0,10,242,161,0,114,255,218,255,233,248,28,2,228,0,33,0,164,0,50,4,4,0,234,254,198,255,245,15,217,254,229,252,31,0,238,1,43,2,6,255,22,0,54,255,200,254,92,0,109,0,18,255,64,254,146,253,25,250,6,239,95,254,62,253,37,0,133,4,160,255,57,255,197,255,29,1,213,255,39,255,234,255,161,255,103,0,194,8,244,0,45,0,182,255,249,255,110,1,177,255,153,254,226,254,188,0,242,255,34,0,49,0,245,0,148,255,172,255,88,0,179,254,40,255,177,255,15,0,178,233,220,255,154,255,216,253,43,255,248,255,156,254,3,2,212,0,247,254,80,0,60,1,117,251,207,253,251,253,54,253,137,254,176,239,73,0,102,253,149,254,228,255,224,4,188,255,222,1,88,10,130,2,58,253,213,253,24,253,90,255,24,253,172,253,138,0,243,1,59,0,197,1,185,253,222,254,245,255,208,255,78,16,4,255,182,255,178,255,194,255,193,1,247,254,206,252,155,254,171,0,255,253,72,0,106,0,211,255,137,2,145,0,182,21,196,255,120,255,69,0,84,255,122,255,190,255,188,255,100,0,171,2,85,254,27,3,105,254,89,1,66,19,186,252,105,1,23,1,66,255,173,0,171,254,247,255,210,2,127,1,116,255,123,0,243,254,154,0,31,0,79,1,47,254,55,1,46,0,183,17,125,255,90,0,151,0,31,1,245,255,242,253,154,253,51,247,191,254,163,255,218,253,128,255,25,0,47,1,117,255,19,0,0,0,73,243,95,255,20,1,103,0,11,255,253,253,48,3,238,251,87,250,157,6,141,253,7,5,187,252,41,253,176,255,34,254,175,254,116,0,1,0,242,254,201,253,201,254,105,254,136,249,40,255,196,0,188,11,227,254,247,253,230,5,26,7,112,5,42,0,212,255,12,255,163,254,191,3,73,255,25,0,58,0,43,0,167,254,202,254,0,224,172,255,55,1,196,255,164,254,125,0,33,0,177,255,118,255,88,0,138,0,135,255,219,255,45,255,138,255,114,255,219,255,124,255,181,0,162,0,113,250,245,6,131,242,237,4,134,0,158,2,194,4,249,2,36,1,110,255,199,252,160,2,225,2,37,1,177,1,245,0,120,254,46,0,86,2,1,1,22,255,79,251,206,2,59,238,195,253,72,253,32,255,171,255,75,0,244,254,244,0,25,7,85,1,90,255,180,1,126,254,33,251,22,0,144,255,201,255,61,254,106,0,132,1,224,255,2,255,160,246,139,254,124,3,78,1,238,239,205,254,149,255,196,254,41,0,42,255,109,254,200,255,43,254,10,255,120,0,19,255,10,1,43,0,185,12,171,240,35,1,239,0,240,2,101,254,162,0,181,1,159,0,0,1,37,0,71,0,177,255,120,255,37,254,124,0,48,255,40,255,11,255,16,0,40,0,53,254,32,239,84,1,74,250,146,3,10,0,234,1,180,1,162,0,15,1,18,255,218,255,171,8,25,0,115,255,149,1,107,0,235,0,26,1,201,255,249,255,155,242,53,2,185,251,90,253,187,7,233,0,150,252,80,2,38,254,168,2,146,1,30,253,21,0,18,1,191,254,143,2,164,254,222,253,254,1,62,0,23,0,114,18,60,2,167,1,0,255,217,1,216,4,27,252,125,252,203,255,183,255,76,1,122,252,253,252,177,254,0,0,1,3,181,253,80,2,65,253,168,253,179,255,162,255,49,255,24,3,123,255,10,253,244,1,242,255,74,1,22,0,231,254,172,234,152,0,95,2,81,1,217,255,138,255,176,255,205,255,228,0,65,0,250,255,28,2,69,242,80,249,63,254,99,255,92,255,61,255,137,249,251,250,90,0,251,253,140,255,11,0,122,5,94,255,192,255,153,255,46,0,46,1,37,0,71,0,87,11,136,11,12,3,25,254,215,254,86,254,143,254,150,0,127,255,23,255,45,3,103,6,190,0,54,1,201,254,64,1,94,0,9,255,204,5,224,255,70,0,36,255,48,2,116,1,54,0,205,0,96,0,17,242,88,253,147,6,183,246,17,0,36,2,246,254,1,1,144,2,75,1,205,0,135,255,210,252,139,0,70,1,142,254,113,2,243,7,50,3,7,3,115,251,215,255,94,239,41,0,85,4,216,3,139,252,213,255,198,254,204,0,204,0,95,0,151,1,161,254,101,0,133,0,95,252,131,3,250,255,128,1,79,255,182,254,240,0,90,0,78,0,194,254,57,254,251,255,147,254,195,255,176,255,184,255,14,237,174,254,128,254,30,0,181,0,95,245,1,253,145,12,197,1,30,255,186,253,27,1,135,0,153,255,9,1,238,1,92,250,136,255,70,0,48,252,189,255,166,255,148,2,110,1,159,253,32,0,205,0,73,0,51,0,90,1,250,255,136,255,246,255,44,1,32,0,14,1,139,0,201,255,197,1,80,22,97,1,111,255,176,0,88,255,216,0,205,0,226,255,208,254,61,4,221,0,208,1,86,254,126,6,139,250,166,251,45,1,222,251,225,13,124,254,231,2,184,2,131,252,216,254,199,255,2,255,5,255,78,255,161,1,82,0,36,252,18,242,123,8,224,250,70,252,233,255,187,250,224,1,54,2,24,0,125,253,220,254,188,255,47,1,73,0,175,255,40,1,7,0,115,1,94,0,182,6,242,1,250,252,89,3,246,3,102,1,180,1,210,0,103,242,54,255,96,254,59,0,195,7,137,0,36,254,32,0,141,253,193,0,112,1,253,255,222,254,37,244,160,254,57,254,159,253,81,255,251,255,168,253,75,255,7,255,9,246,226,0,105,0,7,255,59,7,170,255,77,251,214,0,199,255,7,254,246,253,9,255,102,255,216,255,239,255,245,253,77,1,15,249,158,254,224,249,92,242,8,4,41,6,90,0,153,0,22,2,150,255,230,253,102,0,3,0,58,255,157,255,233,255,67,3,167,13,181,251,44,0,220,2,162,254,158,3,40,254,21,2,249,5,54,0,180,252,15,5,61,2,158,1,233,255,185,255,23,1,133,252,31,1,126,0,176,5,205,3,200,1,72,6,122,253,36,251,196,1,139,2,182,2,87,3,21,255,9,254,233,2,224,253,72,242,118,255,166,2,217,1,220,0,239,254,247,255,9,1,174,248,141,1,172,4,28,1,61,252,42,1,62,1,251,246,94,255,66,1,30,251,240,255,20,252,251,255,240,10,192,255,72,0,30,254,94,255,100,254,150,244,6,3,177,254,238,0,136,251,122,255,148,5,46,2,177,7,109,253,134,3,94,249,25,3,166,252,155,253,230,3,253,0,176,254,164,254,176,255,139,255,248,254,99,1,40,3,16,3,209,253,238,7,160,7,12,255,150,251,38,252,91,7,147,4,19,254,186,254,144,252,28,10,13,255,52,255,194,0,84,255,191,255,234,7,168,1,75,2,195,254,246,9,167,253,203,0,99,253,219,1,92,253,44,250,27,0,41,0,202,251,213,254,138,253,177,0,92,255,83,254,10,255,155,254,167,4,157,252,173,250,85,6,146,255,148,3,217,0,11,251,110,2,78,254,167,251,120,3,215,255,252,3,18,249,46,0,80,0,29,254,132,252,195,255,40,254,193,0,64,255,208,7,153,255,228,2,33,255,189,9,166,1,204,9,181,254,214,1,47,251,47,0,83,2,27,3,47,254,192,254,93,255,128,0,6,0,47,255,91,2,24,2,96,254,81,250,169,255,89,251,158,255,231,254,235,3,141,5,132,1,139,4,134,251,175,255,213,254,214,9,208,251,207,0,69,254,250,1,36,255,166,254,98,0,71,8,96,254,36,247,14,254,109,0,194,250,177,254,101,4,56,253,156,0,192,251,212,247,140,4,12,254,113,0,239,255,39,2,57,255,6,1,229,255,76,253,139,253,204,0,88,250,186,249,238,249,33,1,126,1,77,253,205,4,158,1,46,249,82,251,89,4,126,254,54,1,74,5,244,255,228,254,199,253,46,0,210,253,215,5,172,0,125,252,105,2,59,3,147,254,100,0,240,3,136,0,63,8,10,0,16,9,221,254,108,1,111,254,104,254,240,253,156,253,127,0,194,4,128,254,129,0,189,249,182,1,5,4,232,9,106,255,104,250,168,252,44,4,5,3,6,253,216,252,164,2,75,253,148,1,145,0,4,0,27,0,108,255,194,254,5,252,235,254,124,5,112,3,145,251,93,3,135,3,227,2,47,1,139,0,126,7,72,252,33,3,206,254,121,246,253,255,186,1,178,253,246,251,178,0,174,1,153,0,61,7,205,7,230,2,209,6,160,253,19,255,160,0,11,2,182,3,82,0,68,250,200,249,39,3,207,2,106,2,63,1,57,0,235,0,31,1,64,5,206,255,68,1,74,255,147,254,131,254,135,254,197,7,147,0,195,253,222,4,233,6,39,254,78,255,193,3,239,250,18,253,108,250,34,251,21,3,158,0,100,2,17,0,220,254,29,255,114,255,64,0,51,0,240,255,211,254,225,254,196,255,108,254,245,254,109,0,148,255,189,0,74,254,48,0,95,0,61,236,214,255,229,240,64,254,154,8,129,0,156,255,137,1,37,0,245,254,100,255,23,0,238,254,222,0,33,0,65,255,104,0,116,255,206,255,228,255,108,255,75,255,234,255,6,0,233,1,225,3,52,245,167,4,251,252,13,3,52,254,75,3,179,255,119,250,134,1,124,0,53,255,205,0,150,2,240,255,57,2,61,252,97,2,101,255,64,0,219,254,89,10,27,246,70,0,40,254,30,254,60,249,235,0,251,255,27,254,116,0,79,255,152,255,58,1,157,254,118,0,25,0,153,3,29,1,130,0,162,255,77,0,121,0,44,4,77,254,127,5,191,1,85,254,184,251,11,253,2,1,19,0,164,12,190,2,106,1,96,252,164,254,106,255,240,252,81,253,124,254,80,255,218,255,16,0,242,255,249,3,111,3,167,3,0,5,246,3,171,255,0,255,153,255,200,242,96,252,56,255,106,254,81,255,48,1,202,255,195,0,178,255,164,2,156,254,89,255,91,255,200,255,195,243,156,0,85,255,84,253,70,253,121,255,230,0,226,255,32,0,30,2,167,7,132,255,180,255,162,0,182,0,82,255,243,3,159,255,166,2,10,0,188,0,30,0,62,4,250,254,99,255,250,0,241,0,233,0,184,253,204,12,78,8,206,255,49,255,125,2,72,254,75,1,78,254,251,0,245,254,13,1,120,254,68,0,12,255,8,0,160,3,59,3,184,251,203,254,156,254,137,254,124,243,166,1,183,2,2,0,240,0,83,2,129,2,70,2,86,1,42,0,7,0,27,2,192,255,140,255,82,0,16,0,26,0,120,255,134,255,142,255,74,233,22,0,240,254,10,0,113,0,186,0,90,254,161,255,53,1,52,1,138,255,48,255,52,0,81,255,12,0,150,255,250,255,20,0,58,0,165,23,155,255,236,255,10,0,70,0,189,0,57,0,245,255,210,0,83,0,239,0,250,255,177,255,23,255,197,255,31,0,226,255,194,255,64,0,218,255,25,0,178,255,54,255,41,255,141,255,197,5,255,0,101,0,241,245,186,0,68,12,210,255,211,255,53,0,73,255,167,255,100,254,183,0,34,255,50,0,19,255,96,0,35,0,148,6,247,253,87,255,76,254,217,254,110,5,5,1,27,0,163,0,96,1,68,0,163,241,12,0,54,1,169,253,75,1,138,0,179,254,243,254,126,255,212,255,242,255,9,1,142,253,2,1,197,255,31,0,239,255,222,0,246,255,148,254,24,1,73,255,21,255,39,255,73,0,189,255,114,0,196,0,244,235,13,1,159,0,250,255,220,255,8,255,18,1,184,254,152,10,119,254,203,10,251,1,146,255,90,255,172,255,184,255,169,251,237,255,114,1,25,0,5,0,156,0,224,255,237,0,199,255,150,255,234,255,114,1,27,255,75,4,201,16,152,0,72,0,200,255,91,1,64,0,11,254,199,255,178,0,175,0,242,255,172,255,142,253,43,2,155,0,20,0,181,255,20,0,223,255,2,255,131,255,247,255,150,0,91,0,249,255,211,255,239,0,147,255,72,0,190,255,84,255,45,255,175,23,51,255,171,0,181,255,50,0,181,255,22,0,109,0,21,0,198,255,58,0,151,255,80,254,54,1,198,14,238,255,209,251,19,0,20,0,175,5,81,1,255,254,224,254,204,255,7,2,43,0,80,0,81,255,38,255,9,0,176,0,228,255,94,254,200,0,254,253,95,1,119,0,224,232,160,255,223,255,223,254,74,0,26,0,120,0,219,255,113,0,47,0,111,255,239,255,78,1,46,0,47,0,19,0,18,1,172,0,159,0,108,254,79,12,104,254,209,253,219,3,78,255,253,0,166,255,14,254,174,5,159,4,136,1,250,2,220,0,73,251,36,255,187,255,171,255,22,0,108,6,66,7,213,2,60,4,0,0,255,254,34,1,176,6,105,255,68,255,122,254,126,2,185,254,119,247,190,254,164,251,106,255,120,0,116,255,198,0,162,0,173,255,41,5,232,0,242,0,204,255,56,254,10,3,224,254,65,0,127,9,37,0,85,0,23,254,94,3,216,10,4,1,184,255,24,3,100,0,17,0,46,255,76,2,49,0,88,2,246,0,254,254,128,0,205,255,20,254,117,254,23,254,50,0,68,235,189,255,58,1,124,0,46,0,68,255,192,255,155,255,51,0,233,253,108,0,56,0,252,255,65,255,101,252,229,1,66,2,40,5,228,0,233,253,54,1,227,0,139,1,95,250,100,10,226,0,120,254,221,0,82,253,213,6,81,255,120,252,197,253,127,255,154,0,62,10,97,2,9,255,16,255,131,252,98,0,35,1,27,247,155,1,4,1,96,255,13,8,53,255,75,254,103,1,21,0,155,255,19,0,49,0,15,0,158,255,82,0,3,0,213,253,164,0,104,255,198,255,38,0,175,0,73,254,219,255,68,0,235,255,75,255,76,234,229,255,8,0,48,0,21,0,105,255,125,1,3,0,104,255,182,255,202,0,227,255,71,7,177,6,102,252,72,248,39,2,14,250,13,2,140,255,146,0,62,249,18,255,184,255,73,255,126,0,234,0,16,255,82,0,138,0,196,255,125,255,78,247,226,0,66,253,183,0,175,255,206,1,221,244,117,250,19,252,124,0,175,255,4,255,191,255,147,0,198,255,77,255,50,1,154,0,122,0,187,255,69,0,11,0,115,0,40,1,12,13,11,254,236,245,220,252,9,0,79,2,170,255,88,0,127,0,76,2,183,0,48,0,79,0,218,255,57,255,63,0,116,255,29,0,88,0,228,255,3,1,69,0,207,6,237,253,110,0,238,255,8,3,238,255,79,255,112,0,36,0,13,255,48,255,16,2,209,255,101,18,107,0,131,255,140,0,255,255,22,0,15,0,160,1,62,255,245,254,207,255,43,0,253,255,204,254,214,0,128,255,140,0,252,20,133,255,70,0,19,1,210,0,182,0,109,255,125,255,172,255,69,0,116,0,29,0,111,254,94,255,20,255,83,255,122,1,45,0,244,255,179,255,191,231,153,255,126], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1533125);
/* memory initializer */ allocate([0,54,0,237,255,236,255,43,0,64,0,92,0,248,255,244,255,118,0,133,255,58,0,212,241,98,254,157,247,76,0,95,0,157,255,101,1,246,255,22,1,4,0,160,253,248,1,105,0,184,255,147,255,164,255,201,255,111,1,89,255,40,0,222,255,76,0,220,0,106,13,146,254,191,0,248,0,29,0,187,0,79,255,155,0,164,254,171,254,94,246,16,1,120,255,254,1,139,0,81,0,184,0,33,0,213,254,92,0,212,255,110,254,185,253,43,253,112,254,97,255,239,2,31,255,121,1,96,255,20,6,164,245,173,2,203,251,252,4,76,1,255,254,87,250,230,254,25,255,111,255,58,0,173,0,165,1,15,1,145,1,70,255,79,0,254,254,127,0,252,0,214,0,96,0,157,0,195,0,205,0,118,0,93,237,161,255,92,255,217,0,221,1,205,255,252,255,8,0,170,5,205,255,204,255,184,3,163,2,161,3,239,254,219,1,9,0,26,1,7,255,236,0,234,2,129,250,240,254,53,7,180,2,151,255,130,10,168,0,1,0,255,255,157,0,169,253,49,1,255,0,52,247,45,0,57,255,119,0,95,242,95,255,6,0,249,254,253,254,82,1,5,255,61,0,153,0,132,255,176,1,249,255,131,0,5,0,49,1,190,254,45,243,224,255,176,254,239,254,195,8,95,3,255,255,169,2,147,254,10,255,104,255,119,1,123,255,241,255,48,255,152,255,89,0,128,0,121,255,44,0,1,255,37,2,65,245,208,255,14,1,232,245,219,253,137,253,189,1,182,0,58,255,231,2,41,255,196,255,112,254,103,5,167,0,191,255,250,0,146,0,185,0,22,0,28,254,95,255,86,0,222,6,196,3,148,1,242,245,2,4,6,0,252,253,44,253,59,1,157,248,55,1,2,0,83,1,217,255,68,1,43,1,15,254,244,255,179,0,38,251,108,1,71,255,59,255,62,250,232,0,22,254,202,15,151,255,119,3,31,0,27,2,235,0,75,0,144,255,56,255,225,255,74,0,180,255,240,255,236,255,38,0,97,255,113,255,114,0,179,255,146,255,28,0,238,255,172,255,229,255,203,255,174,255,32,255,75,0,0,0,210,255,192,255,44,0,144,255,84,0,171,255,114,232,232,255,149,2,38,254,78,255,8,0,1,252,116,254,199,0,237,255,206,255,163,255,129,1,209,0,53,251,188,9,115,8,218,3,177,250,143,1,80,3,169,2,195,252,211,0,184,2,169,253,138,250,159,7,143,255,118,1,239,255,167,251,84,249,14,5,154,2,238,6,111,2,3,1,105,0,193,3,169,255,43,0,49,254,65,0,155,0,230,255,225,255,59,250,4,254,67,4,73,250,244,253,195,248,74,5,178,1,86,0,125,3,153,252,151,0,161,248,205,0,167,1,89,3,201,255,245,255,217,255,85,1,61,0,134,4,90,10,131,3,69,246,175,253,181,252,137,250,241,255,55,253,85,255,61,255,245,253,210,255,243,0,117,0,241,0,248,255,140,0,107,255,65,255,70,0,134,0,122,251,141,7,111,4,20,247,231,251,181,6,122,1,101,255,219,255,171,0,76,253,232,254,150,3,238,252,133,255,46,2,59,2,39,0,197,254,62,0,27,0,59,0,196,2,122,255,56,255,88,255,122,255,148,0,114,255,25,0,164,0,230,254,28,1,161,255,221,255,120,1,165,0,111,1,177,254,15,1,249,0,88,238,176,0,220,255,40,255,233,250,119,1,92,0,90,2,135,252,122,254,28,1,78,0,218,250,235,4,73,7,218,5,15,8,22,255,184,252,121,254,88,0,168,0,21,255,182,255,31,0,17,255,197,4,71,0,155,249,233,5,68,0,153,8,233,5,181,251,146,253,170,1,87,1,182,254,120,253,125,1,100,255,27,0,225,255,164,255,133,0,210,0,103,0,101,255,13,8,146,254,107,251,225,255,238,254,55,253,41,254,253,1,20,4,208,0,147,1,230,1,190,255,247,253,165,248,76,255,231,253,3,5,158,255,72,250,56,254,252,1,149,253,222,253,173,2,176,3,171,255,55,1,148,4,62,255,126,5,157,255,197,252,226,5,140,1,196,0,2,250,99,251,52,6,226,4,47,0,10,4,85,255,33,251,158,255,136,255,157,4,109,247,128,254,177,3,115,2,26,0,8,255,92,5,97,253,214,0,119,253,239,255,212,255,12,254,209,253,65,2,167,253,32,0,165,1,19,2,88,1,47,251,145,0,92,1,102,2,208,253,12,255,155,254,54,255,46,3,18,254,240,246,52,1,27,247,31,254,250,253,81,254,173,252,43,0,52,255,230,255,26,253,59,4,126,255,210,7,106,6,124,251,210,6,239,253,169,3,224,253,160,1,27,253,251,2,24,255,253,1,243,0,54,254,78,0,126,255,143,0,133,255,71,0,102,253,151,255,31,0,219,251,185,1,208,255,155,1,245,249,155,0,38,253,183,1,88,6,105,3,157,253,42,254,44,9,99,255,160,4,166,2,82,255,30,2,161,255,244,255,107,254,237,0,66,1,86,251,111,7,216,5,101,1,222,255,107,253,0,252,188,8,92,3,0,255,105,2,244,2,27,254,239,254,179,253,24,2,214,0,226,254,14,3,162,1,90,1,50,254,187,1,32,4,110,252,208,254,204,253,180,254,31,7,31,8,93,0,49,252,133,252,191,251,48,253,153,251,190,2,44,1,19,3,118,1,178,255,46,4,179,2,59,5,227,252,57,0,226,1,176,1,236,2,2,6,161,2,93,7,8,254,121,7,66,255,121,255,113,3,117,255,84,0,123,1,80,255,127,255,181,254,222,255,78,253,26,1,205,253,51,0,71,0,54,253,153,255,50,4,117,253,186,253,108,5,192,254,165,251,11,6,192,251,191,255,182,245,55,255,115,253,116,0,18,255,38,255,220,1,137,5,135,6,111,4,255,251,102,2,106,253,127,0,95,3,139,255,214,2,53,252,102,5,226,254,209,1,171,4,53,253,94,3,24,251,105,0,37,0,90,251,70,254,15,249,50,0,162,0,41,6,68,2,250,2,253,0,92,0,204,254,42,251,95,255,39,1,106,255,197,6,39,7,241,253,241,253,228,255,70,0,153,254,202,249,92,3,35,255,47,0,79,251,2,255,39,0,12,3,186,254,73,4,5,252,66,3,106,1,101,1,41,0,181,2,181,251,129,245,102,2,14,1,128,255,190,254,131,251,119,2,210,255,169,254,215,5,128,252,160,252,9,6,200,0,102,252,147,251,131,253,49,251,228,1,228,252,25,253,141,254,231,3,20,5,173,0,237,255,76,241,29,255,184,0,254,254,79,249,122,0,154,1,224,255,12,255,199,250,184,254,236,255,20,255,153,254,243,255,204,255,181,255,252,254,170,1,160,255,219,255,218,255,117,0,86,252,231,1,60,0,30,1,59,2,112,1,217,253,198,0,154,255,15,0,245,255,183,17,129,255,15,255,114,0,179,255,196,254,46,1,195,0,107,255,183,255,101,1,128,255,233,255,34,0,63,1,159,255,189,0,30,23,236,255,122,255,209,255,7,255,7,0,3,0,116,0,7,0,48,0,47,0,92,0,19,0,14,0,31,0,124,254,183,254,170,248,80,252,190,3,120,2,181,7,182,0,126,255,63,255,5,9,156,252,63,0,4,1,244,255,167,255,168,255,48,255,127,0,88,255,237,0,74,0,129,4,157,3,244,8,176,11,221,255,204,0,254,2,94,252,169,255,85,1,155,255,245,1,35,0,74,255,112,0,91,0,228,255,79,0,193,0,183,255,185,255,52,0,82,0,85,254,109,255,187,255,114,18,212,1,69,255,98,0,217,254,36,1,33,252,43,0,98,0,225,0,213,253,173,253,190,255,75,255,91,0,104,255,253,255,89,0,37,255,100,1,137,254,142,255,246,249,148,253,136,2,154,7,39,0,160,253,82,252,103,0,179,0,170,0,210,246,157,0,108,4,80,252,229,254,64,0,119,254,15,0,166,255,249,2,71,255,132,2,152,254,5,0,164,235,106,0,120,255,216,255,97,255,216,255,136,255,213,255,248,255,61,255,208,0,77,255,217,254,193,255,19,0,32,0,152,255,233,255,132,0,148,2,52,254,237,0,11,2,92,253,134,254,175,255,72,255,158,10,64,0,19,2,71,8,228,249,102,2,165,3,6,0,65,0,206,255,55,0,243,0,229,253,144,4,185,3,229,254,45,0,220,1,166,254,237,8,100,7,103,2,247,253,23,0,225,247,57,0,245,255,208,0,5,4,115,1,28,0,170,0,193,255,89,255,184,0,39,255,76,0,192,254,69,245,30,2,206,247,105,254,246,255,148,252,59,250,206,254,53,2,57,0,207,255,145,255,185,0,6,255,120,0,70,255,214,0,248,253,207,1,24,3,140,246,200,10,129,254,241,252,183,251,71,254,233,253,46,4,78,0,96,0,122,0,63,255,4,2,114,0,100,0,99,254,100,0,233,255,103,255,243,4,142,239,26,253,228,0,147,2,143,1,87,255,156,1,175,255,32,4,4,0,2,255,173,0,109,0,38,255,196,0,64,0,26,0,143,255,196,255,248,255,15,0,121,21,180,255,169,0,218,254,118,254,84,2,123,1,12,0,192,255,53,255,118,255,41,0,7,255,203,255,212,255,237,255,55,0,222,255,99,0,36,0,186,255,8,0,46,0,227,10,74,3,125,7,75,253,88,254,151,0,208,1,118,251,3,4,148,0,253,251,83,255,72,1,23,0,24,3,72,255,139,1,84,253,229,0,117,255,249,255,228,10,148,1,43,0,28,250,178,253,6,0,72,255,136,3,219,1,219,255,20,1,151,254,132,7,68,255,143,255,202,250,80,255,11,0,222,255,186,255,188,255,95,0,79,254,225,0,181,1,61,254,215,1,240,254,127,254,233,10,131,245,32,2,113,3,153,1,235,252,188,2,251,255,112,255,66,0,239,255,248,1,115,254,8,1,74,0,175,255,245,248,188,1,195,253,121,2,121,254,245,242,192,0,228,1,102,4,206,254,153,0,47,1,61,0,3,255,1,255,199,255,235,254,168,255,156,255,32,0,79,0,216,250,167,252,8,12,154,4,67,1,97,1,107,255,36,5,113,254,236,0,127,255,231,0,67,1,184,2,59,0,193,4,201,253,244,254,130,2,128,1,185,254,209,255,210,1,250,5,68,4,104,251,100,2,1,1,113,255,242,254,231,1,194,255,76,1,65,4,193,3,62,253,170,3,78,0,97,0,11,245,192,251,153,252,239,254,87,0,167,254,148,0,113,0,167,0,97,0,31,0,68,0,209,255,203,255,53,0,29,0,165,233,203,255,244,255,241,0,92,0,131,0,139,0,48,0,102,0,230,255,209,255,152,2,188,253,249,255,7,5,227,9,37,4,58,253,24,0,109,5,50,249,254,0,133,251,27,2,106,255,232,255,239,1,52,255,85,255,187,3,202,0,145,255,147,0,78,250,123,240,165,1,96,254,224,253,136,1,139,5,78,255,88,255,203,255,50,0,231,253,249,255,166,254,223,254,204,255,218,255,253,254,141,255,120,255,118,255,167,255,51,255,107,253,179,238,146,255,124,1,47,253,76,255,127,0,165,250,178,255,20,1,63,1,229,0,90,252,11,1,159,254,44,0,65,0,193,1,224,255,159,0,245,255,234,255,197,253,100,0,92,253,76,11,76,245,139,3,255,1,248,0,185,1,194,255,251,253,165,254,21,255,63,1,248,255,116,255,53,1,2,1,150,255,215,0,1,0,76,243,170,1,199,1,91,247,7,4,174,1,234,2,111,1,90,2,187,0,109,255,56,255,97,0,43,2,149,255,7,255,185,255,101,0,59,0,162,255,192,255,223,255,221,0,184,0,233,252,159,2,65,255,28,1,225,250,146,1,227,255,250,0,66,255,9,254,38,0,106,0,74,2,159,18,14,2,147,0,74,255,249,0,146,0,17,0,37,1,185,251,55,4,95,255,141,0,254,255,169,2,237,254,85,255,104,238,61,0,151,255,206,254,190,255,229,0,20,0,154,255,163,255,78,1,67,255,5,0,250,255,161,1,247,9,193,255,172,252,72,6,28,7,158,2,56,6,102,0,203,0,147,0,1,253,109,255,54,1,50,253,175,0,39,2,158,255,54,255,53,1,70,0,81,0,201,255,238,5,222,0,82,1,156,254,93,1,97,0,86,0,239,1,23,255,135,255,120,11,200,0,167,3,131,254,170,9,53,0,238,1,248,0,117,255,211,255,100,0,249,250,75,255,142,254,55,1,31,1,200,11,160,255,128,255,98,8,55,2,129,254,217,253,160,255,144,0,239,1,172,1,224,255,137,0,27,0,240,254,107,255,9,0,195,255,177,0,140,235,91,0,187,252,99,2,233,254,182,255,140,2,14,0,78,255,174,255,167,255,91,1,11,255,135,2,194,255,49,0,41,255,29,0,201,255,229,255,178,0,79,0,237,255,197,255,177,0,104,255,0,0,189,0,246,255,128,0,141,255,33,0,61,0,150,255,56,0,243,255,135,0,116,0,116,233,157,0,43,0,26,0,245,255,102,0,252,255,204,255,208,0,70,255,198,0,99,0,81,0,227,255,153,255,193,0,221,255,172,255,252,255,145,255,125,235,84,0,71,0,171,255,179,255,55,0,234,0,38,0,0,0,221,255,60,0,243,22,98,0,36,0,37,255,239,255,93,254,120,255,47,0,34,0,55,0,235,255,239,255,255,255,72,0,94,0,52,0,253,255,65,253,99,250,250,253,45,2,121,0,100,1,167,254,51,253,74,254,233,254,13,0,70,0,161,255,254,255,182,239,40,0,136,0,17,0,103,255,8,0,107,255,229,255,209,253,12,1,19,255,174,255,36,255,103,252,180,253,106,255,153,13,142,248,135,2,163,2,57,254,86,2,126,254,204,255,249,255,222,0,55,255,90,0,54,0,75,0,229,254,118,0,137,254,136,22,20,0,130,255,115,255,157,255,64,0,116,0,16,0,198,255,0,0,225,255,241,255,250,0,152,255,226,255,112,255,115,0,12,0,117,0,30,254,83,249,76,254,122,0,10,255,249,255,15,1,169,7,154,0,149,0,170,255,147,0,2,1,19,2,224,6,146,3,84,251,248,248,44,3,147,253,125,0,95,255,81,5,50,0,117,253,229,250,104,1,239,252,205,0,100,255,38,1,21,0,100,242,238,255,177,255,246,254,2,3,51,1,29,0,3,253,6,255,183,0,55,0,131,0,172,5,4,1,224,0,221,0,165,254,104,1,160,254,116,247,104,253,9,254,57,1,150,1,5,255,196,12,210,0,210,255,129,0,236,254,87,1,113,255,104,0,201,255,205,1,17,0,192,253,225,254,223,254,33,0,60,246,171,255,84,254,143,251,150,3,11,255,22,254,252,254,242,254,123,255,177,253,199,0,218,254,224,10,102,0,19,0,147,255,23,253,91,0,244,253,212,255,28,0,252,0,1,254,176,255,110,255,15,1,7,2,40,255,24,247,101,254,115,14,144,254,230,253,171,1,98,255,114,0,206,255,179,253,172,254,76,255,191,2,70,255,231,1,119,253,156,2,108,252,76,254,156,241,8,252,109,3,191,255,103,255,194,255,108,255,239,255,150,255,142,0,183,255,255,255,188,255,55,2,110,253,47,3,222,8,205,253,249,253,30,255,33,255,230,254,72,2,240,0,14,250,113,248,145,4,112,3,127,0,4,251,129,255,143,1,63,0,25,0,239,250,83,8,80,2,116,6,49,10,69,0,187,253,77,255,179,3,85,2,150,0,35,0,0,0,1,255,24,255,40,253,239,0,91,0,130,0,22,255,231,0,56,0,123,247,238,6,108,247,97,6,215,251,106,253,9,3,81,255,128,255,11,1,249,255,51,0,27,0,123,255,95,0,12,254,188,0,89,255,94,0,80,255,227,255,191,255,95,255,115,255,74,253,56,252,82,2,243,254,90,254,40,254,37,253,186,4,208,252,94,8,215,250,46,249,107,255,41,252,30,5,185,252,250,2,28,1,99,0,225,255,111,251,172,255,161,251,201,255,48,253,80,252,165,251,241,254,248,251,40,4,187,0,11,252,171,11,26,0,47,255,4,2,248,255,107,0,232,255,188,0,22,1,203,255,112,2,204,1,237,254,167,248,47,248,83,3,52,249,105,254,107,6,160,254,239,255,240,253,230,253,81,255,179,0,160,1,215,254,54,0,132,0,21,254,180,255,34,0,72,254,175,0,17,8,42,248,92,255,38,0,109,254,134,3,127,255,215,0,9,6,98,254,97,251,236,253,66,2,248,0,204,254,189,0,205,253,167,254,75,252,233,254,157,6,65,252,101,0,15,3,9,0,105,6,214,5,167,0,218,254,230,253,183,3,115,0,78,2,105,0,177,252,21,252,208,1,144,254,12,251,129,2,254,0,243,0,232,1,76,10,71,251,240,254,181,1,189,1,13,3,49,254,97,254,26,2,213,252,76,2,59,4,206,0,221,253,171,0,183,253,24,253,87,1,164,253,139,1,180,255,142,3,245,253,148,255,63,254,113,2,187,254,201,251,17,1,63,250,184,251,119,255,203,253,29,8,145,253,214,0,170,254,239,254,1,3,113,4,145,252,37,253,56,0,182,251,211,0,54,3,67,2,185,252,164,0,168,253,176,255,61,0,60,1,132,2,165,5,123,3,252,248,250,248,94,255,161,249,20,254,142,253,81,2,32,2,66,0,63,0,167,252,7,251,150,1,129,6,131,3,45,254,87,0,139,255,43,254,126,0,30,0,93,252,166,5,66,255,132,1,184,249,196,254,105,247,129,255,228,1,205,255,56,0,244,253,244,5,153,255,207,4,28,253,205,2,163,252,55,3,103,253,2,249,155,1,78,253,47,1,177,249,63,0,24,255,19,0,66,4,160,255,137,0,80,0,253,251,69,2,195,255,160,2,133,0,188,1,1,253,254,2,214,255,154,243,242,254,233,255,130,255,169,251,67,0,169,250,4,0,59,1,203,255,166,255,91,255,48,0,135,249,139,255,136,1,100,1,24,3,158,253,150,253,37,255,190,1,102,0,118,1,207,0,2,4,176,9,51,254,242,252,137,4,185,250,8,4,230,1,204,254,34,1,240,254,131,3,120,7,36,0,144,253,30,1,84,254,145,253,103,253,12,0,147,253,63,248,222,255,212,1,62,1,45,254,127,0,52,252,217,255,105,253,3,9,230,255,150,1,44,254,111,253,132,250,170,254,52,9,117,254,114,250,37,251,209,1,90,0,103,253,232,254,222,254,235,255,40,249,24,1,15,1,139,1,240,0,110,254,55,0,53,4,148,0,203,254,26,7,227,1,243,250,43,0,5,1,54,2,125,255,179,3,209,252,152,252,3,252,23,252,117,254,7,1,213,253,78,0,111,247,152,254,180,255,251,251,19,254,48,254,59,5,203,255,238,2,97,253,187,250,133,0,186,255,114,0,245,1,254,2,208,252,191,2,32,252,134,255,248,253,213,250,21,246,147,254,221,255,213,253,136,252,235,5,65,255,42,5,97,6,94,253,195,1,34,251,14,1,156,252,191,2,118,254,106,0,245,252,242,2,138,2,42,4,95,254,231,250,149,0,91,255,0,32,69,255,41,254,55,255,185,0,47,254,208,3,1,1,83,0,238,253,54,1,164,2,85,1,48,0,9,1,161,254,50,1,24,1,46,1,48,0,240,1,173,254,168,1,126,235,3,255,92,2,195,254,223,254,22,1,61,2,189,253,79,0,146,12,194,253,135,254,20,1,15,11,225,254,2,255,76,1,31,255,42,0,162,0,55,254,65,252,115,250,171,2,197,255,223,255,34,13,137,1,94,2,249,0,151,252,94,252,200,4,189,5,37,0,200,249,129,6,186,253,193,6,28,1,106,0,111,237,136,255,37,254,99,3,68,254,53,255,175,1,245,255,242,253,188,254,220,2,210,251,96,255,157,253,16,7,215,254,232,253,62,255,202,252,200,4,172,8,230,246,72,0,236,3,237,252,107,255,45,2,109,11,29,0,41,3,93,9,137,251,136,2,136,3,200,253,61,253,185,252,238,254,214,250,153,4,45,254,30,254,195,235,234,0,223,0,98,1,130,1,225,2,249,4,234,0,159,254,31,0,248,255,120,254,85,0,22,255,86,5,169,5,120,0,73,253,70,3,146,253,160,255,126,1,115,250,100,2,83,255,129,243,106,255,218,1,118,254,207,253,109,251,237,9,241,254,209,9,158,2,29,1,124,2,60,254,54,255,39,5,122,247,89,252,182,253,243,0,211,252,215,255,203,255,239,251,212,0,58,0,160,242,111,0,12,1,196,3,97,243,12,254,99,3,65,255,207,0,31,2,127,1,27,250,104,245,64,245,201,0,172,1,209,2,242,1,19,0,21,253,67,0,87,0,244,1,176,4,196,8,122,251,210,1,248,251,103,255,173,4,177,10,188,254,210,7,174,254,89,0,84,254,78,0,63,2,74,1,221,7,175,0,49,1,55,2,229,253,17,0,128,1,229,1,92,3,2,13,173,0,74,2,137,2,132,1,195,3,28,7,206,245,251,0,106,244,103,5,103,255,110,255,52,2,50,253,230,3,253,250,202,253,149,253,138,1,203,1,47,251,6,10,155,254,215,245,98,0,95,252,145,254,11,254,96,0,193,4,97,249,188,254,137,1,5,1,209,6,185,251,17,253,156,3,20,4,175,254,37,251,137,1,150,9,37,250,11,255,134,3,157,3,178,247,167,0,70,3,126,2,248,8,218,254,50,1,53,253,234,10,242,5,173,254,21,0,62,1,161,255,54,5,75,0,83,255,165,255,36,248,104,252,223,252,78,1,221,242,164,254,38,2,113,252,251,254,207,251,185,0,87,254,175,1,3,2,173,254,25,7,203,249,241,0,36,2,175,254,41,254,52,242,114,251,120,3,141,0,235,254,73,5,54,1,114,253,198,0,252,253,135,11,203,8,234,253,189,2,237,0,20,0,171,253,211,254,3,0,154,1,56,254,187,253,26,251,28,4,41,5,165,0,36,12,221,1,196,0,156,10,85,0,5,0,222,255,209,2,206,253,4,0,84,0,231,252,232,2,243,0,134,0,127,254,127,255,134,255,128,255,179,254,29,254,164,253,13,1,65,24,3,0,3,2,193,255,134,253,217,253,229,252,96,249,94,247,136,8,92,1,30,0,157,1,227,9,214,0,214,0,70,255,184,255,216,253,190,3,191,6,153,249,106,2,195,255,80,254,109,1,15,253,15,0,242,255,33,0,208,3,84,252,157,254,246,12,165,2,110,248,21,0,113,3,186,254,173,255,229,242,203,5,69,251,94,253,166,0,139,0,236,254,158,0,32,253,14,4,19,252,105,4,195,4,91,4,120,254,46,2,96,0,68,255,58,1,24,2,89,254,66,243,139,1,126,255,75,4,48,1,75,255,85,3,96,255,8,251,172,1,77,255,122,2,96,2,83,255,130,10,113,247,105,5,250,253,96,254,167,12,178,12,57,1,233,255,200,0,131,2,129,253,239,255,48,255,27,0,74,255,6,1,53,255,97,253,157,0,221,239,127,1,108,254,81,1,51,0,175,1,92,0,138,0,74,254,29,0,81,1,232,1,4,255,144,2,253,1,245,7,133,253,206,251,165,251,169,247,252,252,126,254,42,255,114,253,71,254,125,6,30,2,129,254,72,249,22,0,153,255,62,250,248,250,9,17,26,1,28,251,222,2,166,252,212,253,38,1,243,0,37,1,133,0,80,3,65,0,41,253,137,252,222,250,187,1,160,255,90,254,172,16,160,2,142,0,96,2,70,254,75,3,109,1,158,252,99,255,12,3,107,0,136,252,41,8,233,6,73,0,227,2,241,255,62,249,45,251,152,3,79,249,163,0,40,2,199,5,76,253,13,253,150,5,63,255,236,254,248,254,78,253,4,3,123,5,216,255,167,2,252,254,130,2,22,242,194,3,5,8,68,5,36,0,98,244,155,0,47,1,53,3,80,252,77,255,57,252,120,2,43,253,155,1,65,254,49,254,182,2,175,254,110,255,59,0,255,255,96,254,12,0,12,2,15,254,182,237,23,253,113,2,243,3,20,0,50,254,9,254,220,7,37,254,229,255,85,0,90,251,22,2,202,8,87,0,31,10,171,4,129,6,167,1,211,252,197,253,140,254,41,10,35,248,171,252,34,253,109,254,25,3,219,253,219,4,56,1,210,2,11,252,102,250,19,253,197,253,238,1,168,255,127,255,51,5,38,3,53,251,70,1,116,251,183,9,197,255,42,9,71,2,7,2,112,1,25,3,154,4,149,2,140,0,202,4,122,1,83,254,66,251,158,5,193,254,179,255,41,250,14,14,105,1,21,0,39,0,138,7,198,0,26,4,19,2,18,1,32,0,13,254,163,254,251,255,123,255,4,243,133,254,26,253,6,255,174,249,0,250,36,8,89,5,253,2,124,255,188,254,150,1,106,247,58,1,246,1,105,250,247,2,39,253,64,1,184,247,204,5,164,9,45,243,4,0,16,1,254,255,236,1,91,0,221,252,48,0,179,2,119,1,87,0,4,254,43,253,136,253,12,1,113,11,22,5,245,255,140,253,79,247,211,2,21,2,141,3,166,3,170,2,94,1,229,5,61,253,138,251,106,0,130,247,86,1,59,252,200,1,113,253,113,4,215,253,159,1,94,254,185,245,135,255,237,0,3,0,157,251,237,249,123,250,251,242,205,2,115,0,250,251,17,252,205,252,130,0,173,252,25,1,213,255,39,254,189,251,70,1,101,3,135,254,22,1,108,255,162,1,200,247,90,254,111,2,15,249,121,2,9,4,17,248,59,251,30,16,196,255,240,255,89,31,243,0,172,254,169,253,11,254,223,254,37,255,152,255,26,255,208,1,191,0,18,0,89,1,191,255,188,255,31,254,113,2,202,252,85,240,252,253,229,2,222,2,196,254,18,2,122,0,177,3,115,1,214,254,170,4,6,255,89,255,136,1,161,255,105,255,255,255,26,254,189,0,90,0,116,255,30,0,133,17,69,2,54,0,113,7,129,252,16,248,82,255,169,9,80,253,152,255,197,254,136,254,62,3,40,1,220,253,242,2,195,0,123,252,244,249,117,248,24,3,254,1,38,1,153,0,107,2,246,251,34,244,110,4,142,0,227,255,218,252,138,255,227,255,246,246,97,255,2,3,173,244,23,0,235,251,13,4,216,5,80,4,241,253,135,0,231,254,202,254,197,255,202,0,166,254,156,253,206,0,27,0,56,254,246,2,67,0,219,13,99,3,227,0,253,255,61,2,160,5,165,1,170,0,211,5,77,253,213,255,248,255,16,3,51,1,45,2,106,2,173,246,54,2,116,254,182,0,109,3,150,245,93,255,41,2,101,255,179,2,68,255,208,249,195,251,9,4,204,254,76,5,198,253,47,253,24,255,183,243,104,0,255,1,60,252,223,10,83,253,88,255,205,255,18,6,232,248,127,9,71,1,72,254,150,4,247,254,220,255,120,0,115,254,70,4,26,251,51,252,62,2,61,4,117,255,17,253,239,253,16,255,25,0,113,4,45,254,113,242,82,1,218,252,20,248,94,0,158,255,176,254,231,253,165,4,144,252,233,241,88,255,197,255,100,0,53,1,73,4,39,1,6,1,106,0,248,255,210,0,219,226,139,1,8,255,205,1,234,1,186,254,8,1,105,0,13,0,96,255,96,2,69,254,205,250,67,3,194,250,179,13,251,2,198,3,101,0,23,4,43,254,81,250,200,251,28,0,99,0,212,255,14,1,16,253,130,0,2,0,57,0,102,1,103,254,2,0,110,253,212,252,125,252,155,0,141,0,53,8,32,14,40,0,91,248,252,251,215,239,212,0,44,6,66,2,251,3,0,254,167,0,110,1,188,253,192,1,216,0,79,0,107,255,32,229,145,2,147,253,69,0,219,0,180,253,169,2,229,0,248,0,210,254,146,255,222,2,12,0,253,0,58,254,134,252,244,241,10,3,216,245,0,255,17,2,76,1,187,255,39,1,57,254,214,3,247,254,186,255,180,254,145,254,214,5,74,2,98,255,226,251,225,9,199,254,107,253,234,250,74,246,220,1,5,0,126,0,69,2,105,1,82,6,138,2,241,7,202,0,76,0,247,254,95,255,75,14,224,252,45,4,89,255,0,249,133,1,188,253,85,2,244,254,109,2,245,251,198,2,86,3,212,7,239,252,154,10,123,6,17,3,32,3,176,255,9,0,171,254,248,251,21,3,139,2,44,4,159,253,149,2,235,2,96,252,25,252,167,250,107,251,96,254,60,6,16,245,74,1,34,2,5,251,22,253,120,254,239,253,134,254,243,13,21,245,37,253,73,255,182,254,201,249,115,1,98,3,67,1,252,253,167,255,229,8,57,6,192,3,66,249,75,247,215,2,97,254,189,0,244,1,111,255,79,255,38,2,211,1,240,0,107,4,218,1,93,254,44,251,162,2,152,253,249,253,135,9,67,251,118,253,99,3,206,3,116,252,205,4,0,254,164,3,17,254,39,246,159,252,46,254,8,0,86,254,144,3,179,255,20,255,105,254,177,1,128,0,69,14,86,3,243,0,2,3,191,0,224,0,188,255,59,254,129,254,23,1,67,253,77,253,26,1,63,254,124,4,241,252,241,0,99,236,131,2,177,31,167,254,13,0,90,0,199,255,219,1,64,0,244,254,93,255,156,255,161,255,6,2,65,2,29,2,7,8,102,1,99,255,104,1,24,1,184,252,119,251,244,1,95,0,46,1,106,253,110,4,59,3,228,12,183,2,7,3,226,252,165,245,181,244,157,251,43,2,155,251,156,0,72,1,159,2,239,2,165,254,52,252,120,254,64,251,165,10,224,235,110,254,241,255,150,0,31,0,74,255,234,254,245,0,81,0,253,255,210,255,54,1,184,255,118,255,231,5,30,249,208,248,148,254,123,0,241,10,240,255,225,253,224,250,50,2,250,254,148,0,9,2,57,253,61,0,161,252,145,0,73,1,249,2,76,0,101,255,101,0,134,236,192,0,13,1,148,254,82,255,128,2,251,254,117,2,54,14,141,1,35,249,103,251,86,1,132,1,65,4,56,3,115,0,150,0,125,0,38,3,247,4,58,255,32,3,81,255,127,252,119,253,187,252,178,2,13,253,136,5,213,246,155,4,243,252,58,3,31,6,108,255,100,255,244,251,220,249,224,4,69,255,208,1,252,254,19,253,210,251,85,0,46,254,144,247,14,245,233,0,75,255,191,1,30,254,113,0,36,2,141,11,192,249,61,5,209,253,35,3,37,8,217,252,57,253,111,251,56,254,145,2,180,255,109,255,140,7,226,251,57,252,180,251,207,255,243,244,132,5,161,3,183,4,58,0,110,255,77,0,54,254,26,2,141,253,244,255,214,0,163,246,180,2,4,5,110,1,6,5,205,7,168,252,11,1,74,7,212,4,25,0,254,0,93,251,128,13,27,1,72,2,44,9,92,2,150,251,7,0,244,1,232,0,205,255,120,0,73,253,94,252,61,1,67,0,190,250,12,254,56,1,220,251,222,246,188,248,45,250,3,6,85,249,10,3,115,253,215,255,145,1,55,1,243,255,107,8,13,252,139,4,200,2,42,8,56,5,42,253,62,2,176,4,26,251,225,249,211,2,171,2,147,252,115,253,113,4,198,249,103,4,81,10,209,1,3,1,209,247,184,2,107,254,40,0,253,254,216,252,82,252,139,1,76,255,161,251,58,252,26,255,234,253,142,255,88,0,107,253,245,2,75,0,226,254,137,255,156,3,147,244,179,9,126,6,31,7,78,2,211,16,42,3,191,1,165,0,243,0,72,255,94,255,180,1,130,255,62,255,109,1,89,2,158,254,65,248,45,255,105,253,20,1,155,0,72,253,18,246,194,252,70,9,21,255,183,253,43,254,34,254,21,0,99,3,159,249,157,7,75,252,182,254,222,253,72,1,32,255,212,4,10,1,163,251,36,0,195,255,221,0,153,0,93,242,73,250,19,255,68,18,15,255,17,1,12,1,91,1,119,254,235,254,168,0,170,1,155,0,191,255,163,253,199,253,120,250,233,250,224,4,83,2,108,255,0,2,38,14,35,1,68,254,245,253,104,2,105,0,101,0,77,5,4,3,175,254,238,1,58,2,15,0,150,0,112,254,60,2,78,2,138,6,246,239,172,3,167,0,185,254,176,254,184,2,79,2,106,1,23,1,137,17,211,250,96,2,38,1,215,255,37,2,214,3,225,255,72,255,111,1,77,0,46,254,142,1,120,248,161,253,239,0,55,0,15,0,7,4,26,254,228,10,103,8,249,253,83,251,136,251,18,1,159,2,84,6,31,8,237,249,63,252,31,2,245,255,26,0,141,253,9,3,187,253,220,251,103,251,216,252,39,3,47,11,95,2,144,0,195,0,238,254,18,0,232,233,157,254,254,251,56,0,116,0,81,254,19,254,5,2,30,1,97,1,97,1,199,0,117,253,161,252,236,254,212,253,206,253,157,252,113,255,157,254,189,254,242,255,202,255,22,235,213,255,200,249,8,0,225,253,24,0,94,0,37,253,223,253,193,2,85,255,248,1,202,251,217,242,69,5,196,1,108,255,159,4,142,249,136,250,10,255,248,251,137,255,203,254,202,253,230,3,88,243,68,254,110,253,163,253,70,255,235,1,183,1,66,255,176,2,227,255,59,252,2,10,144,255,183,254,231,255,223,245,99,1,203,255,180,2,12,0,175,253,138,7,220,252,174,255,130,1,136,253,159,3,238,3,27,255,133,251,75,255,205,251,11,255,162,241,136,3,214,254,215,8,50,0,51,2,81,1,229,251,173,0,54,1,44,242,153,253,8,254,237,2,192,0,166,255,143,255,38,253,54,248,34,3,211,255,186,8,167,0,33,1,186,6,206,253,170,2,197,1,35,6,171,0,131,246,71,254,26,255,136,251,217,3,190,249,102,1,83,253,233,255,245,253,239,253,122,246,188,2,144,253,37,0,61,250,218,250,220,12,190,2,138,1,226,252,3,10,33,4,177,254,102,2,14,1,63,12,255,250,215,247,6,255,116,255,45,0,251,253,42,254,107,250,84,255,77,10,11,1,55,0,243,251,82,255,144,3,159,252,238,252,106,254,25,2,11,245,126,253,193,249,120,3,236,251,81,255,56,1,28,0,123,251,16,255,75,255,42,1,9,2,218,14,169,255,93,0,48,0,56,5,209,251,178,248,83,1,174,251,80,252,244,251,105,1,121,241,109,255,113,2,70,1,134,255,151,1,39,255,140,1,17,1,254,255,197,254,250,254,120,2,212,26,228,0,245,254,207,0,227,255,238,254,192,0,63,0,159,254,76,2,38,2,253,255,156,0,67,8,44,6,194,246,50,1,121,2,74,5,9,9,152,254,167,254,14,1,13,254,48,252,155,241,231,250,139,3,151,5,9,6,202,250,18,0,135,4,229,0,132,255,157,0,214,1,151,255,188,2,6,249,153,248,27,3,228,251,234,254,233,2,145,255,211,255,182,2,87,2,115,242,40,2,186,255,34,255,45,0,128,3,5,255,1,0,250,0,255,252,45,1,129,251,33,5,218,16,198,2,168,2,87,255,105,253,40,0,143,1,147,4,69,2,7,3,168,3,24,254,154,244,155,0,87,255,232,249,162,252,39,254,15,3,184,255,1,249,55,2,195,247,100,255,226,4,50,250,181,12,61,0,206,255,138,254,235,254,174,3,111,0,95,2,196,254,197,0,20,253,103,3,100,2,14,255,216,254,53,0,63,255,209,4,11,0,62,252,249,1,116,238,21,0,242,2,106,255,195,1,183,0,113,3,116,253,97,255,240,24,170,0,15,1,11,4,145,1,48,0,49,254,16,255,161,255,143,253,101,2,165,255,142,251,148,4,30,2,53,250,178,245,140,250,107,251,100,2,0,2,75,5,209,3,150,254,234,255,239,255,124,0,150,243,236,253,96,1,125,245,98,2,57,2,228,2,189,249,251,255,20,254,192,2,76,254,160,255,173,253,41,250,170,10,239,243,92,255,53,2,20,5,35,254,199,253,45,4,38,1,23,255,123,255,196,2,150,0,132,1,196,247,238,251,189,249,227,8,70,249,49,2,140,0,251,1,125,252,231,254,162,0,239,250,224,5,98,255,193,0,38,253,80,252,76,246,103,2,226,255,32,0,158,254,129,254,86,0,73,1,150,242,130,254,188,249,213,254,208,0,0,32,243,255,90,1,204,255,5,0,131,0,218,254,89,255,191,255,165,254,74,254,209,253,57,0,170,255,33,255,32,255,5,255,117,2,198,255,129,20,127,0,48,254,132,2,210,0,102,255,32,254,165,0,211,0,13,0,62,1,152,0,83,255,75,21,235,0,170,0,156,255,250,255,52,254,7,255,134,1,54,0,225,3,155,249,224,254,46,252,59,255,234,0,195,244,198,253,105,255,174,255,4,3,199,0,127,254,149,248,89,1,231,255,15,2,35,254,154,244,129,1,224,10,78,0,244,253,9,253,27,3,177,1,255,1,88,3,237,254,255,1,136,0,68,254,151,0,233,0,208,0,179,253,137,254,26,1,70,11,30,0,67,245,94,252,55,4,86,0,19,247,212,3,27,255,167,250,93,0,176,255,10,9,86,255,200,4,141,1,149,1,207,1,246,3,135,254,166,255,243,254,174,255,136,254,251,252,172,2,162,255,179,244,189,254,124,253,175,252,156,248,60,247,161,1,117,8,92,255,221,0,198,1,223,246,142,0,99,0,162,1,230,1,207,255,97,0,138,0,173,8,3,247,100,255,190,253,123,15,196,0,140,0,138,254,180,0,195,1,98,1,72,252,178,3,33,254,150,252,97,255,145,0,34,1,240,0,16,255,23,255,94,254,226,0,62,11,197,253,69,246,229,2,98,250,45,2,197,0,142,254,144,237,123,1,32,0,53,3,39,0,223,253,115,255,29,250,192,0,130,251,137,3,185,251,92,236,87,255,21,2,233,255,115,1,162,0,82,251,209,1,143,254,242,255,163,252,112,253,67,253,216,254,31,0,194,1,125,254,244,11,72,253,85,2,14,0,5,252,75,245,48,255,94,251,174,254,200,2,192,255,168,254,41,0,71,1,9,0,64,2,163,254,8,245,124,9,177,1,202,253,140,3,148,255,111,255,13,252,201,0,30,244,185,254,210,0,144,254,230,0,202,254,112,254,12,0,246,251,198,6,224,3,50,7,254,3,114,8,76,2,110,1,154,0,250,243,181,253,72,4,215,0,208,251,240,252,216,1,191,251,94,0,231,1,18,0,72,0,34,0,241,255,138,254,161,253,60,1,62,3,110,255,25,17,211,254,134,1,70,3,121,0,146,255,113,255,163,255,172,11,98,11,160,254,159,254,24,253,141,255,99,0,239,1,169,254,53,1,237,4,249,253,101,0,154,245,212,255,189,243,21,254,118,4,189,254,206,255,8,3,86,0,187,0,224,1,15,1,89,255,1,0,245,254,157,255,223,3,188,9,104,255,119,9,31,255,34,0,64,2,50,250,20,255,137,254,160,0,80,255,111,255,221,9,125,255,194,0,61,1,191,4,17,6,39,1,128,250,130,0,231,8,95,251,111,10,119,255,188,254,233,255,26,0,245,252,81,254,252,255,232,1,70,255,174,0,137,255,246,11,107,255,88,255,191,0,169,0,100,4,45,1,191,5,103,254,25,252,90,255,126,8,131,250,224,3,77,255,210,245,185,255,177,243,92,0,48,252,19,12,190,254,54,1,138,254,245,252,87,2,201,255,169,1,71,253,63,0,27,0,218,255,86,0,170,0,245,255,152,253,159,255,13,2,78,0,14,0,172,2,76,234,204,254,68,254,10,1,116,254,127,249,86,0,46,253,193,251,103,252,243,253,3,0,73,254,192,249,219,255,246,7,144,245,69,255,105,1,0,224,169,1,109,1,54,0,87,1,65,253,253,0,28,1,199,255,185,254,102,255,136,1,99,0,75,255,213,0,139,1,148,246,209,254,182,0,82,0,7,9,45,0,9,7,47,255,36,252,42,0,106,250,38,0,47,253,118,0,93,255,255,4,136,8,238,255,35,11,18,1,149,254,41,1,150,0,36,255,69,14,63,12,131,254,79,1,254,0,122,1,204,255,52,0,72,1,129,254,195,255,222,252,103,254,207,255,49,0,0,224,106,1,208,255,82,254,202,255,255,0,243,0,243,253,14,0,152,0,10,0,120,254,211,254,174,253,229,253,176,4,114,2,93,244,233,0,32,250,152,2,40,253,243,250,21,254,138,1,37,5,42,1,169,0,214,0,83,254,197,251,42,0,133,1,143,18,254,1,43,1,226,253,200,1,172,252,30,0,208,0,193,255,125,255,72,0,87,254,73,0,213,0,225,254,235,254,43,0,128,0,152,21,165,0,196,254,121,255,192,253,185,253,217,0,238,250,47,0,134,0,103,0,154,248,148,0,78,13,112,3,196,3,71,253,162,255,166,249,223,0,232,4,254,253,31,8,239,253,125,7,84,250,152,253,163,253,129,1,61,252,139,1,105,0,102,255,165,249,42,255,40,0,201,3,60,253,44,250,200,252,153,9,19,1,148,1,108,3,243,252,251,251,34,0,72,0,229,0,119,255,8,1,125,254,49,1,199,255,92,11,113,255,7,255,87,246,202,0,69,250,148,254,46,8,247,253,186,255,4,1,132,0,209,1,71,0,214,3,220,255,0,7,50,1,91,11,201,255,254,0,165,1,231,0,140,0,191,6,218,1,249,2,81,12,238,255,156,254,158,1,170,8,52,2,9,255,2,254,67,0,86,9,227,9,240,0,117,0,25,254,202,254,5,1,222,0,226,254,163,252,124,247,224,1,181,255,161,18,105,254,248,0,227,0,32,255,46,1,133,3,80,251,40,253,1,4,222,2,176,254,115,0,66,249,77,255,131,0,43,0,155,254,108,1,87,253,27,1,67,255,203,2,23,245,76,253,87,5,148,3,28,0,12,254,22,12,225,253,141,253,59,253,6,254,186,251,34,0,96,246,178,1,1,1,101,1,10,0,122,254,134,12,155,13,137,0,147,0,180,0,231,0,252,254,61,253,206,252,220,1,240,253,144,2,56,3,248,255,1,12,106,1,38,244,57,255,47,0,182,2,4,255,51,3,109,255,33,254,224,255,18,2,115,255,165,255,251,0,102,255,120,1,165,253,1,9,219,244,146,253,60,1,88,253,146,1,205,252,67,1,215,1,209,255,236,6,227,5,228,251,83,253,18,0,51,246,94,254,121,1,225,255,100,254,105,0,118,252,245,254,10,245,67,255,159,255,198,0,222,252,174,255,110,253,92,244,27,3,65,254,134,2,13,4,230,1,79,253,162,245,55,0,50,242,28,2,188,255,246,1,166,255,21,1,169,255,15,254,24,0,10,255,144,1,136,1,92,1,76,0,167,254,25,255,185,255,155,0,249,255,30,255,153,25,115,1,5,1,222,254,88,0,212,255,55,1,214,1,251,255,182,0,151,255,56,0,188,254,11,1,241,0,71,1,198,3,218,0,169,237,56,252,27,0,160,254,197,254,202,0,52,255,179,1,104,1,229,253,137,254,241,253,123,251,242,3,15,255,75,16,220,254,66,0,39,9,54,1,86,253,83,2,224,11,27,2,138,255,195,253,128,255,184,3,84,255,221,253,227,254,255,255,89,1,187,233,89,1,103,255,77,0,93,1,31,255,148,254,113,253,242,254,52,253,199,252,27,0,55,0,131,8,102,255,237,254,103,1,11,254,32,252,103,253,2,6,38,255,121,251,128,8,179,252,54,244,105,0,53,254,182,243,67,0,59,255,219,254,27,2,115,0,182,255,119,0,98,255,167,255,169,5,66,244,104,0,139,2,118,3,202,254,14,255,195,4,13,7,176,0,187,8,67,2,38,1,122,2,65,5,255,255,58,254,243,2,250,251,224,6,156,246,106,254,126,3,102,2,182,255,113,0,211,250,51,7,120,254,89,243,136,9,202,255,222,0,69,5,73,253,15,252,178,1,44,254,3,254,232,254,206,1,228,0,61,2,213,0,55,0,69,1,45,2,100,0,47,253,94,253,88,2,27,3,31,6,151,1,201,12,198,255,206,250,93,1,75,255,161,1,9,254,143,3,94,1,87,253,106,238,129,255,230,255,74,1,106,2,241,0,109,255,28,1,30,255,129,255,124,245,228,1,110,255,238,255,96,254,243,2,85,0,209,243,108,254,0,0,34,254,18,239,154,5,28,255,197,5,207,250,230,0,174,2,210,253,230,1,68,255,168,1,58,254,200,253,115,255,186,254,124,255,217,255,184,9,9,0,119,2,1,2,204,1,95,254,96,10,121,2,132,250,175,255,229,254,225,254,224,1,254,9,237,255,98,255,117,245,149,1,20,1,129,253,105,255,17,2,241,0,83,252,228,252,43,255,101,4,121,254,211,9,78,0,79,255,117,10,217,0,187,3,81,253,99,3,27,254,135,255,255,3,220,249,177,253,139,0,30,3,238,4,45,254,210,2,83,10,19,255,232,251,130,1,80,254,180,0,236,252,78,255,234,0,147,1,11,1,56,1,101,10,73,2,41,245,82,253,168,255,240,255,37,251,67,254,253,254,47,1,42,1,29,1,21,1,51,9,163,0,161,246,96,254,115,0,229,8,61,253,194,0,27,1,159,4,23,0,119,0,97,0,0,32,216,255,67,0,155,255,151,0,169,0,21,0,109,255,96,255,55,0,49,255,38,2,220,255,12,254,224,255,225,0,206,0,72,0,179,0,208,1,106,254,52,0,184,2,238,255,37,237,11,6,252,253,29,247,87,3,174,1,245,253,83,0,159,249,150,248,29,1,202,0,123,253,89,255,102,0,132,255,126,1,24,0,236,0,62,3,68,1,172,255,235,1,161,255,102,255,255,2,25,0,133,18,194,253,240,245,215,254,6,255,166,254,205], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1543365);
/* memory initializer */ allocate([244,192,255,161,251,239,3,141,252,201,1,184,254,170,252,43,252,201,255,10,27,57,2,205,254,5,1,156,255,192,252,129,0,160,1,102,255,169,2,120,255,128,4,112,255,230,255,38,247,192,254,115,255,127,252,32,2,50,255,77,3,178,253,88,0,211,0,31,249,194,253,115,253,28,245,252,0,246,254,100,239,39,1,97,0,192,247,209,0,112,255,143,2,167,255,143,254,79,2,205,0,113,4,30,0,165,244,88,0,92,0,16,255,222,243,240,255,114,254,192,253,48,253,165,1,171,1,89,254,61,255,238,255,199,9,123,255,106,252,104,0,0,254,23,254,63,10,198,254,215,0,153,255,10,252,249,2,126,1,80,250,183,6,44,252,248,0,55,0,132,2,103,248,42,0,94,255,221,255,172,252,201,7,67,255,152,2,107,255,60,12,206,255,110,13,38,2,22,255,202,253,178,1,64,0,123,1,87,255,221,254,50,253,160,253,31,0,49,255,139,2,249,245,234,252,138,3,6,2,204,6,117,1,134,4,114,0,4,248,29,1,144,251,139,254,164,3,119,247,24,254,148,0,3,0,212,2,111,2,200,253,153,254,68,245,239,2,182,251,166,252,140,251,3,255,183,246,110,254,200,254,114,254,209,255,198,245,48,3,200,253,250,4,98,255,118,0,107,0,181,0,138,1,198,10,80,0,15,244,20,0,233,254,110,0,226,1,242,3,94,255,199,251,200,255,173,2,159,8,246,255,82,0,184,1,81,2,43,0,242,3,171,252,144,253,32,1,27,244,86,254,9,0,132,0,104,0,157,0,210,1,138,255,116,0,226,0,42,255,37,255,43,1,205,23,122,0,7,0,174,0,188,1,200,0,214,255,252,255,199,254,99,0,218,0,36,1,97,255,103,254,11,2,179,250,254,239,160,255,200,3,8,0,84,255,68,254,240,251,243,2,36,254,199,3,175,0,156,255,153,6,211,252,103,12,113,1,36,7,248,0,95,255,37,26,119,2,24,2,131,255,18,1,45,254,3,1,85,254,130,0,245,253,105,1,72,2,27,0,60,0,199,255,226,255,0,224,148,0,192,255,217,0,204,254,163,0,140,255,89,0,108,0,191,0,127,255,107,255,128,0,60,0,63,2,253,0,127,254,135,244,120,3,134,250,225,253,161,253,79,10,156,0,251,0,54,27,109,255,130,254,124,254,39,0,220,1,4,1,232,251,63,2,145,1,11,255,71,254,121,0,133,1,102,253,95,0,103,11,92,247,3,253,169,0,95,255,184,0,192,254,197,254,15,254,136,0,42,254,223,1,227,253,200,2,150,11,7,2,35,10,179,255,65,4,18,0,71,253,152,253,241,0,202,255,132,1,205,1,112,1,144,0,107,255,181,0,19,30,11,0,3,0,144,254,65,0,48,1,102,1,227,255,255,0,94,255,87,255,42,254,240,255,198,0,92,0,89,8,233,0,17,1,255,0,238,15,233,254,62,255,238,254,101,0,45,0,31,255,52,253,38,246,68,255,10,0,178,253,23,253,126,3,184,7,208,255,254,8,252,255,173,237,189,255,211,250,6,254,93,2,215,254,61,1,241,254,80,255,170,6,29,2,1,0,31,0,188,253,103,0,148,0,134,255,115,255,175,252,76,0,234,243,189,255,215,10,218,255,170,253,198,254,25,3,40,0,68,1,194,5,194,7,225,5,64,3,8,254,227,2,47,251,177,4,183,2,173,250,158,2,37,3,184,2,119,255,143,236,206,254,137,0,139,252,199,1,253,3,88,2,81,249,24,2,235,0,107,255,31,0,251,255,93,241,107,254,138,1,140,0,102,0,216,249,190,0,152,1,151,2,229,247,21,253,210,1,119,2,39,3,75,7,113,253,102,0,85,1,179,1,39,2,244,1,170,1,118,253,168,255,230,255,112,10,1,249,34,0,170,255,147,11,254,242,231,252,205,254,21,1,184,253,16,255,115,255,2,1,196,2,14,255,13,254,40,3,152,255,243,247,250,253,172,2,121,3,150,1,3,1,211,0,206,1,172,1,219,245,133,251,193,6,171,2,131,247,89,255,136,1,184,1,87,2,209,252,144,253,144,254,110,244,84,255,77,3,167,1,106,1,199,2,83,8,197,240,84,0,147,0,58,3,113,254,131,253,108,4,108,0,32,254,230,0,9,1,89,254,48,0,11,0,239,0,169,253,231,254,10,0,29,2,115,254,142,0,30,239,148,4,255,254,155,255,36,1,191,254,111,254,60,0,203,254,212,1,11,1,99,2,182,1,130,253,146,8,90,1,141,5,88,251,219,243,86,255,248,242,207,255,187,255,181,255,184,0,22,12,79,2,82,0,139,254,140,0,234,255,80,3,124,0,77,2,157,0,252,255,4,1,79,255,147,0,73,0,228,254,109,24,111,0,46,1,182,255,100,1,125,1,221,253,240,255,237,254,12,254,93,0,88,1,166,254,235,244,108,1,213,255,176,253,205,6,66,253,57,247,80,3,53,255,168,0,246,2,175,252,106,246,50,2,80,4,87,255,207,1,114,254,57,245,213,254,121,252,135,2,194,255,132,255,45,1,81,1,55,255,207,1,170,255,117,255,115,247,136,246,82,252,136,254,5,248,176,255,1,249,212,249,1,2,29,0,165,251,186,253,190,4,126,253,99,1,240,0,29,1,223,6,185,4,94,3,171,6,25,13,33,255,245,0,253,253,96,252,26,3,66,255,230,254,73,4,224,255,139,6,89,3,38,253,241,255,102,0,100,1,203,254,27,15,24,0,93,0,131,3,160,253,15,254,41,255,60,247,223,2,62,255,102,0,205,255,109,248,78,3,74,0,140,255,7,0,189,7,0,2,233,0,62,2,52,246,83,0,174,7,5,255,160,255,20,2,97,0,129,3,160,251,134,1,136,243,116,253,253,7,193,0,144,252,114,254,108,255,36,2,231,254,237,255,37,252,211,1,186,254,217,10,195,0,24,6,10,4,196,252,102,0,5,250,12,5,130,255,27,2,9,255,36,0,55,0,73,246,215,254,150,254,226,1,63,247,3,252,1,250,12,255,38,0,168,242,141,0,80,13,35,0,189,255,95,0,77,1,85,254,21,255,128,255,48,1,220,253,81,1,163,254,182,254,23,0,62,254,121,6,71,1,241,243,183,2,239,254,190,251,238,4,145,255,156,252,236,5,13,1,119,0,192,0,14,0,200,0,141,0,117,254,233,27,48,0,78,1,143,0,117,255,154,0,154,255,200,254,254,255,27,1,238,0,226,255,114,2,48,5,242,0,96,254,186,1,22,244,108,5,156,255,191,4,49,3,130,241,172,254,111,12,200,0,132,255,167,1,95,254,80,254,232,0,216,252,85,0,111,255,39,0,196,0,59,255,196,255,102,255,43,255,192,254,131,244,225,3,228,11,4,254,61,0,171,252,75,0,40,0,105,3,3,253,147,254,147,253,146,245,188,0,57,0,109,254,26,255,119,255,40,0,53,2,138,248,160,251,5,252,165,253,121,248,150,0,239,243,23,0,96,254,57,255,63,243,15,0,128,0,243,253,237,253,91,0,217,255,66,2,124,254,59,1,40,0,72,9,226,6,2,0,61,250,18,249,111,0,166,3,53,254,9,3,186,253,114,0,38,255,174,255,61,255,165,0,123,8,120,2,189,255,239,0,89,1,255,254,104,0,222,255,145,252,232,1,90,254,148,247,201,252,148,7,187,2,95,11,23,255,131,255,38,255,145,255,177,254,109,242,195,255,185,255,67,254,249,0,182,254,102,0,120,1,140,255,107,10,59,254,19,0,223,239,90,0,5,254,236,0,162,1,43,0,79,0,61,0,40,1,181,0,190,0,152,1,216,0,198,0,32,0,175,255,245,0,99,255,179,21,94,255,62,1,179,0,83,1,49,254,64,254,2,255,242,253,64,255,85,254,63,2,76,2,232,10,123,10,171,252,202,253,19,0,230,255,106,0,36,255,6,2,222,2,23,255,68,0,164,253,25,255,0,1,69,255,197,255,107,254,206,0,75,1,231,255,27,237,189,254,146,0,29,2,211,2,147,3,112,255,194,1,102,0,141,254,27,0,88,0,176,255,20,1,239,0,101,0,157,0,187,255,242,255,234,0,0,224,238,255,146,255,204,255,248,255,48,0,79,0,213,255,153,0,187,0,211,0,138,255,145,255,238,0,11,0,42,248,168,2,222,1,73,253,6,12,226,255,124,3,233,255,232,5,62,255,167,1,240,255,194,254,127,3,150,1,122,2,47,0,51,243,51,255,4,253,41,1,155,254,195,255,68,255,245,249,156,252,82,255,86,1,5,1,134,7,88,0,221,255,78,243,236,255,96,12,144,254,10,3,120,1,167,0,86,2,186,1,134,0,231,1,164,0,224,255,245,0,180,1,19,8,83,2,190,253,49,0,93,255,121,2,138,0,233,254,157,255,118,0,117,4,160,243,68,2,166,255,136,243,39,2,105,253,143,245,201,255,147,0,27,5,9,0,15,0,176,1,51,1,15,2,234,3,43,254,180,246,170,254,219,254,183,255,253,254,154,1,53,1,76,0,192,254,95,255,26,1,28,243,249,255,160,0,220,2,228,1,191,255,147,0,107,11,17,9,184,252,141,7,12,1,172,2,148,4,135,254,147,254,200,253,229,254,236,1,230,253,153,1,62,255,17,0,215,254,204,255,133,255,242,254,161,0,162,255,92,0,143,17,116,254,28,2,229,0,226,255,148,255,29,0,1,0,198,0,236,1,196,253,118,254,174,246,227,10,117,3,105,251,127,255,143,251,220,0,148,0,5,1,191,255,12,255,1,0,58,0,195,0,207,255,222,254,162,255,235,255,105,0,71,0,241,25,56,255,105,254,16,254,181,255,233,0,222,0,37,2,107,1,188,0,227,2,155,252,122,0,157,254,254,12,67,1,194,246,115,0,121,243,223,10,223,7,148,0,156,3,103,255,123,255,81,255,225,254,144,1,73,0,75,255,82,255,72,0,45,0,219,0,164,255,245,255,59,0,225,234,150,254,68,255,136,255,239,0,249,0,133,0,27,255,158,0,180,0,193,253,174,246,158,254,248,0,20,2,178,253,103,2,171,255,187,255,138,1,236,11,147,252,192,254,228,1,218,0,49,254,54,255,183,252,193,6,28,1,229,4,145,8,14,2,116,246,161,254,7,5,139,254,131,1,184,1,53,255,163,0,103,255,206,0,199,255,160,255,56,10,172,255,40,2,33,0,193,2,37,253,181,252,107,247,166,247,198,253,22,0,248,254,95,8,213,2,124,255,120,254,215,1,11,255,51,0,227,2,223,251,25,4,8,253,141,10,200,1,20,0,228,1,83,2,176,12,121,250,162,252,76,1,95,254,67,1,81,254,34,8,78,0,172,2,87,255,84,2,28,255,37,255,172,0,160,0,76,255,28,255,135,243,248,253,156,255,65,254,139,253,126,247,253,254,10,255,4,249,40,247,223,0,115,0,182,255,230,0,45,246,212,0,77,255,200,1,209,0,181,246,10,255,167,254,154,255,209,253,3,1,242,254,86,254,77,1,154,254,50,11,179,253,42,250,94,254,96,255,118,255,40,8,171,2,223,250,37,4,168,255,148,3,108,255,231,246,211,254,241,254,7,255,6,11,243,253,107,254,80,2,190,254,208,250,240,255,135,0,186,253,92,253,9,254,142,247,185,254,19,255,105,1,166,0,88,2,152,4,247,3,97,0,251,255,209,1,17,9,64,238,202,0,162,254,57,1,149,0,32,2,92,254,40,2,183,0,95,1,129,249,176,2,238,0,75,2,139,3,73,249,243,4,235,246,112,1,236,0,40,1,208,245,240,0,229,3,240,1,105,0,75,0,77,255,235,0,125,0,216,255,57,0,234,255,100,254,48,254,18,254,175,255,64,2,123,242,243,251,24,253,78,5,168,252,228,254,232,253,131,1,154,254,184,0,171,255,102,8,138,251,132,255,119,0,218,4,136,2,199,2,113,8,177,253,184,248,96,253,62,0,87,7,243,255,55,0,29,1,89,255,142,0,126,255,66,1,8,0,221,255,26,255,120,2,69,253,18,16,12,254,67,255,208,255,186,10,47,0,165,1,80,251,114,9,204,1,206,254,75,1,164,0,178,250,34,3,197,1,202,1,10,14,249,11,232,255,122,255,75,254,132,252,146,255,241,0,144,254,80,1,161,2,109,255,130,0,154,0,89,0,81,0,171,254,239,27,175,0,118,0,29,255,230,254,6,1,20,1,138,255,138,255,11,255,7,0,144,0,169,255,120,255,110,255,28,254,70,0,221,0,36,255,243,255,42,226,93,0,218,255,193,254,34,254,26,0,228,255,25,1,76,255,182,0,70,255,90,0,192,0,50,0,153,244,153,0,165,245,33,1,47,0,241,252,0,3,128,1,39,0,194,0,202,246,218,4,113,249,80,0,12,5,28,0,170,2,247,10,86,1,210,1,43,1,132,254,120,1,114,17,12,0,41,2,153,0,65,254,221,2,99,0,8,0,114,255,94,2,196,246,168,0,167,0,194,255,148,1,184,243,96,1,115,0,106,241,104,1,54,255,50,254,60,255,208,1,100,254,192,0,149,254,99,254,107,254,254,0,101,1,15,245,30,4,190,249,130,2,2,255,82,254,45,247,159,255,16,0,201,254,245,2,192,255,156,1,83,1,29,255,40,255,227,255,219,0,67,0,63,0,26,0,24,255,118,255,211,254,241,0,204,255,26,232,223,0,133,254,99,255,35,255,55,255,163,255,2,234,226,254,62,255,133,0,46,0,151,0,188,1,40,254,103,0,141,255,253,254,203,255,161,2,208,6,186,246,103,1,237,9,101,2,119,254,211,4,221,0,139,255,182,252,142,4,105,0,114,255,146,5,3,0,89,254,36,0,142,1,74,245,211,2,28,253,217,3,242,1,175,1,224,250,64,3,148,249,146,0,187,255,146,255,164,1,126,255,79,1,13,1,207,244,189,255,168,255,50,0,175,10,14,4,205,3,115,1,142,2,87,255,144,255,67,2,193,254,130,9,8,253,198,2,241,0,159,248,39,0,241,248,226,255,103,5,200,251,193,1,127,2,82,246,8,253,47,2,42,1,56,0,91,254,50,3,70,254,22,6,182,249,88,8,244,255,245,255,80,2,73,0,77,0,84,255,77,0,92,0,143,255,25,1,69,2,184,253,160,238,251,1,61,255,183,0,4,254,56,1,44,253,19,4,238,255,246,255,248,252,234,253,249,0,150,243,136,3,210,4,30,254,126,1,240,251,64,254,189,253,227,0,174,255,252,21,91,255,255,0,109,0,115,255,7,0,228,255,63,0,93,0,45,255,0,0,162,0,69,2,103,255,212,22,190,255,122,0,154,255,166,255,51,255,75,255,243,0,56,1,111,0,77,254,151,255,169,254,16,1,115,255,6,0,158,255,240,255,183,255,230,255,131,255,53,226,183,255,190,255,108,0,81,255,186,0,67,255,154,255,16,255,219,255,158,254,252,254,136,255,30,0,87,0,0,10,85,12,113,1,106,253,82,1,9,254,190,255,131,250,178,0,76,4,85,253,198,245,155,9,245,250,8,255,117,255,85,253,159,252,165,5,165,0,112,1,251,1,183,253,215,243,97,0,229,0,53,1,100,255,30,255,43,254,70,2,126,243,176,254,102,0,20,0,96,0,64,252,41,1,29,255,80,2,232,242,238,10,131,253,123,255,191,0,105,254,170,0,192,253,53,255,232,254,40,3,85,3,10,254,143,255,88,249,255,251,155,1,242,10,233,0,200,253,104,1,152,253,77,249,47,0,135,1,187,247,54,254,221,254,107,255,174,255,26,0,227,255,168,255,100,255,225,30,32,0,181,255,102,255,178,255,212,255,155,0,255,255,174,254,133,252,170,0,181,255,155,0,226,0,64,255,184,254,17,255,194,253,165,255,95,0,168,253,175,16,25,0,222,3,49,255,68,18,59,0,188,254,116,3,107,1,65,0,167,1,248,252,118,252,177,255,252,255,195,5,37,2,4,255,0,14,215,13,103,254,26,1,22,1,125,0,133,254,125,0,76,255,133,255,4,255,196,254,63,255,91,1,53,0,217,7,195,0,152,0,152,255,233,0,181,255,222,253,52,2,79,255,171,12,159,252,100,252,6,2,76,253,131,254,163,248,146,255,68,255,116,4,5,248,74,254,71,249,251,3,142,6,13,0,17,1,17,253,154,3,221,254,241,255,75,0,232,0,144,255,60,0,142,10,88,0,175,0,137,255,43,0,219,253,186,251,169,248,145,1,51,6,7,5,215,255,41,0,140,255,233,255,57,1,168,0,147,0,155,255,199,255,141,255,178,228,54,0,242,255,16,255,92,255,127,0,25,0,65,253,151,254,1,3,19,6,120,246,200,245,64,255,86,0,1,3,227,255,47,253,42,2,105,253,71,1,147,2,225,255,177,255,91,0,109,1,182,255,244,4,115,0,224,1,238,11,34,249,168,6,247,2,111,253,240,254,183,254,31,0,111,255,234,253,241,4,73,0,179,1,202,255,224,1,157,252,164,10,69,9,122,3,198,254,144,255,240,245,170,253,217,1,121,0,204,10,123,6,105,0,67,2,96,254,169,255,158,0,44,1,191,1,231,254,35,232,35,0,217,0,185,0,56,0,155,254,151,0,108,0,207,255,230,254,28,254,36,255,178,255,115,255,0,1,185,251,20,7,39,252,91,4,43,2,188,247,13,9,139,251,232,252,158,252,137,255,187,0,103,2,62,255,73,0,213,255,12,1,181,1,250,0,204,255,221,1,7,255,37,254,195,245,78,2,85,244,165,253,116,253,203,3,84,253,81,1,116,255,176,254,38,9,134,1,52,255,39,1,85,0,212,255,65,1,242,2,100,10,61,0,14,3,118,6,180,255,167,10,54,6,181,251,98,1,49,0,224,10,187,1,6,253,60,3,204,254,19,254,13,253,142,254,176,254,49,255,132,1,118,2,129,255,163,7,137,7,246,4,6,8,13,2,132,1,50,2,174,3,235,252,59,254,158,0,227,3,157,255,210,8,195,254,19,254,129,1,166,255,177,255,199,0,93,251,7,2,2,255,179,0,61,2,243,10,37,9,151,1,95,0,3,2,76,1,1,0,250,255,175,254,142,0,196,254,162,1,30,2,209,12,10,0,92,2,226,253,197,249,43,0,79,0,10,0,75,0,134,255,100,0,201,255,212,0,33,255,159,254,211,253,234,1,6,19,151,241,10,14,111,255,64,255,209,255,4,255,132,254,76,255,35,255,144,2,78,0,68,255,120,0,135,0,3,255,75,254,48,255,105,255,8,254,217,0,125,241,106,255,16,2,121,0,68,250,127,1,55,3,201,255,113,251,248,255,58,255,253,253,216,254,232,255,84,0,129,0,40,254,7,0,207,19,142,255,56,255,240,255,241,254,59,0,82,254,114,255,197,254,90,0,17,1,200,255,114,1,14,13,97,255,235,0,166,3,69,6,37,250,207,0,142,249,113,4,140,1,54,247,20,1,192,254,195,254,233,255,20,1,249,253,163,0,54,2,110,1,250,255,214,8,13,248,106,253,28,243,123,255,29,241,150,254,164,254,113,0,146,0,177,255,214,254,238,0,221,0,99,0,194,0,70,1,69,1,144,255,32,224,197,255,241,255,8,0,215,255,251,254,236,255,250,255,188,255,116,255,215,255,167,0,131,255,129,0,81,1,100,9,25,1,176,254,37,254,37,8,170,245,60,2,228,250,120,1,114,0,6,254,38,4,193,253,239,253,19,13,44,255,8,2,18,1,93,255,14,244,163,255,53,255,92,252,49,255,220,255,47,1,139,255,22,1,31,1,204,0,205,0,28,255,14,255,227,0,3,0,99,2,66,255,54,254,212,255,47,255,122,0,122,254,47,238,117,255,98,5,183,254,184,1,221,3,10,249,164,254,217,4,199,3,35,254,248,246,42,2,54,252,177,251,217,1,253,252,206,255,150,0,71,1,138,1,245,254,120,253,88,253,72,9,17,246,20,1,196,4,40,2,10,0,119,5,38,250,223,252,9,0,47,9,201,255,155,0,71,1,88,0,96,3,172,1,179,0,94,243,6,0,32,2,121,253,206,254,132,0,73,1,123,4,128,7,156,5,197,247,158,251,85,1,228,7,80,254,159,255,117,0,25,3,100,0,75,253,174,0,55,14,198,253,142,3,45,245,231,0,108,255,64,252,195,251,57,0,188,0,232,2,59,253,71,254,21,2,217,254,7,5,123,11,171,11,117,3,99,2,188,2,108,1,51,255,169,252,151,253,48,0,94,255,12,255,194,254,208,0,4,3,132,255,55,246,198,1,74,1,36,255,79,1,150,254,125,252,197,252,140,8,216,255,154,249,100,1,96,255,129,255,70,11,187,255,215,255,209,0,55,7,20,255,192,10,232,255,131,1,98,1,145,255,14,2,19,255,135,247,39,5,163,8,144,0,164,254,78,254,193,254,93,5,78,0,138,3,189,2,27,2,122,255,158,1,240,1,187,254,220,255,116,0,124,0,102,16,221,255,73,254,48,255,237,253,156,255,173,5,81,255,211,2,116,252,51,254,87,0,127,0,165,255,131,255,116,255,76,31,70,255,23,0,163,255,107,0,176,0,218,0,35,0,193,0,174,0,229,255,252,255,77,0,153,255,57,255,116,0,215,255,176,255,186,0,203,228,68,255,125,0,202,255,43,0,9,0,207,255,64,255,69,0,120,255,232,255,139,255,60,247,241,8,145,0,226,0,119,251,98,248,113,3,104,255,75,6,247,3,82,255,235,254,98,255,113,1,49,0,23,255,221,0,19,1,69,0,108,0,136,0,132,255,1,0,42,254,120,1,149,0,84,226,55,0,53,0,213,0,9,255,80,0,39,255,245,255,189,0,125,0,239,255,115,255,165,0,182,244,14,0,201,0,106,0,242,0,2,255,206,254,171,243,203,1,246,255,24,0,241,254,109,3,181,1,74,254,18,0,130,255,247,255,177,21,63,0,22,0,55,0,172,0,21,0,177,254,127,0,160,0,208,0,121,0,13,0,197,7,164,2,218,254,160,8,178,255,122,2,18,250,243,251,29,5,124,0,217,255,190,254,116,250,108,254,121,1,221,255,242,255,178,0,110,0,46,224,26,0,158,255,103,255,13,255,145,0,24,1,248,255,29,0,199,255,85,0,203,254,25,1,26,1,209,255,229,255,11,11,77,252,141,0,88,3,79,246,150,1,130,253,150,254,249,251,230,0,171,254,137,255,239,255,1,0,190,0,41,0,241,255,247,19,59,0,74,0,123,0,230,254,231,255,212,254,4,0,52,254,40,255,39,1,39,255,26,0,227,0,62,0,129,1,236,2,107,11,154,7,135,1,116,249,87,2,148,0,56,254,160,255,42,4,222,1,117,0,255,0,87,255,99,253,109,248,112,253,116,10,165,2,28,248,222,250,169,1,243,253,167,255,246,253,147,10,153,0,5,0,49,255,244,0,235,251,75,1,221,250,174,255,193,1,116,246,70,1,28,254,72,247,76,9,177,253,25,252,8,246,211,249,93,1,72,254,217,0,42,1,39,253,250,255,116,254,182,255,110,0,186,255,41,242,124,254,205,255,84,2,126,0,39,1,27,8,133,255,75,253,208,251,13,249,92,254,127,0,176,1,87,243,25,255,10,255,105,0,75,254,189,255,137,255,131,244,255,254,47,0,55,252,123,1,106,2,163,255,7,0,202,0,87,254,218,255,140,0,202,1,15,14,242,0,232,255,213,252,144,253,237,255,12,2,94,9,212,254,111,0,120,1,223,7,175,1,125,0,231,0,219,254,181,246,134,253,50,7,255,255,210,250,158,253,168,255,128,0,80,0,75,0,30,0,172,0,21,255,34,0,206,0,177,255,72,1,128,0,229,254,50,229,155,255,4,1,68,0,40,33,21,1,63,0,173,0,224,0,226,255,98,255,64,0,133,0,123,255,234,0,205,0,191,255,152,1,249,0,222,253,226,255,255,255,82,254,80,0,102,0,62,254,96,255,254,233,145,0,106,254,161,254,37,0,26,1,232,0,126,252,174,1,229,12,105,251,209,253,239,1,125,10,235,255,41,255,169,255,216,2,201,255,235,0,174,1,6,255,7,254,250,1,128,255,184,255,216,12,52,6,35,1,7,0,217,255,80,252,222,1,183,6,168,0,195,251,225,0,74,1,200,5,73,255,171,253,13,232,156,2,125,254,160,2,83,255,201,255,113,0,40,0,143,255,212,255,85,1,172,254,174,253,23,252,221,6,127,0,197,255,25,2,214,248,121,5,88,3,127,251,22,255,208,4,206,253,220,1,110,0,140,8,146,0,119,0,71,8,152,252,194,1,85,2,141,254,186,250,28,252,136,255,17,254,61,3,111,0,127,252,187,234,98,253,134,1,138,255,4,0,109,0,4,3,239,1,196,0,154,1,131,255,44,3,170,1,132,3,180,1,131,4,215,253,57,251,19,1,10,1,133,252,63,0,13,251,11,2,220,253,115,246,239,0,139,4,72,0,188,255,216,249,164,8,172,254,219,5,238,1,97,253,183,255,231,254,86,2,109,7,140,249,179,252,10,1,27,3,223,253,194,253,19,0,51,254,115,1,32,1,137,240,165,1,43,1,135,255,255,245,191,255,118,0,181,0,29,255,207,2,164,255,226,246,150,243,63,246,58,255,58,0,255,4,203,254,152,0,53,253,210,1,196,254,10,0,98,0,32,6,9,252,238,255,77,254,214,255,46,10,179,7,137,255,193,2,254,0,187,1,36,0,20,3,111,4,210,4,233,8,174,3,115,0,69,2,143,255,62,255,74,253,178,1,226,255,19,11,89,254,180,1,10,2,150,1,49,5,167,4,188,245,165,1,215,245,134,2,54,255,125,2,98,2,184,253,101,1,206,249,13,254,50,251,134,0,173,255,16,251,130,9,198,255,148,244,129,2,227,254,172,0,34,254,110,254,72,2,100,251,119,255,18,255,105,255,89,253,149,253,17,254,20,4,1,5,100,251,68,254,120,1,177,7,75,253,229,254,106,2,128,0,194,245,166,255,141,255,160,2,202,6,53,254,7,2,100,252,22,10,169,3,213,253,160,2,131,0,31,0,7,3,51,1,230,254,241,253,237,250,252,253,10,0,239,0,27,240,118,0,10,0,103,253,241,255,28,254,216,1,6,1,23,1,165,2,13,253,8,5,2,251,147,1,154,2,118,254,50,251,253,244,35,255,109,0,91,2,242,2,183,3,232,1,109,255,149,255,86,254,83,7,8,8,127,255,239,0,207,253,81,0,188,254,243,0,93,1,197,0,213,252,110,255,95,252,169,4,153,5,248,252,137,12,178,1,250,255,161,9,25,255,199,255,56,1,131,3,116,254,86,255,219,253,90,1,135,0,17,0,172,253,145,1,13,1,243,1,192,255,191,254,170,254,124,255,200,254,213,22,20,1,152,255,247,255,206,255,90,253,34,254,155,251,59,250,10,8,156,0,26,2,195,1,12,10,239,1,101,0,74,0,15,253,98,0,173,2,120,9,49,248,26,4,232,254,250,251,29,0,78,255,12,255,122,255,130,0,119,255,153,255,11,255,113,8,66,254,8,252,208,1,61,2,39,254,190,1,18,241,174,3,19,251,178,254,56,2,240,253,211,254,159,1,28,253,149,2,211,252,81,3,211,5,6,3,250,252,101,6,47,252,10,255,135,2,196,253,116,255,126,244,114,253,118,253,201,254,83,1,91,255,245,2,35,3,66,252,192,2,171,0,124,1,251,2,159,0,161,10,193,249,238,3,138,255,171,253,169,11,139,10,69,0,139,1,11,2,145,2,182,1,190,0,72,0,164,0,244,254,111,255,250,1,218,253,222,0,199,241,5,0,83,255,60,0,62,255,165,2,174,2,212,2,149,255,114,3,173,254,14,0,202,255,43,2,227,1,243,5,119,0,114,255,118,254,109,249,40,252,18,0,148,255,66,255,141,0,28,2,25,1,42,251,109,247,171,254,185,254,10,252,34,252,86,18,46,0,6,252,104,1,97,253,173,255,218,0,89,3,144,0,68,255,207,1,133,254,197,253,159,252,191,250,65,254,238,255,192,255,81,20,132,0,90,0,98,255,124,255,125,1,171,255,149,255,153,255,202,3,213,253,76,251,10,7,206,4,253,0,28,2,140,254,213,246,126,254,67,3,63,253,75,254,173,3,27,3,74,255,144,254,64,4,168,0,0,1,210,0,101,253,34,1,247,6,132,253,165,0,149,254,126,2,57,242,80,7,205,7,223,5,67,255,229,245,153,254,128,1,237,1,128,254,110,253,34,249,225,3,206,254,148,0,198,0,163,0,174,1,199,254,107,255,175,254,96,1,158,254,228,1,102,1,248,254,83,238,208,253,201,255,154,0,118,1,195,254,86,254,166,5,95,255,227,254,146,255,209,0,43,1,25,9,99,0,126,5,94,5,225,3,154,4,99,254,126,253,153,255,94,14,219,248,14,253,178,250,163,254,136,2,20,254,243,2,188,0,114,0,68,254,94,252,32,255,63,1,212,0,199,4,120,253,81,2,13,5,247,250,24,0,56,253,31,10,18,254,223,5,247,255,22,2,155,3,210,5,217,3,235,1,16,1,220,3,92,1,9,254,58,254,125,3,153,1,90,254,93,251,25,12,90,2,110,254,206,1,62,6,37,255,214,3,63,1,125,0,46,2,156,255,251,254,108,0,197,255,149,242,76,0,215,251,106,255,34,249,51,248,129,7,215,4,170,1,251,1,173,0,168,252,195,252,230,253,247,0,77,251,232,1,186,251,197,1,176,251,253,3,137,8,217,244,171,1,177,0,246,252,74,255,129,2,98,253,91,0,57,2,50,0,166,255,59,2,108,0,138,254,174,0,205,7,196,3,132,2,84,254,180,248,156,2,171,0,64,1,164,2,121,0,38,255,109,7,167,252,47,253,62,255,127,246,222,255,121,249,96,1,124,253,39,1,59,2,253,0,224,254,6,249,32,0,74,0,183,255,122,252,94,248,154,251,157,242,168,0,194,254,23,0,13,253,71,254,201,0,172,255,243,1,111,1,103,255,86,254,204,2,138,2,55,254,80,0,59,253,91,3,206,247,45,253,59,255,250,251,3,255,27,1,93,251,125,252,123,5,139,255,231,255,193,29,193,255,157,254,229,254,208,253,171,255,154,254,211,255,63,0,179,0,63,255,130,0,218,254,92,253,243,253,117,252,82,254,141,253,109,235,229,253,1,1,82,2,83,255,122,3,203,0,223,255,120,255,221,252,223,1,200,255,134,253,208,1,105,252,110,255,50,1,5,0,198,0,166,255,118,255,175,254,218,18,202,254,3,1,115,6,81,253,116,249,168,1,169,10,58,252,195,255,130,1,60,0,1,3,184,255,140,249,49,0,106,0,247,1,74,250,224,251,124,3,103,1,209,0,127,255,4,1,126,255,223,247,30,3,232,1,78,3,188,252,146,254,250,6,67,247,28,254,72,0,136,245,196,252,167,252,152,3,48,2,162,3,59,255,56,0,152,252,222,255,157,254,161,3,35,0,63,254,2,2,70,0,3,251,208,0,97,1,70,14,0,255,134,0,129,252,72,255,119,1,146,1,40,6,235,5,156,255,74,254,89,253,128,1,119,4,232,255,100,0,254,244,42,2,37,255,105,0,140,2,38,245,148,255,44,0,50,1,189,1,42,254,129,251,110,251,25,5,27,253,199,4,69,254,186,252,118,1,72,244,72,0,178,253,181,253,102,14,76,0,19,254,246,0,68,5,65,251,217,1,12,255,208,254,145,7,188,255,142,253,22,1,136,1,143,4,149,248,203,254,218,1,226,0,91,254,161,255,29,254,105,0,108,255,237,2,82,254,15,244,235,252,255,248,191,248,98,255,23,254,92,253,52,255,38,3,94,252,136,243,52,255,150,255,212,252,135,4,136,2,119,0,163,255,51,255,117,255,24,1,150,225,124,254,124,255,244,255,180,254,32,0,82,255,100,0,153,0,249,255,33,1,227,255,40,252,183,254,176,253,8,10,192,2,32,2,66,0,9,2,107,253,160,249,156,252,202,254,57,1,46,254,165,254,110,255,197,0,10,1,253,2,16,255,55,255,247,254,151,251,221,255,205,253,156,254,172,0,94,3,247,14,11,6,174,249,91,250,114,241,132,1,36,2,55,254,143,0,218,255,146,1,255,0,72,3,65,253,102,255,8,3,242,251,99,233,205,4,118,255,242,3,55,3,166,253,37,252,19,255,47,0,227,255,172,1,210,0,87,0,245,255,236,255,251,254,180,243,195,4,230,247,124,255,254,254,195,2,134,253,110,3,26,254,221,3,236,254,119,255,249,254,80,2,224,4,218,1,219,254,43,252,77,8,115,253,85,250,191,252,14,250,131,1,243,254,93,1,186,2,39,1,102,3,149,2,252,5,202,0,142,2,106,1,15,251,132,15,117,253,224,0,213,0,40,253,173,255,63,2,9,254,2,253,47,2,111,253,86,0,173,3,218,5,184,255,249,8,133,5,136,254,185,2,30,253,128,1,217,252,158,254,117,4,118,1,162,4,171,253,222,0,118,2,51,253,139,249,106,0,159,250,95,252,214,3,115,242,191,254,55,255,95,251,109,255,243,255,12,1,103,0,151,11,221,247,96,254,190,2,121,1,154,251,92,0,195,3,18,254,162,255,76,254,101,7,121,5,216,255,72,250,184,249,188,7,44,0,254,0,164,2,17,2,133,252,161,255,9,0,84,255,127,255,158,0,109,254,133,251,2,4,102,254,86,0,33,10,220,251,147,253,224,1,254,0,244,252,179,2,4,252,79,0,64,255,40,247,61,251,20,253,90,2,243,0,82,1,38,2,68,254,126,255,79,0,24,0,68,13,124,0,196,253,237,2,208,3,33,0,141,252,144,254,159,253,182,2,199,253,208,253,192,0,100,3,132,2,173,0,86,0,50,239,121,2,219,30,152,254,222,1,237,1,206,254,14,0,244,0,96,0,71,0,87,255,80,1,90,1,74,0,204,255,243,6,60,3,4,255,227,2,19,252,13,253,31,0,210,255,200,0,69,2,245,255,34,3,80,4,180,12,227,251,211,2,21,254,68,246,230,246,11,255,52,1,3,252,200,254,51,2,171,255,223,3,240,255,224,0,171,255,67,252,214,8,23,238,61,250,102,0,54,1,42,1,149,252,250,255,244,254,8,0,228,254,68,1,41,254,32,255,133,0,222,5,78,249,185,251,152,255,41,3,24,10,239,254,10,252,216,254,130,0,220,2,253,254,177,254,23,253,149,253,52,253,247,0,247,1,94,3,235,254,119,255,32,255,223,236,124,0,21,1,42,1,216,255,169,0,166,2,45,2,27,17,165,2,32,248,6,254,148,255,209,255,49,0,141,255,252,254,212,254,206,0,172,4,239,255,202,0,109,1,216,252,39,254,96,255,159,253,14,2,156,251,93,6,148,244,201,2,25,254,147,255,28,2,1,254,221,0,118,254,116,250,255,3,52,254,168,1,170,255,149,252,235,249,168,255,12,255,195,249,57,244,99,1,166,0,74,1,178,254,187,254,249,1,48,14,32,249,90,6,85,254,61,2,173,4,195,254,202,253,105,253,204,1,82,1,70,254,171,253,29,6,170,252,234,253,37,255,128,255,129,247,227,2,40,4,2,8,195,255,163,254,105,1,137,254,87,4,134,255,135,255,92,255,243,245,170,3,222,6,241,255,116,3,97,3,138,253,195,253,226,3,88,4,230,255,9,0,226,255,53,15,218,255,106,5,93,2,56,2,88,253,117,0,37,0,60,2,245,0,203,255,250,251,15,255,141,1,107,1,160,249,201,253,230,255,70,253,195,247,247,251,147,250,101,5,94,254,146,1,234,253,9,0,119,4,223,3,181,2,253,9,12,251,249,4,64,255,201,4,108,3,216,1,67,3,253,1,60,254,17,250,226,1,79,4,142,253,213,254,44,6,4,250,87,2,197,8,247,1,146,255,169,248,210,3,122,251,126,255,103,253,192,1,33,251,92,2,240,253,91,253,57,253,78,0,205,253,163,254,203,255,5,1,184,3,174,254,234,253,43,0,254,255,5,246,184,7,89,9,179,6,228,3,252,21,12,4,171,0,228,255,57,255,173,255,130,255,221,255,8,255,119,254,36,0,209,0,77,0,255,248,244,0,148,255,126,255,215,255,190,253,213,246,81,253,114,6,131,0,118,255,151,1,28,255,188,250,47,255,183,252,52,5,226,253,220,0,63,255,75,3,153,255,85,3,5,1,115,253,217,0,149,255,143,255,202,255,201,239,233,250,225,254,225,15,136,254,185,255,43,0,55,250,153,254,31,254,78,0,17,2,177,2,62,255,178,0,60,0,27,252,237,249,151,6,89,1,169,0,10,1,78,11,83,0,12,254,87,254,116,254,11,255,6,0,5,2,112,0,129,0,213,2,135,255,108,254,234,0,47,0,195,255,134,255,198,2,69,239,217,3,56,0,151,255,211,255,19,4,208,2,73,0,65,1,100,17,178,249,91,0,148,253,213,254,250,1,254,2,142,252,138,2,118,255,123,0,160,253,210,0,210,249,230,253,194,255,246,0,208,1,180,254,232,249,223,8,23,6,57,255,192,252,147,251,227,252,85,1,68,7,92,6,147,251,161,253,125,2,108,254,181,1,132,251,30,2,38,254,142,252,158,253,196,250,97,255,244,5,144,5,169,0,250,255,52,0,191,1,119,234,176,253,244,0,218,254,44,0,164,0,205,255,147,0,202,0,208,255,139,0,113,0,113,254,239,255,83,255,57,255,1,0,17,0,90,255,15,0,254,254,249,255,238,0,140,233,118,254,172,252,8,255,210,255,192,0,224,255,247,251,163,254,151,0,227,1,130,0,164,249,193,242,247,5,182,2,207,254,228,2,155,254,21,254,70,255,143,249,142,250,151,252,213,0,140,2,73,248,63,1,149,251,153,255,208,255,161,2,155,0,141,253,91,4,213,1,158,251,109,7,72,255,19,255,216,254,185,244,136,255,211,0,67,3,57,0,198,252,248,4,1,255,87,252,242,0,243,253,68,3,178,254,137,1,144,253,111,0,165,254,78,255,143,242,219,0,160,254,39,7,216,254,75,2,155,254,181,251,5,0,57,1,34,241,118,254,46,3,138,255,23,255,233,255,131,255,235,255,122,250,45,3,109,254,178,9,186,1,72,255,166,3,84,1,216,1,118,1,49,4,229,254,212,246,221,1,125,254,55,253,47,4,125,252,252,0,237,250,10,254,137,254,102,254,7,249,174,2,163,253,115,255,153,252,15,249,220,10,53,0,19,255,19,255,141,10,176,3,44,0,83,2,3,0,239,4,234,249,37,247,26,252,221,0,99,1,193,254,29,253,120,251,174,253,161,11,191,0,215,255,228,254,83,0,228,1,225,1,183,255,243,255,138,0,55,245,115,252,190,253,117,255,224,251,189,0,123,253,109,255,195,255,88,255,112,1,130,0,134,1,91,16,101,0,79,0,211,255,195,1,162,250,107,248,234,253,211,254,45,252,100,253,235,253,94,244,130,1,62,2,58,254,252,255,42,2,136,255,110,1,83,0,55,4,161,254,156,0,133,1,44,30,83,0,102,0,65,255,221,251,1,255,170,255,195,1,45,255,175,0,6,3,50,1,3,255,82,9,142,4,23,248,223,0,182,1,255,4,185,6,233,255,165,255,94,2,251,250,249,252,100,243,232,253,31,2,109,3,116,4,176,249,165,253,38,2,90,253,50,254,248,0,209,0,253,253,202,254,22,246,46,248,231,0,17,254,63,1,26,2,253,1,143,255,239,255,143,0,10,244,227,255,204,255,43,1,169,2,83,2,134,1,18,2,114,254,55,252,216,1,135,251,92,3,17,16,73,1,97,251,77,253,163,253,91,3,49,1,218,3,175,255,237,7,152,1,2,0,118,246,59,0,171,255,113,252,227,254,236,253,28,0,178,1,9,247,180,255,95,244,51,0,56,3,6,249,253,8,110,2,175,253,247,255,131,2,246,0,171,1,193,0,51,0,118,0,4,0,234,0,203,1,31,0,104,254,198,2,248,254,144,0,108,254,36,254,22,1,28,237,143,255,126,1,227,255,177,0,89,1,223,255,239,255,171,255,139,23,72,0,91,255,32,2,58,255,75,0,234,254,250,254,155,0,245,1,207,254,233,254,73,254,226,5,59,3,149,252,224,245,84,251,79,251,149,0,16,0,35,2,252,3,152,253,118,1,63,255,101,255,213,241,231,0,8,1,161,247,90,0,163,1,62,2,229,252,177,0,72,1,240,2,217,254,210,0,152,254,30,251,79,10,156,243,243,255,222,255,233,1,228,1,122,254,97,255,227,254,27,0,188,1,4,255,9,1,18,2,102,245,172,254,249,249,26,9,128,251,142,255,196,1,48,1,32,255,61,254,195,254,189,253,45,1,201,253,190,4,174,253,147,253,98,245,59,0,1,1,154,1,253,255,145,0,70,0,109,3,225,243,244,0,146,251,236,0,132,251,109,37,58,255,156,255,234,255,237,0,241,255,155,255,233,255,46,0,129,0,63,0,113,255,5,0,205,254,113,255,247,255,27,0,50,0,40,0,160,23,25,0,58,0,240,255,95,255,147,255,99,255,137,0,115,0,121,0,164,0,4,0,202,255,77,25,188,255,136,255,227,255,45,0,248,255,243,255,78,1,169,255,105,0,76,250,28,0,178,254,93,255,192,255,211,241,185,255,176,0,61,255,53,0,255,255,160,255,208,253,235,255,135,0,178,0,179,255,150,239,20,0,240,9,51,255,85,0,180,254,158,0,61,0,151,255,142,1,168,255,14,0,241,0,107,255,62,0,132,255,120,255,103,255,27,0,190,0,35,10,25,0,61,246,238,253,17,7,152,255,63,245,42,1,145,0,253,252,139,0,165,0,158,9,10,254,92,3,82,255,199,0,74,0,163,0,82,253,231,255,57,0,153,255,203,254,152,254,39,0,216,254,51,245,193,254,74,252,90,253,121,251,49,249,219,5,240,6,80,255,9,0,44,0,187,253,69,0,39,0,162,0,70,1,160,255,73,1,247,255,250,4,117,246,151,255,206,255,116,16,233,255,146,0,25,255,234,255,206,255,128,255,11,0,28,0,116,0,41,255,46,0,217,0,204,0,153,0,183,255,100,255,156,255,225,255,72,10,66,255,46,247,199,0,35,249,194,0,53,0,38,0,165,233,66,0,169,0,96,1,217,255,106,255,255,255,50,254,41,0,158,255,146,255,216,255,125,233,66,255,98,255,156,250,205,0,29,255,110,254,81,0,85,255,151,1,131,255,192,254,56,254,195,254,233,1,186,2,204,254,149,15,84,255,146,1,196,0,55,254,42,251,64,255,187,253,193,255,21,255,153,0,186,251,203,255,211,255,170,255,240,0,64,255,156,245,52,9,153,0,196,255,21,1,33,0,198,0,199,255,197,4,88,244,185,254,186,254,208,255,61,0,93,0,222,255,89,255,201,254,136,3,92,1,159,1,57,0,208,7,179,255,238,0,40,0,0,244,220,255,27,1,202,255,113,253,6,255,234,255,199,253,184,253,238,255,221,2,5,255,184,255,228,255,80,0,206,254,211,0,188,0,107,255,244,17,49,1,116,1,95,1,174,255,72,255,177,255,191,255,128,10,110,10,202,255,175,255,86,255,19,0,168,255,122,0,139,255,33,0,51,0,227,255,143,255,99,244,46,0,34,243,90,0,8,0,76,255,29,255,194,255,43,0,231,255,187,0,132,254,227,255,167,255,138,0,160,254,231,0,72,10,158,0,201,7,241,255,94,1,107,0,42,252,240,255,160,251,136,0,85,255,214,255,45,10,70,255,110,0,167,0,137,6,116,4,227,255,79,253,81,0,141,3,57,254,163,11,44,0,1,0,252,254,26,0,28,0,166,255,200,253,133,255,81,255,232,0,218,255,68,9,111,0,56,1,17,2,191,255,75,1,100,0,232,1,12,0,172,253,15,254,7,9,183,251,218,4,162,255,14,247,98,255,165,245,16,0,24,255,24,13,24,0,203,255,173,255,251,255,204,255,205,0,152,255,218,254,217,0,60,255,219,255,249,255,0,0,228,255,211,255,60,0,13,0,41,0,111,0,142,0,93,227,216,255,56,255,18,0,90,255,14,251,209,255,6,255,176,253,164,253,33,0,83,0,52,255,149,251,90,255,68,5,199,250,184,0,50,0,174,216,30,0,24,0,72,255,137,0,53,0,32,0,87,0,229,255,151,0,100,0,10,0,209,255,28,0,118,255,12,0,95,244,136,254,58,0,168,0,106,6,144,0,15,4,113,254,217,252,5,0,77,249,12,0,114,255,179,255,206,254,246,2,162,2,174,255,144,12,143,254,60,0,224,1,20,1,89,254,238,19,253,12,169,0,47,0,235,0,37,0,81,0,170,255,228,255,200,255,197,255,51,255,130,255,28,0,23,1,15,223,137,0,230,255,103,254,237,255,106,0,93,255,180,255,199,255,235,0,7,0,131,0,175,255,59,255,194,254,1,5,54,1,138,244,204,3,201,250,35,0,204,254,163,255,128,255,177,1,15,2,63,255,233,250,162,0,222,255,169,255,99,255,6,1,135,19,25,0,201,254,163,254,94,0,250,254,0,0,37,255,57,0,12,0,252,255,10,0,239,255,38,0,192,254,48,0,156,0,80,0,248,22,48,0,45,0,31,0,2,252,31,0,227,0,41,253,121,255,5,1,235,255,80,253,51,1,124,12,53,2,115,2,222,253,237,0,193,246,223,255,86,6,169,255,186,6,55,255,208,2,229,253,224,254,12,252,141,0,124,254,184,255,236,255,197,255,6,248,203,255,155,255,208,0,23,255,189,252,240,255,20,12,2,0,54,1,94,0,150,254,93,255,128,255,30,0,234,255,111,255,164,1,255,255,66,1,244,253,182,10,236,254,206], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1553605);
/* memory initializer */ allocate([0,85,246,63,2,115,253,170,254,132,5,1,0,75,0,242,255,54,0,170,0,66,0,86,1,251,254,197,2,181,255,192,8,122,255,32,0,153,2,171,0,122,255,30,7,109,0,57,2,57,12,168,0,156,254,53,0,235,4,189,255,43,0,120,0,132,255,137,8,157,9,239,255,1,255,163,254,89,255,98,255,237,255,84,0,36,253,52,252,30,1,87,0,251,17,96,255,7,0,141,0,1,0,30,1,54,1,197,254,157,255,26,1,128,1,68,0,93,0,233,248,63,0,170,255,121,0,219,254,210,0,115,0,63,0,82,255,104,2,200,248,132,255,251,4,42,1,185,0,245,254,188,13,151,255,94,255,3,255,78,254,94,253,166,255,72,247,38,0,168,0,251,254,33,1,70,0,130,14,0,16,175,255,17,0,56,0,57,0,68,0,236,255,110,255,28,0,104,255,239,255,159,255,125,255,88,10,71,0,225,242,40,0,235,254,57,1,85,0,230,255,41,0,54,255,76,0,8,0,176,255,96,255,154,255,239,255,155,0,189,0,16,6,86,242,66,254,153,255,24,255,51,255,194,253,124,255,169,0,206,0,153,6,19,4,32,253,78,255,163,255,103,244,26,0,5,255,108,255,139,0,70,0,187,254,117,0,255,243,9,0,43,0,245,255,132,254,66,255,198,254,60,244,50,0,182,254,230,255,198,2,153,0,19,0,129,244,58,0,20,244,200,255,7,0,40,0,9,0,65,1,219,255,51,254,234,255,138,254,57,0,53,255,16,0,241,255,231,255,240,255,219,255,248,255,215,255,140,255,28,31,70,0,197,255,77,0,200,0,0,0,213,255,118,0,184,255,189,255,104,0,250,255,78,0,171,0,13,0,153,255,25,3,98,0,126,237,52,255,11,0,30,0,184,255,33,0,194,255,47,0,157,0,236,0,109,255,96,254,42,253,66,2,5,0,198,15,162,0,254,255,63,9,118,255,71,255,214,1,49,12,70,0,185,0,234,255,51,255,37,0,193,255,177,254,115,254,43,0,10,0,99,230,144,255,2,255,106,0,127,255,20,255,0,0,6,255,42,0,128,255,84,0,237,253,229,255,211,8,230,254,235,255,186,255,104,254,19,0,104,253,177,3,60,255,206,251,89,5,216,255,95,243,28,0,20,0,171,247,125,0,87,1,113,0,72,2,242,255,50,0,126,255,48,254,1,2,39,3,134,238,193,255,57,0,96,4,64,0,226,255,90,1,206,1,129,0,219,0,226,255,31,1,192,1,128,1,198,0,153,254,73,4,0,255,60,3,181,245,198,254,80,1,250,1,112,255,194,0,167,0,43,5,239,254,184,239,245,10,138,255,248,255,136,0,174,255,44,255,53,0,253,254,195,255,94,0,214,0,11,0,29,0,250,254,187,255,24,0,102,0,45,0,225,255,70,255,58,0,129,2,147,2,84,255,44,14,64,255,89,254,34,0,3,0,45,0,19,0,93,1,117,0,251,255,197,236,99,0,108,255,180,0,119,2,50,0,52,255,129,2,164,255,156,0,63,248,53,4,201,0,56,0,107,254,198,2,36,255,131,248,239,254,22,255,100,0,90,228,30,11,79,0,145,255,236,255,74,1,227,0,220,255,49,1,45,0,81,0,148,0,243,255,68,0,108,1,195,254,184,255,229,7,28,0,93,0,72,1,0,255,75,255,243,9,235,0,178,251,130,0,191,253,92,255,10,5,93,7,85,255,109,255,81,243,68,1,184,255,199,254,194,255,32,0,28,1,118,255,247,255,110,255,173,6,122,254,41,7,33,1,125,0,65,9,60,0,223,0,119,255,130,2,143,255,204,0,32,1,20,250,118,255,228,0,112,1,219,0,146,253,17,1,139,12,41,255,89,254,139,0,65,0,85,0,53,255,71,252,11,0,193,0,38,1,23,1,195,12,246,0,183,246,197,255,188,254,136,0,20,254,23,0,200,255,79,0,51,1,115,0,110,255,181,8,69,1,112,249,171,253,89,254,152,8,212,255,48,0,130,1,140,1,134,255,220,255,35,0,35,38,33,0,189,255,19,0,222,255,15,0,41,0,231,255,226,255,195,255,20,0,135,255,117,0,101,255,228,255,191,255,229,255,40,0,137,0,188,0,45,255,16,255,71,0,223,255,247,236,200,7,56,0,115,245,255,255,151,0,160,255,30,1,114,254,94,254,35,255,39,1,118,254,137,255,74,255,132,255,77,0,7,0,212,255,168,0,222,255,102,255,1,1,4,0,142,255,122,2,131,0,66,19,138,255,196,246,46,0,52,255,127,255,160,243,118,255,23,254,198,1,160,255,120,0,65,254,9,0,26,255,174,0,95,44,200,1,251,254,182,255,7,255,228,255,149,0,177,255,220,255,211,0,246,255,213,0,146,255,81,1,40,241,4,0,33,255,238,255,136,0,222,254,101,255,21,255,57,0,191,1,17,254,25,255,241,255,244,251,171,255,102,255,187,238,237,255,19,255,89,251,12,0,237,255,2,0,168,255,172,255,13,1,249,255,175,1,230,255,140,245,156,255,31,1,225,255,156,244,96,255,173,255,58,255,9,0,183,0,233,254,188,255,233,255,201,255,139,11,135,255,185,255,183,0,66,253,189,254,153,6,124,255,53,1,136,0,63,251,184,1,131,255,121,249,33,6,95,255,148,255,232,0,13,1,252,253,37,0,21,0,252,254,26,255,52,2,137,254,224,0,129,0,236,16,136,255,234,12,153,0,231,255,252,254,172,255,123,0,21,0,5,0,239,255,111,255,212,255,7,0,255,255,34,1,166,246,74,255,51,0,165,3,13,4,26,0,211,0,187,0,9,249,68,0,19,253,204,255,148,5,221,249,251,254,34,0,57,255,210,2,129,255,138,255,142,255,175,246,146,0,238,251,185,255,61,250,106,255,109,247,151,0,227,255,6,0,96,0,67,251,26,1,219,0,210,1,144,0,212,254,109,0,182,255,125,0,47,11,2,0,109,244,38,255,235,0,3,0,103,1,63,1,116,1,12,254,241,254,238,1,135,10,191,255,227,255,47,0,74,0,222,255,161,255,208,255,180,255,185,255,87,244,226,255,245,255,26,0,80,255,107,0,96,0,22,0,196,255,114,0,186,255,109,255,213,255,69,27,110,0,170,255,33,0,66,0,8,0,195,255,52,0,87,255,82,0,233,0,56,0,141,255,217,254,241,0,227,251,182,240,177,255,105,1,155,252,112,255,112,255,219,252,158,0,234,254,3,2,4,0,195,254,149,3,99,253,242,12,253,0,36,5,3,1,12,0,234,31,15,0,129,0,56,255,120,0,245,255,34,0,179,255,243,255,1,1,79,0,9,0,23,0,54,0,73,0,0,0,12,217,5,0,7,0,43,0,29,0,4,0,152,255,43,0,220,255,76,0,28,255,1,0,179,255,100,255,187,255,47,255,84,0,246,244,242,0,75,250,50,253,242,255,248,6,15,2,226,0,124,38,83,0,241,255,123,254,34,0,51,0,240,255,210,255,255,255,232,0,115,0,26,0,214,255,132,255,178,255,58,0,20,12,59,245,145,255,223,0,226,254,23,0,86,255,90,255,248,254,75,1,84,255,207,255,230,255,166,0,56,10,128,0,46,12,59,0,76,3,135,255,8,254,63,255,203,255,161,255,26,1,235,255,248,255,245,255,58,0,208,255,102,38,25,0,230,255,53,0,113,0,96,0,125,0,12,0,192,255,185,0,225,255,19,0,5,255,205,254,120,255,103,5,219,255,128,255,56,0,207,16,24,255,240,254,44,0,64,255,19,2,113,255,71,253,13,247,70,0,229,0,80,254,176,253,238,4,138,3,49,255,242,5,5,1,88,225,217,255,48,252,150,0,115,0,117,255,61,0,230,255,45,255,39,3,231,255,55,1,158,255,215,254,133,0,205,1,147,255,250,255,249,251,236,0,221,244,86,0,136,8,2,255,173,255,137,255,110,3,149,255,231,255,100,6,160,6,237,5,249,0,215,255,229,254,190,255,229,2,192,2,126,252,46,1,214,1,104,1,249,255,142,232,26,0,12,1,147,255,150,0,202,0,196,0,250,254,199,255,160,0,155,0,7,0,9,0,118,233,28,0,127,0,112,0,180,255,234,252,45,0,138,255,201,0,193,252,67,0,175,255,199,0,40,1,156,6,226,255,130,255,135,255,29,0,131,1,215,0,13,1,250,253,24,255,155,0,175,10,21,255,174,255,223,255,17,12,144,241,217,255,205,255,124,0,36,255,37,0,51,0,127,255,194,0,176,255,81,0,0,0,17,255,124,248,12,255,107,0,116,1,111,0,206,0,162,1,39,0,138,255,245,247,66,254,98,5,149,2,169,247,122,0,151,255,60,0,16,1,165,255,29,255,48,0,102,243,168,255,147,255,199,0,54,2,158,0,108,9,228,238,79,255,153,0,252,0,24,0,189,254,8,1,140,255,244,255,179,254,99,0,75,255,132,255,0,1,125,255,217,255,211,255,168,255,69,0,230,255,83,255,44,237,30,1,85,255,174,255,175,1,18,0,197,252,149,255,142,0,60,0,44,1,166,1,7,1,61,0,94,1,85,0,64,4,123,255,252,250,70,0,31,238,5,0,114,0,233,255,23,0,91,11,174,0,43,0,18,0,33,0,225,255,64,1,247,255,34,1,2,0,249,255,39,0,245,255,52,0,32,0,252,255,6,33,18,0,10,0,67,0,20,0,22,0,253,255,47,255,153,255,44,255,155,255,155,255,92,254,235,244,228,255,142,1,140,0,3,4,69,255,222,246,150,1,104,255,224,254,211,2,100,254,197,248,185,0,129,2,66,255,107,0,249,255,134,243,128,255,130,254,165,0,0,255,85,0,96,0,155,0,112,255,175,1,156,254,86,1,52,246,114,247,247,254,192,254,191,250,27,0,67,248,99,248,95,0,178,255,56,254,153,254,126,1,38,255,154,255,164,0,126,1,139,3,87,2,153,2,27,11,179,16,17,0,100,255,248,254,73,0,104,0,231,255,136,255,91,0,84,0,69,1,170,0,191,255,11,255,233,255,89,0,52,0,43,18,124,0,185,0,30,0,65,1,145,0,111,0,15,251,128,0,100,255,64,0,24,0,114,248,133,0,172,255,246,255,34,0,33,3,108,255,168,255,169,0,105,249,163,1,203,6,52,255,186,255,185,0,117,0,123,1,92,254,145,0,190,241,248,254,94,4,75,1,206,252,103,253,92,254,74,0,32,0,104,255,30,255,6,0,216,0,77,16,23,0,206,4,239,0,2,0,199,255,78,253,4,2,90,0,58,0,232,255,195,255,175,0,20,245,143,255,242,254,94,0,241,246,98,255,205,251,237,254,121,253,1,241,37,0,171,16,20,0,207,255,168,255,72,0,85,255,61,255,45,0,233,255,97,255,192,255,110,0,45,255,42,0,45,255,55,6,20,1,178,241,213,0,54,0,76,255,18,3,164,255,183,254,126,1,88,1,165,0,193,255,14,0,249,255,66,0,29,0,171,34,43,0,206,255,65,0,13,0,15,0,48,0,216,255,114,0,125,0,229,255,158,0,3,0,75,3,8,0,122,253,100,0,207,243,184,6,88,0,130,3,90,1,184,244,73,255,22,14,0,0,33,0,99,0,180,255,248,254,161,254,4,254,222,253,153,255,252,0,207,255,46,0,224,255,48,0,11,255,67,0,152,246,84,1,81,12,102,255,232,254,72,254,118,1,32,255,217,255,48,253,223,254,120,255,233,243,158,255,219,255,170,255,145,0,51,0,132,0,5,3,122,251,182,254,63,254,115,255,217,248,154,2,136,245,146,255,118,252,205,254,29,243,31,1,55,0,247,253,83,255,81,254,129,254,67,0,228,255,34,0,247,0,254,10,199,5,32,0,108,247,167,249,135,0,72,0,3,0,122,2,76,0,246,1,206,254,146,254,136,255,37,255,142,7,116,1,126,255,143,255,255,0,242,255,30,0,81,253,192,253,29,3,50,1,200,246,14,255,14,8,69,0,225,8,26,0,236,255,235,255,188,255,187,255,246,237,60,0,85,255,21,255,241,254,175,0,146,255,147,0,100,0,92,6,59,255,254,255,94,240,8,2,44,251,235,255,62,0,116,254,1,2,143,254,88,255,29,1,49,2,131,0,67,5,83,0,155,255,89,0,206,0,5,0,204,17,233,255,167,4,39,0,96,1,98,255,99,0,61,255,223,255,225,1,66,254,131,255,181,0,118,10,44,11,244,253,17,255,55,0,152,254,154,254,208,253,93,0,51,1,29,1,77,0,217,254,166,255,114,0,211,255,54,0,184,254,94,0,34,255,226,255,116,236,92,255,100,0,123,1,208,0,168,1,245,255,26,0,10,0,230,255,224,255,114,0,30,0,18,0,212,255,35,255,72,255,224,255,0,0,157,255,215,220,249,255,223,255,1,0,41,0,253,255,13,0,9,0,210,255,170,255,47,0,56,0,72,0,249,255,5,0,118,251,101,0,200,1,39,255,112,13,36,255,144,1,100,0,223,5,109,1,143,2,26,255,42,0,105,4,255,2,192,0,240,255,144,242,177,255,20,255,3,0,176,255,51,0,245,255,40,252,114,255,29,0,42,2,83,1,59,7,105,0,233,254,157,244,116,0,18,12,81,254,233,0,81,1,61,0,159,3,32,0,82,255,237,0,255,0,6,255,92,2,115,0,244,7,78,0,177,255,206,255,163,254,82,1,29,1,169,0,138,1,207,255,170,4,106,244,191,1,57,0,225,245,159,1,182,253,200,245,59,255,195,255,84,2,121,251,130,0,71,254,100,1,47,0,168,4,240,1,247,248,241,255,114,255,233,255,132,0,21,0,84,0,234,0,119,255,23,0,109,255,74,243,151,1,107,0,108,4,130,0,74,0,153,0,76,12,136,8,48,254,14,5,222,0,77,2,201,1,115,254,169,255,163,253,137,253,55,1,65,253,110,0,20,0,233,255,181,255,18,0,213,255,74,255,8,0,162,255,151,0,125,19,149,253,150,2,82,0,8,0,69,0,252,255,126,0,221,255,157,255,235,254,29,255,92,247,116,12,91,4,45,254,150,253,35,252,169,2,218,0,231,255,219,255,247,255,32,0,210,255,97,0,15,0,233,255,161,255,250,255,55,0,19,0,224,30,242,255,4,254,3,0,14,0,244,255,198,255,28,0,154,0,11,0,15,1,175,253,88,1,176,254,161,13,215,255,74,244,110,2,77,245,236,10,0,6,54,1,176,0,194,254,143,1,186,255,214,254,3,254,0,1,131,254,98,255,66,1,59,255,3,0,203,255,37,0,98,0,8,232,231,255,202,255,57,0,138,0,182,255,239,0,210,255,238,255,29,0,247,254,26,247,22,0,110,0,235,255,109,255,10,1,85,0,226,254,137,0,106,13,27,254,68,0,219,1,253,255,159,0,75,255,19,255,59,6,247,2,18,3,210,5,158,3,231,244,96,255,68,4,249,255,130,0,127,3,167,254,161,255,225,255,221,255,139,0,158,255,58,8,49,1,160,2,190,255,93,1,229,0,231,249,98,249,6,249,25,253,180,255,189,255,130,6,76,0,10,0,234,255,60,0,211,255,5,0,153,1,54,254,71,2,107,254,26,10,248,254,175,0,121,2,74,3,136,12,48,250,222,252,40,0,137,255,59,255,172,255,109,6,72,1,55,3,81,255,86,1,12,0,39,255,67,0,124,0,76,255,150,255,195,244,176,254,171,0,185,0,132,0,41,247,181,255,146,253,137,253,156,246,176,0,124,255,35,0,179,0,38,250,182,0,68,0,187,2,85,2,88,245,69,1,52,0,165,1,161,252,97,2,53,0,97,255,2,1,205,254,103,11,44,0,198,252,45,254,91,0,30,2,91,7,47,3,86,253,36,2,93,254,81,2,82,0,196,247,98,255,181,255,244,253,136,9,240,253,43,254,211,2,242,255,231,248,25,254,192,1,4,0,101,255,186,255,77,249,34,0,201,255,134,0,0,0,19,0,107,0,163,1,78,1,74,0,190,1,217,4,64,239,61,0,191,255,21,0,71,0,133,0,2,0,168,255,18,255,66,1,229,254,250,255,148,1,98,0,78,0,97,248,156,1,106,248,162,1,1,1,214,255,116,246,159,255,211,5,208,1,90,1,229,0,102,255,96,0,5,1,29,0,46,1,39,0,55,255,216,255,158,255,99,255,79,1,216,241,163,254,195,253,121,2,140,255,200,254,174,255,7,1,254,255,155,255,199,255,25,7,88,254,3,0,11,255,130,1,74,0,97,2,123,8,179,255,212,245,244,251,139,255,49,6,254,255,9,0,233,255,31,0,244,255,48,0,215,0,84,0,13,0,219,0,163,1,237,254,21,17,165,255,250,255,18,0,180,8,210,255,157,0,104,254,240,8,142,2,43,253,11,255,246,255,98,251,190,6,68,1,111,1,197,11,101,13,116,255,104,1,134,255,194,253,91,255,109,0,182,254,174,255,84,1,123,255,210,0,99,1,248,255,47,0,204,255,128,31,5,0,60,0,214,255,161,255,253,255,91,0,187,255,209,255,214,255,101,0,118,0,212,255,240,255,242,255,247,255,27,0,8,0,223,255,253,255,170,219,27,0,49,0,250,255,61,0,74,0,204,0,174,1,252,0,253,254,73,0,125,0,110,1,54,254,226,244,89,0,122,245,150,255,168,254,66,253,41,3,195,1,69,0,73,2,151,248,96,2,142,251,52,0,106,2,106,0,3,3,176,11,10,1,239,3,184,0,26,254,36,0,245,12,201,254,38,0,105,0,167,255,16,0,97,0,168,255,28,0,183,0,238,244,212,255,131,1,207,255,211,1,36,246,77,0,200,255,113,241,81,0,204,254,63,0,119,255,203,0,179,255,139,0,254,0,191,255,248,254,198,255,119,2,1,246,227,2,193,250,83,2,139,255,63,255,244,245,66,1,11,1,185,0,157,2,146,255,129,2,212,0,45,0,240,255,12,0,14,0,253,255,244,255,78,0,208,255,60,255,128,255,179,0,146,0,76,227,177,0,118,255,208,255,142,0,223,255,34,0,107,232,15,0,151,255,103,0,136,0,208,255,217,0,87,255,88,0,225,255,9,0,24,0,41,0,197,6,59,245,177,254,247,6,220,3,95,255,246,3,121,2,190,255,166,251,13,2,246,254,205,1,113,4,230,255,83,255,89,0,82,0,219,242,67,0,58,255,149,255,44,0,96,1,231,252,99,3,217,252,90,255,107,0,4,0,71,0,61,0,124,0,27,0,83,246,178,0,224,255,84,255,79,11,21,5,30,3,195,2,11,1,48,253,109,254,167,0,99,255,12,10,46,255,15,2,200,254,128,249,42,255,236,249,180,254,83,2,158,249,198,255,203,0,15,249,43,254,24,0,188,0,197,255,164,252,111,3,15,0,87,3,2,250,94,11,22,2,185,255,20,1,215,1,41,0,231,255,105,0,219,255,106,255,110,0,226,0,235,254,177,237,62,2,139,0,104,255,182,253,67,0,198,251,5,1,188,255,25,0,40,255,110,0,46,0,137,241,25,1,99,1,6,254,80,0,38,255,164,0,114,254,75,0,159,255,150,22,39,0,188,255,26,0,76,0,74,0,38,0,153,255,105,0,44,0,116,0,187,0,32,1,90,0,215,22,215,255,28,0,237,255,20,0,129,0,157,255,2,1,22,0,228,255,136,255,155,255,135,255,79,0,76,255,233,255,22,0,251,255,196,255,63,0,35,0,229,220,245,255,2,0,241,255,253,255,228,255,47,0,29,0,241,0,132,0,90,255,253,254,208,255,102,0,70,0,14,11,91,12,29,1,211,252,0,0,105,0,176,0,57,254,141,0,102,5,31,254,22,247,155,11,56,255,39,254,37,0,94,252,118,251,162,3,122,3,156,1,190,0,96,255,38,242,79,254,180,255,46,0,24,0,127,253,214,0,114,0,245,252,94,252,199,255,50,254,199,253,176,252,99,254,53,0,45,0,156,243,99,11,34,253,152,0,231,1,143,255,246,0,60,255,69,255,120,255,213,1,219,1,126,1,213,0,138,252,237,254,57,1,76,12,194,255,251,252,17,3,232,255,37,250,191,255,81,255,106,248,187,254,78,0,241,255,218,255,2,0,6,0,227,255,240,255,218,37,241,255,207,255,243,255,12,0,235,255,11,0,211,255,193,255,240,253,192,0,119,255,201,0,138,0,102,255,57,0,168,255,97,249,155,0,105,0,121,0,153,16,197,255,211,1,73,254,131,17,126,255,217,255,6,1,235,255,135,254,185,1,159,254,0,253,110,1,23,0,73,3,17,2,195,0,162,10,76,11,1,255,189,255,116,2,14,254,33,0,241,0,212,0,4,252,159,255,45,253,82,2,35,0,225,255,179,5,19,0,181,255,229,255,255,255,48,0,28,0,11,1,237,254,196,14,253,253,45,254,36,0,107,254,240,254,80,248,60,0,44,0,193,1,195,244,132,255,12,250,171,4,18,4,117,0,115,0,207,254,225,0,215,0,155,254,144,0,35,0,233,255,89,0,85,8,2,0,65,0,229,255,208,255,13,255,40,255,217,252,188,2,234,4,6,0,116,255,4,0,225,255,235,255,42,0,67,0,97,0,254,255,104,0,246,255,202,225,134,0,206,255,161,255,168,255,243,254,105,0,238,255,27,255,197,1,14,4,207,245,128,244,199,255,27,0,116,1,59,0,212,253,169,255,14,255,114,0,59,4,137,255,117,255,175,0,146,0,201,255,153,6,86,1,245,1,162,10,7,251,90,6,100,3,222,254,111,255,62,0,194,0,233,255,77,255,4,6,171,255,104,1,254,0,83,1,87,253,33,8,170,10,70,3,128,255,31,0,171,247,83,255,227,1,118,255,146,10,215,7,91,0,37,1,126,253,35,0,24,1,124,255,198,1,190,255,137,231,232,255,82,0,225,255,217,255,5,0,41,0,66,0,239,0,18,0,199,255,61,0,139,255,103,0,16,0,49,251,104,5,92,255,104,0,114,1,157,248,189,8,72,254,137,250,142,250,3,0,18,1,223,0,226,255,186,255,67,2,105,1,167,1,99,1,80,255,92,255,69,254,206,254,178,246,201,2,85,244,172,254,77,253,127,5,251,255,183,1,248,254,170,255,172,7,239,255,88,0,175,0,56,0,137,255,31,0,210,1,188,7,176,0,1,2,17,7,17,0,184,11,69,7,185,255,58,1,1,255,249,7,64,2,203,0,187,1,120,254,229,253,132,254,83,253,52,255,95,255,31,1,122,1,10,254,106,7,4,6,49,4,234,8,61,2,99,3,122,0,40,4,140,253,204,253,97,0,24,1,220,255,65,6,166,255,82,255,246,255,45,0,199,255,159,0,16,254,129,2,65,252,165,255,166,255,241,11,144,6,173,255,80,0,19,0,63,0,137,255,1,0,184,255,210,1,177,254,197,1,79,255,90,15,235,255,71,1,57,255,117,253,218,255,250,255,243,255,7,0,179,255,1,0,8,0,40,0,131,255,36,0,120,255,16,1,122,24,29,243,3,13,24,0,18,0,185,255,9,0,177,255,138,254,235,254,128,0,23,255,81,255,162,254,40,255,81,0,75,253,207,255,33,0,212,255,219,255,92,239,186,255,96,0,177,0,193,254,133,0,178,0,135,254,211,255,182,0,156,0,101,255,222,255,10,0,22,0,53,0,45,255,4,0,108,22,48,0,214,255,114,0,149,0,226,255,122,0,150,255,203,254,108,255,174,255,20,0,130,0,174,10,216,255,172,253,29,5,139,4,66,250,140,1,248,254,116,3,142,0,230,248,67,0,255,255,38,0,204,255,183,255,1,0,23,1,143,0,22,1,211,255,5,6,138,252,91,253,207,245,168,255,74,241,55,255,237,0,216,255,195,0,206,255,146,254,88,0,166,0,147,1,236,0,126,255,205,0,211,255,68,222,243,255,229,255,206,255,8,0,40,0,21,0,41,0,220,255,231,255,216,255,242,255,242,255,42,0,40,1,191,9,116,1,151,254,11,254,159,7,163,247,220,0,177,252,98,0,228,0,6,255,51,2,159,251,227,255,72,11,60,255,151,0,237,255,225,254,6,247,65,0,30,254,132,255,70,255,191,4,212,1,243,252,29,255,109,2,42,1,214,255,212,255,141,255,0,0,50,0,179,0,23,0,9,0,191,255,248,255,10,0,155,255,122,236,77,0,157,4,208,254,139,0,250,0,47,247,159,255,79,3,177,1,129,1,149,246,32,3,172,252,240,253,179,1,71,252,233,255,4,0,160,3,148,255,134,253,239,254,145,252,6,10,207,245,109,2,39,3,39,1,179,255,115,2,166,251,215,254,147,255,55,8,203,255,247,255,44,0,32,0,83,1,167,2,77,0,142,243,96,254,210,4,223,252,216,1,152,1,153,0,209,1,167,6,111,3,149,246,215,253,184,1,51,8,125,252,224,254,54,1,153,2,209,255,108,255,177,5,92,15,43,255,243,0,29,249,254,255,32,1,87,254,52,252,222,1,210,254,40,2,135,254,160,254,179,0,32,254,186,5,227,7,1,11,5,0,56,3,13,0,128,254,186,253,215,254,115,251,177,2,136,255,191,2,138,255,151,2,206,0,207,255,219,244,180,255,32,0,170,0,11,0,42,0,9,254,141,251,12,6,225,254,168,251,253,2,57,254,221,255,148,9,22,0,122,255,144,0,75,7,107,255,211,10,19,0,8,1,188,2,208,255,30,1,175,253,179,245,152,1,0,9,242,255,187,0,121,255,46,255,233,2,26,1,212,2,93,3,21,0,98,254,94,2,68,3,204,253,212,0,203,0,64,0,98,18,226,255,213,255,171,255,195,255,166,255,132,2,231,254,31,1,134,255,172,254,119,255,36,0,252,255,234,255,8,0,14,37,253,255,4,0,10,0,4,0,86,0,58,0,248,255,6,0,151,255,241,255,15,0,193,255,198,255,226,255,15,0,0,0,237,255,78,0,181,223,122,255,248,255,211,255,163,0,237,255,149,0,214,254,89,255,34,0,190,0,217,255,75,247,5,11,126,0,185,0,233,252,51,251,235,3,181,254,212,3,147,2,196,255,196,255,208,255,20,0,12,0,89,255,196,255,217,255,66,0,180,0,234,255,236,255,84,0,148,255,131,0,246,255,211,222,255,255,238,255,252,255,203,255,25,0,193,255,242,255,20,0,25,0,215,255,40,0,251,255,230,246,182,255,59,0,249,255,102,255,219,254,192,255,114,245,51,3,75,0,209,3,166,253,114,4,160,0,6,1,26,0,175,255,18,0,182,21,118,0,89,255,98,0,110,0,251,255,212,255,229,255,72,0,51,0,67,255,0,0,76,7,231,2,237,254,226,9,6,0,180,0,5,252,229,250,198,2,47,1,104,255,141,255,38,250,11,254,17,254,153,255,180,255,78,0,249,255,135,219,250,255,31,0,235,255,16,0,242,255,57,0,36,0,175,255,189,255,226,255,233,253,216,0,57,1,54,1,99,255,14,11,110,252,122,0,73,5,206,248,42,1,115,251,243,255,3,255,156,255,208,253,195,255,40,0,24,0,3,0,56,0,238,255,77,22,41,0,13,0,233,255,201,255,158,255,214,0,109,0,51,255,211,255,27,0,230,255,177,0,222,254,89,0,8,0,35,5,30,12,121,6,210,0,248,251,6,3,45,255,187,253,205,255,128,3,84,3,75,1,93,1,38,254,137,255,159,252,111,255,222,8,191,2,81,248,216,247,98,2,68,253,113,0,25,255,14,8,104,255,169,253,38,254,218,255,167,253,176,1,41,252,37,253,232,2,192,244,156,0,16,255,145,248,193,9,167,255,61,252,125,247,72,251,189,0,62,1,150,0,204,0,29,0,89,255,118,255,163,255,73,0,36,1,103,243,202,254,2,254,173,0,166,255,154,0,39,7,124,1,89,251,48,252,76,250,254,253,235,0,13,0,122,244,22,0,161,255,228,0,85,0,10,0,8,1,163,243,46,0,72,255,242,252,143,0,247,255,37,0,12,0,108,0,191,255,192,255,115,0,86,0,175,19,201,255,53,255,93,255,50,254,77,0,164,255,167,1,139,0,239,0,251,255,95,7,170,1,217,2,118,0,97,255,251,244,132,255,99,8,89,255,1,252,92,0,233,255,162,0,97,255,209,255,253,255,14,0,222,255,37,0,227,255,159,255,41,0,164,255,181,255,185,228,32,255,250,0,176,255,110,243,161,253,129,6,76,4,205,253,165,1,121,1,189,1,242,254,253,255,33,250,224,0,175,253,196,254,31,0,106,1,162,4,133,1,231,248,77,2,230,244,33,1,123,248,156,254,28,255,108,255,106,2,135,0,102,1,238,0,1,0,1,253,246,254,1,0,101,0,245,0,231,0,89,255,152,1,1,0,162,0,221,255,241,0,215,0,162,237,230,1,34,2,173,254,93,1,220,254,62,5,143,252,184,0,93,253,79,10,228,254,29,252,90,1,13,254,219,5,80,6,66,2,189,1,178,255,76,3,8,7,82,253,98,254,111,250,27,3,242,2,118,250,78,255,78,247,3,2,113,255,43,0,57,2,199,3,227,246,57,248,26,1,16,2,130,5,135,254,224,2,138,1,26,255,147,254,14,255,213,10,136,0,30,253,220,255,109,251,180,255,124,255,212,254,33,255,88,253,96,254,78,245,93,0,158,1,234,1,166,254,75,0,191,251,148,251,189,8,52,7,139,1,69,1,22,250,121,7,198,248,138,4,70,254,177,2,190,255,185,255,173,255,86,1,59,255,84,252,206,0,203,242,5,251,89,254,169,255,57,254,242,1,97,3,99,1,201,4,141,255,251,242,108,254,180,253,253,3,124,247,66,250,201,4,216,2,59,0,32,10,177,254,194,0,119,253,2,14,73,252,114,255,77,252,130,3,157,255,243,254,209,3,240,5,232,1,148,254,3,255,127,0,220,9,81,3,114,251,65,255,115,2,116,1,4,3,145,0,235,255,23,1,146,1,161,252,121,245,193,4,7,6,237,3,117,250,176,6,110,0,113,247,201,3,27,6,183,0,43,3,38,255,202,251,36,255,188,251,190,254,35,3,235,253,153,254,149,1,186,255,253,252,245,254,134,237,235,0,161,253,125,254,227,254,188,255,48,0,196,255,34,255,229,0,193,251,19,251,55,247,241,4,168,249,96,3,191,255,223,0,190,254,81,1,250,254,158,243,244,255,219,17,19,0,198,0,202,1,251,251,0,10,253,255,141,255,107,2,123,253,188,252,113,254,246,0,175,255,244,255,223,251,185,247,220,10,25,0,233,249,35,1,80,2,255,253,62,0,157,0,41,2,58,2,111,253,72,0,138,255,228,254,58,254,13,15,145,0,3,1,83,249,143,247,161,243,189,0,23,255,181,251,141,0,114,0,6,254,12,252,249,252,218,1,75,1,30,3,213,1,123,7,96,0,246,254,127,254,183,254,110,253,192,0,16,0,97,0,209,255,28,1,93,255,200,0,189,0,18,0,227,226,160,0,84,244,165,10,8,2,124,255,33,10,115,2,74,253,230,255,210,253,44,0,47,255,40,0,121,1,235,1,188,255,128,1,15,1,69,8,130,2,94,12,199,253,190,2,1,2,190,248,108,0,176,3,248,0,166,0,169,2,152,1,116,252,13,2,111,255,11,4,189,0,252,10,135,0,156,254,9,246,145,1,150,0,4,254,247,254,244,0,205,1,190,3,23,255,52,255,232,2,189,249,141,1,27,255,82,255,27,2,117,255,135,238,69,3,202,254,253,0,133,253,141,1,176,255,89,2,141,254,33,248,251,254,148,254,50,0,75,1,89,0,86,252,197,2,164,5,162,244,28,255,94,255,163,1,62,0,193,254,246,254,72,2,144,14,57,0,220,0,225,253,0,3,138,253,105,1,105,1,130,2,199,254,182,0,24,254,208,255,185,11,115,254,128,2,179,0,8,0,57,4,119,251,198,255,186,255,192,255,104,17,67,1,115,3,65,255,240,255,61,0,163,1,173,1,115,2,126,252,141,252,238,2,243,1,201,250,45,254,126,250,251,255,27,1,211,254,20,1,156,249,54,1,114,0,84,254,0,224,12,0,142,255,74,0,215,0,255,1,61,1,198,254,170,255,198,0,138,0,59,1,241,254,246,0,149,254,170,1,96,2,54,253,111,1,180,250,87,247,154,4,127,254,162,5,28,0,126,253,141,254,169,255,177,244,58,253,47,1,106,255,114,254,156,252,65,249,12,6,214,3,153,4,76,1,135,254,44,6,194,3,252,251,130,7,214,5,200,252,93,0,174,250,216,253,105,6,63,249,228,0,30,4,165,1,71,255,232,253,51,0,87,0,52,255,88,0,177,252,14,253,79,241,110,245,118,255,38,251,35,0,64,0,162,1,52,254,201,2,120,15,221,2,212,1,106,255,201,252,45,255,94,253,110,1,243,254,180,0,218,254,128,254,92,2,37,7,135,255,15,1,241,0,192,0,45,255,144,245,53,250,178,251,192,3,90,0,49,0,136,251,248,9,137,252,224,255,211,254,62,0,73,255,193,0,78,0,243,252,193,0,162,253,227,254,246,243,240,0,136,1,192,2,20,0,177,251,61,255,166,0,65,2,151,255,211,255,202,254,150,255,219,11,28,0,143,254,213,2,53,0,87,0,24,255,65,255,7,0,230,254,196,253,0,224,69,1,99,0,162,0,143,255,19,255,47,255,156,1,195,253,39,1,123,254,189,249,190,255,27,254,157,252,210,1,142,252,94,3,40,255,221,0,50,0,205,255,87,15,45,2,185,1,223,0,234,0,208,15,83,255,164,1,134,6,180,1,85,1,175,0,71,254,55,255,75,0,219,253,59,1,172,0,162,1,97,255,7,0,157,11,253,255,36,255,176,250,26,0,221,10,132,0,39,1,241,255,217,0,90,255,187,0,230,254,101,1,135,255,224,1,40,255,38,1,7,1,95,0,57,227,77,2,193,255,100,254,153,255,55,255,79,1,160,255,53,255,240,0,223,0,77,254,110,1,45,254,118,0,16,2,40,254,209,253,95,254,67,255,127,253,83,1,10,6,75,245,133,5,247,254,125,2,236,249,207,255,166,1,61,255,136,1,235,255,3,0,254,255,26,1,126,255,240,254,29,254,164,252,93,253,250,2,81,250,92,20,178,0,197,0,44,254,14,1,202,254,14,4,150,1,139,10,231,253,223,255,16,1,225,0,62,248,15,5,167,252,166,244,120,252,187,248,50,255,98,3,111,255,49,255,252,0,199,252,235,11,175,250,71,254,85,0,70,255,129,255,139,0,29,1,251,11,180,254,139,4,248,0,29,254,79,255,12,1,179,2,221,2,152,255,202,255,237,9,238,251,30,255,165,0,250,0,7,0,253,254,129,254,71,1,116,8,224,8,18,253,178,9,94,252,117,255,179,4,254,2,150,0,64,1,202,3,28,0,185,250,211,1,32,2,9,2,164,244,181,255,122,252,99,2,63,2,192,4,47,255,249,255,29,2,74,1,16,2,91,1,71,255,206,254,80,254,200,242,204,248,132,254,155,0,50,251,117,2,195,251,99,254,119,0,114,0,69,4,198,0,38,3,235,1,119,255,250,253,24,2,192,255,131,1,80,249,96,2,232,255,97,19,149,0,43,1,170,254,249,1,247,1,125,254,80,252,215,254,137,246,158,255,253,251,80,254,253,254,224,2,127,0,233,13,39,254,145,253,17,253,114,0,74,254,145,2,144,9,95,3,99,254,175,255,18,8,220,3,229,253,240,253,145,255,58,1,134,1,52,251,161,252,19,0,251,2,179,8,180,252,232,255,68,16,139,0,130,0,145,255,138,253,84,254,26,2,162,253,172,3,147,252,122,0,14,2,194,0,152,255,127,0,117,0,139,3,235,252,49,11,14,2,220,253,3,255,33,1,25,9,176,0,186,255,7,3,169,2,21,0,38,0,55,250,254,2,45,8,98,244,223,254,197,253,67,254,41,7,77,1,172,255,13,255,99,254,188,0,20,254,234,255,157,252,93,2,179,254,136,3,120,12,227,255,235,1,101,254,114,1,212,253,145,245,218,254,132,0,13,255,23,255,180,0,181,0,127,1,177,255,26,0,45,242,130,2,103,4,179,247,86,255,126,254,121,255,65,253,222,254,99,255,68,254,139,252,171,254,104,252,204,1,105,254,80,255,81,12,244,243,7,254,31,2,7,0,79,0,167,4,124,4,111,254,239,255,33,1,33,253,44,1,179,7,114,2,110,255,110,0,255,250,155,253,119,253,50,255,58,7,189,2,114,4,221,252,230,2,144,250,147,0,42,2,69,7,110,253,55,250,108,0,88,3,253,3,62,2,242,12,6,2,124,251,205,254,42,0,164,255,124,255,22,1,160,254,219,255,35,0,146,0,163,255,106,253,216,0,125,0,55,3,148,252,86,255,93,236,188,1,74,255,76,3,189,0,22,254,95,250,177,254,117,252,83,255,114,4,40,254,31,250,151,249,136,2,66,0,115,2,64,0,184,251,148,253,52,6,6,254,53,1,156,255,70,22,213,253,99,255,77,255,171,255,213,254,142,255,236,255,178,0,159,1,118,0,187,253,124,255,1,4,185,245,126,251,63,10,226,254,201,0,84,1,181,3,235,0,171,0,137,2,72,1,141,1,114,255,89,5,249,255,1,9,139,254,146,2,111,249,24,253,10,242,34,0,73,255,8,254,165,0,81,0,21,0,123,2,205,254,172,1,248,253,164,0,163,237,232,2,249,0,180,252,249,255,178,254,38,0,27,2,11,1,43,255,73,0,134,0,5,255,8,255,101,252,121,5,117,1,252,253,74,1,57,253,16,253,37,254,32,255,139,0,236,1,212,253,21,18,15,4,77,1,104,3,226,253,218,1,152,254,134,254,125,242,254,0,175,4,113,0,243,253,87,249,231,0,46,0,188,0,206,255,242,251,32,0,58,255,147,255,107,2,47,4,191,249,234,3,101,254,67,255,52,243,103,2,44,254,45,254,237,254,250,250,224,2,29,2,173,251,167,1,191,0,183,1,51,255,17,0,169,255,244,1,176,0,6,1,171,254,114,255,12,1,228,31,254,255,112,0,66,255,227,0,206,255,113,255,186,254,135,2,89,2,226,1,187,1,201,10,15,254,211,3,214,254,198,1,145,244,234,2,33,253,81,15,224,1,89,255,195,254,23,5,111,0,216,0,63,252,110,0,173,253,244,0,246,0,34,255,51,255,46,0,61,0,226,252,2,1,104,1,130,228,114,253,161,255,75,0,242,1,232,255,6,255,71,0,138,0,15,2,240,0,41,255,250,0,104,254,40,2,187,254,77,1,35,252,88,10,29,254,159,251,40,9,145,249,140,255,123,252,103,2,71,1,1,0,241,1,155,1,118,255,76,1,25,1,111,255,81,1,163,0,45,227,70,0,9,1,109,1,238,0,92,2,99,0,107,255,233,0,109,0,59,3,64,253,87,5,184,4,51,253,239,255,33,255,15,0,69,243,53,0,27,254,137,253,29,1,255,1,248,255,242,0,35,2,129,0,145,0,254,7,8,2,44,0,79,255,126,1,27,1,87,255,166,254,79,245,38,1,225,250,145,0,81,7,47,3,54,4,165,2,165,242,78,254,228,1,144,0,229,255,157,2,153,0,14,255,14,255,46,3,94,1,105,1,50,254,193,255,13,9,235,4,139,254,23,254,234,253,44,1,99,3,61,10,139,255,88,255,98,254,17,255,44,3,72,3,112,0,49,254,114,231,75,253,194,252,140,0,88,255,192,1,37,2,107,255,162,1,151,255,137,0,31,0,216,255,213,255,166,1,157,255,41,1,3,0,36,255,241,255,81,0,45,0,121,253,233,253,64,254,37,253,250,0,170,229,192,254,162,254,64,255,4,6,168,251,237,251,37,5,77,251,11,4,6,254,161,2,209,2,86,3,49,250,12,3,218,254,149,4,94,8,0,224,86,255,118,255,202,255,202,255,23,255,129,255,145,0,23,255,71,255,87,0,20,0,18,2,207,254,141,0,118,254,54,1,40,0,133,2,41,3,193,18,70,255,80,254,61,254,56,1,112,255,191,255,65,0,135,0,192,255,241,255,155,254,38,242,237,250,216,0,249,0,5,1,49,255,117,0,190,243,15,2,14,0,114,255,30,1,100,0,84,1,69,2,157,0,234,0,227,2,39,246,253,255,127,2,96,250,131,0,44,241,159,0,39,0,41,0,109,253,28,1,165,0,76,4,166,254,31,254,39,1,38,3,29,255,224,254,168,17,253,0,231,1,4,255,88,0,213,255,180,249,251,255,199,255,190,255,18,0,19,0,45,2,175,254,246,5,175,244,144,0,76,3,108,254,184,7,19,3,246,0,8,1,106,254,10,3,106,252,51,0,143,255,21,255,6,2,90,2,205,254,2,248,76,253,215,10,144,1,139,247,72,255,139,0,147,1,193,248,219,250,33,1,198,2,100,4,96,7,251,253,20,1,190,0,125,2,71,254,205,2,204,3,142,254,222,1,114,2,158,254,241,0,189,241,145,0,7,0,30,253,141,1,223,3,169,254,198,252,142,0,160,2,121,9,152,253,50,243,239,2,63,255,80,252,221,255,219,251,234,4,119,2,47,253,145,0,144,255,187,255,60,3,217,255,60,255,19,255,183,255,3,3,61,255,239,0,235,253,119,249,149,13,209,253,104,0,121,253,226,252,167,0,15,254,209,253,79,2,3,1,44,1,231,255,166,1,93,0,39,0,193,255,233,0,144,0,110,251,142,0,56,254,73,0,155,1,8,27,174,254,205,254,180,1,143,0,164,1,152,0,247,255,4,249,184,251,74,244,41,253,244,253,128,0,204,1,14,3,154,255,192,253,118,255,48,252,11,4,132,243,76,254,229,255,233,251,147,250,172,12,113,255,141,252,12,252,4,0,71,1,16,0,155,1,15,254,164,5,4,2,159,4,252,0,254,1,70,253,92,253,57,2,186,255,115,254,29,255,149,30,56,1,102,254,20,0,41,0,191,255,37,255,175,0,41,1,40,0,2,250,14,254,194,0,103,3,153,1,24,1,74,4,65,250,247,244,163,3,151,255,223,253,223,252,229,252,140,254,73,0,75,1,100,0,232,1,203,247,48,2,44,0,117,3,41,4,124,1,61,255,20,1,124,0,169,255,193,0,139,15,30,0,95,0,3,254,93,252,177,10,55,254,37,3,10,0,53,0,183,255,53,255,181,253,79,255,242,0,238,0,144,2,181,242,132,254,60,9,86,11,30,255,204,0,23,6,85,247,216,255,70,254,111,0,65,253,88,254,4,255,15,255,205,1,237,2,146,2,31,254,125,0,146,254,89,2,10,255,226,254,132,0,41,1,24,255,111,20,115,255,196,0,135,255,21,255,150,1,57,255,82,255,87,0,149,255,107,1,16,1,205,253,148,253,235,0,223,0,141,253,173,254,45,254,93,1,196,249,136,234,132,2,160,255,175,255,146,7,237,2,96,255,72,248,100,250,224,251,235,251,182,251,23,9,208,3,199,255,132,255,115,4,19,1,47,255,132,253,42,1,180,9,204,10,194,3,217,255,108,0,50,253,70,254,9,0,29,3,99,4,68,4,155,4,110,251,67,253,131,254,19,255,14,251,235,251,175,254,161,254,238,254,43,252,240,254,145,255,175,242,125,254,165,1,106,254,181,247,111,2,238,255,169,9,105,2,176,0,26,0,122,5,185,250,212,0,23,0,84,255,40,1,36,6,193,255,110,254,69,3,247,253,161,8,155,253,183,254,203,254,76,255,128,251,233,253,156,250,199,245,219,1,129,1,96,253,182,0,92,0,93,247,64,1,109,0,135,253,186,253,184,4,0,250,241,3,128,3,199,7,138,254,214,6,21,251,171,254,238,6,39,4,166,2,220,247,219,3,175,254,48,0,51,255,174,255,224,254,132,1,217,0,239,4,123,9,64,250,207,251,60,252,188,252,38,8,95,255,182,1,63,254,219,255,98,252,134,241,164,0,140,254,152,253,160,0,196,253,43,253,215,2,11,0,53,0,172,255,70,29,182,255,11,2,84,255,208,1,196,1,86,254,35,3,106,0,250,254,32,0,42,1,21,254,75,255,8,253,116,252,47,1,235,2,36,5,16,1,138,3,255,2,105,0,247,0,232,23,180,3,211,253,96,252,173,253,170,254,62,254,174,2,209,252,37,251,99,255,60,2,134,5,166,0,27,255,245,12,148,7,229,254,111,2,243,252,205,2,44,255,61,253,30,0,51,14,123,4,72,253,96,252,131,253,157,3,29,3,75,3,177,250,214,0,72,4,7,4,84,3,172,255,28,255,222,255,43,4,171,251,136,1,36,1,13,253,167,13,216,255,242,248,131,253,20,255,166,253,248,254,109,255,188,255,23,255,201,255,43,248,241,254,121,253,195,3,53,1,251,255,56,0,237,254,114,254,34,0,16,254,252,9,225,4,169,255,144,255,127,6,214,253,122,248,115,2,211,9,152,251,202,253,3,6,228,2,38,0,154,253,16,1,24,255,104,255,242,252,92,254,208,254,247,246,223,255,80,252,179,255,116,242,187,255,62,249,235,255,153,2,198,254,152,249,148,2,149,2,106,0,235,255,31,250,184,244,85,254,158,252,102,253,56,12,18,3,201,255,227,2,112,0,8,0,55,2,166,253,162,254,165,0,108,0,255,2,64,0,53,253,212,3,161,2,70,255,0,3,223,253,214,254,23,255,244,253,186,255,255,1,253,247,232,14,176,251,17,2,244,3,17,10,9,3,86,1,125,254,170,10,247,0,236,255,29,255,80,254,249,254,139,252,88,251,124,253,253,254,10,9,38,0,108,0,102,2,126,254,214,1,178,255,169,2,250,242,231,251,212,254,177,0,82,255,90,254,110,0,127,253,106,254,40,254,212,1,117,3,38,253,147,252,76,248,164,250,102,254,33,2,31,2,224,252,124,251,23,1,218], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1563845);
/* memory initializer */ allocate([12,231,250,43,255,250,254,192,252,30,252,170,251,206,2,148,254,136,5,249,255,195,3,196,1,168,2,165,0,25,241,135,3,38,3,149,0,11,0,204,250,146,253,61,254,152,0,150,253,203,254,246,0,179,1,206,247,231,1,213,1,61,254,218,249,52,255,69,255,40,2,179,254,3,2,181,254,172,5,22,1,125,245,110,255,241,3,97,1,185,252,6,0,122,243,200,251,196,253,118,245,240,2,66,249,194,254,141,1,104,255,128,255,179,255,220,255,6,254,200,1,70,4,25,1,98,255,237,255,107,255,48,0,241,244,250,7,241,9,95,255,107,2,105,4,18,1,24,0,1,0,57,1,92,255,143,2,157,0,2,3,182,0,150,7,241,0,126,252,44,249,179,253,0,1,66,1,171,2,191,255,183,255,109,2,74,0,195,254,25,10,185,0,47,254,227,255,243,255,183,231,120,255,60,255,24,0,28,255,211,254,101,255,219,255,202,255,165,255,252,255,126,255,88,254,167,255,75,255,145,2,110,0,82,238,121,254,250,2,9,4,202,254,216,252,230,254,47,253,78,253,2,1,253,254,16,0,213,253,115,10,133,254,236,245,100,1,198,0,57,254,95,0,62,255,14,253,127,1,249,254,151,252,15,1,149,255,65,255,228,255,11,0,190,255,91,0,25,0,41,255,9,0,152,0,11,0,132,255,66,0,166,1,9,2,25,21,103,0,77,255,221,254,203,252,15,251,116,254,150,0,187,255,241,255,154,0,224,5,67,254,116,0,120,255,56,242,3,11,251,255,174,0,166,0,33,1,196,255,158,0,67,253,83,0,132,253,105,254,194,0,16,255,118,255,124,0,162,255,132,0,151,255,150,255,72,0,139,0,101,0,97,0,8,225,6,0,112,0,164,0,173,255,183,254,41,0,124,0,133,1,234,255,62,255,157,0,134,254,49,247,81,254,104,12,57,255,202,254,49,0,227,1,48,255,21,255,11,0,45,0,125,2,196,4,5,9,93,0,2,2,109,248,136,0,20,1,91,255,137,0,192,9,56,0,31,0,238,0,230,253,79,254,178,2,194,254,212,255,66,3,108,249,124,255,59,10,99,255,167,7,202,253,119,0,183,0,227,0,18,8,145,1,208,255,233,4,92,2,26,5,149,0,17,1,74,2,57,255,118,8,1,1,255,7,210,255,135,254,7,253,231,255,58,254,200,249,214,255,176,1,248,246,222,0,240,253,169,255,225,254,20,2,90,11,37,248,208,2,42,2,167,1,192,253,169,1,24,1,130,252,24,255,77,255,229,1,116,2,154,244,149,1,229,0,254,255,110,255,127,0,183,254,13,255,194,0,139,9,237,253,80,2,242,255,143,6,36,1,110,252,180,254,78,9,32,244,41,1,216,244,168,255,236,0,27,254,182,1,241,0,229,254,192,1,67,2,108,253,21,1,233,0,201,0,126,0,15,0,101,254,208,253,186,253,123,254,120,254,249,255,238,0,1,0,88,1,40,255,7,238,55,254,3,4,142,255,13,0,211,254,32,1,172,0,24,254,132,255,95,245,100,0,151,255,178,1,243,255,231,10,197,252,64,6,37,255,128,236,156,255,155,1,70,1,160,253,245,252,94,0,206,3,197,1,210,250,20,255,173,1,67,255,62,3,32,0,187,0,203,1,185,9,220,1,165,0,189,12,67,254,169,0,179,0,143,255,168,0,119,254,52,0,129,254,223,255,73,0,137,0,123,232,253,254,135,255,227,255,210,255,100,255,68,0,31,255,217,0,152,0,232,254,7,0,62,0,3,0,17,0,39,1,221,0,98,255,226,234,177,254,232,0,58,254,192,254,211,1,211,255,96,0,86,255,245,254,249,4,31,1,2,1,24,2,73,253,71,252,110,4,172,1,251,0,3,13,205,2,220,252,115,2,75,4,120,0,4,0,42,0,191,0,247,255,3,1,177,254,175,254,231,255,200,255,116,0,28,255,161,254,49,254,54,23,193,0,142,255,192,255,244,254,44,1,146,0,241,255,145,2,111,1,254,255,161,244,70,3,5,255,255,255,81,11,178,255,159,253,223,253,180,253,232,1,103,5,230,1,28,7,126,0,155,11,105,255,11,0,10,0,163,254,233,254,252,254,247,254,142,0,85,253,65,255,172,0,30,0,219,254,17,236,195,255,9,255,218,255,210,2,19,1,186,254,222,255,132,0,41,1,233,12,210,255,227,0,228,251,166,251,50,2,62,0,174,249,187,2,106,1,168,249,57,254,150,0,146,255,61,0,246,254,88,255,88,255,121,254,136,0,199,253,252,252,53,255,211,1,20,0,117,237,86,255,142,0,118,255,129,0,183,6,104,7,210,0,16,252,206,0,73,2,187,254,39,1,175,0,18,246,23,254,121,0,162,255,218,255,50,245,141,255,122,243,207,254,64,1,77,255,247,1,83,0,184,255,134,255,204,255,75,255,98,0,39,0,6,254,65,245,163,255,255,255,197,255,85,10,248,0,203,254,53,255,138,0,68,1,201,253,184,2,19,254,170,0,136,9,151,3,92,254,43,244,177,254,175,253,184,255,24,2,174,255,202,0,78,0,254,1,184,0,254,255,227,0,242,244,19,0,54,6,231,254,131,1,210,255,152,1,49,254,232,253,6,1,166,8,141,255,178,249,127,254,203,0,32,0,139,252,210,245,34,9,97,0,36,1,63,254,193,1,242,251,186,253,0,0,188,255,211,0,96,255,62,0,226,254,94,246,91,254,208,255,111,7,243,251,83,255,59,5,177,253,152,0,49,251,24,3,12,2,214,0,164,255,29,0,181,0,31,255,106,255,255,255,139,0,57,224,238,0,137,255,189,0,34,0,116,255,68,255,141,0,144,255,56,0,80,255,154,0,91,0,21,22,42,1,196,254,233,255,232,0,182,255,195,254,252,255,138,253,6,254,105,0,137,249,130,255,113,9,113,0,161,255,40,254,134,0,34,1,13,253,152,0,58,251,198,255,213,3,20,255,0,32,102,255,75,0,218,0,71,255,107,0,246,255,39,0,9,1,31,255,169,255,9,0,123,0,118,252,130,254,240,9,44,0,63,248,154,255,151,1,165,255,213,248,148,255,122,0,142,0,169,0,134,0,47,253,6,250,252,255,123,255,45,0,118,1,231,251,180,255,16,0,155,254,21,1,158,0,220,245,252,255,52,250,243,255,100,10,58,255,9,0,38,255,152,1,193,255,177,0,185,255,61,255,197,16,248,255,228,0,34,0,91,254,183,2,127,250,85,0,180,10,94,1,44,0,217,1,141,0,163,255,144,0,197,255,36,255,102,255,108,255,88,255,51,255,233,11,229,0,194,0,149,255,90,0,159,254,252,1,169,254,217,1,66,254,201,1,60,254,140,255,165,13,248,1,104,8,28,255,216,248,49,254,111,253,43,2,145,2,28,2,34,2,92,2,166,8,188,255,254,0,51,2,11,1,227,0,92,0,149,255,143,0,4,1,23,0,42,0,64,0,189,255,138,0,89,255,72,0,201,1,94,19,61,0,91,252,1,0,221,20,224,255,89,0,161,0,248,1,55,3,55,1,11,0,72,255,194,253,177,255,138,249,182,255,146,254,164,0,149,254,117,0,53,0,194,2,67,253,106,244,233,0,11,0,165,0,138,1,206,1,184,245,191,2,221,254,191,255,207,255,240,15,162,252,191,255,237,255,146,255,152,252,67,1,65,3,102,255,113,1,219,1,163,8,20,0,44,255,175,6,232,255,228,255,198,255,32,0,210,6,41,0,245,252,102,2,252,1,234,11,175,2,167,1,74,255,28,254,196,255,242,0,55,15,203,253,59,254,110,0,35,2,63,252,64,1,222,255,165,254,85,248,140,255,218,2,77,254,222,255,41,0,26,0,205,255,0,32,141,255,56,1,184,0,108,255,57,255,157,0,153,0,82,0,99,0,138,0,224,255,237,255,192,255,117,255,107,0,43,0,133,0,169,255,42,0,108,255,168,27,98,255,177,254,7,255,192,255,81,0,157,0,45,3,233,254,178,8,240,255,167,4,63,253,95,2,205,0,245,255,195,250,220,253,53,247,186,254,107,255,24,246,139,0,18,253,73,0,118,254,38,255,221,255,181,0,157,3,211,253,226,0,193,255,22,10,31,253,164,0,181,0,89,255,26,255,157,1,72,1,150,1,225,254,80,244,27,2,109,4,171,255,142,247,102,255,155,254,11,255,248,255,162,0,138,255,111,0,251,4,47,0,198,254,5,248,84,245,228,251,228,255,113,2,214,252,25,254,40,0,125,255,17,1,105,0,45,10,98,244,12,1,237,255,255,254,74,3,106,253,87,3,249,1,78,2,13,255,68,0,66,27,118,0,155,255,93,1,24,255,254,254,194,254,212,0,55,0,82,253,79,255,83,255,154,255,224,1,35,0,149,0,7,1,234,244,58,255,174,3,136,1,135,0,164,11,34,0,92,0,19,255,96,253,224,0,214,254,42,1,80,8,103,1,254,0,150,0,185,252,233,3,162,12,87,255,5,1,210,254,74,0,235,254,242,1,65,1,194,0,53,243,104,255,30,245,33,0,70,0,236,0,34,255,88,0,119,254,47,0,132,253,101,3,14,253,74,3,234,246,52,254,133,0,0,0,8,1,172,0,117,244,226,254,13,255,143,1,114,3,46,253,130,254,104,3,137,255,191,255,157,246,137,255,10,255,134,252,71,255,102,0,224,255,195,253,225,0,228,11,28,254,216,255,215,252,147,1,233,239,211,244,180,255,207,255,64,255,226,253,0,0,94,0,218,253,6,0,89,2,236,0,66,254,54,255,167,0,238,0,49,10,80,253,106,254,9,1,250,243,65,1,59,0,167,253,157,0,200,0,247,254,78,0,69,253,89,253,18,0,202,255,203,0,81,253,123,10,145,255,35,244,141,253,19,254,157,1,32,254,54,0,75,0,20,1,206,0,187,248,17,0,92,254,87,255,56,1,105,1,235,254,244,255,149,254,176,253,246,2,133,255,195,12,78,0,162,252,81,0,156,254,84,2,232,253,217,2,191,8,207,255,41,2,112,0,188,1,140,2,82,244,186,255,60,4,76,254,34,0,53,0,246,255,233,255,41,0,253,255,130,255,207,0,126,255,48,255,63,0,224,1,191,0,85,24,211,255,223,255,174,255,35,0,56,0,3,1,1,0,98,31,159,255,52,0,97,255,178,254,215,255,50,0,199,255,56,0,62,255,201,253,2,8,146,0,219,3,129,254,160,1,254,254,30,11,51,0,8,0,178,2,130,255,64,253,60,1,16,0,252,255,166,255,159,0,34,0,126,0,65,0,218,0,131,228,251,254,169,255,235,255,71,255,14,0,112,0,42,0,92,255,18,1,243,254,114,4,48,255,62,2,77,2,113,255,33,254,185,10,14,3,243,255,68,246,124,255,242,1,106,254,4,1,60,3,188,253,46,2,211,244,168,253,65,254,199,254,36,5,32,3,236,6,107,4,67,1,208,255,124,240,185,2,5,0,109,254,46,0,95,0,130,0,84,0,217,255,219,0,117,0,93,6,67,255,165,250,25,0,140,255,7,9,87,253,101,254,83,253,196,250,103,254,223,0,50,254,226,9,208,252,162,251,58,1,131,252,147,255,250,254,120,1,21,245,208,255,194,244,250,255,180,0,53,0,12,254,75,255,125,0,221,254,247,254,102,255,233,255,72,255,185,0,205,253,121,251,163,2,24,0,43,255,17,1,167,244,14,255,69,9,250,255,90,255,92,0,20,1,95,5,228,255,87,7,12,10,205,0,135,255,51,0,100,1,151,252,204,254,220,251,184,3,207,2,200,1,106,0,116,0,149,255,45,255,235,255,247,12,61,8,84,255,84,255,143,0,50,253,118,255,111,4,232,0,175,250,157,0,157,255,10,2,241,238,84,0,93,2,63,1,87,252,115,254,117,0,78,254,82,0,121,2,18,1,237,249,35,255,197,255,141,246,74,246,144,255,136,0,74,255,32,254,27,0,220,253,19,255,49,3,18,2,144,2,252,0,131,245,230,255,191,2,60,243,125,1,129,254,189,254,105,0,12,254,66,0,213,254,224,251,149,254,187,255,21,0,36,1,142,1,133,254,150,255,156,254,38,0,169,0,50,11,206,0,245,253,235,254,197,244,186,253,187,255,137,2,253,255,198,0,226,255,98,0,145,0,131,255,70,255,237,255,149,255,154,255,83,255,125,227,194,255,9,254,25,255,24,0,145,0,87,5,157,254,81,255,117,1,71,252,64,253,130,242,170,0,131,3,130,1,80,2,14,253,108,2,81,0,86,0,191,255,84,0,171,2,238,11,232,254,247,244,11,253,53,0,246,255,185,1,111,255,138,0,84,5,254,255,164,255,212,254,225,0,57,255,217,247,71,4,149,254,181,255,32,1,253,2,155,252,249,255,189,12,9,0,212,244,182,254,130,254,237,12,28,0,117,2,244,0,113,255,214,254,0,254,103,254,15,255,104,0,250,255,241,254,254,255,0,32,119,255,139,0,208,254,242,255,81,0,6,1,220,255,51,0,124,1,11,0,101,0,100,0,103,255,119,8,241,254,11,1,50,1,64,244,67,2,235,254,60,1,71,1,144,4,71,0,135,250,133,1,231,255,247,254,101,0,203,255,86,255,30,255,45,11,145,0,224,11,97,255,77,0,240,255,233,0,198,253,234,1,149,2,196,1,194,7,246,253,212,0,149,255,196,0,9,255,52,1,159,254,186,0,127,245,230,1,210,255,45,3,232,255,233,0,90,255,233,12,16,11,169,254,174,255,219,1,11,1,127,254,26,0,221,255,30,255,27,0,160,1,231,0,12,0,88,0,47,255,117,255,148,1,17,255,147,255,74,255,173,252,4,1,242,0,109,0,11,0,184,251,85,0,126,239,132,255,12,0,117,255,156,255,164,253,169,255,89,0,188,22,59,0,213,255,172,255,8,1,225,253,0,0,172,1,240,255,110,255,212,253,61,255,97,255,107,3,27,0,5,1,207,0,74,255,63,9,146,253,135,243,225,1,223,254,52,0,12,0,34,0,198,11,10,0,167,254,162,255,189,244,194,255,144,1,249,0,51,0,78,255,166,4,128,255,156,240,41,0,216,254,208,255,13,0,230,255,223,0,168,246,4,2,128,254,33,0,210,255,95,255,213,255,32,255,167,255,252,255,163,254,135,0,28,2,136,255,236,254,58,255,129,0,7,236,175,0,211,255,222,255,147,255,163,1,211,255,152,255,71,255,119,254,160,1,70,242,149,0,240,243,141,255,178,255,175,1,84,255,21,0,222,254,94,255,216,0,41,0,200,255,25,254,193,2,62,255,21,252,100,0,172,0,233,10,173,255,24,10,67,255,174,4,39,2,137,255,183,255,165,255,55,8,149,253,124,0,128,0,68,10,192,0,160,0,146,255,14,1,203,6,38,4,200,253,183,255,200,255,72,1,100,0,128,1,83,255,83,0,39,0,20,255,231,255,55,254,53,0,243,230,89,1,53,254,146,255,28,0,129,255,147,255,175,253,32,0,141,0,145,252,254,0,84,8,102,254,145,253,79,4,2,247,16,2,156,0,28,0,81,0,101,2,90,2,171,0,244,1,204,246,108,2,17,0,245,253,111,244,103,252,149,255,107,254,26,255,127,255,18,0,107,1,143,252,2,5,147,5,149,254,146,2,205,0,205,255,19,11,45,248,188,0,230,255,73,0,25,255,96,1,74,0,22,254,34,255,119,9,171,254,54,245,242,255,200,255,252,254,215,255,33,0,169,0,66,255,224,4,179,255,238,246,161,253,26,14,152,255,56,255,166,255,175,255,207,2,204,255,153,254,138,1,211,254,66,0,217,255,200,255,0,224,87,0,56,0,221,254,50,0,231,0,28,1,45,255,240,255,170,255,172,255,228,255,52,0,3,0,205,255,48,1,32,255,228,0,138,254,202,1,90,248,46,255,203,245,145,1,176,247,137,255,244,255,196,255,242,255,0,224,53,0,27,0,113,0,33,1,249,255,22,0,60,0,64,255,77,1,72,0,168,254,238,0,147,0,69,247,68,1,124,0,176,0,97,254,194,1,36,254,210,253,83,254,10,255,217,253,225,254,160,2,97,8,0,32,161,0,91,255,222,255,193,0,148,255,119,255,160,255,188,255,156,0,52,1,74,255,5,0,182,1,185,255,229,255,92,255,187,0,146,255,154,22,174,255,126,255,130,255,197,0,250,254,74,255,138,255,146,255,121,0,163,255,235,0,200,255,157,255,44,255,59,244,63,255,246,255,128,244,58,0,121,255,144,253,86,255,84,0,83,1,115,0,171,255,162,248,250,0,123,0,152,255,138,254,63,247,150,9,74,254,88,255,120,2,120,255,43,253,183,254,118,254,196,255,19,0,235,10,182,1,228,252,141,0,113,255,132,0,251,0,37,0,30,1,66,7,39,0,77,9,247,255,171,255,146,255,149,0,97,254,99,1,84,255,247,255,107,255,42,2,188,254,189,236,231,253,251,254,183,253,221,254,252,2,164,255,117,255,248,255,176,255,65,0,250,255,230,255,175,255,37,0,242,255,45,0,115,0,171,0,191,254,57,1,52,1,227,237,128,255,136,255,82,255,148,0,0,3,234,1,81,0,81,255,251,254,120,255,221,5,89,1,25,0,200,255,44,255,188,254,188,252,207,0,116,253,16,253,102,9,180,254,233,1,237,254,92,252,28,1,31,12,197,254,102,2,105,245,170,6,208,251,93,255,181,255,176,251,163,0,91,254,252,5,164,255,93,255,213,252,138,255,218,255,14,253,210,1,198,254,232,0,173,253,29,14,226,255,58,2,194,255,17,3,90,6,56,4,41,2,105,254,32,0,151,255,82,0,100,255,181,255,127,31,189,255,114,0,191,255,191,255,14,255,98,0,132,255,38,0,185,1,171,245,164,255,69,0,17,0,44,243,234,254,234,254,116,0,55,2,26,253,182,0,208,254,176,1,5,1,86,0,243,239,133,1,27,3,118,255,151,0,111,0,33,255,88,9,143,1,121,255,223,253,182,0,30,255,61,0,234,0,73,0,78,0,192,255,76,0,17,0,106,24,252,255,89,255,52,0,4,0,253,255,11,0,67,255,237,255,120,255,36,255,15,0,6,0,92,254,99,247,38,0,128,244,16,0,118,0,140,255,61,0,119,0,122,254,217,0,36,2,24,0,161,0,232,255,218,246,108,255,97,255,33,245,225,0,145,1,30,255,210,0,131,2,146,254,240,0,8,1,167,0,115,0,59,3,217,255,95,255,30,0,83,255,42,0,29,0,98,0,121,1,198,255,93,255,215,255,27,0,25,0,16,17,87,0,236,244,81,255,185,255,194,255,172,255,36,254,4,0,162,9,113,0,242,244,108,252,81,2,20,1,156,254,85,254,82,253,41,255,192,10,139,1,247,255,167,254,117,0,134,255,185,254,92,0,107,0,150,255,32,0,14,1,15,1,171,0,66,12,198,0,210,255,186,255,46,0,246,1,91,0,77,0,237,255,216,0,94,0,122,0,192,255,120,254,225,255,120,245,148,254,125,255,197,254,129,0,51,254,229,0,192,0,236,0,185,0,249,254,83,255,44,0,24,0,245,254,216,255,79,255,107,255,89,246,26,0,113,0,73,255,99,249,68,255,48,0,22,0,183,255,50,0,123,255,58,0,186,255,83,255,204,254,70,254,68,255,92,0,133,1,221,255,167,0,235,0,66,0,33,10,131,9,244,0,118,2,234,255,235,0,112,0,224,255,21,2,98,255,81,0,71,0,44,0,197,255,98,255,233,255,28,0,0,32,198,255,75,255,39,0,220,0,202,255,132,255,197,255,235,254,71,0,41,0,174,255,99,255,52,229,252,255,44,0,172,255,208,255,134,0,63,255,159,0,211,255,218,0,209,255,123,255,147,0,213,6,253,2,172,255,184,0,195,254,226,254,239,255,172,254,250,254,12,255,235,255,50,12,34,1,129,255,137,255,179,0,128,255,131,255,73,254,206,10,125,7,85,0,57,0,224,255,117,1,240,255,170,0,182,255,31,0,169,1,114,2,1,0,1,254,64,0,131,1,142,0,147,253,183,0,32,255,220,0,171,4,130,1,224,242,76,1,228,1,168,251,160,255,187,0,43,0,46,7,39,0,220,255,13,0,124,255,248,255,255,255,213,255,29,0,124,255,237,255,10,0,10,0,38,255,181,241,119,0,153,255,229,255,227,255,148,255,13,0,181,0,39,0,139,255,92,0,37,0,239,255,58,255,74,1,26,2,17,0,113,0,150,18,1,0,28,0,246,255,87,0,22,0,96,0,242,255,157,255,200,255,126,255,0,0,201,255,45,0,193,255,227,244,191,10,208,1,225,255,194,255,76,0,102,255,88,0,81,0,125,0,117,1,164,254,75,2,198,254,234,254,203,255,247,7,252,253,133,9,191,0,44,255,87,0,254,255,181,0,14,255,117,0,23,0,193,255,78,1,145,0,198,1,87,1,21,255,91,0,69,0,248,255,2,0,150,255,148,255,251,255,137,0,88,255,118,225,25,255,25,0,37,0,75,0,118,255,56,0,142,0,172,253,130,0,142,255,221,12,146,254,34,1,160,0,254,255,37,255,83,0,75,3,238,255,9,5,79,255,226,0,155,2,252,0,85,253,48,3,26,0,157,0,168,0,25,254,207,255,46,243,176,1,184,0,183,4,23,0,164,0,32,2,197,3,255,255,61,0,138,255,92,0,79,5,89,0,94,243,15,0,240,1,244,0,177,0,155,253,96,255,233,255,61,255,145,255,140,254,141,255,22,1,96,0,77,0,249,245,49,0,89,254,44,254,13,0,28,254,65,5,214,254,194,0,133,255,8,255,117,255,226,2,102,0,130,4,177,254,134,10,46,5,213,0,246,2,17,0,154,0,97,2,250,253,145,254,201,0,112,255,61,0,66,0,240,8,50,0,128,10,169,255,45,0,243,255,155,255,127,0,66,255,216,255,226,254,6,0,121,0,32,0,31,0,119,0,171,255,28,0,93,0,0,32,17,1,169,0,44,0,37,0,255,0,32,255,219,0,222,255,129,255,122,255,165,0,169,0,126,0,68,255,204,255,98,0,15,0,68,233,63,255,181,254,117,254,255,255,49,0,69,255,55,0,135,255,60,255,114,0,10,0,2,1,111,255,242,255,127,254,105,0,69,255,59,0,127,1,202,20,147,0,146,255,187,255,122,1,138,0,160,254,187,255,15,0,245,254,75,0,162,0,250,255,76,12,3,2,231,0,182,255,76,254,8,5,210,4,151,255,68,0,160,255,90,255,207,255,192,255,144,0,189,255,135,0,2,1,185,255,94,255,156,0,146,254,249,255,189,255,123,255,236,255,137,255,71,0,172,255,31,0,26,0,116,0,67,247,212,0,43,0,124,1,182,255,13,0,249,255,6,3,4,251,153,255,132,255,208,255,78,255,193,254,26,0,179,1,145,255,90,3,39,1,65,6,89,245,14,255,8,0,36,0,195,255,236,255,237,255,237,255,31,0,2,1,21,0,242,255,125,1,103,255,0,224,157,255,71,1,72,0,175,0,99,251,241,254,104,0,226,255,121,255,87,255,21,0,29,0,74,255,231,255,125,0,165,0,174,255,73,0,230,255,7,9,171,255,89,244,131,255,85,0,50,255,156,255,156,255,36,0,253,255,179,255,76,255,35,0,0,0,86,255,123,0,168,0,210,254,110,1,178,254,120,11,186,255,148,1,202,244,13,0,79,0,226,0,93,255,14,255,132,255,216,255,85,255,147,255,189,0,20,0,204,255,144,0,179,248,168,255,230,0,248,255,229,255,45,0,131,0,245,255,68,255,93,0,29,255,60,254,27,255,158,0,121,1,247,255,56,249,16,0,196,12,92,255,41,0,49,1,98,254,126,253,145,255,156,255,118,0,101,255,20,255,168,3,142,255,51,0,31,0,60,0,19,5,5,0,232,11,18,1,17,1,59,255,223,254,11,255,224,254,135,7,249,255,27,0,51,1,174,0,13,255,161,255,122,255,14,0,24,0,137,255,124,255,5,245,2,255,35,0,95,0,22,0,135,0,21,0,101,255,176,255,113,255,196,255,250,255,182,0,77,0,11,0,59,255,248,255,64,232,28,0,155,0,11,0,229,255,22,0,208,255,248,255,206,255,134,255,11,0,222,255,86,1,255,255,40,0,48,255,117,0,221,255,187,255,150,0,152,240,87,254,46,0,200,1,182,0,61,254,37,255,38,0,15,0,53,255,254,2,24,255,243,0,186,255,179,0,59,8,34,255,90,1,90,255,143,0,239,0,245,0,59,0,119,255,17,0,219,1,188,255,119,10,89,254,20,0,199,254,74,0,152,0,171,0,243,254,68,0,39,0,121,237,94,0,253,255,110,0,134,0,88,255,73,0,180,0,140,255,20,1,182,255,53,255,2,0,173,255,17,0,170,0,96,0,169,0,75,0,91,234,46,0,20,0,88,255,234,255,35,0,182,255,104,0,103,255,8,1,4,0,199,255,94,0,64,255,161,0,15,0,7,0,45,0,70,255,15,0,131,255,121,0,139,236,2,255,179,0,26,1,72,0,31,2,159,255,107,1,251,255,189,255,123,254,190,255,178,0,171,1,236,254,141,245,191,1,254,255,131,255,33,255,53,11,10,254,117,0,225,7,185,255,41,0,9,0,124,0,19,0,101,1,206,253,25,0,127,254,80,0,203,255,81,255,228,9,183,255,82,244,92,255,57,0,128,255,2,255,53,0,106,255,76,255,16,0,211,255,66,1,10,1,142,246,248,254,61,1,115,1,5,0,197,0,7,0,84,246,163,255,152,0,90,0,91,255,11,0,253,254,232,255,201,255,240,255,98,0,216,236,140,255,53,0,205,0,211,255,199,255,116,0,75,0,161,0,201,255,97,0,220,254,27,0,140,250,105,0,129,255,133,0,247,254,223,255,5,0,218,241,25,0,253,255,152,255,8,0,229,254,27,255,236,0,48,255,145,0,115,2,16,255,118,0,40,1,108,0,203,254,48,0,239,242,70,2,242,1,3,1,20,0,17,3,118,255,165,1,97,0,114,1,161,0,141,0,23,245,106,0,10,255,116,255,84,255,42,0,62,255,54,255,193,254,149,255,232,255,167,1,125,28,147,255,243,255,14,255,55,0,171,0,13,0,163,255,131,0,115,255,88,0,132,0,76,0,176,0,78,0,153,0,193,255,201,255,102,254,217,255,6,0,27,0,33,255,82,255,61,0,133,2,167,0,221,255,7,12,83,255,182,3,1,0,147,255,138,255,150,255,15,0,191,250,242,255,50,0,186,255,187,255,24,0,109,0,182,0,84,0,31,0,77,255,163,255,176,243,59,244,196,255,56,0,196,255,58,0,166,0,95,255,24,0,129,0,1,0,181,0,128,0,244,255,17,1,213,255,24,251,134,0,159,0,220,255,175,0,43,0,207,255,41,0,48,0,218,255,211,255,59,0,220,255,174,255,48,0,182,255,152,255,128,11,132,255,232,255,98,0,248,0,110,255,25,255,15,255,72,0,142,255,8,3,14,254,242,0,155,254,250,0,154,255,209,27,109,0,11,0,94,0,203,255,37,0,219,255,123,255,24,0,99,255,47,0,210,255,187,255,62,0,177,255,210,255,47,236,119,0,188,255,8,0,96,255,201,0,241,255,55,0,44,0,44,0,59,255,146,255,173,255,166,255,190,255,227,255,128,255,145,9,74,255,178,8,42,1,187,255,189,0,89,255,199,0,178,255,60,0,102,255,87,255,14,255,189,0,214,0,132,0,215,255,169,0,222,0,126,255,209,0,20,0,102,255,185,254,126,242,186,0,76,5,160,2,133,0,100,0,119,1,21,254,204,255,169,255,153,0,25,2,209,9,163,254,47,0,229,255,118,0,211,254,250,0,45,0,191,0,106,255,23,1,63,9,186,255,191,0,211,254,50,255,251,255,216,255,55,255,96,14,189,255,36,0,171,254,123,255,59,255,129,254,155,255,21,0,188,255,40,251,69,0,248,255,249,255,240,255,28,0,209,255,111,255,87,255,32,0,170,0,246,0,149,0,223,11,199,245,214,255,161,255,184,0,182,255,71,0,200,255,234,255,171,255,53,255,129,0,97,0,151,255,165,255,208,254,4,0,93,0,89,0,164,10,249,10,78,255,52,0,101,255,104,255,149,0,47,0,182,0,124,0,181,255,24,0,0,1,218,255,53,0,121,255,63,0,70,0,59,0,197,255,7,0,6,0,46,0,0,32,99,255,142,0,81,0,121,0,136,0,169,255,109,255,185,255,59,0,57,0,119,0,21,0,110,248,46,0,186,0,100,0,98,255,204,255,34,0,95,0,22,0,20,0,179,0,112,0,116,0,234,0,247,9,60,244,89,255,163,255,133,254,166,255,24,0,208,0,1,1,253,0,23,0,175,250,209,0,75,0,191,0,233,255,141,255,232,7,8,1,77,0,97,255,77,0,37,255,19,255,102,255,13,0,17,1,246,242,122,0,51,255,212,14,160,255,103,0,120,255,196,255,115,0,175,255,19,0,69,0,140,1,225,0,232,254,86,0,73,1,28,1,249,1,147,1,219,255,203,0,54,1,229,245,186,246,15,255,239,255,236,1,214,255,224,255,5,1,112,0,123,0,223,255,9,251,144,255,215,255,12,0,82,0,67,0,185,255,56,0,246,255,173,255,228,255,15,0,244,255,42,0,244,8,41,1,21,255,253,255,16,2,199,255,159,0,71,255,202,255,172,255,104,255,7,3,15,0,54,0,195,1,218,254,53,0,254,255,141,0,39,0,191,255,75,0,149,0,172,234,17,0,198,255,130,255,231,254,8,1,151,0,106,1,158,255,62,0,199,246,0,246,173,0,42,0,222,254,95,255,160,255,204,255,82,0,130,0,170,255,106,255,48,0,20,0,199,255,52,0,41,247,160,255,102,10,190,255,21,0,74,0,219,255,22,0,67,1,64,0,14,1,115,255,169,253,212,254,135,255,244,255,128,255,160,255,253,255,127,255,13,239,219,254,201,255,31,0,174,255,8,0,82,0,236,255,58,0,15,0,18,255,140,0,131,255,158,255,208,29,242,255,96,0,127,255,244,255,217,255,85,0,0,0,152,255,31,255,24,0,3,0,95,0,169,255,115,0,168,0,19,0,22,0,95,0,120,31,36,0,244,255,106,0,157,255,241,255,169,255,112,0,134,255,55,0,14,0,26,1,225,255,80,0,42,0,252,255,81,0,183,255,74,0,246,255,82,0,35,0,173,0,236,255,216,255,0,224,221,255,126,254,14,1,7,1,25,255,114,255,42,0,67,254,204,0,177,0,182,254,165,252,203,2,171,10,59,0,18,10,220,0,34,254,3,0,154,1,209,255,61,0,42,255,205,10,50,255,174,0,56,0,171,1,186,1,118,0,148,10,190,255,216,255,41,0,119,0,191,255,185,255,235,255,124,0,106,0,238,255,230,245,221,255,106,0,148,254,30,1,240,255,78,255,110,255,174,255,157,0,92,0,252,255,75,254,125,255,171,255,229,255,166,255,23,0,198,255,44,235,115,0,187,255,231,255,242,255,13,0,52,0,14,0,226,254,243,255,196,255,16,0,19,0,53,0,35,0,7,0,235,255,7,0,231,0,48,0,191,9,174,255,20,11,44,0,122,255,180,255,33,0,118,254,47,0,132,255,81,255,95,0,103,0,161,0,57,0,219,255,174,0,13,254,131,0,118,254,215,7,220,245,31,254,38,1,152,0,89,2,144,0,74,254,109,0,52,255,61,1,37,0,106,1,103,255,216,0,13,1,217,255,226,4,249,1,249,1,11,10,141,255,173,253,218,252,26,252,202,4,185,255,26,0,189,255,6,1,51,0,95,255,183,0,86,6,224,255,233,0,3,0,39,255,19,0,240,255,209,0,51,0,40,0,216,255,213,255,229,255,197,227,13,0,128,255,238,255,82,0,154,0,133,0,135,255,33,0,190,255,8,0,154,255,71,0,8,0,220,10,213,255,79,0,140,12,230,254,91,255,125,0,78,0,155,255,197,255,59,0,120,255,52,1,195,255,217,254,15,255,227,255,27,0,186,254,116,11,205,253,52,1,243,254,222,255,98,255,230,255,192,255,101,254,181,255,164,1,218,254,17,255,245,255,173,1,44,0,36,0,69,0,56,255,200,255,23,1,80,0,38,255,218,254,218,254,252,0,64,0,113,30,7,0,101,255,200,255,210,243,67,245,78,255,62,0,185,1,105,0,211,255,23,0,23,0,155,255,147,255,230,255,107,255,54,2,227,255,118,254,174,252,163,6,194,7,243,0,103,253,53,2,155,0,46,249,96,0,168,254,117,253,131,1,149,254,27,1,241,0,101,0,71,0,238,255,247,255,43,0,114,0,234,255,9,0,147,255,137,255,164,255,117,0,0,32,189,255,87,0,174,0,214,255,61,255,15,2,101,255,61,255,89,255,173,249,78,10,200,252,121,0,44,0,138,0,216,252,151,1,72,2,39,255,166,255,234,254,37,2,138,255,2,251,69,3,220,0,142,0,68,252,218,254,89,0,67,10,13,1,127,255,253,0,10,0,15,0,167,0,163,0,87,0,250,254,89,0,48,0,14,0,24,0,151,11,81,255,246,9,51,0,11,0,104,255,145,255,230,0,245,254,177,255,65,1,127,253,251,1,224,255,236,255,18,255,23,0,190,254,54,246,173,0,157,8,165,255,235,255,198,249,164,1,99,255,97,0,64,0,126,0,218,255,172,255,10,0,171,255,93,0,235,255,16,1,85,254,30,0,196,255,61,0,175,255,216,255,27,0,18,0,227,255,48,255,186,255,0,224,16,0,15,0,53,0,34,0,49,0,230,255,48,246,104,255,23,0,179,255,199,11,87,0,92,255,247,0,119,0,91,0,188,1,213,255,90,255,230,255,253,0,163,255,50,0,152,1,54,243,145,3,104,0,119,0,17,0,202,255,42,0,19,0,218,254,214,254,96,254,174,255,38,0,249,254,137,0,132,0,207,245,212,255,223,10,222,255,247,255,10,1,8,0,18,0,73,255,8,2,3,2,163,255,97,255,235,255,186,0,27,0,167,255,137,0,77,0,196,255,223,255,34,0,5,236,212,255,84,255,134,255,247,255,152,255,69,0,16,0,94,0,253,10,56,255,114,255,206,255,119,1,204,12,240,254,212,255,47,0,215,255,68,255,7,1,19,255,232,255,56,1,120,0,186,254,55,3,193,0,154,1,161,255,100,1,53,2,40,1,178,4,79,245,56,252,87,0,52,255,207,250,198,252,197,252,72,2,194,0,225,255,244,255,147,255,217,255,249,255,73,0,29,0,24,0,244,255,0,1,158,255,210,255,63,0,207,0,248,255,73,0,170,254,226,17,219,255,60,0,190,255,8,0,217,255,80,255,131,255,222,255,57,0,115,255,204,255,217,255,128,255,206,255,113,255,171,255,149,255,19,0,218,255,74,0,216,255,95,255,202,255,193,255,132,242,176,0,116,0,154,20,19,0,214,255,198,0,3,0,33,0,80,0,157,255,145,255,11,0,166,255,97,0,250,255,253,255,204,255,45,1,31,9,148,0,85,255,168,255,44,0,108,254,124,0,4,0,176,255,189,0,22,11,62,0,9,255,138,1,26,255,165,255,92,0,229,245,84,0,117,255,225,255,198,11,25,0,201,0,119,255,192,255,127,1,2,0,186,255,141,255,46,255,43,0,169,251,109,254,133,254,247,255,243,0,77,0,36,255,196,255,218,255,241,255,7,0,109,0,41,0,143,0,56,0,45,255,68,246,208,255,38,255,141,255,191,254,154,254,132,1,246,255,84,255,204,255,177,0,180,11,160,255,224,1,233,255,241,255,177,0,31,255,217,0,10,0,111,1,129,0,211,255,142,255,23,0,1,1,208,255,193,9,236,0,12,0,197,0,245,0,19,0,83,255,191,254,54,1,150,1,232,254,184,255,233,254,73,0,235,12,245,0,78,0,70,255,112,11,8,1,7,1,29,255,50,0,172,0,91,0,37,1,24,0,108,255,11,255,195,255,219,0,168,255,169,0,220,0,157,255,150,12,3,0,0,0,103,0,19,0,116,0,69,0,76,255,249,255,207,255,26,0,197,255,163,255,188,255,123,0,101,1,241,0,20,243,215,254,198,0,40,0,176,255,29,1,161,0,90,0,210,255,91,255,224,255,87,0,212,233,254,0,219,255,7,0,236,255,39,246,250,253,38,7,217,3,12,254,109,0,217,252,59,255,31,2,244,251,104,0,197,7,172,1,228,2,86,4,146,254,202,5,131,3,220,248,159,0,57,244,201,254,232,252,214,255,3,0,100,254,99,255,243,255,95,3,8,255,5,1,69,255,103,254,156,0,4,3,15,1,62,1,250,254,78,0,197,253,28,0,114,1,119,0,46,1,70,237,106,0,133,255,103,255,65,7,66,253,66,4,193,254,159,1,185,254,76,8,86,255,101,254,174,0,62,0,249,255,153,3,128,255,223,2,129,255,204,3,142,6,166,0,65,250,48,255,32,255,103,3,124,252,33,255,207,252,32,1,40,254,10,0,31,0,111,254,127,243,246,250,253,255,211,254,183,0,218,2,217,1,182,1,175,255,114,3,192,255,82,11,14,255,152,1,45,255,179,254,2,255,204,252,100,2,152,251,196,255,183,255,44,246,45,0,125,2,126,255,203,1,200,254,33,255,139,253,210,5,0,7,57,255,235,255,223,253,236,6,196,251,83,255,125,1,124,1,9,5,139,255,227,1,138,0,80,251,249,253,86,2,131,242,93,1,226,243,236,4,86,255,238,0,84,253,48,0,29,254,141,252,145,252,139,0,42,1,146,255,53,255,69,252,195,0,57,0,218,253,153,7,57,253,80,253,66,250,247,5,58,0,61,1,144,2,54,1,57,0,162,0,214,7,107,5,77,3,129,255,114,254,62,1,216,9,210,7,118,252,189,254,62,255,139,3,76,2,28,255,155,254,196,254,45,2,172,253,233,249,253,255,78,6,37,5,91,249,168,3,167,255,34,247,47,5,22,4,144,1,23,255,18,0,38,253,233,255,75,255,175,253,74,0,198,253,55,252,176,1,251,254,191,252,166,255,189,237,18,3,202,253,73,255,165,252,214,253,90,1,19,254,55,255,36,255,241,0,105,252,152,248,9,1,222,252,100,5,50,253,177,251,194,253,51,1,138,0,20,251,175,0,236,9,174,255,58,0,22,4,155,250,182,9,70,2,199,1,229,1,200,252,106,255,57,0,211,255,101,255,22,254,172,251,113,247,65,3,167,1,37,248,11,1,11,3,140,0,228,255,57,0,94,0,6,0,211,254,5,0,191,252,54,251,63,255,86,4,193,255,79,0,20,254,71,250,83,245,188,1,56,0,164,251,167,253,20,0,150,253,221,250,73,253,122,4,190,255,80,1,90,255,158,0,18,2,203,255,141,254,174,253,83,253,114,0,110,255,117,1,174,0,255,255,47,0,119,0,132,255,135,255,215,229,162,255,40,242,226,5,197,4,155,255,112,8,46,2,2,255,40,253,255,1,122,1,129,254,12,0,114,2,172,0,183,0,98,1,49,0,133,6,164,4,226,14,153,1,152,0,182,2,40,246,86,1,61,0,171,255,218,255,86,255,5,0,49,1,154,0,164,254,187,2,76,1,238,9,161,2,150,251,215,245,42,2,203,5,210,1,15,1,234,1,124,253,54,3,160,255,221,1,131,0,253,247,145,255,43,0,225,255,194,255,1,253,71,243,151,2,232,1,31,7,10,2,243,253,7,255,225,1,249,255,238,250,83,252,177,254,202,253,49,1,22,2,33,253,207,0,197,2,158,243,19,0,236,255,160,248,15,1,95,249,117,0,45,7,130,10,49,1,29,254,49,254,151,1,62,253,211,1,6,2,14,7,244,0,176,255,59,254,7,254,114,3,75,3,48,5,232,254,175,0,63,1,182,252,192,0,88,253,43,254,64,21,51,255,69,255,53,0,76,1,204,0,72,255,96,0,2,4,243,253,20,0,207,3,125,0,230,249,175,248,11,253,119,255,133,0,246,255,172,254,241,252,52,250,98,247,214,4,164,235,46,254,129,0,32,255,17,0,241,1,215,255,78,3,88,0,215,255,29,1,28,1,101,255,21,0,31,255,150,0,223,0,217,252,68,254,139,251,116,252,36,1,186,254,47,2,66,254,229,254,215,255,235,254,105,242,101,253,20,2,83,0,1,1,127,1,86,244,149,6,185,2,9,3,15,6,114,255,250,6,67,2,237,253,19,3,200,2,40,252,91,2,82,255,53,254,23,5,81,252,229,2,79,4,183,255,88,2,109,254,214,255,87,255,166,255,220,0,208,0,105,0,13,240,211,251,213,3,98,252,124,0,17,1,111,255,123,255,51,1,112,18,209,0,68,1,177,255,12,0,215,255,36,255,211,0,72,255,179,1,51,1,248,249,83,0,29,6,67,254,39,255,120,253,133,254,10,251,202,249,223,246,164,252,92,1,136,2,99,255,239,252,246,12,133,255,118,255,100,254,148,252,102,1,83,255,232,254,175,255,107,255,89,255,96,255,191,247,20,0,216,255,254,3,176,1,47,253,55,0,117,253,17,0,145,251,132,254,226,253,152,251,103,11,37,254,113,255,203,255,176,0,104,255,7,0,227,255,84,255,174,0,195,0,187,224,21,1,105,0,35,0,115,0,198,254,137,0,3,255,75,0,234,254,90,0,28,250,79,0,103,255,208,253,3,4,163,254,220,254,46,254,179,251,188,254,172,255,155,16,54,3,92,254,55,0,43,0,94,7,25,1,196,3,104,9,169,1,163,4,229,255,172,255,3,251,63,0,46,252,113,255,250,1,215,2,101,255,128,254,106,13,80,2,250,254,74,254,226,255,33,11,187,255,198,255,75,255,169,255,20,0,43,1,156,1,249,254,190,2,131,0,241,254,246,255,224,2,121,0,101,231,124,255,140,255,26,0,3,255,182,253,32,0,111,255,5,255,244,255,215,1,135,0,73,2,92,2,29,0,105,3,107,1,254,255,197,249,41,0,133,251,114,255,153,2,64,245,22,5,154,254,122,255,29,0,77,253,244,255,66,253,53,254,100,0,22,1,9,0,54,0,66,0,54,254,53,0,213,0,193,0,14,0,112,254,6,19,74,252,47,255,50,0,214,1,193,1,3,0,138,255,239,8,43,254,198,255,126,0,243,3,198,252,130,1,5,252,170,246,182,253,135,250,137,0,248,2,141,0,167,255,117,0,4,255,34,12,88,252,58,255,134,1,207,1,11,255,3,254,133,255,241,11,176,4,123,13,26,1,180,254,183,253,106,253,69,252,165,0,236,254,73,0,117,1,202,0,250,1,100,1,125,0,141,0,155,253,98,253,190,1,239,7,241,5,66,254,59,5,198,0,144,255,214,0,70,0,9,1,226,250,188,9,123,255,168,248,165,254,63,252,56,1,126,241,37,254,102,0,135,1,64,0,67,4,82,253,155,255,144,0,191,1,173,0,66,0,138,254,86,1,69,0,205,242,205,250,136,4,135,252,166,252,214,3,179,249,33,255,57,0,186,0,172,1,226,0,35,254,193,1,228,251,107,253,130,254,203,1,21,1,235,254,6,255,12,0,237,15,252,254,95,255,93,255,38,0,159,0,243,0,131,0,201,1,51,247,211,254,166,249,37,0,38,3,104,0,191,0,107,7,90,1,142,1,172,251,145,253,121,254,68,4,228,4,102,4,81,0,140,255,168,4,162,2,215,250,224,255,203,6,60,253,26,255,180,252,5,254,159,1,5,1,211,0,149,253,65,255,84,21,8,0,139,0,197,0,136,1,212,253,41,255,66,0,64,0,216,252,0,0,120,255,151,0,156,0,4,1,94,0,162,1,90,250,23,7,228,253,231,252,195,1,35,254,252,6,132,255,74,1,102,6,86,1,9,254,128,254,79,251,6,253,161,3,186,244,120,3,193,255,62,1,86,2,42,0,54,251,112,254,50,254,120,255,65,1,80,7,120,1,236,4,142,0,177,255,25,17,9,0,38,1,185,255,66,255,235,255,204,245,16,255,26,0,238,255,29,255,96,3,79,0,28,10,142,252,87,0,96,244,9,0,224,1,219,249,86,255,83,254,201,0,132,255,171,0,120,2,196,255,65,254,64,0,219,255,98,251,170,255,151,255,85,11,27,242,122,255,230,1,141,0,253,254,239,0,209,1,211,1,241,3,103,254,34,0,254,0,165,9,234,3,66,3,45,2,179,252,149,0,21,253,8,254,238,1,102,5,43,4,97,1,191,0,175,251,169,6,182,253,192,5,68,254,233,250,198,0,90,2,215,1,212,1,247,18,127,0,115,255,231,1,58,254,118,255,120,254,138,255,21,254,76,252,58,0,222,254,249,255,106,253,229,0,244,254,254,255,231,253,148,253,94,237,128,4,83,255,166,0,187,255,32,0,5,246,177,1,185,253,85,247,83,4,58,4,82,252,83,255,143,1,167,253,250,0,167,1,125,0,64,254,96,1,197,253,106,254,0,0,127,18,248,254,82,255,4,252,81,4,131,251,85,255,4,255,126,255,54,255,182,255,89,2,89,2,58,2,74,245,133,250,57,12,163,254,194,0,53,1,130,0,5,1,93,0,154,0,139,255,94,254,111,253,14,1,96,255,124,6,206,252,101,2,78,250,115,253,77,241,24,255,90,0,247,254,157,255,228,255,243,255,231,254,215,253,11,0,114,255,28,249,60,238,168,3,235,255,85,253,168,255,218,252,69,255,28,0,78,0,186,255,157,255,254,255,19,254,240,255,48,0,189,4,234,250,150,251,90,0,187,255,22,0,152,254,104,1,201,255,197,1,63,253,64,17,227,0,173,0,248,255,149,0,210,0,138,255,51,0,81,241,181,3,114,9,18,255,201,0,171,253,94,0,3,255,24,0,225,0,15,254,197], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1574085);
/* memory initializer */ allocate([255,17,1,64,2,139,2,96,2,29,254,79,1,131,255,0,1,199,244,62,1,110,255,118,253,206,254,27,248,20,4,41,0,57,254,160,251,64,3,210,3,212,0,49,254,47,255,12,0,237,254,236,255,118,0,31,0,127,2,45,23,76,255,135,255,227,254,65,0,212,0,183,1,121,255,26,2,116,0,210,254,11,255,230,9,145,253,13,6,222,255,215,2,42,249,197,5,79,0,133,6,196,252,106,2,168,252,5,3,226,254,87,1,162,255,107,0,192,254,184,243,132,254,182,2,176,255,75,3,103,0,68,253,243,254,196,1,65,229,244,255,241,253,97,0,235,255,180,255,10,255,2,0,152,255,188,255,98,0,56,1,117,0,170,254,1,4,207,0,70,3,185,255,159,9,60,0,242,250,13,6,226,250,54,255,207,249,170,2,71,1,96,2,137,2,152,2,223,252,76,2,137,0,44,254,30,1,234,0,186,229,149,255,177,0,109,255,22,1,118,0,175,255,14,255,97,0,21,255,63,6,147,252,193,7,192,1,193,254,23,253,8,254,79,254,189,248,221,255,30,1,103,253,87,250,132,255,159,255,162,3,62,10,170,2,186,2,106,7,96,4,189,254,114,255,89,253,38,1,94,255,229,253,143,249,152,0,23,0,98,254,213,5,90,2,145,3,148,5,116,243,153,255,182,254,45,2,207,1,92,0,251,0,83,1,16,0,168,3,140,255,229,0,197,252,8,254,223,7,17,6,9,254,162,254,214,0,130,1,39,1,137,10,173,1,72,0,63,253,136,255,171,1,117,255,178,254,194,254,43,230,44,254,10,0,134,255,59,0,190,254,91,255,112,255,45,0,85,254,244,255,177,255,54,255,246,254,213,3,239,254,240,0,58,254,226,255,137,255,84,1,92,0,5,255,247,0,189,0,71,0,243,0,240,233,167,253,78,254,94,253,99,3,55,253,84,254,155,255,25,255,120,4,167,255,246,255,57,0,46,1,154,0,106,1,87,254,222,7,17,10,45,222,133,1,166,255,76,0,15,0,147,0,30,0,54,255,157,255,1,255,14,255,91,255,1,1,97,0,41,0,184,255,7,1,101,2,16,1,144,1,156,19,57,255,60,255,79,255,236,254,231,255,28,0,97,0,101,255,119,0,251,2,33,0,44,242,89,250,16,0,87,255,148,0,113,255,195,2,77,246,178,0,83,0,173,255,154,0,181,255,241,255,153,0,27,1,189,254,117,255,146,250,69,0,213,2,48,249,75,1,175,241,159,1,254,253,146,254,124,0,148,2,217,254,180,0,77,0,28,255,192,0,172,2,63,255,4,0,57,17,42,1,171,1,79,2,34,1,97,255,90,255,140,254,254,253,208,248,206,253,27,3,27,249,163,254,154,4,173,249,121,254,103,2,240,252,73,5,234,2,153,252,30,252,182,0,48,254,14,254,160,255,206,254,39,253,231,2,14,1,223,0,37,253,73,0,132,10,86,4,206,246,184,254,235,255,84,255,173,254,240,253,93,0,174,254,36,2,218,5,53,1,122,255,160,0,9,255,149,253,103,4,15,3,235,249,144,1,11,4,67,254,101,255,117,246,78,2,234,252,137,0,132,1,164,4,76,3,117,254,237,3,55,0,117,4,134,255,154,243,138,0,155,0,6,254,50,1,73,243,128,9,140,255,247,250,24,253,162,254,3,0,192,0,100,255,95,0,216,253,199,255,73,1,107,254,225,2,138,0,189,252,0,16,243,251,29,3,95,254,94,254,5,254,74,253,0,255,78,0,162,255,193,255,163,255,242,2,213,253,166,255,18,250,146,252,167,0,120,254,156,255,178,255,176,255,211,255,166,18,114,0,228,254,208,253,235,255,19,1,15,0,61,255,100,249,57,253,223,251,167,0,237,249,78,253,249,254,245,254,54,1,27,255,242,255,144,252,170,1,246,244,64,1,207,255,57,251,43,253,210,13,242,254,162,253,236,248,225,1,65,253,176,0,228,254,83,255,15,1,79,3,199,2,239,0,58,1,209,4,195,255,221,1,173,1,77,253,100,255,56,26,82,3,109,1,229,0,59,255,157,254,42,1,250,0,207,0,75,254,145,249,251,254,165,0,114,0,165,0,141,4,198,255,171,253,38,243,251,253,34,254,182,252,69,255,64,254,210,254,52,255,154,1,32,2,157,2,36,248,220,1,178,1,214,0,186,2,46,1,100,0,61,0,63,0,126,254,150,3,82,17,26,255,157,0,5,252,49,250,191,8,250,252,22,255,134,254,4,3,66,255,14,1,195,255,237,255,66,1,232,1,169,3,2,242,97,254,43,8,70,7,81,0,122,255,5,5,84,245,221,0,21,255,132,1,40,255,193,255,152,2,151,255,219,255,165,0,131,3,139,254,28,1,137,254,30,1,249,254,217,254,20,1,10,255,188,0,165,20,209,254,34,1,196,255,255,255,95,0,65,253,224,254,74,0,51,253,129,255,203,255,90,254,60,254,166,0,202,255,241,255,12,1,238,0,225,255,233,254,16,233,95,3,117,252,155,255,117,3,40,2,186,1,224,246,162,247,220,252,109,255,233,252,232,3,96,0,250,0,206,254,134,0,231,2,144,249,157,252,161,2,58,6,141,14,15,2,92,253,107,253,238,0,6,1,48,2,21,1,198,255,188,1,166,0,241,251,66,253,46,2,54,252,29,249,82,251,68,2,122,1,91,254,52,252,118,2,233,254,104,246,58,251,24,255,19,253,3,243,174,0,21,3,217,2,25,254,71,2,99,255,223,5,223,252,218,255,245,255,44,2,81,0,228,5,116,255,74,0,93,5,144,3,191,5,4,0,200,251,151,255,198,255,152,255,202,255,224,253,168,246,14,6,62,1,6,254,245,255,76,255,157,248,26,255,253,254,98,251,102,255,12,2,200,253,180,7,34,2,213,1,48,253,65,4,6,250,88,253,69,5,173,1,82,0,12,250,102,7,166,255,188,0,111,255,15,0,167,251,15,0,53,0,26,1,164,8,32,253,83,252,132,251,168,254,193,5,88,1,136,1,179,254,212,253,32,254,7,241,35,0,96,255,243,253,151,0,234,253,242,252,38,0,8,2,96,254,128,254,158,29,98,255,227,255,74,0,199,255,233,255,73,0,119,254,11,255,244,255,252,254,102,255,193,254,101,1,247,0,206,254,95,1,17,1,243,2,227,0,89,0,27,1,104,255,17,0,9,20,191,0,43,255,237,253,255,0,44,254,47,255,104,4,72,0,217,252,225,0,193,254,102,6,42,0,20,0,167,3,204,255,186,254,29,2,106,251,130,0,28,1,144,255,188,1,119,15,6,1,137,253,250,254,19,1,1,4,190,0,101,4,247,254,161,255,9,1,35,0,14,1,164,255,226,255,115,255,69,1,77,254,45,0,109,253,149,0,64,14,83,1,91,249,198,250,112,255,35,252,164,253,84,0,118,254,168,0,210,254,242,250,79,254,103,252,247,4,77,0,118,1,164,253,26,255,97,0,206,0,118,255,93,11,222,1,195,2,0,0,218,4,172,254,133,249,93,1,191,10,105,251,110,255,14,4,65,0,249,252,89,254,14,0,22,0,41,0,119,252,31,1,24,1,91,252,195,0,231,248,28,2,186,246,107,253,178,251,111,3,208,4,29,0,109,249,30,1,120,255,146,2,117,254,10,249,249,244,144,253,33,255,213,254,43,11,153,255,211,255,32,2,82,0,235,255,249,254,102,253,150,254,36,253,249,0,63,4,14,255,30,0,151,2,126,254,162,254,216,4,20,254,156,252,69,0,215,255,35,0,30,0,1,249,30,15,57,254,75,5,74,4,117,11,91,1,105,1,79,0,39,11,230,255,190,255,170,253,213,255,21,0,126,254,222,252,175,255,76,254,78,3,95,253,121,1,186,254,63,251,185,5,32,254,51,255,136,247,103,249,178,2,99,1,168,4,222,2,143,255,39,0,26,254,124,253,182,1,72,4,45,253,244,253,158,249,147,253,118,254,226,0,167,0,143,253,59,253,86,3,189,11,114,252,13,0,231,252,19,250,26,251,18,0,72,254,188,252,139,2,225,255,229,0,199,251,130,255,65,255,228,241,231,1,195,1,220,254,175,3,30,248,150,253,253,254,119,253,45,253,65,254,18,255,72,4,76,247,163,2,51,2,196,254,32,251,32,0,228,255,37,1,231,248,226,0,11,1,11,5,112,2,25,247,143,0,138,2,5,0,205,253,8,254,180,247,162,255,179,249,22,244,196,2,126,242,186,1,30,0,65,0,176,255,89,0,204,0,11,255,94,0,28,0,254,255,25,255,111,2,67,255,107,254,157,247,123,4,52,12,38,3,24,4,121,4,141,2,47,0,86,0,252,255,46,0,181,1,229,0,66,255,54,1,203,7,208,255,9,252,242,248,246,254,83,252,105,1,179,0,172,0,141,1,182,0,67,1,252,253,107,13,7,0,251,255,191,254,249,255,187,229,220,255,77,0,236,255,155,255,239,253,90,255,97,0,180,255,24,255,186,255,16,0,13,0,93,0,206,255,222,0,254,254,184,238,131,255,125,0,83,0,57,1,10,255,187,254,108,0,181,254,228,1,68,255,192,0,60,252,43,10,218,255,68,247,58,0,81,1,2,255,239,255,166,255,168,255,40,0,115,255,243,250,200,255,213,252,247,0,178,255,222,255,144,0,112,0,43,0,142,0,119,255,109,255,56,0,106,254,12,0,210,0,132,0,123,14,109,0,128,252,244,254,9,247,3,254,32,0,37,255,113,0,152,255,141,0,17,1,18,0,154,254,16,0,230,242,146,13,89,255,220,0,10,0,104,0,81,255,248,255,185,255,179,255,208,255,21,1,82,0,86,0,35,0,56,253,224,255,36,0,191,255,213,0,121,0,180,255,26,253,35,1,21,238,87,255,134,255,179,255,227,254,54,0,136,255,89,0,71,0,12,0,123,255,54,0,41,255,142,248,141,255,148,12,62,255,121,254,87,0,159,1,44,255,46,255,118,255,182,0,78,2,201,2,176,3,64,1,142,0,78,248,197,0,177,255,220,253,202,1,20,11,33,0,194,255,73,255,107,255,128,253,147,0,85,254,143,255,78,255,161,249,148,255,106,10,198,255,162,8,5,255,32,1,16,0,126,1,75,8,124,2,252,255,94,4,232,0,79,1,223,255,142,255,24,0,188,255,29,5,218,255,32,8,22,2,32,1,94,255,138,253,152,254,125,253,10,0,62,0,75,247,7,1,19,0,54,1,212,255,163,1,30,11,237,245,97,255,10,255,173,2,189,255,138,1,58,1,156,254,98,255,19,0,90,0,116,0,43,247,163,0,152,2,163,0,65,255,207,255,238,255,204,254,241,255,204,9,142,254,181,2,194,255,50,3,205,254,110,253,133,0,66,7,220,236,53,0,75,246,208,255,247,255,126,0,159,0,6,0,185,255,35,1,102,0,145,254,194,255,27,0,88,0,250,255,204,0,191,255,43,253,31,0,97,255,255,255,251,255,45,0,123,255,110,255,5,1,127,238,237,255,182,2,251,254,34,254,79,255,88,0,214,0,188,252,242,255,6,253,145,255,245,1,0,0,254,0,179,7,0,252,118,10,115,255,80,232,76,0,174,1,160,0,61,255,186,253,24,1,68,2,183,0,197,254,243,255,153,2,203,255,59,1,57,255,182,1,220,0,195,12,194,0,2,0,248,10,168,255,42,0,150,0,77,255,237,0,101,255,143,0,46,0,99,0,27,0,30,0,7,232,205,255,167,255,201,0,145,0,77,255,13,0,154,254,55,0,71,0,253,255,28,0,247,255,240,255,125,0,160,0,159,0,235,255,225,234,27,254,252,255,168,255,167,255,44,0,3,0,166,0,22,0,99,254,225,3,80,0,229,1,149,255,190,1,81,252,1,4,5,1,253,255,175,11,35,2,244,254,147,255,24,2,246,255,187,0,17,0,132,1,136,255,185,255,169,254,96,254,162,0,69,0,247,255,46,0,35,254,83,0,246,23,146,0,20,255,131,255,162,255,201,255,238,254,25,255,96,4,171,0,117,255,102,245,80,0,145,255,20,0,171,9,121,255,82,249,61,1,6,253,155,0,198,4,68,0,168,4,241,255,33,7,220,255,211,255,136,255,28,254,125,255,94,255,128,255,163,0,105,254,72,0,34,255,210,255,34,255,57,235,22,1,139,254,76,254,28,1,138,0,13,255,152,255,28,0,179,255,206,11,93,0,241,255,187,253,14,254,36,1,91,255,52,249,121,0,195,0,168,250,122,255,188,255,236,255,181,255,246,255,113,0,128,0,131,254,5,254,19,255,59,253,13,0,234,255,155,0,55,236,161,255,246,0,30,255,193,0,175,2,47,7,246,0,24,255,153,254,219,1,106,0,41,1,205,0,114,245,134,254,37,255,236,255,140,0,130,243,192,0,251,243,121,255,218,255,233,255,213,0,184,255,255,0,166,255,126,255,106,255,62,0,28,254,162,255,191,245,167,255,88,1,127,255,95,10,113,1,221,255,17,0,71,253,251,0,169,254,68,0,53,0,176,0,32,12,237,0,181,255,52,244,178,0,45,0,170,255,45,0,141,255,183,0,49,0,26,0,140,0,77,0,40,0,245,246,249,0,255,6,48,0,13,253,244,255,201,0,57,254,6,255,194,255,193,6,143,255,65,252,238,0,142,255,33,1,121,255,96,247,188,10,65,0,50,1,173,255,3,0,255,253,31,254,207,255,93,255,200,253,168,255,156,2,205,255,230,245,106,0,234,255,72,2,59,254,162,254,77,1,79,255,20,255,111,253,24,2,163,254,138,1,200,255,14,0,133,0,201,255,172,255,210,0,237,255,57,222,154,0,80,0,27,0,249,255,180,255,139,255,100,0,55,255,1,0,40,1,155,255,250,255,10,22,137,0,197,255,163,255,95,0,146,255,232,254,195,255,212,254,25,0,119,3,43,0,226,255,189,9,76,0,234,255,169,254,233,1,10,1,52,1,163,0,132,0,163,254,229,7,18,0,176,60,61,0,11,0,215,255,214,255,41,0,252,255,73,255,216,255,232,255,26,0,241,0,154,255,141,255,92,255,252,7,221,255,39,255,30,255,222,2,28,255,14,246,218,0,0,0,122,0,106,255,240,253,68,255,7,251,155,0,107,0,223,255,219,255,219,254,6,0,112,0,101,255,28,255,192,0,182,246,153,0,235,251,213,0,159,11,39,0,97,255,246,255,215,255,34,0,131,255,4,0,226,255,67,15,215,255,80,3,166,254,191,0,61,255,220,254,130,255,93,13,232,255,12,255,92,0,181,2,64,0,63,255,192,0,121,0,223,255,115,255,11,2,94,255,194,10,71,0,59,0,40,0,193,255,114,255,156,255,174,254,123,1,120,255,192,255,60,255,11,0,126,12,162,0,49,8,124,255,201,246,63,255,114,254,194,254,74,3,133,253,88,255,169,1,209,7,120,255,34,1,206,0,50,2,160,255,248,255,42,255,211,255,245,255,4,0,52,0,177,0,108,255,229,0,33,0,208,255,210,255,138,25,150,255,229,255,234,255,127,25,20,0,107,254,157,0,87,0,208,0,139,255,252,255,30,0,87,0,28,0,156,254,180,255,148,255,223,255,200,253,242,254,177,0,49,0,55,254,118,243,119,0,103,0,0,1,76,255,211,0,71,251,143,254,0,255,37,0,209,255,112,19,84,0,207,0,225,0,224,0,87,254,140,1,153,3,58,0,106,255,104,0,229,5,15,0,198,255,188,6,47,0,232,255,21,0,120,1,97,1,226,1,20,255,122,2,50,1,107,12,73,0,223,255,202,255,87,255,42,255,146,0,226,16,40,255,124,253,49,1,49,1,59,254,53,0,143,0,247,255,64,250,115,255,34,5,57,0,40,0,201,255,176,255,67,0,48,36,57,0,86,0,22,0,109,255,1,0,250,255,0,0,39,0,7,0,114,0,205,255,119,255,155,0,241,255,134,255,5,0,137,0,125,0,213,0,250,255,246,27,36,0,204,255,202,255,149,0,133,3,91,3,191,2,110,1,161,2,243,255,162,4,76,2,54,255,61,254,18,0,183,253,6,255,184,245,122,255,61,0,34,244,254,3,78,0,96,253,236,254,96,0,70,3,21,2,2,255,243,253,150,255,134,254,91,6,12,0,31,0,61,1,138,255,81,0,57,1,70,255,197,0,196,1,101,244,83,0,46,5,163,1,194,246,184,254,169,255,153,255,13,255,232,254,25,0,16,255,78,2,24,255,105,0,106,244,169,246,186,254,82,1,80,0,120,254,13,255,15,1,249,255,103,4,1,0,109,7,25,247,49,255,32,0,157,255,48,2,63,255,115,1,238,1,250,1,255,0,76,1,241,41,48,0,8,0,223,255,223,255,32,0,223,255,45,0,152,255,253,254,157,255,219,255,122,255,72,0,206,255,138,0,172,1,46,247,77,0,232,2,5,0,96,0,204,11,243,254,49,0,112,0,33,255,186,0,48,0,224,0,11,10,84,1,127,255,217,255,148,248,211,255,186,7,251,254,223,0,38,1,22,0,148,255,198,255,109,0,225,255,76,243,118,255,103,244,237,255,123,255,190,0,220,255,132,0,120,255,63,0,81,255,95,1,180,255,232,0,108,245,239,255,232,255,126,255,38,254,74,0,94,244,45,0,117,255,233,255,227,0,214,255,115,255,22,1,81,0,8,0,69,246,66,254,59,1,192,255,89,255,125,253,237,254,100,0,0,0,180,9,30,254,128,255,112,255,50,255,19,241,187,242,203,0,231,255,234,255,68,0,189,0,243,255,226,254,94,0,18,0,32,1,29,0,251,255,3,0,98,254,203,5,84,255,5,251,76,255,48,241,104,1,145,0,113,255,188,1,117,255,58,255,70,0,239,255,159,254,135,255,250,255,76,0,206,255,171,11,173,0,2,244,27,255,240,255,192,0,134,0,201,255,170,255,56,255,128,0,252,247,197,255,245,255,252,255,53,1,179,0,238,1,118,255,149,254,176,254,119,0,129,255,193,9,87,255,196,254,169,255,230,253,42,0,234,253,59,1,60,9,61,0,13,1,169,255,162,255,82,0,235,247,18,0,214,4,249,255,79,0,247,255,41,0,70,0,50,0,209,0,98,255,120,255,28,0,237,254,62,0,40,1,77,0,125,24,72,255,73,0,237,255,231,255,199,255,134,0,204,255,121,33,80,255,248,255,17,0,15,0,79,0,36,0,119,255,12,0,44,0,242,254,31,9,111,0,5,2,173,255,207,0,236,254,17,10,58,255,83,0,120,1,181,255,239,254,62,0,109,0,4,0,208,255,122,0,215,255,99,0,169,255,14,0,240,225,138,255,190,255,171,0,96,0,225,255,123,0,39,255,92,253,73,254,151,1,97,0,231,254,81,7,114,2,108,255,220,253,98,6,192,2,97,0,228,247,176,254,120,2,141,254,113,0,32,2,168,255,184,0,104,247,92,254,176,253,88,255,247,2,35,1,167,8,192,2,116,255,111,255,8,240,39,1,186,0,242,254,27,1,38,1,214,255,76,0,69,0,41,0,116,255,99,6,56,255,86,253,46,1,64,255,134,3,228,253,181,252,18,254,239,253,102,0,9,253,91,255,88,12,76,255,86,250,88,254,240,255,6,0,220,253,40,1,16,244,219,0,165,248,147,255,202,253,81,254,95,0,90,254,236,253,230,255,120,0,210,255,23,0,174,0,175,0,143,254,110,0,254,255,25,0,132,0,255,255,246,242,189,255,92,8,231,255,54,2,127,255,35,0,163,4,81,1,207,7,152,10,185,255,45,0,79,255,94,0,191,254,59,255,195,253,98,0,225,0,46,0,53,0,78,0,216,255,82,0,23,0,158,10,230,9,89,0,191,255,77,0,206,0,87,1,15,2,102,0,65,255,94,0,207,1,111,0,79,238,97,0,108,3,51,255,80,252,181,0,124,255,211,1,110,1,85,0,210,254,156,255,223,255,180,255,241,243,14,246,215,0,21,1,204,255,96,1,137,0,211,255,162,0,78,2,150,1,126,1,85,0,248,244,141,0,219,0,50,241,40,0,126,0,32,0,30,0,100,0,121,0,46,255,196,0,244,254,178,0,102,0,205,4,176,255,18,253,245,255,199,255,84,0,238,0,243,13,18,1,2,255,55,0,176,249,80,255,13,253,46,0,230,250,55,255,28,255,101,0,197,0,163,255,100,255,63,1,82,0,127,254,239,255,204,237,180,0,254,4,143,255,41,255,103,0,64,3,23,255,156,1,249,0,124,252,124,255,157,242,52,0,160,1,11,1,61,1,128,254,130,0,78,0,91,0,152,254,75,0,130,1,171,8,152,254,97,244,17,0,30,1,218,254,43,255,231,0,131,0,53,3,154,254,222,0,26,255,212,255,163,255,129,251,38,1,196,254,248,255,129,0,231,0,31,252,198,255,247,12,48,0,14,246,43,255,242,255,136,12,162,0,16,255,80,255,51,1,91,255,236,255,92,1,143,255,178,255,165,255,248,255,251,254,97,31,77,255,64,0,249,255,143,255,197,255,224,255,86,255,52,0,55,0,176,255,140,0,64,0,217,255,147,3,28,0,160,1,38,0,232,246,206,0,115,0,110,1,164,255,140,2,110,0,234,244,197,255,101,2,23,0,109,0,105,255,58,255,185,0,217,11,134,255,47,11,239,254,86,0,41,0,114,0,157,255,59,1,116,1,14,0,143,8,85,255,19,2,238,255,222,255,160,254,130,0,152,254,117,0,176,244,2,0,204,253,51,0,223,0,57,0,255,254,89,12,58,12,128,254,126,0,216,255,96,255,24,255,118,255,81,0,222,255,160,255,82,0,9,0,62,0,95,255,88,1,100,0,22,3,13,255,168,254,119,254,237,253,145,1,90,0,171,0,144,0,183,254,7,0,225,237,121,255,250,255,95,1,235,255,61,255,224,0,231,255,139,23,224,0,242,255,88,1,170,0,87,255,159,255,252,0,24,254,133,254,183,255,117,2,247,255,10,1,152,0,192,255,74,1,248,255,32,8,165,255,13,243,229,0,25,0,45,0,240,253,133,255,135,11,40,0,171,255,252,255,121,245,218,255,144,255,84,0,226,255,79,0,250,2,151,0,7,240,161,255,105,255,9,0,138,0,50,255,253,255,190,247,99,0,156,255,116,0,109,254,200,255,248,255,220,255,115,0,238,255,61,255,218,255,16,255,8,0,224,255,122,0,125,0,18,227,45,0,46,255,111,0,104,255,104,255,221,255,184,255,28,0,102,255,47,1,181,243,203,1,191,244,242,255,243,255,200,255,130,255,187,255,43,255,159,255,202,0,168,255,235,254,211,253,195,1,136,254,165,255,63,1,141,0,168,10,23,0,202,9,155,255,120,2,62,0,198,254,159,0,44,0,207,4,191,255,219,255,192,0,46,12,70,255,116,254,148,255,71,0,63,8,74,2,95,0,15,0,228,255,176,0,20,0,189,255,3,0,247,254,101,0,74,255,235,255,57,254,241,255,175,231,211,255,159,254,128,254,234,255,113,0,216,255,209,255,57,0,183,255,9,254,134,0,224,2,186,255,131,255,251,255,6,255,62,0,165,0,182,0,185,0,124,255,170,1,236,254,100,0,15,254,233,255,81,0,144,255,56,242,51,248,22,255,102,255,165,255,131,255,230,255,179,0,157,253,143,2,255,2,216,251,130,0,248,254,107,0,251,10,145,250,42,1,236,255,37,0,182,255,244,255,99,255,242,254,150,255,255,9,167,255,221,243,55,0,187,0,247,254,195,0,140,0,1,0,28,254,201,2,171,0,157,251,30,255,82,14,145,254,252,253,7,255,38,0,195,0,236,0,134,254,129,254,51,255,184,255,249,255,15,0,143,219,250,255,230,255,56,0,141,0,48,0,6,0,115,255,161,255,187,255,216,255,157,255,176,255,73,0,3,255,200,1,82,255,51,0,6,255,208,255,189,247,193,255,5,246,231,255,246,247,198,255,66,0,176,0,14,0,187,216,233,255,217,255,219,255,241,255,38,0,82,0,11,0,97,0,169,0,5,0,189,255,57,0,61,0,56,247,108,0,237,255,0,1,87,255,134,255,176,254,81,254,179,255,6,255,100,255,23,253,184,0,172,2,63,41,57,255,222,255,219,255,96,0,174,255,239,255,60,0,65,0,21,0,189,255,175,254,62,0,35,0,74,0,42,255,38,0,47,0,127,255,251,23,117,255,199,255,102,255,5,1,7,0,129,255,109,0,40,0,179,0,157,255,198,0,205,255,48,0,220,255,183,246,62,255,178,254,246,244,103,0,36,255,199,255,41,0,211,3,129,252,68,0,39,255,80,249,82,254,158,255,91,0,149,255,37,249,55,10,84,0,12,254,231,0,224,1,225,255,146,0,99,255,136,255,152,0,38,9,220,255,79,248,57,0,147,255,220,1,13,255,5,1,198,255,206,7,4,0,108,5,158,255,45,0,116,255,144,1,180,255,191,254,234,255,247,255,210,0,5,2,5,0,156,237,66,0,182,254,107,254,237,255,110,8,191,255,141,247,244,0,240,255,64,255,238,1,131,254,62,255,157,1,89,0,220,0,199,1,202,255,4,0,206,0,221,0,122,236,63,0,147,254,98,1,108,1,165,2,207,0,190,255,229,255,35,254,74,255,73,3,85,0,216,255,166,0,71,255,65,1,219,254,75,255,83,254,25,255,121,5,134,255,170,3,67,0,71,255,51,0,116,12,222,252,165,1,98,243,152,5,80,254,110,253,181,253,181,252,165,1,177,0,190,1,254,1,116,255,166,255,129,255,178,255,2,0,65,4,71,255,45,1,119,254,4,16,104,255,9,1,224,0,25,0,95,0,22,2,24,1,2,255,211,255,251,255,49,255,49,0,130,255,218,34,43,0,9,0,21,0,28,0,21,0,214,255,172,255,38,0,90,0,34,248,61,0,107,255,188,0,234,242,136,255,213,255,10,0,14,0,155,0,31,255,161,254,142,255,28,0,233,255,208,238,111,1,205,255,76,0,167,255,143,255,122,0,215,7,25,0,164,254,29,255,142,254,195,255,135,0,177,255,175,255,5,0,240,255,34,0,19,0,186,42,141,0,235,255,27,0,151,255,146,255,32,0,189,255,181,255,19,0,118,255,3,0,242,255,104,254,210,254,36,0,252,237,23,0,189,253,221,255,19,0,200,254,35,0,120,0,97,0,82,0,147,255,41,0,47,249,98,255,43,1,3,244,84,0,18,0,65,254,223,255,65,0,224,255,45,0,249,255,144,0,86,0,100,0,54,249,250,0,30,255,119,255,159,0,211,255,134,0,182,1,102,0,37,0,241,255,95,255,233,255,125,16,174,0,47,0,248,254,74,255,74,255,174,2,8,255,89,0,215,255,80,0,129,245,62,255,248,9,151,1,174,251,54,252,75,255,28,255,43,17,118,0,3,4,1,255,136,0,100,0,213,255,246,0,80,0,15,0,34,0,82,0,202,255,145,254,186,2,232,0,79,255,45,0,189,255,49,0,138,0,98,255,168,0,202,0,43,0,186,255,155,255,20,0,159,255,119,242,170,254,1,255,127,0,25,0,204,255,251,255,7,0,76,0,253,255,19,0,237,255,42,0,10,0,193,255,16,0,121,0,220,2,201,243,213,255,116,0,36,0,41,246,23,0,18,0,181,0,41,0,224,255,245,255,22,0,51,0,35,0,16,0,222,255,194,255,208,6,94,0,173,0,37,251,250,254,11,0,146,12,239,0,149,0,37,255,29,0,118,0,130,254,223,254,214,255,161,0,17,0,255,255,247,9,173,255,90,0,128,255,138,0,166,12,43,0,227,255,144,255,110,0,244,254,37,1,23,0,139,255,192,255,119,255,79,0,186,255,5,214,190,255,73,0,90,0,35,0,90,0,227,255,178,255,145,255,75,0,48,0,8,0,87,255,128,11,16,0,89,0,186,0,222,255,82,0,241,0,210,255,1,1,13,255,93,0,150,11,178,0,0,255,238,255,223,255,103,0,192,254,241,254,16,12,77,11,6,255,102,0,184,2,124,0,45,255,18,0,113,255,97,0,216,0,157,255,195,0,40,0,221,255,144,0,26,0,135,0,104,255,41,255,120,0,25,0,2,255,173,248,145,2,197,0,57,242,180,254,54,1,245,255,166,7,102,0,244,255,211,255,2,0,129,255,4,0,1,0,237,255,47,0,236,255,204,255,97,0,226,255,198,225,51,0,26,0,5,0,235,255,18,0,15,0,15,0,66,0,30,0,248,255,249,255,225,255,255,255,223,255,38,0,164,0,90,0,142,26,223,255,166,255,239,255,251,255,14,0,214,255,21,0,236,255,215,255,48,0,250,255,220,255,6,0,49,255,245,238,211,19,31,0,6,0,100,0,65,0,86,0,19,0,98,255,28,0,122,255,165,255,188,255,9,0,230,255,219,255,28,10,51,1,139,13,61,254,101,0,71,254,67,1,62,0,188,0,124,255,218,254,98,0,234,255,152,0,210,255,65,0,217,255,219,255,174,255,247,255,18,0,43,0,17,0,8,0,56,0,97,0,212,210,21,0,15,0,75,0,85,0,155,0,15,0,32,0,0,0,20,0,211,255,244,28,48,0,3,0,38,0,72,0,30,0,23,0,42,0,236,255,146,255,58,254,23,255,141,2,187,254,236,254,248,1,31,254,71,2,14,1,119,253,225,1,162,243,83,6,164,0,166,255,150,0,32,0,160,255,209,255,49,0,243,255,115,0,73,255,75,0,62,0,190,220,12,0,163,255,53,253,6,0,137,0,174,254,42,3,217,255,235,254,148,255,236,255,59,1,60,2,253,255,38,238,29,4,124,255,13,0,132,1,33,255,157,254,31,0,209,255,61,0,143,255,5,0,218,255,43,0,209,255,176,255,246,9,27,0,247,0,21,1,170,255,80,1,139,0,146,0,145,255,183,255,187,0,200,254,68,0,236,254,72,0,126,2,73,0,24,3,86,255,103,5,165,1,65,253,27,241,112,0,135,1,61,255,94,255,228,255,231,255,61,1,228,0,173,255,3,18,142,2,97,1,132,254,229,254,141,253,211,254,161,0,100,255,175,255,5,0,241,255,243,255,239,255,53,0,206,255,36,0,190,255,15,225,254,255,202,255,215,255,230,255,47,0,253,255,22,0,250,255,11,0,63,0,2,0,42,0,71,0,206,255,169,255,217,255,2,0,200,255,254,255,157,43,44,0,137,255,182,255,131,0,134,0,5,0,115,0,217,255,144,0,233,255,0,0,186,0,40,18,95,1,36,0,186,255,185,255,170,6,83,8,28,255,42,0,6,0,8,0,4,0,213,255,244,255,216,255,212,255,249,255,242,255,11,0,83,0,163,255,112,255,186,0,210,255,247,255,13,0,169,255,136,255,70,0,47,255,115,0,71,242,139,0,210,255,133,0,96,0,25,0,215,0,221,255,75,254,126,0,147,1,141,255,145,0,203,0,187,255,178,254,37,0,166,3,31,254,91,12,32,246,207,255,57,0,100,0,76,0,82,0,251,0,32,1,142,255,46,0,55,255,95,255,95,255,52,253,16,240,122,1,194,252,2,255,12,0,194,247,212,254,78,0,32,1,48,0,166,255,157,255,225,255,146,255,201,0,66,0,71,1,119,0,76,255,148,0,121,2,71,0,252,239,33,0,57,0,247,255,208,255,151,0,236,255,72,0,71,0,245,255,39,0,189,255,176,0,27,0,143,0,198,0,127,1,155,0,110,12,128,255,104,255,119,243,84,255,250,254,243,255,129,0,89,255,128,255,55,0,46,0,219,255,70,0,107,0,7,0,233,255,222,247,241,0,236,0,209,255,171,255,105,0,209,255,54,255,208,0,201,0,30,0,150,255,242,255,218,255,14,0,211,255,24,0,232,255,51,47,22,0,151,0,198,255,247,255,59,0,170,0,113,0,174,255,113,1,101,255,53,0,97,0,71,255,199,255,203,0,55,1,236,0,181,18,232,255,177,253,73,250,118,0,94,0,238,254,116,12,111,255,106,254,183,0,0,0,202,255,17,0,234,255,37,0,201,255,222,255,63,0,172,254,175,0,212,254,106,0,66,255,218,255,67,0,254,255,19,0,210,255,214,255,11,0,223,255,223,255,228,255,246,255,229,255,237,219,29,0,62,0,97,252,5,5,49,0,72,0,65,0,89,0,57,0,212,255,247,255,241,255,85,0,255,255,74,0,81,0,133,255,160,0,69,0,13,245,234,255,47,0,45,254,182,255,236,2,168,0,247,255,235,0,173,243,102,255,48,0,227,1,171,254,74,0,99,9,97,0,93,0,150,255,219,0,136,0,65,255,206,255,7,0,71,0,153,255,5,1,211,12,132,255,144,253,246,245,73,0,225,255,10,0,183,255,30,0,241,255,48,247,254,255,183,255,55,0,73,0,14,0,182,255,175,255,38,0,96,1,108,0,238,255,25,0,61,0,54,0,1,0,251,255,109,0,25,0,140,245,231,255,204,255,196,254,2,0,36,0,220,255,157,254,40,0,237,255,120,0,27,0,252,255,205,255,248,255,42,0,246,255,228,255,166,255,113,255,29,0,246,255,6,223,234,255,202,253,59,0,217,255,255,255,27,0,29,0,236,255,6,0,19,0,0,0,220,255,38,0,68,0,213,255,35,0,22,0,209,255,110,255,239,13,13,0,12,0,158,12,238,255,224,255,75,0,144,255,248,255,99,255,233,255,101,0,165,0,198,0,93,0,127,1,212,4,53,4,248,241,135,250,111,4,76,3,246,254,182,255,186,255,232,254,158,255,67,0,147,255,38,0,11,236,190,255,199,255,89,0,235,255,6,0,19,0,235,255,70,0,60,0,76,0,35,0,18,0,44,0,51,0,45,0,40,0,54,0,227,229,189,255,9,0,113,0,227,255,246,255,160,255,80,0,98,0,103,0,216,255,248,255,236,255,125,255,15,0,6,1,47,0,3,255,140,255,244,255,57,237,2,0,175,255,76,0,210,255,37,0,97,1,126,255,65,255,129,255,246,255,221,255,91,0,134,255,173,0,91,255,248,255,181,196,86,0,70,255,123,0,217,254,231,255,21,0,63,0,163,255,218,2,20,0,136,255,240,237,84,1,3,255,39,254,44,0,238,255,157,255,219,255,202,255,195,254,65,0,204,255,119,8,68,0,11,255,224,0,117,0,76,255,169,237,236,254,118,0,142,0,155,255,202,0,211,254,223,255,127,255,209,254,166,255,181,255,50,0,98,0,200,255,188,255,103,255,218,255,168,0,234,254,234,255,192,255,29,38,165,255,233,255,4,5,53,0,56,0,245,255,210,255,147,249,11,0,15,0,12,0,8,0,216,255,254,255,84,0,200,255,17,0,249,255,226,255,86,240,27,242,4,255,56,0,177,255,169,255,249,255,8,0,79,0,16,0,21,0,51,0,193,255,234,255,118,0,228,0,11,250,178,255,234,255,254,255,16,0,207,255,17,0,219,255,253,255,242,255,10,0,31,0,17,0,145,255,32,0,112,255,228,241,145,13,79,0,23,0,167,255,74,0,33,0,227,255,11,0,214,255,214,255,127,255,215,255,155,0,52,0,31,0,94,255,65,49,147,0,17,0,68,0,2,0,15,0,244,255,217,255,50,0,148,255,190,255,121,0,69,0,229,255,94,0,241,255,229,225,115,0,30,0,220,255,229,255,234,255,213,255,2,0,5,0,31,0,255,255,87,0,2,0,41,0,21,0,14,1,16,0,163,14,251,252,211,11,224,0,92,0,88,255,249,255,194,255,177,255,212,255,247,255,252,255,198,255,178,255,39,4,203,0,254,255,76,0,33,1,220,255,92,0,227,255,178,255,108,255,200,235,137,0,219,0,43,1,89,0,23,255,62,0,127,255,33,0,123,0,226,255,197,0,178,15,219,255,218,255,139,0,41,0,153,0,71,0,230,255,27,0,53,0,72,0,30,13,188,255,134,255,37,1,237,255,157,254,104,0,34,0,49,12,16,0,29,0,168,254,37,0,174,0,228,255,213,255,154,255,197,255,131,249,14,0,5,0,194,255,255,255,14,0,15,0,214,255,4,0,225,255,254,255,13,0,23,0,189,3,93,254,20,0,31,0,242,255,51,0,24,0,210,255,8,0,240,255,27,0,181,255,229,255,223,255,228,255,18,0,189,255,104,255,208,255,47,0,90,0,48,0,182,255,153,255,238,255,255,18,3,0,132,0,158,1,170,255,196,255,29,1,16,0,32,0,212,255,0,0,22,0,93,255,23,0,253,255,23,0,195,255,168,51,52,0,117,255,243,255,171,0,215,0,205,255,235,255,208,255,33,0,246,255,239,255,235,255,18,226,199,255,212,255,205,255,35,0,35,0,34,0,105,0,178,0,179,255,77,0,147,0,67,0,208,252,97,11,241,243,4,2,144,255,216,254,21,0,133,0,211,0,162,0,87,0,231,255,233,253,194,252,244,255,46,0,197,255,246,255,252,255,42,0,0,0,165,255,247,255,47,0,166,255,227,255,74,0,66,1,150,255,83,0,44,0,85,18,236,252,183,255,171,255,151,255,180,255,249,251,34,0,6,0,78,0,222,255,160,0,208,255,61,253,244,255,247,255,39,0,14,0,23,0,88,0,18,247,21,0,231,255,42,0,130,0,39,0,251,0,16,0,206,255,141,1,30,255,246,245,88,0,127,255,165,254,159,0,92,0,0,0,212,255,207,255,235,0,60,255,232,255,220,255,113,0,75,52,45,0,22,0,54,0,236,255,29,0,27,0,229,255,54,0,38,0,193,255,244,255,182,255,45,0,248,255,141,255,79,2,46,0,5,0,22,255,57,0,124,0,86,0,46,241,205,255,36,1,96,255,104,255,96,0,178,254,92,1,96,0,70,255,226,240,125,241,54,0,0,0,227,255,191,255,188,255,6,0,132,0,47,0,101,255,62,0,26,0,66,0,246,255,210,255,235,243,66,0,49,14,183,0,85,255,124,255,232,255,154,0,157,0,129,0,71,255,12,0,230,255,96,0,244,255,88,0,222,255,42,0,241,255,37,0,31,230,229,255,13,0,41,0,226,255,62,0,142,0,163,255,88,255,84,0,234,255,139,0,237,255,18,0,94,41,145,255,36,0,13,0,212,255,4,0,211,255,253,255,253,255,28,0,231,255,252,255,115,0,119,0,207,255,41,0,33,0,87,0,171,255,156,48,73,0,71,0,145,255,61,0,241,255,117,0,23,0,232,255,251,255,131,0,225,255,255,255,234,255,199,255,244,255,50,0,35,0,237,249,236,255,38,0,82,0,204,255,27,0,128,255,230,200,40,3,190,0,89,0,83,2,63,0,221,254,26,1,208,255,32,0,62,253,79,254,95,253,213,12,31,5,62,3,161,14,52,255,95,251,184,253,205,255,184,3,237,3,202,253,228,6,186,0,187,4,17,254,144,255,189,4,192,0,16,9,213,255,226,255,24,0,128,251,2,0,2,0,32,0,201,255,231,255,254,255,239,255,242,255,250,255,22,0,202,255,32,0,45,0,10,0,171,255,230,255,240,255,190,255,196,255,46,255,152,255,208,0,8,255,62,0,228,255,40,199,245,255,212,255,65,6,47,0,118,255,46,0,221,255,87,10,175,255,253,255,218,255,190,255,197,255,223,255,237,255,43,0,239,255,177,255,53,0,29,7,220,249,22,10,85,0,48,0,116,255,78,0,101,255,83,255,96,0,224,255,121,0,198,255,201,0,82,255,202,255,74,0,118,246,230,254,253,252,37,0,142,244,15,0,226,6,154,0,7,1,241,255,237,255,139,0,246,0,13,255,225,255,84,0,145,0,8,0,152,0,43,0,128,0,167,2,36,7,148,13,17,0,92,0,102,0,2,1,227,255,237,254,217,255,69,255,88,0,70,0,28,0,2,0,95,8,18,1,202,0,189,255,243,255,234,255,68,0,221,255,135,0,114,0,108,0,27,0,1,0,16,212,156,255,14,0,26,0,59,0,10,0,232,255,30,0,1,0,218,255,247,255,21,0,18,0,255,255,237,7,173,255,170,254,115,13,231,255,7,0,0,0,54,0,78,0,198,0,45,0,233,0,250,255,0,0,147,255,84,255,54,247,41,0,177,255,4,11,44,0,216,0,39,0,59,0,215,255,52,0,79,0,204,255,12,0,23,0,184,255,131,255,83,0,17,0,228,255,224,255,13,0,2,0,28,0,0,0,230,255,75,0,175,255,66,0,25,0,175,255,116,25,9,0,163,255,49,0,60,240,76,246,214,255,185,255,178,0,99,0,123,255,79,0,215,255,144,255,57,0,66,0,228,255,13,0,39,0,64,0,133,255,102,12,245,11,3,1,55,0,123,0,133,255,246,0,118,255,139,0,75,0,31,0,41,255,102,255,38,255,26,0,16,0,21,0,126,0,26,0,223,255,246,255,241,255,16,0,236,255,203,255,21,0,166,60,221,255,197,255,206,255,245,255,198,255,67,0,245,255,107,0,232,255,219,255,219,31,31,0,145,255,194,255,138,0,196,255,246,255,84,0,128,255,37,0,24,0,211,255,246,255,129,0,188,255,219,255,42,0,176,255,51,255,177,255,106,23,163,255,242,254,112,254,20,0,167,255,217,255,56,255,230,0,197,0,69,1,207,254,218,254,94,0,135,12,128,0,47,12,226,0,28,0,207,255,8,1,186,0,8,0,227,255,243,255,27,0,22,0,193,255,43,0,84,0,237,255,57,0,211,245,60,1,3,1,213,255,50,0,63,247,105,0,244,255,233,255,220,255,89,0,41,0,241,255,145,0,10,0,175,255,7,0,206,255,70,0,60,0,233,255,55,0,194,255,0,0,52,0,179,255,180,0,74,0,79,0,39,200,6,0,24,0,43,1,149,255,4,0,227,255,76,243,205,255,40,0,113,255,222,13,228,255,102,0,24,0,215,0,147,0,87,255,196,255,213,255,26,254,5,0,255,255,62,0,140,255,155,244,174,1,50,0,111,11,139,0,127,0,63,0,203,255,141,0,1,255,171,255,95,0,155,255,80,255,195,0,104,0,6,244,200,255,167,12,95,255,42,255,57,0,24,0,137,254,75,255,0,0,253,254,130,0,136,255,254,255,250,255,175,0,109,255,71,255,68,0,219,0,169,1,125,10,208,243,10,1,246,0,242,254,186,255,17,1,168,0,121,0,113,255,81,10,215,253,221,253,126,2,113,0,149,11,95,255,29,0,138,254,105,0,155,252,108,0,70,0,15,0,230,0,202,255,150,255,235,255,252,255,86,0,85,0,155,0,136,255,239,255,235,255,26,246,57,0,149,0,127,255,21,0,87,255,15,247,129,255,237,255,230,255,3,0,60,0,35,0,1,0,228,255,249,255,36,0,76,255,243,255,87,0,188,255,56,0,80,0,64,0,248,255,183,255,35,26,224,255,47,0,48,0,250,255,61,0,36,0,248,255,215,255,255,255,13,0,68,0,140,0,205,255,25,0,12,0,3,0,57,0,202,255,223,255,237,255,12,0,28,0,196,255,200,255,161,246,242,255,127,0,143,7,84,0,127,0,63,255,253,255,235,12,200,255,15,0,31,0,140,255,69,255,236,0,223,254,5,1,69,0,144,0,187,6,79,0,188,255,102,0,215,2,69,0,142,2,196,255,21,0,124,0,169,13,248,0,84,253,189,5,112,1,2,255,45,255,216,245,3,3,118,255,112,1,17,12,52,0,50,255,147,0,200,0,241,255,120,255,194,0,92,255,160,254,104,255,250,236,5,0,191,0,253,255,159,255,28,0,215,255,107,0,2,0,11,0,60,0,180,255,221,255,214,255,129,0,179,255,206,245,217,254,38,255,143,254,10,0,253,0,15,0,131,255,74,0,169,255,186,255,38,13,115,0,240,0,150,255,163,255,121,0,10,0,36,0,9,0,238,255,190,255,179,255,7,0,37,0,180,255,234,255,97,11,242,0,22,0,172,0,102,0,186,0,25,255,90,0,245,255,199,255,45,0,246,255,212,255,172,255,44,0,139,255,213,255,49,0,209,21,18,0,90,255,213,255,64,0,28,0,247,255,26,0,96,255,31,0,228,255,29,0,56,0,29,0,199,255,109,0,231,255,68,12,125,255,57,0,236,255,27,0,229,255,251,255,214,255,204,255,18,0,23,0,200,255,218,255,242,255,213,0,223,255,170,255,123,237,105,255,210,255,1,0,239,255,46,0,7,0,243,255,0,0,50,0,28,0,199,255,133,227,236,255,12,0,66,0,214,0,119,2,225,11,191,4,72,9,205,248,153,255,238,2,144,0,169,255,7,255,203,2,55,255,246,2,202,0,59,255,121,255,245,253,219,4,201,1,51,253,68,253,126,6,150,3,208,255,16,252,180,0,155,1,180,3,144,8,47,10,198,252,62,252,150,251,197,255,233,251,207,254,187,254,248,251,48,8,225,254,139,1,249,249,244,254,62,251,3,248,118,249,183,3,202,248,132,253,7,1,118,255,225,254,185,254,96,247,104,253,240,1,131,8,109,6,84,1,167,253,217,1,158,2,182,3,214,10,108,1,101,2,152,248,172,248,151,243,151,255,250,1,92,255,25,1,206,2,115,9,203,251,206,255,109,1,161,249,122,255,128,254,231,0,255,2,227,254,244,4,65,1,128,250,217,0,103,254,43,253,201,4,9,246,194,245,238,254,217,1,192,10,245,255,86,1,17,254,91,6,79,0,240,0,2,0,3,252,128,2,4,254,243,254,136,2,140,255,253,250,39,255,13,0,118,249,98,9,145,252,255,6,193,10,82,9,171,4,68,253,230,254,84,254,97,253,164,255,163,4,96,253,13,4,135,248,246,0,208,252,187,255,20,247,56,253,28,252,194,9,134,3,41,3,107,255,66,0,7,3,212,255,202,253,187,3,207,251,98,250,130,252,46,252,18,1,122,254,152,21,129,4,17,0,18,253,63,0,33,2,43,253,211,254,189,254,149], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1584325);
/* memory initializer */ allocate([2,211,252,165,254,227,2,79,1,136,0,203,0,86,1,34,3,57,255,206,252,89,253,230,254,147,8,78,249,11,253,102,255,182,0,132,0,55,249,149,1,90,9,113,241,69,5,213,0,63,255,65,246,182,250,139,253,109,251,149,5,240,255,66,3,20,251,160,0,156,248,106,3,218,6,201,253,88,1,85,242,76,6,37,252,88,254,27,252,152,249,82,2,34,4,241,252,255,1,164,253,56,250,38,249,88,254,214,8,57,248,17,5,130,253,94,1,180,253,201,255,203,5,56,254,201,253,146,0,78,252,219,2,5,6,9,253,80,2,207,4,242,254,171,0,73,248,109,245,56,254,29,255,136,1,133,252,240,3,214,251,25,254,231,0,92,5,205,255,169,253,29,255,184,2,204,252,98,1,136,7,208,255,234,250,198,253,60,1,229,254,176,252,3,10,246,254,5,11,28,2,41,2,8,251,96,4,116,251,61,254,128,1,222,251,6,252,199,6,224,3,60,251,173,255,210,5,0,9,122,0,94,6,84,4,205,7,42,9,121,253,45,1,46,249,38,255,57,1,206,1,206,5,232,253,4,254,49,254,104,0,162,3,93,2,68,8,25,3,65,11,44,253,157,250,203,255,106,17,25,3,19,1,76,255,252,253,23,254,250,252,247,254,192,2,112,0,175,0,112,0,135,255,140,2,54,1,52,2,72,254,5,3,93,7,159,3,96,253,251,252,190,6,154,253,50,3,53,6,140,254,49,255,243,1,130,252,219,3,28,3,140,2,52,251,86,240,96,247,202,1,133,2,242,1,233,254,172,252,151,248,228,248,221,255,162,2,201,0,218,1,77,0,94,0,23,9,211,2,199,251,5,1,209,0,155,4,105,251,111,2,243,250,106,8,139,255,133,241,172,3,45,3,221,251,177,254,26,5,13,2,65,255,238,247,87,254,19,0,146,254,17,2,111,255,54,3,111,252,254,0,168,1,158,254,89,255,123,246,103,250,91,2,194,254,19,250,154,16,29,2,176,250,194,1,237,253,200,0,22,2,176,4,34,255,233,253,94,255,69,251,140,255,112,255,50,254,117,255,30,254,255,1,20,8,204,247,203,3,49,250,230,251,178,243,67,253,119,0,16,0,255,5,16,1,96,251,194,8,232,1,20,254,109,252,124,6,212,0,198,252,68,254,235,3,145,10,7,14,82,255,179,254,81,254,197,255,121,252,61,0,239,2,63,4,211,255,249,251,105,2,174,2,241,255,80,3,164,254,179,3,140,1,163,3,249,6,216,253,104,252,99,253,193,255,179,248,53,9,243,249,39,3,121,3,211,249,209,251,51,6,172,251,20,5,110,253,143,253,44,1,227,254,47,252,120,6,87,16,207,5,65,255,146,2,212,254,241,1,98,5,212,254,7,4,66,1,114,0,63,254,154,2,226,4,8,1,125,0,147,255,236,2,9,254,216,255,199,0,68,251,149,249,38,246,151,0,121,0,152,251,128,243,108,3,66,254,110,3,35,252,230,5,213,8,29,250,1,7,110,254,30,0,228,0,206,255,217,3,224,249,243,2,23,6,80,253,62,5,89,254,29,250,96,0,11,254,218,1,146,244,67,246,125,255,112,253,194,1,11,4,44,3,242,255,91,252,173,3,116,5,67,252,147,253,252,253,123,1,31,255,241,247,0,248,157,2,31,1,152,6,191,6,43,1,110,253,84,3,233,2,252,254,225,3,158,0,44,251,114,250,33,0,99,2,144,255,189,254,62,255,71,3,129,250,31,250,38,248,243,4,157,254,93,253,61,241,0,3,28,255,125,253,149,2,33,5,239,253,194,3,76,252,44,255,19,4,24,6,82,255,208,6,86,252,33,1,150,7,76,247,116,248,32,4,178,253,84,252,154,3,89,2,171,252,233,252,131,253,254,255,204,255,173,255,47,255,142,5,88,3,139,251,196,9,85,251,5,3,63,4,147,250,153,1,183,1,166,241,197,1,101,6,241,255,245,3,75,10,250,5,176,251,184,1,127,3,46,255,94,4,250,255,45,0,65,0,170,251,21,243,181,254,222,1,101,255,102,254,47,253,46,251,129,0,53,252,163,251,229,255,148,251,247,250,96,7,168,251,203,0,189,251,186,1,97,247,245,1,169,254,212,1,204,255,129,1,13,1,226,243,146,254,43,254,135,1,249,1,176,0,100,1,187,255,95,252,131,4,232,254,16,251,127,252,238,3,18,254,155,0,36,0,141,253,156,3,208,252,154,0,18,253,187,252,143,20,181,251,91,0,31,254,71,0,87,253,194,253,205,4,163,2,193,4,49,4,73,253,18,1,131,254,116,255,92,5,244,253,140,4,85,1,107,255,168,252,25,3,242,250,213,3,63,252,115,1,154,4,183,5,117,1,95,5,224,238,239,0,136,0,67,0,84,251,130,255,23,252,28,255,150,0,181,1,218,248,221,1,242,1,150,16,25,3,107,253,4,1,238,248,125,5,76,0,134,3,180,252,140,3,38,7,27,0,132,255,1,1,253,2,158,255,80,2,231,1,124,255,202,0,163,2,99,253,89,253,29,5,94,240,50,255,190,255,122,254,3,255,66,255,103,252,173,255,131,5,95,254,0,246,122,253,61,7,108,255,36,2,142,254,45,253,191,3,118,252,14,244,236,254,211,1,0,251,202,3,175,2,228,1,250,1,119,4,27,250,60,3,135,247,115,11,42,5,189,253,9,4,209,0,45,252,217,0,78,254,98,250,58,1,80,9,118,252,227,255,58,250,225,255,62,2,139,254,198,5,132,255,88,253,74,1,26,3,15,253,47,252,127,4,90,251,57,250,126,253,122,6,103,247,67,250,53,6,75,2,52,0,18,5,44,8,53,250,166,2,196,7,150,3,120,253,72,1,48,8,190,251,105,8,120,250,39,1,25,2,5,1,142,1,147,250,113,254,81,4,10,0,117,254,145,4,81,254,89,254,175,249,254,2,148,248,123,243,131,0,22,253,172,252,167,8,195,254,24,255,55,4,37,1,41,253,50,0,66,254,55,253,127,252,0,3,128,252,101,253,231,254,121,1,115,0,159,6,250,236,201,2,119,254,251,0,244,4,221,1,15,254,38,1,18,0,153,254,44,2,52,1,16,253,161,252,40,255,151,0,93,255,183,2,75,2,42,3,59,8,149,255,153,3,179,4,40,254,0,5,116,1,110,0,187,253,31,255,54,253,198,255,229,245,68,248,70,255,140,254,126,250,32,250,4,252,23,253,168,255,69,9,200,253,231,244,7,248,207,248,17,8,133,1,82,254,139,4,48,255,57,2,119,1,138,2,61,1,90,4,244,251,65,252,128,252,36,4,246,3,169,253,49,249,97,4,40,3,20,6,70,1,196,244,236,249,253,250,128,1,178,251,122,1,153,5,190,2,174,5,37,251,43,253,224,0,158,253,57,254,133,5,45,249,44,246,196,253,81,250,199,254,231,0,12,3,251,5,85,246,222,255,153,3,142,249,13,1,50,3,5,0,67,3,47,255,113,252,80,254,176,251,165,0,154,249,210,255,17,248,67,254,28,5,239,5,56,248,70,6,188,3,245,2,115,4,116,0,61,3,160,250,209,0,131,252,195,3,199,253,46,254,71,255,191,250,244,5,178,6,13,1,219,0,95,255,226,1,102,251,219,241,193,252,100,253,79,7,239,253,41,252,46,2,206,252,81,0,43,2,33,0,39,254,69,255,113,0,131,3,191,253,187,251,128,5,134,3,254,254,145,255,120,253,244,16,244,252,117,253,21,3,164,255,6,9,111,254,157,2,43,255,113,1,152,255,204,252,222,254,48,0,107,252,71,0,46,4,17,255,24,253,123,3,23,0,246,235,7,253,56,1,63,1,74,3,24,1,78,0,107,255,96,1,174,253,151,254,98,1,118,252,42,0,182,249,67,3,157,0,137,253,76,4,215,254,57,4,160,255,228,1,199,252,172,247,37,2,25,5,128,0,198,254,59,249,247,254,5,5,35,240,164,254,120,255,84,252,5,254,24,255,25,250,148,252,78,0,72,8,175,0,168,8,155,4,241,1,79,1,94,1,238,255,229,250,125,254,97,247,75,2,137,12,142,254,131,4,221,5,105,249,228,252,119,250,35,253,243,254,33,3,83,0,149,4,206,2,114,245,19,0,197,254,149,17,1,4,147,254,92,1,95,254,2,254,84,255,79,251,198,5,159,2,141,7,223,6,164,2,160,1,30,0,144,1,19,2,95,1,104,251,9,245,177,7,138,250,135,4,200,253,242,2,107,255,168,248,238,254,77,251,213,255,111,5,127,1,190,2,68,8,19,5,160,7,134,2,49,253,199,6,38,252,100,0,68,252,16,4,239,8,186,249,100,2,224,6,221,2,107,246,19,2,242,255,255,255,114,243,55,248,115,1,227,0,45,0,219,7,237,253,65,4,251,251,26,1,134,246,243,253,221,3,43,254,29,1,251,6,159,3,177,254,103,4,207,254,119,4,100,254,166,249,223,6,249,245,174,255,146,4,21,244,242,4,242,5,132,255,113,248,40,2,98,4,205,255,91,1,94,253,152,254,159,4,223,0,199,11,187,3,198,252,84,4,21,9,100,3,128,4,55,4,223,0,217,0,84,254,126,1,130,2,223,244,1,253,186,255,151,1,147,0,120,254,105,254,201,255,4,254,249,6,85,253,139,252,83,3,39,15,215,1,94,253,25,255,213,5,85,6,94,249,16,2,111,2,44,1,87,5,180,253,48,3,232,255,88,2,74,255,183,252,86,3,114,1,203,2,116,0,202,2,228,250,155,5,10,7,189,245,210,252,107,1,194,254,183,255,82,3,48,249,205,9,209,254,53,4,148,2,97,8,82,8,38,253,168,255,141,255,251,253,102,255,160,0,175,254,27,0,222,5,253,1,186,255,246,1,52,3,203,254,100,241,242,250,158,253,241,0,106,253,244,253,39,5,200,1,158,3,190,3,145,255,20,252,3,7,164,253,62,4,206,1,129,255,131,255,8,1,187,251,147,5,78,1,70,3,187,7,192,253,236,11,250,241,71,6,100,1,216,2,83,6,112,254,23,1,58,2,78,254,9,3,88,250,136,252,156,0,235,254,7,250,98,4,187,8,230,252,89,13,194,252,174,255,104,253,211,248,178,3,142,254,154,5,206,255,230,2,192,246,158,5,240,4,148,4,198,250,148,255,30,255,66,252,174,247,254,255,149,3,128,3,27,6,133,8,124,10,39,9,237,0,105,254,131,245,167,5,4,4,40,253,109,0,148,253,222,1,46,0,226,253,235,252,145,252,74,254,220,4,51,4,62,249,119,0,74,253,137,0,5,224,90,0,74,253,88,255,60,254,252,255,253,254,180,254,96,1,214,253,43,0,133,1,236,0,252,1,81,255,205,1,235,254,118,0,139,2,11,255,184,2,113,250,112,1,119,250,246,6,114,6,228,253,27,0,51,254,4,2,169,253,71,255,166,1,245,255,75,255,19,0,17,7,102,243,185,252,65,255,212,1,180,0,218,253,198,0,183,9,101,252,201,250,16,252,5,4,180,6,76,2,115,1,134,3,66,251,179,0,2,4,24,6,23,7,78,249,206,4,56,253,139,6,75,7,102,255,212,244,28,254,241,8,6,252,33,0,42,250,102,2,220,246,44,253,192,251,118,248,249,252,148,252,130,2,178,250,112,255,42,246,62,0,31,2,231,251,199,251,160,2,25,5,30,250,170,255,104,11,6,2,212,248,222,253,124,255,211,255,126,253,125,1,108,254,98,247,69,251,186,2,65,253,101,253,162,253,91,253,58,247,14,2,123,251,177,0,254,1,116,250,151,253,229,248,174,6,95,6,25,4,95,249,17,254,193,3,30,251,39,0,226,1,189,1,68,252,185,255,209,3,170,1,34,7,30,1,36,0,39,1,250,6,26,3,128,242,109,6,2,253,212,249,125,246,84,4,226,254,219,2,109,253,192,3,33,249,46,252,60,1,162,254,91,0,221,255,34,255,119,250,203,255,239,253,89,253,169,2,164,237,244,253,217,255,162,254,196,0,199,0,191,0,141,2,64,5,82,252,84,254,156,0,173,0,124,2,254,249,3,7,173,6,66,255,241,4,164,0,138,2,254,8,35,249,226,6,157,1,173,252,44,0,165,250,87,1,251,240,134,255,72,7,23,254,89,2,20,253,110,254,78,2,132,255,60,248,0,250,25,252,143,1,15,253,39,1,128,254,220,250,55,0,99,253,6,1,123,251,74,241,224,3,145,255,144,244,112,250,158,255,194,255,178,254,200,248,121,1,24,6,179,3,32,6,18,6,206,0,152,2,222,7,50,8,92,255,128,253,175,244,121,253,117,249,253,246,2,255,213,253,134,246,217,5,209,1,11,250,132,251,55,0,120,2,42,2,20,8,195,1,4,250,53,253,239,247,103,251,145,253,222,1,168,255,140,251,184,255,62,254,8,255,169,251,6,255,76,5,157,10,207,248,164,1,237,250,77,249,234,2,155,255,88,2,106,4,121,252,39,254,201,4,148,252,193,0,182,2,63,255,30,254,210,248,94,0,157,0,107,4,11,1,14,255,229,7,217,255,27,3,227,254,182,1,30,239,73,4,147,253,250,253,174,254,223,254,142,255,97,253,164,6,35,254,193,1,128,249,75,253,123,5,211,241,200,5,33,252,22,255,43,255,98,1,243,254,140,251,216,255,175,5,10,253,249,4,241,1,82,253,79,252,59,0,190,255,255,252,142,244,39,9,148,9,216,249,227,3,34,253,241,3,98,0,162,254,164,251,33,2,189,0,99,0,54,2,108,252,20,0,117,0,217,252,218,3,84,254,177,0,223,4,229,1,88,253,115,4,17,251,0,255,220,18,89,0,27,0,197,250,189,251,149,0,127,253,65,253,198,253,144,255,90,1,163,255,127,253,159,255,33,252,57,247,236,8,79,3,62,8,143,250,197,254,68,250,2,2,43,250,210,255,111,4,49,251,39,0,111,252,234,254,6,253,239,6,84,253,223,2,116,249,130,1,18,248,230,9,189,246,131,249,180,4,145,255,248,255,161,253,209,4,4,250,17,251,250,5,231,253,64,249,177,254,13,1,154,253,12,0,93,251,254,252,215,1,117,1,135,18,12,0,197,0,98,2,155,255,161,1,162,254,39,2,32,2,126,252,131,1,86,253,64,251,126,0,96,0,94,0,244,254,23,2,126,0,246,252,59,6,157,250,38,13,49,0,204,1,236,6,198,0,128,252,75,0,253,0,160,250,68,0,70,3,159,251,190,253,138,253,50,253,49,252,203,253,23,5,98,1,255,252,218,255,10,255,63,255,104,254,41,0,165,0,118,1,169,255,101,255,248,255,22,253,82,254,155,252,206,248,127,254,25,1,255,19,176,1,95,4,217,252,220,6,48,3,131,0,220,253,240,253,67,5,222,1,202,5,126,11,222,254,138,2,244,3,163,0,72,3,220,252,94,0,203,9,234,5,71,252,223,254,23,0,104,4,129,252,15,252,79,7,142,254,187,2,147,2,3,244,73,253,233,249,155,5,160,2,94,0,216,5,131,253,96,247,59,4,176,2,229,1,251,0,196,252,33,5,235,255,100,248,230,0,165,253,15,3,195,252,12,2,138,251,251,240,153,250,67,1,15,5,220,2,247,2,79,2,68,0,179,248,12,253,191,6,83,1,227,249,2,254,63,10,102,1,255,11,25,1,234,252,105,4,243,0,180,253,81,254,236,1,116,1,96,0,122,3,89,252,41,253,20,255,96,254,171,0,226,0,190,251,233,4,217,251,209,254,207,252,30,250,77,252,234,8,109,253,106,254,79,0,4,3,208,252,206,245,246,248,5,252,208,252,162,248,230,250,85,5,112,2,246,246,199,255,244,3,215,0,126,255,76,13,160,252,191,3,202,0,230,255,9,252,68,251,222,255,104,254,166,13,228,254,77,3,19,1,19,252,202,1,72,3,46,247,243,255,127,255,232,9,245,4,192,4,23,8,13,255,112,2,72,2,144,8,208,2,92,2,139,250,254,2,216,3,230,251,157,0,10,255,182,1,240,0,181,253,227,4,119,253,234,255,33,0,186,22,96,2,28,252,218,1,245,253,58,254,228,4,233,252,119,2,47,254,151,2,196,1,1,7,85,3,39,0,148,14,246,2,207,250,11,0,169,8,120,255,228,253,55,5,65,0,1,248,175,3,189,2,94,7,37,8,134,252,240,255,72,255,69,1,203,251,241,254,34,251,135,1,106,249,117,253,179,255,63,1,36,1,96,255,180,4,69,4,8,3,202,254,232,5,84,251,149,0,46,0,81,2,202,6,202,253,97,0,173,241,27,254,85,253,135,255,40,255,107,255,168,254,150,1,35,252,201,254,127,1,211,3,196,252,138,1,234,255,233,235,168,250,238,255,79,254,103,1,95,2,228,3,136,251,27,255,85,5,37,251,157,1,177,253,147,253,35,3,76,5,143,253,125,4,22,255,182,0,251,250,73,246,103,1,80,10,110,250,190,255,80,253,237,0,27,5,151,254,108,0,207,0,2,4,12,254,124,251,237,251,112,247,72,247,254,6,111,4,206,6,214,5,124,251,70,253,216,9,220,245,148,253,175,1,236,2,88,0,144,3,64,3,98,4,29,254,45,7,29,7,198,252,88,4,88,254,206,254,18,253,61,4,4,1,152,0,142,255,215,251,90,238,212,254,48,252,143,0,172,5,115,5,141,6,59,0,205,255,208,251,100,3,85,255,230,255,110,252,147,255,140,246,208,255,69,0,26,255,118,2,246,253,226,8,241,4,180,249,10,10,68,3,6,248,126,248,154,11,7,3,192,254,74,246,137,244,41,2,178,0,226,3,226,251,215,250,187,2,237,2,234,3,1,2,74,2,14,6,35,0,142,2,29,252,207,6,231,251,107,254,153,242,151,7,188,2,43,2,111,0,189,255,239,3,111,0,199,255,149,2,148,1,140,253,169,1,137,8,92,3,252,253,245,253,196,1,238,0,14,249,134,254,47,253,107,247,218,0,96,3,249,251,192,252,135,0,17,246,65,254,21,3,93,4,45,250,120,0,14,5,66,253,115,2,100,254,122,252,148,1,205,248,238,252,171,253,132,3,171,7,22,0,181,252,144,4,235,251,227,252,252,2,89,254,73,1,4,9,98,248,75,1,190,251,94,246,29,254,231,7,221,242,78,8,239,1,252,10,130,7,48,250,239,251,226,252,135,0,152,1,33,0,51,2,53,5,220,255,123,247,237,252,197,2,31,1,53,252,93,0,53,254,49,252,108,9,24,1,251,9,32,0,169,8,223,248,138,2,57,1,73,2,77,252,146,4,45,0,84,4,77,254,68,4,220,0,101,255,0,2,204,1,211,0,25,255,141,253,188,252,99,247,75,255,143,255,130,0,226,0,191,254,3,253,209,250,90,251,92,253,155,254,179,2,232,0,147,254,230,248,65,244,162,8,229,3,89,2,108,8,242,252,90,6,199,251,207,255,152,253,173,2,244,255,40,0,152,13,51,2,3,2,245,0,51,0,34,1,203,4,171,0,202,251,8,2,29,254,24,1,19,250,205,250,84,8,104,251,155,250,246,249,156,5,172,252,7,254,160,2,217,252,111,2,12,255,131,255,90,248,4,2,30,3,161,4,154,3,185,1,139,2,158,253,106,250,161,248,114,0,155,252,24,248,165,249,28,247,216,7,56,251,125,0,159,253,115,1,176,251,6,254,82,252,144,253,34,254,197,0,141,0,14,255,229,251,252,5,11,251,154,2,225,251,153,6,188,1,184,6,16,0,45,1,249,246,172,4,84,4,18,5,204,253,83,251,190,248,183,1,58,255,68,1,164,248,121,12,233,8,201,0,75,2,20,248,177,7,193,251,160,254,169,255,136,253,144,0,165,0,68,0,126,4,173,0,222,1,187,252,42,254,48,254,61,255,51,255,63,8,15,0,131,2,59,254,173,254,152,251,168,250,158,4,54,3,142,2,229,246,124,249,41,255,90,253,100,246,145,4,104,253,9,3,164,254,10,10,1,253,205,253,254,0,50,2,211,253,4,0,159,255,198,7,117,1,244,252,91,253,204,7,9,250,147,254,96,254,187,254,75,2,142,3,60,241,215,253,104,0,169,6,240,0,49,253,75,249,205,10,186,253,180,255,143,1,128,251,75,9,97,12,127,251,43,253,221,255,66,251,106,1,64,6,44,253,168,1,46,253,216,1,104,3,182,2,130,255,143,249,222,250,234,248,161,255,200,254,222,255,12,3,140,252,56,3,160,252,14,2,156,255,236,14,200,255,60,254,43,0,52,2,231,1,177,0,122,3,113,250,126,3,216,253,158,5,204,0,247,3,252,255,71,1,1,243,79,254,177,254,155,252,32,5,24,254,249,250,87,255,226,7,179,1,73,0,252,1,136,4,220,251,122,255,232,250,171,254,111,2,125,0,241,255,160,251,108,0,185,255,49,250,67,255,200,241,144,5,204,6,92,4,67,2,67,6,34,243,217,4,31,255,201,5,215,10,46,5,14,255,136,253,232,249,51,2,47,2,138,0,115,0,211,253,212,7,21,249,205,2,228,251,165,251,158,249,121,3,71,254,162,7,92,255,29,250,224,250,105,254,150,2,157,252,128,252,225,0,16,10,32,255,149,255,237,0,74,253,91,3,192,0,247,251,207,8,55,251,133,252,54,248,166,255,83,1,130,254,250,252,180,5,239,249,136,2,247,253,66,9,160,0,202,2,54,0,118,252,155,5,40,249,238,254,245,253,220,255,184,4,17,6,173,254,232,3,78,255,209,0,23,252,148,3,239,1,54,1,214,2,127,0,121,254,107,0,255,253,228,251,136,254,41,1,205,254,165,3,23,255,3,255,172,4,11,18,2,251,250,2,243,255,125,254,51,252,105,8,68,0,106,1,137,252,126,248,150,255,42,1,153,251,215,245,120,247,145,255,111,0,204,249,234,3,147,254,78,247,222,254,169,253,98,2,39,2,168,250,8,239,106,2,84,255,93,1,110,252,238,253,64,255,206,2,92,1,93,253,140,252,145,3,162,255,215,0,190,252,97,1,241,2,213,252,172,255,119,252,128,255,29,254,10,249,25,251,227,246,170,251,221,1,202,253,90,1,226,7,148,249,187,254,85,5,57,251,158,0,6,249,54,2,203,0,230,2,25,1,213,253,61,2,46,252,53,254,121,249,122,1,79,253,93,1,94,2,183,232,50,2,243,255,33,255,93,254,70,254,65,254,125,0,228,251,53,0,34,10,159,250,209,0,243,249,21,2,138,255,22,246,16,7,148,254,219,255,197,4,95,2,81,2,53,1,16,255,38,6,254,0,178,1,115,255,36,255,30,248,104,1,34,12,250,253,185,0,118,252,173,12,252,1,165,255,170,3,10,251,20,254,36,0,168,0,27,252,48,255,223,3,99,0,17,6,218,254,204,0,234,255,148,255,155,246,77,11,49,0,72,0,22,254,239,253,38,255,63,5,238,252,135,3,155,1,207,0,131,0,132,253,127,255,122,255,109,2,3,255,63,1,135,0,22,255,181,255,219,254,46,0,207,0,97,23,24,1,170,255,178,255,178,2,216,3,254,252,203,253,30,255,14,255,118,1,26,0,72,253,81,0,235,254,247,255,127,2,38,253,250,0,24,255,24,254,228,254,204,1,114,254,240,16,209,254,246,254,34,2,220,254,120,11,70,0,29,8,117,1,115,255,36,1,54,8,84,1,200,254,245,253,171,254,249,3,201,1,224,0,59,1,15,1,56,4,152,0,192,0,56,2,246,3,155,0,85,0,73,1,141,235,137,0,9,254,141,0,19,1,249,255,240,2,26,1,245,254,65,1,33,253,234,2,233,1,194,1,222,1,176,1,104,255,195,1,88,251,243,4,171,254,112,4,100,0,46,242,241,249,11,6,217,253,38,1,39,254,203,252,205,255,206,2,113,253,245,255,1,11,230,255,73,0,53,254,223,249,181,0,4,2,105,255,30,11,144,255,186,0,202,2,28,255,46,255,61,254,152,3,157,255,124,255,154,245,77,2,224,11,120,1,150,2,190,252,14,3,30,2,205,5,26,2,203,13,107,0,47,0,62,0,142,1,245,255,241,255,35,253,215,1,25,255,156,2,44,255,38,0,232,253,143,248,209,10,107,255,87,6,166,242,237,0,55,0,184,254,254,252,79,1,195,10,84,1,62,0,46,254,11,1,78,252,171,1,10,1,80,0,110,4,34,0,181,3,110,1,173,254,144,255,3,0,151,255,186,1,253,19,33,2,163,255,99,2,70,255,54,2,217,255,84,255,197,255,160,251,132,1,191,2,107,2,153,254,139,255,188,255,57,2,148,0,42,255,11,255,25,1,105,2,223,246,168,255,1,255,124,0,220,12,187,1,178,1,239,255,123,251,18,12,51,255,11,255,41,252,250,0,194,251,131,2,112,5,63,3,221,2,197,255,81,251,211,6,97,254,49,4,23,1,172,1,0,254,192,242,0,0,250,255,14,2,19,1,177,255,221,1,155,1,85,0,205,5,27,3,47,255,239,1,188,245,111,1,58,249,132,3,45,1,239,0,203,255,236,247,147,1,53,5,232,250,202,253,116,250,253,252,4,247,241,255,74,3,86,1,187,246,61,0,157,250,47,1,221,2,148,255,196,254,94,0,35,254,2,255,45,255,39,3,17,1,232,252,159,0,190,255,167,252,68,4,23,252,187,255,70,241,231,3,114,9,86,3,173,0,233,8,87,253,229,1,66,2,145,0,35,251,77,3,137,254,219,0,253,254,118,1,239,2,226,0,189,250,199,252,66,0,63,1,83,255,191,0,189,1,28,1,62,0,42,224,185,255,53,0,125,2,160,255,227,0,75,0,73,0,168,255,142,2,232,255,46,254,221,1,159,2,131,255,82,252,104,0,248,0,105,255,129,254,11,0,66,1,76,1,64,16,108,0,211,254,207,1,110,254,96,1,249,248,68,2,163,5,140,1,31,1,98,255,91,254,84,1,163,254,109,0,61,0,47,0,0,245,214,254,77,252,207,252,161,2,189,0,36,0,229,15,184,253,177,254,48,10,10,0,134,254,138,253,223,252,228,0,178,3,107,254,94,251,217,1,113,2,254,255,27,253,11,2,163,14,62,1,221,2,171,0,12,1,6,246,146,1,4,255,51,255,36,1,161,254,64,0,33,1,33,3,221,3,179,1,156,255,93,255,65,251,45,254,149,2,54,253,165,0,28,255,131,253,77,5,14,254,204,255,232,1,214,240,130,0,227,251,28,3,16,4,125,1,39,253,147,0,35,3,169,0,46,0,99,255,167,0,47,255,126,0,8,252,88,0,6,252,54,254,241,253,235,4,109,2,7,15,243,253,223,4,18,0,253,0,130,2,84,1,63,253,70,3,47,245,96,253,153,0,115,0,197,1,5,3,9,0,19,247,221,254,6,0,37,255,116,2,28,1,182,254,56,2,16,255,50,255,129,255,17,1,117,1,111,1,18,254,0,32,173,253,1,255,98,255,186,254,196,255,1,2,78,1,101,253,219,253,146,255,2,0,61,2,62,4,158,253,144,254,3,1,229,241,57,254,41,6,244,253,11,0,136,3,134,1,57,1,195,2,110,10,33,255,150,10,81,2,231,255,228,0,28,2,151,2,228,2,172,251,42,1,199,4,237,253,70,248,248,0,107,253,171,254,114,252,126,246,111,0,217,0,236,2,231,0,207,254,93,254,81,7,70,4,88,252,51,249,109,4,89,7,97,253,41,0,12,1,222,248,210,1,135,0,37,0,56,255,15,18,68,251,55,252,29,2,254,4,140,2,37,4,9,253,21,253,85,254,149,255,207,250,185,253,1,255,189,255,201,254,246,255,91,254,0,224,66,1,75,255,70,254,76,0,176,0,26,253,81,255,147,0,129,1,237,254,169,255,64,253,223,253,197,254,98,254,57,2,81,0,125,254,116,2,138,11,164,253,77,250,227,255,157,6,72,3,0,252,190,255,195,254,10,1,95,246,107,252,242,255,151,0,143,254,110,1,172,246,1,0,251,252,53,5,157,255,223,0,74,253,111,251,149,3,64,246,246,250,226,254,17,252,4,254,222,2,195,1,0,255,10,1,151,255,113,255,183,1,136,255,110,255,10,30,73,255,188,0,68,0,127,254,7,0,234,254,232,255,190,255,36,1,137,0,143,0,21,0,17,254,241,253,228,254,89,0,208,249,192,255,176,241,30,1,46,247,80,0,92,252,253,252,174,254,194,252,251,251,157,255,224,255,224,252,95,1,169,255,88,2,163,255,133,0,133,1,78,253,13,1,201,0,184,254,113,21,46,2,66,253,25,254,210,0,35,12,212,241,160,255,124,254,87,255,35,255,83,1,147,1,208,252,232,255,213,1,144,255,48,2,76,3,71,254,186,2,169,0,134,254,229,254,100,252,26,11,33,254,74,253,139,255,162,255,11,2,206,3,76,5,130,253,78,2,52,3,116,8,247,0,236,253,136,2,13,255,169,253,189,255,54,22,174,0,78,0,160,253,230,0,84,255,113,1,86,1,143,255,111,0,167,254,201,254,82,2,94,1,252,254,113,250,87,254,105,254,7,252,214,254,76,255,30,253,133,252,66,0,16,243,123,251,1,0,43,3,105,250,100,2,29,3,192,250,134,252,65,252,62,1,136,1,66,255,223,2,196,0,165,254,61,0,140,255,88,1,243,0,101,254,66,254,62,0,128,255,198,242,220,1,135,10,63,255,217,255,168,7,249,255,141,3,138,255,29,247,228,255,27,252,46,255,118,1,182,253,174,255,146,3,67,1,183,255,73,245,90,3,191,255,43,0,116,246,10,255,145,0,78,0,130,253,76,3,225,247,96,1,180,254,103,2,245,252,14,1,7,7,168,2,244,1,174,2,144,4,115,254,71,247,225,255,93,255,238,255,90,2,24,255,109,252,83,252,124,14,175,254,209,253,59,1,111,254,42,0,26,0,60,1,156,255,65,255,36,0,206,0,214,0,248,242,105,254,238,1,237,2,21,254,94,255,201,255,170,244,21,250,58,255,201,254,153,254,183,1,103,1,89,252,203,0,42,255,159,246,161,253,229,244,50,3,189,253,238,247,132,1,254,253,112,252,19,3,52,2,149,0,153,255,11,253,133,1,173,0,209,254,154,0,46,3,95,6,119,254,40,247,128,6,222,252,136,3,29,2,16,3,39,4,128,4,50,246,41,1,84,0,102,255,160,0,15,254,178,255,223,5,170,253,225,253,86,0,147,6,182,254,46,0,232,255,132,252,235,2,248,242,119,254,36,247,107,0,198,2,146,6,235,254,234,254,236,254,229,4,71,1,38,252,34,3,191,0,36,253,30,1,7,253,240,3,205,1,79,6,239,251,79,8,152,9,87,15,96,255,187,0,31,0,155,255,186,12,202,0,181,255,74,1,119,1,211,254,237,254,242,252,181,3,12,0,147,253,151,253,60,2,239,3,158,1,165,255,84,254,120,254,39,252,76,253,162,242,199,0,77,3,91,0,162,1,34,1,41,252,209,2,15,251,208,0,176,4,91,0,10,253,167,245,61,254,210,252,145,253,54,254,16,1,217,10,41,3,2,5,251,2,98,4,21,0,8,2,50,0,6,252,172,1,129,1,5,24,1,255,8,0,244,255,21,0,20,0,37,1,197,254,66,254,89,254,37,2,172,1,200,255,15,254,101,0,141,2,79,255,121,240,56,0,129,255,142,12,35,1,128,254,47,253,222,1,198,254,25,255,43,254,150,254,86,253,253,2,204,254,164,1,200,1,66,1,202,255,254,255,10,0,17,255,4,27,51,254,30,254,45,255,226,254,146,255,147,252,57,253,42,254,159,0,4,1,59,0,252,0,159,255,94,244,122,253,221,255,156,0,133,255,104,1,44,2,74,243,37,254,199,254,244,254,21,249,230,253,203,0,199,3,27,1,115,253,203,253,131,1,231,243,1,255,25,0,39,1,8,1,124,241,249,1,0,4,197,254,41,255,34,255,244,252,148,2,175,1,171,254,247,253,46,0,127,0,12,255,252,252,99,241,190,0,177,254,239,255,87,8,232,2,221,255,115,2,165,251,169,2,169,254,123,0,2,250,170,255,226,253,215,254,174,255,44,245,74,15,181,255,14,2,124,0,245,253,144,255,244,1,95,3,115,1,190,0,12,4,141,0,13,252,117,1,28,3,165,1,86,253,147,1,108,11,146,14,6,0,211,0,77,253,89,255,121,254,113,253,162,0,92,1,216,0,29,255,233,253,109,255,111,1,67,255,75,1,65,255,159,0,49,0,215,236,4,255,222,254,97,2,60,254,18,4,3,4,123,253,97,255,135,253,226,253,99,252,250,254,165,255,192,0,242,4,254,255,92,255,75,2,188,0,106,13,10,252,2,0,93,5,40,7,56,251,59,252,63,3,37,252,156,4,109,5,99,252,48,0,89,243,7,1,183,254,108,253,35,253,6,1,36,252,86,2,139,246,118,2,208,2,99,252,57,254,208,0,68,4,218,254,148,3,243,254,212,255,87,1,111,2,48,246,85,255,144,248,233,3,216,10,226,0,207,5,193,2,251,2,152,253,32,1,44,255,233,253,8,12,160,254,145,254,0,2,95,253,108,2,150,252,1,3,68,252,204,1,167,253,23,245,154,255,3,253,81,254,167,250,149,0,225,1,207,255,109,0,100,254,158,2,153,253,31,1,150,0,65,1,35,243,19,255,165,249,188,0,75,7,201,5,97,1,122,255,146,10,147,0,74,0,179,255,108,255,32,255,196,0,196,255,179,0,125,0,243,255,243,3,67,255,84,255,146,2,89,17,228,253,19,2,239,0,183,254,222,10,136,1,97,0,108,253,160,13,178,255,28,5,194,253,121,252,86,255,233,254,173,0,186,255,89,2,127,254,123,0,89,254,0,254,63,255,23,255,106,0,175,0,210,0,185,0,233,1,20,255,153,0,98,253,25,0,61,0,60,255,213,0,67,0,83,1,67,21,116,0,121,253,149,0,126,255,197,0,245,255,49,1,109,10,188,4,42,1,84,0,219,0,230,255,101,10,138,2,68,5,191,255,62,2,54,250,244,254,226,255,114,2,72,1,23,1,11,255,87,0,94,0,54,255,2,0,110,1,7,254,176,253,2,0,34,22,128,1,22,0,227,0,208,0,59,251,78,0,155,0,4,1,169,251,165,0,140,1,90,253,29,253,199,9,165,246,233,7,144,5,169,254,9,253,187,252,101,0,55,0,18,1,31,254,22,0,200,253,20,4,241,254,132,255,159,253,191,252,50,255,53,0,177,253,126,4,98,248,197,244,157,7,59,0,178,254,98,243,176,0,109,4,140,254,121,11,221,252,105,253,119,2,109,253,224,255,174,255,83,3,113,0,196,255,143,253,44,2,177,0,112,0,15,253,223,255,57,1,223,255,48,255,79,255,136,234,55,0,235,253,209,252,123,0,13,253,41,255,126,2,223,0,100,255,107,252,90,255,223,255,248,1,192,2,71,244,124,0,103,255,239,248,47,252,51,253,182,6,220,1,212,0,125,6,185,3,114,250,10,252,162,255,244,253,254,245,245,254,115,1,104,0,193,255,222,253,6,1,193,0,78,249,5,1,75,7,226,2,170,248,144,1,218,6,67,254,107,254,183,252,73,254,197,2,44,0,163,2,248,0,128,2,118,255,193,4,137,1,134,250,141,2,38,12,86,252,69,246,80,253,190,4,119,253,180,250,202,9,203,0,172,0,167,2,235,3,4,3,62,244,82,0,26,252,243,3,44,252,228,255,118,255,82,254,102,2,171,1,171,254,201,0,110,224,138,255,224,0,113,251,195,0,104,252,160,254,111,253,5,0,46,0,217,255,184,255,186,2,120,255,216,255,135,1,31,1,157,0,83,251,196,255,248,10,133,255,233,1,152,0,14,9,219,252,190,3,98,0,40,250,189,252,178,252,77,2,199,1,156,252,245,0,246,255,73,236,12,0,206,255,253,4,161,255,200,1,207,255,58,2,96,2,110,253,160,254,235,254,244,254,214,0,132,1,73,7,2,0,217,11,243,254,3,1,181,255,147,242,32,3,66,255,156,2,249,254,145,255,229,0,213,255,117,255,147,2,222,254,14,3,238,255,170,252,15,1,81,247,30,0,94,255,71,0,47,0,244,2,11,251,80,1,95,3,50,248,240,255,148,4,236,0,161,3,35,254,114,246,164,255,87,254,63,255,0,224,65,1,154,255,85,0,171,255,108,0,62,1,149,0,229,255,74,255,69,0,19,255,35,0,195,1,249,254,134,252,164,254,217,254,64,0,154,1,27,25,57,2,92,2,31,2,38,0,31,0,241,255,148,0,249,0,173,255,189,255,201,1,180,255,208,253,182,2,227,252,190,0,143,255,214,7,136,0,169,6,84,254,221,13,218,253,70,0,253,255,109,255,224,254,118,4,105,252,237,1,231,250,52,254,105,255,63,3,111,2,0,253,45,255,31,0,216,254,167,0,95,245,240,255,114,253,243,0,251,9,201,254,53,7,237,253,192,253,143,0,194,253,234,1,191,251,2,247,56,4,189,2,216,1,222,10,64,1,81,250,136,253,38,255,25,1,44,250,107,253,157,250,230,253,20,255,120,248,10,254,203,253,32,254,13,2,175,255,38,0,7,1,3,0,110,1,163,0,188,243,114,3,189,0,99,4,126,1,44,249,70,251,115,1,166,253,184,2,99,254,49,255,102,1,152,253,117,18,39,254,240,252,249,0,109,2,252,2,247,254,20,252,198,253,83,1,125,253,133,255,46,1,28,1,1,0,97,255,191,254,250,0,215,254,213,255,72,242,216,251,19,254,44,2,96,251,249,254,34,5,236,7,50,4,9,0,125,11,26,252,241,254,198,3,14,253,227,245,88,0,229,2,205,254,134,0,152,0,170,255,55,1,136,3,107,252,175,4,30,236,118,0,181,0,201,254,100,254,219,1,121,253,51,253,131,253,35,255,221,254,43,254,77,0,178,3,84,251,137,255,81,255,18,2,47,254,127,1,27,251,77,2,58,3,67,3,6,242,193,254,176,255,232,1,18,255,15,254,104,1,71,3,78,7,250,2,123,249,255,252,173,1,10,3,207,243,187,254,201,255,128,255,46,10,150,252,19,4,122,252,210,6,43,253,115,0,167,0,142,0,92,2,155,255,43,253,245,255,54,254,229,255,194,1,37,1,2,0,129,254,23,0,172,0,187,229,144,1,51,255,165,0,45,0,218,255,86,0,116,1,98,1,188,255,134,1,140,9,9,2,4,0,254,241,101,1,129,0,153,2,184,254,12,2,113,0,66,254,254,253,108,4,33,1,208,253,239,0,167,0,163,254,44,253,101,0,163,243,189,243,93,255,109,255,97,3,151,253,0,0,235,252,29,3,254,251,176,1,103,1,52,254,151,255,95,4,230,1,23,255,152,254,81,255,163,254,69,3,213,1,6,255,247,253,138,238,148,255,241,3,193,253,27,1,22,0,213,253,86,253,22,255,7,255,223,255,150,255,9,2,3,2,229,254,178,255,101,0,121,255,120,253,250,1,181,0,136,1,251,253,29,21,186,1,150,255,24,224,51,0,202,254,211,252,49,0,198,254,74,2,33,254,120,1,113,0,81,1,105,255,245,0,14,1,255,255,107,2,200,254,219,255,41,255,30,254,17,244,67,243,166,254,19,254,155,254,50,1,96,255,235,255,2,1,104,3,191,253,115,255,18,0,172,255,181,2,151,0,218,0,235,253,219,255,28,2,61,0,40,0,78,12,157,0,11,246,188,254,11,1,56,254,44,251,30,3,5,2,32,255,60,255,75,2,17,254,18,0,2,1,75,12,241,255,200,253,189,3,68,254,125,2,158,254,60,3,158,4,255,252,119,255,174,247,152,1,125,249,252,0,26,1,201,0,239,0,154,0,125,0,54,225,180,254,198,0,209,255,9,1,223,254,102,1,252,255,103,0,229,252,207,0,82,0,229,0,173,1,105,1,7,1,103,254,61,254,244,251,165,242,131,3,200,253,56,250,130,3,28,1,203,255,179,0,207,3,253,250,247,2,106,255,172,12,152,1,19,10,94,254,139,255,226,0,71,2,210,0,194,255,23,250,108,255,204,252,49,4,10,5,249,254,58,254,141,2,43,2,30,1,218,0,151,255,121,255,231,0,132,252,228,254,209,9,155,10,6,250,91,255,117,250,33,255,190,255,13,2,20,6,238,255,104,253,237,255,88,3,179,0,23,2,173,254,11,255,242,1,193,0,235,0,72,1,21,254,231,0,3,234,65,0,171,255,57,1,117,254,6,0,88,1,11,1,160,2,33,252,178,0,201,250,192,255,9,0,28,250,187,255,57,0,202,254,255,248,174,252,171,241,171,1,177,255,48,253,219,0,110,1,131,0,11,2,141,0,225,251,190,255,13,0,181,252,201,255,230,252,149,2,112,0,105,254,16,254,38,2,163,3,158,240,244,6,3,254,225,253,99,255,242,254,9,252,52,2,25,255,170,252,212,242,185,254,101,3,60,255,43,252,51,255,41,255,93,2,234,2,116,247,202,8,74,0,93,244,14,255,64,3,66,255,109,1,209,250,197,1,95,0,76,0,158,0,85,253,116,2,41,1,157,252,226,253,113,255,200,253,98,254,130,23,216,255,221,255,56,254,136,253,245,252,30,255,70,254,217,254,54,1,2,253,66,2,59,255,84,0,63,252,238,242,150,255,194,12,253,255,35,254,248,255,140,2,122,0,162,253,49,0,34,0,174,2,129,1,254,254,214,0,196,253,184,255,63,255,124,0,184,1,48,0,45,0,75,0,9,0,212,225,200,0,148,254,66,2,62,1,51,254,84,0,23,255,46,0,108,254,185,0,214,1,197,242,187,242,118,1,249,253,192,254,134,254,27,0,153,3,232,254,188,0,11,255,187,255,190,254,248,1,184,255,204,1,176,255,221,255,36,255,230,243,162,241,221,1,248,0,223,252,68,2,187,0,212,1,132,253,148,254,80,254,183,0,174,255,177,255,10,1,237,252,28,253,40,2,228,0,238,0,226,1,75,247,19,1,149,0,152,254,162,254,214,10,103,3,138,255,55,0,63,252,91,255,125,9,214,3,57,1,10,254,22,12,81,254,157,13,217,1,165,254,171,0,32,2,253,0,188,254,206,255,208,1,116,0,138,2,78,4,239,1,164,1,108,254,255,255,81,244,215,15,207,0,118,1,69,255,135,255,130,0,61,254,71,252,54,3,14,2,31,1,120,0,45,252,120,1,82,2,177,255,126,255,150,254,45,252,166,0,181,2,244,239,84,0,121,255,61,255,65,253,30,250,182,251,157,253,102,3,167,3,100,255,206,3,30,1,170,255,83,0,159,11,87,253,146,12,226,254,60,254,186,255,143,255,117,254,137,0,241,250,9,254,85,3,41,1,160,254,20,252,139,255,220,1,81,254,224,244,249,255,17,14,146,1,234,253,56,1,86,0,244,5,154,254,92,255,213,255,145,3,235,3,239,0,148,254,168,255,44,254,96,253,220,0,45,255,186,254,81,254,182,1,215,254,124,1,125,0,110,255,198,17,241,254,193,252,0,3,176,250,211,255,10,1,234,254,10,255,113,2,124,255,153,0,2,2,115,0,225,250,195,2,151,254,167,253,104,243,120,1,197,247,253,254,125,251,170,1,122,253,25,253,212,254,165,254,71,254,85,0,162,20,6,255,32,0,28,0,206,254,78,254,78,0,78,255,144,255,228,255,94,255,68,255,213,255,17,0,94,0,14,255,254,254,125,245,41,254,212,253,209,252,120,0,199,255,220,255,187,254,210,12,3,253,99,1,2,0,94,255,58,254,184,255,192,0,86,0,219,0,133,255,237,0,135,0,214,255,236,1,41,254,142,255,26,20,92,255,28,0,77,0,70,0,20,1,108,255,77,1,64,0,167,255,210,255,121,255,218,1,38,255,137,255,95,1,195,29,93,0,176,255,172,255,205,255,146,255,33,255,243,255,140,255,96,255,154,255,192,255,116,255,136,254,156,0,113,255,91,254,105,0,102,0,7,2,232,4,18,3,228,254,43,244,51,244,147,254,253,253,178,250,239,254,138,1,233,1,14,255,31,0,239,0,208,250,169,0,24,254,3,244,114,254,47,1,238,254,242,1,58,245,20,253,48,255,188,254,227,254,78,0,126,254,217,251,42,1,5,0,181,2,160,0,139,253,120,6,186,0,201,1,230,2,166,1,117,241,205,7,1,4,232,255,35,1,180,253,16,0,185,254,203,1,247,253,165,1,255,4,104,254,254,255,216,250,101,0,140,254,190,255,100,0,163,253,142,12,138,254,108,253,141,254,207,0,175,0,215,253,194,253,146,11,119,0,217,253,116,255,194,255,50,0,160,253,19,255,156,255,108,0,101,0,186,12,225,255,211,255,119,1,95,255,132,0,26,11,178,5,235,0,32,3,143,255,207,2,221,254,227,255,0,254,245,254,53,0,12,3,197,255,59,13,81,255,88,0,178,255,37,254,232,253,72,2,47,244,237,255,151,255,91,0,107,3,201,255,253,252,143,0,128,1,42,3,140,254,3,255,160,0,128,255,232,0,98,0,75,30,181,0,237,255,79,255,46,0,217,255,226,255,44,255,223,254,75,0,127,0,142,255,80,0,79,0,69,1,128,255,76,254,243,9,183,255,227,255,22,4,88,1,12,13,177,254,202,1,125,2,81,255,73,253,146,254,38,1,190,254,52,2,30,2,209,0,12,2,194,255,188,1,11,11,203,255,66,0,65,252,84,0,228,1,109,255,158,0,3,1,33,254,144,12,232,0,188,255,71,2,214,252,107,0,93,0,117,2,88,255,143,0,216,253,96,0,185,255,193,240,74,254,79,1,123,255,70,255,234,254,73,0,193,253,3,255,35,253,165,255,248,255,131,251,94,1,140,0,12,0,95,15,20,255,103,0,213,1,98,2,232,253,207], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1594565);
/* memory initializer */ allocate([254,40,12,13,0,74,255,82,253,125,2,13,2,71,1,102,0,207,255,62,254,240,255,32,254,233,0,174,255,124,255,117,240,170,1,245,2,54,0,152,0,67,253,1,2,26,9,148,0,242,0,173,6,162,0,88,255,146,0,0,0,123,3,124,253,109,0,219,253,104,0,206,255,19,1,63,255,201,255,112,255,139,255,31,0,22,255,68,0,7,235,72,0,54,0,54,0,119,0,116,255,192,0,30,1,214,255,234,254,60,242,231,241,180,2,146,254,241,255,87,1,139,252,245,254,38,1,125,254,41,255,173,255,43,254,22,3,85,0,172,1,155,253,114,0,122,2,23,1,198,253,104,2,211,252,139,255,1,12,49,12,51,253,56,255,29,1,219,251,212,255,177,3,130,1,90,255,238,1,8,3,36,0,231,255,68,254,252,254,151,1,45,15,25,4,68,5,185,0,198,1,120,255,29,247,40,4,241,254,196,254,133,2,230,251,227,1,174,1,32,0,57,2,92,253,177,254,184,254,90,244,142,254,50,0,189,0,155,0,34,4,137,255,105,254,202,254,205,1,221,12,164,253,195,0,48,0,68,0,196,0,194,0,35,2,46,255,17,3,129,254,102,254,244,254,107,255,192,0,168,255,243,255,20,0,176,255,230,235,170,255,145,255,40,0,220,255,118,255,12,0,239,0,220,255,172,255,0,254,149,0,19,255,96,253,149,13,138,242,174,4,220,0,146,0,21,253,242,0,48,0,110,255,60,255,177,254,247,252,107,254,108,2,172,254,145,254,123,254,148,255,229,255,72,255,24,248,6,2,241,0,152,255,161,1,180,250,87,248,134,0,149,12,89,254,30,1,196,255,146,255,200,253,14,0,76,0,112,255,159,0,192,2,102,254,30,2,213,255,223,0,105,0,102,255,115,255,172,255,124,255,241,254,21,255,227,254,8,255,224,1,174,1,153,237,25,254,170,255,226,1,80,0,46,0,17,255,163,255,141,255,202,255,255,255,7,0,97,0,244,255,151,0,76,255,159,0,193,255,65,0,41,255,54,0,80,22,70,11,141,255,20,255,113,0,231,255,211,254,62,254,236,254,178,255,197,0,201,255,234,254,1,254,163,0,114,13,114,252,182,255,31,255,153,255,63,0,52,255,213,255,130,255,178,254,223,0,192,0,125,255,202,0,173,255,136,19,190,255,185,1,33,0,0,0,140,255,237,0,18,255,219,255,189,1,208,255,7,0,193,248,126,251,5,255,139,255,71,255,125,0,85,7,119,1,132,1,120,252,202,0,137,2,120,1,97,243,129,3,101,0,131,253,120,1,16,0,1,0,77,3,218,253,158,253,132,254,173,250,69,252,71,0,23,5,40,1,248,254,184,253,247,0,175,12,98,0,11,4,98,253,160,1,40,248,64,254,200,255,87,255,5,249,242,12,152,1,237,9,191,252,254,255,87,255,72,255,193,0,193,253,175,255,154,1,219,254,34,254,21,0,194,0,223,0,145,255,40,18,60,0,98,1,175,253,131,246,97,253,150,0,162,254,151,0,64,254,251,255,130,1,71,254,131,0,173,254,87,0,47,3,23,1,51,0,131,0,56,0,134,243,86,255,197,240,215,254,14,1,21,0,41,255,7,0,205,0,207,254,141,0,65,2,83,0,223,254,10,254,190,255,160,255,177,1,150,255,83,253,62,255,174,255,33,0,98,0,59,1,2,1,107,246,115,244,96,2,160,2,152,0,87,253,12,7,182,255,53,254,89,254,114,0,97,251,156,255,226,252,101,1,177,255,166,242,92,253,68,2,155,249,6,254,50,1,181,1,233,3,219,2,139,252,4,251,185,253,153,254,138,2,15,0,67,255,190,0,86,0,39,0,205,224,123,255,68,1,174,0,22,0,86,0,112,255,131,255,213,255,175,255,207,255,68,0,39,0,52,255,97,255,221,254,39,255,188,255,8,1,193,0,150,1,247,0,27,0,240,254,88,255,24,2,148,233,115,255,38,0,18,0,249,255,2,1,145,255,125,0,220,1,148,254,5,0,72,0,148,245,59,255,163,253,97,253,174,255,201,0,16,253,227,0,240,0,89,1,245,255,118,255,39,2,161,254,28,255,42,245,124,255,91,4,242,251,238,255,23,3,192,243,81,0,219,0,101,1,243,2,67,2,26,0,199,243,114,254,49,253,193,0,239,1,34,1,157,251,86,3,131,254,233,253,33,0,232,0,36,9,31,238,162,255,255,3,139,255,39,0,202,255,15,0,95,255,164,252,64,0,47,255,171,253,159,1,121,255,105,254,44,4,126,3,240,252,108,0,11,1,82,29,140,0,67,0,198,0,74,0,52,0,124,254,72,255,232,255,202,255,232,255,172,0,172,0,206,255,72,255,143,255,164,0,128,0,217,255,252,0,90,0,100,1,199,254,166,255,199,254,157,254,183,255,19,0,139,0,141,0,134,255,25,255,60,238,99,255,29,255,47,0,231,0,91,254,60,0,176,255,221,241,156,16,158,254,69,0,148,0,80,1,190,1,73,255,86,0,248,0,35,0,73,0,120,0,157,0,156,0,221,254,245,253,35,0,248,254,106,13,189,0,239,1,197,255,21,2,169,254,214,253,58,244,97,254,17,0,180,1,40,2,16,255,118,254,7,253,43,0,2,253,46,0,161,251,2,255,4,6,195,0,214,254,191,252,45,0,163,255,61,0,40,0,85,255,167,0,82,0,107,0,16,0,40,0,90,255,210,255,120,0,71,255,13,0,151,0,215,31,21,255,92,0,233,255,214,0,206,0,4,1,93,0,163,0,78,0,184,0,196,255,244,255,85,255,13,254,105,255,37,255,11,0,35,255,221,0,181,12,136,254,201,251,31,254,251,2,255,254,136,255,246,255,34,0,128,253,85,1,119,244,16,2,55,2,96,253,177,254,81,255,195,255,69,2,252,254,135,4,222,252,46,4,12,0,168,0,1,9,35,1,203,0,241,255,199,253,175,12,77,255,108,2,83,1,224,0,198,2,96,254,0,2,170,255,59,2,183,1,89,255,59,2,184,255,112,255,236,0,130,254,11,0,12,1,80,255,120,255,175,254,220,0,64,0,85,1,105,1,134,238,25,0,129,1,197,1,103,255,89,0,196,253,245,0,59,255,33,0,75,0,76,2,51,0,57,255,182,255,107,255,224,0,210,0,81,18,26,1,20,0,209,255,129,0,221,0,184,255,27,0,76,0,93,0,75,1,215,0,251,255,236,255,74,0,176,255,169,0,126,0,216,255,119,255,232,255,91,224,233,255,165,0,15,1,147,1,222,255,237,255,34,1,57,255,242,255,205,0,145,2,45,1,139,252,153,9,83,248,38,247,20,252,32,255,214,253,182,0,36,255,45,254,157,253,244,3,134,255,231,12,183,255,51,255,93,0,221,13,217,0,33,255,55,0,53,254,29,2,30,1,210,255,128,0,98,1,137,0,56,3,199,254,32,0,45,1,139,0,20,254,170,0,136,0,221,255,16,253,5,18,194,252,222,255,41,0,88,1,23,1,131,2,118,254,51,254,163,0,182,254,199,0,41,255,83,0,72,4,101,2,39,254,48,3,206,13,210,0,252,252,167,3,237,254,168,253,171,254,90,2,104,0,170,253,39,255,235,252,132,246,102,3,161,254,218,1,50,0,65,1,108,255,143,244,25,0,121,255,210,255,11,0,202,253,15,244,104,253,188,2,212,254,0,1,64,252,94,1,32,254,158,1,175,1,24,0,205,255,28,255,151,1,142,0,191,254,60,1,222,254,149,0,56,0,172,255,153,254,138,255,172,236,138,0,117,1,207,255,142,0,71,0,93,255,243,255,233,254,38,0,135,255,35,0,209,255,186,255,213,255,116,0,3,0,97,255,245,255,97,0,140,255,194,255,156,0,51,1,83,255,126,28,113,255,32,1,222,255,159,2,101,2,16,0,16,255,27,255,98,254,18,254,213,255,87,255,170,252,80,1,33,252,207,2,159,254,93,255,18,253,125,10,21,11,210,253,129,0,28,8,209,255,129,2,219,255,163,255,226,0,187,255,86,2,228,254,127,0,106,0,86,254,213,253,77,252,229,1,54,0,153,243,110,2,171,254,224,253,22,1,51,255,79,253,135,1,238,0,9,0,152,0,23,255,120,254,28,0,36,0,118,254,221,251,132,0,177,14,32,254,87,0,112,253,24,5,222,1,240,254,65,0,109,255,91,0,8,2,128,252,166,0,62,0,226,255,228,255,194,0,30,2,3,0,113,2,3,7,29,14,73,4,6,4,138,3,144,1,133,0,129,255,219,0,190,3,93,0,222,253,66,253,121,11,244,253,242,254,1,253,64,255,213,2,127,252,125,253,198,9,141,0,133,251,1,1,23,1,214,1,71,244,152,255,79,0,252,1,194,1,9,1,235,255,182,255,75,254,135,2,61,245,105,254,208,252,108,2,24,0,25,2,100,253,92,2,104,241,103,241,238,255,227,254,127,1,112,255,101,255,52,255,40,1,113,254,105,253,100,1,148,254,73,1,182,254,251,255,204,255,168,255,215,255,228,0,235,255,211,255,120,255,232,254,147,255,170,255,57,0,91,0,44,255,158,0,150,255,166,255,0,224,70,0,1,255,78,0,248,255,167,255,146,255,198,255,104,0,205,255,218,245,155,1,162,255,201,253,209,0,48,254,139,0,22,255,176,254,242,2,95,3,143,1,89,1,117,0,149,242,37,255,113,1,59,0,187,254,135,9,108,255,6,0,208,255,84,0,242,255,71,0,94,0,10,0,6,0,73,0,106,0,22,254,56,255,186,0,89,1,248,255,99,0,153,241,221,249,44,7,199,249,87,4,140,241,214,1,250,255,145,1,74,255,137,255,182,1,249,254,228,0,17,3,151,254,200,255,20,254,209,1,77,1,61,0,53,0,234,0,233,255,169,255,39,0,105,0,114,28,59,0,209,255,199,255,179,255,211,255,84,255,12,0,179,0,122,255,37,0,99,255,237,255,50,255,9,0,162,4,248,254,88,2,94,1,118,1,115,0,201,255,215,2,92,255,193,240,33,253,74,2,232,255,145,0,238,252,138,255,175,3,2,2,140,1,107,13,221,255,83,0,38,1,107,0,16,0,204,241,163,255,104,1,205,254,151,255,84,255,204,0,64,1,108,255,154,1,175,0,79,1,0,0,78,255,12,0,94,0,209,255,165,255,207,255,97,255,101,255,191,255,239,255,97,255,196,254,64,0,155,0,252,254,81,0,98,237,106,255,140,255,180,254,128,0,163,2,151,255,33,254,51,2,155,255,101,0,133,254,33,0,37,0,1,0,106,0,151,0,69,0,140,0,250,255,182,255,157,0,131,255,136,255,223,255,78,255,226,254,60,0,98,255,43,0,133,227,217,254,188,255,222,255,188,255,198,255,8,0,176,0,214,255,44,255,176,0,235,253,194,255,229,255,167,0,35,1,59,0,55,1,22,244,40,2,19,254,49,255,16,10,33,252,137,254,154,255,44,252,106,4,203,253,57,255,47,2,146,250,84,254,150,253,70,0,75,254,11,255,148,251,234,250,59,254,83,0,222,0,237,249,78,255,140,250,104,251,28,255,218,2,207,243,195,251,84,0,186,254,71,0,71,255,197,254,121,3,35,3,162,244,231,241,129,253,57,255,187,0,137,0,146,253,217,1,121,0,181,0,85,0,139,1,11,2,77,2,71,0,191,2,123,0,105,1,47,0,93,253,43,1,66,254,51,1,79,2,13,13,64,0,14,2,251,249,206,255,167,250,189,2,112,255,184,6,55,253,50,2,41,1,146,0,222,255,35,5,188,3,249,2,97,254,225,250,125,2,17,251,184,251,127,254,156,12,117,254,61,1,158,254,9,254,255,0,242,253,245,0,86,2,85,3,243,254,146,255,74,5,77,1,110,0,87,3,238,242,123,2,124,2,107,252,191,253,4,1,147,0,17,4,249,4,129,1,162,252,215,6,181,251,80,0,108,255,120,0,138,255,189,21,28,254,182,255,70,1,35,1,234,0,215,255,212,0,192,0,207,0,148,255,198,0,118,0,123,254,178,0,105,255,4,255,187,255,13,255,224,252,80,10,237,253,84,0,211,254,157,0,156,242,3,0,94,254,83,255,90,255,46,253,207,0,192,1,125,254,8,254,202,0,197,1,210,0,53,255,48,1,190,0,248,254,101,0,233,255,36,0,74,0,110,255,26,0,29,0,223,255,59,0,129,255,22,0,213,0,89,255,103,0,0,32,183,0,149,10,131,255,68,1,60,252,253,254,112,254,215,255,82,254,111,1,127,0,10,1,113,1,57,4,66,255,36,255,197,251,129,2,83,245,238,2,13,2,145,253,238,255,87,12,174,2,234,254,221,247,144,6,75,2,123,0,250,255,246,254,120,1,10,2,79,254,13,254,169,0,106,0,249,7,174,0,59,2,148,255,129,0,140,255,169,255,4,255,89,0,242,255,14,0,120,0,62,225,52,255,15,0,19,0,146,255,174,255,202,255,66,0,31,0,210,0,55,0,83,1,61,0,37,255,123,243,12,5,80,0,88,1,35,253,100,12,235,255,201,255,200,2,64,255,38,0,152,1,233,1,132,1,169,254,5,253,182,1,236,248,250,255,127,255,144,250,130,254,228,255,105,0,228,254,88,255,50,254,228,254,22,0,113,0,179,4,181,12,179,253,149,253,92,1,113,0,79,3,3,0,211,253,204,1,132,253,167,253,26,253,46,0,145,255,51,0,190,255,205,244,39,2,199,1,130,3,17,0,157,8,236,3,210,255,61,250,145,254,33,11,254,2,224,255,137,255,112,2,46,253,43,13,172,0,182,254,93,0,35,255,201,1,59,254,84,0,231,254,152,254,108,0,231,1,211,254,166,0,205,245,65,2,192,0,34,0,81,4,193,2,34,0,29,0,31,244,126,252,172,0,66,2,51,1,227,1,73,254,185,254,104,1,89,252,180,255,131,1,75,246,32,3,77,1,89,2,56,253,51,252,191,255,70,254,220,0,249,13,84,254,46,255,53,2,245,2,130,254,33,1,214,2,237,255,74,255,128,1,224,255,38,0,214,252,75,255,94,244,3,1,43,255,39,254,69,255,201,252,233,254,238,5,26,0,127,254,119,4,103,254,30,5,164,2,88,246,64,0,121,254,154,255,199,1,137,233,22,1,30,0,64,0,79,255,143,255,86,255,94,0,22,255,89,255,101,0,254,255,107,255,125,255,95,1,2,255,118,255,149,0,214,255,119,2,235,255,237,0,77,11,221,254,101,11,40,251,211,0,41,255,22,0,197,252,96,255,140,0,43,255,156,0,6,255,47,251,179,2,242,1,226,255,94,1,228,255,244,255,217,0,34,0,164,254,186,255,116,255,103,0,196,255,97,1,56,255,198,254,182,255,112,0,83,17,176,255,225,254,157,1,157,255,127,5,239,5,74,247,114,0,107,12,245,253,39,0,84,1,133,254,117,1,240,249,118,255,66,254,150,255,6,253,7,252,215,254,73,255,242,1,31,254,118,1,15,1,23,234,41,1,98,0,134,254,187,0,178,255,131,255,77,1,114,0,175,255,62,0,111,255,14,0,106,1,6,2,134,0,195,0,130,0,222,255,184,255,240,243,107,244,142,255,73,2,178,255,6,0,40,2,135,253,158,255,32,255,212,3,82,1,173,255,216,251,42,0,106,0,137,255,132,2,219,254,240,1,67,0,128,0,127,255,108,2,20,0,14,2,79,255,68,0,95,1,137,241,185,5,137,3,11,255,86,0,255,1,39,0,0,254,106,255,239,0,86,0,60,0,39,0,177,255,247,255,191,255,77,0,199,224,57,0,237,255,56,0,218,255,161,0,35,255,127,255,8,0,93,0,52,0,10,234,142,255,133,0,26,0,64,0,62,255,196,254,113,255,225,0,190,255,175,255,182,255,240,0,130,0,137,0,219,253,11,0,96,1,203,255,67,240,1,2,92,12,51,255,127,0,80,0,63,255,59,255,220,255,139,252,223,0,166,252,5,0,54,254,34,1,203,1,247,0,228,254,80,255,20,253,173,0,191,0,114,0,150,1,126,0,3,0,91,0,84,0,91,31,123,1,200,255,47,0,35,0,246,0,113,255,65,0,220,255,8,0,59,0,67,0,187,255,91,254,92,242,56,1,4,255,5,1,39,13,63,1,189,255,77,0,166,254,130,1,34,0,237,0,18,0,111,0,92,1,221,253,186,0,163,255,26,242,78,255,39,241,123,255,229,255,207,253,204,254,112,0,32,255,16,1,61,255,242,254,77,255,91,255,199,0,244,253,169,2,139,255,83,254,37,0,253,232,94,0,201,255,79,254,158,254,122,0,196,255,67,0,56,255,176,255,11,1,120,255,214,255,130,0,188,254,231,255,156,0,167,0,209,255,178,0,8,0,33,1,157,0,88,0,228,255,217,255,250,254,245,255,9,0,143,255,76,0,0,32,89,0,115,0,214,254,137,0,34,0,0,0,5,1,226,255,49,0,18,1,130,0,56,3,80,252,200,255,50,4,198,254,180,255,15,2,75,0,7,243,221,2,226,252,160,254,242,251,25,4,72,0,23,255,56,1,35,13,69,0,104,0,107,255,22,0,27,1,236,255,155,255,234,242,164,0,184,254,150,254,31,252,174,1,78,0,125,0,13,1,227,255,106,1,183,255,226,255,91,251,116,5,59,0,251,250,40,255,135,255,53,15,84,0,48,254,218,255,143,255,143,254,75,255,94,252,12,252,138,1,120,0,18,1,216,253,224,252,105,0,115,255,244,255,241,0,101,253,31,2,96,254,28,0,74,255,51,0,137,3,132,240,67,251,12,0,241,254,122,1,22,255,70,3,143,255,56,0,55,2,35,0,48,0,234,1,76,255,73,4,170,0,36,10,228,255,26,12,36,255,168,1,117,3,214,255,15,3,226,255,139,3,63,0,46,0,125,255,28,0,201,255,54,0,210,255,231,255,30,0,58,0,241,255,56,255,250,255,11,0,186,255,66,0,103,224,86,0,120,255,96,0,200,255,155,255,44,1,107,253,215,255,55,255,248,2,4,255,187,3,189,0,179,5,234,13,55,254,35,0,202,255,92,255,183,254,35,251,194,252,147,254,113,254,233,255,104,2,18,255,235,250,58,255,79,1,184,242,149,0,175,0,159,255,233,254,174,253,164,255,109,252,194,252,212,1,116,2,216,2,0,4,219,253,49,4,222,0,114,255,40,1,181,255,88,255,251,255,189,255,113,227,206,255,0,255,191,254,121,0,102,1,240,254,30,0,2,1,105,0,95,255,221,254,206,1,249,255,45,255,29,255,152,255,105,255,104,255,184,255,158,255,197,255,233,255,158,255,53,255,103,0,89,0,239,0,28,254,69,30,110,0,35,0,89,1,26,1,190,253,140,0,205,255,194,255,18,255,102,0,198,1,64,0,149,255,33,255,82,255,29,1,110,0,66,255,240,255,88,6,142,0,229,14,175,252,43,0,234,0,84,0,0,0,124,255,131,0,121,255,186,255,255,255,125,0,173,255,171,0,109,0,108,31,97,0,218,255,143,0,64,0,13,0,4,0,31,255,181,0,200,2,114,2,20,0,167,0,45,254,186,0,217,14,125,247,121,253,137,255,144,255,73,255,33,255,39,1,74,254,105,254,227,255,36,0,222,255,232,9,209,255,110,254,223,255,194,255,120,255,140,9,104,255,51,253,156,252,86,0,237,246,163,3,147,2,255,250,158,255,126,2,94,255,195,0,251,255,216,255,168,255,203,11,138,13,189,254,60,1,240,252,53,253,5,0,188,0,42,0,155,0,160,253,244,1,185,0,219,1,100,0,205,255,111,3,133,252,98,255,18,0,59,254,124,1,49,255,113,255,145,1,103,255,158,3,72,255,215,10,104,12,227,252,58,255,136,252,149,1,204,1,53,1,48,1,142,255,82,9,15,9,146,2,104,247,216,0,179,1,70,251,113,253,154,0,81,0,26,2,140,3,220,0,138,255,226,1,160,252,242,253,15,255,89,3,39,254,6,3,224,254,138,252,46,0,250,0,160,255,45,1,120,0,24,254,128,255,23,255,166,1,38,0,168,242,50,252,13,255,30,255,125,1,90,9,140,2,52,12,51,255,233,250,204,5,97,255,104,255,243,251,151,255,135,255,46,254,180,255,93,2,181,0,201,255,186,254,241,253,130,255,155,6,36,5,180,254,26,5,90,6,19,6,74,242,31,255,162,1,240,5,55,252,182,255,226,254,233,0,199,254,159,255,119,1,181,0,203,254,68,5,201,3,8,254,115,255,21,3,56,251,119,255,64,253,98,0,235,3,210,1,211,8,205,5,31,255,61,0,16,1,33,255,165,254,233,255,144,254,96,0,41,9,112,0,107,1,216,253,250,255,218,252,155,249,89,249,61,6,190,247,60,255,37,1,107,251,138,253,161,252,56,251,16,3,46,253,232,2,117,3,30,3,128,254,92,0,42,1,151,252,16,7,109,5,232,1,223,249,251,249,8,244,34,253,3,0,211,1,37,252,90,1,123,7,85,253,205,0,25,254,85,1,182,254,18,1,231,255,49,0,173,255,222,4,107,254,247,252,10,1,121,0,6,255,210,1,48,251,131,243,153,252,130,253,180,254,27,6,108,7,42,254,44,2,47,254,100,254,133,3,170,255,85,253,191,253,247,251,40,3,161,252,188,4,44,253,174,8,173,1,173,10,157,1,123,3,133,6,3,2,73,254,187,0,153,254,158,1,176,0,62,253,167,2,193,255,223,4,71,249,11,3,46,245,28,254,135,253,31,252,13,255,162,5,200,254,188,254,142,254,136,1,105,254,229,0,97,0,243,4,238,255,46,0,209,254,84,253,3,2,90,255,116,16,249,252,233,255,203,255,23,0,174,7,47,254,231,0,171,4,252,0,244,251,16,0,200,252,140,255,186,253,226,254,214,1,97,255,217,0,56,254,37,2,136,2,60,0,161,251,221,0,21,253,98,1,140,253,26,254,126,3,0,5,185,245,247,0,174,1,89,249,69,0,20,255,147,0,165,5,28,2,88,252,181,0,93,255,163,3,236,251,157,2,153,9,7,2,85,2,17,248,11,0,217,250,252,255,90,251,85,0,254,0,42,250,230,0,47,6,221,253,21,1,42,248,153,255,171,4,38,246,21,5,135,253,152,255,1,254,61,2,92,6,61,254,2,252,52,2,76,253,255,0,5,4,104,254,245,2,172,0,117,254,40,254,89,249,192,248,133,254,33,1,253,1,140,253,187,250,49,255,148,1,113,254,135,6,136,1,89,252,66,255,184,3,13,251,126,4,26,6,159,253,235,1,166,254,242,254,29,254,54,1,140,5,7,252,178,6,123,253,129,3,209,250,82,12,234,251,167,252,13,254,16,254,188,250,143,1,63,0,115,253,197,254,52,3,109,6,102,2,154,8,11,3,185,11,102,5,131,1,181,252,208,248,166,1,7,252,246,0,37,255,218,253,105,0,160,253,170,1,166,254,32,255,119,1,22,0,64,254,242,254,130,251,127,252,202,16,142,252,49,0,121,2,87,252,74,253,163,2,190,254,231,252,252,253,152,254,8,255,166,4,63,2,181,252,243,255,50,0,223,252,157,4,196,1,177,254,17,254,154,255,223,251,250,1,50,255,66,0,121,253,223,3,3,1,3,1,44,254,197,0,117,1,136,239,18,253,224,0,74,255,8,2,238,253,96,7,30,248,44,250,144,2,89,250,225,3,234,252,239,252,24,3,122,6,117,1,131,0,52,254,65,253,56,4,149,252,44,255,74,253,235,2,129,253,37,247,239,4,97,254,19,253,2,251,79,2,23,253,31,255,115,249,69,0,113,2,110,255,212,0,89,1,216,2,215,253,93,4,215,1,38,2,14,254,39,253,234,247,238,3,182,254,171,3,52,14,34,0,93,1,249,2,125,255,116,1,98,2,113,254,10,0,86,0,110,0,163,3,121,251,81,255,121,2,56,2,140,0,200,2,240,10,234,249,39,9,3,0,50,252,95,253,233,0,156,5,241,252,87,2,70,254,84,3,127,2,191,1,48,252,204,253,231,5,36,0,17,2,177,1,165,2,179,7,217,10,204,252,113,253,73,250,144,250,138,251,160,254,176,1,218,2,183,1,239,254,76,3,108,0,115,0,152,1,151,254,248,1,81,1,58,0,50,4,147,249,169,249,19,254,186,255,207,249,62,11,27,253,124,2,32,255,50,252,210,2,109,255,149,0,135,0,149,255,102,255,253,251,238,255,35,252,26,1,101,12,99,4,246,252,109,5,177,253,81,1,124,6,224,254,138,4,191,255,148,2,70,1,141,0,102,1,167,2,34,255,204,1,105,0,0,2,36,0,170,252,35,254,82,252,198,246,9,1,204,8,92,255,245,247,106,0,154,2,92,254,9,2,78,255,140,1,212,248,219,1,82,0,100,1,207,0,177,1,19,252,97,0,129,1,208,254,171,252,2,5,17,255,170,247,83,0,84,0,201,0,154,248,189,249,171,2,91,248,143,255,71,3,163,4,199,254,6,3,14,253,173,3,29,253,236,2,116,0,204,2,110,4,238,253,126,247,71,0,157,253,8,6,199,13,253,255,27,1,15,2,201,1,143,1,250,2,17,0,233,254,196,0,250,253,96,255,76,251,223,254,182,250,132,0,197,254,222,254,125,247,164,2,62,250,14,252,139,250,107,1,211,255,15,3,46,5,223,255,147,255,151,253,241,254,57,252,153,255,75,7,1,3,228,2,206,252,243,3,131,5,75,253,102,246,40,3,38,3,43,255,212,1,31,0,186,255,166,0,230,0,107,254,163,0,70,0,140,2,53,4,66,255,146,253,39,9,208,250,89,2,160,3,131,249,174,0,173,1,81,246,245,1,247,1,215,255,85,5,159,2,238,3,80,248,7,0,103,0,113,254,130,254,61,2,229,255,42,2,41,247,154,243,21,1,177,0,39,3,184,254,208,252,197,1,244,249,60,3,185,254,187,0,119,254,23,253,180,255,216,252,63,2,248,255,186,254,242,247,89,2,54,2,243,2,7,3,83,2,163,1,171,240,30,255,16,1,112,1,139,1,59,0,93,4,36,2,119,253,83,254,65,1,37,2,24,253,63,1,82,0,135,0,73,0,14,0,118,1,93,0,242,254,59,254,177,0,127,19,57,2,169,0,111,0,10,255,150,254,168,255,207,255,71,2,221,255,60,0,9,253,47,5,232,6,254,2,162,254,144,252,150,255,63,254,143,255,85,253,94,254,25,252,224,3,47,2,222,254,109,255,188,254,93,0,77,252,164,240,219,255,51,1,63,4,198,254,219,254,176,1,62,3,126,255,48,255,59,0,207,2,164,254,159,17,224,0,232,1,82,255,76,2,27,3,211,254,10,255,65,254,170,2,149,3,73,251,9,254,62,254,63,2,140,255,130,255,82,2,234,255,155,255,5,0,92,251,81,254,122,4,227,240,184,255,146,1,95,254,122,254,94,1,117,4,118,255,185,2,77,0,73,243,244,254,238,252,150,255,150,250,144,1,168,252,77,253,74,254,242,249,28,255,114,8,236,0,64,0,130,254,1,0,8,4,153,0,109,253,27,6,102,254,0,5,37,6,165,241,239,251,240,0,145,1,215,0,159,254,140,251,9,1,153,255,200,252,163,255,193,254,175,252,253,0,35,254,49,254,153,0,7,252,26,2,209,4,239,251,11,0,230,3,75,254,199,253,54,252,70,8,215,249,1,0,65,1,248,6,214,254,11,9,72,0,236,255,83,0,137,3,247,250,10,255,219,2,236,15,59,250,90,2,113,252,210,3,186,2,17,255,135,1,39,253,236,254,225,0,143,0,95,254,12,254,229,255,60,251,89,0,109,254,83,250,14,246,247,3,70,0,78,0,60,9,97,255,249,252,29,0,37,0,25,255,73,0,177,1,170,1,239,253,164,1,155,253,156,255,163,253,183,5,233,3,135,4,14,240,215,253,92,1,218,252,112,2,94,255,159,251,231,255,151,3,194,255,90,0,237,254,233,0,203,0,32,0,233,2,35,255,202,1,17,2,133,3,64,4,38,0,185,4,194,1,195,1,202,8,101,254,51,255,249,2,249,0,54,251,246,254,133,243,223,252,225,255,247,3,188,254,172,253,214,255,150,0,207,0,37,10,17,4,235,251,50,247,108,250,250,0,217,0,69,0,91,252,144,5,24,1,190,1,12,2,28,2,127,2,253,251,23,0,156,1,36,0,189,255,219,1,154,251,29,253,136,4,2,2,99,255,240,244,104,250,47,2,77,0,228,2,136,252,134,0,24,5,245,254,245,254,73,1,8,0,185,6,208,5,227,255,32,249,144,248,182,245,194,250,240,253,185,8,37,255,62,255,153,244,128,0,179,4,145,253,129,255,232,1,126,254,123,255,183,254,62,0,85,0,247,4,71,255,33,254,180,253,108,244,34,2,115,6,246,5,194,252,22,4,91,1,63,0,232,251,239,0,122,5,234,255,51,1,186,249,0,3,231,3,48,1,0,254,81,255,10,255,139,254,17,2,93,0,247,253,30,5,4,254,242,238,27,0,0,253,154,254,193,253,254,255,175,253,235,255,186,252,123,2,197,0,122,2,65,1,249,254,135,254,219,253,20,0,227,2,139,1,247,255,120,254,70,0,47,22,123,255,126,255,16,255,90,253,165,1,155,255,156,1,143,0,209,0,194,0,216,0,200,0,234,255,20,253,113,254,47,11,28,1,231,0,179,2,59,2,124,242,56,255,56,1,224,1,198,250,165,253,179,1,204,254,153,253,8,2,178,0,68,0,52,253,45,0,175,253,224,255,143,250,214,253,24,252,157,252,101,2,32,1,251,1,202,0,143,255,17,0,93,0,115,255,209,255,153,2,47,2,216,252,5,240,193,253,63,255,151,252,234,252,161,2,160,253,83,252,233,2,26,6,220,251,220,3,168,4,29,0,73,251,207,0,141,2,146,253,124,255,114,1,155,5,185,7,170,248,137,255,101,0,156,255,102,255,155,252,185,246,230,4,122,0,188,0,109,3,188,0,186,252,157,254,155,2,229,14,52,4,113,1,253,252,56,253,99,253,242,255,107,0,3,4,112,0,2,9,138,5,133,0,31,4,121,1,249,0,255,3,97,252,12,0,65,248,150,4,223,0,129,1,59,3,145,5,98,249,102,251,162,255,175,253,226,254,239,4,97,253,87,254,210,7,189,2,10,6,35,2,182,0,245,3,128,0,95,1,13,255,151,1,45,9,136,254,189,1,163,255,200,3,175,254,167,253,62,5,219,3,37,250,124,253,9,2,71,1,211,253,8,7,12,0,29,1,127,0,243,254,59,248,63,254,87,0,238,251,184,0,13,254,207,4,128,249,160,254,4,0,229,4,147,1,216,251,69,3,90,249,133,0,151,6,236,250,200,8,179,0,177,252,151,253,204,1,194,1,252,254,94,0,244,252,93,253,185,4,38,0,197,1,89,3,137,253,61,1,23,2,62,4,60,255,126,2,224,254,123,254,176,2,163,255,247,4,62,239,160,255,189,1,64,0,45,255,148,0,182,255,230,1,175,248,190,4,44,7,60,253,8,7,108,6,64,2,192,251,68,251,123,4,56,254,173,0,113,252,233,1,69,254,132,2,22,2,78,3,14,250,238,252,241,1,111,254,193,251,130,5,111,5,69,3,3,255,124,0,170,253,2,255,151,240,111,251,103,0,63,255,50,0,78,3,10,252,97,1,199,1,16,3,63,5,239,11,178,0,140,253,108,255,246,254,188,254,160,255,66,255,94,252,115,0,219,1,117,253,198,254,174,255,20,255,168,255,87,241,232,251,229,254,78,255,95,1,97,253,69,1,30,4,28,0,28,2,113,0,183,255,251,2,76,3,31,2,250,255,31,3,245,0,176,0,124,0,6,1,144,255,242,3,105,1,181,252,218,12,99,241,146,3,213,248,253,254,163,9,41,1,75,251,168,0,131,248,156,0,87,0,125,2,91,253,69,252,56,1,222,4,37,255,92,0,66,4,220,254,251,252,87,1,245,253,43,1,255,253,41,5,232,253,74,2,212,250,41,9,80,9,49,253,88,252,109,5,229,255,112,3,82,1,129,255,102,253,71,254,67,6,143,0,38,255,119,8,201,250,213,1,56,251,185,9,85,5,56,2,19,0,214,250,32,253,208,0,18,254,58,254,222,3,6,255,49,1,193,253,206,0,88,255,103,251,26,1,223,230,239,1,235,254,138,253,155,1,217,4,186,254,87,254,11,2,114,0,31,255,203,255,230,253,66,253,252,254,95,254,111,254,34,255,249,254,96,254,163,0,24,251,78,2,104,251,73,7,203,5,97,252,191,255,94,253,23,5,109,255,18,253,124,255,151,1,229,254,84,3,252,6,47,247,210,0,62,254,47,1,240,254,24,246,94,0,218,7,172,1,103,252,253,255,185,255,149,252,156,0,87,253,9,2,49,0,51,0,245,253,252,5,83,6,78,253,146,1,101,252,62,1,97,3,193,0,117,247,106,253,41,2,176,251,186,255,223,250,206,1,235,251,64,1,169,3,83,250,254,253,148,1,25,255,44,249,200,249,9,248,39,255,148,254,223,250,84,254,115,9,233,4,244,250,19,0,51,11,234,254,216,248,17,255,77,253,129,254,62,0,185,0,57,254,203,249,116,0,163,1,193,254,94,254,25,2,232,254,214,248,121,10,167,252,46,255,100,255,137,251,152,255,18,249,166,6,184,0,249,3,121,255,158,253,13,2,79,1,157,254,18,254,25,255,102,255,218,3,178,1,110,4,189,4,146,3,177,5,254,254,194,251,221,1,57,247,242,1,51,249,49,252,250,254,44,3,108,0,66,3,100,254,120,0,248,251,235,253,56,254,139,0,211,254,125,254,78,253,30,3,3,0,236,249,237,4,233,2,122,238,8,0,213,0,209,3,105,255,243,254,168,254,13,0,32,2,242,254,90,255,62,253,160,2,184,0,81,252,78,249,230,5,29,253,99,7,35,254,16,2,55,7,220,249,164,1,103,0,171,255,252,1,231,0,232,7,193,250,20,0,238,0,113,253,156,2,231,249,25,253,117,253,197,2,144,251,48,255,211,3,2,1,75,253,233,253,154,251,229,254,80,252,47,255,91,2,251,248,74,244,253,0,216,254,74,3,63,0,53,255,44,254,163,2,81,1,178,5,114,0,3,1,130,12,145,0,163,1,119,2,96,1,5,9,57,5,47,3,157,255,200,252,245,252,209,248,81,250,166,0,212,247,19,5,162,0,254,251,110,252,128,0,41,5,128,3,47,255,255,0,136,251,39,3,202,244,136,253,180,253,98,3,81,0,197,1,154,0,22,251,13,254,60,254,158,255,39,10,254,11,28,2,190,252,28,255,12,251,199,254,245,4,191,255,200,255,11,4,13,254,5,254,111,253,191,1,26,0,96,0,81,255,133,0,221,254,230,253,253,254,7,0,50,255,155,1,145,0,25,0,215,0,11,1,254,238,70,254,250,0,210,252,113,255,53,254,74,255,128,253,22,251,169,0,123,1,84,251,173,1,128,255,77,248,121,10,211,255,105,6,152,0,212,253,141,3,109,1,150,253,95,254,149,254,78,254,14,1,148,250,39,254,62,0,58,0,253,1,187,240,47,5,35,6,226,1,57,4,128,252,203,1,224,1,211,253,245,254,134,1,241,255,228,1,248,0,52,0,49,0,190,2,246,255,162,0,245,0,96,254,117,5,23,0,183,0,69,1,79,2,208,252,77,17,162,2,180,254,37,251,68,0,29,1,235,0,247,2,197,254,31,3,57,1,181,254,74,255,139,253,138,1,201,251,39,15,175,255,139,2,250,252,235,255,215,254,231,0,222,248,47,0,104,0,28,1,85,255,58,255,146,255,63,255,113,3,53,253,38,1,22,254,139,1,19,251,43,11,153,243,59,250,156,2,41,255,54,1,10,0,250,2,187,252,101,0,142,0,201,0,84,252,197,1,174,255,237,1,41,252,23,0,45,255,222,3,47,5,56,18,229,255,53,3,41,3,244,1,243,0,41,0,56,2,44,0,192,254,105,0,205,1,50,1,104,254,231,252,221,255,238,255,229,0,244,255,96,254,65,2,211,254,6,19,248,253,243,1,57,0,224,253,235,255,99,2,226,0,236,255,100,254,184,1,88,253,192,1,174,1,226,0,158,253,202,254,38,255,137,4,11,2,112,254,108,255,15,3,139,1,130,255,114,1,174,2,15,254,211,254,161,0,251,255,238,0,119,1,101,1,130,255,186,3,64,23,203,255,121,0,107,254,35,6,179,1,205,1,114,251,117,251,67,5,114,5,170,0,243,7,212,249,66,252,20,1,88,253,56,252,19,1,189,254,12,2,48,0,152,248,46,0,17,254,36,2,95,252,165,252,224,0,55,4,95,3,8,12,198,249,133,254,46,1,109,254,198,2,143,2,219,254,49,253,85,253,80,252,228,0,171,254,51,2,17,254,152,3,226,2,154,253,40,2,7,255,110,254,92,255,250,254,87,254,71,240,164,0,40,252,250,253,157,0,124,251,39,253,0,4,0,253,235,3,225,1,140,255,63,1,106,252,27,6,106,253,244,18,105,2,6,255,37,2,247,254,163,255,168,2,214,1,157,3,219,254,117,2,142,0,231,0,44,0,133,0,12,0,40,0,157,252,13,1,179,255,189,1,148,251,39,252,232,250,216,2,168,1,18,2,254,254,143,253,121,1,136,250,22,246,42,254,81,249,157,1,189,249,175,255,119,254,11,252,106,4,138,3,31,1,128,2,201,14,49,254,97,255,43,0,91,255,71,254,255,253,225,254,214,253,11,6,80,3,237,254,168,3,141,2,1,3,198,255,17,252,70,253,232,252,127,8,142,1,102,5,134,255,203,1,249,255,25,1,225,10,131,253,120,2,233,254,37,1,202,251,28,252,96,0,219,254,201,250,182,255,181,253,226,254,203,253,47,252,28,255,216,19,3,0,171,0,111,0,222,255,79,255,149,253,65,2,192,1,232,254,189,0,9,4,189,253,134,0,55,253,77,252,7,255,151,248,108,1,212,6,206,247,21,0,91,3,183,255,167,248,116,0,36,0,55,6,106,5,152,251,166,254,9,252,231,255,166,255,77,253,40,252,136,255,29,0,133,253,20,255,26,0,77,253,26,253,53,255,38,1,40,254,123,252,22,10,85,255,155,254,150,1,162,0,25,6,111,252,52,1,9,243,205,1,11,3,207,254,97,252,34,1,83,252,103,2,80,253,4,254,222,0,80,254,131,1,170,0,141,255,38,235,252,1,44,255,150,0,26,0,218,255,50,1,241,255,50,0,216,7,168,251,69,255,44,0,79,2,232,254,163,4,166,3,28,255,42,2,65,0,149,250,49,248,219,252,251,9,55,251,229,254,77,254,82,254,206,255,113,253,153,255,248,0,22,255,32,0,198,252,60,253,64,253,18,252,176,0,16,3,18,1,114,2,207,246,195,2,60,7,124,255,60,255,87,255,49,254,187,247,56,0,157,1,115,255,206,252,147,254,153,3,208,252,130,255,121,255,182,1,76,252,111,255,163,254,188,2,205,0,233,3,214,241,58,1,19,254,98,251,131,0,221,2,100,9,36,251,52,2,64,252,72,1,143,251,148,255,13,253,88,255,29,252,198,3,86,249,203,253,38,3,75,253,89,5,243,254,84,254,163,2,0,3,85,1,230,252,217,8,48,255,165,248,223,252,159,248,193,3,182,0,8,254,173,253,103,3,0,251,184,3,71,5,153,2,218,1,8,4,58,0,195,1,58,255,89,1,176,0,171,252,181,244,202,8,112,2,152,253,183,0,144,0,224,2,0,0,58,255,118,255,62,251,11,254,110,253,232,255,208,4,226,254,23,255,87,252,102,8,245,251,193,1,145,253,68,245,128,247,150,3,86,255,165,1,96,5,93,0,153,0,115,2,237,1,28,0,37,2,220,254,81,255,42,4,13,4,37,254,157,1,42,248,26,248,178,254,109,1,133,3,177,3,105,253,3,2,161,254,171,253,155,0,38,5,103,255,161,1,87,254,44,0,82,1,90,248,157,254,172,253,170,247,104,1,85,1,197,9,56,3,198,247,230,254,69,249,33,253,218,253,25,253,113,0,3,4,33,254,190,247,240,255,137,253,230,254,226,251,40,5,98,255,22,255,151,13,28,0,26,7,115,2,184,5,229,252,234,255,129,3,250,255,136,1,22,255,86,255,202,2,130,254,238,4,67,0,150,253,145,0,25,0,58,253,9,255,223,253,150,250,251,248,29,252,97,3,209,1,148,254,62,3,203,255,172,251,129,254,230,253,85,0,219,2,68,255,211,252,2,0,125,249,51,13,33,1,169,1,39,5,253,254,176,253,44,255,15,1,244,254,130,255,2,5,50,1,19,15,113,250,95,2,20,0,243,2,174,0,242,252,72,0,22,255,163,2,103,251,77,4,133,253,151,249,14,10,46,252,146,250,49,249,135,8,53,0,75,0,138,2,159,255,56,254,130,255,49,253,93,253,45,2,137,254,131,2,85,3,175,255,64,255,106,251,248,250,70,252,141,252,218,252,122,247,193,247,110,250,180,0,246,254,211,254,114,2,69,254,61,0,107,255,69,254,89,252,208,255,130,2,250,0,17,0,84,2,62,5,177,247,67,1,80,250,203,7,69,3,80,250,109,249,177,3,46,253,91,250,196,1,178,0,71,254,6,255,119,255,128,255,206,255,201,254,168,253,189,8,154,3,139,0,149,255,131,253,234,6,57,246,157,1,221,252,240,1,209,0,121,254,145,1,156,1,216,253,93,2,219,255,101,253,183,249,237,255,207,251,242,5,63,253,158,2,32,252,114,3,67,251,170,252,102,8,141,254,73,0,113,251,176,253,103,255,3,254,184,253,17,254,173,255,27,8,47,250,207,2,221,4,142,251,72,0,182,3,74,252,30,2,178,253,220,3,110,6,192,255,50,2,33,255,73,0,71,2,105,255,215,0,146,3,111,5,75,244,161,0,180,1,49,0,177,8,15,1,229,254,4,15,190,253,79,1,166,255,70,253,94,255,212,4,139,255,214,1,127,1,50,253,8,2,39,1,29,0,36,1,77,255,6,3,204,0,116,1,5,255,200,252,25,254,226,248,200,254,37,253,56,2,16,252,1,255,189,0,85,251,145,2,29,255,94,13,139,2,36,255,76,251,178,253,201,2,109,1,47,252,204,0,46,12,65,1,154,3,165,254,225,5,119,1,179,255,16,250,125,250,88,253,5,254,31,2,20,254,204,248,135,0,177,2,128,1,104,254,140,0,121,2,88,251,219,1,220,0,81,249,218,250,94,2,153,255,56,253,58,249,38,255,169,252,189,252,1,244,147,255,111,5,62,0,21,0,181,255,179,255,113,1,216,0,52,250,9,8,149,2,58,1,19,1,24,4,175,0,50,7,231,2,40,3,174,253,82,1,63,251,70,6,237,253,176,250,207,251,196,1,237,253,226,252,253,252,244,250,106,252,94,2,16,249,3,254,178,0,142,5,96,13,122,2,210,2,255,254,13,2,181,1,59,255,126,255,35,1,101,254,253,254,134,252,172,255,112,1,93,4,215,250,188,254,182,247,3,2,134,4,213,6,61,252,169,2,39,0,12,1,37,2,68,1,167,253,151,0,56,255,61,3,41,15,29,3,148,2,196,253,75,253,121,2,255,3,109,255,187,253,102,0,49,255,93,255,1,254,226,255,154,255,123,1,8,3,238,1,2,254,55,0,237,248,49,4,32,17,194,254,205,12,166,7,47,255,229,253,31,7,176,4,74,255,70,255,213,0,123,0,250,1,41,254,81,254,70,253,181,254,112,251,88,0,20,1,72,255,221,2,217,254,227,251,51,253,94,3,83,250,117,239,39,4,25,4,147,253,83,254,116,1,19,4,87,2,15,1,75,253,79,253,122,0,210,1,189,254,76,1,235,253,133,2,4,2,141,254,49,255,2,248,72,0,155,251,27,255,47,245,182,254,107,5,167,255,86,1,226,10,38,253,152,0,117,2,41,3,53,254,8,255,246,254,111,0,124,1,212,2,101,254,128,2,184,255,67,1,34,0,235,254,187,1,33,1,151,0,48,237,146,1,85,255,37,253,123,2,172,255,123,255,202,254,141,1,136,3,169,4,24,250,231,255,230,250,75,2,66,1,78,241,25,2,206,254,43,252,149,3,190,0,19,3,155,253,149,0,45,1,136,254,110,1,94,1,18,0,125,3,146,255,183,10,225,255,86,0,245,255,121,14,192,0,167,255,57,0,4,255,245,255,44,255,163,0,0,0,119,255,149,1,157,255,132,255,119,255,105,254,125,0,106,0,102,252,31,6,85,0,165,0,241,0,110,0,102,11,86,2,69,254,44,3,159,0,6,2,43,2,162,248,191,255,204,255,253,255,229,255,56,0,226,255,130,255,126,0,23,0,74,0,157,0,78,27,222,255,56,0,255,254,84,255,115,0,233,255,152,253,13,255,71,254,34,0,159,0,6,0,78,0,137,255,49,0,34,0,123,255,220,3,17,252,218,1,77,0,238,254,98,1,43,19,222,0,240,255,69,0,252,255,156,3,238,255,207,13,213,254,218,255,173,255,145,255,209,3,118,255,205,251,68,254,28,2,199,0,202,0,10,254,62,255,58,255,249,0,101,0,20,1,167,255,96,0,211,254,6,0,73,240,186,255,174,0,93,0,192,0,136,255,243,2,208,253,234,255,78,0,56,0,29,0,28,0,212,255,65,0,252,255,0,0,49,0,6,255,87,0,46,0,44,0,215,255,133,228,14,0,32,1,120,2,253,254,192,255,20,0,78,255,169,254,238,254,106,0,26,11,80,1,229,254,245,0,156,253,251,255,244,1,77,0,188,9,6,255,64,0,171,0,36,252,4,0,205,255,222,255,213,253,85,255,187,245,16,1,36,11,94,255,158,255,19,255,234], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1604805);
/* memory initializer */ allocate([254,23,254,129,2,160,255,135,30,117,255,140,255,119,255,135,255,198,254,95,255,211,0,76,0,136,0,221,255,132,255,229,255,76,0,158,255,133,0,85,0,76,1,0,239,251,1,242,255,237,254,44,255,52,1,2,1,129,0,91,255,59,255,152,255,106,255,152,255,60,0,125,0,56,2,253,255,158,6,62,0,186,255,109,0,122,0,199,255,238,255,194,33,100,0,50,0,92,0,17,0,170,255,163,255,188,255,135,255,195,255,224,255,27,0,68,255,246,1,123,0,175,255,37,0,48,0,187,0,75,0,226,255,234,255,32,255,220,254,99,0,207,255,177,16,10,0,66,3,231,255,225,0,213,10,78,0,47,243,75,255,234,0,126,255,182,255,101,0,214,0,230,255,143,255,244,254,88,255,166,255,77,254,230,255,38,0,199,253,87,240,255,255,11,0,69,0,3,0,249,0,98,0,178,0,131,0,44,1,198,252,48,0,81,1,196,252,141,254,96,0,56,1,200,2,101,253,186,255,234,247,14,255,7,2,92,253,143,0,155,253,125,3,111,247,215,1,47,4,213,0,49,251,60,255,188,253,155,0,145,1,78,0,192,255,27,0,18,255,22,0,183,255,237,255,194,0,60,0,169,255,46,255,101,255,244,0,133,255,87,255,166,238,169,0,60,12,75,255,65,0,110,15,116,254,209,0,39,0,204,255,230,255,166,0,1,0,92,255,143,0,190,255,169,0,46,0,240,255,217,254,39,0,42,0,40,0,67,0,25,0,17,0,255,255,40,221,174,255,214,255,49,0,81,0,195,255,1,0,39,0,216,255,18,0,74,0,206,0,125,255,185,255,106,0,7,0,88,0,243,255,69,0,143,255,167,255,212,0,252,255,21,17,222,255,27,1,105,0,252,0,59,0,238,245,214,254,54,7,146,255,151,255,202,254,113,255,129,255,18,1,225,0,93,3,6,1,209,252,201,254,230,255,83,253,243,0,148,253,138,254,176,11,144,255,221,255,87,11,162,255,200,255,43,255,65,0,127,1,41,0,252,1,254,254,153,255,72,254,19,255,172,1,132,0,233,10,179,255,143,255,198,255,237,255,239,240,231,255,40,0,89,255,13,255,23,255,215,255,233,254,213,0,234,255,8,0,120,0,126,0,159,0,44,255,12,255,183,0,69,6,62,0,244,255,12,255,7,2,12,3,116,0,131,243,32,252,85,1,222,0,169,2,155,254,99,253,55,0,189,4,100,0,185,1,1,0,199,255,232,0,10,0,142,255,62,1,109,255,89,0,188,0,192,1,185,254,151,14,220,254,107,3,40,255,211,0,111,0,160,0,172,0,30,1,71,242,175,252,71,255,247,255,31,0,186,1,235,2,235,251,187,0,192,2,37,255,253,1,48,0,69,0,231,255,246,255,75,0,23,0,10,0,23,0,224,255,89,0,180,33,179,255,237,255,27,0,0,0,24,255,22,0,206,255,144,248,119,255,87,255,128,0,138,0,78,0,69,254,243,0,157,0,31,241,231,0,21,1,171,254,73,0,186,255,84,2,3,1,157,0,149,8,63,2,141,9,11,0,203,255,118,0,141,255,50,2,108,0,30,0,15,255,30,0,118,254,101,255,70,255,168,254,19,255,193,254,46,247,87,1,201,254,14,0,169,0,59,0,241,255,233,0,220,2,109,1,76,253,148,255,136,5,49,254,233,254,8,255,61,249,106,254,234,254,42,1,209,0,213,20,58,255,89,255,50,0,183,1,142,0,91,0,245,253,226,0,6,1,126,255,241,255,61,2,252,255,15,1,254,255,209,255,7,0,110,220,187,255,212,255,112,255,158,255,199,0,75,255,6,0,45,0,47,0,37,0,205,255,188,255,206,255,140,255,151,255,49,0,120,1,92,254,187,0,78,11,29,0,41,254,35,255,199,1,255,255,166,252,55,0,59,255,103,1,76,248,68,255,153,3,122,255,186,0,181,252,18,246,66,1,255,255,98,255,160,254,205,254,190,253,196,255,143,0,234,250,77,1,169,2,93,5,3,252,18,0,28,1,228,255,8,0,199,255,240,255,15,0,58,0,31,0,197,32,221,255,18,0,77,0,178,255,15,0,36,0,17,0,122,255,239,255,60,1,88,253,235,1,38,0,39,255,234,254,20,1,213,254,181,255,66,240,219,254,5,254,194,255,168,254,64,0,74,254,168,254,0,255,85,1,199,0,190,255,28,0,239,255,239,255,2,0,142,0,6,0,208,255,87,255,229,255,139,255,83,26,42,0,195,255,140,0,246,0,29,13,85,243,48,0,201,255,49,0,27,0,4,0,172,0,87,255,6,0,69,0,247,254,70,0,25,0,223,0,28,0,129,0,231,0,57,0,184,249,80,10,228,255,59,255,29,0,245,255,138,0,109,2,171,1,20,0,2,2,151,2,50,2,191,1,98,255,115,252,87,1,191,254,255,254,241,25,255,255,236,255,186,255,62,0,241,0,51,0,173,255,208,255,100,255,246,254,177,254,213,255,165,1,94,1,50,1,165,0,227,253,47,0,5,0,216,255,108,1,21,0,190,0,24,238,131,255,71,254,233,1,197,253,209,255,246,255,205,0,60,0,183,255,184,253,161,1,233,0,222,255,147,255,85,0,41,0,134,0,229,1,85,255,73,255,14,250,202,0,134,1,216,243,144,0,139,6,139,2,146,1,161,7,120,0,93,0,236,254,118,248,59,255,195,255,100,0,81,0,6,255,101,255,237,255,80,1,78,255,220,246,88,0,225,253,226,0,53,246,196,255,194,255,218,0,247,255,158,0,223,241,190,255,32,0,58,1,64,255,135,255,116,1,78,1,4,2,156,1,247,0,159,253,43,251,56,1,136,255,217,255,47,0,61,0,193,255,166,255,148,17,65,255,159,254,10,0,54,0,93,255,167,254,121,0,194,254,21,255,190,0,157,255,181,0,215,242,4,0,68,255,169,255,128,0,167,0,5,254,148,251,102,253,158,254,121,0,43,0,222,253,89,2,103,254,181,0,209,255,197,254,127,0,227,244,231,1,186,0,92,245,87,1,177,0,187,252,131,1,172,255,3,1,122,0,97,255,88,0,117,0,137,0,79,0,126,0,48,6,247,253,112,246,88,10,10,255,181,255,55,2,114,0,244,0,141,2,217,253,60,255,145,253,205,0,48,3,48,0,186,254,66,0,162,255,223,255,133,0,156,1,15,255,235,1,224,255,56,253,7,255,84,241,71,255,27,255,248,0,12,1,45,2,73,0,164,0,24,0,186,255,229,255,54,0,100,255,205,255,209,255,230,255,43,0,187,0,179,0,218,255,119,255,218,0,124,7,6,18,179,1,241,255,21,0,145,0,76,7,241,0,240,0,43,1,52,255,73,0,232,255,138,255,140,254,167,255,23,0,214,254,223,1,21,11,191,3,180,255,171,255,254,255,28,0,94,0,83,243,28,0,126,255,159,0,39,1,8,1,93,254,158,255,240,255,97,255,93,1,202,0,98,255,136,245,46,255,122,254,238,255,248,255,108,1,87,5,146,255,164,3,24,255,68,5,176,255,97,3,221,254,104,254,150,1,138,255,62,25,201,255,10,0,104,255,95,255,124,255,231,0,2,1,135,0,243,255,152,255,247,0,207,0,18,255,212,0,237,255,225,255,25,243,96,255,232,255,74,13,50,0,116,0,65,255,97,0,117,255,156,255,71,0,207,255,219,254,133,0,136,255,246,255,197,0,196,0,252,253,82,253,79,0,204,255,114,23,209,255,88,0,55,255,146,0,136,0,54,0,162,0,76,255,31,1,67,0,70,0,201,255,210,0,110,248,123,2,94,255,82,0,136,255,56,254,181,255,87,241,173,255,176,0,137,0,18,0,250,255,231,254,232,0,137,0,89,255,117,1,78,0,194,245,218,255,219,254,89,0,69,0,108,242,8,0,152,0,136,0,32,0,241,255,116,255,11,0,6,0,13,0,225,1,81,255,28,255,2,255,158,0,161,242,206,0,22,0,132,3,233,7,10,1,110,254,132,0,156,254,46,2,176,253,250,254,93,254,234,3,73,0,10,255,232,255,183,243,148,12,223,255,27,1,142,1,225,255,231,255,249,255,103,0,163,255,113,255,1,0,32,0,15,254,206,0,221,255,144,5,114,0,140,0,89,9,173,12,38,255,93,255,113,0,191,0,92,255,41,255,248,1,0,255,140,0,148,254,30,255,172,254,91,0,48,254,32,0,188,0,4,0,15,0,76,232,69,0,109,0,219,0,75,0,196,0,232,255,172,255,38,255,27,0,57,0,159,255,8,0,174,254,252,255,102,1,23,0,204,255,188,255,40,2,183,15,1,255,172,2,144,0,188,0,100,0,219,254,206,1,41,2,9,0,153,2,12,0,128,253,21,236,98,255,11,255,182,255,88,255,7,1,157,254,142,254,115,253,93,255,39,254,118,254,23,255,238,2,17,0,225,255,173,1,152,255,46,255,216,0,105,1,230,245,253,0,186,250,145,0,235,10,251,255,151,2,250,254,37,0,134,255,205,0,14,1,65,1,63,10,0,1,4,0,214,255,219,255,112,0,166,254,20,0,205,255,9,0,166,255,242,242,78,0,52,0,17,255,58,254,49,255,99,1,120,255,237,255,138,1,44,255,90,255,183,255,188,255,25,4,127,244,129,1,223,253,45,255,116,0,241,255,175,2,24,255,32,7,190,255,133,0,109,254,193,255,3,0,46,0,152,255,155,255,136,0,195,255,164,1,149,0,232,255,247,255,181,16,107,255,90,255,96,0,221,255,250,6,236,251,115,0,210,250,53,13,248,253,70,0,122,255,79,254,58,255,146,0,153,253,113,255,201,0,86,1,156,1,94,255,22,0,111,0,16,0,171,255,14,0,136,255,79,0,226,255,172,255,56,0,222,255,204,255,109,255,19,0,155,0,17,0,136,255,221,22,96,0,255,2,6,1,62,255,124,0,76,255,13,0,9,12,39,0,146,1,90,0,36,1,84,0,207,7,240,255,98,3,36,1,160,1,198,254,177,0,255,255,68,0,3,0,228,255,200,255,202,255,10,0,251,255,193,255,89,0,187,255,5,255,70,0,99,29,173,255,67,0,62,0,178,0,69,249,180,255,101,0,113,1,117,255,58,0,135,0,224,255,138,0,65,13,193,253,74,2,36,1,216,254,7,254,134,253,52,0,24,1,78,0,14,0,117,0,217,255,77,0,231,0,136,0,14,0,51,0,173,0,160,255,5,0,122,1,204,255,12,239,249,254,61,0,22,0,176,244,236,255,180,0,21,0,52,14,118,255,104,0,233,254,56,0,105,254,248,255,133,255,134,0,161,255,12,254,10,1,192,255,213,255,1,0,86,255,31,0,110,0,53,0,56,0,206,232,151,0,49,0,180,255,90,255,34,0,248,255,193,0,198,0,138,255,252,255,212,255,249,0,228,255,154,255,226,241,49,0,208,1,124,254,24,253,12,254,91,2,168,255,237,255,70,6,69,1,29,255,235,254,114,255,232,0,213,248,150,0,167,255,29,0,9,0,76,0,169,1,192,254,179,0,231,0,184,6,168,1,86,245,214,254,154,2,72,0,84,254,37,251,213,254,93,0,244,255,236,255,160,255,133,255,18,0,188,0,255,255,21,255,254,255,0,13,107,0,47,250,199,0,125,3,193,255,46,0,215,14,22,0,138,255,129,255,27,1,254,0,213,247,37,1,75,1,89,3,164,255,46,0,13,0,55,254,169,0,83,3,237,255,25,255,225,221,194,255,69,0,66,255,153,255,225,255,108,0,66,0,95,0,53,0,250,255,12,0,19,0,183,255,105,0,216,255,227,255,60,0,249,254,149,255,185,8,10,255,229,1,86,1,196,6,76,0,185,9,40,0,44,0,212,254,24,1,147,255,149,255,34,252,211,255,246,3,47,236,1,0,87,255,25,0,201,255,172,254,85,254,91,2,206,0,151,0,104,1,56,1,212,255,150,255,2,2,171,2,98,0,3,13,19,0,150,255,106,0,201,242,85,0,95,255,168,255,8,0,12,0,93,255,183,0,119,254,117,0,13,255,14,254,196,255,36,1,190,254,199,247,152,3,45,1,41,0,237,255,114,255,75,246,119,2,223,254,175,252,132,0,32,3,1,255,122,254,137,0,174,252,101,254,41,0,163,255,51,222,9,0,231,255,134,0,190,255,222,0,152,0,59,0,29,0,63,255,127,255,151,255,39,0,235,255,188,0,111,0,25,0,253,255,0,0,177,255,203,34,232,255,238,255,37,0,223,255,214,255,87,0,212,255,56,0,177,255,189,255,204,255,18,0,124,255,133,7,53,1,145,0,69,254,255,4,200,0,191,4,25,1,15,13,55,1,134,1,102,255,137,255,245,253,19,0,239,253,190,0,16,1,29,2,119,254,22,1,161,0,13,0,161,0,123,3,191,255,57,255,160,250,162,254,127,250,84,1,67,8,47,255,155,9,30,0,3,254,141,0,11,0,211,253,232,249,136,248,22,255,76,0,19,3,221,10,45,0,98,255,74,1,145,253,143,2,179,252,49,254,137,255,4,255,213,254,108,248,145,0,17,0,73,255,185,255,98,0,67,0,145,0,122,255,168,255,251,255,204,241,3,0,34,0,231,0,213,3,33,0,71,252,109,254,129,0,215,0,245,255,109,0,68,255,51,0,56,20,167,255,143,255,60,0,118,255,162,255,142,0,216,0,66,1,223,255,94,1,227,254,182,0,92,0,240,255,12,0,15,0,126,0,229,255,5,0,156,235,102,255,13,0,109,0,18,0,186,254,255,254,118,0,57,1,86,1,241,8,221,255,234,255,115,0,0,255,164,244,68,0,187,4,203,0,33,253,132,254,122,255,249,0,10,2,109,0,208,255,6,236,32,0,214,255,85,0,157,255,9,1,69,255,163,255,117,1,85,1,2,255,16,0,135,255,164,255,252,254,176,255,254,255,190,254,234,0,160,255,238,244,230,0,146,0,248,254,41,243,103,255,41,0,163,254,107,255,158,255,140,0,141,255,116,2,245,255,36,1,4,0,90,255,82,0,60,238,116,0,233,255,201,254,100,2,178,254,195,1,3,1,47,2,64,1,245,254,5,2,117,255,90,255,126,0,27,0,167,255,100,255,14,0,63,0,253,255,31,0,109,0,213,255,10,0,254,225,36,0,233,255,73,0,129,0,0,0,140,255,66,0,5,0,137,0,239,255,219,9,203,0,175,1,87,245,175,0,28,2,198,1,81,255,215,254,196,255,92,1,53,0,176,2,207,255,133,0,184,255,200,0,164,254,136,0,114,255,45,247,25,244,196,255,31,253,48,0,181,254,85,0,122,255,218,0,62,252,234,254,108,255,203,251,125,255,53,0,129,255,39,247,82,0,225,255,250,254,226,0,127,254,83,0,244,2,101,245,20,254,141,255,151,2,200,254,240,0,194,254,205,252,224,11,75,255,148,0,165,0,120,1,92,0,23,255,188,0,156,255,134,3,111,254,237,3,204,255,162,0,219,0,39,7,188,255,190,255,217,216,166,255,233,255,39,0,165,255,25,255,23,0,174,0,42,0,79,0,199,255,198,255,18,0,175,0,32,0,122,0,71,255,10,1,162,0,44,1,170,243,203,242,253,255,200,254,178,0,232,255,22,255,248,0,68,0,37,1,104,1,110,255,226,255,254,255,177,0,113,0,65,251,230,253,238,254,79,0,254,255,239,255,231,10,71,0,236,250,93,0,206,252,210,253,181,254,115,0,215,0,165,253,54,255,113,0,169,255,39,0,235,254,236,13,75,0,68,254,201,0,111,0,143,254,208,251,212,0,236,254,190,254,28,254,68,253,37,0,210,254,177,0,86,0,10,0,169,255,56,0,76,0,19,221,229,255,183,255,123,255,205,255,150,255,228,255,204,255,49,0,68,0,26,0,16,0,175,255,89,254,18,11,7,0,202,255,149,255,144,0,28,241,17,0,157,254,3,0,224,255,232,255,14,0,76,0,169,0,252,254,93,1,97,255,107,14,72,255,249,16,210,255,146,0,242,255,143,0,128,254,181,255,12,0,144,0,105,0,47,0,141,0,224,255,225,255,48,0,187,0,74,0,139,0,132,0,86,0,241,255,195,254,245,254,40,12,29,7,149,254,131,255,128,251,218,254,63,254,21,1,127,4,171,254,12,0,215,255,210,0,205,255,6,0,18,0,53,0,11,0,37,0,220,255,186,255,65,0,44,0,122,227,15,0,123,255,56,0,150,0,63,0,3,2,15,1,224,255,47,0,41,0,126,255,168,0,98,255,17,255,196,255,226,0,247,0,175,253,19,255,25,242,65,0,111,2,16,0,44,255,26,0,75,255,81,0,83,0,26,0,231,255,164,255,251,255,36,0,225,255,21,1,249,254,135,0,78,0,83,255,220,0,116,235,191,8,160,255,237,255,161,255,75,0,231,255,192,255,244,0,102,255,170,245,66,254,212,3,0,2,136,1,110,254,230,251,20,1,56,254,202,250,71,7,124,2,24,250,234,0,199,0,237,0,107,1,66,0,28,1,198,0,235,254,245,254,228,253,183,254,88,3,30,254,123,253,178,0,16,255,78,255,233,25,251,255,127,0,176,255,89,255,51,1,7,0,248,0,13,0,53,0,124,0,215,0,202,254,255,0,62,255,6,244,234,255,196,13,51,0,193,0,165,0,82,0,176,255,54,0,65,255,234,254,237,255,123,1,29,1,198,255,99,255,88,255,73,255,132,1,58,255,191,0,107,0,10,0,254,255,252,231,45,0,198,255,48,0,106,255,184,255,112,0,132,255,215,255,127,255,36,0,190,255,17,243,4,240,15,0,245,255,93,0,202,255,72,0,151,255,131,0,66,0,29,0,202,255,201,0,46,255,221,0,47,0,55,0,157,255,31,0,214,241,217,241,81,255,91,0,203,255,40,0,158,255,180,255,224,0,15,0,172,0,85,0,103,0,109,255,121,255,42,255,199,254,24,5,143,0,190,0,19,0,34,246,165,255,88,255,107,3,229,255,21,3,23,3,50,254,144,3,188,253,70,0,243,5,19,3,106,255,55,2,157,10,251,255,127,11,149,255,155,0,32,0,65,0,158,0,133,0,65,255,212,255,141,0,107,255,199,0,177,0,14,1,242,255,199,255,171,241,51,15,98,255,239,0,239,255,52,0,244,0,169,254,138,255,186,0,202,255,122,255,106,0,123,255,140,255,186,0,107,255,130,252,234,255,113,254,1,0,32,1,108,240,252,254,113,0,66,0,236,254,179,0,30,255,119,0,164,1,51,0,29,254,39,2,129,0,245,0,221,7,127,2,169,255,194,19,41,0,203,255,140,255,126,255,33,255,152,255,8,253,20,1,117,0,82,1,119,255,23,255,191,255,119,0,100,0,83,243,2,0,37,15,126,0,172,0,254,255,184,255,103,255,200,0,147,255,194,255,135,0,194,0,174,255,106,255,98,0,38,2,5,255,238,254,71,0,160,0,121,0,243,255,147,254,100,1,44,255,241,254,203,19,53,255,5,255,222,0,75,0,125,255,17,0,103,0,113,252,164,254,230,255,6,0,110,0,120,0,123,253,99,1,119,253,124,255,168,242,65,0,58,250,205,1,147,255,2,1,241,255,192,255,11,0,182,255,160,255,39,0,184,23,16,0,46,0,41,255,137,0,77,0,128,0,61,255,64,255,169,255,96,0,123,1,183,255,111,1,181,1,146,254,84,0,101,255,227,255,187,255,195,255,222,255,127,255,4,1,79,255,154,14,227,2,35,255,242,255,216,255,2,0,29,254,243,254,104,10,166,0,29,0,0,255,30,0,92,0,51,0,111,0,211,255,53,15,90,0,226,255,157,255,12,0,74,0,201,0,204,255,160,255,60,255,171,255,220,255,123,0,212,255,188,255,2,0,218,33,33,0,215,255,24,0,244,255,204,255,69,0,59,0,229,255,38,0,108,255,201,255,236,255,196,255,50,0,35,13,30,0,165,14,164,255,228,0,173,0,17,255,89,255,181,255,177,255,170,255,39,255,32,0,34,0,119,255,243,255,17,0,128,255,74,250,86,255,32,255,119,254,201,242,37,251,209,255,24,0,33,255,26,0,55,1,169,254,209,255,16,3,203,1,220,253,46,2,215,3,103,0,13,1,32,0,13,0,19,0,172,255,219,255,227,255,209,255,114,231,7,0,48,0,156,255,13,0,11,0,241,254,170,255,115,0,239,255,183,0,175,12,248,242,57,0,189,255,139,255,169,255,19,0,74,0,241,254,237,0,232,255,242,0,49,0,77,255,42,1,85,0,187,255,72,1,18,255,222,255,103,0,206,255,79,0,2,0,229,255,240,255,153,255,195,255,236,22,151,255,250,254,74,0,182,255,98,255,7,1,146,255,154,0,212,0,253,255,172,255,130,255,25,0,189,255,59,246,244,255,221,255,139,0,3,1,161,255,115,255,137,0,90,0,12,0,12,255,114,255,58,1,15,0,132,255,1,0,231,255,229,255,254,255,250,255,28,0,208,255,239,255,254,255,43,0,67,0,42,0,63,35,231,255,19,0,243,255,233,255,213,255,73,0,226,255,143,0,255,255,68,11,114,255,252,255,221,13,207,255,146,254,110,0,58,1,19,0,201,255,107,1,204,0,213,1,189,0,217,0,75,255,119,0,41,0,123,255,29,0,201,255,162,255,71,0,207,255,41,0,85,0,242,255,252,23,71,0,114,255,10,0,18,0,169,0,136,0,26,1,207,255,36,0,190,1,157,255,7,1,92,0,153,8,129,255,43,0,113,255,162,254,36,0,133,1,48,255,15,0,230,241,237,254,127,1,63,6,77,255,79,255,180,251,252,255,67,0,218,255,2,0,22,1,39,0,107,0,136,255,209,1,204,0,115,254,49,1,160,1,7,0,250,254,68,0,37,9,189,0,181,255,233,255,25,0,236,255,182,255,56,0,213,255,131,255,170,0,253,1,63,0,26,0,7,1,27,253,225,255,8,0,216,254,101,0,20,0,107,255,30,11,38,255,123,1,202,254,151,0,133,3,84,0,171,255,173,255,125,254,161,0,226,243,98,255,74,254,38,0,191,0,198,255,54,255,127,0,126,0,168,255,82,254,251,243,219,248,180,254,61,0,104,255,242,255,224,255,100,255,251,255,137,254,197,251,246,235,110,0,77,0,55,255,241,255,4,0,13,0,86,0,119,0,67,0,149,0,80,0,8,1,3,255,135,255,63,0,193,0,153,255,127,255,63,0,120,0,30,255,156,255,124,12,72,0,245,255,8,0,200,255,23,1,183,255,64,255,47,0,169,255,125,0,213,255,148,255,21,1,188,0,149,255,33,1,78,23,236,255,209,254,178,255,235,255,40,0,117,255,44,0,28,0,6,0,2,255,12,255,47,0,255,255,105,255,29,0,168,254,242,246,30,0,73,241,114,0,84,0,101,255,85,0,166,255,155,0,111,0,6,254,6,0,197,1,15,255,215,0,131,0,222,252,15,0,169,254,176,0,82,254,251,0,182,255,6,0,215,255,212,255,125,255,151,255,8,255,90,1,39,0,84,238,93,0,136,255,177,255,247,252,96,254,198,253,35,255,21,0,28,0,204,255,56,0,71,0,69,255,133,11,29,246,154,2,31,3,119,255,202,3,243,0,73,253,108,255,231,254,70,1,194,1,34,253,157,255,226,247,112,0,173,255,166,255,178,255,6,1,118,255,225,255,251,255,182,255,85,255,157,255,88,1,143,0,195,15,56,0,135,255,103,252,248,255,46,0,224,17,97,0,37,255,222,255,123,0,212,255,255,255,85,0,220,255,143,1,252,254,25,255,132,0,194,254,55,0,75,255,156,0,235,243,142,0,247,255,166,242,225,255,43,0,126,0,136,0,53,1,206,255,236,255,170,0,166,255,188,0,83,255,175,0,50,0,144,0,12,255,22,0,64,0,36,254,234,255,190,255,16,1,255,14,203,2,68,255,174,255,6,255,181,253,10,0,112,1,5,254,242,0,216,255,237,253,195,1,35,0,48,2,149,255,138,0,15,0,113,0,56,0,242,0,33,0,233,255,229,255,81,0,99,255,45,1,185,254,103,1,64,14,62,0,47,250,89,255,136,0,217,255,183,0,53,0,105,255,240,255,196,255,191,255,194,235,239,255,255,254,246,255,56,0,152,255,201,2,254,255,72,1,72,0,97,1,43,0,205,255,195,232,40,0,32,0,174,255,220,255,234,255,57,0,56,0,55,0,112,0,152,255,76,0,5,0,80,0,227,255,173,0,152,254,143,255,42,0,137,255,180,0,230,255,120,0,250,0,48,244,198,0,115,0,116,255,22,0,136,0,19,1,186,2,107,255,187,2,170,1,36,255,23,1,63,0,55,0,193,255,148,255,205,255,186,255,186,255,163,1,100,255,238,22,33,0,199,255,142,255,124,254,43,255,92,255,7,6,117,0,165,0,152,7,223,0,173,255,46,0,201,0,12,0,153,255,228,0,139,0,49,255,136,0,62,251,224,253,45,253,90,0,116,253,25,3,255,255,156,255,224,255,20,255,49,0,164,0,138,0,16,0,82,0,107,243,194,255,88,255,62,0,199,254,98,0,116,253,28,254,172,2,165,255,33,0,146,244,131,242,54,2,34,0,35,0,104,0,13,0,189,0,235,0,207,255,188,254,126,0,226,0,154,255,123,0,3,255,109,254,38,0,160,0,251,255,100,0,226,255,16,0,237,255,212,255,2,0,186,255,226,255,82,0,118,0,6,0,132,0,241,255,220,255,59,0,125,221,64,254,123,14,68,1,87,0,67,0,146,255,114,0,180,255,38,1,98,1,7,0,140,0,11,0,84,1,139,255,209,253,67,0,129,0,201,0,198,254,72,1,47,255,102,0,135,255,122,1,110,236,140,0,53,0,15,0,3,255,242,255,158,1,73,255,186,255,231,255,205,255,34,0,165,254,85,255,146,0,158,255,155,255,253,255,157,255,96,0,66,0,50,0,251,255,141,255,233,255,211,255,161,254,150,239,143,0,224,1,210,255,140,0,17,0,88,231,146,255,233,255,150,0,60,0,217,255,247,255,208,255,196,255,248,255,236,255,37,0,57,0,94,255,60,0,119,255,55,0,155,255,65,0,100,0,8,221,3,0,207,255,253,255,247,255,28,0,15,0,167,255,120,255,59,0,125,0,183,255,221,255,145,255,187,255,228,255,111,0,240,255,48,0,27,0,56,36,55,0,34,0,164,255,66,0,3,0,3,0,218,255,12,0,59,0,95,0,156,255,3,0,51,0,121,0,146,0,56,255,142,0,2,255,65,0,3,0,87,255,248,255,191,255,44,0,10,0,15,0,157,255,56,0,250,255,148,255,236,255,171,234,167,255,139,1,37,8,230,1,208,255,68,1,166,1,137,241,212,1,198,0,239,0,0,0,235,254,141,255,29,255,227,0,227,255,159,0,128,255,65,254,221,254,95,248,146,255,25,0,226,8,141,0,177,0,204,0,38,0,254,254,90,0,248,255,125,255,180,245,55,0,49,2,157,255,36,255,223,255,142,0,178,254,96,255,139,255,244,255,223,255,6,0,72,0,253,255,245,255,50,0,1,0,211,255,8,0,23,0,241,255,223,255,241,255,30,0,224,255,107,0,145,0,14,0,60,0,114,0,45,0,24,0,107,34,247,255,61,0,192,0,16,0,124,0,46,0,202,255,225,255,89,0,109,255,144,255,13,13,117,254,91,0,189,254,45,0,100,255,25,0,238,255,34,0,234,253,118,0,83,0,69,255,164,255,180,0,34,0,147,2,135,0,103,0,218,246,54,0,6,0,179,0,40,0,143,0,232,0,238,240,55,255,179,0,32,0,200,255,150,1,20,255,29,2,186,255,168,255,135,255,191,1,212,11,33,255,138,0,211,253,230,0,129,13,96,0,252,255,234,255,243,255,120,255,211,255,133,255,248,255,107,0,14,1,132,0,192,255,224,255,208,1,223,255,212,255,16,246,5,255,10,255,185,255,33,240,40,0,107,0,128,1,234,255,59,255,64,0,166,0,119,255,212,255,98,0,221,255,193,0,4,0,201,247,57,0,147,255,245,0,159,13,201,255,196,255,21,0,187,0,245,254,23,1,3,0,166,0,178,255,108,0,121,255,126,0,134,255,171,0,123,255,235,255,122,255,183,0,25,0,200,255,190,231,107,0,109,0,22,0,163,255,39,0,95,0,43,0,245,255,212,255,251,255,174,255,6,0,202,255,229,255,140,255,240,255,84,0,44,0,22,0,188,255,255,255,199,255,78,0,35,0,83,0,56,18,46,0,1,0,92,255,229,12,154,254,83,241,236,0,104,0,175,255,135,255,234,254,144,255,236,255,89,0,133,255,35,0,113,0,17,0,181,254,17,1,84,255,125,0,183,255,77,0,211,9,152,240,86,255,169,255,174,0,84,0,142,0,138,0,13,0,227,0,127,0,146,0,141,0,196,0,38,0,216,255,144,255,136,0,7,9,72,1,87,0,234,255,179,255,222,255,61,255,58,0,179,254,81,1,97,255,114,2,64,244,152,1,11,2,196,254,27,2,181,253,175,255,248,244,98,0,200,0,101,2,149,255,86,255,90,251,97,4,9,2,229,0,39,255,143,0,144,0,32,251,128,254,255,5,214,1,113,253,236,1,83,254,230,255,124,255,76,255,52,0,97,0,10,0,221,255,196,255,7,0,210,234,230,255,154,0,124,255,35,255,124,0,136,0,239,255,188,255,25,0,29,0,4,0,5,0,241,255,9,0,69,0,240,255,209,255,180,255,5,0,41,0,6,0,234,255,63,0,248,255,237,37,223,255,138,2,223,253,97,255,81,0,181,255,54,0,164,255,207,255,176,255,14,0,178,255,111,255,113,254,161,240,186,0,136,251,207,0,60,0,30,1,82,10,44,0,117,0,174,14,102,255,170,1,75,1,153,253,40,255,15,1,135,255,147,255,239,1,42,0,45,3,237,255,33,2,107,255,121,2,136,246,215,247,9,1,120,255,198,255,4,0,228,255,147,0,2,0,133,255,163,255,14,0,206,255,61,1,131,0,126,255,104,255,66,1,255,3,92,241,20,241,151,255,16,0,234,255,249,255,112,0,242,255,52,0,28,0,214,255,143,255,132,0,175,255,248,255,144,255,19,0,33,0,5,255,117,0,223,255,247,255,243,255,228,255,60,0,226,255,29,0,27,0,198,255,249,255,4,0,43,0,132,216,218,255,253,255,48,0,3,0,233,255,202,0,81,255,54,255,71,0,161,247,3,0,174,255,218,255,143,255,141,0,38,0,190,255,138,255,218,255,242,255,148,0,248,254,143,0,243,255,200,255,247,255,235,255,228,255,226,34,233,255,53,0,216,255,30,0,72,0,210,255,26,0,66,0,22,0,32,0,44,0,22,0,206,255,190,255,141,255,115,255,24,0,59,244,124,242,236,1,207,0,194,255,201,253,134,0,230,255,192,255,31,1,87,1,43,255,42,0,238,254,112,255,112,255,179,255,230,255,217,255,4,0,252,255,42,0,43,0,30,0,240,255,34,0,113,0,75,36,85,255,239,255,24,0,203,255,229,255,45,0,42,0,21,2,146,0,191,255,32,0,156,0,112,255,5,11,121,3,249,255,102,2,11,0,1,0,39,254,178,1,147,2,189,254,112,246,23,0,118,255,186,253,180,1,104,255,226,255,29,0,222,254,210,254,55,12,240,1,14,0,166,254,186,255,201,1,72,248,27,255,53,0,227,247,199,254,58,0,33,0,165,255,81,255,141,0,168,10,160,12,154,247,245,0,114,255,13,0,194,254,70,0,104,255,192,255,132,0,190,254,44,0,30,0,186,255,72,255,177,1,231,255,159,255,13,248,145,0,47,0,128,2,179,0,71,254,48,0,148,255,206,6,232,254,33,0,69,243,79,0,109,255,68,1,176,255,65,0,48,0,90,0,249,255,235,255,22,0,3,0,56,0,226,255,14,0,254,255,145,255,22,0,248,255,196,223,153,255,220,255,57,0,53,255,31,1,55,245,36,255,143,0,11,0,243,241,21,0,175,255,62,0,157,255,41,0,84,255,108,0,29,0,95,1,142,254,15,0,134,255,49,255,19,1,163,255,56,245,144,1,44,255,225,0,230,0,17,255,54,242,183,255,211,0,32,1,85,0,250,255,134,253,57,0,178,255,105,1,107,255,205,248,233,255,17,0,219,255,185,255,82,255,19,255,42,0,234,255,13,255,63,0,155,255,131,0,35,0,136,0,71,240,41,0,250,254,199,255,197,0,222,254,51,1,35,0,240,255,3,0,251,255,45,0,249,255,1,0,209,255,41,0,237,255,79,0,78,0,42,0,171,255,74,0,98,254,160,6,191,2,41,1,32,243,108,0,222,253,105,4,44,0,191,1,79,254,59,1,12,252,133,0,141,0,27,4,89,2,238,255,236,253,226,255,200,2,129,255,46,255,10,0,138,9,161,255,210,255,242,255,77,0,32,0,245,255,10,0,153,255,241,255,125,2,196,255,96,1,182,2,54,255,28,1,108,234,92,0,174,255,5,0,140,0,202,255,141,255,45,0,31,1,242,255,205,254,170,254,10,0,75,255,50,0,226,255,250,255,160,39,77,0,42,0,13,0,26,0,236,255,34,0,10,0,37,0,219,255,209,255,90,0,251,255,212,255,171,255,192,255,205,255,255,255,16,0,104,255,165,255,212,0,4,0,231,255,19,255,20,232,22,0,136,255,255,255,171,0,239,255,213,255,141,0,243,255,199,255,71,255,80,0,17,1,19,254,178,0,45,0,11,0,199,255,16,0,233,255,226,255,219,255,82,0,4,0,243,255,126,255,98,0,16,1,62,254,95,255,133,0,240,19,14,0,224,17,63,255,11,0,55,0,226,255,1,0,123,0,247,254,172,255,172,254,238,255,152,0,232,255,246,254,33,0,166,255,148,255,129,253,126,6,43,1,242,255,123,254,71,18,30,255,21,0,55,1,218,254,159,0,47,255,172,0,184,0,36,1,139,254,169,0,84,0,55,0,243,254,173,5,206,255,41,0,68,0,247,255,194,255,35,0,23,0,124,255,96,0,58,0,134,255,140,240,194,254,210,0,139,255,166,2,152,255,122,1,182,252,61,0,245,9,37,0,149,0,0,254,70,0,101,244,225,0,101,254,230,0,42,255,185,2,198,255,153,252,231,254,128,255,52,255,219,255,128,255,51,0,82,255,107,254,241,1,153,238,37,255,124,0,136,255,63,0,135,0,201,0,134,255,77,254,91,253,221,0,138,0,230,1,23,2,81,12,165,0,11,0,237,254,94,0,156,255,69,0,52,0,189,255,26,253,212,0,16,0,163,255,84,254,95,3,239,255,95,246,255,2,221,255,126,255,97,0,107,5,34,0,72,0,233,255,239,255,29,11,166,255,185,255,213,0,35,1,87,0,58,3,193,255,189,0,129,2,0,255,64,3,39,8,57,255,86,255,63,255,194,255,249,255,37,0,196,255,75,239,213,255,24,0,187,255,62,2,93,255,143,255,7,1,170,255,45,0,171,0,51,4,102,255,217,255,121,0,74,0,124,255,182,0,34,0,13,0,234,254,215,255,96,0,204,2,35,255,142,253,181,4,244,0,161,254,74,15,178,255,224,255,17,11,106,255,219,255,95,0,29,255,172,255,152,242,57,0,238,0,113,255,147,254,39,0,27,0,18,255,205,254,86,255,124,0,66,0,123,255,40,0,62,0,237,255,42,0,190,255,2,0,176,255,254,255,60,0,7,0,10,0,7,1,133,236,187,255,123,254,62,0,203,255,190,255,24,0,169,255,13,0,34,0,241,255,231,255,236,255,197,0,9,0,101,0,173,255,177,255,100,255,156,255,2,0,148,255,55,22,99,255,110,3,64,249,32,0,72,0,190,255,70,0,254,255,210,255,93,255,206,0,17,0,247,0,158,11,190,255,74,5,79,1,238,0,7,255,102,254,215,253,98,1,215,255,132,0,160,255,68,0,126,8,183,254,198,255,180,255,6,0,17,12,28,1,238,254,114,254,215,1,27,1,171,1,36,255,81,0,116,10,40,0,233,255,210,255,251,0,109,0,13,244,50,0,231,255,217,253,124,0,123,254,228,0,95,0,56,0,216,250,177,255,3,4,182,236,151,255,174,255,13,0,97,255,52,0,155,255,23,0,36,255,179,255,103,255,113,0,230,254,42,0,185,0,112,255,110,254,46,0,112,255,157,255,210,244,152,242,254,255,16,0,224,255,23,0,231,255,111,255,181,0,49,0,6,0,20,255,30,255,228,255,234,0,230,255,167,255,242,255,157,254,146,0,117,0,206,255,76,0,246,255,185,1,161,255,254,255,90,1,14,255,95,241,116,3,207,254,72,255,94,1,18,0,219,254,184,254,1,1,109,0,49,0,157,0,212,255,186,255,35,0,6,0,89,0,11,240,89,255,249,254,197,255,35,0,243,255,174,1,44,255,17,0,150,253,251,255,248,220,114,0,41,0,73,0,171,255,122,0,5,0,38,0,19,0,196,255,14,0,220,255,214,255,167,255,20,0,85,0,239,255,20,0,26,1,188,242,231,255,138,14,151,0,73,255,100,0,106,255,19,0,35,255,126,0,34,0,235,255,72,0,28,0,138,0,166,255,30,0,162,0,46,0,40,0,27,0,15,0,201,255,235,255,38,0,55,0,32,0,83,0,203,37,31,0,26,0,254,255,4,0,96,0,205,255,120,0,124,255,213,0,58,8,39,0,5,255,98,0,244,245,83,254,181,254,156,5,30,8,79,1,131,254,115,1,43,1,83,1,44,1,115,255,157,255,209,254,136,11,49,0,93,0,40,0,147,240,211,255,50,0,41,255,73,0,217,255,91,255,229,254,46,0,133,255,165,254,23,0,98,255,41,0,20,0,41,0,210,255,19,0,34,0,86,0,190,221,40,0,20,0,224,255,226,255,240,255,77,0,72,0,252,255,92,0,222,255,103,0,179,255,128,0,236,253,198,254,24,0,216,2,49,0,220,255,78,255,76,0,22,0,242,255,92,255,62,255,69,0,61,12,239,3,126,255,232,254,198,9,226,1,254,255,45,0,194,255,249,255,162,255,17,0,23,0,252,255,44,37,229,255,11,0,22,0,54,0,243,255,2,0,254,255,6,0,234,255,193,255,67,0,82,253,130,0,124,247,132,255,57,0,195,255,98,255,36,13,6,2,4,0,59,1,145,254,153,255,217,254,3,1,171,253,56,0,250,255,72,0,170,255,211,255,243,255,209,255,243,255,229,255,253,255,48,0,244,255,204,255,250,255,242,255,230,255,240,255,222,255,82,37,80,0,91,0,242,254,1,0,135,255,117,0,33,0,8,0,40,0,157,255,177,255,43,0,133,242,164,255,186,255,199,255,43,0,68,0,64,0,28,1,129,253,202,1,118,0,202,255,61,245,114,1,190,255,54,0,27,0,58,255,75,1,115,0,216,255,47,255,200,254,82,0,240,255,8,0,230,0,212,0,61,7,162,255,165,7,138,255,153,0,243,255,183,255,71,0,116,0,184,255,43,243,106,0,19,0,135,255,177,0,212,254,199,1,227,255,94,0,190,0,235,255,248,255,201,0,16,0,2,0,83,0,120,231,32,0,238,255,59,0,238,255,215,255,124,255,22,0,1,0,217,255,44,255,58,255,186,0,82,12,154,255,135,13,232,254,138,255,124,255,124,255,63,0,237,255,97,1,232,255,179,255,224,0,82,0,143,0,191,255,165,0,240,255,66,241,215,13,228,255,212,255,93,0,211,255,243,255,232,255,251,255,216,255,58,0,3,0,89,0,71,0,113,0,46,0,62,0,44,0,160,0,179,255,248,255,197,255,151,230,134,0,214,255,183,255,0,0,85,0,2,0,16,0,34,0,157,0,222,255,196,255,78,0,24,0,64,0,96,0,222,1,231,0,131,255,39,255,13,0,21,0,44,0,83,0,198,0,187,255,21,0,89,255,204,255,245,15,22,255,119,254,17,0,66,254,158,254,228,255,42,0,53,0,219,255,28,0,15,0,240,255,246,255,171,255,255,36,240,255,167,255,169,255,200,255,52,0,159,255,86,0,249,255,153,255,244,255,71,0,217,255,17,0,216,255,23,0,63,0,65,0,237,255,242,255,150,255,29,0,235,37,255,255,244,255,1,0,170,255,100,0,7,0,73,4,10,1,252,0,197,0,192,255,42,255,59,255,228,255,3,15,215,249,54,1,139,255,82,2,13,0,90,0,203,254,128,254,134,0,166,255,62,255,196,254,68,11,156,0,71,255,196,0,153,255,75,0,241,3,69,0,0,3,181,255,163,253,48,250,133,1,242,0,112,1,22,1,134,255,60,246,121,0,7,0,209,254,91,0,246,255,58,14,23,0,147,255,243,255,138,0,107,254,18,0,213,255,3,0,42,0,194,0,144,255,237,0,63,247,23,0,40,1,173,255,242,255,198,255,93,255,248,255,82,255,17,255,85,0,148,255,174,255,177,255,88,1,236,0,85,254,127,0,52,0,24,9,183,0,116,6,117,252,67,244,49,5,195,255,47,254,0,0,59,254,171,249,223,0,232,0,197,255,254,0,200,254,139,255,197,255,35,254,168,245,104,251,29,255,111,248,194,3,141,0,47,250,81,3,93,0,252,250,232,3,39,1,192,0,117,255,44,254,32,253,76,254,107,8,115,1,171,9,164,254,88,3,63,248,38,0,94,0,240,1,246,2,186,3,13,255,134,0,33,249,235,1,130,250,90,4,6,246,65,254,76,253,176,247,44,0,101,252,74,6,19,3,150,0,12,254,114,13,70,253,20,1,251,253,237,249,123,1,184,255,42,3,163,250,81,11,168,3,182,253,74,254,157,3,89,7,93,254,211,0,188,6,209,2,117,3,102,2,253,0,101,2,96,250,253,1,74,3,153,246,40,255,27,249,195,1,139,5,87,2,177,2,193,5,81,255,98,244,9,252,191,7,188,255,128,2,21,0,140,0,241,250,212,253,167,255,188,252,206,2,169,254,145,248,187,1,246,1,216,251,48,5,86,0,1,8,211,4,130,0,124,3,81,4,180,2,104,244,13,253,217,1,167,1,165,250,16,248,93,7,227,255,252,253,162,251,29,1,226,1,164,0,116,248,83,253,205,252,183,2,203,2,16,250,20,5,92,251,135,255,59,255,119,239,115,255,255,4,43,1,208,0,47,4,20,0,4,3,180,2,19,2,1,1,172,1,78,0,202,0,113,254,229,255,25,3,126,4,32,253,132,1,126,248,155,0,102,254,85,0,111,4,67,3,133,0,168,255,65,0,62,0,234,253,120,255,18,238,94,255,56,252,98,5,67,254,247,244,163,255,249,253,146,1,12,0,170,251,131,253,3,253,210,0,255,246,142,2,191,1,26,0,247,254,165,255,71,0,138,252,126,0,147,255,7,0,90,1,19,0,55,253,255,254,6,3,56,4,189,253,185,0,200,0,197,233,29,2,228,0,168,1,37,0,0,2,178,255,55,255,80,3,143,254,75,4,23,252,214,0,176,254,10,1,198,9,47,6,173,247,114,253,84,246,159,255,237,252,30,253,32,4,105,5,124,0,176,3,163,242,148,4,221,253,30,255,225,4,16,6,170,4,204,254,233,1,128,251,239,2,164,255,88,255,216,243,85,250,246,7,35,0,115,1,207,249,23,2,52,1,5,0,203,255,11,2,87,255,79,2,81,255,252,251,91,0,231,2,112,255,230,0,39,7,79,255,253,1,11,5,16,7,6,243,209,252,29,255,37,254,216,251,121,253,79,0,199,4,174,0,246,255,100,254,137,1,207,254,200,4,30,5,12,0,247,253,13,251,119,7,197,8,151,1,212,2,48,251,31,248,54,2,250,1,45,254,45,3,148,2,60,255,197,241,191,9,102,3,207,253,33,1,150,2,142,2,4,254,34,253,187,254,110,2,220,0,203,254,205,254,75,255,67,254,131,0,137,249,189,252,137,253,115,3,211,0,225,2,40,2,143,252,225,243,2,253,83,2,112,0,151,0,103,251,89,2,223,1,242,255,37,0,98,252,7,254,38,4,37,249,225,252,78,255,213,253,205,9,74,253,232,252,150,2,225,2,79,3,75,6,141,1,189,255,122,255,218,1,53,247,138,10,11,255,6,8,67,6,11,5,164,4,40,0,251,2,40,255,18,6,215,254,23,249,154,1,246,4,65,4,184,1,57,252,38,1,219,255,14,1,215,1,7,5,189,14,148,255,158,253,237,254,214,254,14,1,128,254,24,8,93,253,234,3,174,0,18,0,171,0,192,2,239,12,151,255,18,249,108,0,255,1,71,244,187,255,31,2,29,255,84,251,151,5,193,255,6,0,255,4,255,255,159,2,239,0,177,247,124,248,90,252,168,0,212,254,51,4,47,4,16,12,178,253,159,5,73,1,49,4,127,0,250,2,125,255,18,1,69,3,122,255,158,253,113,254,121,250,23,4,100,255,159,1,253,2,186,2,172,1,20,253,241,0,126,239,152,0,195,252,16,4,87,252,145,0,172,252,171,255,115,244,126,255,106,254,214,2,168,0,219,255,215,250,211,251,25,251,135,4,39,6,40,2,137,2,95,248,239,255,3,4,54,4,127,254,55,245,215,253,55,255,58,0,148,248,232,255,27,1,224,4,166,255,163,1,98,4,134,3,244,249,224,255,34,0,152,254,195,2,45,0,126,242,10,255,31,1,52,1,141,1,137,1,54,3,43,5,203,253,249,1,239,249,146,248,91,253,113,2,55,4,121,255,172,247,69,255,93,255,23,252,57,250,92,252,107,4,228,245,196,254,53,0,246,4,21,253,58,252,212,3,242,0,246,254,217,249,134,251,163,253,245,253,35,255,73,2,237,252,85,5,226,254,73,255,155,1,34,2,171,18,226,254,190,253,155,255,53,1,128,3,34,0,195,1,2,252,69,253,170,0,167,3,202], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1615045);
/* memory initializer */ allocate([1,47,16,229,0,196,253,112,252,115,254,216,255,124,255,58,255,98,0,190,248,100,2,101,0,158,255,238,255,163,254,66,1,166,249,24,5,17,1,21,255,162,1,3,254,121,15,19,254,16,4,96,254,16,7,161,0,163,5,28,4,52,254,55,0,189,255,41,0,2,2,25,5,188,252,156,249,73,5,123,1,147,0,142,1,26,241,89,253,235,0,71,1,11,247,52,253,210,4,40,253,189,254,186,2,200,7,4,0,237,254,176,3,127,3,212,0,78,1,29,1,58,253,133,252,211,250,35,12,3,0,111,1,13,249,44,1,156,252,197,255,124,253,186,254,111,0,11,1,213,255,165,1,208,3,57,0,181,5,84,255,245,0,68,255,40,1,41,255,149,20,210,255,177,0,199,0,229,253,92,0,226,253,251,0,183,3,25,255,117,0,188,253,126,252,146,1,79,3,4,0,128,1,41,255,161,0,57,248,70,17,157,9,61,251,17,253,51,7,203,5,48,4,61,10,240,255,123,251,243,0,211,253,139,2,185,3,220,1,95,254,235,253,249,1,178,253,201,2,153,0,244,4,200,254,39,255,132,255,102,3,28,254,17,253,95,255,129,3,243,2,201,252,21,16,225,250,39,253,191,1,126,253,161,3,152,246,174,254,57,252,152,255,232,251,88,247,70,249,132,255,52,255,60,255,124,251,180,5,135,1,225,253,120,0,70,0,204,0,161,4,70,246,134,11,5,254,153,253,219,4,106,255,149,254,37,254,237,253,15,3,159,2,51,255,177,253,217,0,245,253,7,1,242,255,71,0,190,3,95,251,251,251,182,254,71,1,63,253,205,4,147,244,131,0,17,254,220,6,53,8,185,1,245,255,133,0,250,4,229,4,102,255,4,3,10,2,189,6,235,254,12,252,42,253,59,5,80,251,15,255,140,6,206,3,208,8,91,1,183,10,202,5,30,253,15,255,156,252,242,250,104,253,87,3,207,250,178,239,145,249,152,255,101,0,51,1,121,253,201,252,91,1,4,0,136,255,168,251,78,1,27,0,9,1,222,3,63,1,122,250,57,1,165,253,52,0,190,243,16,6,156,253,170,252,114,2,212,0,5,3,30,9,150,2,102,2,48,2,77,2,235,253,57,5,229,0,45,2,230,255,178,5,142,253,98,7,88,9,11,250,255,3,155,2,81,254,72,0,155,6,247,3,159,255,253,253,100,5,28,3,168,4,217,255,162,0,251,244,144,11,22,6,222,251,47,5,25,3,207,4,25,253,90,251,11,255,29,0,230,1,18,254,165,250,97,6,190,255,242,248,231,0,104,253,109,255,98,9,184,253,217,1,241,253,248,4,208,1,199,7,17,252,21,255,101,1,201,0,104,251,171,254,223,0,209,255,215,247,47,3,49,0,192,0,49,253,239,251,8,255,230,11,216,255,11,254,166,254,189,250,111,254,57,0,204,249,241,251,187,1,78,2,191,251,74,255,171,250,11,252,179,240,130,254,158,255,1,4,205,255,186,2,59,255,80,3,181,255,60,6,104,254,252,248,137,243,131,4,234,0,156,255,186,2,59,2,47,251,197,254,34,250,121,253,197,253,190,254,74,3,232,251,165,251,0,32,240,252,40,254,17,0,50,253,37,0,166,4,119,254,146,0,221,253,90,0,79,254,191,254,137,251,11,254,212,1,235,0,26,254,192,255,90,247,182,254,187,252,190,4,129,255,197,2,253,255,111,2,128,254,221,0,41,1,241,252,38,241,104,254,245,255,61,253,92,0,237,254,244,254,139,255,44,6,186,5,198,2,236,250,142,0,22,253,111,6,95,9,49,251,114,0,196,4,168,251,114,3,211,1,51,252,48,252,15,15,121,253,106,255,36,251,205,3,148,254,102,255,217,1,93,253,207,252,166,254,246,254,255,252,155,253,36,254,157,4,248,255,226,251,149,1,0,253,105,5,194,249,132,252,160,2,119,247,83,0,229,255,70,2,78,254,80,252,99,0,136,252,134,249,20,250,88,9,214,2,34,255,28,1,68,1,240,18,189,255,242,252,211,255,168,1,53,255,62,255,51,251,142,255,67,255,40,255,19,1,89,252,163,255,117,0,67,249,104,1,255,245,237,249,81,251,255,252,227,254,74,0,243,4,125,254,88,5,179,0,143,255,184,3,1,4,213,2,226,253,70,255,234,4,140,250,21,253,60,2,91,2,173,7,100,253,244,255,48,246,57,5,1,255,254,0,237,8,112,4,117,5,45,2,97,253,131,251,154,253,50,254,111,252,60,254,182,4,150,244,229,1,142,252,14,1,227,250,163,253,235,255,188,253,252,250,62,255,169,0,246,246,40,255,27,255,100,4,103,0,75,251,220,5,94,4,176,5,131,251,12,3,45,254,127,254,73,2,218,251,33,1,228,242,198,0,203,254,202,254,91,0,44,0,135,254,136,253,31,253,252,253,30,0,245,252,73,0,30,254,53,18,237,254,38,0,136,253,223,1,167,254,106,254,76,0,48,255,26,255,80,0,36,255,199,254,203,0,253,255,204,6,125,255,5,3,226,255,116,1,255,2,137,6,254,252,254,12,50,6,234,0,152,1,255,254,218,1,184,253,34,252,98,5,184,2,47,0,156,253,199,254,189,0,132,240,27,3,223,254,202,0,75,254,144,249,117,1,244,252,232,255,72,252,123,0,182,1,29,3,27,2,31,254,191,0,35,1,37,0,234,252,191,254,168,17,207,255,231,254,211,0,176,248,180,254,225,250,0,254,90,252,245,255,112,0,133,1,67,255,23,250,228,5,199,251,185,0,169,255,20,12,17,2,90,255,85,255,144,249,240,9,96,8,253,254,80,253,167,251,185,255,131,1,170,4,35,253,175,0,88,3,48,252,12,1,77,2,19,249,86,254,147,255,186,4,26,254,41,1,195,0,33,252,249,249,80,254,166,4,191,251,237,253,91,254,80,0,31,255,98,1,25,255,98,253,213,254,146,241,2,254,142,252,31,0,244,10,220,1,34,254,105,7,174,2,214,251,58,251,142,252,138,254,85,254,72,250,189,3,37,2,69,251,52,255,38,255,124,250,223,253,56,252,175,3,170,254,80,0,231,254,7,255,56,252,96,13,218,246,44,255,181,3,89,255,241,254,95,2,186,252,94,254,133,252,114,254,147,252,138,0,117,6,246,251,45,246,173,250,1,250,148,254,176,1,188,254,160,251,251,5,151,1,70,253,140,1,69,1,152,5,134,2,217,10,174,0,188,252,163,253,209,8,62,4,136,252,92,1,36,0,1,2,181,8,7,6,13,5,94,0,140,9,194,253,250,251,165,3,247,255,100,253,43,2,90,1,255,1,203,2,63,240,153,1,213,254,90,255,188,2,208,253,182,3,15,251,11,255,138,5,174,250,236,255,102,3,152,0,174,3,181,254,190,255,227,0,70,255,251,0,208,241,223,251,35,252,250,248,155,3,30,2,138,253,73,11,128,255,195,5,159,255,60,252,164,252,22,2,39,255,22,253,181,0,65,1,17,252,35,10,101,254,18,5,123,2,54,1,163,7,239,255,78,3,200,252,245,255,72,252,208,0,72,1,221,253,194,251,201,5,248,254,218,249,251,13,244,1,242,0,14,4,250,251,97,1,181,255,204,247,165,254,102,10,182,246,5,1,210,0,129,251,13,2,35,1,112,1,56,255,66,253,105,0,116,255,175,255,151,2,52,253,78,1,196,4,239,0,21,0,114,0,45,1,150,248,63,14,210,254,38,2,23,254,28,254,171,252,238,254,229,5,93,254,182,254,159,251,150,245,203,9,147,253,206,252,164,4,187,255,139,252,231,0,60,1,45,7,28,253,69,255,154,255,124,4,195,4,133,255,84,3,130,4,27,0,139,0,168,254,108,254,147,251,169,1,97,1,145,0,133,255,179,0,49,0,52,233,197,253,39,0,18,1,218,255,55,254,172,0,176,255,81,2,71,248,181,254,91,254,173,7,232,6,143,255,64,0,224,8,219,1,117,8,210,0,105,3,205,252,245,2,137,255,238,253,105,250,137,247,19,250,160,252,36,4,16,253,170,250,45,9,97,253,156,4,77,255,10,0,62,254,13,3,225,252,233,250,119,254,195,255,143,255,5,8,218,253,181,252,4,4,4,248,185,245,148,250,54,4,171,0,5,2,240,1,96,252,97,249,42,1,196,2,211,253,122,0,107,252,59,255,89,254,118,4,116,0,240,253,183,253,42,254,224,1,144,1,253,17,128,1,114,255,57,0,220,246,29,250,189,255,139,3,0,32,100,1,238,255,64,253,16,2,224,255,133,254,157,253,162,1,191,2,116,254,19,2,155,0,130,2,166,2,85,254,85,0,46,3,212,0,77,3,189,253,178,253,56,254,103,0,144,253,67,238,206,254,126,2,8,253,36,0,107,255,137,7,205,4,51,253,225,253,18,2,74,253,169,0,76,244,167,1,166,254,127,252,53,4,255,0,226,251,193,255,19,249,33,254,223,1,67,253,11,6,109,249,170,254,98,252,112,0,105,253,102,6,247,255,27,10,55,1,207,253,92,252,229,253,177,254,77,2,11,3,41,9,80,254,20,3,57,252,63,1,252,255,192,0,180,253,153,255,101,1,76,242,255,254,195,2,39,254,241,5,247,255,130,0,218,12,18,1,216,254,222,252,117,255,210,252,237,255,203,3,81,3,253,0,230,1,40,0,64,251,155,4,20,249,28,252,120,5,70,3,163,7,104,250,123,248,20,9,255,2,128,3,34,5,79,13,21,252,216,253,57,252,90,255,230,255,75,4,83,248,9,0,239,0,246,255,13,255,96,3,227,4,91,0,25,247,77,253,226,253,39,254,140,248,72,251,89,250,133,252,201,254,144,251,102,6,126,4,74,2,120,6,4,1,26,2,46,249,180,5,34,254,164,252,41,1,163,253,117,255,54,3,122,241,62,255,51,1,97,2,30,0,90,13,226,0,174,254,161,0,125,254,168,254,40,254,98,1,86,255,91,254,177,1,89,2,90,250,53,3,208,255,225,255,237,1,148,3,165,254,100,241,125,252,109,5,157,254,71,0,126,1,124,253,229,1,218,0,207,3,226,253,137,243,230,2,154,255,241,252,185,249,217,1,196,0,156,6,185,255,2,1,142,9,227,5,56,252,255,251,193,251,125,2,103,252,131,250,168,4,168,255,252,7,235,248,154,3,156,0,184,251,239,3,73,253,27,254,9,252,44,254,196,254,33,7,190,0,84,8,51,255,38,255,28,242,226,254,186,250,44,255,134,253,120,0,161,1,201,254,166,255,219,0,102,3,178,254,232,250,11,2,231,3,112,255,98,0,109,8,205,0,45,0,9,255,121,5,119,9,22,1,2,253,190,255,53,1,135,255,60,1,225,253,166,242,164,3,221,252,125,2,180,1,219,246,224,7,160,3,188,252,68,251,190,2,101,251,224,253,6,0,107,250,246,3,208,1,142,4,69,2,221,254,136,0,0,0,215,3,225,252,181,2,26,255,41,253,70,255,202,254,180,255,186,2,250,255,108,253,250,2,46,3,195,1,184,254,117,17,58,254,14,0,89,254,140,255,122,255,200,253,255,5,206,253,139,253,243,254,58,3,124,1,68,0,26,1,103,254,128,2,128,254,218,0,186,233,232,254,130,253,230,245,211,253,147,252,49,0,136,2,178,1,154,4,114,13,115,3,178,255,232,7,3,255,46,255,190,251,198,0,189,255,204,255,154,12,97,253,186,249,49,0,239,6,90,254,83,255,53,1,48,253,101,253,7,254,25,8,90,253,128,251,25,255,249,253,49,253,166,1,202,245,118,254,31,2,31,252,169,5,181,1,49,254,250,250,167,4,6,251,58,253,49,254,147,2,213,5,45,0,192,252,98,254,50,1,94,0,4,5,99,253,224,250,58,4,107,252,185,9,18,254,35,2,226,2,96,249,82,255,26,1,94,250,81,250,97,6,144,3,84,254,196,3,12,0,156,246,27,254,119,2,201,254,18,7,96,11,240,255,64,2,50,0,97,252,81,255,37,0,161,2,55,255,227,3,172,2,12,255,5,255,92,250,123,12,71,7,168,255,97,251,58,252,233,6,36,0,199,252,254,2,233,1,170,255,147,254,150,255,59,250,182,254,125,0,3,255,6,255,245,253,37,253,246,235,141,2,139,1,99,0,179,252,47,253,127,0,225,254,82,3,223,1,25,0,226,255,36,0,242,252,99,2,192,1,99,0,165,3,236,255,171,252,75,252,226,254,133,254,114,253,127,254,18,5,35,2,235,0,218,4,185,253,205,239,81,0,221,253,138,251,0,5,33,255,80,249,35,250,202,1,114,255,17,8,208,0,87,3,165,251,69,255,93,3,66,4,8,253,9,246,22,9,134,254,75,251,232,1,15,255,125,3,113,0,176,0,220,15,31,255,215,255,51,253,230,255,70,254,67,254,200,254,45,3,238,1,58,1,46,255,158,255,236,252,255,0,120,2,6,254,166,0,64,253,178,254,42,255,164,252,95,235,60,0,222,255,18,255,109,255,131,2,8,2,246,7,28,0,129,9,98,249,220,250,153,253,60,2,106,255,149,255,93,1,29,249,205,254,78,0,156,251,137,253,138,4,186,254,235,254,177,253,46,2,248,3,196,237,188,254,209,252,5,255,252,250,52,0,38,1,253,250,86,2,118,2,167,254,129,2,222,255,61,4,151,16,125,2,159,6,166,252,212,0,13,255,192,255,71,1,45,2,170,1,191,254,107,1,116,253,116,1,9,3,201,253,19,253,88,249,158,1,179,20,133,1,242,0,39,0,31,0,197,254,179,0,154,255,11,0,62,0,248,0,45,2,194,2,103,1,171,255,47,1,109,254,251,5,153,1,212,247,144,0,182,250,54,0,208,255,51,0,5,249,254,4,174,3,240,4,41,250,135,6,92,0,125,252,131,251,116,7,121,252,172,253,86,1,213,6,199,252,243,255,253,1,117,251,41,4,101,9,3,255,27,253,75,4,240,253,155,11,100,254,21,255,155,252,120,255,160,254,23,254,128,254,233,2,114,254,155,239,84,0,128,4,15,254,187,3,95,255,205,1,240,255,153,252,33,3,163,255,241,255,160,254,34,7,22,254,232,253,219,244,135,253,128,0,255,249,122,249,26,2,20,3,252,4,42,2,172,254,53,2,192,4,34,249,128,1,223,250,140,253,24,0,67,3,162,252,97,252,0,7,238,251,209,0,240,252,39,3,129,254,137,250,203,13,52,0,231,253,205,0,241,254,255,11,142,6,74,253,247,246,1,251,136,249,84,254,217,251,216,249,189,254,170,254,255,254,29,255,52,253,54,254,137,4,76,255,185,255,216,255,4,251,242,6,205,243,134,254,173,250,197,252,112,3,19,1,238,254,187,253,70,255,248,255,149,2,166,251,57,255,85,255,123,1,173,1,241,249,109,6,167,252,93,255,193,245,193,4,178,5,172,253,188,255,127,1,205,3,27,254,158,254,171,253,197,244,252,253,234,0,173,255,84,1,116,254,85,5,194,253,208,252,218,247,221,251,203,249,175,253,245,252,78,1,222,253,49,0,215,251,89,248,200,6,110,4,187,0,41,7,17,0,174,255,68,0,35,3,56,254,167,255,224,6,68,3,34,6,122,0,39,252,245,9,80,6,82,0,78,4,227,0,222,0,44,251,101,255,12,252,121,2,211,1,163,0,189,1,166,0,254,2,3,255,165,254,17,4,1,20,235,255,24,3,81,0,34,254,128,0,98,255,60,1,100,251,140,254,156,6,196,252,225,255,98,4,233,245,66,5,179,9,195,0,72,0,37,2,168,1,179,3,42,254,148,7,181,255,249,1,97,5,38,2,58,0,249,6,87,1,207,252,106,3,155,13,205,254,192,253,240,0,35,0,69,3,51,253,9,255,27,16,182,255,127,2,70,1,146,255,104,7,58,3,169,252,213,254,60,254,24,2,189,254,6,1,79,0,230,1,144,0,14,1,192,255,21,1,154,0,143,1,50,0,154,227,195,255,14,0,248,255,19,0,152,255,77,1,119,0,118,1,133,1,60,255,77,0,190,254,5,1,75,0,130,1,162,0,56,9,132,2,31,245,99,1,21,1,135,255,108,255,156,0,88,8,112,0,59,254,173,1,171,0,101,9,35,251,249,252,75,255,62,8,185,253,127,0,121,3,222,254,218,253,91,255,3,4,107,8,161,254,88,252,176,1,129,10,217,0,236,255,134,2,239,252,140,3,142,2,202,3,218,254,215,255,210,1,11,255,138,0,50,0,148,255,146,254,177,0,225,1,186,247,200,3,174,253,52,15,16,2,188,0,155,253,18,0,27,1,221,2,221,255,62,6,131,1,1,0,156,0,50,255,75,254,203,0,12,255,165,254,69,1,40,1,100,0,147,4,49,0,152,3,94,254,202,255,60,245,24,0,123,0,250,3,47,1,11,254,133,3,65,254,66,1,199,246,15,4,213,251,109,3,49,5,113,255,43,245,13,1,24,6,142,1,135,243,102,0,222,3,23,1,123,1,52,255,112,255,82,255,139,0,155,1,22,255,21,0,56,236,68,255,109,1,22,1,97,1,67,255,94,0,81,2,110,254,159,254,255,254,236,252,127,1,244,251,57,2,184,255,28,249,59,2,235,3,117,2,158,2,136,250,0,0,77,254,64,0,189,0,58,11,239,0,104,4,224,3,189,4,69,0,128,255,207,0,201,2,124,246,93,252,125,254,145,255,40,4,86,255,219,244,208,251,145,254,232,251,18,255,196,255,207,255,84,1,78,9,114,1,11,255,95,1,248,0,192,255,27,9,202,1,28,254,222,255,25,1,177,2,227,1,124,2,199,0,81,12,95,2,132,255,32,243,185,3,105,254,49,0,199,1,59,4,178,2,87,255,43,253,55,1,19,254,31,249,18,244,120,1,224,253,223,1,91,0,159,0,235,244,23,251,194,252,76,252,2,255,33,1,241,251,88,3,86,0,99,4,203,0,0,253,65,4,73,0,158,252,52,1,181,1,162,2,237,247,16,255,201,251,33,0,211,251,82,242,244,2,92,253,45,0,16,246,122,1,147,254,237,254,219,254,118,254,119,253,5,254,222,244,160,2,114,1,186,0,95,254,170,2,185,0,241,255,47,11,21,0,91,255,100,1,64,241,153,255,23,2,96,254,167,254,225,255,24,0,166,255,51,255,96,0,58,252,94,0,168,1,251,255,68,255,149,0,111,247,73,255,38,9,169,1,121,253,95,249,141,253,68,254,224,4,57,252,66,253,208,255,32,14,100,242,6,3,213,254,94,0,165,1,216,1,71,0,112,255,245,253,114,0,84,255,93,1,227,254,150,255,101,0,59,0,173,1,0,2,34,13,218,255,194,255,50,0,31,255,128,250,12,3,69,245,108,254,233,1,49,252,72,3,101,1,214,3,232,1,237,254,147,255,137,1,119,1,186,18,183,0,146,255,154,3,8,253,61,0,213,251,248,255,66,1,74,0,155,255,42,2,162,254,26,254,66,0,128,1,236,2,14,0,223,0,211,255,126,254,69,0,87,24,247,0,69,1,192,254,209,255,206,255,91,255,153,0,132,254,77,2,85,243,83,255,116,255,85,1,21,253,233,249,127,2,134,249,100,1,110,0,106,255,239,254,76,0,136,253,87,254,29,255,128,2,211,0,192,0,21,253,91,255,0,18,34,1,96,255,244,4,194,10,253,255,66,2,189,0,27,254,69,245,133,255,227,250,150,2,89,2,43,0,120,255,84,0,89,6,167,251,120,5,75,0,130,255,253,13,13,255,35,9,254,253,155,8,112,254,29,254,9,2,30,0,10,255,180,255,103,1,101,0,151,2,216,255,57,0,52,0,104,1,65,254,222,254,254,0,104,0,102,0,113,0,215,0,93,255,124,254,43,1,218,17,31,0,108,0,215,255,41,0,183,245,75,11,164,4,7,254,37,4,163,254,164,253,63,254,138,254,192,254,201,3,208,254,64,255,246,0,104,255,185,1,210,255,120,250,137,0,195,7,239,1,193,255,63,4,107,3,187,2,201,0,211,0,171,243,239,254,196,255,195,0,3,245,17,255,182,9,201,255,38,1,59,1,123,255,192,1,199,248,107,1,39,4,76,0,96,252,194,253,184,255,199,255,168,0,41,22,100,255,140,255,144,1,132,255,82,0,218,0,25,254,37,0,112,0,53,0,224,253,178,0,99,0,224,1,245,227,60,255,15,1,96,255,52,1,194,255,137,1,138,1,36,255,28,253,242,255,92,0,152,1,148,254,43,1,207,254,76,0,17,255,26,0,200,254,22,255,34,0,67,255,103,3,215,254,108,1,26,1,191,254,97,252,159,17,2,0,6,0,52,1,174,255,87,0,128,255,6,2,82,0,99,238,121,4,192,3,147,255,70,255,83,0,112,255,240,2,84,0,196,244,94,255,109,3,7,255,61,1,254,1,82,1,42,1,232,2,76,11,233,252,107,1,64,4,118,2,54,246,255,255,78,12,219,0,130,0,119,0,57,1,202,252,100,253,177,4,124,244,19,255,150,255,57,253,149,1,20,1,1,255,0,0,184,1,161,0,27,10,34,253,48,13,20,1,154,0,31,1,56,255,82,2,227,255,198,0,19,255,160,253,67,254,226,254,202,0,241,252,112,0,217,240,78,0,249,10,175,254,162,253,84,253,78,254,47,2,17,1,201,0,75,1,135,3,203,255,90,1,188,2,39,10,46,1,178,253,9,246,14,254,230,255,101,253,64,2,222,253,201,1,223,254,128,250,3,252,193,255,78,0,153,0,173,255,72,253,223,243,194,9,34,250,31,251,18,255,254,0,225,254,215,0,57,1,23,1,251,253,67,0,198,255,108,255,169,251,58,0,31,20,90,1,27,1,145,254,124,252,30,2,209,0,74,254,128,255,121,255,54,0,7,0,101,3,35,1,207,251,7,3,195,255,111,255,201,1,50,2,52,5,19,238,99,0,86,5,184,0,212,3,104,252,80,0,246,254,104,255,171,248,246,254,108,1,104,250,16,1,227,8,55,2,60,0,50,0,56,246,126,254,68,253,117,1,119,26,241,255,78,254,91,1,215,0,143,254,236,255,231,254,13,255,187,254,227,0,229,254,103,253,182,255,80,1,94,253,144,255,143,254,203,255,116,254,72,1,4,14,227,253,211,253,92,255,25,5,207,252,50,254,194,7,225,4,194,253,130,0,152,0,185,246,87,254,186,1,13,241,66,1,40,253,51,2,77,255,22,2,108,2,87,252,78,2,255,255,197,255,72,2,175,0,63,255,88,255,251,255,106,255,156,0,81,255,78,255,11,255,199,226,239,254,212,0,221,255,62,1,78,255,190,1,201,255,230,255,42,0,210,255,247,254,255,2,74,1,39,1,142,3,202,255,234,1,136,11,86,2,238,245,124,253,147,1,149,0,168,255,37,2,2,254,84,2,31,255,219,246,226,254,92,245,5,0,88,248,250,254,154,3,25,2,134,2,194,255,238,255,0,32,228,1,112,0,34,255,45,255,32,255,61,1,112,0,82,0,171,252,1,0,176,0,37,254,94,255,200,0,63,255,166,0,28,255,42,255,72,0,161,1,229,255,240,255,4,0,139,1,253,253,80,229,28,0,209,255,114,2,83,255,63,0,90,0,141,0,217,0,13,4,79,1,168,17,128,252,111,0,91,0,112,253,153,255,39,253,227,255,141,2,169,253,245,255,174,10,134,254,221,254,60,0,228,0,47,0,170,241,64,255,141,2,221,2,171,253,130,3,92,254,36,6,123,255,102,255,73,1,253,254,31,255,218,0,174,255,117,0,44,1,33,254,21,1,19,3,73,249,136,0,237,241,190,2,77,5,12,13,106,1,74,254,131,0,73,250,111,1,45,254,186,6,118,247,87,1,133,254,197,4,206,253,252,254,133,4,132,10,37,0,167,255,190,254,190,254,0,32,228,254,235,0,240,253,113,0,153,254,44,0,74,0,119,0,107,252,147,1,154,1,106,255,157,0,2,2,168,0,151,1,10,255,225,255,254,1,105,0,193,1,4,18,123,2,166,255,20,251,6,3,228,254,176,255,200,1,7,0,72,244,188,254,44,255,152,255,138,254,72,254,244,4,176,10,53,0,102,251,109,254,74,254,234,253,121,0,5,1,15,254,183,255,10,0,250,254,17,0,178,248,178,0,197,250,224,0,43,12,76,254,64,254,129,1,126,3,255,255,105,0,238,255,12,1,86,1,14,1,123,3,111,1,121,0,187,254,182,249,181,255,95,243,67,255,230,251,193,3,239,244,208,254,205,255,144,1,228,254,214,252,56,3,185,255,121,255,194,0,41,1,215,254,105,4,148,2,6,2,122,9,31,255,251,0,69,18,80,255,48,254,40,1,72,251,89,254,149,252,187,253,61,253,130,251,243,1,246,252,28,0,29,0,101,0,139,239,129,255,159,241,169,1,225,1,239,253,89,253,11,0,10,1,127,0,67,254,15,2,191,253,54,1,185,5,200,237,141,255,59,0,232,254,57,255,231,255,213,0,87,252,88,1,167,247,183,252,142,254,0,1,0,2,74,4,126,255,58,0,135,255,98,254,0,32,233,1,216,254,223,255,98,0,49,0,39,255,209,2,214,255,94,254,29,255,248,255,205,0,236,254,151,1,62,251,110,255,220,254,113,255,113,0,210,3,133,10,247,255,248,251,245,6,241,6,41,255,46,252,200,252,68,0,94,255,55,0,175,11,180,252,170,2,241,1,150,1,102,252,167,9,87,2,6,3,127,255,12,5,20,252,9,3,42,0,58,1,154,255,61,252,22,245,196,245,254,1,99,1,116,1,8,255,121,254,93,255,214,254,49,2,117,0,159,4,38,0,182,0,19,7,252,255,72,1,243,255,56,254,49,1,112,1,101,249,254,244,206,251,5,4,5,1,90,250,87,1,12,0,59,245,253,3,137,254,253,255,101,255,116,0,195,0,92,13,64,0,139,0,12,3,187,0,48,254,5,1,199,254,128,255,185,0,119,14,88,12,192,3,194,2,41,0,149,1,10,0,167,4,97,1,219,253,131,0,164,0,105,0,1,0,23,0,130,1,73,0,3,254,91,10,95,250,190,252,135,249,123,253,237,3,247,252,183,2,212,0,140,5,65,0,189,2,25,0,79,1,136,0,103,1,144,255,106,255,191,0,136,1,254,254,140,251,139,2,57,238,155,1,251,0,87,255,36,3,173,255,48,255,149,254,81,0,152,0,75,0,86,251,53,255,247,255,157,0,157,1,194,255,46,255,17,21,234,255,105,254,132,0,224,254,56,9,131,0,1,250,41,2,36,246,116,255,250,0,235,4,226,255,255,255,230,6,99,0,239,253,91,0,108,15,250,254,88,241,130,254,173,254,67,253,116,255,237,252,67,0,245,255,75,1,196,252,69,254,84,2,47,0,98,6,31,0,194,254,39,0,147,0,98,253,248,252,195,2,103,252,172,0,203,3,139,4,48,0,175,255,179,250,75,255,56,11,104,255,130,3,51,4,17,2,91,0,25,247,109,11,176,252,77,2,118,7,37,2,64,4,231,2,137,253,42,0,8,250,23,0,124,1,251,255,133,1,133,251,47,255,7,248,224,0,50,248,8,2,248,252,193,0,168,245,178,255,222,255,125,255,22,0,56,255,228,255,18,0,72,1,215,0,67,0,61,0,50,0,184,255,45,1,49,255,157,1,208,2,206,231,199,3,53,243,149,0,116,246,247,253,252,252,234,254,137,0,97,255,164,3,145,255,195,4,13,2,17,0,84,253,51,251,16,249,66,0,253,246,61,255,241,253,16,1,42,254,156,254,249,255,174,254,146,0,253,3,131,252,92,244,79,2,129,0,255,254,209,0,198,255,26,2,123,240,64,2,119,252,126,253,212,247,153,0,225,2,172,253,61,2,236,0,137,252,100,249,142,254,67,255,40,255,198,255,202,2,10,0,186,253,5,2,170,255,194,1,109,255,202,254,162,0,211,6,112,253,249,13,188,2,190,0,83,253,86,255,241,0,91,0,130,255,191,21,185,1,206,255,80,253,183,255,170,3,64,1,126,255,185,252,130,4,149,0,66,254,246,255,245,255,12,0,109,253,118,255,125,2,42,254,165,3,81,254,235,0,170,255,254,255,105,254,37,233,6,255,134,5,13,2,110,0,165,1,255,0,107,255,86,0,122,1,191,254,100,5,118,0,223,244,142,251,180,0,151,4,140,7,32,0,24,254,135,255,100,254,71,254,141,1,249,0,84,255,161,255,164,1,119,1,124,255,41,255,89,255,50,255,0,32,140,255,195,255,201,254,13,1,103,2,159,254,141,255,129,254,110,1,117,253,60,255,158,255,85,0,93,3,31,2,25,255,237,0,237,1,124,1,2,253,88,255,155,12,147,2,189,2,181,0,68,244,249,255,154,0,42,1,42,1,255,254,224,255,175,233,48,0,102,0,248,252,108,255,146,255,60,1,123,253,212,0,213,0,63,2,187,255,31,0,41,2,95,253,251,255,208,255,108,255,123,255,11,0,143,0,10,0,159,0,63,1,43,0,38,29,162,0,228,0,166,255,75,0,151,0,103,0,18,246,243,255,174,254,11,0,70,254,123,0,33,244,60,254,7,0,106,0,246,1,227,0,14,248,90,0,244,1,228,255,122,253,250,254,194,255,178,255,40,0,163,1,105,26,245,255,40,0,209,0,61,0,105,255,188,255,11,255,111,254,26,0,133,255,189,0,199,255,99,2,6,0,251,250,157,255,134,252,25,14,210,254,216,252,127,2,83,243,30,255,107,0,54,0,148,255,196,254,195,255,200,255,228,0,240,255,195,0,19,1,214,0,196,255,77,0,11,228,130,0,8,0,244,0,144,247,8,253,194,1,70,255,134,254,32,0,227,252,214,0,15,242,62,254,51,1,239,255,115,255,16,0,0,4,148,1,241,247,224,254,96,255,216,15,109,3,166,254,54,252,169,255,80,1,193,3,154,2,73,2,47,254,207,250,94,1,174,254,211,234,83,255,217,254,72,0,55,255,21,2,206,1,123,255,87,252,99,7,8,1,71,0,89,252,128,2,175,2,84,3,126,254,171,255,244,233,50,1,240,0,128,2,67,0,94,0,122,252,161,254,95,254,253,255,28,1,38,0,100,255,103,1,53,0,139,0,185,0,18,1,53,10,213,0,2,5,51,11,30,0,210,4,113,252,87,1,163,255,121,249,57,0,210,252,237,255,70,1,0,255,143,255,72,0,105,12,65,13,131,255,204,1,251,254,9,254,5,252,87,253,3,255,67,252,99,255,139,255,25,255,44,255,166,5,225,0,63,244,57,1,77,254,131,1,96,252,184,2,167,252,60,254,66,0,241,247,14,3,14,0,162,255,51,0,242,0,90,254,236,0,15,241,102,253,92,1,196,0,46,245,173,1,96,254,246,254,65,251,182,253,84,0,72,1,210,254,219,0,55,254,236,253,4,253,85,0,216,7,218,252,90,11,131,250,111,1,67,3,203,2,38,252,39,255,88,0,184,254,57,2,182,253,24,12,249,0,153,253,197,1,176,0,228,253,24,3,88,246,141,8,108,3,159,254,111,0,212,0,249,255,85,2,102,255,50,3,111,254,128,250,236,2,198,9,146,5,175,244,45,4,70,1,163,253,120,0,203,239,241,243,217,2,82,0,224,0,64,1,97,1,179,255,93,255,190,254,220,0,207,251,10,0,33,2,250,253,59,254,50,0,126,254,46,248,102,2,63,253,218,252,96,252,125,11,248,253,221,255,184,4,157,1,132,3,138,0,98,254,223,254,241,255,181,255,185,0,139,254,137,2,5,255,154,2,148,10,255,244,19,253,97,255,144,255,198,1,127,254,13,4,210,255,231,255,242,255,66,0,40,2,160,0,216,255,216,253,100,255,151,0,89,235,29,2,14,255,174,255,116,251,81,3,251,252,120,255,94,255,180,255,23,0,141,254,34,255,59,247,212,1,169,1,156,254,162,1,253,255,190,254,11,242,148,0,4,1,101,255,229,12,91,255,142,243,59,253,54,254,102,3,130,1,59,0,95,255,21,2,106,255,86,2,128,1,132,3,47,251,182,255,48,254,249,253,107,253,201,255,254,245,34,1,209,5,203,6,229,8,106,3,53,250,65,254,93,0,53,1,55,1,53,255,237,255,223,8,0,251,131,255,69,254,230,253,90,10,214,255,34,1,245,0,107,255,24,0,38,0,123,255,102,6,210,0,17,255,76,255,4,2,244,255,49,253,237,255,251,253,210,231,75,255,167,255,62,1,229,1,119,2,11,0,51,255,199,255,1,1,61,2,184,255,17,1,189,253,107,0,251,255,112,0,169,1,145,9,181,10,246,2,144,2,105,253,230,254,208,255,211,255,218,254,64,254,70,234,61,0,255,255,48,254,249,254,80,253,141,255,241,255,148,255,199,253,64,254,208,255,76,255,151,255,14,0,76,255,234,1,18,1,113,2,180,253,136,255,60,255,207,254,130,255,179,1,70,246,123,245,170,242,31,0,97,0,89,255,142,255,247,0,15,30,67,255,188,253,219,0,241,0,188,0,71,1,179,0,63,255,135,0,80,255,127,0,223,1,17,2,234,0,112,0,234,0,154,254,226,254,85,4,124,11,158,253,243,255,166,245,239,1,75,5,194,253,213,255,39,250,220,254,9,254,52,2,149,254,24,0,199,254,107,5,221,0,228,241,15,3,125,2,43,0,71,5,217,0,235,255,149,0,224,243,190,0,253,254,55,255,170,254,55,255,166,0,107,9,198,251,27,1,130,254,43,253,157,0,155,0,183,249,176,253,15,2,113,244,9,0,216,0,14,2,79,0,54,0,124,255,202,0,17,3,161,3,219,6,105,253,110,1,105,241,210,12,49,1,60,2,220,255,145,255,25,255,119,0,91,2,77,5,103,255,41,2,107,1,8,253,92,251,122,3,147,0,252,240,52,241,150,0,1,1,180,253,22,255,241,1,105,1,225,253,255,0,81,255,135,254,49,0,152,253,56,255,19,16,227,253,130,0,166,2,126,242,6,254,38,255,219,250,121,3,29,0,152,255,254,255,20,2,119,254,1,2,232,252,246,0,250,255,76,255,90,0,127,0,250,12,86,2,182,0,81,0,82,0,67,0,217,255,87,0,196,255,248,255,167,255,185,0,99,0,231,255,27,0,9,0,197,255,3,227,49,0,239,255,116,0,171,255,6,0,207,254,88,0,92,255,99,0,61,0,97,254,142,255,224,254,1,0,91,255,244,255,5,0,113,255,114,255,247,253,11,255,203,255,38,0,157,255,125,14,204,255,0,0,215,255,121,255,147,0,39,255,62,0,160,247,255,0,132,0,8,1,65,0,219,255,204,0,174,254,232,254,192,0,72,255,98,255,155,241,230,255,203,0,174,1,227,255,240,255,77,0,230,0,201,254,85,2,249,9,154,251,193,255,154,0,81,254,95,255,59,1,30,1,109,255,177,0,253,255,93,0,193,1,253,0,219,255,101,0,12,255,179,255,42,0,128,254,22,0,36,0,235,0,147,236,243,0,136,255,151,255,30,255,142,255,57,254,108,254,164,0,7,254,220,1,132,255,235,244,174,255,152,244,253,255,0,0,134,0,162,255,8,1,203,255,203,255,108,0,253,255,179,252,3,245,228,0,77,255,196,255,254,255,65,0,33,0,103,255,240,255,107,255,169,247,209,0,95,252,224,254,227,0,96,10,131,255,214,255,17,0,30,0,47,13,145,254,53,0,250,254,161,254,108,0,242,254,11,0,199,255,74,255,205,255,107,255,225,254,141,255,232,255,99,0,180,255,42,27,181,255,252,255,38,0,88,255,138,0,109,0,17,255,211,255,49,0,28,0,160,250,49,0,66,0,173,255,127,255,195,255,157,255,135,0,14,0,163,255,111,0,37,0,240,255,2,0,180,255,104,1,179,255,82,0,161,0,149,0,132,249,18,0,98,0,222,255,244,255,220,255,191,255,126,0,199,255,28,0,7,2,252,7,41,1,73,0,38,255,51,0,17,0,21,0,186,255,224,255,183,255,217,255,218,255,245,255,60,0,38,0,127,255,151,255,83,255,200,0,7,0,124,0,182,255,36,245,48,10,199,255,43,255,54,0,56,255,134,0,208,0,222,255,236,0,143,0,101,0,71,1,46,2,75,0,61,1,18,12,68,255,32,2,70,255,15,0,116,0,237,0,76,0,151,255,29,0,212,254,229,255,45,255,71,0,112,255,183,0,179,255,38,0,240,255,39,0,56,0,116,227,143,255,140,255,224,255,222,0,60,0,76,0,235,255,59,0,52,0,104,0,127,1,73,0,149,0,88,0,127,0,34,0,229,248,210,255,50,0,11,0,97,255,33,255,93,255,107,255,95,0,93,255,136,247,237,255,87,252,73,255,66,0,47,254,255,254,85,1,186,255,111,0,228,0,52,0,83,0,63,0,204,255,69,255,16,0,21,246,205,255,168,12,175,255,87,0,140,255,73,255,74,255,96,0,234,255,65,255,149,255,217,0,246,255,41,255,9,0,249,255,159,255,181,254,201,255,1,2,114,254,98,5,67,10,175,247,51,2,182,5,143,254,242,1,152,4,43,254,220,0,71,252,134,255,20,255,206,254,236,254,31,0,35,0,89,255,46,2,122,255,45,0,202,255,16,0,36,0,18,0,44,1,134,9,62,0,79,255,77,0,78,10,148,255,141,255,64,13,18,1,133,255,190,255,201,0,112,254,170,0,142,0,151,0,76,1,53,0,5,254,81,0,115,253,163,255,124,243,251,255,10,0,213,255,79,0,39,15,77,0,191,0,24,0,23,0,48,255,6,0,147,255,159,255,126,0,206,254,117,2,26,0,252,253,79,0,21,0,131,0,43,0,3,255,121,242,72,3,141,2,161,255,208,255,44,1,254,251,188,254,115,252,129,254,195,0,86,1,120,255,64,255,166,1,6,1,243,255,22,2,53,12,8,0,136,6,176,0,219,254,211,0,67,251,25,2,125,2,246,255,140,255,107,255,44,0,53,0,105,0,7,0,159,255,3,0,17,0,8,0,235,255,249,255,215,255,218,255,161,236,175,255,1,0,165,0,196,0,98,0,35,0,221,255,8,0,228,255,113,0,236,255,108,0,126,255,191,255,172,0,42,11,41,0,33,243,138,0,10,0,161,255,226,255,83,255,85,0,42,0,30,0,137,255,161,0,195,0,125,0,224,255,136,0,63,1,223,255,22,20,50,0,100,0,128,0,166,255,203,255,189,255,53,255,28,0,19,0,37,0,119,255,132,255,151,255,231,255,179,242,6,255,38,1,153,1,157,255,208,251,129,254,244,255,212,0,236,254,61,13,155,255,171,0,215,255,214,253,217,254,75,254,86,0,158,0,14,255,167,0,135,0,7,0,107,255,48,0,252,255,172,255,47,19,27,1,5,0,242,255,105,0,149,255,128,254,102,0,183,0,47,0,67,0,15,236,251,255,16,0,101,255,181,0,110,0,24,0,179,255,224,255,120,0,1,0,22,0,167,0,166,255,106,255,251,255,163,0,212,255,228,255,54,0,14,244,82,255,58,0,152,0,225,255,77,255,134,255,199,255,232,0,117,254,159,236,61,0,141,255,31,0,14,0,82,0,147,255,217,255,59,0,207,255,123,255,52,0,17,0,57,0,52,0,193,255,19,1,146,0,104,0,53,0,47,0,201,255,55,1,7,19,230,255,48,0,162,255,245,255,198,255,63,0,140,0,182,255,162,255,243,254,179,255,44,13,212,243,16,0,209,255,182,255,95,255,115,0,58,0,9,255,137,255,143,1,42,0,75,255,154,0,38,255,232,255,19,255,58,0,237,254,163,11,187,0,132,255,56,1,45,1,207,10,248,255,40,0,233,255,250,255,218,255,204,255,149,254,247,254,178,255,26,255,30,1,121,255,175,254,175,255,170,0,243,255,198,255,139,255,7,2,80,237,157,0,63,255,9,0,62,0,235,255,180,0,128,0,70,1,213,0,136,9,62,0,167,253,201,255,2,0,238,255,170,254,142,0,102,1,136,253,135,254,6,14,8,255,234,254,21,255,228,255,242,0,123,255,144,0,26,0,251,254,113,0,45,0,233,255,64,248,179,255,128,0,249,0,248,255,246,254,218,255,250,255,120,249,211,255,172,255,135,254,154,0,17,0,173,255,212,255,156,0,119,255,43,0,91,0,253,0,17,0,185,255,164,255,178,0,12,0,18,0,248,255,151,255,101,0,156,27,71,0,175,255,84,0,223,255,79,0,53,0,249,255,171,255,247,254,117,0,61,1,114,0,72,0,30,254,94,254,71,255,159,255,12,1,249,249,177,255,110,255,208,255,211,255,69,243,44,255,125,4,91,255,177,0,98,255,179,255,100,0,86,0,187,255,107,0,219,0,0,254,3,255,94,254,211,255,16,0,125,21,72,255,207,0,67,0,46,0,109,0,228,255,247,255,33,0,63,0,240,255,39,0,92,0,27,0,23,0,246,255,0,224,0,0,50,0,199,255,68,0,68,254,58,4,247,0,118,255,120,0,216,1,76,253,212,0,216,249,66,0,245,11,146,1,96,255,81,1,83,253,249,253,227,0,233,254,92,0,217,239,119,254,212,255,6,0,127,255,59,0,239,0,151,0,153,0,217,255,116,0,134,0,216,255,171,0,118,0,207,0,55,10,38,0,89,255,121,249,85,0,121,255,74,255,168,255,246,0,53,0,29,0,254,255,16,0,232,0,32,2,210,255,118,255,122,0,204,255,32,5,9,0,92,0,13,0,4,0,66,0,221,255,122,255,200,255,85,0,213,255,225,255,28,0,141,243,100,0,153,255,70,0,253,255,186,0,213,255,122,0,32,244,229,255,210,255,135,255,1,0,37,0,0,0,196,255,2,0,156,255,104,255,38,255,175,0,106,254,175,0,63,255,68,0,48,255,233,255,26,255,221,0,69,13,45,0,48,0,37,0,81,1,11,0,15,0,187,255,252,255,174,255,53,0,33,0,200,255,75,0,158,255,187,255,245,255,237,255,244,255,81,0,204,255,52,21,121,0,82,0,209,1,10,0,27,255,126,0,32,0,119,0,183,1,126,0,204,7,171,255,175,255,199,255,88,0,232,0,108,0,234,255,232,255,27,0,120,255,91,0,224,255,18,0,226,0,223,255,15,0,117,0,145,0,199,225,9,0,58,0,154,255,143,255,26,0,130,247,28,0,91,254,245,255,186,255,233,255,186,255,137,255,160,255,123,255,208,0,20,0,90,241,242,255,23,0,41,0,76,255,49,8,153,255,169,253,146,0,251,0,179,255,211,253,180,255,160,255,69,0,10,1,60,1,74,0,239,255,29,255,223,0,33,0,251,254,135,0,190,31,250,0,251,255,199,255,35,0,126,1,212,255,136,0,81,0,42,0,176,255,179,0,183,255,181,255,199,255,18,1,241,255,188,243,164,12,196,0,150,0,205,255,222,0,66,255,13,0,83,0,199,254,107,255,89,0,231,254,244,255,214,255,37,1,55,2,19,0,213,255,146,0,102,0,217,255,82,14,95,0,76,0,255,255,12,0,27,0,7,0,251,255,5,1,132,0,41,255,217,254,205,255,240,1,77,0,100,0,16,0,227,254,137,2,161,255,24,1,77,0,121,0,140,245,25,0,132,251,96,11,171,254,165,255,76,9,176,255,250,255,13,1,222,255,82,253,48,255,19,0,228,0,24,0,251,255,106,255,11,0,214,0,196,254,163,4,87,2,194,255,30,247,16,255,48,0,170,255,87,0,86,0,221,1,248,14,67,0,135,0,68,0,235,2,83,1,129,1,1,255,32,255,184,0,70,0,171,0,122,255,44,10,25,255,72,0,170,0,51,0,31,245,188,253,170,255,119,254,193,255,177,255,105,255,78,1,78,0,73,1,234,254,102,0,230,255,201,255,53,242,134,254,9,255,176,0,54,255,147,0,169,0,87,0,24,0,180,243,217,243,106,0,45,0,142,255,171,255,45,255,154,0,172,0,246,0,112,1,126,255,58,0,121,255,70,0,102,0,106,255,180,255,249,255,13,0,255,255,227,255,20,0,249,255,112,0,22,255,141,255,118,255,216,255,106,0,178,0,148,227,231,253,25,0,88,3,204,1,35,12,146,0,248,253,137,253,138,255,137,1,179,0,144,0,170,255,47,0,82,0,215,11,28,0,164,0,204,254,101,254,72,0,138,0,122,1,242,0,253,0,12,0,158,0,228,255,196,255,227,255,210,255,251,255,245,255,84,0,193,10,143,255,191,255,3,0,5,0,13,0,10,236,182,255,130,255,127,255,174,255,198,255,116,0,15,0,68,0,243,0,224,255,126,0,208,255,11,0,249,255,75,0,10,0,166,0,103,255,8,0,213,255,218,255,81,0,215,255,13,0,100,0,27,0,46,0,71,254,200,255,35,0,4,0,51,0,104,29,52,0,115,255,103,255,39,0,220,255,170,255,80,0,221,255,50,0,210,255,23,0,178,0,110,240,234,242,59,0,234,254,37,0,254,255,14,0,99,255,48,255,195,254,218,0,15,0,216,254,224,255,205,255,36,0,229,255,242,247,28,0,219,255,66,1,238,8,214,0,60,255,85,255,192,255,93,255,9,1,206,255,3,0,79,255,234,255,68,0,124,0,37,0,241,255,102,247,60,0,133,0,4,0,115,1,193,10,145,255,224,1,66,254,228,1,43,0,150,0,181,254,130,5,233,252,123,0,120,255,64,255,11,1,0,0,167,255,151,255,165,1,68,0,130,255,79,0,23,1,202,0,124,255,48,255,239,242,151,255,59,0,118,0,121,253,208,255,244,255,145,0,109,254,200,0,7,0,252,255,136,243,33,255,64,0,0,0,159,1,110,1,136,0,49,0,69,226,79,0,151,255,127,0,187,255,213,255,103,0,161,255,163,255,246,255,226,255,94,0,108,0,147,255,0,0,169,255,186,255,44], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1625285);
/* memory initializer */ allocate([1,163,255,113,0,25,0,239,255,215,8,41,0,192,0,18,0,73,0,179,0,129,0,149,0,175,255,255,255,0,0,201,0,184,0,139,2,8,0,18,0,114,0,4,11,127,1,185,255,120,1,23,247,90,251,113,255,121,0,211,255,147,247,102,254,81,0,242,255,1,6,191,252,29,0,126,4,18,254,248,255,242,255,210,0,188,0,1,12,17,249,133,255,80,0,153,255,227,0,40,1,111,0,101,6,59,255,69,5,174,0,204,12,49,0,158,255,74,0,148,2,3,0,4,255,156,254,247,255,15,2,193,255,197,224,240,255,85,0,249,0,74,0,26,0,2,0,3,0,26,0,132,255,195,255,230,255,112,255,4,0,204,255,6,0,251,253,161,255,6,10,230,255,66,255,60,255,3,254,90,244,4,0,78,255,247,255,189,255,231,255,1,0,193,0,188,255,210,255,174,255,106,241,242,255,173,254,212,255,105,255,55,0,230,0,253,255,100,0,209,255,187,255,35,0,107,0,127,0,81,255,245,255,246,255,98,255,116,255,118,11,124,255,11,10,98,255,39,255,106,0,137,0,34,255,74,0,214,255,64,0,47,2,122,0,73,0,144,255,108,244,198,9,13,0,45,1,215,255,203,0,130,254,105,255,35,255,109,255,232,255,83,0,37,0,211,255,56,0,89,0,71,0,109,0,242,255,213,255,126,255,148,255,238,255,74,0,233,255,222,255,79,0,238,29,168,255,70,0,21,0,146,255,147,0,26,0,250,0,74,0,165,0,49,0,43,0,45,0,234,255,242,255,37,1,155,20,57,0,184,255,93,0,40,0,115,0,117,255,180,254,95,0,92,0,230,255,26,0,169,0,162,255,76,1,71,0,30,254,137,0,190,0,114,0,14,0,151,0,53,12,6,0,109,0,6,0,7,0,7,6,26,1,232,255,24,0,142,0,33,0,123,0,41,0,184,255,3,255,223,255,53,1,149,255,192,255,125,255,56,0,56,242,82,0,239,255,161,1,209,255,180,253,18,1,155,0,158,0,11,255,186,0,147,0,249,255,206,255,38,255,12,0,118,0,194,255,140,2,145,0,64,0,169,9,110,255,220,0,99,244,97,0,28,1,29,0,12,1,29,0,48,255,216,255,5,255,81,255,240,255,198,255,191,255,28,0,26,0,55,0,74,0,244,255,119,7,43,0,174,255,106,255,243,255,137,255,8,0,119,0,156,0,14,6,168,255,154,255,46,0,226,0,124,255,95,0,100,0,87,0,7,0,210,255,8,0,224,255,240,255,244,255,61,1,223,255,229,255,35,1,168,255,169,0,1,0,155,255,195,255,161,0,162,0,223,255,255,255,11,0,233,19,222,255,142,0,31,0,94,0,35,14,162,255,67,0,51,13,191,255,28,0,254,0,189,0,110,0,138,0,215,255,52,0,32,0,152,255,154,0,172,0,195,246,48,254,25,1,207,0,190,255,66,255,143,1,98,255,13,0,101,255,33,255,92,0,148,255,231,255,212,1,189,0,249,238,42,0,121,255,138,0,36,0,133,250,248,254,176,254,92,255,207,255,54,0,131,255,195,255,62,0,16,0,172,0,182,0,62,12,163,250,63,0,29,255,150,255,123,255,91,255,187,255,199,255,72,255,210,255,9,0,199,255,50,0,253,255,194,255,241,255,133,255,108,0,111,0,91,0,95,255,23,0,175,255,7,0,208,0,247,234,12,255,24,0,95,0,12,0,248,254,62,0,212,255,21,0,16,255,213,254,244,255,117,0,195,255,9,246,133,1,0,11,77,255,203,0,91,254,131,3,249,255,174,0,56,255,98,0,12,4,90,255,11,0,119,255,78,0,249,255,135,255,245,0,179,255,124,0,102,0,51,0,64,12,74,0,202,254,40,0,212,0,17,255,139,254,102,255,142,1,151,11,142,2,232,1,103,0,26,255,182,254,63,3,193,255,39,254,152,0,212,253,118,247,141,254,4,0,86,0,244,255,115,255,127,21,169,255,133,255,239,255,241,255,154,0,192,0,170,255,97,0,165,0,96,1,56,0,154,0,43,0,181,254,236,3,204,255,125,255,17,243,3,0,110,0,103,255,186,255,137,0,88,255,236,255,115,0,140,0,231,255,202,255,243,255,212,254,57,0,125,255,214,0,5,1,164,255,106,2,64,245,182,243,61,0,205,255,210,0,26,255,87,0,72,255,74,1,22,0,237,255,149,255,35,254,217,255,1,0,127,0,178,0,183,255,169,1,56,0,231,255,215,255,135,0,119,9,59,0,210,255,246,255,49,0,140,255,205,255,65,247,28,255,181,255,48,0,3,0,181,0,161,0,123,255,157,254,81,0,5,0,84,0,34,255,173,255,92,0,33,0,122,226,218,255,253,255,159,0,33,0,198,255,219,255,149,255,16,0,195,255,162,255,93,0,97,0,49,0,237,254,29,0,58,255,252,255,188,255,87,0,116,0,129,228,46,0,81,0,231,255,0,0,249,255,210,255,152,0,64,0,216,255,113,255,200,255,147,0,147,1,1,1,76,9,230,253,112,254,124,255,167,255,227,255,194,244,201,1,216,253,244,255,67,255,142,254,155,254,161,241,166,1,63,0,200,0,116,0,247,255,27,255,184,255,156,255,18,13,88,0,238,255,28,0,209,255,159,0,108,0,96,255,253,0,58,0,122,11,55,0,110,1,223,255,119,243,31,0,108,255,246,255,216,255,69,254,127,0,120,0,106,0,9,0,4,0,16,255,200,0,129,0,72,1,154,255,187,0,182,0,112,0,197,10,68,243,58,1,93,255,253,255,71,255,98,1,159,255,187,255,57,255,41,0,113,255,19,0,108,0,234,255,224,255,238,255,107,255,35,0,31,0,251,255,37,236,52,0,9,0,5,0,212,255,204,255,76,0,7,0,156,255,7,0,177,255,0,0,223,255,110,0,48,255,20,0,97,255,180,255,2,0,0,224,156,0,118,0,206,254,168,255,136,0,219,254,80,255,163,0,8,0,79,7,144,255,229,0,55,1,161,255,181,255,17,0,217,0,152,0,62,0,17,0,10,255,251,13,5,0,169,255,235,255,92,0,114,0,71,255,118,0,8,0,196,0,132,255,36,255,175,0,104,0,54,0,104,0,216,255,211,255,104,255,136,1,216,0,232,255,228,255,232,7,250,255,42,0,165,255,55,255,247,255,64,255,35,0,213,255,125,6,156,254,183,4,214,250,84,1,135,244,240,255,163,0,223,252,89,254,197,0,0,254,186,255,229,0,100,254,35,1,255,1,220,255,77,255,158,255,202,255,93,0,87,0,7,1,212,255,167,0,77,0,252,255,110,28,155,255,63,255,91,0,5,255,125,255,13,1,15,0,88,255,234,255,230,255,44,0,24,0,154,0,115,0,245,255,132,255,28,0,37,0,242,255,210,255,189,255,0,224,205,255,87,255,41,0,210,254,175,255,199,7,245,255,136,0,81,255,71,0,152,255,89,0,60,0,137,0,17,0,106,0,96,0,18,255,173,255,204,255,143,255,53,0,87,11,209,255,9,0,29,255,32,245,11,255,146,0,60,255,40,255,41,0,250,255,128,255,203,255,1,0,128,255,111,255,149,0,32,0,25,0,199,255,242,255,72,0,121,255,10,0,102,248,189,255,74,0,129,255,141,0,213,254,55,0,8,0,179,3,65,247,241,254,74,0,29,255,175,255,31,0,35,1,170,255,158,244,22,0,249,255,37,1,2,0,231,255,9,0,75,244,89,0,86,12,192,0,210,255,10,255,116,255,46,0,31,1,133,0,146,255,52,1,142,255,223,255,150,255,9,0,167,255,105,0,108,1,84,255,185,0,195,255,112,17,164,255,248,254,190,255,95,255,102,0,78,255,248,254,235,255,114,0,72,10,231,5,176,3,76,255,183,246,54,0,42,254,69,255,58,253,26,252,252,253,108,252,72,254,182,252,29,1,22,0,230,254,53,254,213,254,47,245,19,247,132,254,110,247,33,3,173,253,4,255,248,1,187,255,16,253,204,3,127,2,21,1,246,1,117,0,208,251,111,255,182,5,240,253,117,8,112,3,74,255,119,244,238,2,190,251,84,2,105,0,187,0,43,2,103,255,143,255,62,3,161,0,52,1,212,255,6,255,198,255,5,254,106,254,142,253,173,5,77,5,116,0,56,254,170,12,161,253,94,0,134,1,137,1,114,0,45,4,254,255,2,0,193,9,125,5,13,253,73,5,192,0,8,5,69,255,6,1,186,6,91,0,117,3,146,253,191,254,246,0,213,248,17,0,213,0,176,255,110,253,108,248,19,1,77,3,147,254,20,1,94,8,40,255,182,242,122,253,37,2,178,255,80,255,204,255,17,3,201,250,44,0,163,0,103,254,249,4,167,2,135,254,20,3,181,250,71,249,76,1,223,0,129,5,152,255,165,0,98,1,66,1,110,9,181,249,216,0,250,255,24,255,22,249,117,248,192,9,238,253,228,0,100,252,83,255,183,254,193,253,83,249,124,252,199,0,223,0,178,2,132,253,73,0,145,254,204,1,201,252,15,236,179,1,189,3,224,0,246,0,150,1,95,253,240,2,156,1,98,255,245,254,4,0,182,2,10,0,211,255,219,0,16,4,10,3,138,248,94,7,77,253,162,2,61,4,231,253,120,1,24,4,90,3,95,255,101,2,120,1,23,2,187,250,135,248,250,253,174,252,153,2,4,3,87,244,190,255,214,255,94,8,176,252,129,251,237,0,45,255,95,255,63,245,91,2,251,1,39,0,193,253,195,255,227,251,239,254,34,1,254,254,94,255,139,0,95,0,244,255,55,255,20,255,197,2,184,254,198,254,126,255,39,235,100,0,238,255,159,255,50,255,35,7,186,6,46,1,156,3,53,255,249,2,53,253,232,255,116,1,168,253,67,8,173,4,130,250,164,2,236,247,89,255,35,255,88,252,139,5,97,1,195,254,245,0,182,244,111,2,9,1,146,253,204,0,245,9,84,2,239,0,231,255,96,253,71,2,117,0,243,255,53,247,211,250,192,7,151,5,201,250,12,251,223,2,245,0,105,0,81,2,63,255,154,253,141,3,173,254,247,251,127,1,102,0,107,1,220,2,159,5,4,4,251,4,186,1,219,3,195,240,255,254,220,255,224,0,140,255,110,254,200,0,172,253,131,255,116,1,196,253,142,1,225,253,0,4,210,6,32,253,224,251,56,249,185,3,2,4,59,252,186,1,227,249,64,254,160,255,218,5,30,0,25,255,29,254,73,0,143,243,229,6,33,5,156,255,221,1,58,255,14,3,60,1,108,1,149,255,81,254,253,248,12,255,122,0,89,254,127,254,201,1,152,252,233,253,182,251,80,0,146,255,140,5,134,2,33,0,102,243,136,2,93,3,72,1,11,251,210,253,239,1,113,3,112,0,223,1,170,0,203,254,112,7,124,250,0,253,60,251,222,255,227,3,119,253,162,0,1,0,153,0,217,3,250,2,249,254,68,255,77,0,248,2,214,246,102,13,62,254,141,6,66,4,235,6,61,8,242,255,137,255,29,252,12,1,141,0,33,0,35,0,31,0,25,2,65,0,167,254,69,0,192,0,251,2,238,255,54,4,245,14,18,1,186,1,83,255,100,254,178,1,73,253,156,3,2,0,15,6,54,2,171,255,217,0,208,3,148,8,9,254,135,250,247,2,154,3,48,244,61,252,253,255,88,2,60,254,63,255,237,252,7,0,186,0,60,3,3,2,148,0,31,255,30,251,39,252,187,1,1,254,245,7,24,6,158,12,135,2,138,5,91,255,251,254,143,254,224,0,194,1,156,255,241,254,134,255,1,254,77,253,92,250,138,3,112,255,248,0,196,1,189,3,186,255,251,253,116,0,25,242,147,252,113,254,162,1,236,250,97,254,79,255,2,3,250,245,141,254,119,249,238,251,12,254,222,254,60,253,137,253,193,0,190,9,63,1,33,2,255,2,102,0,231,0,213,255,117,255,159,255,68,253,200,249,26,1,45,5,117,250,121,253,193,1,203,7,31,253,149,2,81,6,213,2,72,250,103,2,138,3,202,0,102,255,28,255,110,247,25,255,43,1,110,0,38,5,29,4,200,254,75,3,87,252,95,249,176,253,56,251,135,253,206,255,24,3,64,6,93,251,85,255,211,0,24,253,206,254,186,0,122,7,209,243,120,252,97,255,178,0,172,253,114,253,49,3,94,0,14,255,184,246,38,255,91,254,147,254,69,253,177,0,85,254,224,255,9,1,223,255,245,0,222,255,189,20,205,254,250,254,213,254,86,0,22,1,33,0,56,255,76,255,200,255,81,1,10,4,27,255,88,19,50,1,159,253,189,0,234,255,24,1,96,255,5,254,135,0,15,251,4,255,178,1,85,254,158,0,222,253,126,255,60,246,85,2,140,3,150,3,194,2,203,4,62,13,227,3,42,1,210,253,27,5,253,2,112,255,219,255,226,254,122,0,215,0,29,251,66,4,85,0,110,252,10,2,60,1,37,7,67,253,147,254,17,243,56,1,22,0,168,2,185,250,220,0,243,0,166,0,220,255,12,3,91,9,192,255,68,3,13,4,223,2,198,3,173,0,90,4,192,0,254,1,226,251,61,5,152,253,23,6,129,3,82,1,253,255,62,255,42,255,195,253,247,254,72,1,147,254,177,1,7,254,170,255,33,0,100,255,127,255,119,255,119,0,143,0,141,22,180,255,68,0,52,3,191,4,35,5,201,2,12,0,54,6,131,0,63,255,143,252,29,255,224,2,69,2,224,2,219,255,78,254,63,254,164,254,93,16,132,8,176,250,129,249,182,255,191,4,22,1,44,8,190,255,57,1,132,1,163,250,25,0,87,2,120,3,169,255,37,1,30,0,111,1,242,3,141,252,50,3,114,252,130,248,96,3,226,1,56,252,31,251,222,0,76,4,23,0,169,255,189,9,8,255,146,253,240,0,151,0,105,3,81,245,45,5,68,253,101,254,26,1,199,246,205,248,137,253,48,255,103,0,101,254,63,3,66,254,220,254,194,1,184,0,98,255,228,1,84,248,55,18,123,0,18,0,174,0,109,2,158,0,236,252,233,0,46,1,185,1,173,254,200,0,194,255,59,255,247,255,20,255,216,3,72,2,247,253,139,254,51,255,142,3,136,1,82,3,104,244,68,0,41,253,50,5,66,2,36,0,127,254,242,2,230,253,220,255,15,1,162,1,220,253,239,6,235,251,145,252,129,250,12,2,195,251,57,250,115,1,19,0,105,3,171,0,116,11,40,255,42,0,71,0,93,251,198,253,244,253,88,1,254,252,10,240,33,253,253,253,31,4,217,253,177,3,128,250,145,3,19,252,34,255,69,254,60,0,62,255,34,253,116,7,234,253,185,250,72,0,86,252,190,255,60,245,33,5,87,255,242,249,194,1,158,253,125,3,76,4,185,253,87,0,111,255,46,255,25,1,122,5,162,2,0,0,218,255,106,3,149,254,132,9,108,8,133,249,31,254,126,255,193,255,99,253,196,254,7,253,99,254,108,0,58,9,98,1,76,0,67,249,100,252,93,250,227,4,103,3,246,247,6,2,187,3,229,254,168,2,171,255,208,253,48,254,127,0,40,255,154,250,116,7,238,0,74,255,203,1,53,251,120,4,218,8,160,255,83,2,18,253,144,3,58,255,250,6,113,250,150,253,62,254,185,0,68,251,194,2,79,253,102,255,147,254,87,253,158,250,146,3,80,251,3,255,236,253,172,12,188,1,1,0,160,255,108,254,192,255,100,254,136,250,242,244,239,252,172,3,39,255,102,1,106,2,208,0,98,244,147,254,224,255,193,255,23,255,156,252,99,254,102,1,61,254,30,5,17,253,207,250,80,246,63,0,202,1,239,254,246,4,60,1,93,0,59,254,49,254,22,251,199,255,207,251,11,248,46,0,96,255,1,18,87,251,192,0,157,254,61,252,164,255,240,2,81,2,102,0,176,255,135,255,166,0,162,253,238,254,28,0,2,1,45,0,211,255,160,3,75,252,122,255,244,254,179,255,242,0,87,6,246,250,227,2,109,0,29,1,175,0,164,255,43,240,30,254,110,1,217,0,130,255,181,252,182,3,212,251,9,3,26,7,38,2,133,252,222,255,29,252,184,7,117,10,4,253,45,0,216,255,248,248,57,2,189,254,154,255,216,251,160,15,147,255,89,254,223,254,226,2,152,252,40,3,47,252,248,1,123,252,41,0,211,255,225,254,116,255,68,254,221,1,241,254,148,252,45,1,139,246,97,6,106,252,108,253,107,255,18,246,9,254,247,254,149,255,145,253,65,254,242,252,166,252,233,253,36,255,186,1,149,2,47,255,110,3,191,249,26,14,149,0,181,254,190,0,102,0,14,1,171,5,237,0,13,0,254,251,178,0,10,5,231,254,39,255,11,0,64,249,19,4,80,244,50,253,248,252,101,1,153,253,25,255,45,3,39,254,98,6,27,2,255,253,240,0,134,4,144,0,57,0,225,4,199,5,31,254,35,253,127,6,11,253,129,2,168,2,44,254,119,245,227,255,194,255,229,4,118,4,36,1,245,0,160,255,39,1,104,253,248,254,204,254,98,253,63,253,155,0,72,240,74,1,191,0,179,255,34,250,70,1,9,0,39,1,201,253,34,0,152,255,133,255,192,254,1,255,100,4,64,1,98,0,19,5,76,254,211,5,171,254,140,3,11,0,8,0,220,3,127,248,5,0,145,250,91,3,245,250,187,253,34,2,161,255,16,1,71,254,185,0,0,255,57,1,210,1,119,254,206,255,78,17,84,252,87,0,32,255,134,1,229,253,222,254,234,251,19,2,231,246,251,4,182,253,234,251,110,249,135,4,140,3,231,7,183,3,239,254,188,255,201,2,212,253,2,3,15,3,223,0,60,0,143,252,159,255,248,2,44,2,19,255,249,254,10,255,16,255,165,0,14,2,64,3,103,237,176,1,173,254,186,0,236,1,81,0,120,255,197,252,122,254,254,251,141,254,220,254,169,3,13,255,120,255,6,0,49,0,33,255,168,253,157,254,186,20,140,0,34,0,172,255,113,247,159,252,142,248,5,255,18,1,82,2,66,251,165,2,226,1,104,251,43,0,182,251,53,255,231,253,42,7,52,5,52,1,176,1,65,255,19,12,100,7,158,3,66,254,74,251,155,253,198,0,63,2,218,255,8,1,119,1,22,1,77,253,149,255,17,0,17,255,5,1,80,3,148,253,183,0,112,2,122,0,154,254,206,255,249,3,205,251,63,253,166,254,81,1,135,255,100,0,38,255,229,251,49,254,136,237,255,253,129,251,225,2,4,17,172,2,162,250,94,6,9,2,248,253,204,255,90,0,119,0,213,255,125,255,24,0,254,255,72,255,191,255,102,2,115,1,64,254,98,254,135,5,81,253,32,255,72,2,0,253,70,251,125,11,15,244,132,0,150,1,72,252,35,1,39,1,226,252,96,2,60,250,252,253,21,0,210,254,37,8,92,249,161,245,157,254,175,0,103,254,150,2,46,0,9,255,55,255,188,253,179,0,202,255,202,1,68,3,7,6,37,7,230,254,234,254,156,1,118,9,29,8,197,0,127,252,195,1,83,2,11,6,26,2,57,3,51,2,187,1,192,253,170,252,196,253,241,0,41,254,201,0,201,254,239,253,112,0,248,235,83,255,23,255,77,254,84,1,158,0,215,255,17,1,32,255,151,3,222,249,51,4,9,1,230,254,232,4,239,3,231,0,208,2,161,1,111,254,19,238,21,253,59,254,168,251,54,0,156,0,207,253,186,10,90,254,173,255,165,255,131,254,242,254,54,251,219,3,59,252,113,2,38,254,53,2,74,11,171,255,11,5,232,254,114,2,230,255,72,3,98,4,133,248,12,3,66,253,24,3,190,253,134,255,247,255,151,4,62,255,197,253,124,11,28,2,31,0,25,7,160,254,8,1,185,3,13,248,238,0,178,12,231,249,141,2,181,254,119,254,59,3,130,254,67,1,25,1,197,250,205,252,33,2,207,0,14,0,82,1,176,1,92,3,155,6,142,0,199,2,125,1,129,251,68,16,157,252,15,255,111,0,255,253,161,252,78,0,173,5,149,254,128,255,24,255,195,248,69,9,124,251,210,0,186,2,110,4,155,252,79,255,160,254,234,5,166,250,235,252,87,251,51,3,92,1,80,0,236,1,179,0,115,252,79,2,168,253,135,254,83,249,59,0,229,253,45,2,211,255,150,254,10,3,201,236,121,253,203,0,97,3,199,254,255,254,173,0,145,246,237,3,21,249,75,3,38,254,83,6,169,4,70,255,49,1,124,2,106,253,184,7,34,2,174,255,148,255,17,253,82,3,9,2,167,249,193,243,124,254,64,0,249,0,91,251,240,249,69,10,2,0,35,255,151,255,242,2,251,0,219,0,242,254,54,255,33,2,147,0,251,3,108,0,178,250,219,250,82,5,213,250,6,243,107,254,141,254,214,253,178,254,40,1,237,1,248,0,252,255,60,5,123,0,184,253,220,252,2,253,92,255,42,254,39,1,218,0,253,255,62,0,62,255,111,253,152,19,24,1,252,255,187,255,231,254,30,252,209,0,51,1,200,33,219,255,118,255,45,0,183,254,155,255,191,255,98,0,58,0,202,2,56,0,86,255,60,0,53,255,8,255,103,0,107,0,104,254,84,2,170,0,61,0,72,2,215,2,78,254,75,255,4,236,10,254,238,1,52,0,83,0,151,255,69,1,68,0,207,253,238,254,115,1,215,248,178,255,82,244,64,1,141,0,20,253,228,6,133,4,230,253,236,254,198,249,104,255,70,3,211,255,113,4,13,0,221,252,94,255,186,252,81,251,211,7,68,2,103,14,180,252,216,253,241,254,50,254,246,251,227,255,17,1,94,3,13,1,95,0,186,0,34,255,132,255,79,0,222,255,84,253,40,3,219,251,108,252,98,2,27,2,9,5,14,3,192,4,141,12,218,255,222,253,71,251,114,254,98,0,217,255,58,0,9,251,157,253,61,2,243,1,134,247,99,255,81,252,173,253,180,1,179,4,231,1,117,250,198,253,188,5,199,2,179,253,155,255,227,12,211,255,104,250,59,254,28,7,165,2,28,4,255,248,47,4,112,254,12,1,48,254,187,1,252,1,239,254,32,253,23,255,14,1,93,251,117,248,72,251,249,253,145,252,69,1,8,4,24,1,53,2,38,1,28,10,209,254,128,2,138,250,46,4,162,2,57,0,91,255,210,255,0,2,245,2,113,242,212,252,170,252,45,0,101,0,123,12,238,252,195,255,122,0,46,251,182,255,119,0,123,254,254,0,172,255,61,3,185,5,94,252,171,0,8,255,201,0,171,3,1,0,52,0,67,242,194,248,147,0,181,252,54,1,246,1,217,2,191,0,13,2,77,1,99,253,226,242,215,0,40,2,156,0,21,249,214,3,22,253,11,2,69,255,84,253,200,1,123,0,248,249,111,255,58,0,197,251,146,249,227,250,7,3,156,5,129,5,166,251,85,255,26,0,17,249,79,4,120,254,251,247,59,251,100,0,160,251,25,0,217,254,50,1,151,255,254,253,246,238,156,0,132,247,65,255,166,255,7,0,194,255,244,0,149,255,9,2,53,1,22,0,105,253,239,0,43,255,30,255,100,0,180,8,182,254,59,255,33,251,148,252,25,6,255,255,158,254,183,1,93,255,194,254,195,255,96,251,50,244,154,5,65,0,87,0,38,3,211,247,200,11,254,3,245,252,121,254,238,255,165,250,220,253,142,3,114,252,74,254,161,2,48,0,4,4,36,2,153,0,175,254,42,2,97,1,150,6,212,1,66,255,143,255,208,253,30,2,94,0,116,255,62,255,198,255,165,0,102,255,201,254,136,18,108,255,49,0,3,255,180,0,191,255,131,255,117,255,207,255,141,255,242,254,183,1,139,0,210,0,202,0,49,255,191,255,35,254,168,0,144,237,160,255,189,251,233,247,201,253,206,250,237,0,155,1,133,255,173,4,65,10,68,5,26,255,106,1,109,255,117,255,69,253,186,4,213,254,92,0,19,11,220,255,216,254,31,1,122,9,109,251,38,255,116,3,192,254,106,4,195,251,153,4,71,252,248,252,97,2,59,3,166,255,131,0,59,245,55,2,117,3,201,246,187,3,56,255,165,248,131,0,26,1,176,255,141,0,248,255,223,255,77,1,41,3,101,1,243,255,243,1,85,2,155,3,67,249,3,250,209,1,163,255,139,8,183,252,239,2,74,0,146,247,99,0,202,251,53,254,136,2,254,254,93,1,107,252,176,4,118,1,51,249,11,252,212,2,195,255,182,0,192,15,187,253,99,4,112,254,53,254,69,254,196,254,3,0,241,254,8,255,239,255,83,2,206,0,92,251,53,11,58,5,3,255,60,1,38,254,144,6,168,252,49,250,35,2,167,2,169,1,254,254,92,0,252,255,232,255,117,0,99,255,129,1,255,254,180,254,35,234,188,255,183,254,191,255,148,255,235,254,202,0,112,254,124,0,205,255,5,0,71,0,90,0,97,252,198,3,12,3,49,1,191,2,34,3,131,249,121,250,190,255,181,1,158,253,61,1,27,3,87,2,67,255,66,1,249,253,86,240,217,2,148,253,177,247,95,1,250,1,188,255,162,0,41,252,224,254,95,12,116,255,223,3,169,253,128,0,76,7,64,0,193,255,255,255,255,7,155,0,153,252,126,255,226,0,252,1,243,1,114,3,178,14,129,254,233,255,0,0,167,254,24,254,167,0,136,2,139,1,114,0,97,4,87,1,232,0,230,253,15,0,86,1,204,252,38,0,179,1,44,254,230,254,97,254,99,236,219,254,147,0,21,2,128,255,186,255,247,1,76,3,170,255,44,7,201,247,137,251,186,255,2,254,64,2,79,253,154,1,203,247,177,1,83,1,95,254,52,3,157,0,173,0,198,1,182,253,195,4,183,255,253,235,88,1,141,1,53,0,105,0,245,1,197,255,3,2,194,0,100,1,78,0,194,2,47,1,76,1,180,17,227,2,193,3,247,253,120,254,20,0,71,253,55,3,95,2,13,255,76,1,109,1,182,254,51,1,173,1,159,252,248,255,33,2,253,255,153,23,202,254,16,1,208,1,22,0,100,255,142,0,193,255,169,255,41,1,232,255,50,2,247,255,147,0,85,1,235,255,119,0,106,5,179,3,54,249,12,254,113,253,95,0,32,0,32,0,187,0,6,2,50,5,95,0,188,254,36,14,225,2,202,255,55,0,158,2,28,251,227,3,228,1,67,5,23,253,244,0,6,1,173,255,134,255,170,4,115,253,169,251,185,254,187,254,251,13,42,255,219,255,100,254,245,254,135,254,194,255,131,0,104,1,203,0,175,233,214,255,94,0,23,1,150,1,157,254,34,0,112,255,156,0,0,255,208,255,158,255,144,250,249,4,202,0,31,251,127,242,58,253,239,3,37,0,4,249,86,0,198,253,23,2,17,0,143,254,104,6,48,3,139,255,128,0,55,252,155,250,224,0,239,5,28,252,191,252,163,3,185,0,36,3,209,1,82,0,69,0,9,255,240,12,82,254,233,255,173,0,33,255,8,12,56,7,93,251,42,250,27,254,149,251,240,1,251,253,172,253,64,1,171,252,233,250,240,0,214,254,159,0,15,2,255,254,156,1,71,3,4,252,194,2,85,242,81,255,191,251,51,253,187,254,5,1,54,1,52,249,245,251,109,254,27,255,163,252,54,252,194,255,64,255,23,2,150,247,148,254,147,251,211,3,29,243,97,1,214,3,251,253,120,4,205,253,163,2,29,1,63,0,17,0,91,248,82,0,28,0,255,253,245,1,97,251,196,5,211,252,2,255,208,249,99,251,86,254,200,255,108,252,203,0,123,245,209,0,214,251,106,251,23,1,183,1,201,0,155,4,29,3,151,1,83,3,159,3,60,1,128,253,118,5,128,255,181,10,51,2,3,249,221,3,164,3,247,0,6,0,151,253,12,1,77,253,88,4,199,253,115,3,42,1,37,0,150,254,107,253,239,255,102,255,194,253,209,2,226,17,205,0,251,1,77,0,166,255,79,254,179,249,14,1,12,254,219,251,98,6,124,254,80,254,120,253,63,248,117,2,71,11,55,255,224,255,223,0,109,2,143,0,190,1,104,5,85,4,43,1,73,1,22,252,156,254,224,5,179,255,49,0,184,3,70,16,224,253,171,255,100,254,7,255,218,1,27,0,149,255,1,13,59,0,195,0,165,255,186,255,190,12,124,255,104,1,157,0,102,254,184,0,157,255,118,255,81,1,33,1,61,1,156,0,179,253,129,255,52,255,37,0,81,255,227,233,204,255,174,3,156,0,255,255,59,255,97,1,90,0,57,0,225,254,38,255,182,1,252,255,250,254,9,0,66,1,89,255,88,11,244,255,169,245,8,255,53,255,245,254,140,255,121,255,77,1,36,255,56,255,40,0,228,0,117,10,50,254,73,255,127,255,82,11,40,253,25,3,166,1,29,2,162,254,28,0,222,0,230,10,25,255,61,255,65,255,186,11,182,0,158,253,145,0,30,255,154,255,29,1,88,1,155,254,217,0,110,255,158,255,18,0,1,255,96,0,105,255,10,1,208,0,53,254,124,255,167,254,219,15,141,254,79,0,44,0,193,255,23,255,78,1,44,0,44,15,49,0,25,243,88,0,233,255,225,254,51,254,57,0,94,0,203,255,127,255,104,0,167,0,231,255,177,255,131,255,138,253,208,246,150,0,93,254,40,0,193,255,91,2,67,0,209,0,65,1,27,249,56,255,68,0,217,1,110,2,5,0,189,244,112,0,188,0,67,255,51,245,169,0,141,1,182,254,126,253,226,252,129,0,146,255,92,255,236,255,176,0,43,255,217,234,39,0,31,0,13,0,14,1,35,254,166,0,167,0,4,0,216,0,244,255,240,253,181,255,221,254,140,1,13,254,37,248,84,255,247,254,96,0,83,0,233,254,114,0,90,255,65,3,30,0,189,9,94,0,130,0,73,255,109,253,1,0,29,255,75,0,93,1,59,245,82,0,140,255,9,0,184,3,144,255,116,246,179,254,50,255,106,254,201,0,15,0,0,253,88,0,110,5,223,255,210,253,97,0,55,255,29,0,142,13,50,0,216,255,241,254,85,255,230,255,47,0,229,1,6,255,246,12,112,0,127,2,161,244,123,0,248,254,3,0,8,0,123,1,73,0,54,0,88,0,227,0,73,0,58,0,196,253,14,3,73,255,49,1,49,0,233,255,104,244,215,255,35,1,231,255,157,0,39,1,186,247,125,0,5,0,63,255,97,255,225,253,181,255,157,4,65,255,221,253,163,255,117,0,217,248,9,1,161,253,226,255,194,0,167,240,186,255,159,0,79,0,17,250,38,0,201,0,14,0,232,255,180,255,146,254,14,0,68,245,0,0,140,254,149,1,39,0,86,255,64,1,255,254,105,8,244,255,158,0,66,1,83,240,22,0,155,255,217,0,125,2,17,1,82,254,228,0,84,254,102,0,156,254,246,254,82,0,225,255,14,0,33,255,221,245,152,254,46,8,133,254,112,2,64,255,245,0,38,1,204,5,139,255,156,0,203,255,84,14,11,242,138,255,43,255,1,1,45,255,66,0,194,255,83,255,90,255,133,255,163,0,175,255,217,255,182,255,235,255,126,0,210,2,120,255,2,8,50,255,86,0,19,1,76,0,7,255,55,0,52,246,95,0,196,255,222,255,152,254,247,255,187,0,34,0,169,255,226,255,137,0,48,0,153,18,109,0,255,1,16,254,104,0,143,1,151,254,162,0,78,0,227,255,159,0,144,255,182,0,246,0,52,0,255,0,82,1,221,255,255,255,188,255,5,0,182,0,251,29,137,255,242,255,147,248,145,255,150,255,22,0,240,255,81,0,159,0,137,246,185,255,232,255,103,255,248,253,126,0,114,1,70,255,230,0,205,255,111,254,206,0,224,255,52,0,185,255,177,255,247,1,17,255,25,255,55,0,123,255,106,20,211,255,91,255,57,0,10,9,47,255,46,1,78,0,154,0,236,243,163,253,14,254,154,1,159,0,80,1,109,255,136,255,143,0,36,0,75,2,74,255,74,255,177,5,240,3,220,9,66,254,29,9,15,254,7,253,94,255,125,0,164,1,225,0,139,255,188,254,181,1,206,255,190,0,129,0,3,1,33,0,254,255,247,255,32,0,232,255,91,0,97,0,201,0,19,0,169,0,207,13,229,1,112,255,74,1,63,255,101,245,91,2,47,1,100,4,107,0,150,250,99,250,53,255,180,0,175,255,47,1,209,0,235,255,191,255,26,0,91,0,98,0,187,250,196,0,55,8,149,3,36,253,66,3,176,5,164,255,57,254,126,255,36,253,224,254,39,0,171,255,211,253,217,255,141,12,41,1,136,1,134,254,248,253,27,3,153,246,6,0,7,0,150,1,203,0,183,255,9,255,61,1,248,242,94,12,206,0,220,255,159,0,233,254,186,1,54,0,188,254,238,255,32,2,6,255,142,0,72,254,100,0,111,255,68,241,57,255,139,0,100,255,245,255,34,0,78,255,23,255,142,254,89,2,198,255,143,6,86,255,76,0,172,2,221,255,183,255,204,255,223,255,253,255,167,255,251,255,174,255,73,0,245,255,51,0,208,255,244,255,136,254,252,16,53,255,80,254,189,0,221,255,144,0,31,0,181,0,150,255,8,236,40,2,224,1,0,0,63,0,31,0,33,0,248,1,31,4,65,244,42,255,154,0,156,255,246,0,13,1,89,254,67,2,63,0,132,6,216,254,134,1,109,0,21,0,250,255,71,0,249,12,246,0,197,0,99,1,58,255,216,1,135,0,181,1,58,249,19,5,227,0,150,253,208,255,57,255,217,0,26,255,70,0,99,0,72,10,53,255,33,12,169,255,149,0,47,1,124,0,106,1,190,254,212,255,38,0,104,0,228,255,48,0,81,255,44,254,102,254,157,238,104,255,109,8,26,0,231,254,187,253,36,0,51,255,101,0,230,0,192,0,127,255,63,1,20,0,65,0,15,19,123,0,20,255,78,255,128,255,125,254,132,255,16,2,142,0,249,252,211,254,168,255,132,254,120,0,214,255,239,255,64,0,206,251,234,242,55,5,202,251,242,255,50,254,143,255,253,0,194,1,36,0,248,255,166,254,202,255,249,255,52,0,156,255,74,0,74,32,63,255,220,255,205,255,12,0,59,0,188,255,190,0,220,255,89,0,38,0,197,255,13,0,13,1,109,0,241,255,115,255,192,255,196,255,238,0,6,0,14,239,125,1,228,4,98,1,215,255,41,0,191,0,20,255,122,0,104,245,96,1,139,255,135,255,228,254,236,5,217,1,180,254,235,254,0,249,177,254,84,0,64,0,123,37,10,255,234,254,190,1,161,255,224,255,60,0,110,255,104,0,172,255,253,255,107,0,140,255,135,254,101,0,107,255,211,255,108,1,104,0,63,255,2,255,113,11,92,255,163,255,68,1,237,2,96,252,179,1,53,9,94,1,216,255,103,255,208,255,142,253,134,1,208,255,104,239,54,254,94,252,38,255,26,254,233,6,79,1,152,0,165,0,111,0,118,0,105,254,169,255,139,254,179,254,122,255,86,0,224,255,112,255,238,255,240,255,131,226,110,255,49,0,72,255,116,0,228,255,205,255,190,0,115,0,80,0,68,0,129,0,206,0,38,1,75,1,179,0,242,254,174,0,140,9,55,0,57,243,70,0,132,255,228,0,74,1,235,255,93,254,62,0,116,255,172,246,7,0,133,245,127,255,230,251,220,253,43,3,189,0,103,1,127,254,174,255,71,35,95,0,77,0,187,255,164,0,5,1,61,0,183,255,230,0,93,255,141,0,218,255,213,255,106,255,164,0,28,0,164,0,59,0,198,255,200,254,122,255,102,0,189,255,166,0,93,255,63,0,117,229,153,255,109,255,81,0,17,1,133,0,122,0,94,255,49,255,127,0,196,255,20,18,255,255,35,5,6,2,93,255,10,255,54,0,239,0,154,0,102,255,9,1,208,7,25,0,227,0,42,0,179,0,88,0,138,242,42,255,182,0,182,1,90,0,196,0,187,255,134,0,200,255,61,254,204,2,160,251,225,254,118,0,230,0,219,255,145,0,28,1,6,255,139,0,77,252,203,0,152,243,199,255,151,0,129,12,50,3,169,255,91,1,26,254,55,255,152,4,187,254,58,252,249,254,72,255,238,0,100,255,116,254,152,0,191,3,197,255,223,255,97,255,253,255,178,36,137,255,175,255,206,255,67,0,9,0,27,0,194,255,135,255,46,255,48,0,45,255,5,0,140,1,121,2,34,0,240,255,67,0,9,255,179,255,128,0,185,1,56,15,251,0,202,3,119,0,125,254,221,255,124,0,192,255,104,253,106,230,101,0,204,255,19,0,44,0,124,255,79,0,219,2,101,255,250,254,116,255,225,255,65,255,146,255,20,1,94,255,207,255,81,0,139,255,15,0,198,253,164,1,48,251,131,255,153,14,161,255,32,2,107,255,207,1,127,255,167,254,94,1,183,0,173,0,197,0,208,1,180,0,7,255,147,254,239,252,247,255,173,242,21,255,132,255,225,0,92,238,196,0,106,255,167,255,167,255,54,0,146,255,137,0,81,254,16,1,244,255,249,255,114,0,55,255,166,0,34,6,182,255,168,255,131,23,94,1,181,255,68,0,227,255,175,255,206,255,57,0,194,255,103,0,61,0,20,1,22,0,125,255,122,255,237,242,196,255,187,242,201,254,151,255,90,0,97,255,34,255,151,0,224,0,46,255,8,1,192,0,29,0,172,255,29,242,150,255,125,255,203,255,100,255,196,0,50,255,152,255,18,0,124,244,122,0,146,0,248,253,2,0,38,1,93,254,255,255,231,255,255,254,118,36,87,0,201,255,214,255,30,0,92,0,35,0,195,0,31,0,59,0,88,0,47,0,47,0,36,255,52,2,106,249,170,1,106,0,140,1,97,0,35,5,27,9,167,0,19,251,235,3,220,2,212,254,170,254,162,1,87,0,236,0,11,255,187,8,11,0,213,2,232,255,87,255,32,254,29,11,96,0,222,255,67,0,89,3,28,0,50,0,92,0,52,8,172,255,168,253,58,248,96,247,93,255,43,1,175,1,199,252,229,254,43,1,158,255,135,1,191,255,164,255,56,255,79,253,188,8,174,255,175,255,204,255,127,0,86,0,119,255,193,254,255,245,166,255,35,2,58,255,10,0,195,0,146,254,128,245,179,255,22,255,144,255,11,255,14,1,199,0,114,10,199,255,95,253,247,255,5,4,225,255,55,1,206,255,96,255,81,255,67,9,151,10,153,1,237,255,22,0,12,255,56,1,98,255,14,1,131,255,9,255,118,0,165,255,166,253,86,0,174,0,40,255,18,0,232,11,95,248,171,0,63,248,215,254,39,1,218,255,58,255,27,255,107,1,243,255,127,0,13,0,54,255,139,255,65,0,74,0,63,0,125,0,194,255,254,255,225,253,88,253,83,239,126,255,69,1,207,255,11,255,206,255,3,254,105,255,237,255,3,0,152,0,44,252,127,255,22,255,143,1,93,1,171,0,60,255,88,19,254,255,36,0,32,1,3,3,9,9,231,0,217,255,60,2,60,244,77,0,11,254,41,255,28,255,68,254,62,3,200,0,68,255,99,255,176,12,23,1,9,243,0,0,76,0,10,0,160,0,176,255,135,0,102,0,163,254,174,0,226,255,168,255,111,255,51,255,10,0,71,255,177,0,222,255,25,0,31,0,218,0,252,255,191,0,172,0,228,0,120,255,78,255,12,1,126,2,231,13,55,0,198,0,145,0,86,1,231,255,108,248,50,11,178,254,103,252,149,7,48,254,17,1,75,255,6,254,235,255,102,254,116,0,77,255,207,255,239,254,234,255,220,255,238,250,18,1,217,248,65,1,130,254,238,0,120,242,188,255,62,255,32,0,161,255,6,254,72,0,64,0,183,254,19,0,217,255,91,1,210,254,204,0,145,0,184,255,87,3,144,255,244,241,221,3,15,245,130,1,193,245,41,254,101,0,101,255,1,1,35,1,30,0,103,255,185,0,172,0,255,1,20,0,166,0,18,1,29,0,49,244,129,0,33,0,37,255,51,255,6,0,47,0,105,254,137,0,51,2,150,255,239,247,76,0,201,0,157,255,86,255,179,255,170,0,72,238,72,254,160,255,84,252,214,251,81,0,205,0,102,1,179,1,178,255,108,255,55,255,171,255,205,254,206,254,14,0,209,255,155,255,69,255,120,255,124,1,252,255,224,255,222,255,202,255,16,2,198,255,245,24,46,1,177,255,52,0,228,255,191,255,179,255,244,255,64,35,156,255,6,1,20,0,189,255,225,255,50,0,223,255,226,255,116,255,70,1,110,251,208,254,120,255,23,255,170,0,60,0,58,1,90,255,48,255,151,255,11,255,87,255,184,255,137,0,251,227,254,255,119,1,152,0,226,0,50,255,171,254,47,1,47,0,242,3,68,255,65,2,220,254,3,242,244,255,61,255,20,0,117,8,50,255,168,255,173,255,124,255,216,255,69,254,236,0,179,254,179,0,45,255,200,255,62,1,103,254,34,12,95,0,116,45,84,1,204,0,189,254,167,0,76,0,61,0,65,0,99,255,71,0,235,255,38,0,66,0,135,1,204,255,20,0,239,255,11,0,3,1,45,0,62,255,184,1,104,13,122,0,212,1,173,253,192,248,94,0,85,254,123,255,149,0,239,254,61,0,34,230,48,0,97,0,94,255,93,0,146,1,152,255,49,255,64,0,234,254,92,0,131,1,3,0,96,0,254,255,229,255,226,255,84,0,64,0,35,0,191,255,98,0,85,0,240,255,8,255,250,30,74,0,4,0,152,255,83,0,208,255,40,0,200,247,170,255,167,255,99,0,114,255,65,0,103,245,63,0,81,254,11,2,175,2,212,0,21,250,3,0,59,0,55,0,250,255,22,0,248,255,108,255,180,0,78,0,153,30,193,255,173,255,13,0,69,255,140,255,156,0,227,255,70,255,96,255,148,0,174,255,209,254,90,255,112,0,153,255,217,255,91,255,11,11,202,255,230,255,24,0,17,244,78,0,21,0,128,0,175,255,231,255,134,255,51,0,202,255,237,255,188,0,238,255,255,255,116,255,238,255,107,224,124,0,210,255,45,0,194,253,12,0,106,255,147,0,65,0,47,255,116,254,68,254,214,240,221,254,25,255,40,1,244,0,76,0,180,0,36,0,241,245,147,2,193,255,205,12,171,255,48,0,250,253,159,254,130,0,50,0,13,0,82,1,169,254,236,254,240,255,97,1,108,232,179,255,18,0,139,0,43,0,79,1,38,1,99,0,219,0,186,1,231,255,203,255,40,0,15,1,175,0,230,254,165,255,174,1,180,238,241,255,215,244,194,255,229,255,86,255,33,0,87,253,146,255,180,255,153,0,42,0,122,255,111,255,222,0,79,255,217,255,58,1,222,8,14,2,244,1,113,9,83,1,16,7,239,255,208,1,243,253,159,255,124,0,224,255,114,1,48,0,117,249,194,255,87,255,82,10,207,9,213,255,243,251,72,255,54,0,199,253,8,254,9,255,216,255,71,1,7,0,82,0,59,255,214,10,222,255,141,244,52,255,144,255,194,0,150,254,187,0,65,0,90,255,115,0,131,255,14,0,210,0,144,0,181,255,57,0,1,255,105,255,18,242,103,255,182,0,89,0,30,246,98,0,247,254,83,255,123,255,4,1,231,255,244,250,35,0,131,0,158,255,171,255,19,255,82,0,73,5,47,0,2,15,148,0,171,0,183,0,234,0,89,0,163,255,47,0,102,0,252,255,90,0,164,11,33,1,25,255,97,1,241,1,147,255,190,0,203,244,185,2,136,0,90,0,12,255,42,1,137,255,249,253,206,255,207,0,213,255,160,250,100,1,142,7,189,2,237,246,159,2,71,0,200,255,89,255,47,241,91,241,153,255,134,0,28,255,243,255,27,0,211,255,151,255,172,0,179,255,233,255,53,0,110,0,138,255,176,255,92,255,64,255,205,253,137,1,198,255,84,254,152,254,112,14,162,0,83,255,147,6,82,254,196,1,164,255,107,0,215,255,28,0,171,255,165,1,190,255,98,1,168,255,211,2,191,10,117,244,31,254,122,255,25,255,111,255,3,0,65,0,168,255,189,0,187,0,151,0,174,0,220,255,240,0,3,255,21,255,62,255,222,234,209,255,158,255,82,1,25,254,175,255,221,255,174,255,72,254,31,0,109,0,217,0,20,1,243,248,22,1,17,1,143,254,117,2,219,254,243,253,8,241,73,0,200,255,149,254,173,6,177,0,3,245,28,3,94,255,171,254,152,4,181,255,21,2,86,3,207,2,242,0,62,255,90,0,109,255,203,0,120,255,118,255,4,253,6,0,29,245,243,255,80,4,217,5,73,4,90,0,157,252,50,253,195,254,119,0,180,0,160,0,1,1,228,9,211,253,194,255,14,0,153,2,240,5,200,1,58,3,138,1,163,253,140,3,222,0,116,255,121,0,121,0,232,0,124,0,96,0,169,255,48,0,205,255,41,0,115,225,219,255,130,0,245,255,223,255,119,255,16,0,42,0,229,5,248,255,119,0,173,255,238,255,64,0,41,0,78,255,228,255,182,0,20,2,166,2,181,255,21,1,26,255,186,255,185,255,248,255,106,255,65,1,102,231,236,255,125,255,191,255,139,0,41,255,101,255,229,255,146,255,255,254,32,0,201,0,215,0,184,0,228,34,150,255,206,255,66,0,15,0,212,255,203,0,218,255,19,0,178,255,65,0,135,0,133,255,166,0,117,0,76,0,4,0,34,0,166,255,96,23,59,0,184,255,100,1,192,255,6,0,194,255,43,0,170,255,81,255,150,255,10,0,25,0,228,14,121,255,15,243,142,0,92,1,155,255,221,255,122,1,6,255,150,255,213,254,237,0,40], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1635525);
/* memory initializer */ allocate([0,224,255,236,0,247,253,63,0,113,255,26,2,0,255,43,0,211,255,106,6,214,2,103,243,109,0,27,252,3,0,0,255,229,255,74,255,178,255,4,240,247,255,231,0,34,0,9,0,250,255,155,0,26,11,53,0,126,255,122,254,110,255,168,0,182,255,25,248,69,252,64,2,139,253,180,255,70,0,140,0,225,254,111,254,198,3,103,1,161,4,30,255,201,2,241,2,29,253,114,239,36,13,75,0,43,255,27,0,84,255,222,255,171,0,138,255,210,255,92,255,243,255,202,255,53,255,102,255,244,255,65,0,63,241,132,242,41,1,152,255,163,255,175,255,69,0,77,255,191,254,51,0,47,0,242,0,241,255,112,255,213,255,11,11,67,0,207,254,54,0,28,244,57,0,241,255,85,254,55,1,51,255,226,0,22,254,37,0,107,1,168,255,104,254,198,255,222,0,102,255,182,255,203,255,75,19,165,1,67,0,26,0,132,0,60,0,159,255,255,255,213,255,72,1,2,0,204,1,190,255,245,255,211,255,200,255,170,255,183,214,127,255,58,0,231,255,39,0,28,0,26,0,45,0,195,255,117,255,234,255,121,255,230,254,251,253,144,254,55,0,209,255,30,0,146,255,47,0,75,0,243,255,65,0,215,255,104,0,137,18,107,255,157,255,28,0,165,1,5,2,200,255,81,0,203,254,67,0,214,255,250,255,17,0,196,255,105,255,50,0,172,255,247,255,29,0,184,255,53,244,82,0,61,255,41,0,242,255,50,255,222,255,198,255,238,255,30,0,106,8,236,255,2,0,255,255,41,0,246,255,7,0,86,0,238,1,123,0,72,1,73,0,213,0,227,255,17,0,43,0,164,255,195,255,247,255,126,255,143,255,33,0,228,255,235,229,58,255,71,255,20,255,183,0,148,255,227,2,60,0,98,0,198,254,66,0,10,0,167,243,97,255,222,244,118,0,37,0,215,255,137,255,15,12,43,0,220,255,42,0,106,0,82,255,205,242,164,255,114,255,19,255,94,0,197,255,133,255,139,255,144,0,181,255,146,0,244,254,49,2,120,251,80,1,197,5,207,0,89,0,130,0,127,0,179,14,140,254,48,0,99,0,204,0,84,0,209,0,103,0,118,0,125,0,70,1,227,255,50,255,139,0,195,255,94,0,77,0,224,25,93,255,23,0,27,0,152,255,150,0,180,255,51,255,70,255,226,255,29,255,198,255,17,0,25,0,120,230,237,255,190,255,211,255,184,255,41,0,49,0,177,255,105,0,252,255,139,255,219,255,73,255,216,0,229,255,233,255,225,255,96,245,53,0,233,255,210,255,247,255,246,255,50,0,244,255,206,255,200,255,35,0,122,21,146,255,254,255,44,0,255,255,13,0,52,0,238,255,195,255,176,255,227,255,25,0,61,0,219,255,93,0,237,255,67,0,75,0,215,255,254,0,161,0,118,0,205,242,142,1,247,255,48,255,113,255,207,0,121,255,224,255,171,0,187,0,62,255,210,1,201,255,158,0,34,0,105,0,122,19,27,0,215,255,20,0,87,0,146,255,39,0,80,0,219,255,8,0,231,255,212,255,148,255,85,255,146,254,208,0,31,255,1,0,132,255,21,0,81,0,147,215,205,255,33,0,205,255,141,0,220,255,106,0,156,255,64,1,122,0,3,0,10,1,72,0,248,255,144,255,55,0,149,255,198,239,187,255,0,0,71,0,103,255,176,255,206,255,20,0,144,255,225,0,66,248,17,1,237,255,129,255,109,0,231,255,47,0,57,0,158,255,246,255,42,0,231,255,10,0,24,0,41,0,183,255,45,0,61,242,142,254,141,12,54,0,169,255,67,0,71,255,100,0,223,255,215,255,3,0,218,255,70,0,148,255,136,255,189,255,112,255,75,255,223,255,152,255,173,1,89,0,81,3,206,11,51,245,171,254,184,0,8,255,98,2,152,1,34,255,184,0,84,0,192,255,223,1,110,255,47,0,156,255,13,0,17,0,249,255,58,0,243,255,220,255,233,255,255,255,231,255,10,0,106,10,143,255,215,255,116,255,248,11,105,0,31,0,226,11,181,255,124,255,143,255,80,0,156,255,217,255,216,0,252,255,7,0,213,255,242,0,19,0,249,251,219,2,181,241,232,255,236,255,109,0,126,0,164,11,19,0,245,255,208,255,57,0,118,255,245,255,45,255,105,255,28,2,143,255,146,255,0,0,97,254,150,0,176,255,176,255,209,0,174,255,164,235,131,255,120,1,8,0,131,0,118,255,30,0,102,252,192,254,181,0,181,255,138,0,144,255,146,0,184,255,64,0,181,255,250,254,8,19,245,255,195,255,37,0,51,255,48,0,47,247,82,0,106,0,93,0,190,255,48,0,71,0,29,0,72,0,32,0,29,0,17,0,5,0,34,0,29,0,227,255,184,255,50,0,234,225,142,255,139,255,47,0,11,0,19,0,100,0,48,0,228,255,248,255,53,0,21,0,80,0,213,255,37,0,164,0,22,0,241,255,118,235,233,255,224,255,108,0,52,0,7,0,95,255,11,0,84,0,141,0,248,255,244,255,231,255,111,0,146,0,160,255,66,0,220,28,54,0,17,0,202,255,62,0,44,0,190,255,243,255,26,0,13,0,85,0,177,255,235,255,98,0,156,0,181,0,153,255,68,255,221,255,77,255,83,0,117,0,164,255,49,0,71,255,216,14,166,255,14,0,42,0,94,0,173,255,78,255,100,255,248,255,33,0,42,0,204,0,42,0,1,0,171,255,47,0,10,0,52,42,36,0,8,0,26,0,209,255,205,255,67,255,83,0,209,255,233,255,104,0,26,228,189,255,55,0,21,0,68,0,8,0,172,255,196,255,213,255,142,0,215,255,27,0,184,255,186,255,86,255,115,255,202,0,58,255,151,255,41,0,31,242,222,255,108,255,34,0,194,255,95,255,236,255,183,255,128,0,162,0,105,223,4,0,185,255,210,255,12,0,27,0,48,0,215,255,50,0,237,255,168,255,7,0,79,0,29,0,237,255,225,255,207,255,109,255,162,248,153,255,43,255,28,0,73,255,23,16,87,0,6,0,250,255,51,0,66,255,89,255,140,255,23,0,230,255,7,0,218,255,66,21,179,248,175,255,197,0,105,0,134,255,65,0,220,0,32,0,199,255,217,255,241,255,4,0,112,0,201,255,117,255,199,252,217,3,147,255,254,9,218,0,94,0,65,0,72,255,197,12,101,0,191,255,42,0,116,1,218,255,58,0,8,0,113,255,224,253,244,254,121,0,38,0,61,0,193,255,246,255,226,255,204,255,180,255,182,255,222,229,251,255,96,255,76,0,179,255,74,0,118,1,107,252,239,0,53,255,38,2,172,255,207,254,36,1,205,255,36,0,135,0,177,255,27,0,187,255,203,254,209,17,189,255,11,0,196,255,43,0,18,0,254,255,8,0,241,255,20,0,22,0,254,255,215,255,164,246,37,0,177,255,67,0,27,0,172,255,97,1,43,255,224,246,58,0,39,0,126,0,178,255,158,255,166,255,253,255,247,255,213,255,254,255,227,255,251,255,107,255,42,0,98,0,147,255,137,0,58,0,173,255,218,255,51,0,125,25,50,0,97,0,225,255,8,0,132,0,185,255,201,255,11,0,120,0,2,0,213,255,136,0,219,255,171,255,150,0,133,0,67,0,215,255,60,254,152,255,4,0,126,0,100,0,156,245,148,255,147,255,192,255,103,2,181,255,45,0,10,0,199,255,199,255,148,255,167,0,38,255,246,255,181,254,230,255,235,255,161,25,73,0,169,253,126,0,233,255,250,0,153,255,252,255,228,255,236,255,221,255,237,255,51,0,9,0,231,255,216,255,44,212,254,255,28,0,244,255,23,0,153,13,169,0,159,0,39,255,208,255,114,0,163,255,222,255,65,255,193,255,31,0,182,0,79,0,90,0,55,0,67,0,111,255,153,1,190,0,145,225,230,255,18,0,71,0,143,255,176,255,69,0,235,255,229,255,135,255,51,0,108,255,103,0,196,0,166,10,189,255,206,11,228,255,26,0,157,255,51,0,24,0,61,0,104,0,89,0,199,255,233,255,144,255,43,0,6,0,13,0,72,255,88,255,117,0,227,255,73,7,253,255,20,0,8,0,30,0,32,0,175,255,80,0,236,255,197,255,37,0,19,0,149,255,176,240,253,254,44,0,23,0,127,255,24,0,190,255,229,255,1,244,116,0,9,0,180,255,56,0,173,255,25,0,54,0,236,255,2,0,230,0,56,0,215,255,131,0,241,255,194,255,61,0,56,0,74,0,222,255,110,0,254,17,252,255,18,0,209,255,75,1,150,255,178,255,70,0,53,0,70,0,234,255,77,0,185,255,196,255,155,255,70,0,7,0,104,0,249,255,39,0,229,255,42,28,253,0,241,255,0,0,160,255,32,0,50,0,246,255,33,0,10,8,11,0,241,255,42,0,242,255,51,0,4,0,253,255,245,255,170,255,10,0,33,0,21,0,238,255,225,255,249,255,53,0,249,255,95,0,7,0,75,0,206,211,7,0,17,0,240,255,173,255,37,254,137,252,139,251,1,0,155,255,5,0,210,255,110,0,166,255,209,255,241,255,19,0,66,0,18,240,104,0,43,0,105,0,130,255,181,0,43,0,137,249,175,255,245,255,33,0,223,255,33,0,28,0,212,255,35,0,250,255,218,255,68,0,216,255,67,0,73,0,227,255,171,0,206,46,42,0,248,255,190,255,190,255,40,0,237,255,14,0,33,0,193,255,24,0,94,0,162,255,150,255,72,2,74,1,148,255,255,240,14,3,212,254,245,255,209,254,82,255,39,255,253,255,24,0,168,0,187,0,90,255,54,0,238,0,243,254,229,255,182,0,252,255,184,255,209,255,32,0,39,0,198,29,210,255,189,255,203,255,56,0,123,0,206,255,69,0,220,255,237,254,116,2,201,255,195,0,200,255,247,254,124,255,217,255,252,255,169,0,113,0,76,255,237,255,88,0,229,230,42,0,255,254,156,4,103,1,79,1,237,14,116,0,79,0,3,0,163,255,67,0,212,255,58,0,240,255,9,1,172,0,217,255,212,255,18,0,92,0,4,0,218,0,122,0,79,244,150,0,138,0,106,2,66,0,150,253,146,1,179,8,10,0,38,0,52,1,82,1,186,255,9,1,23,4,152,255,74,255,49,1,94,255,157,255,254,1,236,255,142,255,17,2,214,255,15,242,52,0,176,255,198,254,204,2,225,255,3,1,59,0,183,255,139,255,38,0,212,255,240,255,182,255,60,236,35,0,10,0,226,255,54,0,217,0,36,0,51,255,164,0,203,241,21,242,13,255,133,255,209,255,169,255,224,255,62,0,129,0,254,255,131,0,220,255,54,255,59,255,37,0,221,255,70,254,117,255,187,255,197,255,29,0,194,255,189,255,239,255,214,255,74,0,10,0,107,0,74,0,147,255,40,0,30,216,223,255,118,243,102,254,150,255,0,2,40,0,239,255,109,0,67,0,99,0,170,0,53,0,34,0,188,255,240,255,55,15,185,255,140,255,1,0,96,2,66,0,41,255,34,0,77,0,50,0,211,255,183,255,3,0,11,0,223,255,18,0,222,255,58,0,25,0,68,17,96,0,77,0,189,255,23,0,173,255,188,229,226,0,224,255,106,255,102,255,30,0,244,255,248,255,249,255,89,0,42,0,173,0,205,255,38,0,196,248,40,0,208,255,216,255,81,0,34,0,81,0,66,0,16,0,20,0,3,0,99,0,41,0,123,0,52,0,154,0,20,0,218,255,6,0,137,42,212,255,22,0,217,255,55,0,222,255,25,0,211,255,234,255,139,0,19,0,236,255,192,255,62,247,39,254,143,255,60,1,127,0,225,255,128,0,149,254,132,255,196,0,3,1,196,255,48,241,215,255,153,255,104,0,176,255,123,254,179,0,110,0,83,0,102,12,60,0,59,255,101,0,66,0,209,255,149,255,96,0,229,255,45,0,235,255,6,0,116,0,205,255,248,255,174,253,121,1,233,254,158,0,97,255,243,17,93,255,46,255,19,0,3,0,220,254,189,255,14,0,115,0,215,255,131,255,102,255,249,254,155,255,4,0,245,255,167,255,130,0,58,0,32,0,92,0,16,0,126,0,163,255,157,255,113,239,187,255,88,0,5,0,143,255,238,255,35,0,31,0,208,255,240,255,35,0,62,0,233,244,14,0,121,0,19,0,41,0,125,0,154,255,26,0,168,204,6,0,226,255,249,255,60,0,4,0,36,0,216,255,230,255,54,0,199,255,247,255,226,255,13,0,255,255,73,0,125,255,29,0,0,1,39,0,205,255,244,255,252,6,4,0,10,0,198,255,17,0,220,255,254,255,13,0,59,0,236,255,235,255,173,0,129,0,77,254,149,255,42,255,33,0,6,12,13,0,31,0,148,0,97,244,201,254,38,0,25,0,9,255,226,253,34,0,106,0,120,254,85,0,53,255,182,0,24,255,167,1,117,2,73,255,32,3,46,254,73,12,62,246,207,254,39,0,22,0,41,0,0,0,242,255,159,2,75,255,125,12,109,0,84,11,72,0,192,255,8,0,158,1,133,0,244,0,249,254,53,0,187,255,70,0,68,202,243,255,21,0,50,0,12,0,242,255,244,255,249,255,97,0,224,255,24,0,51,0,232,255,227,255,53,0,34,0,237,255,219,246,208,3,25,0,198,255,18,0,208,255,70,246,201,255,225,255,91,255,220,255,28,0,230,255,92,0,60,0,137,0,69,0,35,235,131,255,174,7,102,255,190,255,243,255,172,255,243,255,81,0,210,255,160,255,50,0,206,255,142,255,15,0,30,0,45,255,109,255,213,253,158,15,88,0,102,1,97,255,151,255,205,255,147,255,240,255,70,0,91,0,12,1,125,0,161,255,194,255,38,0,101,243,7,14,241,255,92,0,184,255,115,0,144,0,216,255,142,0,172,0,72,0,239,255,23,0,1,0,28,0,218,255,121,255,220,0,176,255,77,255,9,0,224,255,250,255,37,0,223,255,253,255,167,255,146,28,5,0,194,0,243,255,23,0,31,0,42,0,84,0,197,0,93,255,5,255,239,254,193,0,206,0,155,253,138,1,141,13,27,10,67,253,62,0,45,1,152,255,200,0,164,0,55,255,39,254,52,0,39,254,128,0,131,254,148,1,187,255,26,255,231,253,157,0,133,1,249,255,223,10,242,11,95,0,197,255,82,6,1,0,4,0,53,0,250,255,28,0,10,0,2,0,82,0,28,0,248,255,242,255,25,0,59,0,10,0,252,255,36,0,247,252,136,236,29,0,8,0,85,0,213,255,119,255,222,255,53,0,198,255,1,0,229,255,91,0,15,0,80,0,237,255,70,255,211,1,94,0,130,254,129,0,71,1,237,11,35,255,143,1,251,244,66,4,22,1,254,255,93,255,114,254,126,0,246,254,180,0,21,255,70,0,238,255,222,255,211,255,159,0,224,255,66,0,11,0,105,12,68,255,27,0,35,0,204,255,114,0,228,255,120,255,186,0,98,8,100,0,92,0,6,0,58,0,186,255,159,0,242,255,224,255,9,0,6,0,229,255,183,255,28,0,23,0,232,255,101,0,148,0,80,0,204,255,229,255,203,255,220,255,4,0,182,255,47,0,226,255,148,255,34,0,45,28,12,0,31,0,239,255,71,255,246,12,199,0,192,0,122,13,169,255,3,0,47,0,46,0,115,255,49,0,83,0,174,255,124,255,174,255,68,0,138,0,249,251,20,255,134,1,219,255,23,0,162,255,249,255,9,0,114,244,202,248,213,255,23,0,25,0,177,255,63,255,179,255,252,242,229,242,117,255,56,0,163,0,26,243,174,255,231,255,35,0,96,0,73,0,166,0,102,255,174,0,135,255,14,0,167,255,101,0,89,241,168,254,16,255,221,255,145,1,242,255,47,0,207,255,24,0,178,255,24,0,6,0,68,0,51,0,111,255,20,0,83,0,57,0,147,0,156,255,60,0,33,0,203,255,11,0,37,0,95,233,163,255,189,255,247,255,117,0,112,0,205,255,60,0,48,0,49,0,72,1,37,1,127,0,198,254,50,244,118,1,211,12,170,255,76,2,166,254,180,1,249,255,230,255,168,255,104,0,205,0,150,0,147,0,34,0,126,0,85,0,46,0,131,255,137,255,75,0,13,0,144,0,137,14,19,1,185,255,43,0,163,0,183,255,220,254,131,254,177,255,33,0,79,0,177,255,34,0,162,255,18,0,229,0,63,0,28,0,212,255,97,0,234,241,77,0,161,255,94,255,163,0,62,0,36,24,81,0,205,255,237,255,251,255,109,0,71,0,7,0,219,255,156,255,225,255,162,255,188,0,169,0,242,255,46,10,95,254,18,0,237,238,231,255,180,0,108,0,17,0,33,0,48,0,210,255,163,255,179,255,32,0,219,255,185,255,241,254,208,255,239,254,242,255,115,0,197,255,200,254,250,242,26,244,71,0,90,255,123,1,209,0,114,255,22,0,89,0,215,255,216,255,249,255,206,255,8,0,241,255,12,0,186,255,229,255,229,255,25,0,225,255,38,0,251,255,15,11,167,255,248,255,206,255,146,255,88,5,197,255,253,246,6,0,179,0,75,0,189,0,170,0,201,255,74,1,186,255,172,0,67,0,20,254,199,255,176,242,9,0,163,255,120,211,14,0,255,255,235,255,65,0,241,255,45,0,234,255,40,0,246,255,215,255,23,0,227,255,160,255,201,255,190,255,199,255,195,255,227,255,241,255,155,255,153,217,33,0,42,0,221,255,42,0,212,255,198,255,11,0,216,255,27,0,21,0,203,2,197,254,1,255,141,255,200,6,4,0,41,0,186,255,205,255,148,255,160,0,247,255,87,0,250,255,36,0,236,255,188,255,10,0,82,0,223,255,214,255,15,0,199,255,216,255,225,255,21,0,39,39,62,0,215,255,246,255,85,0,191,255,244,255,195,255,184,255,158,253,128,0,180,255,198,0,111,1,44,238,60,0,158,0,243,255,122,255,211,255,223,255,245,255,205,255,184,255,111,0,68,255,232,0,18,254,229,255,42,0,46,0,233,255,137,0,102,12,242,241,211,0,152,0,155,0,213,254,56,0,233,255,133,255,132,0,50,0,28,0,192,255,28,0,9,0,239,255,31,0,112,0,237,255,4,0,45,0,249,227,54,0,195,255,249,255,87,0,164,0,195,0,227,255,208,255,28,0,196,255,70,0,187,255,112,0,217,254,5,0,167,255,38,0,36,0,19,211,17,0,230,255,192,255,34,255,91,0,233,255,167,255,0,0,162,255,143,8,182,255,172,255,195,255,215,255,57,0,24,0,221,255,228,255,219,255,230,1,131,0,115,14,235,254,64,0,131,255,13,255,14,1,57,1,144,255,145,0,47,0,210,244,2,255,146,255,229,255,187,255,170,254,136,255,216,0,35,0,24,0,62,0,217,255,227,255,98,9,249,255,253,255,14,0,209,255,229,255,4,0,27,0,20,0,81,0,138,0,75,0,178,0,165,1,129,244,248,243,172,255,216,255,198,255,61,255,74,255,101,0,69,255,6,0,173,255,13,1,224,255,157,255,51,0,218,255,44,0,82,0,242,255,221,255,0,0,8,0,233,255,2,42,183,255,199,255,68,0,107,0,85,0,77,0,101,0,1,0,228,255,103,0,246,255,48,0,55,0,33,0,163,255,238,255,8,0,28,0,242,255,193,253,28,0,64,210,90,0,70,255,58,0,38,0,214,255,108,8,174,255,28,0,233,255,43,0,43,0,8,0,25,0,65,0,0,0,203,255,28,0,168,255,132,1,220,255,107,1,64,0,252,11,56,0,64,1,54,255,151,242,73,0,173,254,99,255,117,1,40,255,213,255,171,0,140,0,75,254,113,255,252,244,155,255,53,0,145,255,65,0,217,255,65,0,226,255,69,0,201,255,49,0,45,0,126,0,174,0,220,0,73,0,155,255,196,255,105,255,243,255,215,255,208,255,247,255,25,0,134,255,176,255,110,246,19,0,94,0,14,0,238,255,237,255,60,0,76,243,246,255,62,13,241,255,147,254,241,255,183,255,34,255,51,1,70,0,161,255,237,0,114,255,93,255,212,255,118,255,249,255,6,0,220,255,189,255,9,0,234,255,251,39,200,255,248,255,44,0,101,255,139,255,234,255,224,255,182,255,242,255,224,6,17,239,240,24,12,248,58,11,56,246,7,250,102,0,83,27,13,251,187,243,26,4,197,255,20,6,22,252,0,6,0,4,75,7,40,0,124,251,189,245,43,255,246,251,108,253,35,1,61,252,189,254,206,1,220,252,171,8,165,252,173,6,38,2,194,242,63,1,24,0,132,2,82,12,151,17,87,248,232,2,194,0,105,255,25,251,218,250,217,11,125,252,238,255,1,0,0,0,2,0,0,0,28,0,67,251,115,241,35,246,79,255,116,251,105,1,155,254,119,253,53,254,44,5,159,9,220,243,5,243,193,253,72,245,148,255,135,255,4,254,204,253,175,252,251,252,224,254,0,0,8,0,0,0,254,255,5,0,179,2,166,253,221,8,69,9,21,248,18,3,195,11,162,12,149,250,202,254,147,2,154,254,34,4,238,249,7,4,27,3,206,8,219,253,78,1,69,1,87,2,220,255,255,255,255,255,254,255,3,0,4,0,62,254,235,253,135,249,120,248,246,251,132,253,90,250,192,254,135,10,160,4,185,2,102,4,135,4,154,11,193,1,226,255,246,247,109,251,84,253,190,255,137,3,213,255,1,0,0,0,3,0,0,0,3,0,228,0,16,1,177,255,50,253,186,7,155,2,56,245,227,5,155,248,228,252,140,4,35,0,168,238,116,238,125,249,93,16,85,25,17,254,185,6,153,249,242,253,202,1,0,0,129,1,73,255,255,1,103,255,23,248,136,254,132,11,210,245,114,252,27,253,85,254,200,251,80,8,53,2,29,254,255,6,82,247,211,255,76,251,31,3,0,2,74,237,182,5,255,1,142,248,15,0,0,0,0,0,1,0,3,0,8,0,157,252,83,253,116,255,179,20,120,1,133,252,121,6,51,7,71,250,239,250,6,2,224,237,47,1,235,254,118,253,159,255,4,9,89,253,208,2,85,255,37,254,243,254,0,0,251,255,4,0,255,255,9,0,125,251,166,236,148,6,3,248,171,3,51,3,17,253,91,255,163,255,233,246,50,1,197,3,135,19,45,2,201,255,25,252,30,0,220,255,221,3,112,249,198,249,62,1,253,255,248,255,252,255,1,0,247,255,110,254,0,32,219,1,32,8,94,254,53,249,239,254,201,255,71,254,26,3,177,255,16,1,9,248,21,3,218,8,106,3,191,9,115,2,155,8,188,4,228,251,133,1,14,0,232,255,197,255,10,0,133,0,233,253,120,251,141,251,110,255,180,0,40,4,134,14,124,250,129,4,81,7,219,253,94,249,57,250,209,0,213,2,84,252,104,8,56,7,166,2,189,9,0,18,245,255,0,0,255,255,253,255,253,255,2,0,78,1,169,2,161,2,0,224,118,15,217,243,105,6,220,5,160,4,244,254,181,243,59,2,190,3,105,253,249,251,154,252,94,253,182,251,239,253,78,0,188,4,120,0,248,255,243,255,251,255,214,255,219,255,14,254,24,5,19,246,194,6,157,254,182,5,11,9,225,7,109,254,38,248,43,2,111,5,119,3,247,7,110,1,135,0,85,0,115,1,11,5,31,255,79,1,211,255,0,0,1,0,2,0,255,255,2,0,185,251,251,254,177,12,140,12,171,248,166,3,121,249,247,250,118,5,17,247,51,255,123,6,130,2,81,4,239,2,48,11,147,4,23,252,62,1,222,254,60,0,202,255,5,0,3,0,5,0,2,0,1,0,151,255,78,2,36,0,62,255,40,7,129,253,9,3,171,12,66,2,4,11,172,1,228,7,111,2,200,247,204,255,181,254,9,252,248,11,165,254,209,254,180,251,61,0,255,255,255,255,0,0,2,0,255,255,80,2,127,0,119,3,186,251,253,244,13,10,146,245,99,249,41,245,48,0,246,254,63,252,196,4,40,254,167,0,129,12,94,4,83,255,24,5,230,255,125,252,76,0,0,0,3,0,0,0,1,0,255,255,50,253,22,253,179,3,244,253,142,0,190,3,183,249,247,252,174,250,129,1,190,253,221,228,157,0,222,254,77,5,89,249,228,1,117,0,80,247,104,241,186,252,160,255,255,255,11,0,5,0,4,0,2,0,219,1,86,254,244,1,1,253,0,247,224,4,152,8,219,248,32,252,31,255,195,253,173,251,192,252,251,9,206,244,125,13,239,16,168,255,120,251,126,249,162,255,223,255,0,0,0,0,1,0,254,255,249,255,109,255,0,224,180,4,99,251,66,253,164,253,254,252,8,4,83,255,2,3,93,3,99,2,3,254,34,3,45,254,71,3,235,1,239,252,11,2,99,253,73,0,222,255,0,0,0,0,254,255,253,255,253,255,30,1,121,247,42,251,207,6,131,1,76,247,132,250,145,242,91,249,189,246,61,254,246,8,13,8,246,11,158,251,47,250,6,251,51,0,17,22,86,255,149,8,109,1,255,255,243,255,4,0,3,0,251,255,241,255,253,239,21,3,36,16,118,19,52,248,16,3,236,2,75,8,207,13,43,250,82,250,168,254,157,252,40,0,63,3,82,251,66,0,30,2,97,6,158,246,117,0,137,255,238,255,49,0,18,0,40,0,12,254,40,3,42,253,168,4,39,14,246,5,28,254,56,4,58,246,189,253,35,5,161,248,84,0,235,6,170,244,107,5,182,251,23,6,154,251,140,2,128,252,32,0,255,255,3,0,1,0,3,0,254,255,233,0,14,3,0,32,54,2,67,253,160,254,23,4,69,2,210,251,87,12,123,251,207,249,63,6,46,252,105,253,93,252,235,245,210,19,13,3,217,253,178,253,9,255,193,255,202,255,206,255,253,0,118,255,199,254,131,1,68,244,144,251,142,2,253,250,38,5,178,1,80,0,50,250,182,2,0,254,137,1,18,255,68,253,24,255,194,2,198,5,0,224,121,1,89,2,18,0,255,255,253,255,0,0,250,255,253,255,173,8,203,13,162,252,0,7,14,255,154,241,164,1,99,7,150,3,44,5,234,0,205,252,167,253,59,9,183,251,51,9,242,2,131,255,245,0,153,253,213,12,204,0,0,0,6,0,252,255,253,255,255,255,131,253,161,2,209,4,70,11,9,1,61,255,30,255,217,9,25,1,46,255,17,7,83,245,231,240,17,247,129,2,212,245,117,239,107,0,21,3,139,4,216,245,49,254,251,255,10,0,2,0,246,255,39,0,100,5,242,2,43,236,221,15,159,249,54,249,188,249,145,7,23,7,15,4,112,14,175,253,170,8,219,251,57,4,63,251,14,8,131,253,212,249,149,0,142,253,3,255,253,255,239,255,2,0,33,0,1,0,118,0,13,2,158,0,189,4,142,3,151,255,99,250,225,250,207,8,93,254,166,246,6,6,10,241,113,251,26,252,181,251,99,6,142,6,168,251,237,254,122,0,206,255,0,0,3,0,0,0,255,255,255,255,230,3,76,240,135,248,197,251,97,255,61,7,76,254,85,253,42,1,211,0,199,2,32,16,71,248,66,252,24,4,130,2,92,254,73,1,130,251,203,1,113,8,29,0,252,255,0,0,255,255,250,255,1,0,85,5,29,4,8,4,184,3,86,3,101,9,242,19,71,7,233,11,213,3,161,252,115,254,252,1,253,250,137,253,17,0,20,2,83,250,224,251,66,0,245,1,229,255,255,255,3,0,255,255,243,255,254,255,239,254,148,244,71,3,79,254,117,254,4,255,153,7,195,0,205,254,239,250,62,250,39,252,60,17,7,252,50,4,151,10,228,3,151,3,183,0,246,255,163,253,38,0,1,0,255,255,255,255,2,0,1,0,67,8,90,254,71,14,76,248,193,5,15,248,157,9,168,251,13,251,179,0,118,254,118,252,7,251,80,254,58,4,111,1,48,253,210,6,111,253,83,2,189,2,16,0,255,255,0,0,0,0,2,0,253,255,1,255,187,1,208,248,181,246,40,1,2,1,93,253,35,255,150,1,40,255,105,231,239,251,38,4,199,0,169,6,248,251,165,249,161,246,198,0,183,251,241,254,157,255,0,0,1,0,254,255,2,0,243,255,87,1,37,255,89,250,243,6,118,2,104,248,187,251,214,249,194,255,202,250,251,10,209,252,31,5,226,243,212,254,67,0,24,0,98,0,252,2,34,251,203,0,6,0,0,0,252,255,0,0,1,0,0,0,238,255,88,249,109,250,160,254,151,245,180,253,31,1,203,2,58,254,176,2,88,254,200,6,156,251,4,4,99,226,16,253,30,254,149,254,181,255,48,253,149,253,193,1,0,0,3,0,0,0,16,0,253,255,69,251,180,9,162,13,221,253,63,253,240,6,226,254,212,249,80,11,47,247,42,255,8,249,14,251,206,253,110,251,226,253,17,3,70,6,23,2,51,0,131,250,249,255,255,255,255,255,0,0,255,255,2,0,84,254,189,253,189,251,189,245,239,8,11,253,165,5,101,254,96,255,55,2,108,0,231,250,252,238,122,254,107,252,89,1,135,247,128,252,188,14,200,4,179,2,231,255,1,0,1,0,1,0,254,255,1,0,25,1,85,5,164,249,183,253,157,13,169,0,234,2,117,254,48,4,33,6,207,251,232,2,250,4,112,242,11,4,118,252,190,242,255,249,155,252,25,11,145,1,4,0,255,255,253,255,253,255,255,255,253,255,219,255,164,249,136,252,17,3,0,13,81,4,223,13,34,27,104,249,130,10,253,247,92,247,90,241,145,248,15,254,227,4,163,4,202,231,90,15,85,0,203,251,16,0,233,255,176,255,126,255,43,0,66,0,50,252,67,2,1,248,233,241,102,253,56,247,11,18,190,26,88,0,119,253,105,4,1,255,239,13,132,255,41,0,58,0,122,2,28,251,184,2,232,9,202,249,209,0,12,0,154,255,237,254,27,0,216,0,86,4,3,1,213,247,239,6,72,241,86,2,185,1,239,248,81,254,22,0,33,252,147,253,84,0,245,248,49,6,47,2,179,251,42,0,200,1,120,254,150,252,252,255,0,0,0,0,1,0,255,255,0,0,141,254,45,255,173,254,48,251,182,1,133,245,17,252,226,4,223,20,93,3,231,250,191,253,59,8,167,245,101,243,252,3,129,255,50,2,119,21,192,243,98,254,239,253,12,0,203,255,222,255,151,0,106,0,126,244,193,253,252,248,23,12,255,254,177,253,126,0,199,3,221,253,241,254,48,2,206,3,249,242,194,247,133,250,27,23,172,251,132,1,14,251,246,253,80,1,167,0,1,0,253,255,254,255,2,0,253,255,200,254,19,0,28,13,99,4,92,253,9,255,185,2,36,2,232,6,150,4,243,253,3,255,89,254,34,2,187,246,132,244,225,251,0,247,203,0,29,5,194,253,248,255,0,0,253,255,4,0,0,0,4,0,41,255,0,32,98,253,247,250,245,249,208,254,218,5,57,252,239,253,186,253,99,247,216,6,65,1,61,2,184,251,64,0,128,4,169,255,62,2,6,255,27,2,62,0,7,0,2,0,255,255,253,255,3,0,47,254,243,0,101,251,60,3,59,246,33,255,198,0,141,252,28,253,89,4,227,248,236,247,94,243,179,6,197,7,25,7,215,2,104,6,58,13,254,249,160,252,45,0,0,0,252,255,0,0,0,0,2,0,96,2,41,250,235,4,124,255,31,5,94,1,25,2,175,10,148,5,151,0,44,5,35,2,113,240,156,248,104,0,231,7,116,7,238,251,106,4,228,4,67,253,9,0,0,0,254,255,255,255,1,0,1,0,90,2,0,224,40,245,107,253,104,6,187,1,124,13,30,253,61,3,125,2,36,1,232,0,72,5,15,19,149,5,144,3,137,2,57,6,52,1,182,254,68,0,63,0,253,255,4,0,199,255,26,0,25,0,226,4,144,1,25,237,211,0,68,245,104,253,228,3,85,1,227,251,65,1,154,9,252,2,231,2,39,253,12,0,229,254,166,254,118,0,7,255,103,255,231,246,219,255,0,0,255,255,0,0,1,0,1,0,96,1,146,252,32,9,134,253,126,245,169,242,123,244,237,253,235,4,138,1,163,0,30,252,77,3,235,4,122,3,120,5,23,1,116,7,161,0,130,247,84,7,76,0,1,0,255,255,255,255,10,0,0,0,47,0,157,251,75,6,233,1,106,2,208,252,249,255,209,7,90,251,65,7,67,245,201,254,181,254,221,2,132,5,110,5,11,250,238,4,143,250,249,254,52,12,158,255,0,0,1,0,0,0,1,0,254,255,2,2,51,242,166,246,39,14,249,0,224,251,3,2,255,4,5,11,221,1,183,0,177,2,158,4,98,5,7,5,57,253,240,4,55,253,234,254,217,0,104,253,31,255,255,255,0,0,6,0,2,0,9,0,109,251,47,12,60,5,51,251,119,248,192,7,203,250,250,3,10,0,181,4,63,0,102,1,172,251,57,254,99,254,86,3,242,249,89,254,76,255,225,9,0,224,238,255,0,0,254,255,255,255,0,0,0,0,90,253,235,14,220,250,135,4,78,2,25,255,155,8,3,250,218,3,193,16,90,4,111,4,118,251,103,252,198,255,179,2,11,0,74,249,242,254,237,253,18,2,65,0,0,0,255,255,1,0,4,0,0,0,96,251,177,250,62,28,235,253,227,247,92,251,113,0,64,250,234,1,238,5,196,5,163,248,166,3,244,0,48,7,72,253,32,254,84,246,252,12,127,246,78,4,120,0,1,0,245,255,254,255,18,0,253,255,8,252,189,0,5,241,133,249,210,255,76,255,157,245,206,7,99,250,83,4,56,247,165,0,111,253,41,236,32,255,222,4,213,1,165,1,121,4,124,4,84,0,238,255,3,0,0,0,0,0,250,255,0,0,190,255,50,255,231,8,36,255,70,6,91,254,54,250,99,254,43,251,118,1,107,14,235,1,250,252,154,1,23,3,124,1,57,13,103,2,74,252,148,253,59,255,65,0,255,255,3,0,253,255,2,0,255,255,28,254,116,5,17,1,249,241,37,5,11,252,27,6,122,255,90,2,211,251,221,2,113,251,233,0,63,1,250,254,94,1,12,3,105,254,16,254,251,250,46,5,243,255,0,0,2,0,255,255,0,0,255,255,184,254,142,253,176,252,233,2,233,251,208,15,132,254,56,254,154,248,101,3,195,251,139,254,13,11,110,2,217,1,138,1,237,0,129,247,143,4,178,236,246,0,100,0,255,255,1,0,250,255,1,0,250,255,186,255,35,0,77,6,37,10,27,5,220,6,96,251,58,4,203,3,44,248,77,250,18,254,216,255,233,2,228,10,194,252,76,0,24,2,46,248,145,1,199,255,236,255,0,0,0,0,0,0,0,0,0,0,248,255,244,0,135,7,138,4,144,246,122,250,207,1,167,255,193,4,226,252,138,1,9,250,49,253,102,253,230,3,238,5,105,246,23,244,106,251,120,245,209,243,2,0,0,0,254,255,2,0,2,0,3,0,69,4,145,253,124,6,157,249,177,5,0,10,251,2,66,245,163,3,6,7,246,9,122,5,146,3,105,252,139,7,129,254,77,254,185,253,183,1,9,0,174,251,244,255,255,255,0,0,0,0,0,0,254,255,177,254,38,253,202,247,122,250,16,10,227,240,1,4,135,249,254,255,89,3,176,254,61,244,205,0,84,4,108,1,235,252,77,255,171,0,75,1,156,8,15,2,243,255,1,0,253,255,2,0,1,0,252,255,203,253,45,255,117,255,7,7,195,0,147,252,136,253,102,1,12,255,77,250,118,5,223,8,38,2,195,7,158,8,175,254,199,0,132,228,77,2,195,0,46,254,72,0,255,255,2,0,1,0,0,0,0,0,229,255,131,254,154,249,0,224,5,0,215,3,55,250,236,255,49,253,18,255,255,2,59,2,56,255,242,2,204,1,142,6,96,5,101,255,50,248,38,1,57,254,80,0,2,0,26,0,3,0,10,0,25,0,93,252,182,251,114,251,107,243,53,248,190,2,104,0,131,246,34,247,92,5,22,9,219,255,44,250,156,6,132,2,253,250,107,1,112,2,29,254,241,255,90,1,250,255,2,0,0,0,1,0,3,0,2,0,131,246,0,224,68,252,166,4,194,2,69,252,111,1,191,3,62,255,45,253,176,251,119,1,42,2,62,252,27,255,66,0,112,1,18,0,106,255,56,0,200,3,241,255,0,0,255,255,251,255,0,0,9,0,6,255,48,253,118,7,59,3,198,0,123,253,229,7,32,0,76,248,63,253,185,1,117,1,32,3,11,247,211,6,224,5,231,253,61,249,88,251,61,6,65,240,24,0,0,0,254,255,1,0,1,0,1,0,125,255,58,6,103,255,103,4,172,10,213,1,210,253,245,255,166,4,115,0,91,252,196,7,49,7,78,238,105,5,59,2,95,9,173,6,193,255,177,241,135,245,57,0,252,255,11,0,252,255,0,0,253,255,170,1,95,239,195,10,180,255,125,249,146,9,139,254,47,13,165,255,24,255,255,1,136,2,118,3,158,4,131,6,65,0,43,244,189,253,97,3,138,8,95,11,25,2,0,0,2,0,253,255,0,0,7,0,73,2,0,32,217,244,0,32,151,21,141,234,122,248,121,239,76,251,161,7,87,251,191,0,206,12,66,249,3,1,22,245,109,16,219,16,23,232,162,253,126,248,82,14,188,254,18,255,199,254,48,253,89,250,229,253,230,252,79,12,66,249,116,13,108,3,72,2,97,253,15,254,151,1,141,3,121,247,15,10,246,0,95,253,14,1,56,3,248,6,55,255,161,28,77,2,186,255,255,255,4,0,251,255,253,255,248,255,95,254,126,1,226,10,52,252,8,2,130,4,118,3,9,2,144,23,81,253,207,14,246,253,54,251,96,2,172,1,123,3,12,250,9,252,123,4,254,4,47,2,250,255,3,0,0,0,6,0,2,0,253,255,115,0,2,14,225,244,95,0,204,1,16,11,22,9,127,249,184,6,197,1,197,3,130,4,196,1,71,249,161,250,243,254,90,8,16,248,55,0,94,253,154,252,132,255,0,0,5,0,0,0,251,255,253,255,229,254,53,4,44,10,246,4,198,251,39,249,184,26,58,246,220,3,2,249,98,5,207,4,182,1,92,251,30,1,28,2,118,255,30,4,145,255,239,246,74,0,56,0,253,255,254,255,0,0,224,255,5,0,3,6,137,250,245,28,121,252,94,249,245,6,1,255,46,254,100,250,91,13,124,7,84,3,78,2,154,251,175,249,227,250,72,234,15,255,35,13,55,251,122,10,108,2,250,255,58,0,2,0,70,255,239,255,113,244,107,2,180,8,189,245,209,243,218,2,132,14,230,253,155,255,185,248,252,253,142,0,176,246,22,250,126,234,199,252,2,2,202,2,234,2,26,245,57,2,87,254,4,0,188,255,70,0,24,0,12,0,49,3,236,254,221,242,130,244,103,0,187,253,99,252,139,2,49,2,43,0,178,1,200,2,227,253,6,248,245,250,59,254,69,254,40,239,192,250,253,4,93,2,252,255,0,0,255,255,255,255,1,0,2,0,94,252,20,1,147,12,108,254,80,252,15,254,72,3,22,1,158,255,104,250,144,251,73,248,185,248,178,251,90,250,170,3,181,2,190,235,255,255,61,4,29,247,1,0,1,0,255,255,255,255,254,255,3,0,86,251,200,254,23,251,181,7,34,6,89,249,155,249,127,2,169,252,133,7,202,3,92,2,33,5,12,3,206,235,165,253,220,0,37,253,136,11,152,252,166,0,30,0,0,0,254,255,255,255,3,0,255,255,25,253,248,1,83,5,156,5,96,6,134,253,59,253,214,246,87,0,125,4,140,13,84,8,212,11,241,251,164,255,39,8,34,252,211,254,198,3,251,252,223,251,42,0,0,0,254,255,0,0,2,0,2,0,252,0,217,0,41,14,237,246,212,0,131,254,159,251,128,6,205,254,144,6,145,8,194,248,69,255,228,243,254,0,95,253,83,2,203,7,157,2,81,253,3,254,13,0,0,0,8,0,253,255,11,0,253,255,216,253,169,255,6,0,117,11,245,254,144,250,40,0,132,2,32,0,150,11,150,250,80,246,68,252,136,4,119,5,25,4,62,15,212,247,243,253,188,6,69,0,223,255,0,0,254,255,0,0,2,0,2,0,60,254,125,237,91,243,2,254,170,253,139,250,87,3,37,6,95,8,177,255,246,249,239,255,51,252,160,246,153,6,133,0,67,251,16,3,214,2,148,3,124,254,122,254,1,0,255,255,253,255,255,255,0,0,170,0,51,255,167,244,0,32,47,254,47,12,55,17,59,253,109,254,91,3,139,254,235,250,139,250,18,253,168,255,21,1,207,247,34,255,122,255,168,255,91,251,206,3,200,255,199,255,173,255,235,255,102,0,114,2,142,255,0,247,211,3,212,248,156,252,237,4,178,8,251,254,67,2,215,3,143,2,238,245,11,7,117,0,152,251,109,1,131,15,211,13,235,255,234,252,194,255,2,0,3,0,23,0,253,255,31,0,249,4,140,12,175,249,20,16,231,254,213,2,228,254,55,4,37,1,81,241,21,10,175,249,253,254,237,255,49,248,224,11,251,243,14,250,32,4,164,255,129,3,243,0,255,255,36,0,237,255,246,255,210,255,231,0,105,4,107,1,70,248,142,252,4,249,63,1,199,18,85,249,157,250,71,250,23,9,197,252,87,253,154,1,232,248,53,246,12,4,228,2,218,2,81,253,100,0,255,255,255,255,255,255,1,0,252,255,236,254,47,1,229,246,160,244,184,248,146,241,156,1,62,251,106,6,96,17,146,2,43,255,104,3,51,11,227,0,100,3,178,253,245,8,223,6,126,249,207,249,116,255,1,0,253,255,255,255,26,0,246,255,225,254,130,3,118,246,157,15,137,249,195,250,200,255,177,2,179,248,60,2,4,248,104,2,213,245,234,254,171,11,93,9,249,247,247,0,128,0,86,2,196,6,110,255,0,0,3,0,255,255,253,255,5,0,74,3,85,2,11,3,7,250,222,252,94,8,124,249,35,9,34,242,165,245,197,6,5,250,210,255,88,2,106,2,157,252,103,253,244,5,136,1,150,250,49,243,45,0,0,0,9,0,249,255,253,255,248,255,32,255,184,245,109,255,7,254,175,8,237,6,7,7,96,249,194,0,94,251,225,253,7,3,109,251,115,21,241,246,135,243,199,254,157,254,123,255,183,251,125,0,234,255,254,255,2,0,1,0,253,255,246,255,158,254,89,250,106,253,199,254,50,239,48,15,135,255,189,254,88,4,223,252,23,250,210,252,146,249,152,253,73,251,91,1,227,1,158,2,132,3,221,255,139,252,14,0,1,0,0,0,1,0,254,255,7,0,80,254,26,254,253,249,17,3,245,18,136,3,157,3,127,3,57,251,96,246,67,13,6,254,216,252,207,0,197,0,106,3,96,252,67,5,149,255,232,5,39,4,74,255,1,0,252,255,255,255,250,255,3,0,44,251,233,251,6,3,26,0,138,253,95,3,31,4,184,245,93,251,234,253,149,253,201,251,242,245,11,248,146,2,205,4,250,254,142,10,191,242,117,247,228,6,66,0,0,0,7,0,0,0,7,0,253,255,165,2,68,254,193,247,120,235,123,238,125,249,29,8,77,6,203,5,16,250,64,6,231,6,124,4,6,8,140,6,74,7,15,3,105,247,253,2,56,2,219,10,85,253,4,0,17,0,0,0,224,255,15,0,45,0,228,0,115,246,240,2,206,9,135,249,241,251,113,0,83,4,226,251,27,249,35,251,33,246,77,2,199,1,72,1,128,2,189,253,66,9,33,5,228,253,31,0,1,0,255,255,252,255,2,0,253,255,21,255,208,253,199,1,225,14,102,0,147,1,235,255,52,7,146,1,148,0,224,255,197,21,75,241,247,254,50,253,113,254,163,254,110,1,175,251,91,0,89,7,34,0,1,0,1,0,5,0,0,0,9,0,33,1,134,251,27,3,56,246,156,1,132,4,210,254,78,252,15,8,247,245,239,254,102,250,141,0,130,2,137,253,248,18,16,252,169,0,216,255,191,0,11,247,170,255,6,0,1,0,254,255,0,0,1,0,139,0,163,7,169,251,80,252,140,0,206,251,47,4,224,250,227,253,152,2,9,7,132,252,69,6,42,249,114,253,88,253,90,224,120,0,232,255,246,3,161,254,136,255,0,0,254,255,1,0,255,255,255,255,14,4,79,20,11,3,85,251,128,0,206,1,184,0,121,14,244,250,57,247,79,246,50,10,44,17,65,16,199,15,87,4,70,3,188,0,197,253,251,10,133,248,139,248,13,0,99,0,236,255,254,255,11,0,139,1,155,0,107,10,54,255,177,245,23,5,112,252,58,249,73,4,185,253,204,13,38,255,22,250,215,240,122,1,210,255,91,251,67,252,62,244,25,253,120,253,15,0,1,0,3,0,3,0,4,0,252,255,74,1,198,0,237,254,91,253,0,224,139,253,161,7,241,252,80,2,158,3,207,5,217,255,22,252,110,4,24,6,229,255,138,255,173,250,152,254,115,8,186,1,92,0,1,0,1,0,254,255,5,0,1,0,98,253,70,1,213,10,66,5,230,255,71,1,184,0,189,251,135,255,64,2,212,250,212,0,123,253,92,3,193,247,19,254,185,247,60,1,80,253,219,1,116,253,223,255,0,0,1,0,2,0,0,0,253,255,92,0,170,0,80,24,114,8,249,2,54,248,128,8,156,6,19,249,49,2,58,252,78,13,236,255,175,253,62,2,87,253,97,4,177,254,100,254,165,245,152,237,177,255,1,0,2,0,255,255,4,0,250,255,164,3,237,245,88,1,202,245,95,4,223,25,198,254,212,251,82,1,185,7,161,250,198,250,52], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1645765);
/* memory initializer */ allocate([248,30,5,118,0,12,254,119,254,110,2,250,248,48,251,3,0,181,255,0,0,17,0,0,0,254,255,247,255,203,2,199,31,144,1,164,14,108,8,90,7,4,3,168,10,109,254,249,252,62,8,67,6,2,253,224,245,255,2,150,253,119,18,156,2,232,8,123,251,222,4,230,252,242,255,254,255,2,0,5,0,16,0,149,255,130,2,242,248,98,255,113,246,53,1,4,253,9,9,155,255,2,253,209,0,77,253,209,7,12,1,239,254,103,2,35,3,174,23,78,254,7,5,225,253,253,255,0,0,0,0,1,0,1,0,0,0,247,1,170,253,5,248,120,251,50,4,231,4,197,12,125,5,158,4,197,0,26,12,118,255,22,9,12,255,252,252,133,3,31,255,81,1,191,255,232,253,181,254,15,0,2,0,13,0,8,0,253,255,20,0,224,255,204,255,12,252,232,0,222,5,239,255,218,249,27,253,199,255,164,0,234,255,74,0,75,255,80,6,40,1,53,250,107,5,155,254,252,234,190,254,190,250,6,0,253,255,2,0,253,255,1,0,0,0,120,254,213,252,118,253,27,254,222,11,190,10,248,252,9,254,128,249,189,254,253,0,232,254,125,242,223,250,29,2,134,8,7,5,242,252,249,6,73,253,207,255,72,0,252,255,0,0,241,255,3,0,235,255,45,255,102,5,107,255,172,2,162,8,94,10,96,250,71,251,152,0,56,4,250,243,74,253,130,18,217,3,199,250,51,3,250,253,7,7,97,253,129,12,76,10,7,0,1,0,250,255,14,0,225,255,0,0,222,255,200,16,233,255,194,0,184,7,31,252,73,5,197,2,170,254,138,251,116,255,241,254,243,8,59,253,198,6,50,3,13,242,101,4,144,3,178,253,16,3,237,254,254,255,255,255,251,255,255,255,0,0,131,254,194,10,9,6,34,247,24,14,4,9,149,248,178,0,135,1,34,7,129,255,119,250,202,252,56,253,146,6,177,8,199,8,190,1,226,3,56,0,222,2,196,0,7,0,3,0,8,0,0,0,7,0,127,2,65,3,15,243,163,2,249,254,120,253,200,11,67,253,235,0,232,250,186,253,142,244,46,255,37,251,118,1,233,243,35,248,98,1,87,2,67,250,140,0,239,255,255,255,253,255,2,0,0,0,254,255,73,255,143,1,165,253,28,3,112,250,125,10,167,240,160,1,13,247,201,6,114,7,131,6,42,3,34,255,170,12,204,241,76,20,250,249,172,3,132,255,255,7,189,255,252,255,6,0,255,255,13,0,2,0,95,255,161,1,36,16,236,1,212,251,207,252,172,10,6,255,79,250,187,6,56,8,97,4,4,251,123,4,222,3,245,253,3,250,41,1,195,4,61,15,11,246,234,255,0,0,0,0,0,0,0,0,2,0,160,249,172,0,61,3,21,253,51,251,58,248,210,251,110,4,87,6,228,0,105,14,113,2,11,253,0,32,174,255,226,2,213,0,108,7,80,251,91,0,124,3,211,255,15,0,255,255,5,0,252,255,5,0,136,1,5,244,145,248,139,0,149,2,43,0,126,8,129,248,242,254,46,250,199,253,2,0,85,0,189,251,84,26,118,3,85,0,228,251,121,253,205,253,101,244,111,255,255,255,39,0,251,255,250,255,249,255,1,252,176,251,18,249,174,243,222,251,160,13,9,246,219,13,3,255,52,255,21,255,248,249,183,255,184,253,210,254,210,243,246,246,204,254,254,6,148,3,152,0,101,255,245,255,6,0,230,255,255,255,225,255,21,0,151,3,192,248,56,254,230,251,151,2,174,5,21,250,210,245,65,239,17,6,236,13,54,5,5,7,4,6,120,254,67,253,53,252,142,242,25,1,241,254,133,0,1,0,5,0,4,0,32,0,3,0,247,253,6,250,168,250,251,6,253,253,111,252,169,246,93,0,130,10,190,253,192,253,136,249,42,2,137,2,27,250,254,254,163,253,209,4,46,247,128,2,69,3,213,255,1,0,253,255,0,0,5,0,3,0,148,0,103,237,247,6,172,12,235,254,141,251,3,6,32,248,106,7,4,251,248,252,67,249,148,248,205,255,47,2,55,1,201,6,96,252,103,14,193,251,49,5,134,0,2,0,254,255,249,255,9,0,5,0,179,255,164,251,122,19,84,252,119,252,99,243,251,252,7,13,233,255,66,2,184,246,130,1,122,0,229,4,107,1,68,245,0,254,252,237,154,6,80,3,164,251,195,0,5,0,2,0,11,0,1,0,18,0,147,2,254,250,50,2,146,4,93,18,135,3,234,1,76,242,140,13,217,255,142,2,84,251,115,252,244,254,212,3,27,1,149,12,92,1,97,4,127,252,13,252,153,255,245,255,254,255,247,255,16,0,248,255,238,254,252,239,248,246,181,246,105,2,93,6,106,8,210,11,55,249,165,253,221,252,146,254,209,3,11,4,213,248,1,255,237,254,35,251,250,4,95,255,132,238,75,255,252,255,0,0,254,255,1,0,2,0,156,0,39,2,192,252,138,253,156,14,189,247,88,1,229,0,15,5,65,0,34,1,74,250,254,248,225,12,231,251,147,9,66,1,174,245,6,245,34,251,101,2,90,0,255,255,255,255,0,0,0,0,0,0,235,254,86,3,235,4,6,6,79,254,17,14,59,254,67,4,143,255,158,5,226,3,70,245,238,252,99,3,142,5,69,4,69,249,113,251,147,250,218,251,76,254,175,255,2,0,1,0,11,0,1,0,26,0,59,255,35,0,19,255,35,2,193,2,247,255,76,6,126,1,195,0,65,255,6,255,155,255,155,254,197,2,153,0,82,3,29,236,156,255,0,0,0,0,0,0,0,0,0,0,250,230,98,255,241,253,137,0,182,254,68,2,28,254,63,0,29,2,35,251,51,255,138,0,247,0,23,254,109,255,124,255,161,252,0,0,0,0,0,0,0,0,0,0,53,0,218,255,27,1,234,255,30,250,45,254,94,254,117,0,133,0,152,247,208,255,33,252,40,3,233,251,98,9,5,1,167,1,0,0,0,0,0,0,0,0,0,0,242,255,244,1,89,18,82,255,224,253,87,0,133,254,13,255,65,2,170,2,2,1,90,251,64,248,87,2,95,2,133,255,222,254,0,0,0,0,0,0,0,0,0,0,60,0,158,16,194,0,120,3,175,255,117,254,166,1,6,249,148,3,32,1,167,4,110,253,246,1,129,8,47,252,211,254,75,2,0,0,0,0,0,0,0,0,0,0,232,0,204,0,60,254,171,252,86,239,37,255,140,4,92,0,91,0,25,6,182,3,63,253,63,251,34,253,81,6,120,0,188,254,0,0,0,0,0,0,0,0,0,0,142,242,56,254,101,253,219,3,167,255,103,5,64,253,69,255,232,254,185,253,85,1,36,253,137,2,175,247,79,242,81,255,41,255,0,0,0,0,0,0,0,0,0,0,200,0,133,253,41,254,59,251,215,0,28,11,97,6,10,2,48,253,186,6,240,254,217,1,198,0,164,253,224,1,168,255,169,0,0,0,0,0,0,0,0,0,0,0,96,255,244,254,130,0,28,1,156,253,95,0,43,0,42,0,129,2,254,254,28,229,89,255,79,253,123,0,20,1,176,253,205,2,0,0,0,0,0,0,0,0,0,0,57,1,166,255,42,239,146,10,84,249,136,2,228,252,23,3,230,3,44,254,120,2,101,7,43,0,145,7,1,251,234,255,192,255,0,0,0,0,0,0,0,0,0,0,150,255,135,0,225,254,79,1,193,224,51,0,6,255,124,254,16,0,29,1,155,255,173,2,80,252,92,2,144,253,232,252,209,0,0,0,0,0,0,0,0,0,0,0,240,1,51,255,166,1,49,0,18,1,27,255,220,0,73,0,34,253,125,1,118,254,0,224,107,254,243,2,247,255,46,0,116,0,0,0,0,0,0,0,0,0,0,0,228,255,76,1,128,4,127,255,244,0,84,0,111,247,120,2,194,248,128,254,110,0,210,254,242,254,179,1,103,249,227,252,174,2,0,0,0,0,0,0,0,0,0,0,132,249,112,2,104,253,51,10,30,0,125,251,93,254,45,242,200,253,183,6,162,250,92,253,201,255,114,248,95,3,111,5,177,1,0,0,0,0,0,0,0,0,0,0,12,252,34,1,254,8,182,254,161,255,205,246,201,255,5,253,53,248,214,254,88,253,203,2,171,255,79,6,243,3,59,248,252,251,0,0,0,0,0,0,0,0,0,0,21,0,119,236,251,1,198,255,229,0,219,255,143,255,120,2,17,7,194,255,78,1,79,251,131,252,168,254,98,0,182,1,191,255,0,0,0,0,0,0,0,0,0,0,0,0,143,0,131,0,238,255,121,255,206,254,136,1,232,0,9,1,31,2,120,1,206,253,106,1,154,9,17,3,69,14,56,254,0,0,0,0,0,0,0,0,0,0,87,3,87,240,73,251,118,0,170,255,33,255,10,1,154,0,162,248,135,251,241,0,115,254,246,0,244,0,248,252,40,3,124,255,0,0,0,0,0,0,0,0,0,0,2,0,135,253,113,0,162,255,102,255,83,255,94,255,88,255,183,1,108,230,10,3,120,254,196,255,99,0,147,248,171,0,126,255,0,0,0,0,0,0,0,0,0,0,245,255,188,254,199,2,121,252,48,2,138,249,193,5,212,254,24,4,137,0,140,251,165,251,234,250,16,252,232,252,64,243,228,253,0,0,0,0,0,0,0,0,0,0,165,254,78,0,153,255,249,255,253,255,181,1,165,23,43,1,77,254,67,1,152,2,221,1,73,4,158,0,144,2,17,1,200,0,0,0,0,0,0,0,0,0,0,0,155,255,80,0,103,255,144,0,21,255,236,1,113,254,253,255,94,19,187,2,182,253,94,255,153,0,164,252,161,0,153,2,4,0,0,0,0,0,0,0,0,0,0,0,169,255,67,255,208,6,162,254,208,248,69,1,206,246,169,4,106,5,203,249,80,0,31,4,68,255,17,1,39,3,246,7,93,254,0,0,0,0,0,0,0,0,0,0,50,0,71,255,68,0,197,255,247,255,78,0,183,253,135,255,48,225,3,3,116,252,228,254,93,1,158,0,158,251,117,255,67,255,0,0,0,0,0,0,0,0,0,0,54,1,226,254,235,0,81,253,105,252,148,254,71,253,3,255,236,1,44,1,18,255,16,1,6,2,243,253,25,233,66,255,197,255,0,0,0,0,0,0,0,0,0,0,151,0,104,2,188,238,227,0,240,0,4,255,4,2,6,255,68,0,155,1,64,255,169,255,161,253,159,2,1,5,195,254,207,254,0,0,0,0,0,0,0,0,0,0,247,255,49,3,61,254,201,251,86,0,196,19,123,251,121,251,91,254,46,1,100,6,196,254,190,255,250,253,242,3,44,4,96,0,0,0,0,0,0,0,0,0,0,0,192,253,150,254,107,0,188,13,47,1,148,254,110,254,37,3,62,2,225,3,214,253,42,1,99,252,154,1,106,7,13,0,138,0,0,0,0,0,0,0,0,0,0,0,172,254,106,255,16,2,142,0,48,254,10,4,115,254,104,15,71,253,194,3,134,3,113,5,164,8,3,252,246,251,63,252,193,254,0,0,0,0,0,0,0,0,0,0,58,0,38,0,126,1,221,0,44,255,58,3,163,250,49,238,49,5,133,255,216,0,233,255,32,253,95,0,212,254,94,254,252,255,0,0,0,0,0,0,0,0,0,0,198,255,134,30,218,0,141,0,166,255,132,255,199,1,229,255,49,0,201,254,148,254,80,0,120,255,23,251,96,0,76,1,225,254,0,0,0,0,0,0,0,0,0,0,248,255,112,2,127,0,65,7,32,254,155,252,193,253,75,250,19,254,251,254,97,0,32,0,184,254,45,254,173,0,228,245,132,0,0,0,0,0,0,0,0,0,0,0,137,20,243,251,191,0,180,252,247,0,130,0,197,253,220,253,16,254,216,0,95,255,80,1,62,0,222,3,130,0,5,2,191,255,0,0,0,0,0,0,0,0,0,0,167,255,9,0,118,255,149,1,67,253,33,254,21,14,187,2,139,253,154,255,27,0,162,250,221,251,238,255,109,245,84,255,211,253,0,0,0,0,0,0,0,0,0,0,189,255,209,0,59,2,163,255,107,254,84,255,252,254,237,255,86,0,22,0,147,2,138,253,222,0,0,224,106,0,222,255,60,0,0,0,0,0,0,0,0,0,0,0,246,255,198,242,80,1,139,2,159,250,169,2,240,255,211,255,130,254,78,4,232,254,169,0,202,252,10,2,178,1,169,251,213,254,0,0,0,0,0,0,0,0,0,0,194,0,67,254,25,255,236,253,74,254,76,255,177,253,112,249,179,0,33,23,72,255,83,253,45,254,107,3,195,253,26,1,235,0,0,0,0,0,0,0,0,0,0,0,83,1,139,0,23,253,188,255,55,255,211,1,25,253,221,1,233,255,103,251,104,5,155,254,26,251,80,241,198,1,151,4,252,0,0,0,0,0,0,0,0,0,0,0,109,0,4,255,91,31,3,253,136,0,111,0,170,255,175,253,172,255,18,253,135,255,14,3,227,2,216,254,28,1,213,0,84,251,0,0,0,0,0,0,0,0,0,0,216,255,69,0,200,7,196,1,181,255,172,255,171,2,142,6,186,250,202,248,252,11,19,253,126,250,241,254,24,2,96,4,117,0,0,0,0,0,0,0,0,0,0,0,213,15,84,1,108,0,168,255,155,1,222,3,217,0,91,14,243,2,240,2,50,255,205,0,215,254,195,253,188,0,127,0,199,254,0,0,0,0,0,0,0,0,0,0,47,0,202,244,167,242,216,0,194,6,173,255,189,0,177,249,248,3,212,255,10,254,103,8,6,0,223,251,38,2,194,0,14,254,0,0,0,0,0,0,0,0,0,0,123,255,1,0,125,254,15,254,74,2,173,0,155,3,18,240,48,251,73,1,218,247,71,255,80,2,169,2,248,12,110,252,185,254,0,0,0,0,0,0,0,0,0,0,124,255,237,1,77,255,220,0,142,0,7,239,166,1,83,255,101,1,37,5,240,0,243,253,77,6,78,255,208,249,34,253,37,2,0,0,0,0,0,0,0,0,0,0,175,254,111,0,42,251,116,0,46,1,69,1,189,0,98,2,148,243,228,254,207,252,103,5,23,6,222,252,166,1,182,1,204,1,0,0,0,0,0,0,0,0,0,0,160,255,116,1,79,1,181,252,127,15,221,0,124,1,227,0,53,1,191,1,57,255,255,254,116,1,115,254,234,253,224,2,104,255,0,0,0,0,0,0,0,0,0,0,112,255,207,1,202,255,224,254,173,255,115,0,194,253,27,255,229,1,173,245,58,0,216,16,125,251,130,2,121,253,98,4,118,0,0,0,0,0,0,0,0,0,0,0,157,0,6,0,7,252,125,251,175,2,224,254,150,3,44,255,180,254,74,246,59,255,255,251,222,253,3,16,155,0,37,253,179,254,0,0,0,0,0,0,0,0,0,0,213,255,16,254,222,253,227,253,27,1,247,253,209,255,238,255,208,0,216,253,107,7,59,8,76,2,50,3,113,252,176,251,172,255,0,0,0,0,0,0,0,0,0,0,185,255,40,0,186,254,92,0,216,0,150,255,1,255,28,0,120,0,198,255,96,245,123,255,224,254,228,255,123,251,27,6,144,1,0,0,0,0,0,0,0,0,0,0,40,0,252,255,47,2,70,5,30,0,65,15,93,253,188,251,181,253,12,250,61,248,249,251,100,7,89,253,145,253,27,4,223,255,0,0,0,0,0,0,0,0,0,0,158,255,106,0,105,0,1,233,49,254,168,1,214,255,6,254,179,253,120,1,72,3,140,0,128,253,3,3,23,0,71,254,250,255,0,0,0,0,0,0,0,0,0,0,22,0,203,0,132,242,133,253,163,253,132,6,166,1,157,11,138,1,187,249,56,252,29,253,88,1,98,250,52,3,218,250,230,255,0,0,0,0,0,0,0,0,0,0,2,1,224,255,37,4,131,2,104,255,92,0,58,254,231,250,85,6,42,2,88,1,82,0,108,254,102,20,168,254,30,1,177,0,0,0,0,0,0,0,0,0,0,0,63,0,152,254,129,255,46,3,55,14,6,243,134,1,12,0,253,253,19,254,235,5,170,6,41,253,138,1,140,4,101,1,48,255,0,0,0,0,0,0,0,0,0,0,229,255,136,2,170,254,131,255,185,254,194,0,201,241,86,2,29,0,244,0,130,3,19,254,116,1,133,253,55,2,31,0,19,255,0,0,0,0,0,0,0,0,0,0,96,255,238,10,24,249,118,247,237,1,5,2,174,255,44,254,222,254,74,11,52,254,194,1,158,1,247,254,159,251,219,0,165,251,0,0,0,0,0,0,0,0,0,0,14,0,76,0,10,245,82,1,107,250,110,254,253,0,126,255,21,255,225,252,53,1,243,253,239,14,175,0,36,0,113,0,247,0,0,0,0,0,0,0,0,0,0,0,96,1,9,2,213,0,149,255,185,255,6,253,22,3,168,252,4,255,10,255,39,253,137,253,234,4,52,243,254,5,76,254,133,253,0,0,0,0,0,0,0,0,0,0,202,255,118,0,59,254,132,255,224,255,27,2,100,1,87,255,54,255,178,253,209,2,68,254,140,231,237,254,17,255,151,255,204,255,0,0,0,0,0,0,0,0,0,0,48,254,251,1,228,252,249,4,249,8,22,3,140,2,136,1,36,13,99,248,106,8,67,253,27,255,99,0,88,0,215,1,244,253,0,0,0,0,0,0,0,0,0,0,71,0,110,252,43,7,100,255,14,255,60,255,1,2,175,1,31,254,172,255,34,253,149,17,2,254,115,0,205,1,84,254,83,0,0,0,0,0,0,0,0,0,0,0,109,240,39,4,51,253,176,245,61,252,101,253,109,255,24,2,188,255,166,1,85,1,132,248,152,253,228,3,10,2,56,2,150,4,0,0,0,0,0,0,0,0,0,0,8,0,112,0,181,2,136,1,189,1,189,20,3,1,121,0,134,6,87,1,176,0,216,1,197,0,163,1,16,255,102,251,149,255,0,0,0,0,0,0,0,0,0,0,0,224,133,1,245,0,189,255,214,255,79,0,247,1,24,254,202,254,107,0,243,255,81,254,53,255,96,0,254,1,151,0,14,1,0,0,0,0,0,0,0,0,0,0,49,254,233,255,184,255,190,254,74,0,53,6,104,255,58,255,81,0,96,4,131,255,78,254,53,243,94,247,164,254,168,254,91,0,0,0,0,0,0,0,0,0,0,0,2,255,32,255,46,0,102,255,125,255,47,254,199,255,0,32,89,1,112,0,43,253,207,255,183,0,65,255,246,0,7,1,114,1,0,0,0,0,0,0,0,0,0,0,39,0,29,253,53,230,106,246,161,255,56,1,203,255,120,254,63,0,91,255,31,0,7,254,111,0,228,1,233,253,179,0,143,0,0,0,0,0,0,0,0,0,0,0,255,4,117,255,23,249,244,0,59,0,121,255,83,254,195,2,41,3,253,238,158,254,172,1,212,254,108,0,225,252,115,250,87,2,0,0,0,0,0,0,0,0,0,0,4,0,251,255,7,0,75,0,49,0,0,32,20,1,200,0,191,0,89,255,242,255,82,0,222,0,235,254,29,254,40,255,71,254,0,0,0,0,0,0,0,0,0,0,171,0,89,254,174,0,145,1,251,253,135,254,22,255,124,253,195,252,162,254,48,252,110,255,96,252,40,1,187,11,217,13,226,255,0,0,0,0,0,0,0,0,0,0,161,0,159,229,114,4,169,252,124,255,14,255,47,2,31,255,166,254,88,255,10,0,31,254,250,255,72,251,252,0,189,254,65,255,0,0,0,0,0,0,0,0,0,0,250,254,62,2,177,1,111,255,110,2,73,1,182,245,73,254,102,251,95,1,79,254,182,252,29,16,40,1,49,1,103,1,234,255,0,0,0,0,0,0,0,0,0,0,222,255,200,255,5,252,9,255,93,255,49,1,62,2,205,255,77,255,24,0,183,251,248,0,90,255,238,255,47,1,252,0,213,253,0,0,0,0,0,0,0,0,0,0,112,254,2,255,0,255,223,10,216,254,144,248,40,2,4,5,176,254,189,246,68,13,188,251,102,0,176,0,140,0,128,2,153,254,0,0,0,0,0,0,0,0,0,0,117,1,217,1,137,247,250,252,124,254,149,1,134,250,145,250,217,250,101,255,80,4,235,253,126,1,25,6,114,244,150,1,19,3,0,0,0,0,0,0,0,0,0,0,40,241,198,255,50,8,75,255,198,253,129,1,227,239,247,2,208,249,9,0,234,254,201,0,240,253,241,253,77,254,180,1,169,2,0,0,0,0,0,0,0,0,0,0,30,0,176,255,196,255,65,240,186,255,217,242,60,1,163,252,67,0,87,255,112,255,62,6,198,3,32,0,17,251,78,254,30,253,0,0,0,0,0,0,0,0,0,0,181,0,12,0,115,0,91,0,253,0,6,2,5,2,216,0,62,3,80,1,200,253,203,243,228,252,177,252,91,6,58,0,98,255,0,0,0,0,0,0,0,0,0,0,48,0,173,252,226,254,137,1,134,1,195,2,83,2,171,1,21,255,140,255,46,3,58,255,1,24,202,249,135,2,15,0,253,254,0,0,0,0,0,0,0,0,0,0,147,253,152,0,78,2,240,255,215,0,135,253,240,252,116,255,63,4,211,2,161,239,141,10,183,3,52,252,17,1,214,253,131,1,0,0,0,0,0,0,0,0,0,0,132,255,133,244,218,255,127,1,234,0,175,2,199,244,46,254,61,0,40,254,86,3,116,254,49,1,23,255,82,0,139,245,50,255,0,0,0,0,0,0,0,0,0,0,136,255,10,255,154,253,118,254,0,32,75,0,62,254,177,0,5,255,45,0,114,255,65,0,32,251,242,255,133,1,119,1,114,0,0,0,0,0,0,0,0,0,0,0,54,11,158,0,39,254,90,255,160,3,150,253,139,248,224,0,93,252,106,7,240,255,171,1,191,1,236,251,85,0,179,254,197,0,0,0,0,0,0,0,0,0,0,0,78,0,114,0,89,255,73,0,210,251,176,255,184,13,68,244,239,249,1,3,213,0,83,3,135,254,210,3,73,4,71,0,66,0,0,0,0,0,0,0,0,0,0,0,127,255,248,0,199,1,136,254,88,1,128,0,196,255,34,2,191,254,38,225,49,253,201,255,83,252,218,4,207,0,215,0,67,1,0,0,0,0,0,0,0,0,0,0,232,255,31,255,136,0,142,0,29,253,139,255,2,0,242,0,104,255,236,255,17,249,28,254,220,255,104,254,49,245,41,254,251,0,0,0,0,0,0,0,0,0,0,0,22,0,111,0,76,255,7,227,109,1,37,1,199,254,7,4,65,255,154,0,46,255,17,255,121,0,179,254,32,250,209,0,146,0,0,0,0,0,0,0,0,0,0,0,130,3,125,253,8,12,16,2,165,255,50,253,0,254,19,1,20,242,140,1,160,0,174,252,90,1,173,253,22,6,172,2,202,254,0,0,0,0,0,0,0,0,0,0,234,0,93,254,44,253,79,254,36,1,21,252,170,2,139,255,218,250,110,252,239,235,128,0,53,0,35,1,152,1,245,4,228,254,0,0,0,0,0,0,0,0,0,0,4,255,190,0,161,244,130,0,255,0,84,255,21,239,26,0,245,254,24,1,123,255,155,253,217,251,145,251,247,2,246,250,216,0,0,0,0,0,0,0,0,0,0,0,133,0,79,255,229,15,201,254,59,255,188,12,85,1,201,0,139,255,253,253,105,0,110,253,207,3,81,0,179,254,179,254,6,1,0,0,0,0,0,0,0,0,0,0,17,1,169,255,65,1,190,0,105,5,18,1,182,0,7,246,106,255,164,0,194,252,89,0,53,254,97,235,144,253,176,254,143,1,0,0,0,0,0,0,0,0,0,0,84,255,24,255,11,0,45,0,121,0,2,255,55,254,196,0,97,242,186,252,0,2,202,254,241,244,171,255,98,0,111,255,181,254,0,0,0,0,0,0,0,0,0,0,201,255,107,255,20,8,195,255,15,12,113,255,38,6,155,250,37,11,107,7,59,254,188,253,119,255,187,4,123,250,171,0,125,0,0,0,0,0,0,0,0,0,0,0,28,255,30,0,68,252,193,21,209,0,167,255,25,0,61,2,123,249,251,1,182,0,124,255,185,2,124,255,108,244,131,253,139,0,0,0,0,0,0,0,0,0,0,0,250,243,50,243,253,252,160,3,218,255,49,254,52,3,117,4,46,251,108,2,140,2,82,249,130,254,174,249,103,254,179,0,227,1,0,0,0,0,0,0,0,0,0,0,154,255,160,16,236,255,94,255,229,7,218,2,159,5,216,10,203,1,242,1,104,255,226,1,35,0,241,254,42,3,191,250,7,255,0,0,0,0,0,0,0,0,0,0,131,0,5,0,231,254,175,1,62,246,234,251,226,1,74,3,41,1,201,254,20,251,148,0,118,252,135,239,125,250,154,255,151,254,0,0,0,0,0,0,0,0,0,0,116,0,245,243,235,0,85,251,237,255,122,253,42,0,231,1,53,1,118,6,27,4,149,249,177,2,201,252,231,8,208,5,59,2,0,0,0,0,0,0,0,0,0,0,42,0,161,255,253,255,36,0,86,255,142,255,168,31,217,0,140,0,39,255,87,2,250,252,192,255,93,253,45,255,166,0,204,0,0,0,0,0,0,0,0,0,0,0,99,0,82,2,208,255,224,0,52,0,37,250,15,1,176,8,37,255,112,12,91,255,60,3,191,250,239,252,181,0,133,0,124,0,0,0,0,0,0,0,0,0,0,0,21,255,226,254,254,0,85,255,140,236,59,254,104,250,12,0,222,2,121,254,128,253,83,1,25,2,57,1,68,253,248,3,148,0,0,0,0,0,0,0,0,0,0,0,207,255,237,255,35,3,167,3,8,2,166,255,129,2,29,4,58,254,34,9,73,232,34,254,104,2,209,253,173,254,189,1,72,250,0,0,0,0,0,0,0,0,0,0,81,255,111,0,124,255,65,0,248,254,220,2,221,0,231,0,76,248,207,254,69,1,165,252,71,2,248,4,71,254,91,10,229,0,0,0,0,0,0,0,0,0,0,0,226,254,218,237,250,254,81,2,101,2,168,3,54,1,153,253,83,0,223,0,208,252,118,7,249,7,25,1,66,255,78,254,114,0,0,0,0,0,0,0,0,0,0,0,133,255,172,2,48,255,12,2,162,253,57,251,8,1,41,252,147,255,223,251,184,2,195,0,247,253,177,3,177,226,193,0,136,255,0,0,0,0,0,0,0,0,0,0,98,0,154,254,139,247,244,0,21,1,137,1,3,3,32,13,254,254,62,251,134,255,27,251,7,247,38,3,58,255,28,2,7,0,0,0,0,0,0,0,0,0,0,0,78,0,231,254,144,254,249,10,159,0,51,10,65,3,136,255,109,240,165,3,104,1,207,255,253,253,150,255,152,254,138,2,131,255,0,0,0,0,0,0,0,0,0,0,203,0,89,5,237,2,10,254,9,247,186,254,192,1,203,254,118,2,172,255,89,1,248,253,252,255,145,253,42,4,181,240,117,1,0,0,0,0,0,0,0,0,0,0,5,238,230,252,143,253,157,254,47,4,167,253,215,253,81,2,216,254,114,2,184,254,109,2,85,0,68,5,92,0,224,254,204,0,0,0,0,0,0,0,0,0,0,0,247,255,90,2,94,255,19,253,152,255,208,1,140,254,161,250,143,248,152,8,61,0,20,243,127,252,122,2,12,4,192,247,74,255,0,0,0,0,0,0,0,0,0,0,180,255,37,9,93,253,184,255,227,255,192,2,232,253,120,6,227,253,32,253,116,250,253,249,154,9,28,255,162,2,22,251,253,255,0,0,0,0,0,0,0,0,0,0,123,255,87,4,63,0,71,1,214,1,202,4,29,2,236,254,30,244,198,249,136,243,101,1,151,253,146,2,197,254,46,252,119,2,0,0,0,0,0,0,0,0,0,0,111,0,68,255,107,2,236,0,104,0,54,0,33,2,168,1,24,23,180,254,199,2,31,251,235,253,35,1,248,249,40,255,113,0,0,0,0,0,0,0,0,0,0,0,57,255,11,1,152,0,211,254,84,255,14,5,7,9,30,254,109,246,174,255,41,7,214,0,130,0,97,251,92,247,147,1,143,253,0,0,0,0,0,0,0,0,0,0,150,255,150,2,208,255,125,255,68,1,33,9,189,1,206,1,163,254,67,255,157,2,81,19,251,248,16,0,12,1,166,253,2,0,0,0,0,0,0,0,0,0,0,0,55,0,154,0,124,3,221,255,111,255,101,1,50,2,42,0,247,255,228,254,177,0,84,0,166,1,75,255,154,254,194,29,29,0,0,0,0,0,0,0,0,0,0,0,159,254,68,0,215,255,0,240,177,0,236,255,245,254,14,3,186,3,82,254,37,6,72,253,249,6,229,241,89,0,13,255,171,2,0,0,0,0,0,0,0,0,0,0,36,255,191,7,133,252,102,2,226,0,54,255,67,0,249,2,112,7,179,0,226,0,160,1,111,253,175,242,2,4,18,11,74,254,0,0,0,0,0,0,0,0,0,0,217,253,27,255,208,254,50,254,27,247,93,254,195,1,134,255,148,255,2,1,16,3,81,4,126,1,137,0,63,22,15,255,21,254,0,0,0,0,0,0,0,0,0,0,34,0,240,254,105,249,233,6,180,254,109,1,33,0,222,245,145,14,69,1,85,0,217,254,222,254,104,255,190,8,157,253,215,255,0,0,0,0,0,0,0,0,0,0,102,0,166,0,241,0,74,4,149,255,7,3,98,254,160,16,235,254,167,3,56,255,239,1,255,0,120,4,212,1,72,255,197,255,0,0,0,0,0,0,0,0,0,0,94,0,230,254,199,255,12,0,122,254,245,0,80,7,148,253,65,4,170,14,176,1,179,3,3,254,228,254,4,241,26,0,226,1,0,0,0,0,0,0,0,0,0,0,9,0,203,3,139,254,87,4,32,254,38,9,74,255,16,2,34,3,172,4,7,252,145,252,243,1,240,10,194,252,26,255,252,255,0,0,0,0,0,0,0,0,0,0,130,254,209,252,123,249,123,246,175,253,193,0,80,253,120,2,223,1,67,11,53,2,28,2,5,0,62,6,82,6,128,253,10,255,0,0,0,0,0,0,0,0,0,0,91,254,153,255,202,5,46,244,191,255,155,255,4,0,81,15,176,2,83,252,22,255,49,0,202,0,113,7,167,3,125,251,252,255,0,0,0,0,0,0,0,0,0,0,210,0,143,253,138,255,113,243,88,1,210,3,246,255,5,3,130,255,220,252,2,250,182,0,134,251,122,253,110,255,219,7,207,1,0,0,0,0,0,0,0,0,0,0,75,0,87,0,225,255,95,2,124,255,75,23,250,254,238,1,134,0,252,255,141,0,19,0,225,0,229,0,239,0,93,0,236,255,67,255,2,0,0,0,253,255,255,255,255,255,0,0,214,0,50,255,109,3,83,0,180,253,83,0,132,0,78,0,5,0,171,255,66,0,232,255,47,0,245,255,25,0,26,0,253,255,46,0,2,0,251,255,0,0,1,0,255,255,0,0,143,255,39,1,175,255,74,0,223,0,206,255,163,255,217,233,228,255,115,0,0,1,28,255,225,255,229,253,44,1,234,254,197,255,170,1,146,255,255,255,1,0,1,0,0,0,0,0,161,255,140,255,10,1,176,0,249,2,253,255,90,0,165,255,98,0,47,255,98,254,229,255,200,255,26,0,180,255,6,0,224,255,26,18,1,0,0,0,252,255,0,0,0,0,0,0,177,0,147,0,20,255,163,255,11,225,11,0,145,255,182,255,36,0,176,0,96,1,88,0,112,0,16,0,144,0,146,255,91,0,73,1,255,255,2,0,0,0,1,0,0,0,1,0,119,0,48,1,162,255,90,254,113,0,129,0,186,255,155,0,247,0,140,255,117,255,71,1,157,254,77,0,143,0,14,235,27,0,135,254,255,255,7,0,2,0,1,0,0,0,0,0,179,0,127,0,220,5,188,254,241,255,161,2,184,0,154,250,167,0,41,7,14,244,200,0,77,251,203,1,143,248,252,3,253,254,136,255,10,0,252,255,0,0,1,0,0,0,0,0,227,3,144,255,37,0,96,255,235,255,85,240,172,0,228,0,46,255,80,0,125,255,1,0,20,0,128,255,4,255,224,254,124,255,81,1,255,255,0,0,255,255,0,0,1,0,255,255,196,255,61,0,197,0,71,255,216,255,121,244,176,253,199,255,210,0,80,243,30,255,212,255,135,1,89,255,249,255,219,0,241,255,172,0,0,0,255,255,1,0,0,0,0,0,0,0,106,0,186,255,221,254,192,0,45,0,162,0,37,0,143,0,91,0,21,0,136,228,12,0,83,255,226,255,1,0,3,1,226,254,131,1,220,255,0,0,0,0,0,0,0,0,0,0,199,249,46,255,83,0,47,0,194,0,61,0,85,0,74,255,233,255,40,0,182,255,22,0,12,0,216,0,59,0,91,255,93,255,97,255,248,255,0,0,0,0,2,0,0,0,0,0,253,255,182,0,176,255,20,8,190,2,115,0,92,255,171,255,21,0,132,255,65,255,143,255,7,1,138,0,139,16,37,0,204,0,76,254,0,0,24,0,1,0,255,255,0,0,0,0,147,0,83,0,79,255,88,255,159,253,247,255,240,255,210,255,127,0,120,0,231,255,107,13,51,0,31,0,49,0,110,1,31,0,127,255,1,0,224,255,0,0,255,255,0,0,254,255,39,1,158,0,116,0,11,0,232,254,215,1,169,0,29,0,227,245,82,1,32,0,43,1,172,0,69,255,224,255,181,1,218,255,103,1,255,255,255,255,1,0,0,0,0,0,0,0,243,0,157,1,227,255,90,237,187,0,12,0,139,255,168,0,142,255,48,255,201,255,5,0,0,0,225,255,180,1,33,2,211,255,16,1,0,0,252,255,0,0,0,0,1,0,0,0,127,0,38,0,220,25,223,255,153,255,34,0,84,0,221,255,30,0,125,255,248,255,177,255,130,255,158,255,17,0,181,255,225,255,80,255,14,0,255,255,0,0,0,0,255,255,255,255,17,1,37,255,176,0,173,255,187,0,220,255,1,0,79,10,158,0,228,14,127,0,23,255,175,0,54,1,148,0,131,1,242,255,52,1,0,0,253,255,0,0,0,0,0,0,0,0,249,12,65,254,153,0,128,255,254,0,237,254,79,0,75,255,17,0,146,0,61,0,46,0,208,255,253,0,51,0,239,255,1,0,1,0,0,0,1,0,255,255,254,255,0,0,243,255,23,3,126,255,40,0,78,0,192,255,77,255,42,0,57,254,166,1,112,0,237,255,109,238,143,255,171,254,52,0,69,0,67,0,254,0,250,255,255,255,4,0,0,0,0,0,1,0,158,255,48,252,68,0,27,6,228,0,250,3,202,1,4,252,155,1,249,0,141,253,17,9,226,2,52,254,67,250,106,1,116,3,251,254,0,0,255,255,1,0,1,0,0,0,0,0,167,253,122,1,185,255,61,0,96,255,32,3,126,254,251,252,47,1,203,255,248,0,234,255,59,0,31,241,195,255,102,0,211,255,139,1,0,0,0,0,28,0,0,0,244,255,0,0,205,2,88,254,243,1,40,1,241,255,11,0,172,10,153,255,137,255,140,255,107,0,206,255,206,1,73,0,174,255,75,0,41,0,131,0,0,0,3,0,1,0,255,255,0,0,0,0,122,255,109,0,48,0,201,248,51,255,250,255,20,0,53,255,136,0,197,0,113,0,179,255,132,255,206,255,184,0,225,0,81,255,217,254,255,255,255,255,250,255,255,255,255,255,0,0,197,255,31,248,63,255,19,255,226,0,118,2,158,7,254,255,179,0,174,241,222,255,140,0,88,0,157,0,51,0,81,0,249,254,87,255,1,0,0,0,0,0,0,0,0,0,0,0,229,0,242,255,202,249,133,255,162,0,63,0,32,255,180,254,119,0,115,11,21,0,208,255,150,1,15,0,64,1,205,255,64,0,28,255,247,255,255,255,0,0,255,255,0,0,0,0,59,254,84,0,192,254,114,253,252,255,165,255,195,255,46,2,195,255,23,255,31,0,32,255,151,255,63,0,86,0,187,14,162,0,1,250,3,0,253,255,1,0,1,0,0,0,1,0,56,248,233,254,197,255,24,244,96,249,102,0,88,255,194,0,172,0,114,255,55,0,134,0,116,0,110,255,227,255,225,254,102,0,9,1,253,255,1,0,0,0,1,0,0,0,0,0,160,255,46,0,240,255,170,9,198,255,56,253,231,255,218,254,187,0,22,0,217,255,154,255,62,0,106,10,19,255,255,255,32,0,215,255,0,0,0,0,0,0,0,0,0,0,0,0,230,254,231,255,58,255,162,252,129,255,133,254,46,255,236,255,45,0,177,255,11,245,148,254,63,2,106,0,215,0,102,254,180,255,255,1,15,0,212,255,255,255,1,0,0,0,0,0,73,1,224,0,130,0,43,0,255,255,1,255,205,255,215,254,177,17,52,0,186,0,245,2,188,255,167,255,46,0,250,0,46,0,177,255,5,0,1,0,0,0,1,0,0,0,237,255,79,0,74,0,65,0,0,1,4,1,236,1,150,255,39,255,155,254,20,0,166,0,233,0,132,0,165,0,18,0,255,255,93,17,234,255,5,0,3,0,249,255,0,0,0,0,250,255,102,252,108,8,13,1,105,5,235,0,50,255,162,255,130,0,112,0,145,0,130,255,166,0,1,0,45,0,83,0,36,0,103,255,1,255,0,0,255,255,0,0,0,0,1,0,0,0,241,0,19,255,139,255,2,254,85,0,7,0,190,238,30,0,94,0,164,255,99,0,185,255,140,0,247,254,149,0,69,0,30,1,104,0,0,0,254,255,1,0,0,0,0,0,0,0,91,255,22,0,11,255,29,0,50,0,145,0,203,255,105,6,216,255,128,255,144,255,66,255,47,0,53,0,9,255,206,255,88,0,39,0,1,0,255,255,0,0,0,0,0,0,0,0,224,254,130,0,88,0,124,255,215,15,249,255,55,0,151,255,21,1,81,0,69,0,190,255,203,255,52,0,200,255,90,0,160,0,130,1,1,0,252,255,0,0,254,255,0,0,0,0,107,0,124,0,217,255,40,0,25,0,250,255,8,255,175,255,70,0,243,255,46,0,5,0,20,0,24,0,251,255,254,255,215,255,222,255,1,0,1,0,248,255,0,0,252,255,0,0,195,255,1,0,201,1,198,1,0,3,89,0,128,2,61,0,66,0,152,254,89,245,101,255,142,254,212,255,220,254,58,2,34,0,119,243,251,255,255,255,1,0,0,0,255,255,0,0,22,0,174,255,236,255,131,255,165,255,98,0,163,30,25,0,254,255,225,255,2,0,204,255,183,255,231,255,31,0,221,255,250,255,142,255,1,0,255,255,2,0,0,0,0,0,0,0,217,0,174,235,86,0,180,255,180,255,109,0,133,1,161,255,3,255,124,0,130,0,58,0,190,0,212,255,189,255,114,255,54,0,6,0,255,255,1,0,1,0,1,0,0,0,0,0,73,255,35,2,56,255,92,1,116,1,181,1,169,1,35,2,55,254,132,1,87,0,38,0,246,253,46,255,212,253,41,0,93,244,239,255,7,0,252,255,6,0,0,0,0,0,0,0,189,0,196,0,240,0,181,255,46,0,206,255,101,0,96,255,240,255,33,255,92,0,71,0,47,226,78,0,90,0,69,0,190,0,181,255,2,0,1,0,254,255,255,255,0,0,1,0,205,0,79,254,245,254,81,255,252,11,46,255,254,253,74,1,229,243,239,254,155,0,132,0,206,254,105,1,60,1,203,255,91,254,131,255,253,255,0,0,245,255,0,0,0,0,0,0,179,0,218,255,151,0,220,255,215,0,154,255,111,255,139,0,50,0,200,0,127,1,37,0,30,12,229,255,9,0,99,255,188,255,111,1,1,0,1,0,0,0,0,0,1,0,0,0,206,255,177,0,232,255,24,0,119,0,4,0,76,0,99,0,145,255,57,227,26,0,51,0,245,255,110,255,131,255,208,255,54,0,50,0,1,0,0,0,0,0,0,0,255,255,0,0,185,255,240,255,72,255,195,255,220,255,105,255,79,0,128,255,154,255,135,0,28,255,190,0,177,255,246,255,80,255,143,255,240,3,168,252,243,255,252,255,8,0,28,0,0,0,1,0,211,236,163,255,89,255,115,255,51,0,53,255,71,0,57,255,207,255,106,0,114,255,162,255,126,0,31,255,158,0,36,0,13,1,159,0,0,0,1,0,1,0,0,0,0,0,251,255,195,255,177,255,236,255,50,1,67,0,147,253,238,6,90,1,70,254,125,0,49,1,86,255,55,0,23,246,153,255,118,0,87,0,249,1,16,0,249,255,254,255,0,0,20,0,0,0,35,0,102,255,98,255,224,0,220,255,168,254,79,0,136,16,234,0,37,255,185,255,204,0,28,254,125,255,129,4,23,0,111,0,243,1,5,0,0,0,239,255,0,0,0,0,1,0,111,4,115,242,23,254,12,10,62,254,80,254,154,254,222,255,178,255,246,255,249,252,17,0,125,255,102,255,218,0,82,0,200,254,23,1,1,0,0,0,1,0,0,0,0,0,0,0,96,0,230,0,18,0,47,0,251,255,154,255,134,2,134,255,35,0,175,255,183,0,171,0,57,250,201,0,84,0,232,255,143,0,46,1,1,0,5,0,0,0,0,0,0,0,0,0,222,255,208,255,89,0,109,30,171,255,229,255,200,255,46,0,39,0,30,0,98,0,216,255,138,0,109,255,104,0,221,255,215,255,105,255,1,0,9,0,1,0,0,0,0,0,0,0,116,255,78,248,86,255,17,1,226,0,33,0,188,254,218,255,11,0,188,0,91,2,188,0,73,255,98,0,198,255,189,255,193,255,7,0,0,0,0,0,0,0,0,0,1,0,0,0,128,1,131,3,237,1,253,2,218,251,134,2,19,1,117,245,93,0,28,3,120,0,231,255,177,0,171,255,209,2,67,255,217,254,76,254,0,0,255,255,0,0,0,0,255,255,0,0,154,254,117,0,125,246,69,1,191,243,98,255,23,0,97,0,6,0,204,0,32,1,86,254,156,0,22,0,155,255,171,0,200,255,235,0,0,0,255,255,0,0,255,255,0,0,0,0,144,2,38,15,226,254,129,254,75,0,206,255,114,0,135,254,151,255,106,0,154,0,226,255,52,255,151,255,171,0,200,255,230,0,181,253,0,0,1,0,0,0,8,0,1,0,255,255,198,255,177,0,249,255,45,0,97,255,149,1,45,0,84,0,50,255,77,0,21,1,253,254,121,0,135,14,140,0,79,0,54,255,75,3,248,255,0,0,255,255,1,0,254,255,0,0,8,255,48,2,91,10,207,255,143,253,109,255,144,246,119,0,186,255,87,0,137,0,18,0,111,254,109,255,170,253,106,255,239,0,20,252,7,0,3,0,13,0,1,0,1,0,1,0,20,1,86,1,97,0,88,2,230,0,95,0,213,0,159,0,253,254,231,255,80,255,32,13,229,254,187,254,219,255,190,245,105,255,178,0,255,255,238,255,0,0,0,0,0,0,0,0,23,255,237,0,178,255,34,1,228,254,141,0,236,255,146,0,58,0,235,255,73,0,221,255,155,255,233,255,28,240,140,255,49,0,60,255,251,255,254,255,0,0,1,0,255,255,0,0,220,254,61,255,51,0,54,253,172,0,44,0,137,255,134,0,168,0,107,0,182,255,181,246,52,1,173,0,4,255,114,242,121,255,129,2,246,255,0,0,0,0,1,0,0,0,0,0,146,0,12,8,172,255,92,255,9,255,26,0,68,249,216,0,226,0,61,246,56,1,190,255,82,3,41,0,255,255,20,0,197,250,155,1,0,0,0,0,255,255,244,255,0,0,0,0,153,3,17,0,74,242,137,255,69,1,34,0,159,255,51,255,3,0,68,255,252,0,91,0,0,0,121,255,180,255,208,0,199,0,54,255,255,255,1,0,1,0,2,0,0,0,255,255,168,255,51,254,63,1,61,252,10,1,4,6,131,2,160,242,76,0,222,251,245,1,86,1,41,1,12,1,98,255,153,255,26,0,226,255,0,0,255,255,255,255,0,0,0,0,0,0,211,0,245,0,183,0,43,6,106,0,26,0,134,242,234,255,227,251,246,254,32,253,113,0,219,1,15,255,117,0,171,255,20,254,116,1,0,0,1,0,1,0,0,0,0,0,0,0,95,254,31,255,172,255,16,0,150,255,222,255,10,255,92,255,112,0,48,0,209,255,36,0,191,255,188,255,84,255,137,249,220,255,140,0,253,255,254,255,254,255,2,0,0,0,0,0,178,0,7,0,75,255,79,255,120,0,192,255,127,255,80,0,86,229,218,255,231,255,147,0,148,0,243,255,231,255,110,0,21,0,21,0,255,255,0,0,0,0,0,0,0,0,0,0,247,12,120,2,34,253,69,255,40,0,7,255,101,255,255,255,83,255,95,0,28,0,254,255,20,0,212,255,35,0,120,0,209,255,35,255,251,255,2,0,249,255,1,0,0,0,0,0,63,0,12,1,252,254,93,254,187,0,181,255,28,255,40,1,42,254,177,0,253,253,62,1,124,0,52,1,92,0,115,1,230,11,106,1,255,255,255,255,246,255,1,0,0,0,0,0,156,254,240,255,57,255,117,0,181,255,46,0,148,255,242,255,132,255,83,255,50,19,181,255,38,254,105,0,87,0,190,0,73,255,48,255,0,0,0,0,1,0,1,0,0,0,255,255,162,0,89,0,49,0,198,254,28,245,9,1,249,254,253,255,172,243,60,1,112,0,128,0,179,254,118,255,142,255,115,255,225,254,22,255,255,255,0,0,0,0,0,0,0,0,1,0,221,2,126,0,88,254,123,254,130,2,176,1,134,0,5,255,151,1,205,255,105,255,21,254,204,254,91,0,50], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1656005);
/* memory initializer */ allocate([0,252,14,87,0,100,0,251,255,250,255,0,0,1,0,0,0,0,0,48,1,191,6,83,0,248,255,216,0,175,255,67,255,152,0,189,255,15,0,54,1,163,255,6,0,219,255,54,0,146,255,241,255,78,0,0,0,0,0,1,0,12,0,0,0,255,255,129,0,58,255,1,0,208,255,190,255,109,255,30,0,8,1,172,255,102,0,42,0,126,0,1,0,205,230,225,0,205,255,8,0,123,0,0,0,255,255,0,0,255,255,0,0,0,0,138,254,66,0,0,255,176,255,141,251,47,1,210,7,57,255,158,255,158,255,217,255,180,255,180,0,15,0,56,254,148,0,73,255,118,0,254,255,1,0,0,0,0,0,0,0,0,0,151,0,13,0,142,255,65,0,12,24,76,0,174,255,226,255,230,255,163,0,81,0,167,0,173,255,155,255,55,0,216,255,161,0,231,252,248,255,0,0,0,0,255,255,255,255,0,0,154,255,223,255,55,0,125,255,178,1,108,0,70,0,68,0,62,0,121,7,147,255,235,0,110,0,124,0,231,255,198,255,180,255,18,0,255,255,255,255,0,0,0,0,0,0,0,0,151,255,102,227,247,255,82,0,53,0,213,255,251,255,18,0,90,0,91,0,20,0,222,255,26,0,163,255,206,255,210,255,179,255,105,0,0,0,6,0,244,255,250,255,1,0,0,0,202,250,212,3,93,255,161,254,254,253,25,2,62,0,212,254,80,0,194,254,14,0,14,242,204,255,140,255,232,254,28,2,250,0,249,252,249,255,0,0,0,0,0,0,0,0,0,0,251,1,61,1,95,254,20,255,122,246,184,255,166,254,203,9,46,1,71,255,30,0,3,6,205,0,87,0,144,255,30,254,216,254,132,0,255,255,0,0,255,255,1,0,0,0,0,0,192,255,48,255,97,255,1,0,80,1,194,255,242,255,13,0,81,0,101,0,126,1,32,0,116,0,251,255,215,255,25,0,81,255,107,225,1,0,0,0,1,0,0,0,0,0,0,0,127,29,249,255,86,0,91,255,199,255,239,255,183,0,49,255,69,0,54,0,157,255,231,255,167,0,198,255,107,0,175,255,165,0,172,0,2,0,254,255,0,0,1,0,0,0,247,255,26,0,28,0,86,0,73,255,192,254,224,255,116,0,203,255,207,255,241,255,133,0,229,254,104,255,64,2,230,25,185,0,44,0,25,0,20,0,1,0,244,255,1,0,255,255,0,0,111,255,205,255,142,255,227,255,28,255,78,0,103,254,235,0,147,0,45,0,64,255,177,0,165,255,68,0,244,245,204,255,81,0,181,0,251,255,13,0,255,255,255,255,239,255,0,0,191,255,233,255,228,255,9,0,242,0,14,0,221,255,88,0,77,0,236,255,37,0,71,228,198,255,51,0,137,0,126,0,166,255,136,0,0,0,4,0,255,255,0,0,0,0,0,0,246,254,174,255,51,255,48,3,203,254,195,12,29,4,113,1,40,255,210,254,18,0,168,0,139,1,17,1,87,1,243,0,158,255,203,255,1,0,0,0,0,0,1,0,0,0,0,0,191,255,180,255,58,7,33,252,58,254,233,253,111,11,111,255,101,0,23,0,20,0,234,0,182,255,77,0,114,0,4,0,150,255,15,2,245,255,4,0,0,0,1,0,255,255,0,0,61,2,210,255,207,0,80,10,68,252,47,0,26,0,246,255,61,1,39,255,251,255,157,252,253,255,213,0,52,0,53,0,84,254,81,255,0,0,0,0,255,255,255,255,0,0,255,255,33,255,201,255,135,0,184,0,57,1,0,0,52,11,245,0,141,243,47,253,221,254,9,0,247,254,136,255,151,255,220,255,198,1,55,0,255,255,49,0,0,0,1,0,255,255,0,0,221,254,41,0,84,0,45,2,55,255,4,247,173,1,27,1,21,0,254,255,132,0,30,1,132,255,149,0,242,255,146,0,64,1,214,254,0,0,255,255,1,0,254,255,0,0,0,0,170,255,91,242,131,0,3,242,185,0,26,0,59,255,191,255,160,255,147,0,203,255,106,255,221,255,221,255,179,0,68,0,99,255,0,0,0,0,2,0,0,0,1,0,2,0,255,255,234,255,38,255,13,0,89,250,112,254,32,1,241,250,0,0,137,255,69,0,200,255,117,255,157,0,230,255,134,255,195,255,218,255,148,255,255,255,1,0,0,0,0,0,0,0,0,0,27,255,7,13,103,0,148,255,10,0,192,11,56,253,50,0,27,0,152,0,205,254,150,255,148,0,179,255,78,255,210,255,7,0,142,255,0,0,247,255,0,0,0,0,1,0,0,0,164,3,69,254,55,1,181,255,62,0,176,255,77,255,203,1,24,255,96,255,2,0,169,0,134,0,252,254,41,0,107,255,23,0,92,0,254,255,0,0,11,0,1,0,0,0,0,0,16,0,166,255,194,253,85,255,163,0,5,1,213,254,178,11,74,0,22,241,116,254,85,255,13,0,227,255,211,255,88,255,225,254,122,254,1,0,0,0,0,0,252,255,0,0,255,255,89,0,66,253,175,8,101,0,7,255,167,11,36,0,179,254,130,254,154,1,250,254,185,0,110,255,98,0,248,255,195,254,233,254,145,252,0,0,0,0,0,0,0,0,4,0,0,0,158,255,187,254,75,0,27,255,243,255,112,0,145,233,222,255,167,255,7,1,101,255,80,0,140,0,206,255,33,0,143,0,196,255,179,255,1,0,254,255,0,0,255,255,1,0,0,0,52,0,192,253,225,253,138,251,77,252,72,255,193,1,185,255,181,255,100,255,172,242,206,255,25,254,51,1,151,2,24,252,97,254,212,246,249,255,255,255,255,255,0,0,0,0,0,0,64,0,3,0,221,255,11,0,14,0,58,255,254,255,150,224,140,0,245,255,163,255,29,0,191,255,74,1,34,0,110,0,237,255,119,255,2,0,0,0,0,0,0,0,0,0,0,0,212,4,47,1,121,10,234,0,39,255,106,254,117,254,132,254,247,0,93,1,155,255,223,255,114,1,217,255,139,0,59,0,18,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,166,0,235,255,240,234,139,255,216,254,114,0,230,0,1,255,131,0,203,255,13,0,211,255,200,0,7,0,200,255,87,0,46,0,223,0,197,255,0,0,255,255,0,0,0,0,255,255,214,0,1,254,175,0,204,0,133,255,209,255,72,254,6,0,23,0,92,0,157,254,80,0,235,236,18,255,219,255,78,0,38,255,175,0,0,0,2,0,0,0,0,0,0,0,0,0,110,255,74,0,243,255,252,255,27,0,211,255,51,0,81,0,176,255,53,0,238,255,173,0,110,255,192,255,248,255,0,32,79,0,15,0,0,0,253,255,0,0,1,0,0,0,0,0,253,255,240,255,228,255,32,1,195,255,4,0,69,255,6,0,251,255,242,255,77,0,244,255,203,255,16,0,215,255,249,255,246,255,254,255,7,0,255,255,247,255,1,0,0,0,0,0,227,254,221,255,248,255,221,0,188,255,114,0,135,0,248,255,53,255,75,255,165,255,251,7,198,255,127,0,201,0,111,0,46,0,168,254,245,255,207,255,0,0,1,0,0,0,255,255,96,255,70,255,58,0,153,18,33,1,51,0,111,255,51,0,224,255,71,0,62,0,175,0,243,255,181,0,203,0,141,0,56,255,106,0,255,255,4,0,254,255,0,0,0,0,0,0,35,3,180,255,160,255,84,252,44,1,101,13,172,255,221,11,6,1,247,255,217,255,120,0,139,253,203,254,233,0,138,254,142,1,126,3,244,255,1,0,1,0,1,0,0,0,0,0,230,254,221,9,225,255,80,255,87,246,53,0,102,0,158,253,180,0,111,255,42,0,205,255,223,0,27,0,187,255,215,2,242,255,205,255,0,0,0,0,0,0,253,255,0,0,216,255,214,0,72,0,41,0,1,0,190,0,78,0,28,255,21,255,105,0,245,237,116,255,210,255,249,255,49,0,9,0,237,255,137,0,254,255,9,0,1,0,0,0,0,0,0,0,0,0,114,255,250,254,29,0,114,255,39,0,217,255,164,255,95,0,50,0,230,254,2,0,150,255,114,0,8,0,35,0,78,0,135,255,29,10,1,0,252,255,246,255,1,0,1,0,0,0,64,255,59,0,31,1,144,1,189,255,179,228,211,254,190,1,115,0,7,0,33,0,196,255,111,0,102,0,8,0,206,0,46,0,225,255,255,255,255,255,254,255,0,0,0,0,0,0,152,255,76,1,33,255,42,4,68,255,246,4,34,255,53,1,216,254,3,1,12,3,52,254,134,248,218,0,212,253,210,0,146,11,130,0,1,0,254,255,2,0,0,0,1,0,0,0,192,254,147,254,246,254,54,3,137,255,56,3,200,254,58,0,191,248,235,0,48,0,111,240,118,0,205,254,65,253,93,252,208,253,105,0,254,255,253,255,0,0,0,0,0,0,1,0,156,0,208,255,187,0,214,0,44,255,180,0,86,1,117,1,181,7,128,0,251,255,146,0,216,255,245,255,71,0,196,255,76,0,17,0,0,0,0,0,255,255,2,0,0,0,7,0,214,0,63,0,18,1,60,11,191,255,58,1,144,1,88,1,140,0,39,0,193,0,30,255,124,0,151,243,68,0,46,0,196,255,195,254,2,0,0,0,255,255,0,0,7,0,0,0,96,255,118,0,233,0,239,0,47,254,96,0,253,0,106,12,168,255,43,1,112,1,36,255,197,0,141,1,159,254,49,254,54,255,153,255,252,255,0,0,0,0,0,0,0,0,0,0,175,2,64,254,19,253,87,0,221,255,112,0,53,1,223,255,240,255,88,0,141,0,63,0,205,255,18,1,143,255,180,255,46,0,239,254,255,255,1,0,0,0,1,0,0,0,1,0,214,254,50,255,158,2,47,1,61,254,235,254,19,254,148,1,83,255,28,1,148,0,114,2,190,254,216,254,188,255,228,11,70,254,114,4,249,255,2,0,0,0,1,0,0,0,0,0,198,250,18,0,46,11,223,0,250,0,4,1,144,0,3,1,218,255,121,253,90,2,96,255,75,0,251,255,248,255,34,0,237,0,50,0,2,0,0,0,1,0,255,255,255,255,0,0,100,254,105,8,165,3,222,1,0,3,186,0,88,254,111,253,126,242,69,254,38,1,224,0,44,254,198,255,136,255,227,249,211,0,92,254,0,0,0,0,1,0,255,255,0,0,0,0,198,0,227,0,144,255,94,1,41,1,209,254,108,0,64,255,153,0,32,0,99,245,145,255,187,251,56,255,220,1,70,1,241,254,115,2,0,0,252,255,0,0,0,0,0,0,255,255,206,1,152,253,126,0,60,1,147,246,204,0,162,254,35,242,249,254,126,254,144,255,227,1,197,250,124,2,70,0,237,253,96,0,38,0,8,0,255,255,0,0,253,255,0,0,0,0,202,254,152,251,104,2,173,254,88,255,132,255,119,252,105,255,129,254,76,0,137,0,212,255,105,14,124,254,184,0,7,7,154,255,94,252,6,0,255,255,255,255,255,255,0,0,0,0,228,254,24,1,39,0,40,253,143,0,15,0,181,0,30,3,126,1,10,0,219,8,244,255,2,242,229,255,101,1,2,2,203,253,135,255,0,0,255,255,0,0,247,255,255,255,0,0,173,1,240,255,177,11,169,244,47,0,120,255,30,0,24,3,185,254,165,254,187,255,206,255,163,255,33,255,74,254,158,0,203,0,37,254,0,0,252,255,255,255,2,0,0,0,0,0,119,242,159,1,61,252,252,0,141,1,79,252,64,254,25,255,126,255,161,2,248,1,55,0,157,254,221,0,29,0,167,0,237,255,134,0,255,255,255,255,252,255,0,0,242,255,254,255,44,0,177,1,233,253,40,255,181,9,33,0,19,0,156,255,71,255,85,255,91,0,80,1,48,255,140,0,253,255,46,0,189,255,140,255,32,0,0,0,5,0,3,0,0,0,0,0,220,0,91,0,191,255,241,255,87,255,217,0,73,255,87,255,209,255,181,0,240,254,138,0,90,255,110,0,247,255,41,0,211,228,33,0,251,255,254,255,1,0,1,0,0,0,255,255,164,0,34,240,147,255,230,0,36,255,212,6,198,250,10,255,14,255,158,255,44,1,217,0,54,255,126,255,157,0,253,255,237,255,59,254,0,0,2,0,0,0,0,0,0,0,0,0,192,209,32,0,108,0,0,0,200,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,42,43,43,44,44,45,45,46,46,47,47,48,48,48,49,49,49,50,50,50,51,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,23,33,23,2,21,0,1,9,0,49,219,118,5,57,243,78,245,65,1,62,12,49,252,73,17,50,18,64,9,43,29,0,26,67,16,90,9,104,210,127,236,104,1,67,243,78,245,65,1,62,250,86,239,95,250,61,9,45,253,69,250,81,245,96,6,55,7,67,251,86,2,88,0,58,253,76,246,94,5,54,4,69,253,81,0,88,249,67,251,74,252,74,251,80,249,72,1,58,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,0,45,252,78,253,96,229,126,228,98,231,101,233,67,228,82,236,94,240,83,234,110,235,91,238,102,243,93,227,127,249,92,251,89,249,96,243,108,253,46,255,65,255,57,247,93,253,74,247,92,248,87,233,126,5,54,6,60,6,59,6,69,255,48,0,68,252,69,248,88,254,85,250,78,255,75,249,77,2,54,5,50,253,68,1,50,6,42,252,81,1,63,252,70,0,67,2,57,254,76,11,35,4,64,1,61,11,35,18,25,12,24,13,29,13,36,246,93,249,73,254,73,13,46,9,49,249,100,9,53,2,53,5,53,254,61,0,56,0,56,243,63,251,60,255,62,4,57,250,69,4,57,14,39,4,51,13,68,3,64,1,61,9,63,7,50,16,39,5,44,4,52,11,48,251,60,255,59,0,59,22,33,5,44,14,43,255,78,0,60,9,69,11,28,2,40,3,44,0,49,0,46,2,44,2,51,0,47,4,39,2,62,6,46,0,54,3,54,2,58,4,63,6,51,6,57,7,53,6,52,6,55,11,45,14,36,8,53,255,82,7,55,253,78,15,46,22,31,255,84,25,7,30,249,28,3,28,4,32,0,34,255,30,6,30,6,32,9,31,19,26,27,26,30,37,20,28,34,17,70,1,67,5,59,9,67,16,30,18,32,18,35,22,29,24,31,23,38,18,43,20,41,11,63,9,59,9,64,255,94,254,89,247,108,250,76,254,44,0,45,0,52,253,64,254,59,252,70,252,75,248,82,239,102,247,77,3,24,0,42,0,48,0,55,250,59,249,71,244,83,245,87,226,119,1,58,253,29,255,36,1,38,2,43,250,55,0,58,0,64,253,74,246,90,0,70,252,29,5,31,7,42,1,59,254,58,253,72,253,81,245,97,0,58,8,5,10,14,14,18,13,27,2,40,0,58,253,70,250,79,248,85,0,0,243,106,240,106,246,87,235,114,238,110,242,98,234,110,235,106,238,103,235,107,233,108,230,112,246,96,244,95,251,91,247,93,234,94,251,86,9,67,252,80,246,85,255,70,7,60,9,58,5,61,12,50,15,50,18,49,17,54,10,41,7,46,255,51,7,49,8,52,9,41,6,47,2,55,13,41,10,44,6,50,5,53,13,49,4,63,6,64,254,69,254,59,6,70,10,44,9,31,12,43,3,53,14,34,10,38,253,52,13,40,17,32,7,44,7,38,13,50,10,57,26,43,14,11,11,14,9,11,18,11,21,9,23,254,32,241,32,241,34,235,39,233,42,223,41,225,46,228,38,244,21,29,45,232,53,211,48,230,65,213,43,237,39,246,30,9,18,26,20,27,0,57,242,82,251,75,237,97,221,125,27,0,28,0,31,252,27,6,34,8,30,10,24,22,33,19,22,32,26,31,21,41,26,44,23,47,16,65,14,71,8,60,6,63,17,65,21,24,23,20,26,23,27,32,28,23,28,24,23,40,24,32,28,29,23,42,19,57,22,53,22,61,11,86,12,40,11,51,14,59,252,79,249,71,251,69,247,70,248,66,246,68,237,73,244,69,240,70,241,67,236,62,237,70,240,66,234,65,236,63,9,254,26,247,33,247,39,249,41,254,45,3,49,9,45,27,36,59,250,66,249,35,249,42,248,45,251,48,244,56,250,60,251,62,248,66,248,76,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,21,243,33,242,39,249,46,254,51,2,60,6,61,17,55,34,42,62,249,92,251,89,249,96,243,108,253,46,255,65,255,57,247,93,253,74,247,92,248,87,233,126,249,92,251,89,249,96,243,108,253,46,255,65,255,57,247,93,253,74,247,92,248,87,233,126,254,85,250,78,255,75,249,77,2,54,5,50,253,68,1,50,6,42,252,81,1,63,252,70,0,67,2,57,254,76,11,35,4,64,1,61,11,35,18,25,12,24,13,29,13,36,246,93,249,73,254,73,13,46,9,49,249,100,9,53,2,53,5,53,254,61,0,56,0,56,243,63,251,60,255,62,4,57,250,69,4,57,14,39,4,51,13,68,254,85,250,78,255,75,249,77,2,54,5,50,253,68,1,50,6,42,252,81,1,63,252,70,0,67,2,57,254,76,11,35,4,64,1,61,11,35,18,25,12,24,13,29,13,36,246,93,249,73,254,73,13,46,9,49,249,100,9,53,2,53,5,53,254,61,0,56,0,56,243,63,251,60,255,62,4,57,250,69,4,57,14,39,4,51,13,68,11,28,2,40,3,44,0,49,0,46,2,44,2,51,0,47,4,39,2,62,6,46,0,54,3,54,2,58,4,63,6,51,6,57,7,53,6,52,6,55,11,45,14,36,8,53,255,82,7,55,253,78,15,46,22,31,255,84,25,7,30,249,28,3,28,4,32,0,34,255,30,6,30,6,32,9,31,19,26,27,26,30,37,20,28,34,17,70,11,28,2,40,3,44,0,49,0,46,2,44,2,51,0,47,4,39,2,62,6,46,0,54,3,54,2,58,4,63,6,51,6,57,7,53,6,52,6,55,11,45,14,36,8,53,255,82,7,55,253,78,15,46,22,31,255,84,25,7,30,249,28,3,28,4,32,0,34,255,30,6,30,6,32,9,31,19,26,27,26,30,37,20,28,34,17,70,252,79,249,71,251,69,247,70,248,66,246,68,237,73,244,69,240,70,241,67,236,62,237,70,240,66,234,65,236,63,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,9,254,26,247,33,247,39,249,41,254,45,3,49,9,45,27,36,59,21,243,33,242,39,249,46,254,51,2,60,6,61,17,55,34,42,62,250,66,249,35,249,42,248,45,251,48,244,56,250,60,251,62,248,66,248,76,252,79,249,71,251,69,247,70,248,66,246,68,237,73,244,69,240,70,241,67,236,62,237,70,240,66,234,65,236,63,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,9,254,26,247,33,247,39,249,41,254,45,3,49,9,45,27,36,59,21,243,33,242,39,249,46,254,51,2,60,6,61,17,55,34,42,62,250,66,249,35,249,42,248,45,251,48,244,56,250,60,251,62,248,66,248,76,243,106,240,106,246,87,235,114,238,110,242,98,234,110,235,106,238,103,235,107,233,108,230,112,246,96,244,95,251,91,247,93,234,94,251,86,9,67,252,80,246,85,255,70,7,60,9,58,5,61,12,50,15,50,18,49,17,54,10,41,7,46,255,51,7,49,8,52,9,41,6,47,2,55,13,41,10,44,6,50,5,53,13,49,4,63,6,64,243,106,240,106,246,87,235,114,238,110,242,98,234,110,235,106,238,103,235,107,233,108,230,112,246,96,244,95,251,91,247,93,234,94,251,86,9,67,252,80,246,85,255,70,7,60,9,58,5,61,12,50,15,50,18,49,17,54,10,41,7,46,255,51,7,49,8,52,9,41,6,47,2,55,13,41,10,44,6,50,5,53,13,49,4,63,6,64,14,11,11,14,9,11,18,11,21,9,23,254,32,241,32,241,34,235,39,233,42,223,41,225,46,228,38,244,21,29,45,232,53,211,48,230,65,213,43,237,39,246,30,9,18,26,20,27,0,57,242,82,251,75,237,97,221,125,27,0,28,0,31,252,27,6,34,8,30,10,24,22,33,19,22,32,26,31,21,41,26,44,23,47,16,65,14,71,14,11,11,14,9,11,18,11,21,9,23,254,32,241,32,241,34,235,39,233,42,223,41,225,46,228,38,244,21,29,45,232,53,211,48,230,65,213,43,237,39,246,30,9,18,26,20,27,0,57,242,82,251,75,237,97,221,125,27,0,28,0,31,252,27,6,34,8,30,10,24,22,33,19,22,32,26,31,21,41,26,44,23,47,16,65,14,71,250,76,254,44,0,45,0,52,253,64,254,59,252,70,252,75,248,82,239,102,247,77,3,24,0,42,0,48,0,55,250,59,249,71,244,83,245,87,226,119,1,58,253,29,255,36,1,38,2,43,250,55,0,58,0,64,253,74,246,90,250,76,254,44,0,45,0,52,253,64,254,59,252,70,252,75,248,82,239,102,247,77,3,24,0,42,0,48,0,55,250,59,249,71,244,83,245,87,226,119,1,58,253,29,255,36,1,38,2,43,250,55,0,58,0,64,253,74,246,90,253,74,247,92,248,87,233,126,253,74,247,92,248,87,233,126,253,74,247,92,248,87,233,126,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,22,25,34,0,16,0,254,9,4,41,227,118,2,65,250,71,243,79,5,52,9,50,253,70,10,54,26,34,19,22,40,0,57,2,41,36,26,69,211,127,241,101,252,76,250,71,243,79,5,52,6,69,243,90,0,52,8,43,254,69,251,82,246,96,2,59,2,75,253,87,253,100,1,56,253,74,250,85,0,59,253,81,249,86,251,95,255,66,255,77,1,70,254,86,251,72,0,61,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,13,15,7,51,2,80,217,127,238,91,239,96,230,81,221,98,232,102,233,97,229,119,232,99,235,110,238,102,220,127,0,80,251,89,249,94,252,92,0,39,0,65,241,84,221,127,254,73,244,104,247,91,225,127,3,55,7,56,7,55,8,61,253,53,0,68,249,74,247,88,243,103,243,91,247,89,242,92,248,76,244,87,233,110,232,105,246,78,236,112,239,99,178,127,186,127,206,127,210,127,252,66,251,78,252,71,248,72,2,59,255,55,249,70,250,75,248,89,222,119,253,75,32,20,30,22,212,127,0,54,251,61,0,58,255,60,253,61,248,67,231,84,242,74,251,65,5,52,2,57,0,61,247,69,245,70,18,55,252,71,0,58,7,61,9,41,18,25,9,32,5,43,9,47,0,44,0,51,2,46,19,38,252,66,15,38,12,42,9,34,0,89,4,45,10,28,10,31,33,245,52,213,18,15,28,0,35,234,38,231,34,0,39,238,32,244,102,162,0,0,56,241,33,252,29,10,37,251,51,227,39,247,52,222,69,198,67,193,44,251,32,7,55,227,32,1,0,0,27,36,33,231,34,226,36,228,38,228,38,229,34,238,35,240,34,242,32,248,37,250,35,0,30,10,28,18,26,25,29,41,0,75,2,72,8,77,14,35,18,31,17,35,21,30,17,45,20,42,18,45,27,26,16,54,7,66,16,56,11,73,10,67,246,116,233,112,241,71,249,61,0,53,251,66,245,77,247,80,247,84,246,87,222,127,235,101,253,39,251,53,249,61,245,75,241,77,239,91,231,107,231,111,228,122,245,76,246,44,246,52,246,57,247,58,240,72,249,69,252,69,251,74,247,86,2,66,247,34,1,32,11,31,5,52,254,55,254,67,0,73,248,89,3,52,7,4,10,8,17,8,16,19,3,37,255,61,251,73,255,70,252,78,0,0,235,126,233,124,236,110,230,126,231,124,239,105,229,121,229,117,239,102,230,117,229,116,223,122,246,95,242,100,248,95,239,111,228,114,250,89,254,80,252,82,247,85,248,81,255,72,5,64,1,67,9,56,0,69,1,69,7,69,249,69,250,67,240,77,254,64,2,61,250,67,253,64,2,57,253,65,253,66,0,62,9,51,255,66,254,71,254,75,255,70,247,72,14,60,16,37,0,47,18,35,11,37,12,41,10,41,2,48,12,41,13,41,0,59,3,50,19,40,3,66,18,50,19,250,18,250,14,0,26,244,31,240,33,231,33,234,37,228,39,226,42,226,47,214,45,220,49,222,41,239,32,9,69,185,63,193,66,192,77,182,54,217,52,221,41,246,36,0,40,255,30,14,28,26,23,37,12,55,11,65,37,223,39,220,40,219,38,226,46,223,42,226,40,232,49,227,38,244,40,246,38,253,46,251,31,20,29,30,25,44,12,48,11,49,26,45,22,22,23,22,27,21,33,20,26,28,30,24,27,34,18,42,25,39,18,50,12,70,21,54,14,71,11,83,25,32,21,49,21,54,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,251,71,0,24,255,36,254,42,254,52,247,57,250,63,252,65,252,67,249,82,253,81,253,76,249,72,250,78,244,72,242,68,253,70,250,76,251,66,251,62,0,57,252,61,247,60,1,54,2,58,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,0,80,251,89,249,94,252,92,0,39,0,65,241,84,221,127,254,73,244,104,247,91,225,127,0,80,251,89,249,94,252,92,0,39,0,65,241,84,221,127,254,73,244,104,247,91,225,127,243,103,243,91,247,89,242,92,248,76,244,87,233,110,232,105,246,78,236,112,239,99,178,127,186,127,206,127,210,127,252,66,251,78,252,71,248,72,2,59,255,55,249,70,250,75,248,89,222,119,253,75,32,20,30,22,212,127,0,54,251,61,0,58,255,60,253,61,248,67,231,84,242,74,251,65,5,52,2,57,0,61,247,69,245,70,18,55,243,103,243,91,247,89,242,92,248,76,244,87,233,110,232,105,246,78,236,112,239,99,178,127,186,127,206,127,210,127,252,66,251,78,252,71,248,72,2,59,255,55,249,70,250,75,248,89,222,119,253,75,32,20,30,22,212,127,0,54,251,61,0,58,255,60,253,61,248,67,231,84,242,74,251,65,5,52,2,57,0,61,247,69,245,70,18,55,4,45,10,28,10,31,33,245,52,213,18,15,28,0,35,234,38,231,34,0,39,238,32,244,102,162,0,0,56,241,33,252,29,10,37,251,51,227,39,247,52,222,69,198,67,193,44,251,32,7,55,227,32,1,0,0,27,36,33,231,34,226,36,228,38,228,38,229,34,238,35,240,34,242,32,248,37,250,35,0,30,10,28,18,26,25,29,41,4,45,10,28,10,31,33,245,52,213,18,15,28,0,35,234,38,231,34,0,39,238,32,244,102,162,0,0,56,241,33,252,29,10,37,251,51,227,39,247,52,222,69,198,67,193,44,251,32,7,55,227,32,1,0,0,27,36,33,231,34,226,36,228,38,228,38,229,34,238,35,240,34,242,32,248,37,250,35,0,30,10,28,18,26,25,29,41,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,253,81,253,76,249,72,250,78,244,72,242,68,253,70,250,76,251,66,251,62,0,57,252,61,247,60,1,54,2,58,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,251,71,0,24,255,36,254,42,254,52,247,57,250,63,252,65,252,67,249,82,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,253,81,253,76,249,72,250,78,244,72,242,68,253,70,250,76,251,66,251,62,0,57,252,61,247,60,1,54,2,58,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,251,71,0,24,255,36,254,42,254,52,247,57,250,63,252,65,252,67,249,82,235,126,233,124,236,110,230,126,231,124,239,105,229,121,229,117,239,102,230,117,229,116,223,122,246,95,242,100,248,95,239,111,228,114,250,89,254,80,252,82,247,85,248,81,255,72,5,64,1,67,9,56,0,69,1,69,7,69,249,69,250,67,240,77,254,64,2,61,250,67,253,64,2,57,253,65,253,66,0,62,9,51,255,66,254,71,254,75,235,126,233,124,236,110,230,126,231,124,239,105,229,121,229,117,239,102,230,117,229,116,223,122,246,95,242,100,248,95,239,111,228,114,250,89,254,80,252,82,247,85,248,81,255,72,5,64,1,67,9,56,0,69,1,69,7,69,249,69,250,67,240,77,254,64,2,61,250,67,253,64,2,57,253,65,253,66,0,62,9,51,255,66,254,71,254,75,19,250,18,250,14,0,26,244,31,240,33,231,33,234,37,228,39,226,42,226,47,214,45,220,49,222,41,239,32,9,69,185,63,193,66,192,77,182,54,217,52,221,41,246,36,0,40,255,30,14,28,26,23,37,12,55,11,65,37,223,39,220,40,219,38,226,46,223,42,226,40,232,49,227,38,244,40,246,38,253,46,251,31,20,29,30,25,44,19,250,18,250,14,0,26,244,31,240,33,231,33,234,37,228,39,226,42,226,47,214,45,220,49,222,41,239,32,9,69,185,63,193,66,192,77,182,54,217,52,221,41,246,36,0,40,255,30,14,28,26,23,37,12,55,11,65,37,223,39,220,40,219,38,226,46,223,42,226,40,232,49,227,38,244,40,246,38,253,46,251,31,20,29,30,25,44,233,112,241,71,249,61,0,53,251,66,245,77,247,80,247,84,246,87,222,127,235,101,253,39,251,53,249,61,245,75,241,77,239,91,231,107,231,111,228,122,245,76,246,44,246,52,246,57,247,58,240,72,249,69,252,69,251,74,247,86,233,112,241,71,249,61,0,53,251,66,245,77,247,80,247,84,246,87,222,127,235,101,253,39,251,53,249,61,245,75,241,77,239,91,231,107,231,111,228,122,245,76,246,44,246,52,246,57,247,58,240,72,249,69,252,69,251,74,247,86,254,73,244,104,247,91,225,127,254,73,244,104,247,91,225,127,254,73,244,104,247,91,225,127,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,29,16,25,0,14,0,246,51,253,62,229,99,26,16,252,85,232,102,5,57,6,57,239,73,14,57,20,40,20,10,29,0,54,0,37,42,12,97,224,127,234,117,254,74,252,85,232,102,5,57,250,93,242,88,250,44,4,55,245,89,241,103,235,116,19,57,20,58,4,84,6,96,1,63,251,85,243,106,5,63,6,75,253,90,255,101,3,55,252,79,254,75,244,97,249,50,1,60,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,7,34,247,88,236,127,220,127,239,91,242,95,231,84,231,86,244,89,239,91,225,127,242,76,238,103,243,90,219,127,11,80,5,76,2,84,5,78,250,55,4,61,242,83,219,127,251,79,245,104,245,91,226,127,0,65,254,79,0,72,252,92,250,56,3,68,248,71,243,98,252,86,244,88,251,82,253,72,252,67,248,72,240,89,247,69,255,59,5,66,4,57,252,71,254,71,2,58,255,74,252,44,255,69,0,62,249,51,252,47,250,42,253,41,250,53,8,76,247,78,245,83,9,52,0,67,251,90,1,67,241,72,251,75,248,80,235,83,235,64,243,31,231,64,227,94,9,75,17,63,248,74,251,35,254,27,13,91,3,65,249,69,8,77,246,66,3,62,253,68,236,81,0,30,1,7,253,23,235,74,16,66,233,124,17,37,44,238,50,222,234,127,4,39,0,42,7,34,11,29,8,31,6,37,7,42,3,40,8,33,13,43,13,36,4,47,3,55,2,58,6,60,8,44,11,44,14,42,7,48,4,56,4,52,13,37,9,49,19,58,10,48,12,45,0,69,20,33,8,63,35,238,33,231,28,253,24,10,27,0,34,242,52,212,39,232,19,17,31,25,36,29,24,33,34,15,30,20,22,73,20,34,19,31,27,44,19,16,15,36,15,36,21,28,25,21,30,20,31,12,27,16,24,42,0,93,14,56,15,57,26,38,232,127,232,115,234,82,247,62,0,53,0,59,242,85,243,89,243,94,245,92,227,127,235,100,242,57,244,67,245,71,246,77,235,85,240,88,233,104,241,98,219,127,246,82,248,48,248,61,248,66,249,70,242,75,246,79,247,83,244,92,238,108,252,79,234,69,240,75,254,58,1,58,243,78,247,83,252,81,243,99,243,81,250,38,243,62,250,58,254,59,240,73,246,76,243,86,247,83,246,87,0,0,234,127,231,127,231,120,229,127,237,114,233,117,231,118,230,117,232,113,228,118,225,120,219,124,246,94,241,102,246,99,243,106,206,127,251,92,17,57,251,86,243,94,244,91,254,77,0,71,255,73,4,64,249,81,5,64,15,57,1,67,0,68,246,67,1,68,0,77,2,64,0,68,251,78,7,55,5,59,2,65,14,54,15,44,5,60,2,70,254,76,238,86,12,70,5,64,244,70,11,55,5,56,0,69,2,65,250,74,5,54,7,54,250,76,245,82,254,77,254,77,25,42,17,243,16,247,17,244,27,235,37,226,41,216,42,215,48,209,39,224,46,216,52,205,46,215,52,217,43,237,32,11,61,201,56,210,62,206,81,189,45,236,35,254,28,15,34,1,39,1,30,17,20,38,18,45,15,54,0,79,36,240,37,242,37,239,32,1,34,15,29,15,24,25,34,22,31,16,35,18,31,28,33,41,36,28,27,47,21,62,18,31,19,26,36,24,24,23,27,16,24,30,31,29,22,41,22,42,16,60,15,52,14,60,3,78,240,123,21,53,22,56,25,61,21,33,19,50,17,61,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,247,71,249,37,248,44,245,49,246,56,244,59,248,63,247,67,250,68,246,79,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,11,80,5,76,2,84,5,78,250,55,4,61,242,83,219,127,251,79,245,104,245,91,226,127,11,80,5,76,2,84,5,78,250,55,4,61,242,83,219,127,251,79,245,104,245,91,226,127,252,86,244,88,251,82,253,72,252,67,248,72,240,89,247,69,255,59,5,66,4,57,252,71,254,71,2,58,255,74,252,44,255,69,0,62,249,51,252,47,250,42,253,41,250,53,8,76,247,78,245,83,9,52,0,67,251,90,1,67,241,72,251,75,248,80,235,83,235,64,243,31,231,64,227,94,9,75,17,63,248,74,251,35,254,27,13,91,252,86,244,88,251,82,253,72,252,67,248,72,240,89,247,69,255,59,5,66,4,57,252,71,254,71,2,58,255,74,252,44,255,69,0,62,249,51,252,47,250,42,253,41,250,53,8,76,247,78,245,83,9,52,0,67,251,90,1,67,241,72,251,75,248,80,235,83,235,64,243,31,231,64,227,94,9,75,17,63,248,74,251,35,254,27,13,91,4,39,0,42,7,34,11,29,8,31,6,37,7,42,3,40,8,33,13,43,13,36,4,47,3,55,2,58,6,60,8,44,11,44,14,42,7,48,4,56,4,52,13,37,9,49,19,58,10,48,12,45,0,69,20,33,8,63,35,238,33,231,28,253,24,10,27,0,34,242,52,212,39,232,19,17,31,25,36,29,24,33,34,15,30,20,22,73,4,39,0,42,7,34,11,29,8,31,6,37,7,42,3,40,8,33,13,43,13,36,4,47,3,55,2,58,6,60,8,44,11,44,14,42,7,48,4,56,4,52,13,37,9,49,19,58,10,48,12,45,0,69,20,33,8,63,35,238,33,231,28,253,24,10,27,0,34,242,52,212,39,232,19,17,31,25,36,29,24,33,34,15,30,20,22,73,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,247,71,249,37,248,44,245,49,246,56,244,59,248,63,247,67,250,68,246,79,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,247,71,249,37,248,44,245,49,246,56,244,59,248,63,247,67,250,68,246,79,234,127,231,127,231,120,229,127,237,114,233,117,231,118,230,117,232,113,228,118,225,120,219,124,246,94,241,102,246,99,243,106,206,127,251,92,17,57,251,86,243,94,244,91,254,77,0,71,255,73,4,64,249,81,5,64,15,57,1,67,0,68,246,67,1,68,0,77,2,64,0,68,251,78,7,55,5,59,2,65,14,54,15,44,5,60,2,70,234,127,231,127,231,120,229,127,237,114,233,117,231,118,230,117,232,113,228,118,225,120,219,124,246,94,241,102,246,99,243,106,206,127,251,92,17,57,251,86,243,94,244,91,254,77,0,71,255,73,4,64,249,81,5,64,15,57,1,67,0,68,246,67,1,68,0,77,2,64,0,68,251,78,7,55,5,59,2,65,14,54,15,44,5,60,2,70,17,243,16,247,17,244,27,235,37,226,41,216,42,215,48,209,39,224,46,216,52,205,46,215,52,217,43,237,32,11,61,201,56,210,62,206,81,189,45,236,35,254,28,15,34,1,39,1,30,17,20,38,18,45,15,54,0,79,36,240,37,242,37,239,32,1,34,15,29,15,24,25,34,22,31,16,35,18,31,28,33,41,36,28,27,47,21,62,17,243,16,247,17,244,27,235,37,226,41,216,42,215,48,209,39,224,46,216,52,205,46,215,52,217,43,237,32,11,61,201,56,210,62,206,81,189,45,236,35,254,28,15,34,1,39,1,30,17,20,38,18,45,15,54,0,79,36,240,37,242,37,239,32,1,34,15,29,15,24,25,34,22,31,16,35,18,31,28,33,41,36,28,27,47,21,62,232,115,234,82,247,62,0,53,0,59,242,85,243,89,243,94,245,92,227,127,235,100,242,57,244,67,245,71,246,77,235,85,240,88,233,104,241,98,219,127,246,82,248,48,248,61,248,66,249,70,242,75,246,79,247,83,244,92,238,108,232,115,234,82,247,62,0,53,0,59,242,85,243,89,243,94,245,92,227,127,235,100,242,57,244,67,245,71,246,77,235,85,240,88,233,104,241,98,219,127,246,82,248,48,248,61,248,66,249,70,242,75,246,79,247,83,244,92,238,108,251,79,245,104,245,91,226,127,251,79,245,104,245,91,226,127,251,79,245,104,245,91,226,127,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,0,11,1,55,0,69,239,127,243,102,0,82,249,74,235,107,229,127,225,127,232,127,238,95,229,127,235,114,226,127,239,123,244,115,240,122,245,115,244,63,254,68,241,84,243,104,253,70,248,93,246,90,226,127,255,74,250,97,249,91,236,127,252,56,251,82,249,76,234,125,249,93,245,87,253,77,251,71,252,63,252,68,244,84,249,62,249,65,8,61,5,56,254,66,1,64,0,61,254,78,1,50,7,52,10,35,0,44,11,38,1,45,0,46,5,44,31,17,1,51,7,50,28,19,16,33,14,62,243,108,241,100,243,101,243,91,244,94,246,88,240,84,246,86,249,83,243,87,237,94,1,70,0,72,251,74,18,59,248,102,241,100,0,95,252,75,2,72,245,75,253,71,15,46,243,69,0,62,0,65,21,37,241,72,9,57,16,54,0,62,12,72,24,0,15,9,8,25,13,18,15,9,13,19,10,37,12,18,6,29,20,33,15,30,4,45,1,58,0,62,7,61,12,38,11,45,15,39,11,42,13,44,16,45,12,41,10,49,30,34,18,42,10,55,17,51,17,46,0,89,26,237,22,239,26,239,30,231,28,236,33,233,37,229,33,233,40,228,38,239,33,245,40,241,41,250,38,1,41,17,30,250,27,3,26,22,37,240,35,252,38,248,38,253,37,3,38,5,42,0,35,16,39,22,14,48,27,37,21,60,12,68,2,97,253,71,250,42,251,50,253,54,254,62,0,58,1,63,254,72,255,74,247,91,251,67,251,27,253,39,254,44,0,46,240,64,248,68,246,78,250,77,246,86,244,92,241,55,246,60,250,62,252,65,244,73,248,76,249,80,247,88,239,110,245,97,236,84,245,79,250,73,252,74,243,86,243,96,245,97,237,117,248,78,251,33,252,48,254,53,253,62,243,71,246,79,244,86,243,90,242,97,0,0,250,93,250,84,248,79,0,66,255,71,0,62,254,60,254,59,251,75,253,62,252,58,247,66,255,79,0,71,3,68,10,44,249,62,15,36,14,40,16,27,12,29,1,44,20,36,18,32,5,42,1,48,10,62,17,46,9,64,244,104,245,97,240,96,249,88,248,85,249,85,247,85,243,88,4,66,253,77,253,76,250,76,10,58,255,76,255,83,249,99,242,95,2,95,0,76,251,74,0,70,245,75,1,68,0,65,242,73,3,62,4,62,255,68,243,75,11,55,5,64,12,70,15,6,6,19,7,16,12,14,18,13,13,11,13,15,15,16,12,23,13,23,15,20,14,26,14,44,17,40,17,47,24,17,21,21,25,22,31,27,22,29,19,35,14,50,10,57,7,63,254,77,252,82,253,94,9,69,244,109,36,221,36,222,32,230,37,226,44,224,34,238,34,241,40,241,33,249,35,251,33,0,38,2,33,13,23,35,13,58,29,253,26,0,22,30,31,249,35,241,34,253,34,3,36,255,34,5,32,11,35,5,34,12,39,11,30,29,34,26,29,39,19,66,31,21,31,31,25,50,239,120,236,112,238,114,245,85,241,92,242,89,230,71,241,81,242,80,0,68,242,70,232,56,233,68,232,50,245,74,23,243,26,243,40,241,49,242,44,3,45,6,44,34,33,54,19,82,253,75,255,23,1,34,1,43,0,54,254,55,0,61,1,64,0,68,247,92,242,106,243,97,241,90,244,90,238,88,246,73,247,79,242,86,246,73,246,70,246,69,251,66,247,64,251,58,2,59,21,246,24,245,28,248,28,255,29,3,29,9,35,20,29,36,14,67,239,123,244,115,240,122,245,115,244,63,254,68,241,84,243,104,253,70,248,93,246,90,226,127,239,123,244,115,240,122,245,115,244,63,254,68,241,84,243,104,253,70,248,93,246,90,226,127,249,93,245,87,253,77,251,71,252,63,252,68,244,84,249,62,249,65,8,61,5,56,254,66,1,64,0,61,254,78,1,50,7,52,10,35,0,44,11,38,1,45,0,46,5,44,31,17,1,51,7,50,28,19,16,33,14,62,243,108,241,100,243,101,243,91,244,94,246,88,240,84,246,86,249,83,243,87,237,94,1,70,0,72,251,74,18,59,249,93,245,87,253,77,251,71,252,63,252,68,244,84,249,62,249,65,8,61,5,56,254,66,1,64,0,61,254,78,1,50,7,52,10,35,0,44,11,38,1,45,0,46,5,44,31,17,1,51,7,50,28,19,16,33,14,62,243,108,241,100,243,101,243,91,244,94,246,88,240,84,246,86,249,83,243,87,237,94,1,70,0,72,251,74,18,59,24,0,15,9,8,25,13,18,15,9,13,19,10,37,12,18,6,29,20,33,15,30,4,45,1,58,0,62,7,61,12,38,11,45,15,39,11,42,13,44,16,45,12,41,10,49,30,34,18,42,10,55,17,51,17,46,0,89,26,237,22,239,26,239,30,231,28,236,33,233,37,229,33,233,40,228,38,239,33,245,40,241,41,250,38], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1666245);
/* memory initializer */ allocate([1,41,17,24,0,15,9,8,25,13,18,15,9,13,19,10,37,12,18,6,29,20,33,15,30,4,45,1,58,0,62,7,61,12,38,11,45,15,39,11,42,13,44,16,45,12,41,10,49,30,34,18,42,10,55,17,51,17,46,0,89,26,237,22,239,26,239,30,231,28,236,33,233,37,229,33,233,40,228,38,239,33,245,40,241,41,250,38,1,41,17,239,120,236,112,238,114,245,85,241,92,242,89,230,71,241,81,242,80,0,68,242,70,232,56,233,68,232,50,245,74,242,106,243,97,241,90,244,90,238,88,246,73,247,79,242,86,246,73,246,70,246,69,251,66,247,64,251,58,2,59,23,243,26,243,40,241,49,242,44,3,45,6,44,34,33,54,19,82,21,246,24,245,28,248,28,255,29,3,29,9,35,20,29,36,14,67,253,75,255,23,1,34,1,43,0,54,254,55,0,61,1,64,0,68,247,92,239,120,236,112,238,114,245,85,241,92,242,89,230,71,241,81,242,80,0,68,242,70,232,56,233,68,232,50,245,74,242,106,243,97,241,90,244,90,238,88,246,73,247,79,242,86,246,73,246,70,246,69,251,66,247,64,251,58,2,59,23,243,26,243,40,241,49,242,44,3,45,6,44,34,33,54,19,82,21,246,24,245,28,248,28,255,29,3,29,9,35,20,29,36,14,67,253,75,255,23,1,34,1,43,0,54,254,55,0,61,1,64,0,68,247,92,250,93,250,84,248,79,0,66,255,71,0,62,254,60,254,59,251,75,253,62,252,58,247,66,255,79,0,71,3,68,10,44,249,62,15,36,14,40,16,27,12,29,1,44,20,36,18,32,5,42,1,48,10,62,17,46,9,64,244,104,245,97,240,96,249,88,248,85,249,85,247,85,243,88,4,66,253,77,253,76,250,76,10,58,255,76,255,83,250,93,250,84,248,79,0,66,255,71,0,62,254,60,254,59,251,75,253,62,252,58,247,66,255,79,0,71,3,68,10,44,249,62,15,36,14,40,16,27,12,29,1,44,20,36,18,32,5,42,1,48,10,62,17,46,9,64,244,104,245,97,240,96,249,88,248,85,249,85,247,85,243,88,4,66,253,77,253,76,250,76,10,58,255,76,255,83,15,6,6,19,7,16,12,14,18,13,13,11,13,15,15,16,12,23,13,23,15,20,14,26,14,44,17,40,17,47,24,17,21,21,25,22,31,27,22,29,19,35,14,50,10,57,7,63,254,77,252,82,253,94,9,69,244,109,36,221,36,222,32,230,37,226,44,224,34,238,34,241,40,241,33,249,35,251,33,0,38,2,33,13,23,35,13,58,15,6,6,19,7,16,12,14,18,13,13,11,13,15,15,16,12,23,13,23,15,20,14,26,14,44,17,40,17,47,24,17,21,21,25,22,31,27,22,29,19,35,14,50,10,57,7,63,254,77,252,82,253,94,9,69,244,109,36,221,36,222,32,230,37,226,44,224,34,238,34,241,40,241,33,249,35,251,33,0,38,2,33,13,23,35,13,58,253,71,250,42,251,50,253,54,254,62,0,58,1,63,254,72,255,74,247,91,251,67,251,27,253,39,254,44,0,46,240,64,248,68,246,78,250,77,246,86,244,92,241,55,246,60,250,62,252,65,244,73,248,76,249,80,247,88,239,110,253,71,250,42,251,50,253,54,254,62,0,58,1,63,254,72,255,74,247,91,251,67,251,27,253,39,254,44,0,46,240,64,248,68,246,78,250,77,246,86,244,92,241,55,246,60,250,62,252,65,244,73,248,76,249,80,247,88,239,110,253,70,248,93,246,90,226,127,253,70,248,93,246,90,226,127,253,70,248,93,246,90,226,127,0,0,1,0,2,0,3,0,5,0,8,0,13,0,21,0,255,0,254,0,253,0,251,0,248,0,243,0,239,0,235,0,0,1,1,1,2,1,3,1,5,1,8,1,13,1,21,1,255,1,254,1,253,1,251,1,248,1,243,1,239,1,235,1,0,2,1,2,2,2,3,2,5,2,8,2,13,2,21,2,255,2,254,2,253,2,251,2,248,2,243,2,239,2,235,2,0,3,1,3,2,3,3,3,5,3,8,3,13,3,21,3,255,3,254,3,253,3,251,3,248,3,243,3,239,3,235,3,0,5,1,5,2,5,3,5,5,5,8,5,13,5,21,5,255,5,254,5,253,5,251,5,248,5,243,5,239,5,235,5,0,8,1,8,2,8,3,8,5,8,8,8,13,8,21,8,255,8,254,8,253,8,251,8,248,8,243,8,239,8,235,8,0,13,1,13,2,13,3,13,5,13,8,13,13,13,21,13,255,13,254,13,253,13,251,13,248,13,243,13,239,13,235,13,0,21,1,21,2,21,3,21,5,21,8,21,13,21,21,21,255,21,254,21,253,21,251,21,248,21,243,21,239,21,235,21,0,255,1,255,2,255,3,255,5,255,8,255,13,255,21,255,255,255,254,255,253,255,251,255,248,255,243,255,239,255,235,255,0,254,1,254,2,254,3,254,5,254,8,254,13,254,21,254,255,254,254,254,253,254,251,254,248,254,243,254,239,254,235,254,0,253,1,253,2,253,3,253,5,253,8,253,13,253,21,253,255,253,254,253,253,253,251,253,248,253,243,253,239,253,235,253,0,251,1,251,2,251,3,251,5,251,8,251,13,251,21,251,255,251,254,251,253,251,251,251,248,251,243,251,239,251,235,251,0,248,1,248,2,248,3,248,5,248,8,248,13,248,21,248,255,248,254,248,253,248,251,248,248,248,243,248,239,248,235,248,0,243,1,243,2,243,3,243,5,243,8,243,13,243,21,243,255,243,254,243,253,243,251,243,248,243,243,243,239,243,235,243,0,239,1,239,2,239,3,239,5,239,8,239,13,239,21,239,255,239,254,239,253,239,251,239,248,239,243,239,239,239,235,239,0,235,1,235,2,235,3,235,5,235,8,235,13,235,21,235,255,235,254,235,253,235,251,235,248,235,243,235,239,235,0,0,248,227,8,227,238,231,17,231,0,233,250,234,6,234,243,237,12,237,0,238,25,238,231,239,251,239,5,239,246,241,10,241,0,242,252,243,4,243,19,243,237,244,248,245,254,245,0,245,2,245,8,245,241,246,252,246,4,246,15,246,250,247,255,247,1,247,6,247,227,248,245,248,248,248,253,248,3,248,8,248,11,248,29,248,251,249,254,249,0,249,2,249,5,249,234,250,247,250,250,250,253,250,255,250,1,250,3,250,6,250,9,250,22,250,239,251,249,251,252,251,254,251,0,251,2,251,4,251,7,251,17,251,243,252,246,252,251,252,253,252,255,252,0,252,1,252,3,252,5,252,10,252,13,252,248,253,250,253,252,253,253,253,254,253,255,253,0,253,1,253,2,253,4,253,6,253,8,253,245,254,249,254,251,254,253,254,254,254,255,254,0,254,1,254,2,254,3,254,5,254,7,254,11,254,247,255,250,255,252,255,253,255,254,255,255,255,0,255,1,255,2,255,3,255,4,255,6,255,9,255,225,0,233,0,238,0,242,0,245,0,249,0,251,0,252,0,253,0,254,0,255,0,0,225,1,0,2,0,3,0,4,0,5,0,7,0,11,0,14,0,18,0,23,0,31,0,247,1,250,1,252,1,253,1,254,1,255,1,0,1,1,1,2,1,3,1,4,1,6,1,9,1,245,2,249,2,251,2,253,2,254,2,255,2,0,2,1,2,2,2,3,2,5,2,7,2,11,2,248,3,250,3,252,3,254,3,255,3,0,3,1,3,2,3,3,3,4,3,6,3,8,3,243,4,246,4,251,4,253,4,255,4,0,4,1,4,3,4,5,4,10,4,13,4,239,5,249,5,252,5,254,5,0,5,2,5,4,5,7,5,17,5,234,6,247,6,250,6,253,6,255,6,1,6,3,6,6,6,9,6,22,6,251,7,254,7,0,7,2,7,5,7,227,8,245,8,248,8,253,8,3,8,8,8,11,8,29,8,250,9,255,9,1,9,6,9,241,10,252,10,4,10,15,10,248,11,254,11,0,11,2,11,8,11,19,12,237,13,252,13,4,13,0,14,246,15,10,15,251,17,5,17,25,17,231,18,0,18,244,19,13,19,250,22,6,22,0,23,239,25,18,25,248,29,8,29,0,31,0,0,250,234,6,234,243,237,12,237,0,238,251,239,5,239,246,241,10,241,0,242,252,243,4,243,19,243,237,244,248,245,254,245,0,245,2,245,8,245,241,246,252,246,4,246,15,246,250,247,255,247,1,247,6,247,245,248,248,248,253,248,0,248,3,248,8,248,11,248,251,249,254,249,0,249,2,249,5,249,234,250,247,250,250,250,253,250,255,250,1,250,3,250,6,250,9,250,22,250,239,251,249,251,252,251,254,251,255,251,0,251,1,251,2,251,4,251,7,251,17,251,243,252,246,252,251,252,253,252,254,252,255,252,0,252,1,252,2,252,3,252,5,252,10,252,13,252,248,253,250,253,252,253,253,253,254,253,255,253,0,253,1,253,2,253,3,253,4,253,6,253,8,253,245,254,249,254,251,254,252,254,253,254,254,254,255,254,0,254,1,254,2,254,3,254,4,254,5,254,7,254,11,254,247,255,250,255,251,255,252,255,253,255,254,255,255,255,0,255,1,255,2,255,3,255,4,255,5,255,6,255,9,255,233,0,238,0,242,0,245,0,249,0,251,0,252,0,253,0,254,0,255,0,0,233,1,0,2,0,3,0,4,0,5,0,7,0,11,0,14,0,18,0,23,0,247,1,250,1,251,1,252,1,253,1,254,1,255,1,0,1,1,1,2,1,3,1,4,1,5,1,6,1,9,1,245,2,249,2,251,2,252,2,253,2,254,2,255,2,0,2,1,2,2,2,3,2,4,2,5,2,7,2,11,2,248,3,250,3,252,3,253,3,254,3,255,3,0,3,1,3,2,3,3,3,4,3,6,3,8,3,243,4,246,4,251,4,253,4,254,4,255,4,0,4,1,4,2,4,3,4,5,4,10,4,13,4,239,5,249,5,252,5,254,5,255,5,0,5,1,5,2,5,4,5,7,5,17,5,234,6,247,6,250,6,253,6,255,6,1,6,3,6,6,6,9,6,22,6,251,7,254,7,0,7,2,7,5,7,245,8,248,8,253,8,0,8,3,8,8,8,11,8,250,9,255,9,1,9,6,9,241,10,252,10,4,10,15,10,248,11,254,11,0,11,2,11,8,11,19,12,237,13,252,13,4,13,0,14,246,15,10,15,251,17,5,17,0,18,244,19,13,19,250,22,6,22,0,23,0,0,0,0,0,0,16,16,16,8,8,16,8,8,8,4,4,8,4,4,4,2,2,4,2,2,2,1,1,2,1,1,8,8,8,4,4,8,4,4,4,2,2,4,2,2,2,1,1,2,1,1,1,1,1,1,1,1,0,0,0,0,1,1,2,253,253,3,4,4,0,1,0,4,4,1,0,1,3,0,0,1,0,4,0,0,1,182,2,255,250,0,0,2,255,251,0,0,2,255,252,0,0,2,255,253,0,0,0,0,152,13,33,0,152,243,32,0,12,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,35,0,108,0,0,0,104,158,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,185,33,0,0,0,0,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,192,151,33,0,0,0,0,0,32,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,119,33,0,0,0,0,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,224,54,33,0,0,0,0,0,40,0,0,0,84,77,70,80,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,64,13,33,0,16,243,32,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,152,215,32,0,16,243,32,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,208,188,32,0,16,243,32,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,112,165,32,0,16,243,32,0,48,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,184,140,32,0,184,115,32,0,44,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,240,92,32,0,184,115,32,0,44,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,8,234,35,0,0,0,0,0,8,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,152,69,32,0,0,0,0,0,16,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,208,13,32,0,0,0,0,0,52,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,133,35,0,108,0,0,0,248,158,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,5,10,7,255,0,1,5,0,3,17,9,16,1,1,1,1,1,1,0,1,1,1,1,1,1,0,9,1,0,1,5,3,8,1,1,1,1,1,1,0,1,1,1,1,1,1,0,0,0,0,0,0,0,2,3,2,2,5,4,5,0,4,1,3,2,6,5,6,0,6,4,1,2,5,3,6,0,5,3,3,1,4,3,5,0,6,5,3,2,4,1,6,0,6,5,3,1,4,2,6,0,1,0,0,0,0,192,0,0,0,192,2,0,0,48,0,0,0,48,2,0,0,240,0,0,0,240,2,0,1,0,1,0,0,192,3,0,0,48,3,0,0,240,3,0,0,0,0,0,254,255,127,185,255,255,187,57,254,255,127,57,3,0,88,185,6,128,56,187,255,63,12,60,0,160,49,188,0,0,0,0,5,96,237,60,0,192,138,189,1,244,192,61,1,160,171,189,4,192,221,60,254,175,114,61,254,161,12,190,253,203,44,62,254,161,12,190,254,175,114,61,4,192,221,60,1,160,171,189,1,244,192,61,0,192,138,189,5,96,237,60,0,0,0,0,0,160,49,188,255,63,12,60,6,128,56,187,3,0,88,185,254,255,127,57,255,255,187,57,254,255,127,185,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,4,0,128,64,0,0,64,32,0,0,32,16,0,0,16,8,0,0,8,4,0,0,4,2,0,0,2,1,0,0,192,0,0,0,129,0,0,0,88,0,0,0,64,0,0,0,56,0,0,0,48,0,0,0,40,0,0,0,36,0,0,0,32,0,0,0,32,240,118,255,0,0,0,0,0,1,2,2,6,3,14,4,30,5,31,5,0,0,0,0,0,1,0,0,2,2,6,3,14,4,15,4,0,0,0,0,0,1,2,2,0,0,6,3,14,4,15,4,0,0,0,0,0,1,0,0,0,0,2,2,6,3,14,4,15,4,0,0,1,2,4,3,5,3,0,2,6,3,7,3,0,0,0,0,1,2,0,0,2,2,0,2,6,3,7,3,0,0,0,0,1,2,2,2,0,0,0,2,6,3,7,3,0,0,0,0,1,2,0,0,0,0,0,2,2,2,6,3,7,3,0,0,112,112,112,112,80,80,0,0,80,80,80,80,80,80,64,64,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,5,7,0,0,0,0,0,0,5,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,5,7,5,7,0,0,0,0,5,7,5,0,0,0,0,0,5,7,6,0,0,0,0,0,5,5,0,0,0,0,0,0,3,0,0,0,0,0,0,0,6,6,0,0,0,0,0,0,2,4,0,0,0,0,0,0,2,4,5,7,0,0,0,0,2,4,5,0,0,0,0,0,2,4,6,0,0,0,0,0,2,4,5,7,5,7,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,1,2,3,0,0,2,0,4,5,0,6,0,0,0,0,0,1,0,0,2,3,0,5,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,192,113,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,5,0,0,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,169,34,0,80,109,34,0,224,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,64,16,0,1,0,48,53,34,0,0,5,34,0,240,214,33,0,0,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,64,16,0,1,0,48,53,34,0,144,178,33,0,80,145,33,0,32,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,64,16,0,1,0,48,53,34,0,16,112,33,0,208,46,33,0,64,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,64,16,0,1,0,48,53,34,0,224,6,33,0,88,236,32,0,208,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,55,64,16,0,1,0,48,53,34,0,240,209,32,0,152,110,140,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,248,160,32,0,152,110,140,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,88,135,32,0,152,110,140,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,112,110,32,0,152,110,140,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,0,88,32,0,152,110,140,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,168,64,32,0,152,110,140,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,168,8,32,0,152,110,140,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,8,240,31,0,152,110,140,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,32,219,31,0,152,110,140,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,80,201,31,0,152,110,140,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,40,179,31,0,152,110,140,0,0,0,0,0,128,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,152,160,31,0,152,110,140,0,0,0,0,0,128,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,104,142,31,0,152,110,140,0,0,0,0,0,128,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,96,125,31,0,152,110,140,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,120,110,31,0,152,110,140,0,0,0,0,0,128,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,200,91,31,0,152,110,140,0,0,0,0,0,128,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,176,48,31,0,152,110,140,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,128,29,31,0,152,110,140,0,0,0,0,0,128,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,96,17,31,0,152,110,140,0,0,0,0,0,128,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,56,2,31,0,152,110,140,0,0,0,0,0,128,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,144,242,30,0,152,110,140,0,0,0,0,0,128,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,88,228,30,0,152,110,140,0,0,0,0,0,128,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,168,215,30,0,152,110,140,0,0,0,0,0,128,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,80,200,30,0,152,110,140,0,0,0,0,0,128,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,48,53,34,0,240,184,30,0,72,168,30,0,244,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,64,127,30,0,152,111,30,0,20,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,232,98,30,0,72,85,30,0,52,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,120,68,30,0,136,57,30,0,84,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,176,46,30,0,176,36,30,0,204,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,232,28,30,0,248,17,30,0,232,1,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,72,239,29,0,176,229,29,0,8,2,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,136,221,29,0,64,212,29,0,40,2,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,168,203,29,0,240,194,29,0,72,2,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,184,187,29,0,200,179,29,0,216,1,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,232,171,29,0,248,161,29,0,180,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,48,130,29,0,16,121,29,0,184,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,94,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,88,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,224,33,0,108,0,0,0,0,166,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,142,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,33,0,72,30,32,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,216,64,31,0,72,30,32,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,8,143,30,0,208,252,29,0,56,0,0,0,3,0,0,0,92,143,194,245,40,92,239,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,24,143,29,0,208,252,29,0,56,0,0,0,3,0,0,0,92,143,194,245,40,92,239,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,80,50,29,0,56,226,28,0,64,0,0,0,3,0,0,0,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,32,222,35,0,56,226,28,0,64,0,0,0,3,0,0,0,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,142,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,64,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,229,33,0,108,0,0,0,64,175,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,255,0,0,0,0,0,0,0,255,0,0,0,0,25,128,128,255,0,0,0,0,20,128,128,255,0,0,0,0,16,128,128,255,0,0,0,0,19,128,128,255,0,0,0,0,1,2,3,6,7,8,11,12,13,0,0,0,0,0,0,0,1,3,6,8,9,10,10,11,11,12,12,13,13,3,4,6,7,8,8,9,10,10,10,11,12,12,6,6,7,8,8,9,10,10,10,11,12,12,12,8,7,8,9,9,10,10,11,11,11,12,12,13,9,8,9,9,10,10,11,11,11,12,12,12,13,10,9,9,10,11,11,11,12,11,12,12,13,13,11,9,10,11,11,11,12,12,12,12,13,13,13,11,10,10,11,11,12,12,13,13,13,13,13,13,11,10,10,11,11,11,12,12,13,13,14,13,14,11,10,11,11,12,12,12,12,13,13,14,14,14,12,11,11,12,12,12,13,13,13,14,14,14,15,12,11,12,12,12,13,13,13,13,14,14,15,15,13,12,12,12,13,13,13,13,14,14,14,14,15,0,0,0,0,0,0,0,5,4,5,6,7,8,9,10,4,3,4,5,6,7,7,8,5,4,4,5,6,7,7,8,6,5,5,6,6,7,8,8,7,6,6,6,7,7,8,9,8,7,6,7,7,8,8,10,9,7,7,8,8,8,9,9,10,8,8,8,9,9,9,10,1,3,6,7,8,9,10,11,3,4,6,7,8,8,9,9,6,6,7,8,8,9,9,10,7,7,8,8,9,9,10,10,8,8,9,9,10,10,10,11,9,8,9,9,10,10,11,11,10,9,9,10,10,11,12,12,11,10,10,10,11,11,12,12,11,10,9,9,9,9,9,10,11,10,9,8,7,7,7,8,9,10,9,8,6,6,6,6,6,8,9,9,7,6,4,4,4,6,7,9,9,7,6,4,4,4,6,7,9,9,7,6,4,4,4,6,7,9,9,8,6,6,6,6,6,8,9,10,9,8,7,7,7,7,8,10,11,10,9,9,9,9,9,10,11,0,0,0,0,0,0,0,13,12,11,11,10,11,11,12,13,12,11,10,9,8,9,10,11,12,12,10,9,8,7,8,9,10,11,11,9,8,5,4,5,8,9,11,10,8,7,4,1,4,7,8,11,11,9,8,5,4,5,8,9,11,11,10,9,8,7,8,9,10,11,12,11,10,9,8,9,10,11,12,13,12,12,11,10,10,11,12,13,0,0,0,0,0,0,0,4,5,8,5,4,8,9,8,11,5,5,8,5,4,8,8,7,10,9,8,11,8,8,10,11,10,11,4,5,8,4,4,8,8,8,10,4,4,8,4,4,7,8,7,9,8,8,10,7,7,9,10,9,10,8,8,11,8,7,10,11,10,12,8,7,10,7,7,9,10,9,11,11,10,12,10,9,11,11,10,11,0,0,0,0,0,0,0,1,4,8,4,5,8,9,9,10,4,6,9,6,6,9,9,9,10,9,10,13,9,9,11,11,10,12,4,6,10,6,7,10,10,10,12,5,7,11,6,7,10,9,9,11,9,10,13,8,9,12,10,11,12,8,10,15,9,11,15,13,14,16,8,10,14,9,10,14,12,12,15,11,12,16,10,11,15,12,12,15,0,0,0,0,0,0,0,9,7,9,8,6,8,9,8,9,8,6,7,6,5,6,7,6,8,9,7,8,8,6,8,9,7,9,8,6,7,6,5,6,7,6,8,6,5,6,5,3,5,6,5,6,8,6,7,6,5,6,8,6,8,9,7,9,8,6,8,8,7,9,8,6,7,6,4,6,8,6,7,9,7,9,7,6,8,9,7,9,0,0,0,0,0,0,0,4,5,6,7,8,8,9,10,10,10,11,11,12,11,12,12,10,5,4,5,6,7,7,8,8,9,9,9,10,10,10,10,11,8,6,5,5,6,7,7,8,8,8,9,9,9,10,10,10,10,8,7,6,6,6,7,7,8,8,8,9,9,9,10,10,10,10,8,8,7,7,7,7,8,8,8,8,9,9,9,10,10,10,10,8,8,7,7,7,7,8,8,8,9,9,9,9,10,10,10,10,8,9,8,8,8,8,8,8,8,9,9,9,10,10,10,10,10,8,9,8,8,8,8,8,8,9,9,9,10,10,10,10,10,10,8,10,9,8,8,9,9,9,9,9,10,10,10,10,10,10,11,8,10,9,9,9,9,9,9,9,10,10,10,10,10,10,11,11,8,11,9,9,9,9,9,9,10,10,10,10,10,11,10,11,11,8,11,10,9,9,10,9,10,10,10,10,10,11,11,11,11,11,8,11,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,9,11,10,9,9,10,10,10,10,10,10,11,11,11,11,11,11,9,11,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,9,12,10,10,10,10,10,10,10,11,11,11,11,11,11,12,12,9,9,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,5,0,0,0,0,0,0,0,6,5,6,6,7,8,9,10,10,10,11,11,12,5,4,4,5,6,7,7,8,8,9,10,10,11,6,4,5,5,6,6,7,8,8,9,9,10,10,6,5,5,5,6,7,7,8,8,9,9,10,10,7,6,6,6,6,7,7,8,8,9,9,10,10,8,7,6,7,7,7,8,8,8,9,10,10,11,9,7,7,7,7,8,8,9,9,9,10,10,11,9,8,8,8,8,8,9,9,9,10,10,11,11,9,8,8,8,8,8,9,9,10,10,10,11,11,10,9,9,9,9,9,9,10,10,10,11,11,12,10,9,9,9,9,10,10,10,10,11,11,11,12,11,10,9,10,10,10,10,10,11,11,11,11,12,11,10,10,10,10,10,10,11,11,12,12,12,12,0,0,0,0,0,0,0,11,9,11,10,7,10,11,9,11,10,7,10,7,5,7,9,7,10,11,9,11,9,7,9,11,9,11,9,7,9,7,5,7,9,7,9,7,5,7,5,1,5,7,5,7,9,7,9,7,5,7,9,7,9,11,9,11,9,7,9,11,9,11,10,7,9,7,5,7,9,7,10,11,9,11,10,7,9,11,9,11,0,0,0,0,0,0,0,232,3,0,0,52,8,0,0,172,13,0,0,24,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,8,0,0,0,24,0,0,0,4,0,0,0,20,0,0,0,12,0,0,0,28,0,0,0,2,0,0,0,18,0,0,0,10,0,0,0,26,0,0,0,6,0,0,0,22,0,0,0,14,0,0,0,30,0,0,0,1,0,0,0,17,0,0,0,9,0,0,0,25,0,0,0,5,0,0,0,21,0,0,0,13,0,0,0,29,0,0,0,3,0,0,0,19,0,0,0,11,0,0,0,27,0,0,0,7,0,0,0,23,0,0,0,15,0,0,0,31,0,0,0,0,0,0,0,16,0,0,0,8,0,0,0,24,0,0,0,4,0,0,0,20,0,0,0,12,0,0,0,28,0,0,0,2,0,0,0,18,0,0,0,10,0,0,0,26,0,0,0,6,0,0,0,22,0,0,0,14,0,0,0,30,0,0,0,1,0,0,0,17,0,0,0,9,0,0,0,25,0,0,0,5,0,0,0,21,0,0,0,13,0,0,0,29,0,0,0,3,0,0,0,19,0,0,0,11,0,0,0,27,0,0,0,7,0,0,0,23,0,0,0,15,0,0,0,31,0,0,0,3,5,7,9,13,17,25,33,65,129,0,0,0,0,0,0,255,254,253,252,250,248,244,240,224,192,0,0,0,0,0,0,2,0,0,0,0,0,0,4,3,3,0,0,0,0,5,5,4,0,0,0,0,6,5,6,0,0,0,0,7,6,5,0,0,0,0,9,8,7,9,8,8,8,9,9,8,9,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,0,0,72,193,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,193,25,0,16,193,25,0,0,193,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,187,25,0,24,187,25,0,8,187,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,186,25,0,168,186,25,0,144,186,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,200,25,0,176,200,25,0,144,200,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,199,25,0,152,199,25,0,112,199,25,0,72,199,25,0,32,199,25,0,248,198,25,0,208,198,25,0,0,0,0,0,184,197,25,0,128,197,25,0,72,197,25,0,16,197,25,0,216,196,25,0,160,196,25,0,104,196,25,0,0,0,0,0,8,195,25,0,192,194,25,0,120,194,25,0,48,194,25,0,232,193,25,0,160,193,25,0,88,193,25,0,0,0,0,0,128,190,25,0,248,189,25,0,112,189,25,0,232,188,25,0,96,188,25,0,216,187,25,0,80,187,25,0,0,0,0,0,16,208,25,0,8,207,25,0,0,206,25,0,248,204,25,0,240,203,25,0,232,202,25,0,224,201,25,0,0,0,0,0,80,193,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,193,25,0,56,193,25,0,48,193,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,187,25,0,64,187,25,0,56,187,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,186,25,0,232,186,25,0,216,186,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,201,25,0,0,201,25,0,240,200,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,200,25,0,96,200,25,0,72,200,25,0,48,200,25,0,24,200,25,0,0,200,25,0,232,199,25,0,0,0,0,0,176,198,25,0,144,198,25,0,112,198,25,0,80,198,25,0,48,198,25,0,16,198,25,0,240,197,25,0,0,0,0,0,64,196,25,0,24,196,25,0,240,195,25,0,200,195,25,0,160,195,25,0,120,195,25,0,80,195,25,0,0,0,0,0,184,192,25,0,112,192,25,0,40,192,25,0,224,191,25,0,152,191,25,0,80,191,25,0,8,191,25,0,0,0,0,0,72,212,25,0,192,211,25,0,56,211,25,0,176,210,25,0,40,210,25,0,160,209,25,0,24,209,25,0,0,0,0,0,28,0,15,0,2,0,7,0,2,0,0,0,6,0,6,0,29,0,0,0,0,0,0,0,24,0,26,0,2,0,7,0,2,0,0,0,3,0,27,0,25,0,0,0,0,0,0,0,48,0,25,0,9,0,5,0,0,0,7,0,13,0,8,0,49,0,0,0,0,0,0,0,6,5,3,3,2,2,3,4,6,0,0,0,0,0,0,0,5,5,3,3,2,2,3,5,5,0,0,0,0,0,0,0,6,5,4,3,1,3,4,4,6,0,0,0,0,0,0,0,0,0,2,0,1,0,3,0,2,0,3,0,1,0,0,0,20,0,11,0,0,0,3,0,1,0,4,0,21,0,0,0,30,0,14,0,5,0,0,0,6,0,4,0,31,0,0,0,4,4,2,2,2,4,4,0,5,4,2,2,2,3,5,0,5,4,3,1,3,3,5,0,12,1,138,3,8,6,134,7,132,0,135,0,2,3,5,3,64,0,224,0,227,0,131,1,30,0,94,0,158,0,222,0,241,0,17,0,57,0,97,0,121,0,9,0,29,0,49,0,61,0,5,0,15,0,25,0,31,0,3,0,6,0,10,0,14,0,11,0,8,0,4,0,0,0,26,0,18,0,10,0,2,0,54,0,38,0,22,0,6,0,110,0,78,0,46,0,14,0,223,0,159,0,95,0,31,0,224,1,128,1,225,0,65,0,194,3,3,3,196,1,133,0,135,7,9,6,139,3,13,1,0,0,0,0,0,0,224,15,226,15,232,15,234,15,236,15,238,15,240,15,242,15,244,15,242,47,242,7,251,7,246,3,250,11,253,11,255,1,255,5,252,2,124,0,124,1,60,0,188,0,28,0,92,0,12,0,44,0,4,0,20,0,0,0,8,0,14,0,2,0,6,0,3,0,15,0,9,0,1,0,21,0,5,0,45,0,13,0,93,0,29,0,189,0,61,0,125,1,125,0,253,2,252,0,252,5,250,1,251,11,247,3,248,23,243,7,243,47,245,15,243,15,241,15,239,15,237,15,235,15,233,15,227,15,225,15,0,0,0,0,0,0,44,3,50,3,120,3,126,3,140,0,74,1,136,1,151,1,158,1,189,1,68,0,71,0,170,0,197,0,205,0,220,0,28,0,44,0,83,0,99,0,104,0,8,0,15,0,23,0,43,0,53,0,5,0,9,0,22,0,28,0,6,0,15,0,4,0,0,0,7,0,29,0,23,0,10,0,6,0,54,0,48,0,40,0,16,0,9,0,105,0,100,0,84,0,45,0,29,0,221,0,206,0,202,0,171,0,164,0,69], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1676485);
/* memory initializer */ allocate([0,190,1,159,1,152,1,137,1,75,1,141,0,127,3,121,3,51,3,45,3,0,0,0,0,0,0,176,112,178,112,180,112,82,40,91,56,46,20,46,28,21,10,20,14,20,2,4,7,4,1,11,1,131,3,131,0,67,1,195,1,67,0,162,0,226,0,34,0,82,0,114,0,18,0,42,0,58,0,10,0,22,0,30,0,6,0,12,0,0,0,4,0,1,0,13,0,7,0,31,0,23,0,11,0,59,0,43,0,19,0,115,0,83,0,35,0,227,0,163,0,160,0,64,0,192,1,132,0,132,3,132,2,5,1,5,7,21,2,21,14,22,10,47,28,47,20,40,20,83,40,181,112,179,112,177,112,0,0,0,0,0,0,92,4,47,2,245,3,188,1,251,1,89,0,208,0,223,0,10,0,45,0,47,0,82,0,105,0,120,0,127,0,10,0,16,0,28,0,35,0,42,0,53,0,58,0,61,0,0,0,3,0,6,0,9,0,12,0,15,0,18,0,22,0,24,0,28,0,25,0,23,0,19,0,16,0,13,0,10,0,7,0,4,0,1,0,62,0,59,0,54,0,43,0,40,0,29,0,17,0,11,0,4,0,121,0,110,0,83,0,68,0,46,0,11,0,252,0,209,0,138,0,88,0,189,1,22,1,244,3,93,4,0,0,0,0,0,0,140,10,71,5,181,1,8,0,219,0,82,1,5,0,11,0,142,0,174,0,228,0,3,0,55,0,57,0,85,0,108,0,115,0,3,0,21,0,29,0,40,0,48,0,55,0,62,0,6,0,11,0,15,0,18,0,22,0,25,0,29,0,1,0,4,0,2,0,30,0,26,0,23,0,19,0,16,0,12,0,7,0,63,0,56,0,49,0,41,0,34,0,26,0,20,0,0,0,109,0,86,0,70,0,56,0,4,0,229,0,175,0,143,0,108,0,10,0,83,1,80,1,9,0,162,2,180,1,141,10,0,0,0,0,0,0,92,158,94,158,44,79,148,39,196,19,68,30,227,9,35,15,243,4,146,7,126,2,206,3,61,1,229,1,156,0,204,0,64,0,88,0,103,0,30,0,33,0,45,0,61,0,7,0,17,0,20,0,23,0,26,0,28,0,31,0,1,0,4,0,6,0,5,0,2,0,0,0,29,0,27,0,24,0,21,0,18,0,14,0,6,0,50,0,38,0,31,0,120,0,89,0,65,0,205,0,157,0,230,1,62,1,207,3,127,2,147,7,144,7,240,4,228,9,69,30,197,19,149,39,45,79,95,158,93,158,0,0,0,0,0,0,11,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,0,0,0,0,0,0,0,14,14,14,14,14,14,14,14,14,14,13,13,12,12,12,11,11,10,9,9,8,8,7,7,6,6,5,5,4,4,4,3,3,3,4,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14,14,14,14,14,14,14,14,0,0,0,0,0,0,0,10,10,10,10,9,9,9,9,9,9,8,8,8,8,8,8,7,7,7,7,7,6,6,6,6,6,5,5,5,5,4,4,3,3,4,5,5,5,5,6,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,0,0,0,0,0,0,0,15,15,15,14,14,13,13,12,12,11,11,10,10,10,9,9,9,8,8,8,7,7,7,6,6,6,5,5,5,4,4,3,3,3,4,4,5,5,5,6,6,6,7,7,7,8,8,8,8,9,9,10,10,10,11,11,12,12,13,13,13,14,15,15,15,0,0,0,0,0,0,0,11,10,10,9,9,8,8,8,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,8,8,8,8,9,9,10,11,0,0,0,0,0,0,0,12,11,10,9,9,9,8,8,8,8,8,7,7,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,4,4,4,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,7,7,7,7,7,8,8,8,8,8,9,9,9,10,10,12,0,0,0,0,0,0,0,16,16,15,14,13,13,12,12,11,11,10,10,9,9,8,8,7,7,7,6,6,6,6,5,5,5,5,5,5,5,4,4,4,4,4,4,5,5,5,5,5,5,5,6,6,6,7,7,7,8,8,9,9,10,10,11,11,11,12,13,13,14,15,16,16,0,0,0,0,0,0,0,7,0,5,0,0,0,4,0,6,0,0,0,0,0,0,0,7,0,1,0,2,0,0,0,6,0,0,0,0,0,0,0,15,0,6,0,0,0,2,0,14,0,0,0,0,0,0,0,3,3,1,3,3,0,0,0,3,2,2,2,3,0,0,0,4,3,1,2,4,0,0,0,3,0,0,0,2,0,0,0,2,1,2,0,0,0,0,0,132,2,66,0,64,1,67,1,62,0,190,0,17,0,81,0,9,0,41,0,5,0,21,0,0,0,8,0,14,0,2,0,6,0,3,0,15,0,9,0,1,0,22,0,6,0,46,0,14,0,94,0,30,0,191,0,63,0,32,0,65,1,67,0,133,2,0,0,0,0,0,0,36,7,147,3,206,1,229,0,44,0,8,0,23,0,62,0,5,0,20,0,29,0,0,0,3,0,6,0,8,0,11,0,13,0,12,0,9,0,7,0,4,0,1,0,30,0,21,0,10,0,63,0,56,0,9,0,45,0,230,0,207,1,200,1,37,7,0,0,0,0,0,0,200,1,230,1,100,0,226,0,229,0,48,0,51,0,115,0,122,0,26,0,58,0,2,0,26,0,31,0,7,0,1,0,2,0,2,0,12,0,0,0,27,0,3,0,59,0,27,0,123,0,120,0,112,0,49,0,242,0,227,0,101,0,231,1,201,1,0,0,0,0,0,0,248,58,250,58,126,29,188,14,92,7,172,3,212,1,148,0,20,0,75,0,11,0,59,0,19,0,3,0,15,0,5,0,1,0,6,0,0,0,8,0,28,0,4,0,36,0,116,0,21,0,149,0,213,1,173,3,93,7,189,14,127,29,251,58,249,58,0,0,0,0,0,0,204,0,103,0,5,0,112,0,3,0,26,0,57,0,63,0,10,0,18,0,24,0,29,0,1,0,3,0,7,0,10,0,13,0,11,0,8,0,4,0,2,0,30,0,25,0,19,0,11,0,0,0,62,0,27,0,24,0,113,0,50,0,4,0,205,0,0,0,0,0,0,0,12,3,135,1,109,0,40,0,55,0,102,0,21,0,49,0,0,0,11,0,18,0,26,0,1,0,7,0,10,0,14,0,1,0,15,0,11,0,8,0,4,0,27,0,19,0,12,0,1,0,50,0,26,0,103,0,96,0,41,0,194,0,108,0,13,3,0,0,0,0,0,0,128,21,130,21,194,10,98,5,178,2,94,1,173,0,84,0,28,0,60,0,15,0,31,0,8,0,11,0,13,0,0,0,2,0,1,0,14,0,12,0,9,0,6,0,20,0,61,0,29,0,85,0,174,0,95,1,179,2,99,5,195,10,131,21,129,21,0,0,0,0,0,0,10,9,9,9,8,8,7,7,6,6,5,5,4,4,4,3,3,3,4,4,4,5,5,6,6,7,7,8,8,8,9,9,10,0,0,0,0,0,0,0,11,10,9,8,7,6,6,6,5,5,5,4,4,4,4,4,4,4,4,4,4,4,5,5,5,6,6,6,7,8,9,9,11,0,0,0,0,0,0,0,9,9,8,8,8,7,7,7,7,6,6,5,5,5,4,3,2,3,4,4,5,5,6,6,7,7,7,7,8,8,8,9,9,0,0,0,0,0,0,0,14,14,13,12,11,10,9,8,7,7,6,6,5,4,4,3,2,3,3,4,5,5,6,7,7,8,9,10,11,12,13,14,14,0,0,0,0,0,0,0,9,8,7,7,6,6,6,6,5,5,5,5,4,4,4,4,4,4,4,4,4,5,5,5,5,5,6,6,6,7,7,7,9,0,0,0,0,0,0,0,10,9,8,7,7,7,6,6,5,5,5,5,4,4,4,4,3,4,4,4,4,5,5,5,5,6,6,7,7,7,8,8,10,0,0,0,0,0,0,0,13,13,12,11,10,9,8,7,6,6,5,5,4,4,4,3,3,3,4,4,4,4,5,6,6,7,8,9,10,11,12,13,13,0,0,0,0,0,0,0,168,3,174,3,213,1,148,0,20,0,75,0,11,0,59,0,19,0,3,0,15,0,5,0,1,0,6,0,0,0,8,0,28,0,4,0,36,0,116,0,21,0,149,0,214,1,175,3,169,3,0,0,0,0,0,0,36,3,147,1,206,0,101,0,36,0,12,0,19,0,4,0,7,0,10,0,13,0,15,0,1,0,0,0,14,0,11,0,8,0,5,0,24,0,13,0,37,0,102,0,207,0,200,0,37,3,0,0,0,0,0,0,60,0,146,0,24,0,31,0,78,0,13,0,37,0,4,0,16,0,0,0,10,0,2,0,3,0,3,0,11,0,1,0,17,0,5,0,38,0,14,0,79,0,72,0,25,0,147,0,61,0,0,0,0,0,0,0,128,7,130,7,194,3,226,1,254,0,121,0,61,0,28,0,12,0,4,0,0,0,6,0,2,0,7,0,1,0,5,0,13,0,29,0,62,0,126,0,255,0,227,1,195,3,131,7,129,7,0,0,0,0,0,0,76,0,39,0,109,0,40,0,55,0,14,0,21,0,0,0,5,0,8,0,11,0,14,0,1,0,15,0,12,0,9,0,6,0,1,0,26,0,15,0,8,0,41,0,18,0,108,0,77,0,0,0,0,0,0,0,28,0,15,0,5,0,0,0,48,0,54,0,14,0,25,0,1,0,8,0,14,0,1,0,5,0,2,0,15,0,9,0,6,0,26,0,15,0,55,0,49,0,1,0,6,0,4,0,29,0,0,0,0,0,0,0,84,40,43,20,11,5,67,1,162,0,82,0,46,0,21,0,4,0,14,0,0,0,3,0,6,0,4,0,1,0,15,0,5,0,22,0,47,0,83,0,163,0,160,0,132,2,20,10,85,40,0,0,0,0,0,0,10,10,9,8,7,7,6,6,5,4,4,3,2,3,3,4,5,5,6,7,7,8,9,10,10,0,0,0,0,0,0,0,10,9,8,7,6,5,5,4,4,4,4,4,3,3,4,4,4,4,5,5,6,7,8,8,10,0,0,0,0,0,0,0,8,8,7,7,7,6,6,5,5,4,4,3,2,3,4,4,5,5,6,6,7,7,7,8,8,0,0,0,0,0,0,0,12,12,11,10,9,8,7,6,5,4,3,3,2,3,3,4,5,6,7,8,9,10,11,12,12,0,0,0,0,0,0,0,8,7,7,6,6,5,5,4,4,4,4,4,3,4,4,4,4,4,5,5,5,6,6,7,8,0,0,0,0,0,0,0,9,8,7,6,6,6,5,5,4,4,4,3,3,3,4,4,4,5,5,6,6,6,7,7,9,0,0,0,0,0,0,0,14,13,11,9,8,7,6,5,4,4,3,3,3,3,3,4,4,5,6,7,8,8,10,12,14,0,0,0,0,0,0,0,96,0,126,0,49,0,25,0,13,0,4,0,0,0,6,0,2,0,7,0,1,0,5,0,14,0,30,0,62,0,127,0,97,0,0,0,0,0,0,0,4,0,3,0,30,0,1,0,1,0,14,0,1,0,4,0,6,0,5,0,2,0,15,0,6,0,14,0,31,0,0,0,5,0,0,0,0,0,0,0,232,0,246,0,117,0,52,0,59,0,27,0,31,0,4,0,0,0,5,0,12,0,28,0,60,0,53,0,122,0,247,0,233,0,0,0,0,0,0,0,0,1,2,1,130,0,66,0,34,0,18,0,10,0,6,0,0,0,7,0,11,0,19,0,35,0,67,0,131,0,3,1,1,1,0,0,0,0,0,0,44,0,23,0,5,0,28,0,3,0,10,0,15,0,3,0,6,0,4,0,0,0,11,0,4,0,29,0,10,0,4,0,45,0,0,0,0,0,0,0,124,0,63,0,25,0,13,0,28,0,8,0,15,0,5,0,0,0,6,0,2,0,9,0,29,0,14,0,30,0,24,0,125,0,0,0,0,0,0,0,84,1,171,0,43,0,11,0,3,0,10,0,1,0,6,0,1,0,7,0,4,0,11,0,0,0,4,0,20,0,84,0,85,1,0,0,0,0,0,0,8,8,7,6,5,4,3,3,2,3,3,4,5,6,7,8,8,0,0,0,0,0,0,0,8,7,6,5,4,4,3,3,3,3,3,4,4,5,6,6,8,0,0,0,0,0,0,0,8,8,7,6,6,5,5,3,1,3,4,5,6,6,7,8,8,0,0,0,0,0,0,0,9,9,8,7,6,5,4,3,1,3,4,5,6,7,8,9,9,0,0,0,0,0,0,0,7,6,5,5,4,4,4,3,3,3,3,4,4,5,5,5,7,0,0,0,0,0,0,0,8,7,6,5,5,4,4,3,2,3,3,4,5,5,6,6,8,0,0,0,0,0,0,0,12,11,9,7,5,4,3,3,2,3,3,4,4,6,8,10,12,0,0,0,0,0,0,0,4,0,26,0,3,0,14,0,0,0,3,0,5,0,4,0,2,0,15,0,12,0,27,0,5,0,0,0,0,0,0,0,56,0,16,0,29,0,7,0,15,0,5,0,0,0,6,0,2,0,9,0,6,0,17,0,57,0,0,0,0,0,0,0,112,0,46,0,57,0,29,0,12,0,15,0,0,0,4,0,13,0,10,0,22,0,47,0,113,0,0,0,0,0,0,0,5,5,4,4,3,3,3,3,3,4,4,5,5,0,0,0,6,5,5,4,4,3,2,3,3,4,4,5,6,0,0,0,7,6,6,5,4,4,1,3,4,4,5,6,7,0,0,0,9,7,7,9,9,0,0,0,0,0,2,0,6,0,14,0,30,0,62,0,255,0,254,0,251,1,250,1,249,1,248,1,1,0,0,0,2,0,15,0,12,0,29,0,57,0,56,0,55,0,54,0,53,0,52,0,0,0,7,0,5,0,4,0,2,0,13,0,12,0,6,0,15,0,29,0,57,0,56,0,3,0,2,0,0,0,2,0,6,0,14,0,30,0,62,0,126,0,254,0,255,1,254,1,1,0,0,0,2,0,6,0,14,0,63,0,61,0,124,0,121,0,120,0,251,0,250,0,1,2,3,4,5,6,8,8,9,9,9,9,1,2,3,5,5,6,7,7,7,7,7,7,2,3,3,3,3,4,4,4,5,6,7,7,2,2,2,3,4,5,6,7,8,9,10,10,1,2,3,4,5,7,7,8,8,8,9,9,0,0,0,0,32,30,94,30,28,3,26,5,24,7,22,9,20,11,18,13,17,15,144,0,143,1,142,2,141,3,140,4,139,5,138,6,137,7,73,0,200,0,72,1,199,1,71,2,198,2,70,3,197,3,37,0,101,0,165,0,228,0,36,1,100,1,164,1,227,1,19,0,51,0,83,0,115,0,147,0,179,0,211,0,243,0,10,0,26,0,42,0,58,0,74,0,90,0,106,0,122,0,6,0,14,0,22,0,30,0,38,0,46,0,54,0,62,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,0,0,29,0,25,0,21,0,17,0,13,0,9,0,5,0,63,0,55,0,47,0,39,0,31,0,23,0,15,0,7,0,123,0,107,0,91,0,75,0,59,0,43,0,27,0,11,0,8,0,240,0,208,0,176,0,144,0,112,0,80,0,48,0,228,1,165,1,101,1,37,1,229,0,226,0,162,0,98,0,202,3,71,3,199,2,196,2,68,2,73,1,201,0,198,0,150,7,139,6,136,6,141,4,138,4,143,2,140,2,145,0,46,15,19,13,21,11,23,9,25,7,27,5,29,3,95,30,33,30,0,0,0,0,0,0,44,118,23,59,85,21,8,6,171,10,242,15,5,3,7,3,99,7,70,0,12,1,188,1,171,2,182,3,253,3,128,0,135,0,223,0,86,1,217,1,248,1,255,1,42,0,65,0,97,0,148,0,212,0,234,0,242,0,253,0,9,0,11,0,26,0,38,0,49,0,64,0,75,0,107,0,115,0,119,0,122,0,124,0,0,0,2,0,6,0,8,0,11,0,14,0,17,0,20,0,22,0,25,0,28,0,30,0,33,0,35,0,38,0,40,0,43,0,45,0,47,0,49,0,51,0,54,0,56,0,55,0,52,0,50,0,48,0,46,0,44,0,41,0,39,0,36,0,34,0,31,0,29,0,26,0,23,0,21,0,18,0,15,0,12,0,9,0,7,0,3,0,1,0,125,0,123,0,120,0,116,0,114,0,84,0,65,0,54,0,39,0,27,0,20,0,10,0,254,0,243,0,235,0,213,0,149,0,110,0,66,0,43,0,16,0,249,1,218,1,87,1,84,1,192,0,129,0,34,0,183,3,176,3,189,1,13,1,71,0,248,7,84,5,6,3,243,15,196,14,9,6,138,29,84,21,45,118,0,0,0,0,0,0,60,161,32,199,63,161,62,161,61,161,34,231,144,80,147,99,146,115,73,40,206,49,206,57,37,20,229,24,229,28,68,8,28,10,124,12,108,3,35,4,15,5,63,6,183,1,22,2,133,2,29,3,157,3,9,1,64,1,128,1,200,1,207,1,122,0,138,0,162,0,193,0,229,0,20,0,55,0,67,0,78,0,86,0,97,0,108,0,124,0,11,0,28,0,31,0,35,0,37,0,41,0,44,0,46,0,50,0,52,0,55,0,58,0,60,0,63,0,1,0,3,0,6,0,8,0,10,0,12,0,11,0,9,0,7,0,4,0,2,0,0,0,61,0,59,0,56,0,53,0,51,0,47,0,45,0,42,0,38,0,36,0,32,0,29,0,26,0,125,0,109,0,98,0,87,0,79,0,68,0,60,0,21,0,230,0,198,0,163,0,139,0,123,0,108,0,201,1,129,1,65,1,10,1,218,0,30,3,134,2,23,2,16,2,56,7,56,6,8,5,109,3,125,12,29,10,69,8,230,28,230,24,38,20,207,57,207,49,78,40,147,115,144,115,145,80,35,231,36,199,37,199,34,199,35,199,33,199,0,0,0,0,0,0,152,165,154,165,156,165,158,165,152,197,134,229,204,58,202,82,205,98,72,13,103,29,120,41,103,49,102,57,165,6,188,14,189,20,177,28,80,3,83,3,95,7,95,10,94,12,94,14,174,1,173,3,45,5,45,6,45,7,213,0,212,1,148,2,20,3,148,3,20,0,148,0,20,1,116,1,180,1,244,1,11,0,75,0,139,0,187,0,219,0,251,0,27,0,59,0,83,0,99,0,115,0,3,0,19,0,35,0,47,0,55,0,63,0,7,0,15,0,21,0,25,0,29,0,1,0,5,0,9,0,6,0,2,0,30,0,26,0,22,0,16,0,8,0,0,0,56,0,48,0,40,0,28,0,12,0,124,0,108,0,92,0,68,0,36,0,4,0,228,0,196,0,164,0,116,0,52,0,245,1,181,1,117,1,21,1,149,0,21,0,149,3,21,3,149,2,213,1,214,0,46,7,46,6,46,5,174,3,175,1,95,14,95,12,88,12,88,10,88,7,81,3,178,28,178,24,189,14,178,14,103,57,96,57,121,41,100,41,73,13,194,114,203,82,205,58,135,229,153,197,159,165,157,165,155,165,153,165,0,0,0,0,0,0,92,14,47,7,29,0,36,7,15,0,13,1,36,3,147,3,233,3,128,0,135,0,250,0,100,1,147,1,222,1,245,1,16,0,42,0,65,0,100,0,115,0,142,0,164,0,179,0,214,0,229,0,244,0,251,0,2,0,9,0,19,0,30,0,38,0,44,0,51,0,63,0,65,0,76,0,83,0,94,0,101,0,112,0,115,0,120,0,123,0,126,0,2,0,5,0,7,0,11,0,13,0,17,0,20,0,23,0,26,0,29,0,33,0,36,0,39,0,42,0,45,0,48,0,51,0,54,0,58,0,55,0,52,0,49,0,46,0,43,0,40,0,37,0,34,0,30,0,27,0,24,0,21,0,18,0,14,0,12,0,8,0,6,0,3,0,127,0,124,0,121,0,118,0,113,0,106,0,95,0,88,0,77,0,70,0,64,0,56,0,45,0,39,0,31,0,20,0,18,0,3,0,0,0,245,0,238,0,215,0,200,0,165,0,143,0,124,0,101,0,66,0,43,0,17,0,2,0,223,1,200,1,101,1,251,0,228,0,129,0,6,0,232,3,37,3,202,1,12,1,37,7,150,3,28,0,93,14,0,0,0,0,0,0,220,41,239,20,85,4,156,14,43,2,137,4,64,7,79,7,114,1,69,2,71,2,10,3,161,3,28,0,139,0,214,0,12,1,72,1,79,1,134,1,209,1,8,0,15,0,70,0,93,0,120,0,135,0,150,0,165,0,188,0,216,0,222,0,246,0,5,0,20,0,36,0,47,0,58,0,61,0,73,0,80,0,88,0,95,0,102,0,109,0,117,0,124,0,4,0,11,0,19,0,24,0,27,0,31,0,34,0,38,0,42,0,45,0,49,0,52,0,56,0,59,0,63,0,3,0,6,0,10,0,7,0,4,0,0,0,60,0,57,0,53,0,50,0,46,0,43,0,39,0,35,0,32,0,28,0,25,0,22,0,16,0,5,0,125,0,122,0,110,0,103,0,96,0,89,0,81,0,74,0,66,0,59,0,52,0,37,0,21,0,6,0,247,0,223,0,217,0,189,0,166,0,151,0,144,0,121,0,106,0,71,0,68,0,9,0,210,1,135,1,132,1,73,1,13,1,215,0,184,0,29,0,166,3,11,3,156,2,70,2,115,1,20,1,65,7,58,5,136,4,157,14,118,10,84,4,221,41,0,0,0,0,0,0,96,6,102,6,236,6,34,7,96,7,110,7,76,0,78,0,244,0,10,1,72,1,86,1,212,1,242,1,49,3,112,3,119,3,150,3,177,3,36,0,100,0,123,0,138,0,165,0,212,0,235,0,250,0,154,1,185,1,201,1,217,1,16,0,48,0,51,0,67,0,83,0,107,0,122,0,202,0,210,0,222,0,230,0,246,0,14,0,31,0,35,0,43,0,59,0,63,0,103,0,112,0,119,0,5,0,13,0,18,0,27,0,44,0,53,0,58,0,4,0,11,0,23,0,31,0,9,0,8,0,10,0,0,0,24,0,12,0,5,0,60,0,54,0,45,0,28,0,19,0,14,0,6,0,122,0,113,0,104,0,100,0,60,0,52,0,40,0,32,0,15,0,247,0,231,0,223,0,211,0,203,0,123,0,116,0,84,0,68,0,60,0,49,0,17,0,218,1,202,1,186,1,155,1,251,0,248,0,213,0,170,0,139,0,132,0,101,0,37,0,182,3,151,3,144,3,113,3,50,3,243,1,213,1,87,1,73,1,11,1,245,0,79,0,77,0,111,7,97,7,35,7,237,6,103,6,97,6,0,0,0,0,0,0,13,13,12,12,12,12,12,12,12,11,11,11,11,11,11,11,11,10,10,10,10,10,10,10,10,9,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,4,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,13,13,0,0,0,0,0,0,0,15,14,13,12,12,12,11,11,11,10,10,10,10,10,10,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,10,11,11,11,12,12,12,13,13,15,0,0,0,0,0,0,0,16,16,16,16,16,16,15,15,15,14,14,14,13,13,13,12,12,12,11,11,11,11,10,10,10,10,10,9,9,9,9,9,8,8,8,8,8,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,13,13,13,14,14,14,15,15,15,16,16,16,16,16,16,0,0,0,0,0,0,0,16,16,16,16,16,16,15,15,15,14,14,14,14,14,13,13,13,13,12,12,12,12,12,12,11,11,11,11,11,10,10,10,10,10,9,9,9,9,9,9,8,8,8,8,8,8,7,7,7,7,7,6,6,6,6,6,6,5,5,5,5,5,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,7,7,7,7,7,7,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,10,11,11,11,11,11,12,12,12,12,12,12,13,13,13,13,14,14,14,14,14,15,15,15,16,16,16,16,16,16,0,0,0,0,0,0,0,13,12,11,11,10,10,10,10,10,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,11,11,11,13,0,0,0,0,0,0,0,14,13,12,12,11,11,11,11,10,10,10,10,10,9,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,11,11,11,12,12,12,14,0,0,0,0,0,0,0,11,11,11,11,11,11,10,10,10,10,10,10,10,10,10,10,10,10,10,9,9,9,9,9,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,4,4,4,4,5,5,5,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,0,0,0,0,0,0,0,248,255,255,255,28,0,0,0,40,0,0,0,48,0,0,0,52,0,0,0,60,0,0,0,68,0,0,0,76,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,144,0,0,0,160,0,0,0,176,0,0,0,192,0,0,0,208,0,0,0,224,0,0,0,240,0,0,0,0,1,0,0,16,1,0,0,32,1,0,0,48,1,0,0,64,1,0,0,80,1,0,0,96,1,0,0,112,1,0,0,0,0,0,0,104,166,33,0,0,0,0,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,224,136,33,0,0,0,0,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,104,93,33,0,0,0,0,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,192,32,33,0,0,0,0,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,96,254,32,0,0,0,0,0,80,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,216,228,32,0,0,0,0,0,88,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,37,34,0,108,0,0,0,64,213,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,237,127,183,127,92,127,221,126,59,126,118,125,143,124,134,123,92,122,19,121,0,0,0,0,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,2,2,1,0,1,4,5,2,7,8,3,7,4,9,5,6,7,8,9,10,16,16,16,19,16,19,22,22,22,22,26,24,26,22,22,27,27,27,26,26,26,29,29,29,27,27,27,26,34,34,34,29,29,29,27,27,37,34,34,32,32,29,29,38,37,35,35,34,35,40,40,40,38,38,48,48,46,46,58,56,56,69,69,83,16,17,17,18,18,18,19,19,19,19,20,20,20,20,20,21,21,21,21,21,21,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,24,24,24,25,24,24,24,25,26,26,26,26,25,27,27,27,27,27,28,28,28,28,30,30,30,31,31,33,1,3,3,1,3,3,1,2,1,2,1,1,1,1,1,1,0,0,0,64,197,66,197,88,69,186,158,83,190,139,65,75,0,0,0,64,130,211,72,50,248,244,162,34,223,85,168,17,197,66,197,88,158,215,32,123,242,251,251,115,107,20,98,104,197,66,197,88,116,31,191,69,146,210,10,48,167,226,125,24,69,186,158,83,242,251,251,115,205,60,65,109,19,166,83,98,69,186,158,83,112,40,179,65,205,60,65,45,85,26,18,23,190,139,65,75,107,20,98,104,19,166,83,98,167,226,125,88,190,139,65,75,158,215,32,59,52,112,186,40,38,90,195,20,0,0,0,64,197,66,197,88,69,186,158,83,190,139,65,75,0,0,0,64,130,211,72,50,248,244,162,34,223,85,168,17,130,211,72,50,116,31,191,69,112,40,179,65,158,215,32,59,130,211,72,50,89,29,130,39,45,185,54,27,209,154,223,13,248,244,162,34,146,210,10,48,205,60,65,45,52,112,186,40,248,244,162,34,45,185,54,27,51,195,190,18,78,99,142,9,223,85,168,17,167,226,125,24,85,26,18,23,38,90,195,20,223,85,168,17,209,154,223,13,78,99,142,9,98,40,223,4,4,0,0,0,8,0,0,0,8,0,0,0,5,0,0,0,5,0,0,0,11,0,0,0,11,0,0,0,4,0,0,0,4,0,0,0,7,0,0,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,1,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,2,2,4,4,5,5,5,5,5,5,5,5,5,5,5,5,2,3,3,4,4,4,5,5,5,5,5,5,5,5,5,5,3,3,3,3,4,4,4,4,5,5,5,5,5,5,5,5,3,3,4,4,4,4,4,4,4,4,4,4,5,5,5,5,2,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,1,3,3,5,5,5,6,6,6,6,6,6,6,6,6,6,1,2,5,5,6,6,6,6,6,6,6,6,6,6,6,6,1,3,4,4,5,5,5,5,6,6,6,6,6,6,6,6,2,2,3,4,4,5,5,5,5,5,6,6,6,6,6,6,1,4,4,4,4,5,5,5,5,5,6,6,6,6,6,6,2,2,2,5,5,5,6,6,6,6,6,6,6,6,6,6,1,3,3,3,6,6,6,6,7,7,7,7,7,7,7,7,1,3,3,3,5,6,7,7,7,7,7,7,7,7,7,7,2,2,3,3,3,6,6,6,6,6,7,7,7,7,7,7,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,0,1,3,5,7,9,11,13,15,19,21,23,25,27,29,31,0,2,1,9,5,21,13,29,3,19,11,27,7,23,15,31,0,2,6,1,9,5,13,29,3,19,11,27,7,23,15,31,0,4,2,6,1,9,5,13,3,19,11,27,7,23,15,31,0,4,2,10,6,14,1,9,5,13,3,11,7,23,15,31,0,2,10,6,14,1,9,5,13,3,11,27,7,23,15,31,0,1,5,3,19,11,27,59,7,39,23,55,15,47,31,63,0,1,3,19,11,43,27,59,7,39,23,55,15,47,31,63,0,1,5,13,3,19,11,27,7,39,23,55,15,47,31,63,0,2,1,5,13,3,19,11,27,7,23,55,15,47,31,63,0,1,9,5,13,3,19,11,27,7,23,55,15,47,31,63,0,2,1,3,19,11,27,59,7,39,23,55,15,47,31,63,0,1,5,3,7,39,23,55,15,79,47,111,31,95,63,127,0,1,5,3,7,23,55,119,15,79,47,111,31,95,63,127,0,2,1,5,3,7,39,23,55,15,47,111,31,95,63,127,0,1,8,9,2,3,10,11,4,5,12,13,6,7,14,15,20,21,28,29,22,23,30,31,16,17,24,25,32,33,40,41,34,35,42,43,48,49,56,57,50,51,58,59,18,19,26,27,36,37,44,45,38,39,46,47,52,53,60,61,54,55,62,63,4,8,12,32,0,0,0,0,0,8,16,24,32,40,48,56,57,49,41,33,25,17,9,1,2,10,18,26,34,42,50,58,59,51,43,35,27,19,11,3,4,12,20,28,36,44,52,60,61,53,45,37,29,21,13,5,6,14,22,30,38,46,54,62,63,55,47,39,31,23,15,7,59,58,57,56,48,49,50,51,43,42,41,40,32,33,34,35,27,26,25,24,16,17,18,19,11,10,9,8,0,1,2,3,4,5,6,7,15,14,13,12,20,21,22,23,31,30,29,28,36,37,38,39,47,46,45,44,52,53,54,55,63,62,61,60,25,17,18,26,27,19,11,3,2,10,9,1,0,8,16,24,32,40,48,56,57,49,41,42,50,58,59,51,43,35,34,33,29,21,22,30,31,23,15,7,6,14,13,5,4,12,20,28,36,44,52,60,61,53,45,46,54,62,63,55,47,39,38,37,3,11,2,10,1,9,0,8,16,24,17,25,18,26,19,27,35,43,34,42,33,41,32,40,48,56,49,57,50,58,51,59,60,52,61,53,62,54,63,55,47,39,46,38,45,37,44,36,28,20,29,21,30,22,31,23,15,7,14,6,13,5,12,4,24,25,16,17,8,9,0,1,2,3,10,11,18,19,26,27,28,29,20,21,12,13,4,5,6,7,14,15,22,23,30,31,39,38,47,46,55,54,63,62,61,60,53,52,45,44,37,36,35,34,43,42,51,50,59,58,57,56,49,48,41,40,33,32,0,1,2,3,8,9,10,11,16,17,18,19,24,25,26,27,32,33,34,35,40,41,42,43,48,49,50,51,56,57,58,59,4,5,6,7,12,13,14,15,20,21,22,23,28,29,30,31,36,37,38,39,44,45,46,47,52,53,54,55,60,61,62,63,6,7,15,14,13,5,12,4,3,11,2,10,9,1,0,8,16,24,17,25,18,26,19,27,20,28,21,29,22,30,23,31,39,47,38,46,37,45,36,44,35,43,34,42,33,41,32,40,49,48,56,57,58,50,59,51,60,52,61,53,54,55,63,62,0,1,2,3,4,5,6,7,15,14,13,12,11,10,9,8,16,17,18,19,20,21,22,23,31,30,29,28,27,26,25,24,32,33,34,35,36,37,38,39,47,46,45,44,43,42,41,40,48,49,50,51,52,53,54,55,63,62,61,60,59,58,57,56,0,8,9,1,2,3,11,10,18,19,27,26,25,17,16,24,32,40,41,33,34,35,43,42,50,49,48,56,57,58,59,51,52,60,61,62,63,55,54,53,45,44,36,37,38,46,47,39,31,23,22,30,29,28,20,21,13,12,4,5,6,14,15,7,24,25,16,17,8,9,0,1,2,3,10,11,18,19,26,27,28,29,20,21,12,13,4,5,6,7,14,15,22,23,30,31,38,39,46,47,54,55,62,63,60,61,52,53,44,45,36,37,34,35,42,43,50,51,58,59,56,57,48,49,40,41,32,33,0,8,1,9,2,10,3,11,19,27,18,26,17,25,16,24,32,40,33,41,34,42,35,43,51,59,50,58,49,57,48,56,60,52,61,53,62,54,63,55,47,39,46,38,45,37,44,36,31,23,30,22,29,21,28,20,12,4,13,5,14,6,15,7,0,8,16,24,25,26,27,19,11,3,2,1,9,17,18,10,4,12,20,28,29,30,31,23,15,7,6,5,13,21,22,14,36,44,52,60,61,62,63,55,47,39,38,37,45,53,54,46,32,40,48,56,57,58,59,51,43,35,34,33,41,49,50,42,0,8,9,1,2,3,11,10,19,27,26,18,17,16,24,25,33,32,40,41,42,34,35,43,51,59,58,50,49,57,56,48,52,60,61,53,54,62,63,55,47,39,38,46,45,44,36,37,29,28,20,21,22,30,31,23,14,15,7,6,5,13,12,4,24,16,8,0,1,2,3,11,19,27,26,25,17,10,9,18,28,20,12,4,5,6,7,15,23,31,30,29,21,14,13,22,60,52,44,36,37,38,39,47,55,63,62,61,53,46,45,54,56,48,40,32,33,34,35,43,51,59,58,57,49,42,41,50,0,8,9,1,2,10,18,17,16,24,25,26,27,19,11,3,7,6,14,15,23,22,21,13,5,4,12,20,28,29,30,31,63,62,54,55,47,46,45,53,61,60,52,44,36,37,38,39,56,48,49,57,58,50,42,41,40,32,33,34,35,43,51,59,0,1,8,9,16,17,24,25,32,33,40,41,48,49,56,57,58,59,50,51,42,43,34,35,26,27,18,19,10,11,2,3,4,5,12,13,20,21,28,29,36,37,44,45,52,53,60,61,62,63,54,55,46,47,38,39,30,31,22,23,14,15,6,7,0,0,1,0,21,99,1,0,61,232,1,0,53,165,2,0,123,78,1,0,119,101,1,0,230,241,2,0,76,114,2,0,0,0,1,0,218,238,0,0,2,65,2,0,155,127,1,0,128,190,0,0,30,97,0,0,60,8,1,0,82,165,0,0,136,31,2,0,83,220,1,0,173,127,2,0,151,246,1,0,25,72,1,0,67,167,0,0,49,90,1,0,136,150,0,0,111,52,2,0,229,14,3,0,250,251,1,0,150,192,2,0,0,208,1,0,150,131,2,0,71,146,1,0,170,249,1,0,111,52,2,0,250,251,1,0,83,220,1,0,184,49,2,0,18,47,1,0,108,224,1,0,16,203,0,0,168,25,1,0,140,196,1,0,72,151,1,0,134,78,1,0,175,34,1,0,40,198,2,0,32,127,2,0,181,151,2,0,50,63,2,0,0,80,2,0,107,171,1,0,34,209,1,0,179,89,1,0,105,38,1,0,67,141,0,0,31,238,0,0,237,117,0,0,12,73,1,0,136,2,1,0,53,247,0,0,81,239,0,0,241,224,0,0,173,114,0,0,216,164,0,0,23,101,0,0,85,85,1,0,113,217,1,0,252,138,2,0,241,134,3,0,249,189,1,0,159,220,1,0,51,237,3,0,17,67,3,0,85,85,1,0,120,62,1,0,88,1,3,0,122,255,1,0,0,254,0,0,125,129,0,0,79,96,1,0,109,220,0,0,181,212,2,0,25,123,2,0,231,84,3,0,31,158,2,0,119,181,1,0,4,223,0,0,150,205,1,0,182,200,0,0,149,240,2,0,220,19,4,0,78,165,2,0,115,171,3,0,171,106,2,0,30,90,3,0,94,24,2,0,56,162,2,0,149,240,2,0,78,165,2,0,25,123,2,0,245,236,2,0,24,148,1,0,144,128,2,0,192,14,1,0,138,119,1,0,102,91,2,0,11,31,2,0,9,190,1,0,148,131,1,0,224,178,3,0,42,84,3,0,241,116,3,0,238,254,2,0,85,21,3,0,228,57,2,0,45,108,2,0,238,204,1,0,140,136,1,0,89,188,0,0,126,61,1,0,60,157,0,0,187,182,1,0,181,88,1,0,156,73,1,0,23,63,1,0,236,43,1,0,230,152,0,0,203,219,0,0,201,134,0,0,171,170,1,0,206,79,2,0,187,45,3,0,173,104,4,0,120,45,2,0,199,83,2,0,127,232,4,0,213,19,4,0,171,170,1,0,22,142,1,0,174,193,3,0,88,127,2,0,128,61,1,0,220,161,0,0,99,184,1,0,136,19,1,0,226,137,3,0,223,25,3,0,33,42,4,0,167,69,3,0,212,34,2,0,197,22,1,0,252,64,2,0,227,250,0,0,186,172,3,0,211,24,5,0,161,78,3,0,79,150,4,0,85,5,3,0,165,48,4,0,118,158,2,0,197,74,3,0,186,172,3,0,161,78,3,0,223,25,3,0,51,168,3,0,30,249,1,0,180,32,3,0,112,82,1,0,109,213,1,0,63,242,2,0,206,166,2,0,139,45,2,0,121,228,1,0,152,159,4,0,53,41,4,0,45,82,4,0,169,190,3,0,171,218,3,0,93,200,2,0,56,7,3,0,42,64,2,0,175,234,1,0,111,235,0,0,222,140,1,0,138,196,0,0,105,36,2,0,226,174,1,0,2,156,1,0,221,142,1,0,231,118,1,0,32,191,0,0,190,18,1,0,123,168,0,0,0,0,2,0,42,198,2,0,122,208,3,0,105,74,5,0,246,156,2,0,239,202,2,0,204,227,5,0,153,228,4,0,0,0,2,0,180,221,1,0,4,130,4,0,54,255,2,0,1,125,1,0,60,194,0,0,119,16,2,0,163,74,1,0,15,63,4,0,166,184,3,0,90,255,4,0,46,237,3,0,50,144,2,0,134,78,1,0,97,180,2,0,17,45,1,0,223,104,4,0,202,29,6,0,245,247,3,0,44,129,5,0,0,160,3,0,44,7,5,0,141,36,3,0,83,243,3,0,223,104,4,0,245,247,3,0,166,184,3,0,112,99,4,0,36,94,2,0,216,192,3,0,32,150,1,0,79,51,2,0,25,137,3,0,145,46,3,0,13,157,2,0,94,69,2,0,80,140,5,0,63,254,4,0,105,47,5,0,101,126,4,0,0,160,4,0,214,86,3,0,67,162,3,0,101,179,2,0,210,76,2,0,133,26,1,0,62,220,1,0,217,235,0,0,24,146,2,0,16,5,2,0,105,238,1,0,162,222,1,0,226,193,1,0,89,229,0,0,176,73,1,0,45,202,0,0,171,170,2,0,227,178,3,0,248,21,5,0,226,13,7,0,242,123,3,0,62,185,3,0,101,218,7,0,33,134,6,0,171,170,2,0,240,124,2,0,177,2,6,0,243,254,3,0,1,252,1,0,250,2,1,0,159,192,2,0,218,184,1,0,106,169,5,0,50,246,4,0,206,169,6,0,62,60,5,0,237,106,3,0,9,190,1,0,45,155,3,0,107,145,1,0,41,225,5,0,184,39,8,0,156,74,5,0,229,86,7,0,85,213,4,0,59,180,6,0,188,48,4,0,111,68,5,0,41,225,5,0,156,74,5,0,50,246,4,0,235,217,5,0,48,40,3,0,33,1,5,0,128,29,2,0,20,239,2,0,204,182,4,0,22,62,4,0,17,124,3,0,40,7,3,0,192,101,7,0,85,168,6,0,226,233,6,0,219,253,5,0,171,42,6,0,200,115,4,0,90,216,4,0,220,153,3,0,24,17,3,0,178,120,1,0,253,122,2,0,119,58,1,0,118,109,3,0,106,177,2,0,55,147,2,0,46,126,2,0,216,87,2,0,204,49,1,0,150,183,1,0,145,13,1,0,0,128,3,0,202,218,4,0,213,172,6,0,56,66,9,0,174,146,4,0,34,227,4,0,165,78,10,0,12,144,8,0,0,128,3,0,251,67,3,0,136,227,7,0,159,62,5,0,193,154,2,0,232,83,1,0,208,156,3,0,158,66,2,0,91,110,7,0,34,131,6,0,222,190,8,0,17,223,6,0,87,124,4,0,107,73,2,0,171,187,4,0,221,14,2,0,134,183,7,0,33,180,10,0,237,241,6,0,13,162,9,0,0,88,6,0,142,204,8,0,247,127,5,0,210,233,6,0,134,183,7,0,237,241,6,0,34,131,6,0,4,174,7,0,191,36,4,0,123,145,6,0,184,198,2,0,203,217,3,0,235,47,6,0,125], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1686725);
/* memory initializer */ allocate([145,5,0,215,146,4,0,100,249,3,0,140,181,9,0,239,188,8,0,248,18,9,0,48,221,7,0,0,24,8,0,247,215,5,0,246,91,6,0,241,185,4,0,112,6,4,0,105,238,1,0,108,65,3,0,188,156,1,0,170,127,4,0,220,136,3,0,56,97,3,0,156,69,3,0,76,19,3,0,92,145,1,0,245,64,2,0,207,97,1,0,0,0,4,0,84,140,5,0,244,160,7,0,211,148,10,0,236,57,5,0,221,149,5,0,152,199,11,0,50,201,9,0,0,0,4,0,104,187,3,0,9,4,9,0,109,254,5,0,1,250,2,0,119,132,1,0,238,32,4,0,71,149,2,0,31,126,8,0,76,113,7,0,181,254,9,0,93,218,7,0,100,32,5,0,13,157,2,0,195,104,5,0,33,90,2,0,190,209,8,0,148,59,12,0,234,239,7,0,88,2,11,0,0,64,7,0,89,14,10,0,26,73,6,0,167,230,7,0,190,209,8,0,234,239,7,0,76,113,7,0,224,198,8,0,72,188,4,0,177,129,7,0,63,44,3,0,159,102,4,0,50,18,7,0,34,93,6,0,26,58,5,0,188,138,4,0,160,24,11,0,127,252,9,0,211,94,10,0,201,252,8,0,0,64,9,0,172,173,6,0,135,68,7,0,202,102,5,0,165,153,4,0,11,53,2,0,123,184,3,0,179,215,1,0,48,36,5,0,32,10,4,0,211,220,3,0,69,189,3,0,197,131,3,0,179,202,1,0,97,147,2,0,90,148,1,0,0,0,5,0,105,239,6,0,49,137,9,0,7,58,13,0,103,136,6,0,85,251,6,0,126,185,14,0,126,59,12,0,0,0,5,0,66,170,4,0,11,69,11,0,8,126,7,0,129,184,3,0,149,229,1,0,42,41,5,0,153,58,3,0,167,157,10,0,159,77,9,0,98,126,12,0,244,208,9,0,125,104,6,0,80,68,3,0,244,194,6,0,170,240,2,0,45,6,11,0,120,74,15,0,228,235,9,0,238,194,13,0,0,16,9,0,239,145,12,0,97,219,7,0,80,224,9,0,45,6,11,0,228,235,9,0,159,77,9,0,152,248,10,0,89,235,5,0,29,98,9,0,79,247,3,0,70,128,5,0,190,214,8,0,106,244,7,0,160,136,6,0,107,173,5,0,200,222,13,0,159,123,12,0,135,246,12,0,251,59,11,0,0,144,11,0,23,89,8,0,168,21,9,0,125,192,6,0,14,192,5,0,77,194,2,0,154,166,4,0,159,77,2,0,60,109,6,0,167,12,5,0,7,212,4,0,150,172,4,0,182,100,4,0,95,61,2,0,57,56,3,0,113,249,1,0,0,0,6,0,126,82,8,0,110,113,11,0,60,223,15,0,225,214,7,0,204,96,8,0,99,171,17,0,203,173,14,0,0,0,6,0,28,153,5,0,13,134,13,0,163,253,8,0,2,119,4,0,179,70,2,0,101,49,6,0,234,223,3,0,46,189,12,0,241,41,11,0,15,254,14,0,139,199,11,0,150,176,7,0,147,235,3,0,36,29,8,0,50,135,3,0,156,58,13,0,93,89,18,0,223,231,11,0,132,131,16,0,0,224,10,0,133,21,15,0,168,109,9,0,250,217,11,0,156,58,13,0,223,231,11,0,241,41,11,0,80,42,13,0,107,26,7,0,137,66,11,0,95,194,4,0,238,153,6,0,74,155,10,0,178,139,9,0,39,215,7,0,26,208,6,0,240,164,16,0,190,250,14,0,60,142,15,0,46,123,13,0,0,224,13,0,130,4,10,0,202,230,10,0,47,26,8,0,119,230,6,0,144,79,3,0,185,148,5,0,140,195,2,0,73,182,7,0,47,15,6,0,60,203,5,0,231,155,5,0,167,69,5,0,12,176,2,0,17,221,3,0,135,94,2,0,0,0,8,0,168,24,11,0,232,65,15,0,165,41,21,0,215,115,10,0,187,43,11,0,47,143,23,0,100,146,19,0,0,0,8,0,207,118,7,0,18,8,18,0,217,252,11,0,2,244,5,0,239,8,3,0,220,65,8,0,142,42,5,0,62,252,16,0,151,226,14,0,105,253,19,0,185,180,15,0,200,64,10,0,26,58,5,0,134,209,10,0,66,180,4,0,123,163,17,0,39,119,24,0,212,223,15,0,176,4,22,0,0,128,14,0,177,28,20,0,53,146,12,0,77,205,15,0,123,163,17,0,212,223,15,0,151,226,14,0,192,141,17,0,143,120,9,0,98,3,15,0,127,88,6,0,61,205,8,0,99,36,14,0,67,186,12,0,52,116,10,0,119,21,9,0,64,49,22,0,254,248,19,0,165,189,20,0,146,249,17,0,0,128,18,0,88,91,13,0,13,137,14,0,148,205,10,0,73,51,9,0,21,106,4,0,247,112,7,0,101,175,3,0,97,72,10,0,63,20,8,0,166,185,7,0,137,122,7,0,137,7,7,0,101,149,3,0,194,38,5,0,180,40,3,0,0,0,12,0,253,164,16,0,219,226,22,0,120,190,31,0,195,173,15,0,152,193,16,0,199,86,35,0,150,91,29,0,0,0,12,0,55,50,11,0,26,12,27,0,70,251,17,0,3,238,8,0,102,141,4,0,202,98,12,0,213,191,7,0,93,122,25,0,227,83,22,0,30,252,29,0,22,143,23,0,44,97,15,0,39,215,7,0,73,58,16,0,100,14,7,0,57,117,26,0,187,178,36,0,189,207,23,0,9,7,33,0,0,192,21,0,10,43,30,0,79,219,18,0,244,179,23,0,57,117,26,0,189,207,23,0,227,83,22,0,160,84,26,0,215,52,14,0,19,133,22,0,190,132,9,0,220,51,13,0,149,54,21,0,101,23,19,0,78,174,15,0,51,160,13,0,225,73,33,0,125,245,29,0,120,28,31,0,91,246,26,0,0,192,27,0,4,9,20,0,148,205,21,0,94,52,16,0,238,204,13,0,32,159,6,0,114,41,11,0,24,135,5,0,145,108,15,0,94,30,12,0,120,150,11,0,206,55,11,0,78,139,10,0,24,96,5,0,34,186,7,0,14,189,4,0,0,0,17,0,102,148,23,0,12,108,32,0,127,248,44,0,42,54,22,0,237,188,23,0,68,16,50,0,20,151,41,0,0,0,17,0,121,220,15,0,37,81,38,0,78,121,25,0,133,166,12,0,251,114,6,0,244,139,17,0,109,250,10,0,4,24,36,0,129,161,31,0,128,122,42,0,10,96,33,0,169,201,21,0,119,27,11,0,60,253,22,0,13,255,9,0,102,123,37,0,51,253,51,0,162,187,33,0,247,201,46,0,0,208,30,0,249,188,42,0,176,182,26,0,68,148,33,0,102,123,37,0,162,187,33,0,129,161,31,0,56,77,37,0,48,32,20,0,48,231,31,0,14,124,13,0,35,180,18,0,82,13,30,0,207,11,27,0,238,54,22,0,158,77,19,0,169,40,47,0,27,113,42,0,255,18,44,0,86,50,38,0,0,80,39,0,27,98,28,0,60,227,30,0,219,244,22,0,251,140,19,0,110,97,9,0,12,208,15,0,183,212,7,0,206,217,21,0,6,43,17,0,128,106,16,0,100,228,15,0,4,240,14,0,119,157,7,0,91,242,10,0,127,182,6,0,0,0,22,0,207,131,30,0,61,245,41,0,134,50,58,0,144,190,28,0,66,184,30,0,194,201,64,0,147,210,53,0,0,0,22,0,186,134,20,0,48,150,49,0,86,247,32,0,6,95,16,0,145,88,8,0,30,181,22,0,6,53,14,0,170,181,46,0,32,239,40,0,225,248,54,0,254,48,43,0,37,50,28,0,199,95,14,0,48,192,29,0,183,239,12,0,147,129,48,0,172,71,67,0,134,167,43,0,229,140,60,0,0,224,39,0,231,78,55,0,18,146,34,0,148,116,43,0,147,129,48,0,134,167,43,0,32,239,40,0,208,69,48,0,137,11,26,0,77,73,41,0,93,115,17,0,105,52,24,0,16,228,38,0,57,0,35,0,143,191,28,0,9,251,24,0,113,7,61,0,186,236,54,0,134,9,57,0,82,110,49,0,0,224,50,0,51,187,36,0,228,248,39,0,87,181,29,0,9,77,25,0,187,35,12,0,166,118,20,0,86,34,10,0,10,71,28,0,173,55,22,0,135,62,21,0,250,144,20,0,185,84,19,0,214,218,9,0,148,42,14,0,240,175,8,0,0,0,28,0,77,214,38,0,170,102,53,0,194,17,74,0,114,149,36,0,14,25,39,0,37,117,82,0,94,128,68,0,0,0,28,0,214,31,26,0,62,28,63,0,249,244,41,0,7,214,20,0,68,159,10,0,131,230,28,0,240,20,18,0,217,114,59,0,17,25,52,0,240,246,69,0,137,248,54,0,187,226,35,0,91,75,18,0,84,221,37,0,233,118,16,0,48,188,61,0,9,161,85,0,100,143,55,0,105,16,77,0,0,192,50,0,108,100,70,0,185,255,43,0,142,78,55,0,48,188,61,0,100,143,55,0,17,25,52,0,32,112,61,0,245,37,33,0,214,139,52,0,188,53,22,0,87,206,30,0,91,127,49,0,235,139,44,0,182,150,36,0,34,203,31,0,97,172,77,0,120,231,69,0,194,151,72,0,127,233,62,0,0,192,64,0,181,191,46,0,174,223,50,0,134,207,37,0,128,51,32,0,75,115,15,0,95,11,26,0,226,229,12,0,83,253,35,0,220,70,28,0,196,9,27,0,225,44,26,0,96,154,24,0,226,138,12,0,165,7,18,0,119,14,11,0,0,0,34,0,204,40,47,0,24,216,64,0,254,240,89,0,83,108,44,0,218,121,47,0,137,32,100,0,41,46,83,0,0,0,34,0,241,184,31,0,75,162,76,0,156,242,50,0,9,77,25,0,247,229,12,0,232,23,35,0,219,244,21,0,7,48,72,0,3,67,63,0,255,244,84,0,20,192,66,0,81,147,43,0,238,54,22,0,121,250,45,0,26,254,19,0,204,246,74,0,103,250,103,0,67,119,67,0,238,147,93,0,0,160,61,0,241,121,85,0,97,109,53,0,136,40,67,0,204,246,74,0,67,119,67,0,3,67,63,0,112,154,74,0,96,64,40,0,96,206,63,0,27,248,26,0,69,104,37,0,165,26,60,0,157,23,54,0,221,109,44,0,60,155,38,0,82,81,94,0,55,226,84,0,254,37,88,0,173,100,76,0,0,160,78,0,55,196,56,0,120,198,61,0,181,233,45,0,247,25,39,0,219,194,18,0,24,160,31,0,110,169,15,0,155,179,43,0,12,86,34,0,0,213,32,0,200,200,31,0,7,224,29,0,238,58,15,0,183,228,21,0,254,108,13,0,0,0,44,0,158,7,61,0,121,234,83,0,12,101,116,0,32,125,57,0,131,112,61,0,131,147,129,0,37,165,107,0,0,0,44,0,117,13,41,0,97,44,99,0,172,238,65,0,12,190,32,0,33,177,16,0,59,106,45,0,12,106,28,0,84,107,93,0,64,222,81,0,194,241,109,0,251,97,86,0,75,100,56,0,143,191,28,0,96,128,59,0,109,223,25,0,38,3,97,0,87,143,134,0,11,79,87,0,202,25,121,0,0,192,79,0,206,157,110,0,35,36,69,0,40,233,86,0,38,3,97,0,11,79,87,0,64,222,81,0,160,139,96,0,19,23,52,0,154,146,82,0,186,230,34,0,210,104,48,0,33,200,77,0,113,0,70,0,30,127,57,0,17,246,49,0,226,14,122,0,116,217,109,0,12,19,114,0,163,220,98,0,0,192,101,0,101,118,73,0,201,241,79,0,174,106,59,0,18,154,50,0,118,71,24,0,77,237,40,0,172,68,20,0,20,142,56,0,90,111,44,0,15,125,42,0,244,33,41,0,115,169,38,0,173,181,19,0,40,85,28,0,223,95,17,0,0,0,1,0,70,121,1,0,169,165,1,0,220,72,2,0,99,99,1,0,167,82,1,0,236,67,2,0,234,9,2,0,0,32,1,0,72,226,0,0,218,187,1,0,188,92,1,0,134,164,0,0,224,83,0,0,54,240,0,0,149,128,0,0,1,183,1,0,89,105,1,0,185,176,1,0,253,83,1,0,231,248,0,0,228,126,0,0,48,234,0,0,99,119,0,0,1,183,1,0,235,96,2,0,233,157,1,0,27,62,2,0,0,112,1,0,110,254,1,0,181,45,1,0,123,162,1,0,209,224,1,0,185,176,1,0,51,138,1,0,141,113,1,0,122,216,0,0,73,68,1,0,154,123,0,0,113,171,0,0,120,49,1,0,234,18,1,0,8,173,0,0,185,155,0,0,151,61,2,0,55,4,2,0,204,28,2,0,180,230,1,0,0,128,1,0,181,45,1,0,217,70,1,0,206,0,1,0,210,207,0,0,92,110,0,0,228,176,0,0,45,90,0,0,204,233,0,0,177,183,0,0,111,132,0,0,133,107,0,0,55,131,0,0,229,66,0,0,16,74,0,0,49,40,0,0,85,85,1,0,8,247,1,0,55,50,2,0,208,11,3,0,217,217,1,0,137,195,1,0,59,5,3,0,227,183,2,0,0,128,1,0,181,45,1,0,206,79,2,0,250,208,1,0,93,219,0,0,213,111,0,0,72,64,1,0,113,171,0,0,87,73,2,0,204,225,1,0,247,64,2,0,81,197,1,0,222,75,1,0,47,169,0,0,64,56,1,0,47,159,0,0,87,73,2,0,228,43,3,0,225,39,2,0,122,253,2,0,171,234,1,0,147,168,2,0,71,146,1,0,249,45,2,0,22,129,2,0,247,64,2,0,153,13,2,0,188,236,1,0,163,32,1,0,97,176,1,0,206,164,0,0,151,228,0,0,75,151,1,0,142,110,1,0,181,230,0,0,162,207,0,0,201,252,2,0,74,176,2,0,16,209,2,0,241,136,2,0,0,0,2,0,71,146,1,0,204,179,1,0,104,86,1,0,24,21,1,0,37,147,0,0,218,235,0,0,61,120,0,0,187,55,1,0,237,244,0,0,147,176,0,0,92,143,0,0,244,174,0,0,49,89,0,0,191,98,0,0,151,53,0,0,171,170,1,0,203,116,2,0,196,190,2,0,196,206,3,0,79,80,2,0,108,52,2,0,137,198,3,0,220,101,3,0,0,224,1,0,34,121,1,0,193,227,2,0,57,69,2,0,53,18,1,0,202,139,0,0,90,144,1,0,77,214,0,0,173,219,2,0,64,90,2,0,52,209,2,0,165,54,2,0,214,158,1,0,123,211,0,0,80,134,1,0,251,198,0,0,173,219,2,0,221,246,3,0,217,177,2,0,216,188,3,0,85,101,2,0,184,82,3,0,216,246,1,0,119,185,2,0,92,33,3,0,52,209,2,0,0,145,2,0,235,103,2,0,204,104,1,0,122,28,2,0,1,206,0,0,189,29,1,0,30,253,1,0,49,202,1,0,98,32,1,0,138,3,1,0,251,187,3,0,92,92,3,0,84,133,3,0,45,43,3,0,0,128,2,0,216,246,1,0,192,32,2,0,2,172,1,0,94,90,1,0,239,183,0,0,209,38,1,0,76,150,0,0,169,133,1,0,40,50,1,0,184,220,0,0,51,179,0,0,178,218,0,0,125,111,0,0,111,123,0,0,252,66,0,0,0,0,2,0,141,242,2,0,82,75,3,0,184,145,4,0,197,198,2,0,78,165,2,0,216,135,4,0,213,19,4,0,0,64,2,0,143,196,1,0,181,119,3,0,119,185,2,0,12,73,1,0,191,167,0,0,108,224,1,0,42,1,1,0,3,110,3,0,179,210,2,0,114,97,3,0,250,167,2,0,206,241,1,0,199,253,0,0,96,212,1,0,199,238,0,0,3,110,3,0,214,193,4,0,209,59,3,0,55,124,4,0,0,224,2,0,221,252,3,0,106,91,2,0,245,68,3,0,161,193,3,0,114,97,3,0,102,20,3,0,27,227,2,0,245,176,1,0,146,136,2,0,53,247,0,0,226,86,1,0,241,98,2,0,213,37,2,0,16,90,1,0,114,55,1,0,45,123,4,0,110,8,4,0,152,57,4,0,105,205,3,0,0,0,3,0,106,91,2,0,179,141,2,0,155,1,2,0,163,159,1,0,184,220,0,0,199,97,1,0,91,180,0,0,152,211,1,0,99,111,1,0,221,8,1,0,10,215,0,0,111,6,1,0,201,133,0,0,31,148,0,0,98,80,0,0,171,170,2,0,17,238,3,0,109,100,4,0,160,23,6,0,178,179,3,0,19,135,3,0,117,10,6,0,198,111,5,0,0,0,3,0,106,91,2,0,155,159,4,0,244,161,3,0,187,182,1,0,170,223,0,0,144,128,2,0,226,86,1,0,174,146,4,0,153,195,3,0,237,129,4,0,162,138,3,0,189,151,2,0,95,82,1,0,128,112,2,0,94,62,1,0,174,146,4,0,200,87,6,0,193,79,4,0,244,250,5,0,85,213,3,0,38,81,5,0,141,36,3,0,242,91,4,0,45,2,5,0,237,129,4,0,51,27,4,0,121,217,3,0,71,65,2,0,195,96,3,0,156,73,1,0,46,201,1,0,150,46,3,0,28,221,2,0,106,205,1,0,67,159,1,0,145,249,5,0,147,96,5,0,32,162,5,0,225,17,5,0,0,0,4,0,141,36,3,0,153,103,3,0,207,172,2,0,47,42,2,0,75,38,1,0,181,215,1,0,121,240,0,0,117,111,2,0,217,233,1,0,39,97,1,0,184,30,1,0,233,93,1,0,98,178,0,0,127,197,0,0,45,107,0,0,0,128,3,0,118,40,5,0,207,195,5,0,2,255,7,0,217,219,4,0,72,161,4,0,186,237,7,0,180,34,7,0,0,240,3,0,251,23,3,0,124,17,6,0,145,196,4,0,213,63,2,0,143,37,1,0,189,72,3,0,9,194,1,0,133,0,6,0,185,240,4,0,135,234,5,0,245,165,4,0,40,103,3,0,28,188,1,0,168,51,3,0,219,161,1,0,133,0,6,0,54,83,8,0,174,168,5,0,96,217,7,0,0,8,5,0,130,250,6,0,249,31,4,0,174,184,5,0,218,146,6,0,135,234,5,0,178,99,5,0,110,13,5,0,173,245,2,0,0,111,4,0,156,176,1,0,12,88,2,0,37,45,4,0,53,194,3,0,155,93,2,0,8,33,2,0,143,215,7,0,193,14,7,0,202,100,7,0,119,167,6,0,0,64,5,0,249,31,4,0,249,119,4,0,208,130,3,0,94,215,2,0,66,130,1,0,29,107,2,0,159,59,1,0,74,50,3,0,237,130,2,0,131,207,1,0,81,120,1,0,66,203,1,0,33,234,0,0,54,3,1,0,172,140,0,0,0,0,4,0,25,229,5,0,164,150,6,0,112,35,9,0,138,141,5,0,156,74,5,0,176,15,9,0,170,39,8,0,0,128,4,0,31,137,3,0,105,239,6,0,238,114,5,0,24,146,2,0,126,79,1,0,216,192,3,0,84,2,2,0,5,220,6,0,101,165,5,0,228,194,6,0,243,79,5,0,155,227,3,0,142,251,1,0,192,168,3,0,141,221,1,0,5,220,6,0,172,131,9,0,162,119,6,0,110,248,8,0,0,192,5,0,185,249,7,0,212,182,4,0,235,137,6,0,67,131,7,0,228,194,6,0,204,40,6,0,53,198,5,0,234,97,3,0,36,17,5,0,105,238,1,0,197,173,2,0,225,197,4,0,170,75,4,0,31,180,2,0,229,110,2,0,90,246,8,0,221,16,8,0,48,115,8,0,209,154,7,0,0,0,6,0,212,182,4,0,101,27,5,0,55,3,4,0,71,63,3,0,112,185,1,0,143,195,2,0,182,104,1,0,48,167,3,0,198,222,2,0,186,17,2,0,20,174,1,0,221,12,2,0,147,11,1,0,62,40,1,0,196,160,0,0,0,0,5,0,96,94,7,0,77,60,8,0,76,108,11,0,237,240,6,0,67,157,6,0,156,83,11,0,148,49,10,0,0,160,5,0,103,107,4,0,68,171,8,0,170,207,6,0,158,54,3,0,94,163,1,0,15,177,4,0,232,130,2,0,7,147,8,0,191,14,7,0,156,115,8,0,240,163,6,0,130,220,4,0,114,122,2,0,240,146,4,0,240,84,2,0,7,147,8,0,151,228,11,0,139,21,8,0,137,54,11,0,0,48,7,0,39,248,9,0,137,228,5,0,102,44,8,0,19,100,9,0,156,115,8,0,255,178,7,0,194,55,7,0,100,58,4,0,109,85,6,0,4,106,2,0,54,89,3,0,90,247,5,0,148,94,5,0,39,97,3,0,158,10,3,0,241,51,11,0,20,21,10,0,252,143,10,0,134,129,9,0,0,128,7,0,137,228,5,0,63,98,6,0,5,4,5,0,25,15,4,0,204,39,2,0,115,116,3,0,227,194,1,0,252,144,4,0,119,150,3,0,41,150,2,0,153,25,2,0,21,144,2,0,120,78,1,0,78,114,1,0,245,200,0,0,0,0,6,0,166,215,8,0,246,225,9,0,40,181,13,0,80,84,8,0,234,239,7,0,136,151,13,0,126,59,12,0,0,192,6,0,174,77,5,0,30,103,10,0,102,44,8,0,36,219,3,0,62,247,1,0,69,161,5,0,125,3,3,0,8,74,10,0,24,120,8,0,85,36,10,0,237,247,7,0,105,213,5,0,85,249,2,0,32,125,5,0,84,204,2,0,8,74,10,0,130,69,14,0,115,179,9,0,165,116,13,0,0,160,8,0,150,246,11,0,62,18,7,0,224,206,9,0,228,68,11,0,85,36,10,0,50,61,9,0,80,169,8,0,223,18,5,0,182,153,7,0,158,229,2,0,167,4,4,0,210,40,7,0,127,113,6,0,47,14,4,0,87,166,3,0,135,113,13,0,75,25,12,0,200,172,12,0,58,104,11,0,0,0,9,0,62,18,7,0,24,169,7,0,210,4,6,0,234,222,4,0,41,150,2,0,86,37,4,0,17,29,2,0,200,122,5,0,40,78,4,0,151,26,3,0,30,133,2,0,76,19,3,0,92,145,1,0,93,188,1,0,38,241,0,0,0,0,8,0,51,202,11,0,72,45,13,0,224,70,18,0,21,27,11,0,56,149,10,0,95,31,18,0,83,79,16,0,0,0,9,0,62,18,7,0,210,222,13,0,221,229,10,0,48,36,5,0,253,158,2,0,177,129,7,0,167,4,4,0,11,184,13,0,203,74,11,0,199,133,13,0,231,159,10,0,54,199,7,0,29,247,3,0,128,81,7,0,26,187,3,0,11,184,13,0,87,7,19,0,68,239,12,0,220,240,17,0,0,128,11,0,114,243,15,0,168,109,9,0,214,19,13,0,134,6,15,0,199,133,13,0,152,81,12,0,106,140,11,0,212,195,6,0,72,34,10,0,211,220,3,0,138,91,5,0,195,139,9,0,84,151,8,0,62,104,5,0,201,221,4,0,180,236,17,0,185,33,16,0,97,230,16,0,163,53,15,0,0,0,12,0,168,109,9,0,203,54,10,0,110,6,8,0,142,126,6,0,225,114,3,0,30,135,5,0,107,209,2,0,96,78,7,0,139,189,5,0,116,35,4,0,40,92,3,0,187,25,4,0,38,23,2,0,124,80,2,0,136,65,1,0,0,0,12,0,76,175,17,0,236,195,19,0,80,106,27,0,159,168,16,0,212,223,15,0,15,47,27,0,253,118,24,0,0,128,13,0,93,155,10,0,60,206,20,0,203,88,16,0,73,182,7,0,123,238,3,0,137,66,11,0,251,6,6,0,16,148,20,0,48,240,16,0,171,72,20,0,218,239,15,0,210,170,11,0,171,242,5,0,64,250,10,0,167,152,5,0,16,148,20,0,3,139,28,0,230,102,19,0,73,233,26,0,0,64,17,0,43,237,23,0,124,36,14,0,193,157,19,0,200,137,22,0,171,72,20,0,99,122,18,0,159,82,17,0,190,37,10,0,109,51,15,0,60,203,5,0,78,9,8,0,164,81,14,0,254,226,12,0,93,28,8,0,174,76,7,0,14,227,26,0,150,50,24,0,145,89,25,0,116,208,22,0,0,0,18,0,124,36,14,0,48,82,15,0,165,9,12,0,213,189,9,0,81,44,5,0,172,74,8,0,33,58,4,0,144,245,10,0,81,156,8,0,46,53,6,0,59,10,5,0,152,38,6,0,185,34,3,0,186,120,3,0,77,226,1,0,0,0,17,0,172,13,25,0,57,0,28,0,156,214,38,0,140,153,23,0,22,125,22,0,171,130,38,0,145,168,34,0,0,32,19,0,195,6,15,0,127,121,29,0,118,40,23,0,231,236,10,0,217,145,5,0,152,243,15,0,227,137,8,0,23,39,29,0,239,254,23,0,71,188,28,0,202,147,22,0,84,135,16,0,29,109,8,0,48,141,15,0,152,237,7,0,23,39,29,0,154,111,40,0,113,124,27,0,211,31,38,0,0,112,24,0,82,229,33,0,4,9,20,0,39,202,27,0,220,237,31,0,71,188,28,0,98,45,26,0,98,138,24,0,34,96,14,0,218,136,21,0,64,53,8,0,132,98,11,0,254,72,20,0,146,65,18,0,132,125,11,0,75,87,10,0,255,22,38,0,170,71,34,0,141,233,35,0,250,81,32,0,0,128,25,0,4,9,20,0,111,180,21,0,170,13,17,0,238,204,13,0,30,84,7,0,31,191,11,0,4,253,5,0,139,134,15,0,200,50,12,0,87,203,8,0,212,35,7,0,173,182,8,0,48,113,4,0,8,235,4,0,66,171,2,0,0,0,22,0,12,108,32,0,134,60,36,0,232,66,50,0,121,138,30,0,89,26,29,0,70,214,49,0,37,218,44,0,0,192,24,0,42,114,19,0,195,36,38,0,32,248,29,0,133,35,14,0,55,53,7,0,167,164,20,0,204,12,11,0,29,186,37,0,174,13,31,0,228,47,37,0,187,55,29,0,214,99,21,0,142,231,10,0,33,32,20,0,136,66,10,0,29,186,37,0,48,84,52,0,251,145,35,0,92,86,49,0,0,160,31,0,122,221,43,0,141,237,25,0,140,246,35,0,239,81,41,0,228,47,37,0,97,224,33,0,36,194,31,0,135,154,18,0,71,222,27,0,68,159,10,0,186,187,14,0,88,64,26,0,38,160,23,0,171,222,14,0,233,97,13,0,239,74,49,0,190,92,44,0,138,121,46,0,128,211,41,0,0,0,33,0,141,237,25,0,174,22,28,0,174,17,22,0,6,220,17,0,234,123,9,0,145,51,15,0,231,191,7,0,135,23,20,0,62,201,15,0,127,97,11,0,109,61,9,0,193,70,11,0,168,191,5,0,85,93,6,0,55,116,3,0,0,0,28,0,178,67,41,0,124,30,46,0,16,248,63,0,201,222,38,0,67,10,37,0,206,109,63,0,163,21,57,0,0,128,31,0,216,191,24,0,225,139,48,0,133,36,38,0,169,254,17,0,117,44,9,0,235,69,26,0,73,16,14,0,37,4,48,0,198,133,39,0,57,84,47,0,168,47,37,0,63,57,27,0,228,224,13,0,65,157,25,0,220,14,13,0,37,4,48,0,178,153,66,0,110,69,45,0,0,203,62,0,0,64,40,0,15,212,55,0,203,255,32,0,109,197,45,0,211,150,52,0,57,84,47,0,147,29,43,0,116,107,40,0,102,173,23,0,254,119,35,0,226,132,13,0,98,192,18,0,42,105,33,0,165,17,30,0,218,236,18,0,64,8,17,0,118,188,62,0,8,118,56,0,82,38,59,0,186,59,53,0,0,0,42,0,203,255,32,0,198,191,35,0,129,22,28,0,241,186,22,0,19,18,12,0,232,88,19,0,248,220,9,0,79,146,25,0,103,23,20,0,22,124,14,0,138,194,11,0,13,90,14,0,4,81,7,0,178,25,8,0,93,101,4,0,0,0,34,0,88,27,50,0,114,0,56,0,56,173,77,0,24,51,47,0,45,250,44,0,86,5,77,0,34,81,69,0,0,64,38,0,134,13,30,0,254,242,58,0,235,80,46,0,206,217,21,0,178,35,11,0,48,231,31,0,199,19,17,0,45,78,58,0,223,253,47,0,142,120,57,0,149,39,45,0,168,14,33,0,57,218,16,0,97,26,31,0,47,219,15,0,45,78,58,0,51,223,80,0,225,248,54,0,165,63,76,0,0,224,48,0,165,202,67,0,9,18,40,0,77,148,55,0,183,219,63,0,142,120,57,0,196,90,52,0,195,20,49,0,68,192,28,0,180,17,43,0,128,106,16,0,9,197,22,0,252,145,40,0,36,131,36,0,8,251,22,0,151,174,20,0,253,45,76,0,84,143,68,0,27,211,71,0,245,163,64,0,0,0,51,0,9,18,40,0,223,104,43,0,83,27,34,0,219,153,27,0,59,168,14,0,62,126,23,0,9,250,11,0,23,13,31,0,143,101,24,0,174,150,17,0,168,71,14,0,90,109,17,0,96,226,8,0,15,214,9,0,132,86,5,0,0,0,44,0,24,216,64,0,12,121,72,0,208,133,100,0,242,20,61,0,178,52,58,0,141,172,99,0,74,180,89,0,0,128,49,0,84,228,38,0,134,73,76,0,63,240,59,0,10,71,28,0,110,106,14,0,77,73,41,0,152,25,22,0,58,116,75,0,92,27,62,0,199,95,74,0,117,111,58,0,172,199,42,0,29,207,21,0,65,64,40,0,16,133,20,0,58,116,75,0,97,168,104,0,246,35,71,0,184,172,98,0,0,64,63,0,243,186,87,0,26,219,51,0,25,237,71,0,222,163,82,0,199,95,74,0,194,192,67,0,72,132,63,0,13,53,37,0,142,188,55,0,135,62,21,0,117,119,29,0,176,128,52,0,76,64,47,0,86,189,29,0,210,195,26,0,222,149,98,0,123,185,88,0,19,243,92,0,1,167,83,0,0,0,66,0,26,219,51,0,92,45,56,0,93,35,44,0,13,184,35,0,212,247,18,0,35,103,30,0,207,127,15,0,14,47,40,0,125,146,31,0,255,194,22,0,217,122,18,0,131,141,22,0,80,127,11,0,170,186,12,0,110,232,6,0,0,48,12,255,1,48,2,48,14,255,39,32,27,255,26,255,31,255,1,255,48,254,38,32,37,32,80,254,81,254,82,254,183,0,84,254,85,254,86,254,87,254,92,255,19,32,49,254,20,32,51,254,116,37,52,254,79,254,8,255,9,255,53,254,54,254,91,255,93,255,55,254,56,254,20,48,21,48,57,254,58,254,16,48,17,48,59,254,60,254,10,48,11,48,61,254,62,254,8,48,9,48,63,254,64,254,12,48,13,48,65,254,66,254,14,48,15,48,67,254,68,254,89,254,90,254,91,254,92,254,93,254,94,254,24,32,25,32,28,32,29,32,29,48,30,48,53,32,50,32,3,255,6,255,10,255,59,32,167,0,3,48,203,37,207,37,179,37,178,37,206,37,6,38,5,38,199,37,198,37,161,37,160,37,189,37,188,37,163,50,5,33,175,0,227,255,63,255,205,2,73,254,74,254,77,254,78,254,75,254,76,254,95,254,96,254,97,254,11,255,13,255,215,0,247,0,177,0,26,34,28,255,30,255,29,255,102,34,103,34,96,34,30,34,82,34,97,34,98,254,99,254,100,254,101,254,102,254,94,255,41,34,42,34,165,34,32,34,31,34,191,34,210,51,209,51,43,34,46,34,53,34,52,34,64,38,66,38,149,34,153,34,145,33,147,33,144,33,146,33,150,33,151,33,153,33,152,33,37,34,35,34,15,255,60,255,21,34,104,254,4,255,229,255,18,48,224,255,225,255,5,255,32,255,3,33,9,33,105,254,106,254,107,254,213,51,156,51,157,51,158,51,206,51,161,51,142,51,143,51,196,51,176,0,89,81,91,81,94,81,93,81,97,81,99,81,231,85,233,116,206,124,129,37,130,37,131,37,132,37,133,37,134,37,135,37,136,37,143,37,142,37,141,37,140,37,139,37,138,37,137,37,60,37,52,37,44,37,36,37,28,37,148,37,0,37,2,37,149,37,12,37,16,37,20,37,24,37,109,37,110,37,112,37,111,37,80,37,94,37,106,37,97,37,226,37,227,37,229,37,228,37,113,37,114,37,115,37,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,65,83,68,83,69,83,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,5,49,6,49,7,49,8,49,9,49,10,49,11,49,12,49,13,49,14,49,15,49,16,49,17,49,18,49,19,49,20,49,21,49,22,49,23,49,24,49,25,49,26,49,27,49,28,49,29,49,30,49,31,49,32,49,33,49,34,49,35,49,36,49,37,49,38,49,39,49,40,49,41,49,217,2,201,2,202,2,199,2,203,2,0,36,1,36,2,36,3,36,4,36,5,36,6,36,7,36,8,36,9,36,10,36,11,36,12,36,13,36,14,36,15,36,16,36,17,36,18,36,19,36,20,36,21,36,22,36,23,36,24,36,25,36,26,36,27,36,28,36,29,36,30,36,31,36,33,36,172,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,89,78,1,78,3,78,67,78,93,78,134,78,140,78,186,78,63,81,101,81,107,81,224,81,0,82,1,82,155,82,21,83,65,83,92,83,200,83,9,78,11,78,8,78,10,78,43,78,56,78,225,81,69,78,72,78,95,78,94,78,142,78,161,78,64,81,3,82,250,82,67,83,201,83,227,83,31,87,235,88,21,89,39,89,115,89,80,91,81,91,83,91,248,91,15,92,34,92,56,92,113,92,221,93,229,93,241,93,242,93,243,93,254,93,114,94,254,94,11,95,19,95,77,98,17,78,16,78,13,78,45,78,48,78,57,78,75,78,57,92,136,78,145,78,149,78,146,78,148,78,162,78,193,78,192,78,195,78,198,78,199,78,205,78,202,78,203,78,196,78,67,81,65,81,103,81,109,81,110,81,108,81,151,81,246,81,6,82,7,82,8,82,251,82,254,82,255,82,22,83,57,83,72,83,71,83,69,83,94,83,132,83,203,83,202,83,205,83,236,88,41,89,43,89,42,89,45,89,84,91,17,92,36,92,58,92,111,92,244,93,123,94,255,94,20,95,21,95,195,95,8,98,54,98,75,98,78,98,47,101,135,101,151,101,164,101,185,101,229,101,240,102,8,103,40,103,32,107,98,107,121,107,203,107,212,107,219,107,15,108,52,108,107,112,42,114,54,114,59,114,71,114,89,114,91,114,172,114,139,115,25,78,22,78,21,78,20,78,24,78,59,78,77,78,79,78,78,78,229,78,216,78,212,78,213,78,214,78,215,78,227,78,228,78,217,78,222,78,69,81,68,81,137,81,138,81,172,81,249,81,250,81,248,81,10,82,160,82,159,82,5,83,6,83,23,83,29,83,223,78,74,83,73,83,97,83,96,83,111,83,110,83,187,83,239,83,228,83,243,83,236,83,238,83,233,83,232,83,252,83,248,83,245,83,235,83,230,83,234,83,242,83,241,83,240,83,229,83,237,83,251,83,219,86,218,86,22,89,46,89,49,89,116,89,118,89,85,91,131,91,60,92,232,93,231,93,230,93,2,94,3,94,115,94,124,94,1,95,24,95,23,95,197,95,10,98,83,98,84,98,82,98,81,98,165,101,230,101,46,103,44,103,42,103,43,103,45,103,99,107,205,107,17,108,16,108,56,108,65,108,64,108,62,108,175,114,132,115,137,115,220,116,230,116,24,117,31,117,40,117,41,117,48,117,49,117,50,117,51,117,139,117,125,118,174,118,191,118,238,118,219,119,226,119,243,119,58,121,190,121,116,122,203,122,30,78,31,78,82,78,83,78,105,78,153,78,164,78,166,78,165,78,255,78,9,79,25,79,10,79,21,79,13,79,16,79,17,79,15,79,242,78,246,78,251,78,240,78,243,78,253,78,1,79,11,79,73,81,71,81,70,81,72,81,104,81,113,81,141,81,176,81,23,82,17,82,18,82,14,82,22,82,163,82,8,83,33,83,32,83,112,83,113,83,9,84,15,84,12,84,10,84,16,84,1,84,11,84,4,84,17,84,13,84,8,84,3,84,14,84,6,84,18,84,224,86,222,86,221,86,51,87,48,87,40,87,45,87,44,87,47,87,41,87,25,89,26,89,55,89,56,89,132,89,120,89,131,89,125,89,121,89,130,89,129,89,87,91,88,91,135,91,136,91,133,91,137,91,250,91,22,92,121,92,222,93,6,94,118,94,116,94,15,95,27,95,217,95,214,95,14,98,12,98,13,98,16,98,99,98,91,98,88,98,54,101,233,101,232,101,236,101,237,101,242,102,243,102,9,103,61,103,52,103,49,103,53,103,33,107,100,107,123,107,22,108,93,108,87,108,89,108,95,108,96,108,80,108,85,108,97,108,91,108,77,108,78,108,112,112,95,114,93,114,126,118,249,122,115,124,248,124,54,127,138,127,189,127,1,128,3,128,12,128,18,128,51,128,127,128,137,128,139,128,140,128,227,129,234,129,243,129,252,129,12,130,27,130,31,130,110,130,114,130,126,130,107,134,64,136,76,136,99,136,127,137,33,150,50,78,168,78,77,79,79,79,71,79,87,79,94,79,52,79,91,79,85,79,48,79,80,79,81,79,61,79,58,79,56,79,67,79,84,79,60,79,70,79,99,79,92,79,96,79,47,79,78,79,54,79,89,79,93,79,72,79,90,79,76,81,75,81,77,81,117,81,182,81,183,81,37,82,36,82,41,82,42,82,40,82,171,82,169,82,170,82,172,82,35,83,115,83,117,83,29,84,45,84,30,84,62,84,38,84,78,84,39,84,70,84,67,84,51,84,72,84,66,84,27,84,41,84,74,84,57,84,59,84,56,84,46,84,53,84,54,84,32,84,60,84,64,84,49,84,43,84,31,84,44,84,234,86,240,86,228,86,235,86,74,87,81,87,64,87,77,87,71,87,78,87,62,87,80,87,79,87,59,87,239,88,62,89,157,89,146,89,168,89,158,89,163,89,153,89,150,89,141,89,164,89,147,89,138,89,165,89,93,91,92,91,90,91,91,91,140,91,139,91,143,91,44,92,64,92,65,92,63,92,62,92,144,92,145,92,148,92,140,92,235,93,12,94,143,94,135,94,138,94,247,94,4,95,31,95,100,95,98,95,119,95,121,95,216,95,204,95,215,95,205,95,241,95,235,95,248,95,234,95,18,98,17,98,132,98,151,98,150,98,128,98,118,98,137,98,109,98,138,98,124,98,126,98,121,98,115,98,146,98,111,98,152,98,110,98,149,98,147,98,145,98,134,98,57,101,59,101,56,101,241,101,244,102,95,103,78,103,79,103,80,103,81,103,92,103,86,103,94,103,73,103,70,103,96,103,83,103,87,103,101,107,207,107,66,108,94,108,153,108,129,108,136,108,137,108,133,108,155,108,106,108,122,108,144,108,112,108,140,108,104,108,150,108,146,108,125,108,131,108,114,108,126,108,116,108,134,108,118,108,141,108,148,108,152,108,130,108,118,112,124,112,125,112,120,112,98,114,97,114,96,114,196,114,194,114,150,115,44,117,43,117,55,117,56,117,130,118,239,118,227,119,193,121,192,121,191,121,118,122,251,124,85,127,150,128,147,128,157,128,152,128,155,128,154,128,178,128,111,130,146,130,139,130,141,130,139,137,210,137,0,138,55,140,70,140,85,140,157,140,100,141,112,141,179,141,171,142,202,142,155,143,176,143,194,143,198,143,197,143,196,143,225,93,145,144,162,144,170,144,166,144,163,144,73,145,198,145,204,145,50,150,46,150,49,150,42,150,44,150,38,78,86,78,115,78,139,78,155,78,158,78,171,78,172,78,111,79,157,79,141,79,115,79,127,79,108,79,155,79,139,79,134,79,131,79,112,79,117,79,136,79,105,79,123,79,150,79,126,79,143,79,145,79,122,79,84,81,82,81,85,81,105,81,119,81,118,81,120,81,189,81,253,81,59,82,56,82,55,82,58,82,48,82,46,82,54,82,65,82,190,82,187,82,82,83,84,83,83,83,81,83,102,83,119,83,120,83,121,83,214,83,212,83,215,83,115,84,117,84,150,84,120,84,149,84,128,84,123,84,119,84,132,84,146,84,134,84,124,84,144,84,113,84,118,84,140,84,154,84,98,84,104,84,139,84,125,84,142,84,250,86,131,87,119,87,106,87,105,87,97,87,102,87,100,87,124,87,28,89,73,89,71,89,72,89,68,89,84,89,190,89,187,89,212,89,185,89,174,89,209,89,198,89,208,89,205,89,203,89,211,89,202,89,175,89,179,89,210,89,197,89,95,91,100,91,99,91,151,91,154,91,152,91,156,91,153,91,155,91,26,92,72,92,69,92,70,92,183,92,161,92,184,92,169,92,171,92,177,92,179,92,24,94,26,94,22,94,21,94,27,94,17,94,120,94,154,94,151,94,156,94,149,94,150,94,246,94,38,95,39,95,41,95,128,95,129,95,127,95,124,95,221,95,224,95,253,95,245,95,255,95,15,96,20,96,47,96,53,96,22,96,42,96,21,96,33,96,39,96,41,96,43,96,27,96,22,98,21,98,63,98,62,98,64,98,127,98,201,98,204,98,196,98,191,98,194,98,185,98,210,98,219,98,171,98,211,98,212,98,203,98,200,98,168,98,189,98,188,98,208,98,217,98,199,98,205,98,181,98,218,98,177,98,216,98,214,98,215,98,198,98,172,98,206,98,62,101,167,101,188,101,250,101,20,102,19,102,12,102,6,102,2,102,14,102,0,102,15,102,21,102,10,102,7,102,13,103,11,103,109,103,139,103,149,103,113,103,156,103,115,103,119,103,135,103,157,103,151,103,111,103,112,103,127,103,137,103,126,103,144,103,117,103,154,103,147,103,124,103,106,103,114,103,35,107,102,107,103,107,127,107,19,108,27,108,227,108,232,108,243,108,177,108,204,108,229,108,179,108,189,108,190,108,188,108,226,108,171,108,213,108,211,108,184,108,196,108,185,108,193,108,174,108,215,108,197,108,241,108,191,108,187,108,225,108,219,108,202,108,172,108,239,108,220,108,214,108,224,108,149,112,142,112,146,112,138,112,153,112,44,114,45,114,56,114,72,114,103,114,105,114,192,114,206,114,217,114,215,114,208,114,169,115,168,115,159,115,171,115,165,115,61,117,157,117,153,117,154,117,132,118,194,118,242,118,244,118,229,119,253,119,62,121,64,121,65,121,201,121,200,121,122,122,121,122,250,122,254,124,84,127,140,127,139,127,5,128,186,128,165,128,162,128,177,128,161,128,171,128,169,128,180,128,170,128,175,128,229,129,254,129,13,130,179,130,157,130,153,130,173,130,189,130,159,130,185,130,177,130,172,130,165,130,175,130,184,130,163,130,176,130,190,130,183,130,78,134,113,134,29,82,104,136,203,142,206,143,212,143,209,143,181,144,184,144,177,144,182,144,199,145,209,145,119,149,128,149,28,150,64,150,63,150,59,150,68,150,66,150,185,150,232,150,82,151,94,151,159,78,173,78,174,78,225,79,181,79,175,79,191,79,224,79,209,79,207,79,221,79,195,79,182,79,216,79,223,79,202,79,215,79,174,79,208,79,196,79,194,79,218,79,206,79,222,79,183,79,87,81,146,81,145,81,160,81,78,82,67,82,74,82,77,82,76,82,75,82,71,82,199,82,201,82,195,82,193,82,13,83,87,83,123,83,154,83,219,83,172,84,192,84,168,84,206,84,201,84,184,84,166,84,179,84,199,84,194,84,189,84,170,84,193,84,196,84,200,84,175,84,171,84,177,84,187,84,169,84,167,84,191,84,255,86,130,87,139,87,160,87,163,87,162,87,206,87,174,87,147,87,85,89,81,89,79,89,78,89,80,89,220,89,216,89,255,89,227,89,232,89,3,90,229,89,234,89,218,89,230,89,1,90,251,89,105,91,163,91,166,91,164,91,162,91,165,91,1,92,78,92,79,92,77,92,75,92,217,92,210,92,247,93,29,94,37,94,31,94,125,94,160,94,166,94,250,94,8,95,45,95,101,95,136,95,133,95,138,95,139,95,135,95,140,95,137,95,18,96,29,96,32,96,37,96,14,96,40,96,77,96,112,96,104,96,98,96,70,96,67,96,108,96,107,96,106,96,100,96,65,98,220,98,22,99,9,99,252,98,237,98,1,99,238,98,253,98,7,99,241,98,247,98,239,98,236,98,254,98,244,98,17,99,2,99,63,101,69,101,171,101,189,101,226,101,37,102,45,102,32,102,39,102,47,102,31,102,40,102,49,102,36], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1696965);
/* memory initializer */ allocate([102,247,102,255,103,211,103,241,103,212,103,208,103,236,103,182,103,175,103,245,103,233,103,239,103,196,103,209,103,180,103,218,103,229,103,184,103,207,103,222,103,243,103,176,103,217,103,226,103,221,103,210,103,106,107,131,107,134,107,181,107,210,107,215,107,31,108,201,108,11,109,50,109,42,109,65,109,37,109,12,109,49,109,30,109,23,109,59,109,61,109,62,109,54,109,27,109,245,108,57,109,39,109,56,109,41,109,46,109,53,109,14,109,43,109,171,112,186,112,179,112,172,112,175,112,173,112,184,112,174,112,164,112,48,114,114,114,111,114,116,114,233,114,224,114,225,114,183,115,202,115,187,115,178,115,205,115,192,115,179,115,26,117,45,117,79,117,76,117,78,117,75,117,171,117,164,117,165,117,162,117,163,117,120,118,134,118,135,118,136,118,200,118,198,118,195,118,197,118,1,119,249,118,248,118,9,119,11,119,254,118,252,118,7,119,220,119,2,120,20,120,12,120,13,120,70,121,73,121,72,121,71,121,185,121,186,121,209,121,210,121,203,121,127,122,129,122,255,122,253,122,125,124,2,125,5,125,0,125,9,125,7,125,4,125,6,125,56,127,142,127,191,127,4,128,16,128,13,128,17,128,54,128,214,128,229,128,218,128,195,128,196,128,204,128,225,128,219,128,206,128,222,128,228,128,221,128,244,129,34,130,231,130,3,131,5,131,227,130,219,130,230,130,4,131,229,130,2,131,9,131,210,130,215,130,241,130,1,131,220,130,212,130,209,130,222,130,211,130,223,130,239,130,6,131,80,134,121,134,123,134,122,134,77,136,107,136,129,137,212,137,8,138,2,138,3,138,158,140,160,140,116,141,115,141,180,141,205,142,204,142,240,143,230,143,226,143,234,143,229,143,237,143,235,143,228,143,232,143,202,144,206,144,193,144,195,144,75,145,74,145,205,145,130,149,80,150,75,150,76,150,77,150,98,151,105,151,203,151,237,151,243,151,1,152,168,152,219,152,223,152,150,153,153,153,88,78,179,78,12,80,13,80,35,80,239,79,38,80,37,80,248,79,41,80,22,80,6,80,60,80,31,80,26,80,18,80,17,80,250,79,0,80,20,80,40,80,241,79,33,80,11,80,25,80,24,80,243,79,238,79,45,80,42,80,254,79,43,80,9,80,124,81,164,81,165,81,162,81,205,81,204,81,198,81,203,81,86,82,92,82,84,82,91,82,93,82,42,83,127,83,159,83,157,83,223,83,232,84,16,85,1,85,55,85,252,84,229,84,242,84,6,85,250,84,20,85,233,84,237,84,225,84,9,85,238,84,234,84,230,84,39,85,7,85,253,84,15,85,3,87,4,87,194,87,212,87,203,87,195,87,9,88,15,89,87,89,88,89,90,89,17,90,24,90,28,90,31,90,27,90,19,90,236,89,32,90,35,90,41,90,37,90,12,90,9,90,107,91,88,92,176,91,179,91,182,91,180,91,174,91,181,91,185,91,184,91,4,92,81,92,85,92,80,92,237,92,253,92,251,92,234,92,232,92,240,92,246,92,1,93,244,92,238,93,45,94,43,94,171,94,173,94,167,94,49,95,146,95,145,95,144,95,89,96,99,96,101,96,80,96,85,96,109,96,105,96,111,96,132,96,159,96,154,96,141,96,148,96,140,96,133,96,150,96,71,98,243,98,8,99,255,98,78,99,62,99,47,99,85,99,66,99,70,99,79,99,73,99,58,99,80,99,61,99,42,99,43,99,40,99,77,99,76,99,72,101,73,101,153,101,193,101,197,101,66,102,73,102,79,102,67,102,82,102,76,102,69,102,65,102,248,102,20,103,21,103,23,103,33,104,56,104,72,104,70,104,83,104,57,104,66,104,84,104,41,104,179,104,23,104,76,104,81,104,61,104,244,103,80,104,64,104,60,104,67,104,42,104,69,104,19,104,24,104,65,104,138,107,137,107,183,107,35,108,39,108,40,108,38,108,36,108,240,108,106,109,149,109,136,109,135,109,102,109,120,109,119,109,89,109,147,109,108,109,137,109,110,109,90,109,116,109,105,109,140,109,138,109,121,109,133,109,101,109,148,109,202,112,216,112,228,112,217,112,200,112,207,112,57,114,121,114,252,114,249,114,253,114,248,114,247,114,134,115,237,115,9,116,238,115,224,115,234,115,222,115,84,117,93,117,92,117,90,117,89,117,190,117,197,117,199,117,178,117,179,117,189,117,188,117,185,117,194,117,184,117,139,118,176,118,202,118,205,118,206,118,41,119,31,119,32,119,40,119,233,119,48,120,39,120,56,120,29,120,52,120,55,120,37,120,45,120,32,120,31,120,50,120,85,121,80,121,96,121,95,121,86,121,94,121,93,121,87,121,90,121,228,121,227,121,231,121,223,121,230,121,233,121,216,121,132,122,136,122,217,122,6,123,17,123,137,124,33,125,23,125,11,125,10,125,32,125,34,125,20,125,16,125,21,125,26,125,28,125,13,125,25,125,27,125,58,127,95,127,148,127,197,127,193,127,6,128,24,128,21,128,25,128,23,128,61,128,63,128,241,128,2,129,240,128,5,129,237,128,244,128,6,129,248,128,243,128,8,129,253,128,10,129,252,128,239,128,237,129,236,129,0,130,16,130,42,130,43,130,40,130,44,130,187,130,43,131,82,131,84,131,74,131,56,131,80,131,73,131,53,131,52,131,79,131,50,131,57,131,54,131,23,131,64,131,49,131,40,131,67,131,84,134,138,134,170,134,147,134,164,134,169,134,140,134,163,134,156,134,112,136,119,136,129,136,130,136,125,136,121,136,24,138,16,138,14,138,12,138,21,138,10,138,23,138,19,138,22,138,15,138,17,138,72,140,122,140,121,140,161,140,162,140,119,141,172,142,210,142,212,142,207,142,177,143,1,144,6,144,247,143,0,144,250,143,244,143,3,144,253,143,5,144,248,143,149,144,225,144,221,144,226,144,82,145,77,145,76,145,216,145,221,145,215,145,220,145,217,145,131,149,98,150,99,150,97,150,91,150,93,150,100,150,88,150,94,150,187,150,226,152,172,153,168,154,216,154,37,155,50,155,60,155,126,78,122,80,125,80,92,80,71,80,67,80,76,80,90,80,73,80,101,80,118,80,78,80,85,80,117,80,116,80,119,80,79,80,15,80,111,80,109,80,92,81,149,81,240,81,106,82,111,82,210,82,217,82,216,82,213,82,16,83,15,83,25,83,63,83,64,83,62,83,195,83,252,102,70,85,106,85,102,85,68,85,94,85,97,85,67,85,74,85,49,85,86,85,79,85,85,85,47,85,100,85,56,85,46,85,92,85,44,85,99,85,51,85,65,85,87,85,8,87,11,87,9,87,223,87,5,88,10,88,6,88,224,87,228,87,250,87,2,88,53,88,247,87,249,87,32,89,98,89,54,90,65,90,73,90,102,90,106,90,64,90,60,90,98,90,90,90,70,90,74,90,112,91,199,91,197,91,196,91,194,91,191,91,198,91,9,92,8,92,7,92,96,92,92,92,93,92,7,93,6,93,14,93,27,93,22,93,34,93,17,93,41,93,20,93,25,93,36,93,39,93,23,93,226,93,56,94,54,94,51,94,55,94,183,94,184,94,182,94,181,94,190,94,53,95,55,95,87,95,108,95,105,95,107,95,151,95,153,95,158,95,152,95,161,95,160,95,156,95,127,96,163,96,137,96,160,96,168,96,203,96,180,96,230,96,189,96,197,96,187,96,181,96,220,96,188,96,216,96,213,96,198,96,223,96,184,96,218,96,199,96,26,98,27,98,72,98,160,99,167,99,114,99,150,99,162,99,165,99,119,99,103,99,152,99,170,99,113,99,169,99,137,99,131,99,155,99,107,99,168,99,132,99,136,99,153,99,161,99,172,99,146,99,143,99,128,99,123,99,105,99,104,99,122,99,93,101,86,101,81,101,89,101,87,101,95,85,79,101,88,101,85,101,84,101,156,101,155,101,172,101,207,101,203,101,204,101,206,101,93,102,90,102,100,102,104,102,102,102,94,102,249,102,215,82,27,103,129,104,175,104,162,104,147,104,181,104,127,104,118,104,177,104,167,104,151,104,176,104,131,104,196,104,173,104,134,104,133,104,148,104,157,104,168,104,159,104,161,104,130,104,50,107,186,107,235,107,236,107,43,108,142,109,188,109,243,109,217,109,178,109,225,109,204,109,228,109,251,109,250,109,5,110,199,109,203,109,175,109,209,109,174,109,222,109,249,109,184,109,247,109,245,109,197,109,210,109,26,110,181,109,218,109,235,109,216,109,234,109,241,109,238,109,232,109,198,109,196,109,170,109,236,109,191,109,230,109,249,112,9,113,10,113,253,112,239,112,61,114,125,114,129,114,28,115,27,115,22,115,19,115,25,115,135,115,5,116,10,116,3,116,6,116,254,115,13,116,224,116,246,116,247,116,28,117,34,117,101,117,102,117,98,117,112,117,143,117,212,117,213,117,181,117,202,117,205,117,142,118,212,118,210,118,219,118,55,119,62,119,60,119,54,119,56,119,58,119,107,120,67,120,78,120,101,121,104,121,109,121,251,121,146,122,149,122,32,123,40,123,27,123,44,123,38,123,25,123,30,123,46,123,146,124,151,124,149,124,70,125,67,125,113,125,46,125,57,125,60,125,64,125,48,125,51,125,68,125,47,125,66,125,50,125,49,125,61,127,158,127,154,127,204,127,206,127,210,127,28,128,74,128,70,128,47,129,22,129,35,129,43,129,41,129,48,129,36,129,2,130,53,130,55,130,54,130,57,130,142,131,158,131,152,131,120,131,162,131,150,131,189,131,171,131,146,131,138,131,147,131,137,131,160,131,119,131,123,131,124,131,134,131,167,131,85,134,106,95,199,134,192,134,182,134,196,134,181,134,198,134,203,134,177,134,175,134,201,134,83,136,158,136,136,136,171,136,146,136,150,136,141,136,139,136,147,137,143,137,42,138,29,138,35,138,37,138,49,138,45,138,31,138,27,138,34,138,73,140,90,140,169,140,172,140,171,140,168,140,170,140,167,140,103,141,102,141,190,141,186,141,219,142,223,142,25,144,13,144,26,144,23,144,35,144,31,144,29,144,16,144,21,144,30,144,32,144,15,144,34,144,22,144,27,144,20,144,232,144,237,144,253,144,87,145,206,145,245,145,230,145,227,145,231,145,237,145,233,145,137,149,106,150,117,150,115,150,120,150,112,150,116,150,118,150,119,150,108,150,192,150,234,150,233,150,224,122,223,122,2,152,3,152,90,155,229,156,117,158,127,158,165,158,187,158,162,80,141,80,133,80,153,80,145,80,128,80,150,80,152,80,154,80,0,103,241,81,114,82,116,82,117,82,105,82,222,82,221,82,219,82,90,83,165,83,123,85,128,85,167,85,124,85,138,85,157,85,152,85,130,85,156,85,170,85,148,85,135,85,139,85,131,85,179,85,174,85,159,85,62,85,178,85,154,85,187,85,172,85,177,85,126,85,137,85,171,85,153,85,13,87,47,88,42,88,52,88,36,88,48,88,49,88,33,88,29,88,32,88,249,88,250,88,96,89,119,90,154,90,127,90,146,90,155,90,167,90,115,91,113,91,210,91,204,91,211,91,208,91,10,92,11,92,49,92,76,93,80,93,52,93,71,93,253,93,69,94,61,94,64,94,67,94,126,94,202,94,193,94,194,94,196,94,60,95,109,95,169,95,170,95,168,95,209,96,225,96,178,96,182,96,224,96,28,97,35,97,250,96,21,97,240,96,251,96,244,96,104,97,241,96,14,97,246,96,9,97,0,97,18,97,31,98,73,98,163,99,140,99,207,99,192,99,233,99,201,99,198,99,205,99,210,99,227,99,208,99,225,99,214,99,237,99,238,99,118,99,244,99,234,99,219,99,82,100,218,99,249,99,94,101,102,101,98,101,99,101,145,101,144,101,175,101,110,102,112,102,116,102,118,102,111,102,145,102,122,102,126,102,119,102,254,102,255,102,31,103,29,103,250,104,213,104,224,104,216,104,215,104,5,105,223,104,245,104,238,104,231,104,249,104,210,104,242,104,227,104,203,104,205,104,13,105,18,105,14,105,201,104,218,104,110,105,251,104,62,107,58,107,61,107,152,107,150,107,188,107,239,107,46,108,47,108,44,108,47,110,56,110,84,110,33,110,50,110,103,110,74,110,32,110,37,110,35,110,27,110,91,110,88,110,36,110,86,110,110,110,45,110,38,110,111,110,52,110,77,110,58,110,44,110,67,110,29,110,62,110,203,110,137,110,25,110,78,110,99,110,68,110,114,110,105,110,95,110,25,113,26,113,38,113,48,113,33,113,54,113,110,113,28,113,76,114,132,114,128,114,54,115,37,115,52,115,41,115,58,116,42,116,51,116,34,116,37,116,53,116,54,116,52,116,47,116,27,116,38,116,40,116,37,117,38,117,107,117,106,117,226,117,219,117,227,117,217,117,216,117,222,117,224,117,123,118,124,118,150,118,147,118,180,118,220,118,79,119,237,119,93,120,108,120,111,120,13,122,8,122,11,122,5,122,0,122,152,122,151,122,150,122,229,122,227,122,73,123,86,123,70,123,80,123,82,123,84,123,77,123,75,123,79,123,81,123,159,124,165,124,94,125,80,125,104,125,85,125,43,125,110,125,114,125,97,125,102,125,98,125,112,125,115,125,132,85,212,127,213,127,11,128,82,128,133,128,85,129,84,129,75,129,81,129,78,129,57,129,70,129,62,129,76,129,83,129,116,129,18,130,28,130,233,131,3,132,248,131,13,132,224,131,197,131,11,132,193,131,239,131,241,131,244,131,87,132,10,132,240,131,12,132,204,131,253,131,242,131,202,131,56,132,14,132,4,132,220,131,7,132,212,131,223,131,91,134,223,134,217,134,237,134,212,134,219,134,228,134,208,134,222,134,87,136,193,136,194,136,177,136,131,137,150,137,59,138,96,138,85,138,94,138,60,138,65,138,84,138,91,138,80,138,70,138,52,138,58,138,54,138,86,138,97,140,130,140,175,140,188,140,179,140,189,140,193,140,187,140,192,140,180,140,183,140,182,140,191,140,184,140,138,141,133,141,129,141,206,141,221,141,203,141,218,141,209,141,204,141,219,141,198,141,251,142,248,142,252,142,156,143,46,144,53,144,49,144,56,144,50,144,54,144,2,145,245,144,9,145,254,144,99,145,101,145,207,145,20,146,21,146,35,146,9,146,30,146,13,146,16,146,7,146,17,146,148,149,143,149,139,149,145,149,147,149,146,149,142,149,138,150,142,150,139,150,125,150,133,150,134,150,141,150,114,150,132,150,193,150,197,150,196,150,198,150,199,150,239,150,242,150,204,151,5,152,6,152,8,152,231,152,234,152,239,152,233,152,242,152,237,152,174,153,173,153,195,158,205,158,209,158,130,78,173,80,181,80,178,80,179,80,197,80,190,80,172,80,183,80,187,80,175,80,199,80,127,82,119,82,125,82,223,82,230,82,228,82,226,82,227,82,47,83,223,85,232,85,211,85,230,85,206,85,220,85,199,85,209,85,227,85,228,85,239,85,218,85,225,85,197,85,198,85,229,85,201,85,18,87,19,87,94,88,81,88,88,88,87,88,90,88,84,88,107,88,76,88,109,88,74,88,98,88,82,88,75,88,103,89,193,90,201,90,204,90,190,90,189,90,188,90,179,90,194,90,178,90,105,93,111,93,76,94,121,94,201,94,200,94,18,95,89,95,172,95,174,95,26,97,15,97,72,97,31,97,243,96,27,97,249,96,1,97,8,97,78,97,76,97,68,97,77,97,62,97,52,97,39,97,13,97,6,97,55,97,33,98,34,98,19,100,62,100,30,100,42,100,45,100,61,100,44,100,15,100,28,100,20,100,13,100,54,100,22,100,23,100,6,100,108,101,159,101,176,101,151,102,137,102,135,102,136,102,150,102,132,102,152,102,141,102,3,103,148,105,109,105,90,105,119,105,96,105,84,105,117,105,48,105,130,105,74,105,104,105,107,105,94,105,83,105,121,105,134,105,93,105,99,105,91,105,71,107,114,107,192,107,191,107,211,107,253,107,162,110,175,110,211,110,182,110,194,110,144,110,157,110,199,110,197,110,165,110,152,110,188,110,186,110,171,110,209,110,150,110,156,110,196,110,212,110,170,110,167,110,180,110,78,113,89,113,105,113,100,113,73,113,103,113,92,113,108,113,102,113,76,113,101,113,94,113,70,113,104,113,86,113,58,114,82,114,55,115,69,115,63,115,62,115,111,116,90,116,85,116,95,116,94,116,65,116,63,116,89,116,91,116,92,116,118,117,120,117,0,118,240,117,1,118,242,117,241,117,250,117,255,117,244,117,243,117,222,118,223,118,91,119,107,119,102,119,94,119,99,119,121,119,106,119,108,119,92,119,101,119,104,119,98,119,238,119,142,120,176,120,151,120,152,120,140,120,137,120,124,120,145,120,147,120,127,120,122,121,127,121,129,121,44,132,189,121,28,122,26,122,32,122,20,122,31,122,30,122,159,122,160,122,119,123,192,123,96,123,110,123,103,123,177,124,179,124,181,124,147,125,121,125,145,125,129,125,143,125,91,125,110,127,105,127,106,127,114,127,169,127,168,127,164,127,86,128,88,128,134,128,132,128,113,129,112,129,120,129,101,129,110,129,115,129,107,129,121,129,122,129,102,129,5,130,71,130,130,132,119,132,61,132,49,132,117,132,102,132,107,132,73,132,108,132,91,132,60,132,53,132,97,132,99,132,105,132,109,132,70,132,94,134,92,134,95,134,249,134,19,135,8,135,7,135,0,135,254,134,251,134,2,135,3,135,6,135,10,135,89,136,223,136,212,136,217,136,220,136,216,136,221,136,225,136,202,136,213,136,210,136,156,137,227,137,107,138,114,138,115,138,102,138,105,138,112,138,135,138,124,138,99,138,160,138,113,138,133,138,109,138,98,138,110,138,108,138,121,138,123,138,62,138,104,138,98,140,138,140,137,140,202,140,199,140,200,140,196,140,178,140,195,140,194,140,197,140,225,141,223,141,232,141,239,141,243,141,250,141,234,141,228,141,230,141,178,142,3,143,9,143,254,142,10,143,159,143,178,143,75,144,74,144,83,144,66,144,84,144,60,144,85,144,80,144,71,144,79,144,78,144,77,144,81,144,62,144,65,144,18,145,23,145,108,145,106,145,105,145,201,145,55,146,87,146,56,146,61,146,64,146,62,146,91,146,75,146,100,146,81,146,52,146,73,146,77,146,69,146,57,146,63,146,90,146,152,149,152,150,148,150,149,150,205,150,203,150,201,150,202,150,247,150,251,150,249,150,246,150,86,151,116,151,118,151,16,152,17,152,19,152,10,152,18,152,12,152,252,152,244,152,253,152,254,152,179,153,177,153,180,153,225,154,233,156,130,158,14,159,19,159,32,159,231,80,238,80,229,80,214,80,237,80,218,80,213,80,207,80,209,80,241,80,206,80,233,80,98,81,243,81,131,82,130,82,49,83,173,83,254,85,0,86,27,86,23,86,253,85,20,86,6,86,9,86,13,86,14,86,247,85,22,86,31,86,8,86,16,86,246,85,24,87,22,87,117,88,126,88,131,88,147,88,138,88,121,88,133,88,125,88,253,88,37,89,34,89,36,89,106,89,105,89,225,90,230,90,233,90,215,90,214,90,216,90,227,90,117,91,222,91,231,91,225,91,229,91,230,91,232,91,226,91,228,91,223,91,13,92,98,92,132,93,135,93,91,94,99,94,85,94,87,94,84,94,211,94,214,94,10,95,70,95,112,95,185,95,71,97,63,97,75,97,119,97,98,97,99,97,95,97,90,97,88,97,117,97,42,98,135,100,88,100,84,100,164,100,120,100,95,100,122,100,81,100,103,100,52,100,109,100,123,100,114,101,161,101,215,101,214,101,162,102,168,102,157,102,156,105,168,105,149,105,193,105,174,105,211,105,203,105,155,105,183,105,187,105,171,105,180,105,208,105,205,105,173,105,204,105,166,105,195,105,163,105,73,107,76,107,51,108,51,111,20,111,254,110,19,111,244,110,41,111,62,111,32,111,44,111,15,111,2,111,34,111,255,110,239,110,6,111,49,111,56,111,50,111,35,111,21,111,43,111,47,111,136,111,42,111,236,110,1,111,242,110,204,110,247,110,148,113,153,113,125,113,138,113,132,113,146,113,62,114,146,114,150,114,68,115,80,115,100,116,99,116,106,116,112,116,109,116,4,117,145,117,39,118,13,118,11,118,9,118,19,118,225,118,227,118,132,119,125,119,127,119,97,119,193,120,159,120,167,120,179,120,169,120,163,120,142,121,143,121,141,121,46,122,49,122,170,122,169,122,237,122,239,122,161,123,149,123,139,123,117,123,151,123,157,123,148,123,143,123,184,123,135,123,132,123,185,124,189,124,190,124,187,125,176,125,156,125,189,125,190,125,160,125,202,125,180,125,178,125,177,125,186,125,162,125,191,125,181,125,184,125,173,125,210,125,199,125,172,125,112,127,224,127,225,127,223,127,94,128,90,128,135,128,80,129,128,129,143,129,136,129,138,129,127,129,130,129,231,129,250,129,7,130,20,130,30,130,75,130,201,132,191,132,198,132,196,132,153,132,158,132,178,132,156,132,203,132,184,132,192,132,211,132,144,132,188,132,209,132,202,132,63,135,28,135,59,135,34,135,37,135,52,135,24,135,85,135,55,135,41,135,243,136,2,137,244,136,249,136,248,136,253,136,232,136,26,137,239,136,166,138,140,138,158,138,163,138,141,138,161,138,147,138,164,138,170,138,165,138,168,138,152,138,145,138,154,138,167,138,106,140,141,140,140,140,211,140,209,140,210,140,107,141,153,141,149,141,252,141,20,143,18,143,21,143,19,143,163,143,96,144,88,144,92,144,99,144,89,144,94,144,98,144,93,144,91,144,25,145,24,145,30,145,117,145,120,145,119,145,116,145,120,146,128,146,133,146,152,146,150,146,123,146,147,146,156,146,168,146,124,146,145,146,161,149,168,149,169,149,163,149,165,149,164,149,153,150,156,150,155,150,204,150,210,150,0,151,124,151,133,151,246,151,23,152,24,152,175,152,177,152,3,153,5,153,12,153,9,153,193,153,175,154,176,154,230,154,65,155,66,155,244,156,246,156,243,156,188,158,59,159,74,159,4,81,0,81,251,80,245,80,249,80,2,81,8,81,9,81,5,81,220,81,135,82,136,82,137,82,141,82,138,82,240,82,178,83,46,86,59,86,57,86,50,86,63,86,52,86,41,86,83,86,78,86,87,86,116,86,54,86,47,86,48,86,128,88,159,88,158,88,179,88,156,88,174,88,169,88,166,88,109,89,9,91,251,90,11,91,245,90,12,91,8,91,238,91,236,91,233,91,235,91,100,92,101,92,157,93,148,93,98,94,95,94,97,94,226,94,218,94,223,94,221,94,227,94,224,94,72,95,113,95,183,95,181,95,118,97,103,97,110,97,93,97,85,97,130,97,124,97,112,97,107,97,126,97,167,97,144,97,171,97,142,97,172,97,154,97,164,97,148,97,174,97,46,98,105,100,111,100,121,100,158,100,178,100,136,100,144,100,176,100,165,100,147,100,149,100,169,100,146,100,174,100,173,100,171,100,154,100,172,100,153,100,162,100,179,100,117,101,119,101,120,101,174,102,171,102,180,102,177,102,35,106,31,106,232,105,1,106,30,106,25,106,253,105,33,106,19,106,10,106,243,105,2,106,5,106,237,105,17,106,80,107,78,107,164,107,197,107,198,107,63,111,124,111,132,111,81,111,102,111,84,111,134,111,109,111,91,111,120,111,110,111,142,111,122,111,112,111,100,111,151,111,88,111,213,110,111,111,96,111,95,111,159,113,172,113,177,113,168,113,86,114,155,114,78,115,87,115,105,116,139,116,131,116,126,116,128,116,127,117,32,118,41,118,31,118,36,118,38,118,33,118,34,118,154,118,186,118,228,118,142,119,135,119,140,119,145,119,139,119,203,120,197,120,186,120,202,120,190,120,213,120,188,120,208,120,63,122,60,122,64,122,61,122,55,122,59,122,175,122,174,122,173,123,177,123,196,123,180,123,198,123,199,123,193,123,160,123,204,123,202,124,224,125,244,125,239,125,251,125,216,125,236,125,221,125,232,125,227,125,218,125,222,125,233,125,158,125,217,125,242,125,249,125,117,127,119,127,175,127,233,127,38,128,155,129,156,129,157,129,160,129,154,129,152,129,23,133,61,133,26,133,238,132,44,133,45,133,19,133,17,133,35,133,33,133,20,133,236,132,37,133,255,132,6,133,130,135,116,135,118,135,96,135,102,135,120,135,104,135,89,135,87,135,76,135,83,135,91,136,93,136,16,137,7,137,18,137,19,137,21,137,10,137,188,138,210,138,199,138,196,138,149,138,203,138,248,138,178,138,201,138,194,138,191,138,176,138,214,138,205,138,182,138,185,138,219,138,76,140,78,140,108,140,224,140,222,140,230,140,228,140,236,140,237,140,226,140,227,140,220,140,234,140,225,140,109,141,159,141,163,141,43,142,16,142,29,142,34,142,15,142,41,142,31,142,33,142,30,142,186,142,29,143,27,143,31,143,41,143,38,143,42,143,28,143,30,143,37,143,105,144,110,144,104,144,109,144,119,144,48,145,45,145,39,145,49,145,135,145,137,145,139,145,131,145,197,146,187,146,183,146,234,146,172,146,228,146,193,146,179,146,188,146,210,146,199,146,240,146,178,146,173,149,177,149,4,151,6,151,7,151,9,151,96,151,141,151,139,151,143,151,33,152,43,152,28,152,179,152,10,153,19,153,18,153,24,153,221,153,208,153,223,153,219,153,209,153,213,153,210,153,217,153,183,154,238,154,239,154,39,155,69,155,68,155,119,155,111,155,6,157,9,157,3,157,169,158,190,158,206,158,168,88,82,159,18,81,24,81,20,81,16,81,21,81,128,81,170,81,221,81,145,82,147,82,243,82,89,86,107,86,121,86,105,86,100,86,120,86,106,86,104,86,101,86,113,86,111,86,108,86,98,86,118,86,193,88,190,88,199,88,197,88,110,89,29,91,52,91,120,91,240,91,14,92,74,95,178,97,145,97,169,97,138,97,205,97,182,97,190,97,202,97,200,97,48,98,197,100,193,100,203,100,187,100,188,100,218,100,196,100,199,100,194,100,205,100,191,100,210,100,212,100,190,100,116,101,198,102,201,102,185,102,196,102,199,102,184,102,61,106,56,106,58,106,89,106,107,106,88,106,57,106,68,106,98,106,97,106,75,106,71,106,53,106,95,106,72,106,89,107,119,107,5,108,194,111,177,111,161,111,195,111,164,111,193,111,167,111,179,111,192,111,185,111,182,111,166,111,160,111,180,111,190,113,201,113,208,113,210,113,200,113,213,113,185,113,206,113,217,113,220,113,195,113,196,113,104,115,156,116,163,116,152,116,159,116,158,116,226,116,12,117,13,117,52,118,56,118,58,118,231,118,229,118,160,119,158,119,159,119,165,119,232,120,218,120,236,120,231,120,166,121,77,122,78,122,70,122,76,122,75,122,186,122,217,123,17,124,201,123,228,123,219,123,225,123,233,123,230,123,213,124,214,124,10,126,17,126,8,126,27,126,35,126,30,126,29,126,9,126,16,126,121,127,178,127,240,127,241,127,238,127,40,128,179,129,169,129,168,129,251,129,8,130,88,130,89,130,74,133,89,133,72,133,104,133,105,133,67,133,73,133,109,133,106,133,94,133,131,135,159,135,158,135,162,135,141,135,97,136,42,137,50,137,37,137,43,137,33,137,170,137,166,137,230,138,250,138,235,138,241,138,0,139,220,138,231,138,238,138,254,138,1,139,2,139,247,138,237,138,243,138,246,138,252,138,107,140,109,140,147,140,244,140,68,142,49,142,52,142,66,142,57,142,53,142,59,143,47,143,56,143,51,143,168,143,166,143,117,144,116,144,120,144,114,144,124,144,122,144,52,145,146,145,32,147,54,147,248,146,51,147,47,147,34,147,252,146,43,147,4,147,26,147,16,147,38,147,33,147,21,147,46,147,25,147,187,149,167,150,168,150,170,150,213,150,14,151,17,151,22,151,13,151,19,151,15,151,91,151,92,151,102,151,152,151,48,152,56,152,59,152,55,152,45,152,57,152,36,152,16,153,40,153,30,153,27,153,33,153,26,153,237,153,226,153,241,153,184,154,188,154,251,154,237,154,40,155,145,155,21,157,35,157,38,157,40,157,18,157,27,157,216,158,212,158,141,159,156,159,42,81,31,81,33,81,50,81,245,82,142,86,128,86,144,86,133,86,135,86,143,86,213,88,211,88,209,88,206,88,48,91,42,91,36,91,122,91,55,92,104,92,188,93,186,93,189,93,184,93,107,94,76,95,189,95,201,97,194,97,199,97,230,97,203,97,50,98,52,98,206,100,202,100,216,100,224,100,240,100,230,100,236,100,241,100,226,100,237,100,130,101,131,101,217,102,214,102,128,106,148,106,132,106,162,106,156,106,219,106,163,106,126,106,151,106,144,106,160,106,92,107,174,107,218,107,8,108,216,111,241,111,223,111,224,111,219,111,228,111,235,111,239,111,128,111,236,111,225,111,233,111,213,111,238,111,240,111,231,113,223,113,238,113,230,113,229,113,237,113,236,113,244,113,224,113,53,114,70,114,112,115,114,115,169,116,176,116,166,116,168,116,70,118,66,118,76,118,234,118,179,119,170,119,176,119,172,119,167,119,173,119,239,119,247,120,250,120,244,120,239,120,1,121,167,121,170,121,87,122,191,122,7,124,13,124,254,123,247,123,12,124,224,123,224,124,220,124,222,124,226,124,223,124,217,124,221,124,46,126,62,126,70,126,55,126,50,126,67,126,43,126,61,126,49,126,69,126,65,126,52,126,57,126,72,126,53,126,63,126,47,126,68,127,243,127,252,127,113,128,114,128,112,128,111,128,115,128,198,129,195,129,186,129,194,129,192,129,191,129,189,129,201,129,190,129,232,129,9,130,113,130,170,133,132,133,126,133,156,133,145,133,148,133,175,133,155,133,135,133,168,133,138,133,103,134,192,135,209,135,179,135,210,135,198,135,171,135,187,135,186,135,200,135,203,135,59,137,54,137,68,137,56,137,61,137,172,137,14,139,23,139,25,139,27,139,10,139,32,139,29,139,4,139,16,139,65,140,63,140,115,140,250,140,253,140,252,140,248,140,251,140,168,141,73,142,75,142,72,142,74,142,68,143,62,143,66,143,69,143,63,143,127,144,125,144,132,144,129,144,130,144,128,144,57,145,163,145,158,145,156,145,77,147,130,147,40,147,117,147,74,147,101,147,75,147,24,147,126,147,108,147,91,147,112,147,90,147,84,147,202,149,203,149,204,149,200,149,198,149,177,150,184,150,214,150,28,151,30,151,160,151,211,151,70,152,182,152,53,153,1,154,255,153,174,155,171,155,170,155,173,155,59,157,63,157,139,158,207,158,222,158,220,158,221,158,219,158,62,159,75,159,226,83,149,86,174,86,217,88,216,88,56,91,93,95,227,97,51,98,244,100,242,100,254,100,6,101,250,100,251,100,247,100,183,101,220,102,38,103,179,106,172,106,195,106,187,106,184,106,194,106,174,106,175,106,95,107,120,107,175,107,9,112,11,112,254,111,6,112,250,111,17,112,15,112,251,113,252,113,254,113,248,113,119,115,117,115,167,116,191,116,21,117,86,118,88,118,82,118,189,119,191,119,187,119,188,119,14,121,174,121,97,122,98,122,96,122,196,122,197,122,43,124,39,124,42,124,30,124,35,124,33,124,231,124,84,126,85,126,94,126,90,126,97,126,82,126,89,126,72,127,249,127,251,127,119,128,118,128,205,129,207,129,10,130,207,133,169,133,205,133,208,133,201,133,176,133,186,133,185,133,166,133,239,135,236,135,242,135,224,135,134,137,178,137,244,137,40,139,57,139,44,139,43,139,80,140,5,141,89,142,99,142,102,142,100,142,95,142,85,142,192,142,73,143,77,143,135,144,131,144,136,144,171,145,172,145,208,145,148,147,138,147,150,147,162,147,179,147,174,147,172,147,176,147,152,147,154,147,151,147,212,149,214,149,208,149,213,149,226,150,220,150,217,150,219,150,222,150,36,151,163,151,166,151,173,151,249,151,77,152,79,152,76,152,78,152,83,152,186,152,62,153,63,153,61,153,46,153,165,153,14,154,193,154,3,155,6,155,79,155,78,155,77,155,202,155,201,155,253,155,200,155,192,155,81,157,93,157,96,157,224,158,21,159,44,159,51,81,165,86,222,88,223,88,226,88,245,91,144,159,236,94,242,97,247,97,246,97,245,97,0,101,15,101,224,102,221,102,229,106,221,106,218,106,211,106,27,112,31,112,40,112,26,112,29,112,21,112,24,112,6,114,13,114,88,114,162,114,120,115,122,115,189,116,202,116,227,116,135,117,134,117,95,118,97,118,199,119,25,121,177,121,107,122,105,122,62,124,63,124,56,124,61,124,55,124,64,124,107,126,109,126,121,126,105,126,106,126,133,127,115,126,182,127,185,127,184,127,216,129,233,133,221,133,234,133,213,133,228,133,229,133,247,133,251,135,5,136,13,136,249,135,254,135,96,137,95,137,86,137,94,137,65,139,92,139,88,139,73,139,90,139,78,139,79,139,70,139,89,139,8,141,10,141,124,142,114,142,135,142,118,142,108,142,122,142,116,142,84,143,78,143,173,143,138,144,139,144,177,145,174,145,225,147,209,147,223,147,195,147,200,147,220,147,221,147,214,147,226,147,205,147,216,147,228,147,215,147,232,147,220,149,180,150,227,150,42,151,39,151,97,151,220,151,251,151,94,152,88,152,91,152,188,152,69,153,73,153,22,154,25,154,13,155,232,155,231,155,214,155,219,155,137,157,97,157,114,157,106,157,108,157,146,158,151,158,147,158,180,158,248,82,168,86,183,86,182,86,180,86,188,86,228,88,64,91,67,91,125,91,246,91,201,93,248,97,250,97,24,101,20,101,25,101,230,102,39,103,236,106,62,112,48,112,50,112,16,114,123,115,207,116,98,118,101,118,38,121,42,121,44,121,43,121,199,122,246,122,76,124,67,124,77,124,239,124,240,124,174,143,125,126,124,126,130,126,76,127,0,128,218,129,102,130,251,133,249,133,17,134,250,133,6,134,11,134,7,134,10,134,20,136,21,136,100,137,186,137,248,137,112,139,108,139,102,139,111,139,95,139,107,139,15,141,13,141,137,142,129,142,133,142,130,142,180,145,203,145,24,148,3,148,253,147,225,149,48,151,196,152,82,153,81,153,168,153,43,154,48,154,55,154,53,154,19,156,13,156,121,158,181,158,232,158,47,159,95,159,99,159,97,159,55,81,56,81,193,86,192,86,194,86,20,89,108,92,205,93,252,97,254,97,29,101,28,101,149,101,233,102,251,106,4,107,250,106,178,107,76,112,27,114,167,114,214,116,212,116,105,118,211,119,80,124,143,126,140,126,188,127,23,134,45,134,26,134,35,136,34,136,33,136,31,136,106,137,108,137,189,137,116,139,119,139,125,139,19,141,138,142,141,142,139,142,95,143,175,143,186,145,46,148,51,148,53,148,58,148,56,148,50,148,43,148,226,149,56,151,57,151,50,151,255,151,103,152,101,152,87,153,69,154,67,154,64,154,62,154,207,154,84,155,81,155,45,156,37,156,175,157,180,157,194,157,184,157,157,158,239,158,25,159,92,159,102,159,103,159,60,81,59,81,200,86,202,86,201,86,127,91,212,93,210,93,78,95,255,97,36,101,10,107,97,107,81,112,88,112,128,115,228,116,138,117,110,118,108,118,179,121,96,124,95,124,126,128,125,128,223,129,114,137,111,137,252,137,128,139,22,141,23,141,145,142,147,142,97,143,72,145,68,148,81,148,82,148,61,151,62,151,195,151,193,151,107,152,85,153,85,154,77,154,210,154,26,155,73,156,49,156,62,156,59,156,211,157,215,157,52,159,108,159,106,159,148,159,204,86,214,93,0,98,35,101,43,101,42,101,236,102,16,107,218,116,202,122,100,124,99,124,101,124,147,126,150,126,148,126,226,129,56,134,63,134,49,136,138,139,144,144,143,144,99,148,96,148,100,148,104,151,111,152,92,153,90,154,91,154,87,154,211,154,212,154,209,154,84,156,87,156,86,156,229,157,159,158,244,158,209,86,233,88,44,101,94,112,113,118,114,118,215,119,80,127,136,127,54,136,57,136,98,136,147,139,146,139,150,139,119,130,27,141,192,145,106,148,66,151,72,151,68,151,198,151,112,152,95,154,34,155,88,155,95,156,249,157,250,157,124,158,125,158,7,159,119,159,114,159,243,94,22,107,99,112,108,124,110,124,59,136,192,137,161,142,193,145,114,148,112,148,113,152,94,153,214,154,35,155,204,158,100,112,218,119,154,139,119,148,201,151,98,154,101,154,156,126,156,139,170,142,197,145,125,148,126,148,124,148,119,156,120,156,247,158,84,140,127,148,26,158,40,114,106,154,49,155,27,158,30,158,114,124,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,54,78,63,78,133,78,160,78,130,81,150,81,171,81,249,82,56,83,105,83,182,83,10,89,128,91,219,93,122,94,127,94,244,94,80,95,97,95,52,101,224,101,146,117,118,118,181,143,182,150,168,0,198,2,253,48,254,48,157,48,158,48,0,0,0,0,5,48,6,48,7,48,252,48,59,255,61,255,61,39,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,231,33,184,33,185,33,207,49,204,0,90,78,138,0,2,82,145,68,176,159,136,81,177,159,7,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,255,228,255,7,255,2,255,49,50,22,33,33,33,155,48,156,48,128,46,132,46,134,46,135,46,136,46,138,46,140,46,141,46,149,46,156,46,157,46,165,46,167,46,170,46,172,46,174,46,182,46,188,46,190,46,198,46,202,46,204,46,205,46,207,46,214,46,215,46,222,46,227,46,0,0,0,0,0,0,131,2,80,2,91,2,84,2,117,2,83,1,248,0,75,1,138,2,106,2,66,78,92,78,245,81,26,83,130,83,7,78,12,78,71,78,141,78,215,86,12,250,110,92,115,95,15,78,135,81,14,78,46,78,147,78,194,78,201,78,200,78,152,81,252,82,108,83,185,83,32,87,3,89,44,89,16,92,255,93,225,101,179,107,204,107,20,108,63,114,49,78,60,78,232,78,220,78,233,78,225,78,221,78,218,78,12,82,28,83,76,83,34,87,35,87,23,89,47,89,129,91,132,91,18,92,59,92,116,92,115,92,4,94,128,94,130,94,201,95,9,98,80,98,21,108,54,108,67,108,63,108,59,108,174,114,176,114,138,115,184,121,138,128,30,150,14,79,24,79,44,79,245,78,20,79,241,78,0,79,247,78,8,79,29,79,2,79,5,79,34,79,19,79,4,79,244,78,18,79,177,81,19,82,9,82,16,82,166,82,34,83,31,83,77,83,138,83,7,84,225,86,223,86,46,87,42,87,52,87,60,89,128,89,124,89,133,89,123,89,126,89,119,89,127,89,86,91,21,92,37,92,124,92,122,92,123,92,126,92,223,93,117,94,132,94,2,95,26,95,116,95,213,95,212,95,207,95,92,98,94,98,100,98,97,98,102,98,98,98,89,98,96,98,90,98,101,98,239,101,238,101,62,103,57,103,56,103,59,103,58,103,63,103,60,103,51,103,24,108,70,108,82,108,92,108,79,108,74,108,84,108,75,108,76,108,113,112,94,114,180,114,181,114,142,115,42,117,127,118,117,122,81,127,120,130,124,130,128,130,125,130,127,130,77,134,126,137,153,144,151,144,152,144,155,144,148,144,34,150,36,150,32,150,35,150,86,79,59,79,98,79,73,79,83,79,100,79,62,79,103,79,82,79,95,79,65,79,88,79,45,79,51,79,63,79,97,79,143,81,185,81,28,82,30,82,33,82,173,82,174,82,9,83,99,83,114,83,142,83,143,83,48,84,55,84,42,84,84,84,69,84,25,84,28,84,37,84,24,84,61,84,79,84,65,84,40,84,36,84,71,84,238,86,231,86,229,86,65,87,69,87,76,87,73,87,75,87,82,87,6,89,64,89,166,89,152,89,160,89,151,89,142,89,162,89,144,89,143,89,167,89,161,89,142,91,146,91,40,92,42,92,141,92,143,92,136,92,139,92,137,92,146,92,138,92,134,92,147,92,149,92,224,93,10,94,14,94,139,94,137,94,140,94,136,94,141,94,5,95,29,95,120,95,118,95,210,95,209,95,208,95,237,95,232,95,238,95,243,95,225,95,228,95,227,95,250,95,239,95,247,95,251,95,0,96,244,95,58,98,131,98,140,98,142,98,143,98,148,98,135,98,113,98,123,98,122,98,112,98,129,98,136,98,119,98,125,98,114,98,116,98,55,101,240,101,244,101,243,101,242,101,245,101,69,103,71,103,89,103,85,103,76,103,72,103,93,103,77,103,90,103,75,103,208,107,25,108,26,108,120,108,103,108,107,108,132,108,139,108,143,108,113,108,111,108,105,108,154,108,109,108,135,108,149,108,156,108,102,108,115,108,101,108,123,108,142,108,116,112,122,112,99,114,191,114,189,114,195,114,198,114,193,114,186,114,197,114,149,115,151,115,147,115,148,115,146,115,58,117,57,117,148,117,149,117,129,118,61,121,52,128,149,128,153,128,144,128,146,128,156,128,144,130,143,130,133,130,142,130,145,130,147,130,138,130,131,130,132,130,120,140,201,143,191,143,159,144,161,144,165,144,158,144,167,144,160,144,48,150,40,150,47,150,45,150,51,78,152,79,124,79,133,79,125,79,128,79,135,79,118,79,116,79,137,79,132,79,119,79,76,79,151,79,106,79,154,79,121,79,129,79,120,79,144,79,156,79,148,79,158,79,146,79,130,79,149,79,107,79,110,79,158,81,188,81,190,81,53,82,50,82,51,82,70,82,49,82,188,82,10,83,11,83,60,83,146,83,148,83,135,84,127,84,129,84,145,84,130,84,136,84,107,84,122,84,126,84,101,84,108,84,116,84,102,84,141,84,111,84,97,84,96,84,152,84,99,84,103,84,100,84,247,86,249,86,111,87,114,87,109,87,107,87,113,87,112,87,118,87,128,87,117,87,123,87,115,87,116,87,98,87,104,87,125,87,12,89,69,89,181,89,186,89,207,89,206,89,178,89,204,89,193,89,182,89,188,89,195,89,214,89,177,89,189,89,192,89,200,89,180,89,199,89,98,91,101,91,147,91,149,91,68,92,71,92,174,92,164,92,160,92,181,92,175,92,168,92,172,92,159,92,163,92,173,92,162,92,170,92,167,92,157,92,165,92,182,92,176,92,166,92,23,94,20,94,25,94,40,95,34,95,35,95,36,95,84,95,130,95,126,95,125,95,222,95,229,95,45,96,38,96,25,96,50,96,11,96,52,96,10,96,23,96,51,96,26,96,30,96,44,96,34,96,13,96,16,96,46,96,19,96,17,96,12,96,9,96,28,96,20,98,61,98,173,98,180,98,209,98,190,98,170,98,182,98,202,98,174,98,179,98,175,98,187,98,169,98,176,98,184,98,61,101,168,101,187,101,9,102,252,101,4,102,18,102,8,102,251,101,3,102,11,102,13,102,5,102,253,101,17,102,16,102,246,102,10,103,133,103,108,103,142], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1707205);
/* memory initializer */ allocate([103,146,103,118,103,123,103,152,103,134,103,132,103,116,103,141,103,140,103,122,103,159,103,145,103,153,103,131,103,125,103,129,103,120,103,121,103,148,103,37,107,128,107,126,107,222,107,29,108,147,108,236,108,235,108,238,108,217,108,182,108,212,108,173,108,231,108,183,108,208,108,194,108,186,108,195,108,198,108,237,108,242,108,210,108,221,108,180,108,138,108,157,108,128,108,222,108,192,108,48,109,205,108,199,108,176,108,249,108,207,108,233,108,209,108,148,112,152,112,133,112,147,112,134,112,132,112,145,112,150,112,130,112,154,112,131,112,106,114,214,114,203,114,216,114,201,114,220,114,210,114,212,114,218,114,204,114,209,114,164,115,161,115,173,115,166,115,162,115,160,115,172,115,157,115,221,116,232,116,63,117,64,117,62,117,140,117,152,117,175,118,243,118,241,118,240,118,245,118,248,119,252,119,249,119,251,119,250,119,247,119,66,121,63,121,197,121,120,122,123,122,251,122,117,124,253,124,53,128,143,128,174,128,163,128,184,128,181,128,173,128,32,130,160,130,192,130,171,130,154,130,152,130,155,130,181,130,167,130,174,130,188,130,158,130,186,130,180,130,168,130,161,130,169,130,194,130,164,130,195,130,182,130,162,130,112,134,111,134,109,134,110,134,86,140,210,143,203,143,211,143,205,143,214,143,213,143,215,143,178,144,180,144,175,144,179,144,176,144,57,150,61,150,60,150,58,150,67,150,205,79,197,79,211,79,178,79,201,79,203,79,193,79,212,79,220,79,217,79,187,79,179,79,219,79,199,79,214,79,186,79,192,79,185,79,236,79,68,82,73,82,192,82,194,82,61,83,124,83,151,83,150,83,153,83,152,83,186,84,161,84,173,84,165,84,207,84,195,84,13,131,183,84,174,84,214,84,182,84,197,84,198,84,160,84,112,84,188,84,162,84,190,84,114,84,222,84,176,84,181,87,158,87,159,87,164,87,140,87,151,87,157,87,155,87,148,87,152,87,143,87,153,87,165,87,154,87,149,87,244,88,13,89,83,89,225,89,222,89,238,89,0,90,241,89,221,89,250,89,253,89,252,89,246,89,228,89,242,89,247,89,219,89,233,89,243,89,245,89,224,89,254,89,244,89,237,89,168,91,76,92,208,92,216,92,204,92,215,92,203,92,219,92,222,92,218,92,201,92,199,92,202,92,214,92,211,92,212,92,207,92,200,92,198,92,206,92,223,92,248,92,249,93,33,94,34,94,35,94,32,94,36,94,176,94,164,94,162,94,155,94,163,94,165,94,7,95,46,95,86,95,134,95,55,96,57,96,84,96,114,96,94,96,69,96,83,96,71,96,73,96,91,96,76,96,64,96,66,96,95,96,36,96,68,96,88,96,102,96,110,96,66,98,67,98,207,98,13,99,11,99,245,98,14,99,3,99,235,98,249,98,15,99,12,99,248,98,246,98,0,99,19,99,20,99,250,98,21,99,251,98,240,98,65,101,67,101,170,101,191,101,54,102,33,102,50,102,53,102,28,102,38,102,34,102,51,102,43,102,58,102,29,102,52,102,57,102,46,102,15,103,16,103,193,103,242,103,200,103,186,103,220,103,187,103,248,103,216,103,192,103,183,103,197,103,235,103,228,103,223,103,181,103,205,103,179,103,247,103,246,103,238,103,227,103,194,103,185,103,206,103,231,103,240,103,178,103,252,103,198,103,237,103,204,103,174,103,230,103,219,103,250,103,201,103,202,103,195,103,234,103,203,103,40,107,130,107,132,107,182,107,214,107,216,107,224,107,32,108,33,108,40,109,52,109,45,109,31,109,60,109,63,109,18,109,10,109,218,108,51,109,4,109,25,109,58,109,26,109,17,109,0,109,29,109,66,109,1,109,24,109,55,109,3,109,15,109,64,109,7,109,32,109,44,109,8,109,34,109,9,109,16,109,183,112,159,112,190,112,177,112,176,112,161,112,180,112,181,112,169,112,65,114,73,114,74,114,108,114,112,114,115,114,110,114,202,114,228,114,232,114,235,114,223,114,234,114,230,114,227,114,133,115,204,115,194,115,200,115,197,115,185,115,182,115,181,115,180,115,235,115,191,115,199,115,190,115,195,115,198,115,184,115,203,115,236,116,238,116,46,117,71,117,72,117,167,117,170,117,121,118,196,118,8,119,3,119,4,119,5,119,10,119,247,118,251,118,250,118,231,119,232,119,6,120,17,120,18,120,5,120,16,120,15,120,14,120,9,120,3,120,19,120,74,121,76,121,75,121,69,121,68,121,213,121,205,121,207,121,214,121,206,121,128,122,126,122,209,122,0,123,1,123,122,124,120,124,121,124,127,124,128,124,129,124,3,125,8,125,1,125,88,127,145,127,141,127,190,127,7,128,14,128,15,128,20,128,55,128,216,128,199,128,224,128,209,128,200,128,194,128,208,128,197,128,227,128,217,128,220,128,202,128,213,128,201,128,207,128,215,128,230,128,205,128,255,129,33,130,148,130,217,130,254,130,249,130,7,131,232,130,0,131,213,130,58,131,235,130,214,130,244,130,236,130,225,130,242,130,245,130,12,131,251,130,246,130,240,130,234,130,228,130,224,130,250,130,243,130,237,130,119,134,116,134,124,134,115,134,65,136,78,136,103,136,106,136,105,136,211,137,4,138,7,138,114,141,227,143,225,143,238,143,224,143,241,144,189,144,191,144,213,144,197,144,190,144,199,144,203,144,200,144,212,145,211,145,84,150,79,150,81,150,83,150,74,150,78,150,30,80,5,80,7,80,19,80,34,80,48,80,27,80,245,79,244,79,51,80,55,80,44,80,246,79,247,79,23,80,28,80,32,80,39,80,53,80,47,80,49,80,14,80,90,81,148,81,147,81,202,81,196,81,197,81,200,81,206,81,97,82,90,82,82,82,94,82,95,82,85,82,98,82,205,82,14,83,158,83,38,85,226,84,23,85,18,85,231,84,243,84,228,84,26,85,255,84,4,85,8,85,235,84,17,85,5,85,241,84,10,85,251,84,247,84,248,84,224,84,14,85,3,85,11,85,1,87,2,87,204,87,50,88,213,87,210,87,186,87,198,87,189,87,188,87,184,87,182,87,191,87,199,87,208,87,185,87,193,87,14,89,74,89,25,90,22,90,45,90,46,90,21,90,15,90,23,90,10,90,30,90,51,90,108,91,167,91,173,91,172,91,3,92,86,92,84,92,236,92,255,92,238,92,241,92,247,92,0,93,249,92,41,94,40,94,168,94,174,94,170,94,172,94,51,95,48,95,103,95,93,96,90,96,103,96,65,96,162,96,136,96,128,96,146,96,129,96,157,96,131,96,149,96,155,96,151,96,135,96,156,96,142,96,25,98,70,98,242,98,16,99,86,99,44,99,68,99,69,99,54,99,67,99,228,99,57,99,75,99,74,99,60,99,41,99,65,99,52,99,88,99,84,99,89,99,45,99,71,99,51,99,90,99,81,99,56,99,87,99,64,99,72,99,74,101,70,101,198,101,195,101,196,101,194,101,74,102,95,102,71,102,81,102,18,103,19,103,31,104,26,104,73,104,50,104,51,104,59,104,75,104,79,104,22,104,49,104,28,104,53,104,43,104,45,104,47,104,78,104,68,104,52,104,29,104,18,104,20,104,38,104,40,104,46,104,77,104,58,104,37,104,32,104,44,107,47,107,45,107,49,107,52,107,109,107,130,128,136,107,230,107,228,107,232,107,227,107,226,107,231,107,37,108,122,109,99,109,100,109,118,109,13,109,97,109,146,109,88,109,98,109,109,109,111,109,145,109,141,109,239,109,127,109,134,109,94,109,103,109,96,109,151,109,112,109,124,109,95,109,130,109,152,109,47,109,104,109,139,109,126,109,128,109,132,109,22,109,131,109,123,109,125,109,117,109,144,109,220,112,211,112,209,112,221,112,203,112,57,127,226,112,215,112,210,112,222,112,224,112,212,112,205,112,197,112,198,112,199,112,218,112,206,112,225,112,66,114,120,114,119,114,118,114,0,115,250,114,244,114,254,114,246,114,243,114,251,114,1,115,211,115,217,115,229,115,214,115,188,115,231,115,227,115,233,115,220,115,210,115,219,115,212,115,221,115,218,115,215,115,216,115,232,115,222,116,223,116,244,116,245,116,33,117,91,117,95,117,176,117,193,117,187,117,196,117,192,117,191,117,182,117,186,117,138,118,201,118,29,119,27,119,16,119,19,119,18,119,35,119,17,119,21,119,25,119,26,119,34,119,39,119,35,120,44,120,34,120,53,120,47,120,40,120,46,120,43,120,33,120,41,120,51,120,42,120,49,120,84,121,91,121,79,121,92,121,83,121,82,121,81,121,235,121,236,121,224,121,238,121,237,121,234,121,220,121,222,121,221,121,134,122,137,122,133,122,139,122,140,122,138,122,135,122,216,122,16,123,4,123,19,123,5,123,15,123,8,123,10,123,14,123,9,123,18,123,132,124,145,124,138,124,140,124,136,124,141,124,133,124,30,125,29,125,17,125,14,125,24,125,22,125,19,125,31,125,18,125,15,125,12,125,92,127,97,127,94,127,96,127,93,127,91,127,150,127,146,127,195,127,194,127,192,127,22,128,62,128,57,128,250,128,242,128,249,128,245,128,1,129,251,128,0,129,1,130,47,130,37,130,51,131,45,131,68,131,25,131,81,131,37,131,86,131,63,131,65,131,38,131,28,131,34,131,66,131,78,131,27,131,42,131,8,131,60,131,77,131,22,131,36,131,32,131,55,131,47,131,41,131,71,131,69,131,76,131,83,131,30,131,44,131,75,131,39,131,72,131,83,134,82,134,162,134,168,134,150,134,141,134,145,134,158,134,135,134,151,134,134,134,139,134,154,134,133,134,165,134,153,134,161,134,167,134,149,134,152,134,142,134,157,134,144,134,148,134,67,136,68,136,109,136,117,136,118,136,114,136,128,136,113,136,127,136,111,136,131,136,126,136,116,136,124,136,18,138,71,140,87,140,123,140,164,140,163,140,118,141,120,141,181,141,183,141,182,141,209,142,211,142,254,143,245,143,2,144,255,143,251,143,4,144,252,143,246,143,214,144,224,144,217,144,218,144,227,144,223,144,229,144,216,144,219,144,215,144,220,144,228,144,80,145,78,145,79,145,213,145,226,145,218,145,92,150,95,150,188,150,227,152,223,154,47,155,127,78,112,80,106,80,97,80,94,80,96,80,83,80,75,80,93,80,114,80,72,80,77,80,65,80,91,80,74,80,98,80,21,80,69,80,95,80,105,80,107,80,99,80,100,80,70,80,64,80,110,80,115,80,87,80,81,80,208,81,107,82,109,82,108,82,110,82,214,82,211,82,45,83,156,83,117,85,118,85,60,85,77,85,80,85,52,85,42,85,81,85,98,85,54,85,53,85,48,85,82,85,69,85,12,85,50,85,101,85,78,85,57,85,72,85,45,85,59,85,64,85,75,85,10,87,7,87,251,87,20,88,226,87,246,87,220,87,244,87,0,88,237,87,253,87,8,88,248,87,11,88,243,87,207,87,7,88,238,87,227,87,242,87,229,87,236,87,225,87,14,88,252,87,16,88,231,87,1,88,12,88,241,87,233,87,240,87,13,88,4,88,92,89,96,90,88,90,85,90,103,90,94,90,56,90,53,90,109,90,80,90,95,90,101,90,108,90,83,90,100,90,87,90,67,90,93,90,82,90,68,90,91,90,72,90,142,90,62,90,77,90,57,90,76,90,112,90,105,90,71,90,81,90,86,90,66,90,92,90,114,91,110,91,193,91,192,91,89,92,30,93,11,93,29,93,26,93,32,93,12,93,40,93,13,93,38,93,37,93,15,93,48,93,18,93,35,93,31,93,46,93,62,94,52,94,177,94,180,94,185,94,178,94,179,94,54,95,56,95,155,95,150,95,159,95,138,96,144,96,134,96,190,96,176,96,186,96,211,96,212,96,207,96,228,96,217,96,221,96,200,96,177,96,219,96,183,96,202,96,191,96,195,96,205,96,192,96,50,99,101,99,138,99,130,99,125,99,189,99,158,99,173,99,157,99,151,99,171,99,142,99,111,99,135,99,144,99,110,99,175,99,117,99,156,99,109,99,174,99,124,99,164,99,59,99,159,99,120,99,133,99,129,99,145,99,141,99,112,99,83,101,205,101,101,102,97,102,91,102,89,102,92,102,98,102,24,103,121,104,135,104,144,104,156,104,109,104,110,104,174,104,171,104,86,105,111,104,163,104,172,104,169,104,117,104,116,104,178,104,143,104,119,104,146,104,124,104,107,104,114,104,170,104,128,104,113,104,126,104,155,104,150,104,139,104,160,104,137,104,164,104,120,104,123,104,145,104,140,104,138,104,125,104,54,107,51,107,55,107,56,107,145,107,143,107,141,107,142,107,140,107,42,108,192,109,171,109,180,109,179,109,116,110,172,109,233,109,226,109,183,109,246,109,212,109,0,110,200,109,224,109,223,109,214,109,190,109,229,109,220,109,221,109,219,109,244,109,202,109,189,109,237,109,240,109,186,109,213,109,194,109,207,109,201,109,208,109,242,109,211,109,253,109,215,109,205,109,227,109,187,109,250,112,13,113,247,112,23,113,244,112,12,113,240,112,4,113,243,112,16,113,252,112,255,112,6,113,19,113,0,113,248,112,246,112,11,113,2,113,14,113,126,114,123,114,124,114,127,114,29,115,23,115,7,115,17,115,24,115,10,115,8,115,255,114,15,115,30,115,136,115,246,115,248,115,245,115,4,116,1,116,253,115,7,116,0,116,250,115,252,115,255,115,12,116,11,116,244,115,8,116,100,117,99,117,206,117,210,117,207,117,203,117,204,117,209,117,208,117,143,118,137,118,211,118,57,119,47,119,45,119,49,119,50,119,52,119,51,119,61,119,37,119,59,119,53,119,72,120,82,120,73,120,77,120,74,120,76,120,38,120,69,120,80,120,100,121,103,121,105,121,106,121,99,121,107,121,97,121,187,121,250,121,248,121,246,121,247,121,143,122,148,122,144,122,53,123,71,123,52,123,37,123,48,123,34,123,36,123,51,123,24,123,42,123,29,123,49,123,43,123,45,123,47,123,50,123,56,123,26,123,35,123,148,124,152,124,150,124,163,124,53,125,61,125,56,125,54,125,58,125,69,125,44,125,41,125,65,125,71,125,62,125,63,125,74,125,59,125,40,125,99,127,149,127,156,127,157,127,155,127,202,127,203,127,205,127,208,127,209,127,199,127,207,127,201,127,31,128,30,128,27,128,71,128,67,128,72,128,24,129,37,129,25,129,27,129,45,129,31,129,44,129,30,129,33,129,21,129,39,129,29,129,34,129,17,130,56,130,51,130,58,130,52,130,50,130,116,130,144,131,163,131,168,131,141,131,122,131,115,131,164,131,116,131,143,131,129,131,149,131,153,131,117,131,148,131,169,131,125,131,131,131,140,131,157,131,155,131,170,131,139,131,126,131,165,131,175,131,136,131,151,131,176,131,127,131,166,131,135,131,174,131,118,131,154,131,89,134,86,134,191,134,183,134,194,134,193,134,197,134,186,134,176,134,200,134,185,134,179,134,184,134,204,134,180,134,187,134,188,134,195,134,189,134,190,134,82,136,137,136,149,136,168,136,162,136,170,136,154,136,145,136,161,136,159,136,152,136,167,136,153,136,155,136,151,136,164,136,172,136,140,136,147,136,142,136,130,137,214,137,217,137,213,137,48,138,39,138,44,138,30,138,57,140,59,140,92,140,93,140,125,140,165,140,125,141,123,141,121,141,188,141,194,141,185,141,191,141,193,141,216,142,222,142,221,142,220,142,215,142,224,142,225,142,36,144,11,144,17,144,28,144,12,144,33,144,239,144,234,144,240,144,244,144,242,144,243,144,212,144,235,144,236,144,233,144,86,145,88,145,90,145,83,145,85,145,236,145,244,145,241,145,243,145,248,145,228,145,249,145,234,145,235,145,247,145,232,145,238,145,122,149,134,149,136,149,124,150,109,150,107,150,113,150,111,150,191,150,106,151,4,152,229,152,151,153,155,80,149,80,148,80,158,80,139,80,163,80,131,80,140,80,142,80,157,80,104,80,156,80,146,80,130,80,135,80,95,81,212,81,18,83,17,83,164,83,167,83,145,85,168,85,165,85,173,85,119,85,69,86,162,85,147,85,136,85,143,85,181,85,129,85,163,85,146,85,164,85,125,85,140,85,166,85,127,85,149,85,161,85,142,85,12,87,41,88,55,88,25,88,30,88,39,88,35,88,40,88,245,87,72,88,37,88,28,88,27,88,51,88,63,88,54,88,46,88,57,88,56,88,45,88,44,88,59,88,97,89,175,90,148,90,159,90,122,90,162,90,158,90,120,90,166,90,124,90,165,90,172,90,149,90,174,90,55,90,132,90,138,90,151,90,131,90,139,90,169,90,123,90,125,90,140,90,156,90,143,90,147,90,157,90,234,91,205,91,203,91,212,91,209,91,202,91,206,91,12,92,48,92,55,93,67,93,107,93,65,93,75,93,63,93,53,93,81,93,78,93,85,93,51,93,58,93,82,93,61,93,49,93,89,93,66,93,57,93,73,93,56,93,60,93,50,93,54,93,64,93,69,93,68,94,65,94,88,95,166,95,165,95,171,95,201,96,185,96,204,96,226,96,206,96,196,96,20,97,242,96,10,97,22,97,5,97,245,96,19,97,248,96,252,96,254,96,193,96,3,97,24,97,29,97,16,97,255,96,4,97,11,97,74,98,148,99,177,99,176,99,206,99,229,99,232,99,239,99,195,99,157,100,243,99,202,99,224,99,246,99,213,99,242,99,245,99,97,100,223,99,190,99,221,99,220,99,196,99,216,99,211,99,194,99,199,99,204,99,203,99,200,99,240,99,215,99,217,99,50,101,103,101,106,101,100,101,92,101,104,101,101,101,140,101,157,101,158,101,174,101,208,101,210,101,124,102,108,102,123,102,128,102,113,102,121,102,106,102,114,102,1,103,12,105,211,104,4,105,220,104,42,105,236,104,234,104,241,104,15,105,214,104,247,104,235,104,228,104,246,104,19,105,16,105,243,104,225,104,7,105,204,104,8,105,112,105,180,104,17,105,239,104,198,104,20,105,248,104,208,104,253,104,252,104,232,104,11,105,10,105,23,105,206,104,200,104,221,104,222,104,230,104,244,104,209,104,6,105,212,104,233,104,21,105,37,105,199,104,57,107,59,107,63,107,60,107,148,107,151,107,153,107,149,107,189,107,240,107,242,107,243,107,48,108,252,109,70,110,71,110,31,110,73,110,136,110,60,110,61,110,69,110,98,110,43,110,63,110,65,110,93,110,115,110,28,110,51,110,75,110,64,110,81,110,59,110,3,110,46,110,94,110,104,110,92,110,97,110,49,110,40,110,96,110,113,110,107,110,57,110,34,110,48,110,83,110,101,110,39,110,120,110,100,110,119,110,85,110,121,110,82,110,102,110,53,110,54,110,90,110,32,113,30,113,47,113,251,112,46,113,49,113,35,113,37,113,34,113,50,113,31,113,40,113,58,113,27,113,75,114,90,114,136,114,137,114,134,114,133,114,139,114,18,115,11,115,48,115,34,115,49,115,51,115,39,115,50,115,45,115,38,115,35,115,53,115,12,115,46,116,44,116,48,116,43,116,22,116,26,116,33,116,45,116,49,116,36,116,35,116,29,116,41,116,32,116,50,116,251,116,47,117,111,117,108,117,231,117,218,117,225,117,230,117,221,117,223,117,228,117,215,117,149,118,146,118,218,118,70,119,71,119,68,119,77,119,69,119,74,119,78,119,75,119,76,119,222,119,236,119,96,120,100,120,101,120,92,120,109,120,113,120,106,120,110,120,112,120,105,120,104,120,94,120,98,120,116,121,115,121,114,121,112,121,2,122,10,122,3,122,12,122,4,122,153,122,230,122,228,122,74,123,59,123,68,123,72,123,76,123,78,123,64,123,88,123,69,123,162,124,158,124,168,124,161,124,88,125,111,125,99,125,83,125,86,125,103,125,106,125,79,125,109,125,92,125,107,125,82,125,84,125,105,125,81,125,95,125,78,125,62,127,63,127,101,127,102,127,162,127,160,127,161,127,215,127,81,128,79,128,80,128,254,128,212,128,67,129,74,129,82,129,79,129,71,129,61,129,77,129,58,129,230,129,238,129,247,129,248,129,249,129,4,130,60,130,61,130,63,130,117,130,59,131,207,131,249,131,35,132,192,131,232,131,18,132,231,131,228,131,252,131,246,131,16,132,198,131,200,131,235,131,227,131,191,131,1,132,221,131,229,131,216,131,255,131,225,131,203,131,206,131,214,131,245,131,201,131,9,132,15,132,222,131,17,132,6,132,194,131,243,131,213,131,250,131,199,131,209,131,234,131,19,132,195,131,236,131,238,131,196,131,251,131,215,131,226,131,27,132,219,131,254,131,216,134,226,134,230,134,211,134,227,134,218,134,234,134,221,134,235,134,220,134,236,134,233,134,215,134,232,134,209,134,72,136,86,136,85,136,186,136,215,136,185,136,184,136,192,136,190,136,182,136,188,136,183,136,189,136,178,136,1,137,201,136,149,137,152,137,151,137,221,137,218,137,219,137,78,138,77,138,57,138,89,138,64,138,87,138,88,138,68,138,69,138,82,138,72,138,81,138,74,138,76,138,79,138,95,140,129,140,128,140,186,140,190,140,176,140,185,140,181,140,132,141,128,141,137,141,216,141,211,141,205,141,199,141,214,141,220,141,207,141,213,141,217,141,200,141,215,141,197,141,239,142,247,142,250,142,249,142,230,142,238,142,229,142,245,142,231,142,232,142,246,142,235,142,241,142,236,142,244,142,233,142,45,144,52,144,47,144,6,145,44,145,4,145,255,144,252,144,8,145,249,144,251,144,1,145,0,145,7,145,5,145,3,145,97,145,100,145,95,145,98,145,96,145,1,146,10,146,37,146,3,146,26,146,38,146,15,146,12,146,0,146,18,146,255,145,253,145,6,146,4,146,39,146,2,146,28,146,36,146,25,146,23,146,5,146,22,146,123,149,141,149,140,149,144,149,135,150,126,150,136,150,137,150,131,150,128,150,194,150,200,150,195,150,241,150,240,150,108,151,112,151,110,151,7,152,169,152,235,152,230,156,249,158,131,78,132,78,182,78,189,80,191,80,198,80,174,80,196,80,202,80,180,80,200,80,194,80,176,80,193,80,186,80,177,80,203,80,201,80,182,80,184,80,215,81,122,82,120,82,123,82,124,82,195,85,219,85,204,85,208,85,203,85,202,85,221,85,192,85,212,85,196,85,233,85,191,85,210,85,141,85,207,85,213,85,226,85,214,85,200,85,242,85,205,85,217,85,194,85,20,87,83,88,104,88,100,88,79,88,77,88,73,88,111,88,85,88,78,88,93,88,89,88,101,88,91,88,61,88,99,88,113,88,252,88,199,90,196,90,203,90,186,90,184,90,177,90,181,90,176,90,191,90,200,90,187,90,198,90,183,90,192,90,202,90,180,90,182,90,205,90,185,90,144,90,214,91,216,91,217,91,31,92,51,92,113,93,99,93,74,93,101,93,114,93,108,93,94,93,104,93,103,93,98,93,240,93,79,94,78,94,74,94,77,94,75,94,197,94,204,94,198,94,203,94,199,94,64,95,175,95,173,95,247,96,73,97,74,97,43,97,69,97,54,97,50,97,46,97,70,97,47,97,79,97,41,97,64,97,32,98,104,145,35,98,37,98,36,98,197,99,241,99,235,99,16,100,18,100,9,100,32,100,36,100,51,100,67,100,31,100,21,100,24,100,57,100,55,100,34,100,35,100,12,100,38,100,48,100,40,100,65,100,53,100,47,100,10,100,26,100,64,100,37,100,39,100,11,100,231,99,27,100,46,100,33,100,14,100,111,101,146,101,211,101,134,102,140,102,149,102,144,102,139,102,138,102,153,102,148,102,120,102,32,103,102,105,95,105,56,105,78,105,98,105,113,105,63,105,69,105,106,105,57,105,66,105,87,105,89,105,122,105,72,105,73,105,53,105,108,105,51,105,61,105,101,105,240,104,120,105,52,105,105,105,64,105,111,105,68,105,118,105,88,105,65,105,116,105,76,105,59,105,75,105,55,105,92,105,79,105,81,105,50,105,82,105,47,105,123,105,60,105,70,107,69,107,67,107,66,107,72,107,65,107,155,107,13,250,251,107,252,107,249,107,247,107,248,107,155,110,214,110,200,110,143,110,192,110,159,110,147,110,148,110,160,110,177,110,185,110,198,110,210,110,189,110,193,110,158,110,201,110,183,110,176,110,205,110,166,110,207,110,178,110,190,110,195,110,220,110,216,110,153,110,146,110,142,110,141,110,164,110,161,110,191,110,179,110,208,110,202,110,151,110,174,110,163,110,71,113,84,113,82,113,99,113,96,113,65,113,93,113,98,113,114,113,120,113,106,113,97,113,66,113,88,113,67,113,75,113,112,113,95,113,80,113,83,113,68,113,77,113,90,113,79,114,141,114,140,114,145,114,144,114,142,114,60,115,66,115,59,115,58,115,64,115,74,115,73,115,68,116,74,116,75,116,82,116,81,116,87,116,64,116,79,116,80,116,78,116,66,116,70,116,77,116,84,116,225,116,255,116,254,116,253,116,29,117,121,117,119,117,131,105,239,117,15,118,3,118,247,117,254,117,252,117,249,117,248,117,16,118,251,117,246,117,237,117,245,117,253,117,153,118,181,118,221,118,85,119,95,119,96,119,82,119,86,119,90,119,105,119,103,119,84,119,89,119,109,119,224,119,135,120,154,120,148,120,143,120,132,120,149,120,133,120,134,120,161,120,131,120,121,120,153,120,128,120,150,120,123,120,124,121,130,121,125,121,121,121,17,122,24,122,25,122,18,122,23,122,21,122,34,122,19,122,27,122,16,122,163,122,162,122,158,122,235,122,102,123,100,123,109,123,116,123,105,123,114,123,101,123,115,123,113,123,112,123,97,123,120,123,118,123,99,123,178,124,180,124,175,124,136,125,134,125,128,125,141,125,127,125,133,125,122,125,142,125,123,125,131,125,124,125,140,125,148,125,132,125,125,125,146,125,109,127,107,127,103,127,104,127,108,127,166,127,165,127,167,127,219,127,220,127,33,128,100,129,96,129,119,129,92,129,105,129,91,129,98,129,114,129,33,103,94,129,118,129,103,129,111,129,68,129,97,129,29,130,73,130,68,130,64,130,66,130,69,130,241,132,63,132,86,132,118,132,121,132,143,132,141,132,101,132,81,132,64,132,134,132,103,132,48,132,77,132,125,132,90,132,89,132,116,132,115,132,93,132,7,133,94,132,55,132,58,132,52,132,122,132,67,132,120,132,50,132,69,132,41,132,217,131,75,132,47,132,66,132,45,132,95,132,112,132,57,132,78,132,76,132,82,132,111,132,197,132,142,132,59,132,71,132,54,132,51,132,104,132,126,132,68,132,43,132,96,132,84,132,110,132,80,132,11,135,4,135,247,134,12,135,250,134,214,134,245,134,77,135,248,134,14,135,9,135,1,135,246,134,13,135,5,135,214,136,203,136,205,136,206,136,222,136,219,136,218,136,204,136,208,136,133,137,155,137,223,137,229,137,228,137,225,137,224,137,226,137,220,137,230,137,118,138,134,138,127,138,97,138,63,138,119,138,130,138,132,138,117,138,131,138,129,138,116,138,122,138,60,140,75,140,74,140,101,140,100,140,102,140,134,140,132,140,133,140,204,140,104,141,105,141,145,141,140,141,142,141,143,141,141,141,147,141,148,141,144,141,146,141,240,141,224,141,236,141,241,141,238,141,208,141,233,141,227,141,226,141,231,141,242,141,235,141,244,141,6,143,255,142,1,143,0,143,5,143,7,143,8,143,2,143,11,143,82,144,63,144,68,144,73,144,61,144,16,145,13,145,15,145,17,145,22,145,20,145,11,145,14,145,110,145,111,145,72,146,82,146,48,146,58,146,102,146,51,146,101,146,94,146,131,146,46,146,74,146,70,146,109,146,108,146,79,146,96,146,103,146,111,146,54,146,97,146,112,146,49,146,84,146,99,146,80,146,114,146,78,146,83,146,76,146,86,146,50,146,159,149,156,149,158,149,155,149,146,150,147,150,145,150,151,150,206,150,250,150,253,150,248,150,245,150,115,151,119,151,120,151,114,151,15,152,13,152,14,152,172,152,246,152,249,152,175,153,178,153,176,153,181,153,173,154,171,154,91,155,234,156,237,156,231,156,128,158,253,158,230,80,212,80,215,80,232,80,243,80,219,80,234,80,221,80,228,80,211,80,236,80,240,80,239,80,227,80,224,80,216,81,128,82,129,82,233,82,235,82,48,83,172,83,39,86,21,86,12,86,18,86,252,85,15,86,28,86,1,86,19,86,2,86,250,85,29,86,4,86,255,85,249,85,137,88,124,88,144,88,152,88,134,88,129,88,127,88,116,88,139,88,122,88,135,88,145,88,142,88,118,88,130,88,136,88,123,88,148,88,143,88,254,88,107,89,220,90,238,90,229,90,213,90,234,90,218,90,237,90,235,90,243,90,226,90,224,90,219,90,236,90,222,90,221,90,217,90,232,90,223,90,119,91,224,91,227,91,99,92,130,93,128,93,125,93,134,93,122,93,129,93,119,93,138,93,137,93,136,93,126,93,124,93,141,93,121,93,127,93,88,94,89,94,83,94,216,94,209,94,215,94,206,94,220,94,213,94,217,94,210,94,212,94,68,95,67,95,111,95,182,95,44,97,40,97,65,97,94,97,113,97,115,97,82,97,83,97,114,97,108,97,128,97,116,97,84,97,122,97,91,97,101,97,59,97,106,97,97,97,86,97,41,98,39,98,43,98,43,100,77,100,91,100,93,100,116,100,118,100,114,100,115,100,125,100,117,100,102,100,166,100,78,100,130,100,94,100,92,100,75,100,83,100,96,100,80,100,127,100,63,100,108,100,107,100,89,100,101,100,119,100,115,101,160,101,161,102,160,102,159,102,5,103,4,103,34,103,177,105,182,105,201,105,160,105,206,105,150,105,176,105,172,105,188,105,145,105,153,105,142,105,167,105,141,105,169,105,190,105,175,105,191,105,196,105,189,105,164,105,212,105,185,105,202,105,154,105,207,105,179,105,147,105,170,105,161,105,158,105,217,105,151,105,144,105,194,105,181,105,165,105,198,105,74,107,77,107,75,107,158,107,159,107,160,107,195,107,196,107,254,107,206,110,245,110,241,110,3,111,37,111,248,110,55,111,251,110,46,111,9,111,78,111,25,111,26,111,39,111,24,111,59,111,18,111,237,110,10,111,54,111,115,111,249,110,238,110,45,111,64,111,48,111,60,111,53,111,235,110,7,111,14,111,67,111,5,111,253,110,246,110,57,111,28,111,252,110,58,111,31,111,13,111,30,111,8,111,33,111,135,113,144,113,137,113,128,113,133,113,130,113,143,113,123,113,134,113,129,113,151,113,68,114,83,114,151,114,149,114,147,114,67,115,77,115,81,115,76,115,98,116,115,116,113,116,117,116,114,116,103,116,110,116,0,117,2,117,3,117,125,117,144,117,22,118,8,118,12,118,21,118,17,118,10,118,20,118,184,118,129,119,124,119,133,119,130,119,110,119,128,119,111,119,126,119,131,119,178,120,170,120,180,120,173,120,168,120,126,120,171,120,158,120,165,120,160,120,172,120,162,120,164,120,152,121,138,121,139,121,150,121,149,121,148,121,147,121,151,121,136,121,146,121,144,121,43,122,74,122,48,122,47,122,40,122,38,122,168,122,171,122,172,122,238,122,136,123,156,123,138,123,145,123,144,123,150,123,141,123,140,123,155,123,142,123,133,123,152,123,132,82,153,123,164,123,130,123,187,124,191,124,188,124,186,124,167,125,183,125,194,125,163,125,170,125,193,125,192,125,197,125,157,125,206,125,196,125,198,125,203,125,204,125,175,125,185,125,150,125,188,125,159,125,166,125,174,125,169,125,161,125,201,125,115,127,226,127,227,127,229,127,222,127,36,128,93,128,92,128,137,129,134,129,131,129,135,129,141,129,140,129,139,129,21,130,151,132,164,132,161,132,159,132,186,132,206,132,194,132,172,132,174,132,171,132,185,132,180,132,193,132,205,132,170,132,154,132,177,132,208,132,157,132,167,132,187,132,162,132,148,132,199,132,204,132,155,132,169,132,175,132,168,132,214,132,152,132,182,132,207,132,160,132,215,132,212,132,210,132,219,132,176,132,145,132,97,134,51,135,35,135,40,135,107,135,64,135,46,135,30,135,33,135,25,135,27,135,67,135,44,135,65,135,62,135,70,135,32,135,50,135,42,135,45,135,60,135,18,135,58,135,49,135,53,135,66,135,38,135,39,135,56,135,36,135,26,135,48,135,17,135,247,136,231,136,241,136,242,136,250,136,254,136,238,136,252,136,246,136,251,136,240,136,236,136,235,136,157,137,161,137,159,137,158,137,233,137,235,137,232,137,171,138,153,138,139,138,146,138,143,138,150,138,61,140,104,140,105,140,213,140,207,140,215,140,150,141,9,142,2,142,255,141,13,142,253,141,10,142,3,142,7,142,6,142,5,142,254,141,0,142,4,142,16,143,17,143,14,143,13,143,35,145,28,145,32,145,34,145,31,145,29,145,26,145,36,145,33,145,27,145,122,145,114,145,121,145,115,145,165,146,164,146,118,146,155,146,122,146,160,146,148,146,170,146,141,146,166,146,154,146,171,146,121,146,151,146,127,146,163,146,238,146,142,146,130,146,149,146,162,146,125,146,136,146,161,146,138,146,134,146,140,146,153,146,167,146,126,146,135,146,169,146,157,146,139,146,45,146,158,150,161,150,255,150,88,151,125,151,122,151,126,151,131,151,128,151,130,151,123,151,132,151,129,151,127,151,206,151,205,151,22,152,173,152,174,152,2,153,0,153,7,153,157,153,156,153,195,153,185,153,187,153,186,153,194,153,189,153,199,153,177,154,227,154,231,154,62,155,63,155,96,155,97,155,95,155,241,156,242,156,245,156,167,158,255,80,3,81,48,81,248,80,6,81,7,81,246,80,254,80,11,81,12,81,253,80,10,81,139,82,140,82,241,82,239,82,72,86,66,86,76,86,53,86,65,86,74,86,73,86,70,86,88,86,90,86,64,86,51,86,61,86,44,86,62,86,56,86,42,86,58,86,26,87,171,88,157,88,177,88,160,88,163,88,175,88,172,88,165,88,161,88,255,88,255,90,244,90,253,90,247,90,246,90,3,91,248,90,2,91,249,90,1,91,7,91,5,91,15,91,103,92,153,93,151,93,159,93,146,93,162,93,147,93,149,93,160,93,156,93,161,93,154,93,158,93,105,94,93,94,96,94,92,94,243,125,219,94,222,94,225,94,73,95,178,95,139,97,131,97,121,97,177,97,176,97,162,97,137,97,155,97,147,97,175,97,173,97,159,97,146,97,170,97,161,97,141,97,102,97,179,97,45,98,110,100,112,100,150,100,160,100,133,100,151,100,156,100,143,100,139,100,138,100,140,100,163,100,159,100,104,100,177,100,152,100,118,101,122,101,121,101,123,101,178,101,179,101,181,102,176,102,169,102,178,102,183,102,170,102,175,102,0,106,6,106,23,106,229,105,248,105,21,106,241,105,228,105,32,106,255,105,236,105,226,105,27,106,29,106,254,105,39,106,242,105,238,105,20,106,247,105,231,105,64,106,8,106,230,105,251,105,13,106,252,105,235,105,9,106,4,106,24,106,37,106,15,106,246,105,38,106,7,106,244,105,22,106,81,107,165,107,163,107,162,107,166,107,1,108,0,108,255,107,2,108,65,111,38,111,126,111,135,111,198,111,146,111,141,111,137,111,140,111,98,111,79,111,133,111,90,111,150,111,118,111,108,111,130,111,85,111,114,111,82,111,80,111,87,111,148,111,147,111,93,111,0,111,97,111,107,111,125,111,103,111,144,111,83,111,139,111,105,111,127,111,149,111,99,111,119,111,106,111,123,111,178,113,175,113,155,113,176,113,160,113,154,113,169,113,181,113,157,113,165,113,158,113,164,113,161,113,170,113,156,113,167,113,179,113,152,114,154,114,88,115,82,115,94,115,95,115,96,115,93,115,91,115,97,115,90,115,89,115,98,115,135,116,137,116,138,116,134,116,129,116,125,116,133,116,136,116,124,116,121,116,8,117,7,117,126,117,37,118,30,118,25,118,29,118,28,118,35,118,26,118,40,118,27,118,156,118,157,118,158,118,155,118,141,119,143,119,137,119,136,119,205,120,187,120,207,120,204,120,209,120,206,120,212,120,200,120,195,120,196,120,201,120,154,121,161,121,160,121,156,121,162,121,155,121,118,107,57,122,178,122,180,122,179,122,183,123,203,123,190,123,172,123,206,123,175,123,185,123,202,123,181,123,197,124,200,124,204,124,203,124,247,125,219,125,234,125,231,125,215,125,225,125,3,126,250,125,230,125,246,125,241,125,240,125,238,125,223,125,118,127,172,127,176,127,173,127,237,127,235,127,234,127,236,127,230,127,232,127,100,128,103,128,163,129,159,129,158,129,149,129,162,129,153,129,151,129,22,130,79,130,83,130,82,130,80,130,78,130,81,130,36,133,59,133,15,133,0,133,41,133,14,133,9,133,13,133,31,133,10,133,39,133,28,133,251,132,43,133,250,132,8,133,12,133,244,132,42,133,242,132,21,133,247,132,235,132,243,132,252,132,18,133,234,132,233,132,22,133,254,132,40,133,29,133,46,133,2,133,253,132,30,133,246,132,49,133,38,133,231,132,232,132,240,132,239,132,249,132,24,133,32,133,48,133,11,133,25,133,47,133,98,134,86,135,99,135,100,135,119,135,225,135,115,135,88,135,84,135,91,135,82,135,97,135,90,135,81,135,94,135,109,135,106,135,80,135,78,135,95,135,93,135,111,135,108,135,122,135,110,135,92,135,101,135,79,135,123,135,117,135,98,135,103,135,105,135,90,136,5,137,12,137,20,137,11,137,23,137,24,137,25,137,6,137,22,137,17,137,14,137,9,137,162,137,164,137,163,137,237,137,240,137,236,137,207,138,198,138,184,138,211,138,209,138,212,138,213,138,187,138,215,138,190,138,192,138,197,138,216,138,195,138,186,138,189,138,217,138,62,140,77,140,143,140,229,140,223,140,217,140,232,140,218,140,221,140,231,140,160,141,156,141,161,141,155,141,32,142,35,142,37,142,36,142,46,142,21,142,27,142,22,142,17,142,25,142,38,142,39,142,20,142,18,142,24,142,19,142,28,142,23,142,26,142,44,143,36,143,24,143,26,143,32,143,35,143,22,143,23,143,115,144,112,144,111,144,103,144,107,144,47,145,43,145,41,145,42,145,50,145,38,145,46,145,133,145,134,145,138,145,129,145,130,145,132,145,128,145,208,146,195,146,196,146,192,146,217,146,182,146,207,146,241,146,223,146,216,146,233,146,215,146,221,146,204,146,239,146,194,146,232,146,202,146,200,146,206,146,230,146,205,146,213,146,201,146,224,146,222,146,231,146,209,146,211,146,181,146,225,146,198,146,180,146,124,149,172,149,171,149,174,149,176,149,164,150,162,150,211,150,5,151,8,151,2,151,90,151,138,151,142,151,136,151,208,151,207,151,30,152,29,152,38,152,41,152,40,152,32,152,27,152,39,152,178,152,8,153,250,152,17,153,20,153,22,153,23,153,21,153,220,153,205,153,207,153,211,153,212,153,206,153,201,153,214,153,216,153,203,153,215,153,204,153,179,154,236,154,235,154,243,154,242,154,241,154,70,155,67,155,103,155,116,155,113,155,102,155,118,155,117,155,112,155,104,155,100,155,108,155,252,156,250,156,253,156,255,156,247,156,7,157,0,157,249,156,251,156,8,157,5,157,4,157,131,158,211,158,15,159,16,159,28,81,19,81,23,81,26,81,17,81,222,81,52,83,225,83,112,86,96,86,110,86,115,86,102,86,99,86,109,86,114,86,94,86,119,86,28,87,27,87,200,88,189,88,201,88,191,88,186,88,194,88,188,88,198,88,23,91,25,91,27,91,33,91,20,91,19,91,16,91,22,91,40,91,26,91,32,91,30,91,239,91,172,93,177,93,169,93,167,93,181,93,176,93,174,93,170,93,168,93,178,93,173,93,175,93,180,93,103,94,104,94,102,94,111,94,233,94,231,94,230,94,232,94,229,94,75,95,188,95,157,97,168,97,150,97,197,97,180,97,198,97,193,97,204,97,186,97,191,97,184,97,140,97,215,100,214,100,208,100,207,100,201,100,189,100,137,100,195,100,219,100,243,100,217,100,51,101,127,101,124,101,162,101,200,102,190,102,192,102,202,102,203,102,207,102,189,102,187,102,186,102,204,102,35,103,52,106,102,106,73,106,103,106,50,106,104,106,62,106,93,106,109,106,118,106,91,106,81,106,40,106,90,106,59,106,63,106,65,106,106,106,100,106,80,106,79,106,84,106,111,106,105,106,96,106,60,106,94,106,86,106,85,106,77,106,78,106,70,106,85,107,84,107,86,107,167,107,170,107,171,107,200,107,199,107,4,108,3,108,6,108,173,111,203,111,163,111,199,111,188,111,206,111,200,111,94,111,196,111,189,111,158,111,202,111,168,111,4,112,165,111,174,111,186,111,172,111,170,111,207,111,191,111,184,111,162,111,201,111,171,111,205,111,175,111,178,111,176,111,197,113,194,113,191,113,184,113,214,113,192,113,193,113,203,113,212,113,202,113,199,113,207,113,189,113,216,113,188,113,198,113,218,113,219,113,157,114,158,114,105,115,102,115,103,115,108,115,101,115,107,115,106,115,127,116,154,116,160,116,148,116,146,116,149,116,161,116,11,117,128,117,47,118,45,118,49,118,61,118,51,118,60,118,53,118,50,118,48,118,187,118,230,118,154,119,157,119,161,119,156,119,155,119,162,119,163,119,149,119,153,119,151,119,221,120,233,120,229,120,234,120,222,120,227,120,219,120,225,120,226,120,237,120,223,120,224,120,164,121,68,122,72,122,71,122,182,122,184,122,181,122,177,122,183,122,222,123,227,123,231,123,221,123,213,123,229,123,218,123,232,123,249,123,212,123,234,123,226,123,220,123,235,123,216,123,223,123,210,124,212,124,215,124,208,124,209,124,18,126,33,126,23,126,12,126,31,126,32,126,19,126,14,126,28,126,21,126,26,126,34,126,11,126,15,126,22,126,13,126,20,126,37,126,36,126,67,127,123,127,124,127,122,127,177,127,239,127,42,128,41,128,108,128,177,129,166,129,174,129,185,129,181,129,171,129,176,129,172,129,180,129,178,129,183,129,167,129,242,129,85,130,86,130,87,130,86,133,69,133,107,133,77,133,83,133,97,133,88,133,64,133,70,133,100,133,65,133,98,133,68,133,81,133,71,133,99,133,62,133,91,133,113,133,78,133,110,133,117,133,85,133,103,133,96,133,140,133,102,133,93,133,84,133,101,133,108,133,99,134,101,134,100,134,155,135,143,135,151,135,147,135,146,135,136,135,129,135,150,135,152,135,121,135,135,135,163,135,133,135,144,135,145,135,157,135,132,135,148,135,156,135,154,135,137,135,30,137,38,137,48,137,45,137,46,137,39,137,49,137,34,137,41,137,35,137,47,137,44,137,31,137,241,137,224,138,226,138,242,138,244,138,245,138,221,138,20,139,228,138,223,138,240,138,200,138,222,138,225,138,232,138,255,138,239,138,251,138,145,140,146,140,144,140,245,140,238,140,241,140,240,140,243,140,108,141,110,141,165,141,167,141,51,142,62,142,56,142,64,142,69,142,54,142,60,142,61,142,65,142,48,142,63,142,189,142,54,143,46,143,53,143,50,143,57,143,55,143,52,143,118,144,121,144,123,144,134,144,250,144,51,145,53,145,54,145,147,145,144,145,145,145,141,145,143,145,39,147,30,147,8,147,31,147,6,147,15,147,122,147,56,147,60,147,27,147,35,147,18,147,1,147,70,147,45,147,14,147,13,147,203,146,29,147,250,146,37,147,19,147,249,146,247,146,52,147,2,147,36,147,255,146,41,147,57,147,53,147,42,147,20,147,12,147,11,147,254,146,9,147,0,147,251,146,22,147,188,149,205,149,190,149,185,149,186,149,182,149,191,149,181,149,189,149,169,150,212,150,11,151,18,151,16,151,153,151,151,151,148,151,240,151,248,151,53,152,47,152,50,152,36,153,31,153,39,153,41,153,158,153,238,153,236,153,229,153,228,153,240,153,227,153,234,153,233,153,231,153,185,154,191,154,180,154,187,154,246,154,250,154,249,154,247,154,51,155,128,155,133,155,135,155,124,155,126,155,123,155,130,155,147,155,146,155,144,155,122,155,149,155,125,155,136,155,37,157,23,157,32,157,30,157,20,157,41,157,29,157,24,157,34,157,16,157,25,157,31,157,136,158,134,158,135,158,174,158,173,158,213,158,214,158,250,158,18,159,61,159,38,81,37,81,34,81,36,81,32,81,41,81,244,82,147,86,140,86,141,86,134,86,132,86,131,86,126,86,130,86,127,86,129,86,214,88,212,88,207,88,210,88,45,91,37,91,50,91,35,91,44,91,39,91,38,91,47,91,46,91,123,91,241,91,242,91,183,93,108,94,106,94,190,95,187,95,195,97,181,97,188,97,231,97,224,97,229,97,228,97,232,97,222,97,239,100,233,100,227,100,235,100,228,100,232,100,129,101,128,101,182,101,218,101,210,102,141,106,150,106,129,106,165,106,137,106,159,106,155,106,161,106,158,106,135,106,147,106,142,106,149,106,131,106,168,106,164,106,145,106,127,106,166,106,154,106,133,106,140,106,146,106,91,107,173,107,9,108,204,111,169,111,244,111,212,111,227,111,220,111,237,111,231,111,230,111,222,111,242,111,221,111,226,111,232,111,225,113,241,113,232,113,242,113,228,113,240,113,226,113,115,115,110,115,111,115,151,116,178,116,171,116,144,116,170,116,173,116,177,116,165,116,175,116,16,117,17,117,18,117,15,117,132,117,67,118,72,118,73], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1717445);
/* memory initializer */ allocate([118,71,118,164,118,233,118,181,119,171,119,178,119,183,119,182,119,180,119,177,119,168,119,240,119,243,120,253,120,2,121,251,120,252,120,242,120,5,121,249,120,254,120,4,121,171,121,168,121,92,122,91,122,86,122,88,122,84,122,90,122,190,122,192,122,193,122,5,124,15,124,242,123,0,124,255,123,251,123,14,124,244,123,11,124,243,123,2,124,9,124,3,124,1,124,248,123,253,123,6,124,240,123,241,123,16,124,10,124,232,124,45,126,60,126,66,126,51,126,72,152,56,126,42,126,73,126,64,126,71,126,41,126,76,126,48,126,59,126,54,126,68,126,58,126,69,127,127,127,126,127,125,127,244,127,242,127,44,128,187,129,196,129,204,129,202,129,197,129,199,129,188,129,233,129,91,130,90,130,92,130,131,133,128,133,143,133,167,133,149,133,160,133,139,133,163,133,123,133,164,133,154,133,158,133,119,133,124,133,137,133,161,133,122,133,120,133,87,133,142,133,150,133,134,133,141,133,153,133,157,133,129,133,162,133,130,133,136,133,133,133,121,133,118,133,152,133,144,133,159,133,104,134,190,135,170,135,173,135,197,135,176,135,172,135,185,135,181,135,188,135,174,135,201,135,195,135,194,135,204,135,183,135,175,135,196,135,202,135,180,135,182,135,191,135,184,135,189,135,222,135,178,135,53,137,51,137,60,137,62,137,65,137,82,137,55,137,66,137,173,137,175,137,174,137,242,137,243,137,30,139,24,139,22,139,17,139,5,139,11,139,34,139,15,139,18,139,21,139,7,139,13,139,8,139,6,139,28,139,19,139,26,139,79,140,112,140,114,140,113,140,111,140,149,140,148,140,249,140,111,141,78,142,77,142,83,142,80,142,76,142,71,142,67,143,64,143,133,144,126,144,56,145,154,145,162,145,155,145,153,145,159,145,161,145,157,145,160,145,161,147,131,147,175,147,100,147,86,147,71,147,124,147,88,147,92,147,118,147,73,147,80,147,81,147,96,147,109,147,143,147,76,147,106,147,121,147,87,147,85,147,82,147,79,147,113,147,119,147,123,147,97,147,94,147,99,147,103,147,128,147,78,147,89,147,199,149,192,149,201,149,195,149,197,149,183,149,174,150,176,150,172,150,32,151,31,151,24,151,29,151,25,151,154,151,161,151,156,151,158,151,157,151,213,151,212,151,241,151,65,152,68,152,74,152,73,152,69,152,67,152,37,153,43,153,44,153,42,153,51,153,50,153,47,153,45,153,49,153,48,153,152,153,163,153,161,153,2,154,250,153,244,153,247,153,249,153,248,153,246,153,251,153,253,153,254,153,252,153,3,154,190,154,254,154,253,154,1,155,252,154,72,155,154,155,168,155,158,155,155,155,166,155,161,155,165,155,164,155,134,155,162,155,160,155,175,155,51,157,65,157,103,157,54,157,46,157,47,157,49,157,56,157,48,157,69,157,66,157,67,157,62,157,55,157,64,157,61,157,245,127,45,157,138,158,137,158,141,158,176,158,200,158,218,158,251,158,255,158,36,159,35,159,34,159,84,159,160,159,49,81,45,81,46,81,152,86,156,86,151,86,154,86,157,86,153,86,112,89,60,91,105,92,106,92,192,93,109,94,110,94,216,97,223,97,237,97,238,97,241,97,234,97,240,97,235,97,214,97,233,97,255,100,4,101,253,100,248,100,1,101,3,101,252,100,148,101,219,101,218,102,219,102,216,102,197,106,185,106,189,106,225,106,198,106,186,106,182,106,183,106,199,106,180,106,173,106,94,107,201,107,11,108,7,112,12,112,13,112,1,112,5,112,20,112,14,112,255,111,0,112,251,111,38,112,252,111,247,111,10,112,1,114,255,113,249,113,3,114,253,113,118,115,184,116,192,116,181,116,193,116,190,116,182,116,187,116,194,116,20,117,19,117,92,118,100,118,89,118,80,118,83,118,87,118,90,118,166,118,189,118,236,118,194,119,186,119,255,120,12,121,19,121,20,121,9,121,16,121,18,121,17,121,173,121,172,121,95,122,28,124,41,124,25,124,32,124,31,124,45,124,29,124,38,124,40,124,34,124,37,124,48,124,92,126,80,126,86,126,99,126,88,126,98,126,95,126,81,126,96,126,87,126,83,126,181,127,179,127,247,127,248,127,117,128,209,129,210,129,208,129,95,130,94,130,180,133,198,133,192,133,195,133,194,133,179,133,181,133,189,133,199,133,196,133,191,133,203,133,206,133,200,133,197,133,177,133,182,133,210,133,36,134,184,133,183,133,190,133,105,134,231,135,230,135,226,135,219,135,235,135,234,135,229,135,223,135,243,135,228,135,212,135,220,135,211,135,237,135,216,135,227,135,164,135,215,135,217,135,1,136,244,135,232,135,221,135,83,137,75,137,79,137,76,137,70,137,80,137,81,137,73,137,42,139,39,139,35,139,51,139,48,139,53,139,71,139,47,139,60,139,62,139,49,139,37,139,55,139,38,139,54,139,46,139,36,139,59,139,61,139,58,139,66,140,117,140,153,140,152,140,151,140,254,140,4,141,2,141,0,141,92,142,98,142,96,142,87,142,86,142,94,142,101,142,103,142,91,142,90,142,97,142,93,142,105,142,84,142,70,143,71,143,72,143,75,143,40,145,58,145,59,145,62,145,168,145,165,145,167,145,175,145,170,145,181,147,140,147,146,147,183,147,155,147,157,147,137,147,167,147,142,147,170,147,158,147,166,147,149,147,136,147,153,147,159,147,141,147,177,147,145,147,178,147,164,147,168,147,180,147,163,147,165,147,210,149,211,149,209,149,179,150,215,150,218,150,194,93,223,150,216,150,221,150,35,151,34,151,37,151,172,151,174,151,168,151,171,151,164,151,170,151,162,151,165,151,215,151,217,151,214,151,216,151,250,151,80,152,81,152,82,152,184,152,65,153,60,153,58,153,15,154,11,154,9,154,13,154,4,154,17,154,10,154,5,154,7,154,6,154,192,154,220,154,8,155,4,155,5,155,41,155,53,155,74,155,76,155,75,155,199,155,198,155,195,155,191,155,193,155,181,155,184,155,211,155,182,155,196,155,185,155,189,155,92,157,83,157,79,157,74,157,91,157,75,157,89,157,86,157,76,157,87,157,82,157,84,157,95,157,88,157,90,157,142,158,140,158,223,158,1,159,0,159,22,159,37,159,43,159,42,159,41,159,40,159,76,159,85,159,52,81,53,81,150,82,247,82,180,83,171,86,173,86,166,86,167,86,170,86,172,86,218,88,221,88,219,88,18,89,61,91,62,91,63,91,195,93,112,94,191,95,251,97,7,101,16,101,13,101,9,101,12,101,14,101,132,101,222,101,221,101,222,102,231,106,224,106,204,106,209,106,217,106,203,106,223,106,220,106,208,106,235,106,207,106,205,106,222,106,96,107,176,107,12,108,25,112,39,112,32,112,22,112,43,112,33,112,34,112,35,112,41,112,23,112,36,112,28,112,42,112,12,114,10,114,7,114,2,114,5,114,165,114,166,114,164,114,163,114,161,114,203,116,197,116,183,116,195,116,22,117,96,118,201,119,202,119,196,119,241,119,29,121,27,121,33,121,28,121,23,121,30,121,176,121,103,122,104,122,51,124,60,124,57,124,44,124,59,124,236,124,234,124,118,126,117,126,120,126,112,126,119,126,111,126,122,126,114,126,116,126,104,126,75,127,74,127,131,127,134,127,183,127,253,127,254,127,120,128,215,129,213,129,100,130,97,130,99,130,235,133,241,133,237,133,217,133,225,133,232,133,218,133,215,133,236,133,242,133,248,133,216,133,223,133,227,133,220,133,209,133,240,133,230,133,239,133,222,133,226,133,0,136,250,135,3,136,246,135,247,135,9,136,12,136,11,136,6,136,252,135,8,136,255,135,10,136,2,136,98,137,90,137,91,137,87,137,97,137,92,137,88,137,93,137,89,137,136,137,183,137,182,137,246,137,80,139,72,139,74,139,64,139,83,139,86,139,84,139,75,139,85,139,81,139,66,139,82,139,87,139,67,140,119,140,118,140,154,140,6,141,7,141,9,141,172,141,170,141,173,141,171,141,109,142,120,142,115,142,106,142,111,142,123,142,194,142,82,143,81,143,79,143,80,143,83,143,180,143,64,145,63,145,176,145,173,145,222,147,199,147,207,147,194,147,218,147,208,147,249,147,236,147,204,147,217,147,169,147,230,147,202,147,212,147,238,147,227,147,213,147,196,147,206,147,192,147,210,147,231,147,125,149,218,149,219,149,225,150,41,151,43,151,44,151,40,151,38,151,179,151,183,151,182,151,221,151,222,151,223,151,92,152,89,152,93,152,87,152,191,152,189,152,187,152,190,152,72,153,71,153,67,153,166,153,167,153,26,154,21,154,37,154,29,154,36,154,27,154,34,154,32,154,39,154,35,154,30,154,28,154,20,154,194,154,11,155,10,155,14,155,12,155,55,155,234,155,235,155,224,155,222,155,228,155,230,155,226,155,240,155,212,155,215,155,236,155,220,155,217,155,229,155,213,155,225,155,218,155,119,157,129,157,138,157,132,157,136,157,113,157,128,157,120,157,134,157,139,157,140,157,125,157,107,157,116,157,117,157,112,157,105,157,133,157,115,157,123,157,130,157,111,157,121,157,127,157,135,157,104,157,148,158,145,158,192,158,252,158,45,159,64,159,65,159,77,159,86,159,87,159,88,159,55,83,178,86,181,86,179,86,227,88,69,91,198,93,199,93,238,94,239,94,192,95,193,95,249,97,23,101,22,101,21,101,19,101,223,101,232,102,227,102,228,102,243,106,240,106,234,106,232,106,249,106,241,106,238,106,239,106,60,112,53,112,47,112,55,112,52,112,49,112,66,112,56,112,63,112,58,112,57,112,64,112,59,112,51,112,65,112,19,114,20,114,168,114,125,115,124,115,186,116,171,118,170,118,190,118,237,118,204,119,206,119,207,119,205,119,242,119,37,121,35,121,39,121,40,121,36,121,41,121,178,121,110,122,108,122,109,122,247,122,73,124,72,124,74,124,71,124,69,124,238,124,123,126,126,126,129,126,128,126,186,127,255,127,121,128,219,129,217,129,11,130,104,130,105,130,34,134,255,133,1,134,254,133,27,134,0,134,246,133,4,134,9,134,5,134,12,134,253,133,25,136,16,136,17,136,23,136,19,136,22,136,99,137,102,137,185,137,247,137,96,139,106,139,93,139,104,139,99,139,101,139,103,139,109,139,174,141,134,142,136,142,132,142,89,143,86,143,87,143,85,143,88,143,90,143,141,144,67,145,65,145,183,145,181,145,178,145,179,145,11,148,19,148,251,147,32,148,15,148,20,148,254,147,21,148,16,148,40,148,25,148,13,148,245,147,0,148,247,147,7,148,14,148,22,148,18,148,250,147,9,148,248,147,10,148,255,147,252,147,12,148,246,147,17,148,6,148,222,149,224,149,223,149,46,151,47,151,185,151,187,151,253,151,254,151,96,152,98,152,99,152,95,152,193,152,194,152,80,153,78,153,89,153,76,153,75,153,83,153,50,154,52,154,49,154,44,154,42,154,54,154,41,154,46,154,56,154,45,154,199,154,202,154,198,154,16,155,18,155,17,155,11,156,8,156,247,155,5,156,18,156,248,155,64,156,7,156,14,156,6,156,23,156,20,156,9,156,159,157,153,157,164,157,157,157,146,157,152,157,144,157,155,157,160,157,148,157,156,157,170,157,151,157,161,157,154,157,162,157,168,157,158,157,163,157,191,157,169,157,150,157,166,157,167,157,153,158,155,158,154,158,229,158,228,158,231,158,230,158,48,159,46,159,91,159,96,159,94,159,93,159,89,159,145,159,58,81,57,81,152,82,151,82,195,86,189,86,190,86,72,91,71,91,203,93,207,93,241,94,253,97,27,101,2,107,252,106,3,107,248,106,0,107,67,112,68,112,74,112,72,112,73,112,69,112,70,112,29,114,26,114,25,114,126,115,23,117,106,118,208,119,45,121,49,121,47,121,84,124,83,124,242,124,138,126,135,126,136,126,139,126,134,126,141,126,77,127,187,127,48,128,221,129,24,134,42,134,38,134,31,134,35,134,28,134,25,134,39,134,46,134,33,134,32,134,41,134,30,134,37,134,41,136,29,136,27,136,32,136,36,136,28,136,43,136,74,136,109,137,105,137,110,137,107,137,250,137,121,139,120,139,69,139,122,139,123,139,16,141,20,141,175,141,142,142,140,142,94,143,91,143,93,143,70,145,68,145,69,145,185,145,63,148,59,148,54,148,41,148,61,148,60,148,48,148,57,148,42,148,55,148,44,148,64,148,49,148,229,149,228,149,227,149,53,151,58,151,191,151,225,151,100,152,201,152,198,152,192,152,88,153,86,153,57,154,61,154,70,154,68,154,66,154,65,154,58,154,63,154,205,154,21,155,23,155,24,155,22,155,58,155,82,155,43,156,29,156,28,156,44,156,35,156,40,156,41,156,36,156,33,156,183,157,182,157,188,157,193,157,199,157,202,157,207,157,190,157,197,157,195,157,187,157,181,157,206,157,185,157,186,157,172,157,200,157,177,157,173,157,204,157,179,157,205,157,178,157,122,158,156,158,235,158,238,158,237,158,27,159,24,159,26,159,49,159,78,159,101,159,100,159,146,159,185,78,198,86,197,86,203,86,113,89,75,91,76,91,213,93,209,93,242,94,33,101,32,101,38,101,34,101,11,107,8,107,9,107,13,108,85,112,86,112,87,112,82,112,30,114,31,114,169,114,127,115,216,116,213,116,217,116,215,116,109,118,173,118,53,121,180,121,112,122,113,122,87,124,92,124,89,124,91,124,90,124,244,124,241,124,145,126,79,127,135,127,222,129,107,130,52,134,53,134,51,134,44,134,50,134,54,134,44,136,40,136,38,136,42,136,37,136,113,137,191,137,190,137,251,137,126,139,132,139,130,139,134,139,133,139,127,139,21,141,149,142,148,142,154,142,146,142,144,142,150,142,151,142,96,143,98,143,71,145,76,148,80,148,74,148,75,148,79,148,71,148,69,148,72,148,73,148,70,148,63,151,227,151,106,152,105,152,203,152,84,153,91,153,78,154,83,154,84,154,76,154,79,154,72,154,74,154,73,154,82,154,80,154,208,154,25,155,43,155,59,155,86,155,85,155,70,156,72,156,63,156,68,156,57,156,51,156,65,156,60,156,55,156,52,156,50,156,61,156,54,156,219,157,210,157,222,157,218,157,203,157,208,157,220,157,209,157,223,157,233,157,217,157,216,157,214,157,245,157,213,157,221,157,182,158,240,158,53,159,51,159,50,159,66,159,107,159,149,159,162,159,61,81,153,82,232,88,231,88,114,89,77,91,216,93,47,136,79,95,1,98,3,98,4,98,41,101,37,101,150,101,235,102,17,107,18,107,15,107,202,107,91,112,90,112,34,114,130,115,129,115,131,115,112,118,212,119,103,124,102,124,149,126,108,130,58,134,64,134,57,134,60,134,49,134,59,134,62,134,48,136,50,136,46,136,51,136,118,137,116,137,115,137,254,137,140,139,142,139,139,139,136,139,69,140,25,141,152,142,100,143,99,143,188,145,98,148,85,148,93,148,87,148,94,148,196,151,197,151,0,152,86,154,89,154,30,155,31,155,32,155,82,156,88,156,80,156,74,156,77,156,75,156,85,156,89,156,76,156,78,156,251,157,247,157,239,157,227,157,235,157,248,157,228,157,246,157,225,157,238,157,230,157,242,157,240,157,226,157,236,157,244,157,243,157,232,157,237,157,194,158,208,158,242,158,243,158,6,159,28,159,56,159,55,159,54,159,67,159,79,159,113,159,112,159,110,159,111,159,211,86,205,86,78,91,109,92,45,101,237,102,238,102,19,107,95,112,97,112,93,112,96,112,35,114,219,116,229,116,213,119,56,121,183,121,182,121,106,124,151,126,137,127,109,130,67,134,56,136,55,136,53,136,75,136,148,139,149,139,158,142,159,142,160,142,157,142,190,145,189,145,194,145,107,148,104,148,105,148,229,150,70,151,67,151,71,151,199,151,229,151,94,154,213,154,89,155,99,156,103,156,102,156,98,156,94,156,96,156,2,158,254,157,7,158,3,158,6,158,5,158,0,158,1,158,9,158,255,157,253,157,4,158,160,158,30,159,70,159,116,159,117,159,118,159,212,86,46,101,184,101,24,107,25,107,23,107,26,107,98,112,38,114,170,114,216,119,217,119,57,121,105,124,107,124,246,124,154,126,152,126,155,126,153,126,224,129,225,129,70,134,71,134,72,134,121,137,122,137,124,137,123,137,255,137,152,139,153,139,165,142,164,142,163,142,110,148,109,148,111,148,113,148,115,148,73,151,114,152,95,153,104,156,110,156,109,156,11,158,13,158,16,158,15,158,18,158,17,158,161,158,245,158,9,159,71,159,120,159,123,159,122,159,121,159,30,87,102,112,111,124,60,136,178,141,166,142,195,145,116,148,120,148,118,148,117,148,96,154,116,156,115,156,113,156,117,156,20,158,19,158,246,158,10,159,164,159,104,112,101,112,247,124,106,134,62,136,61,136,63,136,158,139,156,140,169,142,201,142,75,151,115,152,116,152,204,152,97,153,171,153,100,154,102,154,103,154,36,155,21,158,23,158,72,159,7,98,30,107,39,114,76,134,168,142,130,148,128,148,129,148,105,154,104,154,46,155,25,158,41,114,75,134,159,139,131,148,121,156,183,158,117,118,107,154,122,156,29,158,105,112,106,112,164,158,126,159,73,159,152,159,129,120,185,146,207,136,187,88,82,96,167,124,250,90,84,37,102,37,87,37,96,37,108,37,99,37,90,37,105,37,93,37,82,37,100,37,85,37,94,37,106,37,97,37,88,37,103,37,91,37,83,37,101,37,86,37,95,37,107,37,98,37,89,37,104,37,92,37,81,37,80,37,109,37,110,37,112,37,111,37,147,37,0,0,0,0,0,0,0,0,0,1,0,0,0,255,0,0,1,0,0,0,255,0,0,1,0,0,0,255,0,0,1,0,0,0,255,0,0,0,0,0,1,1,0,0,255,255,0,1,1,0,0,255,255,0,1,1,0,0,255,255,0,0,1,0,0,1,255,0,0,255,0,1,0,1,0,255,0,255,1,0,1,0,255,0,255,0,0,0,255,1,0,0,1,255,0,255,1,0,0,1,255,0,255,1,0,0,1,255,0,0,1,0,0,255,255,0,0,1,0,255,0,1,0,1,0,255,255,0,1,0,1,0,255,0,0,1,1,1,0,255,255,255,1,1,1,0,255,255,255,0,1,1,0,1,255,255,0,255,1,0,1,1,255,0,255,255,0,255,1,1,0,1,255,255,255,1,1,0,1,255,255,0,1,1,0,255,255,255,0,1,1,0,255,1,255,0,1,255,0,1,255,1,0,255,1,255,1,255,1,0,255,1,255,0,255,1,0,1,1,255,0,255,1,0,1,255,255,0,255,1,0,1,1,255,0,255,255,1,1,1,255,0,255,255,1,0,1,255,0,1,255,1,0,255,255,0,1,1,1,0,255,255,1,1,1,1,255,255,255,255,1,1,1,255,255,255,255,1,1,1,255,1,255,255,1,255,1,255,1,1,255,1,255,255,255,1,1,1,1,255,255,255,1,1,255,255,255,255,1,1,1,255,255,1,255,1,1,255,1,255,1,255,255,1,255,1,0,8,32,64,80,0,0,0,117,139,63,193,17,239,1,255,180,76,80,176,18,238,118,138,134,122,64,192,54,202,46,210,16,240,140,116,100,156,62,194,197,59,81,175,135,121,181,75,163,93,79,177,157,99,55,201,71,185,47,209,133,123,203,53,219,37,211,45,101,155,179,77,198,58,220,36,72,184,164,92,196,60,94,162,38,218,186,70,74,170,170,170,186,186,186,170,170,170,170,170,170,170,170,171,170,170,170,170,170,154,169,169,153,169,153,153,169,169,153,153,153,153,153,153,153,153,136,152,136,136,136,136,136,136,136,136,119,120,119,119,119,119,102,102,102,85,85,85,85,84,68,50,68,85,85,102,102,102,102,119,119,119,119,119,119,135,136,136,136,136,136,136,136,136,136,137,136,137,137,153,153,152,153,154,153,153,153,153,154,169,154,153,154,169,169,169,170,170,169,170,170,170,170,170,187,170,170,170,170,186,170,170,170,170,186,64,76,188,172,188,186,171,171,187,186,170,171,170,187,170,187,170,171,186,186,170,187,170,169,170,187,170,170,154,154,170,169,170,153,153,153,153,153,153,153,153,152,152,152,137,136,136,136,136,135,120,119,119,119,119,103,102,102,85,68,69,84,68,68,51,68,69,85,86,102,102,102,103,119,119,119,119,135,135,120,136,136,136,136,136,153,136,153,153,137,153,153,153,153,153,153,169,169,170,154,169,170,154,170,154,170,171,170,170,170,170,170,170,187,188,187,186,170,171,171,170,171,171,172,187,170,187,187,64,91,187,188,187,203,204,187,187,188,204,187,203,186,203,188,187,170,187,171,186,187,187,171,187,170,186,186,170,170,170,170,170,170,170,169,154,154,153,154,153,153,153,153,153,152,152,137,153,136,136,136,136,119,119,119,119,119,102,102,85,84,68,67,34,52,68,85,86,102,102,103,119,119,119,135,136,136,136,136,136,153,137,153,153,153,153,153,154,154,169,169,154,154,170,154,170,170,170,186,170,170,170,186,170,170,171,186,187,170,187,171,187,187,187,187,187,187,187,187,188,187,188,187,187,204,188,203,80,0,0,32,0,64,0,96,0,8,0,40,0,72,0,104,0,12,0,44,0,76,0,108,0,20,0,52,0,84,0,116,0,26,0,58,0,90,0,122,0,128,0,160,0,192,0,224,0,134,0,166,0,198,0,230,0,141,0,173,0,205,0,237,0,150,0,182,0,214,0,246,0,0,1,32,1,64,1,96,1,128,1,160,1,192,1,224,1,12,1,44,1,76,1,108,1,140,1,172,1,204,1,236,1,0,0,8,0,16,0,24,0,32,0,36,0,40,0,44,0,48,0,56,0,64,0,72,0,80,0,86,0,92,0,98,0,104,0,110,0,116,0,122,0,128,0,134,0,140,0,146,0,152,0,159,0,166,0,173,0,180,0,189,0,198,0,207,0,216,0,226,0,236,0,246,0,0,1,12,1,24,1,36,1,48,1,60,1,72,1,84,1,96,1,116,1,136,1,156,1,176,1,196,1,216,1,236,1,0,20,36,52,0,0,0,0,0,24,36,48,72,108,132,156,0,112,176,208,0,0,0,0,20,28,32,36,40,44,48,52,0,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,7,8,9,10,11,12,13,14,15,16,17,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,3,3,3,3,4,4,4,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,7,7,7,8,8,8,9,9,10,10,11,11,12,13,14,15,16,17,18,19,20,21,22,23,23,24,24,25,25,26,27,0,0,0,0,0,0,240,63,0,0,0,0,0,0,208,63,28,199,113,28,199,113,188,63,0,0,0,0,0,0,176,63,123,20,174,71,225,122,164,63,28,199,113,28,199,113,156,63,57,5,47,167,224,229,148,63,0,0,0,0,0,0,144,63,224,233,214,252,176,72,137,63,123,20,174,71,225,122,132,63,144,156,230,107,245,236,128,63,28,199,113,28,199,113,124,63,221,190,178,122,151,60,120,63,57,5,47,167,224,229,116,63,223,188,154,120,86,52,114,63,0,0,0,0,0,0,112,63,134,73,13,209,148,88,108,63,224,233,214,252,176,72,105,63,61,26,163,10,73,177,102,63,123,20,174,71,225,122,100,63,165,4,184,91,114,147,98,63,144,156,230,107,245,236,96,63,173,235,137,179,189,248,94,63,28,199,113,28,199,113,92,63,45,67,28,235,226,54,90,63,221,190,178,122,151,60,88,63,199,8,191,224,128,121,86,63,57,5,47,167,224,229,84,63,68,39,135,36,72,123,83,63,223,188,154,120,86,52,82,63,46,149,208,49,133,12,81,63,0,0,0,0,0,0,80,63,85,22,97,163,9,23,78,63,134,73,13,209,148,88,76,63,166,47,60,224,215,191,74,63,224,233,214,252,176,72,73,63,235,216,56,80,139,239,71,63,61,26,163,10,73,177,70,63,140,226,158,80,49,139,69,63,123,20,174,71,225,122,68,63,139,225,71,168,63,126,67,63,165,4,184,91,114,147,66,63,57,159,146,197,213,184,65,63,144,156,230,107,245,236,64,63,113,139,137,192,133,46,64,63,173,235,137,179,189,248,62,63,26,191,47,228,239,170,61,63,28,199,113,28,199,113,60,63,253,126,249,92,152,75,59,63,45,67,28,235,226,54,58,63,176,150,125,100,75,50,57,63,221,190,178,122,151,60,56,63,224,58,202,61,170,84,55,63,199,8,191,224,128,121,54,63,31,231,69,230,47,170,53,63,57,5,47,167,224,229,52,63,54,80,230,37,207,43,52,63,68,39,135,36,72,123,51,63,201,111,144,116,167,211,50,63,223,188,154,120,86,52,50,63,57,149,143,209,202,156,49,63,46,149,208,49,133,12,49,63,147,32,135,81,16,131,48,63,0,0,0,0,0,0,48,63,27,193,13,157,224,5,47,63,85,22,97,163,9,23,46,63,141,167,214,236,207,50,45,63,134,73,13,209,148,88,44,63,210,38,94,17,197,135,43,63,166,47,60,224,215,191,42,63,190,2,234,0,78,0,42,63,224,233,214,252,176,72,41,63,155,172,71,108,146,152,40,63,235,216,56,80,139,239,39,63,40,88,167,123,59,77,39,63,61,26,163,10,73,177,38,63,31,126,191,229,95,27,38,63,140,226,158,80,49,139,37,63,166,77,123,130,115,0,37,63,123,20,174,71,225,122,36,63,149,121,84,171,57,250,35,63,139,225,71,168,63,126,35,63,81,240,181,224,185,6,35,63,165,4,184,91,114,147,34,63,127,108,90,72,54,36,34,63,57,159,146,197,213,184,33,63,118,6,177,174,35,81,33,63,144,156,230,107,245,236,32,63,43,21,129,198,34,140,32,63,113,139,137,192,133,46,32,63,158,233,243,222,244,167,31,63,173,235,137,179,189,248,30,63,109,151,228,173,37,79,30,63,26,191,47,228,239,170,29,63,47,187,249,156,226,11,29,63,28,199,113,28,199,113,28,63,250,44,75,117,105,220,27,63,253,126,249,92,152,75,27,63,104,247,0,3,37,191,26,63,45,67,28,235,226,54,26,63,224,65,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,76,33,0,56,32,32,0,4,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,111,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,65,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,238,33,0,108,0,0,0,24,117,26,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,201,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,89,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,56,153,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,89,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,32,129,32,0,136,102,32,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,32,129,32,0,112,82,32,0,40,48,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,8,255,31,0,72,233,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,152,213,31,0,120,194,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,144,172,31,0,168,154,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,88,137,31,0,240,195,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,72,106,31,0,240,195,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,96,181,30,0,120,155,30,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,48,121,30,0,120,155,30,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,231,32,0,108,0,0,0,32,118,26,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,0,0,3,0,0,4,0,1,0,0,1,1,0,1,2,0,1,3,0,1,4,0,2,0,0,2,1,0,2,2,0,2,3,0,2,4,0,3,0,0,3,1,0,3,2,0,3,3,0,3,4,0,4,0,0,4,1,0,4,2,0,4,3,0,4,4,1,0,0,1,0,1,1,0,2,1,0,3,1,0,4,1,1,0,1,1,1,1,1,2,1,1,3,1,1,4,1,2,0,1,2,1,1,2,2,1,2,3,1,2,4,1,3,0,1,3,1,1,3,2,1,3,3,1,3,4,1,4,0,1,4,1,1,4,2,1,4,3,1,4,4,2,0,0,2,0,1,2,0,2,2,0,3,2,0,4,2,1,0,2,1,1,2,1,2,2,1,3,2,1,4,2,2,0,2,2,1,2,2,2,2,2,3,2,2,4,2,3,0,2,3,1,2,3,2,2,3,3,2,3,4,2,4,0,2,4,1,2,4,2,2,4,3,2,4,4,3,0,0,3,0,1,3,0,2,3,0,3,3,0,4,3,1,0,3,1,1,3,1,2,3,1,3,3,1,4,3,2,0,3,2,1,3,2,2,3,2,3,3,2,4,3,3,0,3,3,1,3,3,2,3,3,3,3,3,4,3,4,0,3,4,1,3,4,2,3,4,3,3,4,4,4,0,0,4,0,1,4,0,2,4,0,3,4,0,4,4,1,0,4,1,1,4,1,2,4,1,3,4,1,4,4,2,0,4,2,1,4,2,2,4,2,3,4,2,4,4,3,0,4,3,1,4,3,2,4,3,3,4,3,4,4,4,0,4,4,1,4,4,2,4,4,3,4,4,4,0,0,0,0,0,0,0,0,0,3,0,3,0,3,0,3,0,4,0,5,0,6,0,8,0,12,0,17,0,0,0,0,0,2,0,1,0,2,0,2,0,3,0,4,0,5,0,7,0,13,0,25,0,0,0,0,0,1,0,2,0,1,0,2,0,3,0,4,0,6,0,10,0,23,0,76,0,0,0,0,0,1,0,2,0,1,0,2,0,3,0,4,0,6,0,10,0,23,0,76,0,0,0,0,0,3,0,2,0,3,0,4,0,4,0,6,0,9,0,14,0,26,0,57,0,0,0,0,0,3,0,2,0,3,0,4,0,4,0,6,0,9,0,14,0,26,0,57,0,0,0,0,0,1,0,2,0,1,0,2,0,3,0,4,0,6,0,10,0,23,0,76,0,0,0,0,0,3,0,4,0,4,0,4,0,5,0,7,0,10,0,16,0,26,0,49,0,0,0,0,0,3,0,4,0,4,0,4,0,5,0,7,0,10,0,16,0,26,0,49,0,0,0,0,0,2,0,2,0,2,0,3,0,3,0,5,0,7,0,12,0,25,0,67,0,0,0,0,0,2,0,3,0,2,0,3,0,3,0,4,0,6,0,8,0,12,0,21,0,0,0,0,0,2,0,3,0,2,0,3,0,3,0,4,0,6,0,8,0,12,0,21,0,0,0,0,0,2,0,1,0,2,0,3,0,4,0,6,0,13,0,33,0,3,0,3,0,3,0,3,0,4,0,5,0,6,0,8,0,12,0,17,0,0,0,0,0,6,0,5,0,6,0,6,0,6,0,6,0,7,0,7,0,8,0,8,0,9,0,10,0,11,0,13,0,15,0,18,0,20,0,25,0,31,0,39,0,3,0,4,0,3,0,4,0,3,0,4,0,4,0,5,0,5,0,6,0,6,0,8,0,9,0,11,0,13,0,17,0,23,0,29,0,41,0,58,0,3,0,2,0,3,0,3,0,3,0,4,0,3,0,5,0,4,0,6,0,7,0,8,0,10,0,14,0,18,0,25,0,36,0,55,0,95,0,208,0,3,0,2,0,3,0,3,0,3,0,4,0,3,0,5,0,4,0,6,0,7,0,8,0,10,0,14,0,18,0,25,0,36,0,55,0,95,0,208,0,5,0,5,0,5,0,6,0,5,0,7,0,6,0,7,0,9,0,9,0,11,0,13,0,15,0,20,0,24,0,33,0,43,0,61,0,88,0,140,0,5,0,5,0,5,0,6,0,5,0,7,0,6,0,7,0,9,0,9,0,11,0,13,0,15,0,20,0,24,0,33,0,43,0,61,0,88,0,140,0,3,0,2,0,3,0,3,0,3,0,4,0,3,0,5,0,4,0,6,0,7,0,8,0,10,0,14,0,18,0,25,0,36,0,55,0,95,0,208,0,3,0,2,0,3,0,2,0,3,0,3,0,4,0,3,0,4,0,5,0,5,0,7,0,8,0,9,0,13,0,16,0,22,0,30,0,44,0,70,0,7,0,6,0,7,0,7,0,7,0,8,0,9,0,9,0,10,0,11,0,14,0,15,0,18,0,22,0,27,0,34,0,44,0,59,0,81,0,117,0,7,0,6,0,7,0,7,0,7,0,8,0,9,0,9,0,10,0,11,0,14,0,15,0,18,0,22,0,27,0,34,0,44,0,59,0,81,0,117,0,3,0,3,0,3,0,3,0,4,0,3,0,4,0,4,0,4,0,5,0,5,0,6,0,7,0,8,0,10,0,12,0,14,0,18,0,24,0,30,0,42,0,59,0,89,0,152,0,4,0,5,0,4,0,5,0,5,0,5,0,6,0,5,0,7,0,7,0,8,0,9,0,10,0,12,0,15,0,17,0,22,0,28,0,35,0,47,0,4,0,5,0,4,0,5,0,5,0,5,0,6,0,5,0,7,0,7,0,8,0,9,0,10,0,12,0,15,0,17,0,22,0,28,0,35,0,47,0,3,0,3,0,4,0,3,0,4,0,4,0,5,0,6,0,7,0,9,0,11,0,15,0,21,0,30,0,48,0,83,0,6,0,5,0,6,0,6,0,6,0,6,0,7,0,7,0,8,0,8,0,9,0,10,0,11,0,13,0,15,0,18,0,20,0,25,0,31,0,39,0,7,0,8,0,7,0,8,0,8,0,8,0,8,0,8,0,8,0,9,0,9,0,10,0,10,0,11,0,11,0,12,0,12,0,14,0,15,0,16,0,18,0,19,0,21,0,24,0,27,0,30,0,35,0,40,0,46,0,53,0,0,0,0,0,4,0,5,0,4,0,5,0,4,0,5,0,5,0,5,0,5,0,6,0,6,0,6,0,6,0,8,0,7,0,9,0,9,0,11,0,11,0,14,0,15,0,17,0,20,0,24,0,28,0,34,0,41,0,51,0,64,0,83,0,0,0,0,0,5,0,6,0,5,0,6,0,5,0,6,0,6,0,6,0,6,0,6,0,7,0,7,0,7,0,8,0,8,0,9,0,9,0,10,0,11,0,11,0,13,0,14,0,16,0,17,0,19,0,22,0,25,0,29,0,33,0,39,0,46,0,54,0,64,0,79,0,98,0,123,0,161,0,220,0,64,1,0,2,5,0,6,0,5,0,6,0,5,0,6,0,6,0,6,0,6,0,6,0,7,0,7,0,7,0,8,0,8,0,9,0,9,0,10,0,11,0,11,0,13,0,14,0,16,0,17,0,19,0,22,0,25,0,29,0,33,0,39,0,46,0,54,0,64,0,79,0,98,0,123,0,161,0,220,0,64,1,0,2,6,0,7,0,6,0,6,0,7,0,7,0,7,0,7,0,7,0,8,0,9,0,8,0,10,0,10,0,11,0,12,0,13,0,15,0,16,0,18,0,21,0,24,0,27,0,33,0,38,0,46,0,55,0,68,0,84,0,107,0,140,0,191,0,3,0,3,0,3,0,4,0,3,0,3,0,4,0,3,0,4,0,4,0,4,0,5,0,4,0,5,0,6,0,6,0,7,0,7,0,8,0,9,0,10,0,12,0,14,0,16,0,20,0,22,0,28,0,34,0,42,0,53,0,71,0,95,0,6,0,7,0,6,0,6,0,7,0,7,0,7,0,7,0,7,0,8,0,9,0,8,0,10,0,10,0,11,0,12,0,13,0,15,0,16,0,18,0,21,0,24,0,27,0,33,0,38,0,46,0,55,0,68,0,84,0,107,0,140,0,191,0,3,0,4,0,3,0,4,0,3,0,4,0,4,0,4,0,4,0,4,0,5,0,5,0,5,0,6,0,7,0,7,0,8,0,9,0,11,0,12,0,14,0,16,0,20,0,24,0,29,0,36,0,45,0,60,0,80,0,113,0,173,0,46,1,9,0,9,0,8,0,9,0,10,0,9,0,10,0,10,0,10,0,12,0,11,0,13,0,13,0,14,0,16,0,17,0,19,0,20,0,24,0,26,0,30,0,35,0,40,0,48,0,56,0,68,0,83,0,102,0,128,0,165,0,0,0,0,0,9,0,9,0,8,0,9,0,10,0,9,0,10,0,10,0,10,0,12,0,11,0,13,0,13,0,14,0,16,0,17,0,19,0,20,0,24,0,26,0,30,0,35,0,40,0,48,0,56,0,68,0,83,0,102,0,128,0,165,0,0,0,0,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,6,0,6,0,7,0,7,0,7,0,8,0,9,0,10,0,11,0,12,0,14,0,17,0,19,0,22,0,27,0,33,0,40,0,51,0,64,0,84,0,114,0,164,0,1,1,0,0,0,0,6,0,6,0,6,0,6,0,6,0,6,0,7,0,6,0,7,0,7,0,8,0,8,0,8,0,9,0,10,0,10,0,11,0,13,0,13,0,15,0,17,0,18,0,21,0,25,0,27,0,33,0,38,0,45,0,54,0,66,0,0,0,0,0,6,0,6,0,6,0,6,0,6,0,6,0,7,0,6,0,7,0,7,0,8,0,8,0,8,0,9,0,10,0,10,0,11,0,13,0,13,0,15,0,17,0,18,0,21,0,25,0,27,0,33,0,38,0,45,0,54,0,66,0,0,0,0,0,4,0,4,0,5,0,4,0,5,0,4,0,5,0,6,0,6,0,6,0,7,0,8,0,9,0,10,0,12,0,14,0,17,0,21,0,27,0,33,0,44,0,58,0,82,0,121,0,7,0,8,0,7,0,8,0,8,0,8,0,8,0,8,0,8,0,9,0,9,0,10,0,10,0,11,0,11,0,12,0,12,0,14,0,15,0,16,0,18,0,19,0,21,0,24,0,27,0,30,0,35,0,40,0,46,0,53,0,0,0,0,0,96,201,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,56,153,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,32,129,32,0,136,102,32,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,32,129,32,0,112,82,32,0,40,48,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,8,255,31,0,72,233,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,152,213,31,0,120,194,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,144,172,31,0,168,154,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,88,137,31,0,136,237,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,72,106,31,0,136,237,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,26,29,0,108,0,0,0,128,129,26,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,201,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,56,153,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,32,129,32,0,136,102,32,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,32,129,32,0,112,82,32,0,40,48,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,8,255,31,0,72,233,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,152,213,31,0,120,194,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,144,172,31,0,168,154,31,0,0,0,0,0,128,0,0,0,4], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1727685);
/* memory initializer */ allocate([8,0,1,0,32,129,32,0,88,137,31,0,136,237,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,72,106,31,0,136,237,30,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,24,224,30,0,112,211,30,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,220,29,0,108,0,0,0,144,131,26,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,6,0,9,0,12,0,16,0,20,0,24,0,29,0,34,0,40,0,46,0,53,0,60,0,68,0,76,0,84,0,93,0,102,0,111,0,121,0,131,0,141,0,151,0,162,0,173,0,184,0,195,0,207,0,219,0,231,0,243,0,0,1,0,0,0,0,0,0,4,4,4,4,6,8,10,12,14,18,22,30,56,4,4,4,4,6,6,10,12,14,16,20,26,66,4,4,4,4,6,8,12,16,20,26,34,42,12,4,4,4,6,6,8,10,14,18,26,32,42,18,4,4,4,6,8,10,12,14,18,24,32,44,12,4,4,4,6,8,10,12,14,18,24,30,40,18,4,4,4,6,8,10,12,14,18,24,30,40,18,4,4,4,6,8,10,12,14,18,24,30,40,18,8,8,8,12,16,20,24,28,36,2,2,2,26,0,0,0,4,4,4,4,6,8,10,12,14,18,22,30,56,4,4,4,4,6,6,10,12,14,16,20,26,66,4,4,4,4,6,8,12,16,20,26,34,42,12,4,4,4,6,6,8,10,14,18,26,32,42,18,4,4,4,6,8,10,12,14,18,24,32,44,12,4,4,4,6,8,10,12,14,18,24,30,40,18,4,4,4,6,8,10,12,14,18,24,30,40,18,4,4,4,6,8,10,12,14,18,24,30,40,18,8,8,8,12,16,20,24,28,36,2,2,2,26,0,0,0,4,4,4,4,4,4,6,6,8,8,10,12,16,20,24,28,34,42,50,54,76,158,4,4,4,4,4,4,6,6,6,8,10,12,16,18,22,28,34,40,46,54,54,192,4,4,4,4,4,4,6,6,8,10,12,16,20,24,30,38,46,56,68,84,102,26,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,18,22,26,32,38,46,52,64,70,76,36,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,12,12,12,12,12,12,16,20,24,28,32,40,48,56,64,76,90,2,2,2,2,2,0,0,4,4,4,4,4,4,6,6,8,8,10,12,16,20,24,28,34,42,50,54,76,158,4,4,4,4,4,4,6,6,6,8,10,12,16,18,22,28,34,40,46,54,54,192,4,4,4,4,4,4,6,6,8,10,12,16,20,24,30,38,46,56,68,84,102,26,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,18,22,26,32,38,46,52,64,70,76,36,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,12,12,12,12,12,12,16,20,24,28,32,40,48,56,64,76,90,2,2,2,2,2,0,0,0,1,1,0,8,16,1,0,8,64,1,0,8,80,1,0,16,48,2,0,32,48,2,0,16,192,2,0,32,192,2,0,16,240,2,0,32,240,2,0,64,48,4,0,64,192,4,0,64,240,4,0,0,0,0,0,0,1,1,0,8,16,1,0,8,64,1,0,8,80,1,0,16,48,2,0,32,48,2,0,16,192,2,0,32,192,2,0,16,240,2,0,32,240,2,0,64,48,4,0,64,192,4,0,64,240,4,0,0,0,0,0,0,241,1,0,8,16,1,0,8,64,1,0,8,80,1,0,16,48,2,0,32,48,2,0,16,192,2,0,32,192,2,0,16,144,2,0,32,144,2,0,16,96,2,0,32,96,2,0,16,176,2,0,32,176,2,0,16,224,2,0,32,224,2,0,16,112,2,0,32,112,2,0,16,208,2,0,32,208,2,0,16,240,2,0,32,240,2,0,64,240,4,0,0,0,0,0,0,241,1,0,8,16,1,0,8,64,1,0,8,80,1,0,16,48,2,0,32,48,2,0,16,192,2,0,32,192,2,0,16,144,2,0,32,144,2,0,16,96,2,0,32,96,2,0,16,176,2,0,32,176,2,0,16,224,2,0,32,224,2,0,16,112,2,0,32,112,2,0,16,208,2,0,32,208,2,0,16,240,2,0,32,240,2,0,64,240,4,0,0,0,0,0,245,255,247,255,249,255,251,255,253,255,255,255,1,0,3,0,5,0,7,0,9,0,11,0,13,0,15,0,18,0,17,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,35,0,37,0,39,0,41,0,43,0,45,0,47,0,49,0,51,0,53,0,55,0,57,0,59,0,61,0,63,0,65,0,67,0,69,0,71,0,73,0,75,0,77,0,79,0,81,0,83,0,85,0,87,0,89,0,91,0,93,0,95,0,97,0,99,0,101,0,103,0,105,0,107,0,109,0,111,0,113,0,115,0,117,0,119,0,121,0,123,0,125,0,127,0,129,0,131,0,133,0,135,0,137,0,139,0,141,0,143,0,145,0,147,0,149,0,151,0,153,0,155,0,157,0,159,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,8,0,0,0,12,0,0,0,9,0,0,0,13,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,7,0,0,0,10,0,0,0,14,0,0,0,11,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,129,165,129,129,189,153,129,129,126,0,0,0,0,0,0,126,255,219,255,255,195,231,255,255,126,0,0,0,0,0,0,0,0,108,254,254,254,254,124,56,16,0,0,0,0,0,0,0,0,16,56,124,254,124,56,16,0,0,0,0,0,0,0,0,24,60,60,231,231,231,24,24,60,0,0,0,0,0,0,0,24,60,126,255,255,126,24,24,60,0,0,0,0,0,0,0,0,0,0,24,60,60,24,0,0,0,0,0,0,255,255,255,255,255,255,231,195,195,231,255,255,255,255,255,255,0,0,0,0,0,60,102,66,66,102,60,0,0,0,0,0,255,255,255,255,255,195,153,189,189,153,195,255,255,255,255,255,0,0,30,14,26,50,120,204,204,204,204,120,0,0,0,0,0,0,60,102,102,102,102,60,24,126,24,24,0,0,0,0,0,0,63,51,63,48,48,48,48,112,240,224,0,0,0,0,0,0,127,99,127,99,99,99,99,103,231,230,192,0,0,0,0,0,0,24,24,219,60,231,60,219,24,24,0,0,0,0,0,128,192,224,240,248,254,248,240,224,192,128,0,0,0,0,0,2,6,14,30,62,254,62,30,14,6,2,0,0,0,0,0,0,24,60,126,24,24,24,126,60,24,0,0,0,0,0,0,0,102,102,102,102,102,102,102,0,102,102,0,0,0,0,0,0,127,219,219,219,123,27,27,27,27,27,0,0,0,0,0,124,198,96,56,108,198,198,108,56,12,198,124,0,0,0,0,0,0,0,0,0,0,0,254,254,254,254,0,0,0,0,0,0,24,60,126,24,24,24,126,60,24,126,0,0,0,0,0,0,24,60,126,24,24,24,24,24,24,24,0,0,0,0,0,0,24,24,24,24,24,24,24,126,60,24,0,0,0,0,0,0,0,0,0,24,12,254,12,24,0,0,0,0,0,0,0,0,0,0,0,48,96,254,96,48,0,0,0,0,0,0,0,0,0,0,0,0,192,192,192,254,0,0,0,0,0,0,0,0,0,0,0,36,102,255,102,36,0,0,0,0,0,0,0,0,0,0,16,56,56,124,124,254,254,0,0,0,0,0,0,0,0,0,254,254,124,124,56,56,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,60,60,60,24,24,24,0,24,24,0,0,0,0,0,102,102,102,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,108,254,108,108,108,254,108,108,0,0,0,0,24,24,124,198,194,192,124,6,6,134,198,124,24,24,0,0,0,0,0,0,194,198,12,24,48,96,198,134,0,0,0,0,0,0,56,108,108,56,118,220,204,204,204,118,0,0,0,0,0,48,48,48,96,0,0,0,0,0,0,0,0,0,0,0,0,0,12,24,48,48,48,48,48,48,24,12,0,0,0,0,0,0,48,24,12,12,12,12,12,12,24,48,0,0,0,0,0,0,0,0,0,102,60,255,60,102,0,0,0,0,0,0,0,0,0,0,0,24,24,126,24,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,48,0,0,0,0,0,0,0,0,0,0,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,0,2,6,12,24,48,96,192,128,0,0,0,0,0,0,60,102,195,195,219,219,195,195,102,60,0,0,0,0,0,0,24,56,120,24,24,24,24,24,24,126,0,0,0,0,0,0,124,198,6,12,24,48,96,192,198,254,0,0,0,0,0,0,124,198,6,6,60,6,6,6,198,124,0,0,0,0,0,0,12,28,60,108,204,254,12,12,12,30,0,0,0,0,0,0,254,192,192,192,252,6,6,6,198,124,0,0,0,0,0,0,56,96,192,192,252,198,198,198,198,124,0,0,0,0,0,0,254,198,6,6,12,24,48,48,48,48,0,0,0,0,0,0,124,198,198,198,124,198,198,198,198,124,0,0,0,0,0,0,124,198,198,198,126,6,6,6,12,120,0,0,0,0,0,0,0,0,24,24,0,0,0,24,24,0,0,0,0,0,0,0,0,0,24,24,0,0,0,24,24,48,0,0,0,0,0,0,0,6,12,24,48,96,48,24,12,6,0,0,0,0,0,0,0,0,0,126,0,0,126,0,0,0,0,0,0,0,0,0,0,96,48,24,12,6,12,24,48,96,0,0,0,0,0,0,124,198,198,12,24,24,24,0,24,24,0,0,0,0,0,0,0,124,198,198,222,222,222,220,192,124,0,0,0,0,0,0,16,56,108,198,198,254,198,198,198,198,0,0,0,0,0,0,252,102,102,102,124,102,102,102,102,252,0,0,0,0,0,0,60,102,194,192,192,192,192,194,102,60,0,0,0,0,0,0,248,108,102,102,102,102,102,102,108,248,0,0,0,0,0,0,254,102,98,104,120,104,96,98,102,254,0,0,0,0,0,0,254,102,98,104,120,104,96,96,96,240,0,0,0,0,0,0,60,102,194,192,192,222,198,198,102,58,0,0,0,0,0,0,198,198,198,198,254,198,198,198,198,198,0,0,0,0,0,0,60,24,24,24,24,24,24,24,24,60,0,0,0,0,0,0,30,12,12,12,12,12,204,204,204,120,0,0,0,0,0,0,230,102,102,108,120,120,108,102,102,230,0,0,0,0,0,0,240,96,96,96,96,96,96,98,102,254,0,0,0,0,0,0,195,231,255,255,219,195,195,195,195,195,0,0,0,0,0,0,198,230,246,254,222,206,198,198,198,198,0,0,0,0,0,0,124,198,198,198,198,198,198,198,198,124,0,0,0,0,0,0,252,102,102,102,124,96,96,96,96,240,0,0,0,0,0,0,124,198,198,198,198,198,198,214,222,124,12,14,0,0,0,0,252,102,102,102,124,108,102,102,102,230,0,0,0,0,0,0,124,198,198,96,56,12,6,198,198,124,0,0,0,0,0,0,255,219,153,24,24,24,24,24,24,60,0,0,0,0,0,0,198,198,198,198,198,198,198,198,198,124,0,0,0,0,0,0,195,195,195,195,195,195,195,102,60,24,0,0,0,0,0,0,195,195,195,195,195,219,219,255,102,102,0,0,0,0,0,0,195,195,102,60,24,24,60,102,195,195,0,0,0,0,0,0,195,195,195,102,60,24,24,24,24,60,0,0,0,0,0,0,255,195,134,12,24,48,96,193,195,255,0,0,0,0,0,0,60,48,48,48,48,48,48,48,48,60,0,0,0,0,0,0,0,128,192,224,112,56,28,14,6,2,0,0,0,0,0,0,60,12,12,12,12,12,12,12,12,60,0,0,0,0,16,56,108,198,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,48,48,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,12,124,204,204,204,118,0,0,0,0,0,0,224,96,96,120,108,102,102,102,102,124,0,0,0,0,0,0,0,0,0,124,198,192,192,192,198,124,0,0,0,0,0,0,28,12,12,60,108,204,204,204,204,118,0,0,0,0,0,0,0,0,0,124,198,254,192,192,198,124,0,0,0,0,0,0,56,108,100,96,240,96,96,96,96,240,0,0,0,0,0,0,0,0,0,118,204,204,204,204,204,124,12,204,120,0,0,0,224,96,96,108,118,102,102,102,102,230,0,0,0,0,0,0,24,24,0,56,24,24,24,24,24,60,0,0,0,0,0,0,6,6,0,14,6,6,6,6,6,6,102,102,60,0,0,0,224,96,96,102,108,120,120,108,102,230,0,0,0,0,0,0,56,24,24,24,24,24,24,24,24,60,0,0,0,0,0,0,0,0,0,230,255,219,219,219,219,219,0,0,0,0,0,0,0,0,0,220,102,102,102,102,102,102,0,0,0,0,0,0,0,0,0,124,198,198,198,198,198,124,0,0,0,0,0,0,0,0,0,220,102,102,102,102,102,124,96,96,240,0,0,0,0,0,0,118,204,204,204,204,204,124,12,12,30,0,0,0,0,0,0,220,118,102,96,96,96,240,0,0,0,0,0,0,0,0,0,124,198,96,56,12,198,124,0,0,0,0,0,0,16,48,48,252,48,48,48,48,54,28,0,0,0,0,0,0,0,0,0,204,204,204,204,204,204,118,0,0,0,0,0,0,0,0,0,195,195,195,195,102,60,24,0,0,0,0,0,0,0,0,0,195,195,195,219,219,255,102,0,0,0,0,0,0,0,0,0,195,102,60,24,60,102,195,0,0,0,0,0,0,0,0,0,198,198,198,198,198,198,126,6,12,248,0,0,0,0,0,0,254,204,24,48,96,198,254,0,0,0,0,0,0,14,24,24,24,112,24,24,24,24,14,0,0,0,0,0,0,24,24,24,24,0,24,24,24,24,24,0,0,0,0,0,0,112,24,24,24,14,24,24,24,24,112,0,0,0,0,0,0,118,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,56,108,198,198,198,254,0,0,0,0,0,0,0,60,102,194,192,192,192,194,102,60,12,6,124,0,0,0,0,204,0,0,204,204,204,204,204,204,118,0,0,0,0,0,12,24,48,0,124,198,254,192,192,198,124,0,0,0,0,0,16,56,108,0,120,12,124,204,204,204,118,0,0,0,0,0,0,204,0,0,120,12,124,204,204,204,118,0,0,0,0,0,96,48,24,0,120,12,124,204,204,204,118,0,0,0,0,0,56,108,56,0,120,12,124,204,204,204,118,0,0,0,0,0,0,0,0,60,102,96,96,102,60,12,6,60,0,0,0,0,16,56,108,0,124,198,254,192,192,198,124,0,0,0,0,0,0,198,0,0,124,198,254,192,192,198,124,0,0,0,0,0,96,48,24,0,124,198,254,192,192,198,124,0,0,0,0,0,0,102,0,0,56,24,24,24,24,24,60,0,0,0,0,0,24,60,102,0,56,24,24,24,24,24,60,0,0,0,0,0,96,48,24,0,56,24,24,24,24,24,60,0,0,0,0,0,198,0,16,56,108,198,198,254,198,198,198,0,0,0,0,56,108,56,0,56,108,198,198,254,198,198,198,0,0,0,0,24,48,96,0,254,102,96,124,96,96,102,254,0,0,0,0,0,0,0,0,0,110,59,27,126,216,220,119,0,0,0,0,0,0,62,108,204,204,254,204,204,204,204,206,0,0,0,0,0,16,56,108,0,124,198,198,198,198,198,124,0,0,0,0,0,0,198,0,0,124,198,198,198,198,198,124,0,0,0,0,0,96,48,24,0,124,198,198,198,198,198,124,0,0,0,0,0,48,120,204,0,204,204,204,204,204,204,118,0,0,0,0,0,96,48,24,0,204,204,204,204,204,204,118,0,0,0,0,0,0,198,0,0,198,198,198,198,198,198,126,6,12,120,0,0,198,0,124,198,198,198,198,198,198,198,124,0,0,0,0,0,198,0,198,198,198,198,198,198,198,198,124,0,0,0,0,0,24,24,126,195,192,192,192,195,126,24,24,0,0,0,0,0,56,108,100,96,240,96,96,96,96,230,252,0,0,0,0,0,0,195,102,60,24,255,24,255,24,24,24,0,0,0,0,0,252,102,102,124,98,102,111,102,102,102,243,0,0,0,0,0,14,27,24,24,24,126,24,24,24,24,24,216,112,0,0,0,24,48,96,0,120,12,124,204,204,204,118,0,0,0,0,0,12,24,48,0,56,24,24,24,24,24,60,0,0,0,0,0,24,48,96,0,124,198,198,198,198,198,124,0,0,0,0,0,24,48,96,0,204,204,204,204,204,204,118,0,0,0,0,0,0,118,220,0,220,102,102,102,102,102,102,0,0,0,0,118,220,0,198,230,246,254,222,206,198,198,198,0,0,0,0,0,60,108,108,62,0,126,0,0,0,0,0,0,0,0,0,0,56,108,108,56,0,124,0,0,0,0,0,0,0,0,0,0,0,48,48,0,48,48,96,192,198,198,124,0,0,0,0,0,0,0,0,0,0,254,192,192,192,192,0,0,0,0,0,0,0,0,0,0,0,254,6,6,6,6,0,0,0,0,0,0,192,192,194,198,204,24,48,96,206,155,6,12,31,0,0,0,192,192,194,198,204,24,48,102,206,150,62,6,6,0,0,0,0,24,24,0,24,24,24,60,60,60,24,0,0,0,0,0,0,0,0,0,54,108,216,108,54,0,0,0,0,0,0,0,0,0,0,0,216,108,54,108,216,0,0,0,0,0,0,17,68,17,68,17,68,17,68,17,68,17,68,17,68,17,68,85,170,85,170,85,170,85,170,85,170,85,170,85,170,85,170,221,119,221,119,221,119,221,119,221,119,221,119,221,119,221,119,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,248,24,24,24,24,24,24,24,24,24,24,24,24,24,248,24,248,24,24,24,24,24,24,24,24,54,54,54,54,54,54,54,246,54,54,54,54,54,54,54,54,0,0,0,0,0,0,0,254,54,54,54,54,54,54,54,54,0,0,0,0,0,248,24,248,24,24,24,24,24,24,24,24,54,54,54,54,54,246,6,246,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,0,0,0,0,0,254,6,246,54,54,54,54,54,54,54,54,54,54,54,54,54,246,6,254,0,0,0,0,0,0,0,0,54,54,54,54,54,54,54,254,0,0,0,0,0,0,0,0,24,24,24,24,24,248,24,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,31,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,31,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,255,24,24,24,24,24,24,24,24,24,24,24,24,24,31,24,31,24,24,24,24,24,24,24,24,54,54,54,54,54,54,54,55,54,54,54,54,54,54,54,54,54,54,54,54,54,55,48,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,48,55,54,54,54,54,54,54,54,54,54,54,54,54,54,247,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,247,54,54,54,54,54,54,54,54,54,54,54,54,54,55,48,55,54,54,54,54,54,54,54,54,0,0,0,0,0,255,0,255,0,0,0,0,0,0,0,0,54,54,54,54,54,247,0,247,54,54,54,54,54,54,54,54,24,24,24,24,24,255,0,255,0,0,0,0,0,0,0,0,54,54,54,54,54,54,54,255,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,255,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,255,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,63,0,0,0,0,0,0,0,0,24,24,24,24,24,31,24,31,0,0,0,0,0,0,0,0,0,0,0,0,0,31,24,31,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,63,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,255,54,54,54,54,54,54,54,54,24,24,24,24,24,255,24,255,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,24,24,24,24,24,24,24,24,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,220,216,216,216,220,118,0,0,0,0,0,0,120,204,204,204,216,204,198,198,198,204,0,0,0,0,0,0,254,198,198,192,192,192,192,192,192,192,0,0,0,0,0,0,0,0,254,108,108,108,108,108,108,108,0,0,0,0,0,0,0,254,198,96,48,24,48,96,198,254,0,0,0,0,0,0,0,0,0,126,216,216,216,216,216,112,0,0,0,0,0,0,0,0,102,102,102,102,102,124,96,96,192,0,0,0,0,0,0,0,118,220,24,24,24,24,24,24,0,0,0,0,0,0,0,126,24,60,102,102,102,60,24,126,0,0,0,0,0,0,0,56,108,198,198,254,198,198,108,56,0,0,0,0,0,0,56,108,198,198,198,108,108,108,108,238,0,0,0,0,0,0,30,48,24,12,62,102,102,102,102,60,0,0,0,0,0,0,0,0,0,126,219,219,219,126,0,0,0,0,0,0,0,0,0,3,6,126,219,219,243,126,96,192,0,0,0,0,0,0,28,48,96,96,124,96,96,96,48,28,0,0,0,0,0,0,0,124,198,198,198,198,198,198,198,198,0,0,0,0,0,0,0,0,254,0,0,254,0,0,254,0,0,0,0,0,0,0,0,0,24,24,126,24,24,0,0,255,0,0,0,0,0,0,0,48,24,12,6,12,24,48,0,126,0,0,0,0,0,0,0,12,24,48,96,48,24,12,0,126,0,0,0,0,0,0,14,27,27,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,216,216,216,112,0,0,0,0,0,0,0,0,24,24,0,126,0,24,24,0,0,0,0,0,0,0,0,0,0,118,220,0,118,220,0,0,0,0,0,0,0,56,108,108,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,15,12,12,12,12,12,236,108,108,60,28,0,0,0,0,0,216,108,108,108,108,108,0,0,0,0,0,0,0,0,0,0,112,216,48,96,200,248,0,0,0,0,0,0,0,0,0,0,0,0,0,124,124,124,124,124,124,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,1,0,136,88,1,0,0,250,0,0,128,187,0,0,68,172,0,0,0,125,0,0,192,93,0,0,34,86,0,0,128,62,0,0,224,46,0,0,17,43,0,0,64,31,0,0,182,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,172,128,187,0,125,0,0,0,0,32,0,64,0,96,0,128,0,160,0,192,0,224,0,0,1,32,1,64,1,96,1,128,1,160,1,192,1,0,0,32,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,160,0,192,0,224,0,0,1,64,1,128,1,0,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,160,0,192,0,224,0,0,1,64,1,0,0,32,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,176,0,192,0,224,0,0,1,0,0,8,0,16,0,24,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,0,0,8,0,16,0,24,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,0,0,0,0,1,2,3,0,4,17,5,18,33,49,65,6,19,81,97,7,34,113,20,50,129,145,161,8,35,66,177,193,21,82,209,240,36,51,98,114,130,9,10,22,23,24,25,26,37,38,39,40,41,42,52,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,225,226,227,228,229,230,231,232,233,234,241,242,243,244,245,246,247,248,249,250,0,0,0,0,0,0,0,1,2,3,17,4,5,33,49,6,18,65,81,7,97,113,19,34,50,129,8,20,66,145,161,177,193,9,35,51,82,240,21,98,114,209,10,22,36,52,225,37,241,23,24,25,26,38,39,40,41,42,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,130,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,226,227,228,229,230,231,232,233,234,242,243,244,245,246,247,248,249,250,0,0,0,0,0,0,0,0,1,5,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,3,3,2,4,3,5,5,4,4,0,0,1,125,0,0,0,0,0,0,0,0,0,2,1,2,4,4,3,4,7,5,4,4,0,1,2,119,0,0,0,0,0,0,0,0,0,0,0,64,31,0,0,128,62,0,0,0,125,0,0,0,0,0,0,0,0,0,0,17,43,0,0,34,86,0,0,68,172,0,0,0,0,0,0,0,0,0,0,224,46,0,0,192,93,0,0,128,187,0,0,0,119,1,0,0,238,2,0,0,0,0,0,0,0,0,0,126,129,165,129,189,153,129,126,126,255,219,255,195,231,255,126,108,254,254,254,124,56,16,0,16,56,124,254,124,56,16,0,56,124,56,254,254,124,56,124,16,16,56,124,254,124,56,124,0,0,24,60,60,24,0,0,255,255,231,195,195,231,255,255,0,60,102,66,66,102,60,0,255,195,153,189,189,153,195,255,15,7,15,125,204,204,204,120,60,102,102,102,60,24,126,24,63,51,63,48,48,112,240,224,127,99,127,99,99,103,230,192,153,90,60,231,231,60,90,153,128,224,248,254,248,224,128,0,2,14,62,254,62,14,2,0,24,60,126,24,24,126,60,24,102,102,102,102,102,0,102,0,127,219,219,123,27,27,27,0,62,99,56,108,108,56,204,120,0,0,0,0,126,126,126,0,24,60,126,24,126,60,24,255,24,60,126,24,24,24,24,0,24,24,24,24,126,60,24,0,0,24,12,254,12,24,0,0,0,48,96,254,96,48,0,0,0,0,192,192,192,254,0,0,0,36,102,255,102,36,0,0,0,24,60,126,255,255,0,0,0,255,255,126,60,24,0,0,0,0,0,0,0,0,0,0,48,120,120,48,48,0,48,0,108,108,108,0,0,0,0,0,108,108,254,108,254,108,108,0,48,124,192,120,12,248,48,0,0,198,204,24,48,102,198,0,56,108,56,118,220,204,118,0,96,96,192,0,0,0,0,0,24,48,96,96,96,48,24,0,96,48,24,24,24,48,96,0,0,102,60,255,60,102,0,0,0,48,48,252,48,48,0,0,0,0,0,0,0,48,48,96,0,0,0,252,0,0,0,0,0,0,0,0,0,48,48,0,6,12,24,48,96,192,128,0,124,198,206,222,246,230,124,0,48,112,48,48,48,48,252,0,120,204,12,56,96,204,252,0,120,204,12,56,12,204,120,0,28,60,108,204,254,12,30,0,252,192,248,12,12,204,120,0,56,96,192,248,204,204,120,0,252,204,12,24,48,48,48,0,120,204,204,120,204,204,120,0,120,204,204,124,12,24,112,0,0,48,48,0,0,48,48,0,0,48,48,0,0,48,48,96,24,48,96,192,96,48,24,0,0,0,252,0,0,252,0,0,96,48,24,12,24,48,96,0,120,204,12,24,48,0,48,0,124,198,222,222,222,192,120,0,48,120,204,204,252,204,204,0,252,102,102,124,102,102,252,0,60,102,192,192,192,102,60,0,248,108,102,102,102,108,248,0,254,98,104,120,104,98,254,0,254,98,104,120,104,96,240,0,60,102,192,192,206,102,62,0,204,204,204,252,204,204,204,0,120,48,48,48,48,48,120,0,30,12,12,12,204,204,120,0,230,102,108,120,108,102,230,0,240,96,96,96,98,102,254,0,198,238,254,254,214,198,198,0,198,230,246,222,206,198,198,0,56,108,198,198,198,108,56,0,252,102,102,124,96,96,240,0,120,204,204,204,220,120,28,0,252,102,102,124,108,102,230,0,120,204,224,112,28,204,120,0,252,180,48,48,48,48,120,0,204,204,204,204,204,204,252,0,204,204,204,204,204,120,48,0,198,198,198,214,254,238,198,0,198,198,108,56,56,108,198,0,204,204,204,120,48,48,120,0,254,198,140,24,50,102,254,0,120,96,96,96,96,96,120,0,192,96,48,24,12,6,2,0,120,24,24,24,24,24,120,0,16,56,108,198,0,0,0,0,0,0,0,0,0,0,0,255,48,48,24,0,0,0,0,0,0,0,120,12,124,204,118,0,224,96,96,124,102,102,220,0,0,0,120,204,192,204,120,0,28,12,12,124,204,204,118,0,0,0,120,204,252,192,120,0,56,108,96,240,96,96,240,0,0,0,118,204,204,124,12,248,224,96,108,118,102,102,230,0,48,0,112,48,48,48,120,0,12,0,12,12,12,204,204,120,224,96,102,108,120,108,230,0,112,48,48,48,48,48,120,0,0,0,204,254,254,214,198,0,0,0,248,204,204,204,204,0,0,0,120,204,204,204,120,0,0,0,220,102,102,124,96,240,0,0,118,204,204,124,12,30,0,0,220,118,102,96,240,0,0,0,124,192,120,12,248,0,16,48,124,48,48,52,24,0,0,0,204,204,204,204,118,0,0,0,204,204,204,120,48,0,0,0,198,214,254,254,108,0,0,0,198,108,56,108,198,0,0,0,204,204,204,124,12,248,0,0,252,152,48,100,252,0,28,48,48,224,48,48,28,0,24,24,24,0,24,24,24,0,224,48,48,28,48,48,224,0,118,220,0,0,0,0,0,0,0,16,56,108,198,198,254,0,120,204,192,204,120,24,12,120,0,204,0,204,204,204,126,0,28,0,120,204,252,192,120,0,126,195,60,6,62,102,63,0,204,0,120,12,124,204,126,0,224,0,120,12,124,204,126,0,48,48,120,12,124,204,126,0,0,0,120,192,192,120,12,56,126,195,60,102,126,96,60,0,204,0,120,204,252,192,120,0,224,0,120,204,252,192,120,0,204,0,112,48,48,48,120,0,124,198,56,24,24,24,60,0,224,0,112,48,48,48,120,0,198,56,108,198,254,198,198,0,48,48,0,120,204,252,204,0,28,0,252,96,120,96,252,0,0,0,127,12,127,204,127,0,62,108,204,254,204,204,206,0,120,204,0,120,204,204,120,0,0,204,0,120,204,204,120,0,0,224,0,120,204,204,120,0,120,204,0,204,204,204,126,0,0,224,0,204,204,204,126,0,0,204,0,204,204,124,12,248,195,24,60,102,102,60,24,0,204,0,204,204,204,204,120,0,24,24,126,192,192,126,24,24,56,108,100,240,96,230,252,0,204,204,120,252,48,252,48,48,248,204,204,250,198,207,198,199,14,27,24,60,24,24,216,112,28,0,120,12,124,204,126,0,56,0,112,48,48,48,120,0,0,28,0,120,204,204,120,0,0,28,0,204,204,204,126,0,0,248,0,248,204,204,204,0,252,0,204,236,252,220,204,0,60,108,108,62,0,126,0,0,56,108,108,56,0,124,0,0,48,0,48,96,192,204,120,0,0,0,0,252,192,192,0,0,0,0,0,252,12,12,0,0,195,198,204,222,51,102,204,15,195,198,204,219,55,111,207,3,24,24,0,24,24,24,24,0,0,51,102,204,102,51,0,0,0,204,102,51,102,204,0,0,34,136,34,136,34,136,34,136,85,170,85,170,85,170,85,170,219,119,219,238,219,119,219,238,24,24,24,24,24,24,24,24,24,24,24,24,248,24,24,24,24,24,248,24,248,24,24,24,54,54,54,54,246,54,54,54,0,0,0,0,254,54,54,54,0,0,248,24,248,24,24,24,54,54,246,6,246,54,54,54,54,54,54,54,54,54,54,54,0,0,254,6,246,54,54,54,54,54,246,6,254,0,0,0,54,54,54,54,254,0,0,0,24,24,248,24,248,0,0,0,0,0,0,0,248,24,24,24,24,24,24,24,31,0,0,0,24,24,24,24,255,0,0,0,0,0,0,0,255,24,24,24,24,24,24,24,31,24,24,24,0,0,0,0,255,0,0,0,24,24,24,24,255,24,24,24,24,24,31,24,31,24,24,24,54,54,54,54,55,54,54,54,54,54,55,48,63,0,0,0,0,0,63,48,55,54,54,54,54,54,247,0,255,0,0,0,0,0,255,0,247,54,54,54,54,54,55,48,55,54,54,54,0,0,255,0,255,0,0,0,54,54,247,0,247,54,54,54,24,24,255,0,255,0,0,0,54,54,54,54,255,0,0,0,0,0,255,0,255,24,24,24,0,0,0,0,255,54,54,54,54,54,54,54,63,0,0,0,24,24,31,24,31,0,0,0,0,0,31,24,31,24,24,24,0,0,0,0,63,54,54,54,54,54,54,54,255,54,54,54,24,24,255,24,255,24,24,24,24,24,24,24,248,0,0,0,0,0,0,0,31,24,24,24,255,255,255,255,255,255,255,255,0,0,0,0,255,255,255,255,240,240,240,240,240,240,240,240,15,15,15,15,15,15,15,15,255,255,255,255,0,0,0,0,0,0,118,220,200,220,118,0,0,120,204,248,204,248,192,192,0,252,204,192,192,192,192,0,0,254,108,108,108,108,108,0,252,204,96,48,96,204,252,0,0,0,126,216,216,216,112,0,0,102,102,102,102,124,96,192,0,118,220,24,24,24,24,0,252,48,120,204,204,120,48,252,56,108,198,254,198,108,56,0,56,108,198,198,108,108,238,0,28,48,24,124,204,204,120,0,0,0,126,219,219,126,0,0,6,12,126,219,219,126,96,192,56,96,192,248,192,96,56,0,120,204,204,204,204,204,204,0,0,252,0,252,0,252,0,0,48,48,252,48,48,0,252,0,96,48,24,48,96,0,252,0,24,48,96,48,24,0,252,0,14,27,27,24,24,24,24,24,24,24,24,24,24,216,216,112,48,48,0,252,0,48,48,0,0,118,220,0,118,220,0,0,56,108,108,56,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,24,0,0,0,15,12,12,12,236,108,60,28,120,108,108,108,108,0,0,0,112,24,48,96,120,0,0,0,0,0,60,60,60,60,0,0,0,0,0,0,0,0,0,0,3,0,4,0,3,0,7,0,3,1,7,1,3,6,7,6,144,232,31,0,184,89,34,0,0,0,0,0,0,0,0,0,82,73,70,70,65,86,73,32,82,73,70,70,65,86,73,88,82,73,70,70,65,86,73,25,79,78,50,32,79,78,50,102,82,73,70,70,65,77,86,32,0,0,0,0,0,0,0,0,0,229,33,0,0,0,0,0,184,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,3,0,0,0,0,229,33,0,208,144,32,0,216,149,31,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,3,0,0,0,0,229,33,0,168,219,30,0,88,50,30,0,64,4,0,0,1,0,0,0,64,75,76,0,0,0,0,0,0,0,0,0,0,0,64,64,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,0,190,29,0,72,90,29,0,52,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,48,5,29,0,0,0,0,0,60,4,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,3,0,0,0,48,5,29,0,152,183,28,0,208,179,35,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,184,86,35,0,208,4,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,48,196,34,0,216,135,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,144,77,34,0,0,27,34,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,0,231,33,0,136,195,33,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,16,159,33,0,32,130,33,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,8,75,33,0,168,21,33,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,192,248,32,0,128,222,32,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,104,194,32,0,224,169,32,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,40,146,32,0,192,121,32,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,48,5,29,0,64,98,32,0,24,78,32,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,48,5,29,0,128,30,32,0,240,248,31,0,200,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,224,227,31,0,200,208,31,0,68,4,0,0,1,0,0,0,64,75,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,40,188,31,0,24,169,31,0,72,4,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,200,150,31,0,88,133,31,0,100,4,0,0,1,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,224,116,31,0,168,103,31,0,104,4,0,0,1,0,0,0,0,104,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,240,64,31,0,88,36,31,0,144,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,3,0,0,0,240,64,31,0,0,23,31,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,3,0,0,0,240,64,31,0,240,9,31,0,32,249,30,0,56,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,3,0,0,0,0,0,0,0,80,234,30,0,160,220,30,0,128,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,128,255,255,255,223,65,2,0,0,0,0,0,0,0,160,207,30,0,208,190,30,0,164,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,1,0,0,0,0,0,0,0,56,178,30,0,56,143,30,0,168,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,1,0,0,0,0,0,0,0,168,116,30,0,160,104,30,0,172,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,1,0,0,0,0,0,0,0,40,91,30,0,104,76,30,0,132,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,63,30,0,48,63,30,0,56,51,30,0,132,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,63,30,0,32,41,30,0,232,31,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,63,30,0,208,25,30,0,248,252,29,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,63,30,0,224,232,29,0,136,225,29,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,63,30,0,64,216,29,0,72,207,29,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,63,30,0,216,198,29,0,160,190,29,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,63,30,0,216,182,29,0,112,175,29,0,0,0,0,0,128,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1737936);
/* memory initializer */ allocate([2,0,0,0,48,63,30,0,224,168,29,0,32,143,29,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,48,63,30,0,232,123,29,0,168,116,29,0,176,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,2,0,0,0,0,0,0,0,240,109,29,0,0,103,29,0,180,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,1,0,0,0,240,109,29,0,120,96,29,0,8,91,29,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,109,29,0,176,84,29,0,168,78,29,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,109,29,0,0,72,29,0,0,103,29,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,109,29,0,96,50,29,0,80,35,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,240,109,29,0,104,30,29,0,176,23,29,0,192,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,2,0,0,0,0,0,0,0,160,17,29,0,56,10,29,0,196,4,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,152,183,28,0,160,5,29,0,204,4,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,88,1,29,0,232,251,28,0,36,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,240,246,28,0,88,226,28,0,48,5,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,80,212,28,0,136,204,28,0,152,4,0,0,2,0,0,0,128,150,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,140,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,118,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,2,0,0,242,6,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,252,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,152,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,176,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,248,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,176,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,254,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,254,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,42,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,2,0,0,0,0,0,0,0,0,0,0,246,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,138,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,138,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,3,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,2,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,2,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,58,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,58,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,49,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,49,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,1,0,0,0,0,0,0,0,0,0,0,212,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,150,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,150,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,1,0,0,0,0,0,0,0,0,0,0,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,49,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,49,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,1,0,0,0,0,0,0,0,0,0,0,218,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,186,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,2,0,0,0,0,0,0,0,0,0,0,156,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,109,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,109,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,14,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,14,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,0,0,0,0,0,0,0,0,0,0,0,224,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,208,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,208,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,20,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,123,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,6,0,0,128,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,109,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,2,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,1,0,0,0,128,102,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,2,0,0,0,0,0,0,0,0,0,0,170,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,16,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,16,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,234,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,234,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,27,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,27,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,162,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,125,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,125,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,0,0,0,0,0,0,0,0,0,0,0,164,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,140,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,10,0,0,208,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,140,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,234,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,234,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,75,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,75,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,36,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,36,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,116,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,85,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,85,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,0,0,0,0,0,0,0,0,0,0,188,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,213,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,213,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,3,0,0,0,0,0,0,0,0,0,0,28,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,65,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,65,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,245,30,0,144,231,30,0,52,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,1,0,232,245,30,0,16,218,30,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,245,30,0,232,16,34,0,128,203,30,0,64,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,6,31,0,120,8,0,0,144,201,26,0,100,66,52,0,0,0,0,0,0,0,0,0,74,0,0,0,188,2,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,193,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,244,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,118,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,2,0,0,242,6,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,136,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,152,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,193,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,193,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,228,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,4,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,219,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,210,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,210,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,1,0,0,0,0,0,0,0,0,0,0,10,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,3,30,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,58,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,58,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,186,30,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,2,0,0,0,0,0,0,0,0,0,0,156,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,245,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,245,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,166,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,6,0,0,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,93,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,93,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,75,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,75,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,14,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,14,31,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1748176);
/* memory initializer */ allocate([82,2,0,0,0,0,0,0,0,0,0,0,228,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,123,32,0,240,133,31,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,112,123,32,0,216,207,30,0,240,133,31,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,112,123,32,0,96,41,30,0,176,109,140,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,123,32,0,192,84,29,0,176,109,140,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,123,32,0,112,1,29,0,216,178,28,0,64,0,0,0,84,65,82,86,184,175,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,224,80,35,0,216,178,28,0,64,0,0,0,84,65,82,86,184,175,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,0,35,0,24,192,34,0,8,0,0,0,69,90,73,83,56,131,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,24,74,34,0,24,192,34,0,8,0,0,0,69,90,73,83,56,131,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,24,34,0,48,228,33,0,28,0,0,0,1,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,72,192,33,0,152,156,33,0,32,0,0,0,1,0,0,0,160,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,184,128,33,0,136,69,33,0,36,0,0,0,1,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,152,19,33,0,96,247,32,0,40,0,0,0,1,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,200,220,32,0,200,192,32,0,44,0,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,8,169,32,0,240,143,32,0,48,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,48,120,32,0,64,96,32,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,36,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,11,29,0,108,0,0,0,72,213,26,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,238,32,0,88,211,32,0,72,0,0,0,1,0,0,0,64,13,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,48,184,32,0,88,211,32,0,72,0,0,0,1,0,0,0,0,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,64,162,32,0,144,136,32,0,76,0,0,0,1,0,0,0,0,9,61,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,240,145,35,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,59,0,0,0,240,145,35,0,168,112,32,0,184,89,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,145,35,0,216,65,32,0,216,9,32,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,152,240,31,0,232,219,31,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,232,201,31,0,0,180,31,0,0,0,0,0,128,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,48,161,31,0,24,143,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,240,145,35,0,72,126,31,0,24,111,31,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,96,92,31,0,48,50,31,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,96,30,31,0,0,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,240,145,35,0,208,17,31,0,240,2,31,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,240,145,35,0,64,243,30,0,240,228,30,0,0,0,0,0,128,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,240,145,35,0,40,216,30,0,168,200,30,0,0,0,0,0,128,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,240,145,35,0,64,185,30,0,192,168,30,0,0,0,0,0,128,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,240,145,35,0,72,128,30,0,232,111,30,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,56,99,30,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,240,145,35,0,0,86,30,0,152,68,30,0,0,0,0,0,128,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,216,57,30,0,48,47,30,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,64,37,30,0,48,29,30,0,0,0,0,0,128,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,240,145,35,0,96,18,30,0,104,240,29,0,0,0,0,0,128,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,240,145,35,0,16,230,29,0,216,221,29,0,0,0,0,0,128,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,59,0,0,0,240,145,35,0,136,212,29,0,216,203,29,0,0,0,0,0,128,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,72,195,29,0,0,188,29,0,0,0,0,0,128,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,16,180,29,0,24,172,29,0,0,0,0,0,128,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,240,145,35,0,184,162,29,0,200,130,29,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,145,35,0,64,121,29,0,8,114,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,168,107,29,0,224,100,29,0,144,94,29,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,168,107,29,0,144,88,29,0,208,81,29,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,168,107,29,0,72,74,29,0,128,67,29,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,168,107,29,0,56,41,29,0,16,33,29,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,168,107,29,0,128,27,29,0,8,21,29,0,0,0,0,0,128,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,168,107,29,0,128,14,29,0,88,8,29,0,144,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,40,4,29,0,112,254,28,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,72,250,28,0,104,242,28,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,40,217,28,0,176,209,28,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,168,202,28,0,40,196,28,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,184,190,28,0,120,186,28,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,168,181,28,0,216,175,28,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,112,242,35,0,96,237,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,56,212,35,0,224,204,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,48,199,35,0,112,193,35,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,232,187,35,0,112,183,35,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,104,178,35,0,40,173,35,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,152,167,35,0,184,157,35,0,0,0,0,0,128,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,14,29,0,24,133,35,0,0,0,0,0,100,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,56,121,35,0,0,0,0,0,104,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,8,114,35,0,208,105,35,0,136,0,0,0,1,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,56,99,35,0,56,93,35,0,156,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,11,0,0,0,0,0,0,0,216,83,35,0,56,79,35,0,160,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,11,0,0,0,0,0,0,0,96,70,35,0,40,61,35,0,180,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,128,38,35,0,0,0,0,0,168,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,120,30,35,0,0,0,0,0,172,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,112,24,35,0,0,0,0,0,116,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,176,18,35,0,248,12,35,0,236,1,0,0,4,0,0,0,0,0,0,0,0,0,224,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,64,8,35,0,64,3,35,0,240,1,0,0,4,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,144,254,34,0,216,248,34,0,244,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,64,81,64,17,0,0,0,0,0,0,0,216,243,34,0,120,224,34,0,248,1,0,0,1,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,144,64,17,0,0,0,0,0,0,0,184,217,34,0,64,212,34,0,252,1,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,48,207,34,0,200,202,34,0,156,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,216,198,34,0,192,194,34,0,160,0,0,0,4,0,0,0,0,0,0,0,0,0,244,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,16,190,34,0,64,186,34,0,164,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,181,34,0,192,162,34,0,168,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,128,157,34,0,136,152,34,0,116,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,208,147,34,0,0,0,0,0,120,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,80,143,34,0,0,0,0,0,124,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,224,138,34,0,0,0,0,0,128,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,160,133,34,0,0,0,0,0,132,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,48,129,34,0,0,0,0,0,136,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,200,124,34,0,0,0,0,0,140,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,56,120,34,0,0,0,0,0,144,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,168,102,34,0,0,0,0,0,148,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,24,97,34,0,0,0,0,0,152,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,224,92,34,0,0,0,0,0,52,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,232,88,34,0,160,84,34,0,164,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,88,80,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,128,76,34,0,24,72,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,216,67,34,0,144,63,34,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,112,47,34,0,24,41,34,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,64,38,34,0,64,35,34,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,248,31,34,0,0,0,0,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,40,29,34,0,64,26,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,160,22,34,0,0,0,0,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,216,18,34,0,40,15,34,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,120,0,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,112,249,33,0,56,246,33,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,200,241,33,0,216,237,33,0,0,0,0,0,128,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,24,234,33,0,0,0,0,0,0,0,0,0,128,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,184,229,33,0,0,0,0,0,0,0,0,0,128,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,176,227,33,0,24,225,33,0,0,0,0,0,128,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,200,222,33,0,96,210,33,0,0,0,0,0,128,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,232,88,34,0,232,207,33,0,40,205,33,0,168,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,27,0,0,0,232,207,33,0,56,203,33,0,104,200,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,232,207,33,0,232,207,33,0,8,197,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,232,207,33,0,96,193,33,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,232,207,33,0,216,191,33,0,144,189,33,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,232,207,33,0,192,186,33,0,240,172,33,0,0,0,0,0,128,0,0,0,254,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,232,207,33,0,144,168,33,0,152,166,33,0,172,0,0,0,4,0,0,0,0,0,0,0,0,0,244,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,32,165,33,0,160,163,33,0,184,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,32,165,33,0,112,160,33,0,40,158,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,32,165,33,0,8,156,33,0,0,154,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,32,165,33,0,104,152,33,0,192,141,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,32,165,33,0,192,138,33,0,24,137,33,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,32,165,33,0,192,135,33,0,152,133,33,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,32,165,33,0,160,131,33,0,184,129,33,0,0,0,0,0,128,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,32,165,33,0,48,128,33,0,112,125,33,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,32,165,33,0,152,120,33,0,0,0,0,0,176,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,200,107,33,0,0,0,0,0,176,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,224,98,33,0,184,93,33,0,180,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,144,88,33,0,144,84,33,0,0,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,88,64,17,0,0,0,0,0,0,0,40,81,33,0,232,72,33,0,4,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,16,69,33,0,232,72,33,0,8,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,192,62,33,0,0,0,0,0,16,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,208,55,33,0,136,41,33,0,24,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,17,0,0,0,0,0,0,0,120,36,33,0,248,32,33,0,28,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,200,28,33,0,176,24,33,0,32,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,88,23,33,0,224,20,33,0,12,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,0,17,33,0,16,15,33,0,36,2,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,232,13,33,0,24,4,33,0,184,0,0,0,4,0,0,0,154,153,153,153,153,153,233,191,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,48,1,33,0,152,254,32,0,188,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,216,252,32,0,88,251,32,0,40,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,232,249,32,0,112,248,32,0,16,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,232,249,32,0,176,246,32,0,96,245,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,232,249,32,0,216,243,32,0,56,233,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,232,249,32,0,208,230,32,0,248,228,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,232,249,32,0,216,226,32,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,232,249,32,0,80,225,32,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,232,249,32,0,176,223,32,0,224,221,32,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,232,249,32,0,96,220,32,0,128,218,32,0,192,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,96,216,32,0,192,206,32,0,196,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,120,203,32,0,152,201,32,0,200,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,208,199,32,0,208,197,32,0,204,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,216,195,32,0,184,193,32,0,208,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,56,192,32,0,200,190,32,0,20,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,176,246,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,208,230,32,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,192,189,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,200,179,32,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,24,177,32,0,0,0,0,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,80,225,32,0,0,0,0,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,248,175,32,0,0,0,0,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,88,174,32,0,0,0,0,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,216,172,32,0,0,0,0,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,216,170,32,0,0,0,0,0,0,0,0,0,128,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,160,169,32,0,0,0,0,0,0,0,0,0,128,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,200,168,32,0,0,0,0,0,0,0,0,0,128,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,208,167,32,0,0,0,0,0,0,0,0,0,128,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,80,166,32,0,0,0,0,0,0,0,0,0,128,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,88,158,32,0,112,155,32,0,0,0,0,0,128,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,56,192,32,0,80,153,32,0,0,0,0,0,212,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,32,151,32,0,144,149,32,0,172,2,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,32,151,32,0,24,148,32,0,56,145,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,32,151,32,0,176,143,32,0,40,142,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,32,151,32,0,120,141,32,0,0,0,0,0,24,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,104,132,32,0,168,130,32,0,216,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,104,132,32,0,80,129,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,104,132,32,0,64,127,32,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,104,132,32,0,200,125,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,104,132,32,0,24,123,32,0,64,121,32,0,224,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,64,17,0,0,0,0,0,0,0,184,119,32,0,248,117,32,0,176,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,59,0,0,0,184,119,32,0,136,116,32,0,144,107,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,32,105,32,0,184,102,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,184,119,32,0,8,156,33,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,224,101,32,0,192,100,32,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,24,99,32,0,144,97,32,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,248,95,32,0,40,94,32,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,144,93,32,0,0,0,0,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,208,85,32,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,168,83,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,136,82,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,104,81,32,0,120,80,32,0,0,0,0,0,128,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,128,79,32,0,160,77,32,0,0,0,0,0,128,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,144,76,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,40,75,32,0,184,70,32,0,0,0,0,0,128,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,176,61,32,0,32,53,32,0,0,0,0,0,128,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,96,48,32,0,232,42,32,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,119,32,0,48,40,32,0,88,36,32,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,184,119,32,0,216,27,32,0,184,25,32,0,180,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,18,0,0,0,184,20,32,0,88,14,32,0,232,5,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,20,32,0,48,207,34,0,232,1,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,20,32,0,80,255,31,0,128,253,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,184,20,32,0,40,252,31,0,40,250,31,0,232,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,216,246,31,0,104,245,31,0,236,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,240,243,31,0,184,237,31,0,240,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,240,234,31,0,104,233,31,0,244,0,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,72,232,31,0,232,230,31,0,248,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,24,229,31,0,224,226,31,0,252,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,216,225,31,0,136,224,31,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,200,223,31,0,32,217,31,0,4,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,72,215,31,0,184,213,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,144,212,31,0,48,211,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,200,209,31,0,16,208,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,232,249,32,0,248,206,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,72,128,30,0,184,205,31], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1758444);
/* memory initializer */ allocate([128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,208,204,31,0,24,199,31,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,144,196,31,0,192,194,31,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,40,4,29,0,224,192,31,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,64,191,31,0,88,189,31,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,168,187,31,0,96,186,31,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,136,184,31,0,96,183,31,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,192,176,31,0,120,173,31,0,0,0,0,0,128,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,176,172,31,0,160,171,31,0,0,0,0,0,128,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,152,170,31,0,0,0,0,0,0,0,0,0,128,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,160,169,31,0,0,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,176,168,31,0,80,167,31,0,8,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,176,165,31,0,88,164,31,0,12,1,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,104,158,31,0,0,0,0,0,16,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,24,156,31,0,208,154,31,0,20,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,224,153,31,0,232,152,31,0,24,1,0,0,1,0,0,0,63,66,15,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,184,151,31,0,88,150,31,0,28,1,0,0,1,0,0,0,63,66,15,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,248,148,31,0,0,0,0,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,176,147,31,0,0,0,0,0,56,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,176,147,31,0,184,146,31,0,16,140,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,176,147,31,0,216,83,35,0,96,138,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,176,147,31,0,160,137,31,0,56,136,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,176,147,31,0,56,135,31,0,40,134,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,176,147,31,0,80,132,31,0,96,131,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,176,147,31,0,216,129,31,0,144,128,31,0,60,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,144,123,31,0,0,0,0,0,32,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,128,121,31,0,0,0,0,0,36,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,200,120,31,0,136,119,31,0,40,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,17,0,0,0,200,120,31,0,192,189,32,0,40,119,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,200,120,31,0,136,117,31,0,160,116,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,200,120,31,0,144,196,31,0,48,115,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,200,120,31,0,192,113,31,0,0,0,0,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,64,113,31,0,224,108,31,0,52,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,32,107,31,0,112,106,31,0,64,2,0,0,1,0,0,0,236,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,216,105,31,0,56,105,31,0,68,2,0,0,1,0,0,0,74,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,96,104,31,0,112,103,31,0,56,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,144,102,31,0,200,99,31,0,52,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,107,29,0,0,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,27,0,0,0,168,107,29,0,152,95,31,0,0,0,0,0,100,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,224,88,31,0,0,0,0,0,40,3,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,27,0,0,0,224,88,31,0,176,246,32,0,200,80,31,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,224,88,31,0,112,77,31,0,192,73,31,0,60,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,136,71,31,0,168,68,31,0,64,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,72,63,31,0,176,61,31,0,68,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,112,57,31,0,224,52,31,0,68,3,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,46,31,0,64,42,31,0,72,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,0,0,0,0,8,40,31,0,216,38,31,0,76,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,0,0,0,0,184,37,31,0,0,0,0,0,72,3,0,0,1,0,0,0,157,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,184,37,31,0,248,36,31,0,0,0,0,0,0,0,0,0,128,0,0,0,157,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,184,37,31,0,8,36,31,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,16,35,31,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,136,34,31,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,24,33,31,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,88,28,31,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,192,26,31,0,0,0,0,0,0,0,0,0,128,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,0,26,31,0,0,0,0,0,0,0,0,0,128,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,56,25,31,0,0,0,0,0,0,0,0,0,128,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,120,24,31,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,144,23,31,0,0,0,0,0,0,0,0,0,128,0,0,0,131,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,200,22,31,0,0,0,0,0,0,0,0,0,128,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,208,21,31,0,0,0,0,0,0,0,0,0,128,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,208,20,31,0,0,0,0,0,0,0,0,0,128,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,248,19,31,0,0,0,0,0,0,0,0,0,128,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,32,16,31,0,0,0,0,0,0,0,0,0,128,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,37,31,0,184,14,31,0,0,0,0,0,76,3,0,0,1,0,0,0,157,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,184,14,31,0,248,36,31,0,0,0,0,0,0,0,0,0,128,0,0,0,157,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,184,14,31,0,200,13,31,0,152,12,31,0,32,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,26,0,0,0,0,0,0,0,240,11,31,0,88,10,31,0,72,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,112,9,31,0,224,7,31,0,76,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,16,7,31,0,216,5,31,0,80,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,32,1,31,0,16,255,30,0,84,2,0,0,1,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,112,248,31,0,16,254,30,0,120,252,30,0,80,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,176,251,30,0,0,250,30,0,84,1,0,0,1,0,0,0,236,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,192,255,223,64,17,0,0,0,0,0,0,0,216,248,30,0,112,247,30,0,88,1,0,0,1,0,0,0,74,14,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,192,255,223,64,17,0,0,0,0,0,0,0,168,246,30,0,136,245,30,0,92,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,160,240,30,0,248,238,30,0,80,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,176,237,30,0,216,236,30,0,224,235,30,0,84,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,176,237,30,0,208,234,30,0,248,233,30,0,88,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,176,237,30,0,56,233,30,0,104,232,30,0,0,0,0,0,128,0,0,0,240,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,176,237,30,0,64,231,30,0,24,227,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,176,237,30,0,80,225,30,0,56,224,30,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,176,237,30,0,56,223,30,0,88,222,30,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,176,237,30,0,104,221,30,0,16,220,30,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,176,237,30,0,8,219,30,0,112,218,30,0,0,0,0,0,128,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,176,237,30,0,224,217,30,0,208,213,30,0,96,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,17,0,0,0,0,0,0,0,128,212,30,0,176,211,30,0,100,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,64,17,0,0,0,0,0,0,0,152,210,30,0,152,209,30,0,104,1,0,0,1,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,40,208,30,0,56,207,30,0,108,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,32,206,30,0,208,204,30,0,112,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,64,203,30,0,32,199,30,0,88,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,56,197,30,0,48,196,30,0,116,1,0,0,1,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,224,194,30,0,0,0,0,0,120,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,104,193,30,0,160,191,30,0,124,1,0,0,1,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,128,190,30,0,0,0,0,0,84,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,48,189,30,0,0,0,0,0,92,2,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,248,187,30,0,0,0,0,0,96,2,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,48,187,30,0,208,183,30,0,104,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,17,0,0,0,0,0,0,0,16,182,30,0,128,181,30,0,184,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,10,0,0,0,0,0,0,0,128,180,30,0,0,0,0,0,28,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,192,113,33,0,0,0,0,0,192,1,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,11,0,0,0,192,113,33,0,208,179,30,0,0,0,0,0,200,1,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,10,0,0,0,208,179,30,0,240,178,30,0,0,0,0,0,44,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,0,178,30,0,0,0,0,0,48,2,0,0,4,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,16,177,30,0,0,0,0,0,112,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,27,0,0,0,0,0,0,0,16,176,30,0,0,0,0,0,128,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,34,64,19,0,0,0,0,0,0,0,24,172,30,0,0,0,0,0,132,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,46,64,19,0,0,0,0,0,0,0,216,165,30,0,0,0,0,0,136,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,36,64,19,0,0,0,0,0,0,0,64,159,30,0,0,0,0,0,140,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,19,0,0,0,0,0,0,0,224,155,30,0,0,0,0,0,144,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,19,0,0,0,0,0,0,0,32,152,30,0,40,149,30,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,176,146,30,0,8,141,30,0,148,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,48,139,30,0,88,135,30,0,44,3,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,27,0,0,0,48,139,30,0,96,130,30,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,48,139,30,0,16,126,30,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,48,139,30,0,232,122,30,0,96,121,30,0,208,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,64,9,0,0,0,232,122,30,0,72,120,30,0,96,119,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,122,30,0,184,117,30,0,56,116,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,122,30,0,72,115,30,0,136,114,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,122,30,0,160,113,30,0,240,110,30,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,122,30,0,56,109,30,0,96,108,30,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,122,30,0,200,107,30,0,240,106,30,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,122,30,0,160,105,30,0,24,104,30,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,122,30,0,72,103,30,0,24,102,30,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,122,30,0,232,100,30,0,216,97,30,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,122,30,0,96,96,30,0,32,95,30,0,212,1,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,10,0,0,0,96,96,30,0,192,93,30,0,0,0,0,0,120,3,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,16,93,30,0,176,91,30,0,168,3,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,34,0,0,0,0,0,0,0,128,90,30,0,48,89,30,0,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,34,0,0,0,128,90,30,0,128,88,30,0,0,0,0,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,34,0,0,0,128,90,30,0,176,246,32,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,34,0,0,0,128,90,30,0,64,87,30,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,34,0,0,0,128,90,30,0,32,84,30,0,0,0,0,0,232,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,26,0,0,0,0,0,0,0,16,82,30,0,8,81,30,0,176,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,24,80,30,0,232,78,30,0,152,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,19,0,0,0,24,80,30,0,88,77,30,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,24,80,30,0,216,75,30,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,24,80,30,0,80,255,31,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,24,80,30,0,152,74,30,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,24,80,30,0,64,162,32,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,24,80,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,232,3,0,0,6,7,10,11,0,0,0,0,120,0,0,0,0,0,0,0,0,128,64,192,32,160,96,224,16,144,80,208,48,176,112,240,8,136,72,200,40,168,104,232,24,152,88,216,56,184,120,248,4,132,68,196,36,164,100,228,20,148,84,212,52,180,116,244,12,140,76,204,44,172,108,236,28,156,92,220,60,188,124,252,2,130,66,194,34,162,98,226,18,146,82,210,50,178,114,242,10,138,74,202,42,170,106,234,26,154,90,218,58,186,122,250,6,134,70,198,38,166,102,230,22,150,86,214,54,182,118,246,14,142,78,206,46,174,110,238,30,158,94,222,62,190,126,254,1,129,65,193,33,161,97,225,17,145,81,209,49,177,113,241,9,137,73,201,41,169,105,233,25,153,89,217,57,185,121,249,5,133,69,197,37,165,101,229,21,149,85,213,53,181,117,245,13,141,77,205,45,173,109,237,29,157,93,221,61,189,125,253,3,131,67,195,35,163,99,227,19,147,83,211,51,179,115,243,11,139,75,203,43,171,107,235,27,155,91,219,59,187,123,251,7,135,71,199,39,167,103,231,23,151,87,215,55,183,119,247,15,143,79,207,47,175,111,239,31,159,95,223,63,191,127,255,0,0,0,0,0,0,0,0,0,245,32,0,3,1,1,16,32,56,33,56,34,56,0,0,248,24,35,0,3,1,0,0,36,56,76,56,140,56,0,0,160,33,33,0,3,0,0,32,40,56,72,56,104,56,0,0,120,255,31,0,3,0,0,32,104,56,72,56,40,56,0,0,40,40,31,0,3,1,0,16,32,56,33,56,34,56,0,0,128,121,30,0,3,0,0,16,32,56,33,56,34,56,0,0,104,235,29,0,3,2,2,16,32,56,33,56,34,56,0,0,200,126,29,0,3,2,0,16,32,56,33,56,34,56,0,0,48,37,29,0,1,0,0,64,32,56,0,0,0,0,0,0,0,214,28,0,1,0,0,4,32,0,0,0,0,0,0,0,56,208,35,0,1,0,0,4,32,7,0,0,0,0,0,0,96,128,35,0,1,0,0,2,32,56,0,0,0,0,0,0,120,35,35,0,3,1,1,16,32,56,33,56,34,56,0,0,24,221,34,0,3,1,0,16,32,56,33,56,34,56,0,0,176,160,34,0,3,0,0,16,32,56,33,56,34,56,0,0,144,100,34,0,0,0,0,8,0,0,0,0,0,0,0,0,56,45,34,0,0,0,0,8,0,0,0,0,0,0,0,0,88,254,33,0,3,1,0,0,68,56,44,56,108,56,0,0,56,209,33,0,3,2,0,0,76,56,52,56,148,56,0,0,216,170,33,0,3,0,0,96,32,16,32,19,32,14,0,0,88,140,33,0,3,0,0,36,140,0,76,8,44,0,0,0,200,104,33,0,3,0,0,96,32,0,32,9,32,3,0,0,8,40,33,0,3,0,0,96,32,14,32,19,32,16,0,0,224,2,33,0,3,0,0,36,44,0,76,8,140,0,0,0,0,232,32,0,3,0,0,96,32,3,32,9,32,0,0,0,32,205,32,0,3,1,1,16,32,56,37,56,69,56,0,0,160,178,32,0,3,1,1,16,32,56,69,56,37,56,0,0,104,157,32,0,4,0,0,160,76,56,108,56,140,56,44,56,88,131,32,0,4,0,0,160,44,56,76,56,108,56,140,56,120,106,32,0,4,0,0,160,140,56,108,56,76,56,44,56,240,84,32,0,4,0,0,160,108,56,76,56,44,56,140,56,0,59,32,0,1,0,0,1,36,120,0,0,0,0,0,0,232,4,32,0,1,0,0,0,36,120,0,0,0,0,0,0,224,236,31,0,3,0,1,16,32,56,33,56,34,56,0,0,56,216,31,0,3,0,1,16,32,56,33,56,34,56,0,0,24,198,31,0,4,1,1,144,32,56,33,56,34,56,35,56,104,175,31,0,0,1,1,8,0,0,0,0,0,0,0,0,104,157,31,0,0,1,1,8,0,0,0,0,0,0,0,0,232,138,31,0,0,1,1,8,0,0,0,0,0,0,0,0,120,122,31,0,0,1,1,8,0,0,0,0,0,0,0,0,224,107,31,0,0,1,1,8,0,0,0,0,0,0,0,0,48,86,31,0,3,0,0,33,52,120,116,120,180,120,0,0,112,45,31,0,3,0,0,32,52,120,116,120,180,120,0,0,200,27,31,0,3,0,0,33,4,35,36,45,36,32,0,0,80,15,31,0,3,0,0,32,68,35,36,45,36,32,0,0,112,0,31,0,3,0,0,33,4,34,36,37,36,32,0,0,224,239,30,0,3,0,0,32,68,34,36,37,36,32,0,0,88,226,30,0,3,0,0,33,36,32,36,45,4,35,0,0,248,212,30,0,3,0,0,32,36,32,36,45,68,35,0,0,40,198,30,0,3,0,0,33,36,32,36,37,4,34,0,0,168,182,30,0,3,0,0,32,36,32,36,37,68,34,0,0,160,163,30,0,0,1,1,8,0,0,0,0,0,0,0,0,240,124,30,0,0,1,1,8,0,0,0,0,0,0,0,0,8,110,30,0,0,1,1,8,0,0,0,0,0,0,0,0,40,97,30,0,3,1,1,16,36,120,37,120,38,120,0,0,104,83,30,0,3,1,1,17,36,120,37,120,38,120,0,0,224,66,30,0,3,1,0,16,36,120,37,120,38,120,0,0,192,55,30,0,3,1,0,17,36,120,37,120,38,120,0,0,216,44,30,0,3,0,0,16,36,120,37,120,38,120,0,0,232,34,30,0,3,0,0,17,36,120,37,120,38,120,0,0,160,27,30,0,0,1,1,8,0,0,0,0,0,0,0,0,240,14,30,0,0,1,1,8,0,0,0,0,0,0,0,0,160,237,29,0,3,0,0,32,68,24,36,28,36,24,0,0,104,228,29,0,3,0,0,33,4,24,36,28,36,24,0,0,48,220,29,0,3,0,0,32,36,24,36,28,68,24,0,0,88,211,29,0,3,0,0,33,36,24,36,28,4,24,0,0,136,202,29,0,2,0,0,128,36,56,68,56,0,0,0,0,8,194,29,0,3,0,0,33,180,120,116,120,52,120,0,0,96,186,29,0,3,0,0,32,180,120,116,120,52,120,0,0,240,178,29,0,3,1,1,17,36,64,37,64,38,64,0,0,40,171,29,0,3,1,1,16,36,64,37,64,38,64,0,0,48,159,29,0,3,1,1,17,36,72,37,72,38,72,0,0,200,128,29,0,3,1,1,16,36,72,37,72,38,72,0,0,112,120,29,0,3,1,0,17,36,72,37,72,38,72,0,0,32,113,29,0,3,1,0,16,36,72,37,72,38,72,0,0,48,106,29,0,3,0,0,17,36,64,37,64,38,64,0,0,120,99,29,0,3,0,0,16,36,64,37,64,38,64,0,0,224,93,29,0,3,0,0,17,36,72,37,72,38,72,0,0,112,87,29,0,3,0,0,16,36,72,37,72,38,72,0,0,248,80,29,0,3,1,0,17,36,64,37,64,38,64,0,0,200,73,29,0,3,1,0,16,36,64,37,64,38,64,0,0,0,64,29,0,0,1,1,8,0,0,0,0,0,0,0,0,96,39,29,0,3,0,0,48,34,56,32,56,33,56,0,0,104,32,29,0,3,0,0,49,38,64,36,64,37,64,0,0,96,26,29,0,3,0,0,48,38,64,36,64,37,64,0,0,64,20,29,0,3,0,0,49,38,72,36,72,37,72,0,0,144,13,29,0,3,0,0,48,38,72,36,72,37,72,0,0,136,7,29,0,3,0,0,49,38,120,36,120,37,120,0,0,88,3,29,0,3,0,0,48,38,120,36,120,37,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,253,28,0,4,1,1,145,36,64,37,64,38,64,39,64,8,248,28,0,4,1,1,144,36,64,37,64,38,64,39,64,128,239,28,0,4,1,0,145,36,64,37,64,38,64,39,64,184,215,28,0,4,1,0,144,36,64,37,64,38,64,39,64,240,208,28,0,4,0,0,145,36,64,37,64,38,64,39,64,200,201,28,0,4,0,0,144,36,64,37,64,38,64,39,64,56,195,28,0,4,1,1,145,36,72,37,72,38,72,39,72,24,190,28,0,4,1,1,144,36,72,37,72,38,72,39,72,208,185,28,0,4,1,0,145,36,72,37,72,38,72,39,72,240,180,28,0,4,1,0,144,36,72,37,72,38,72,39,72,16,175,28,0,4,0,0,145,36,72,37,72,38,72,39,72,208,241,35,0,4,0,0,144,36,72,37,72,38,72,39,72,120,233,35,0,4,1,1,145,36,120,37,120,38,120,39,120,216,209,35,0,4,1,1,144,36,120,37,120,38,120,39,120,248,203,35,0,4,1,0,145,36,120,37,120,38,120,39,120,24,198,35,0,4,1,0,144,36,120,37,120,38,120,39,120,144,192,35,0,4,0,0,145,36,120,37,120,38,120,39,120,64,187,35,0,4,0,0,144,36,120,37,120,38,120,39,120,128,182,35,0,0,1,1,8,0,0,0,0,0,0,0,0,208,177,35,0,3,0,0,0,52,92,116,92,180,92,0,0,56,172,35,0,3,0,0,1,52,92,116,92,180,92,0,0,192,166,35,0,3,1,0,16,32,56,37,56,69,56,0,0,40,155,35,0,3,1,0,16,36,72,45,72,109,72,0,0,16,131,35,0,3,1,0,17,36,72,45,72,109,72], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1768684);
/* memory initializer */ allocate([72,120,35,0,4,0,0,161,60,120,124,120,188,120,252,120,88,113,35,0,4,0,0,160,60,120,124,120,188,120,252,120,64,105,35,0,4,0,0,161,188,120,124,120,60,120,252,120,16,98,35,0,4,0,0,160,188,120,124,120,60,120,252,120,128,92,35,0,3,0,0,32,76,56,108,56,140,56,0,0,40,83,35,0,3,0,0,32,44,56,76,56,108,56,0,0,112,78,35,0,3,0,0,32,140,56,108,56,76,56,0,0,248,69,35,0,3,0,0,32,108,56,76,56,44,56,0,0,16,59,35,0,4,0,0,144,32,56,33,56,34,56,35,56,248,36,35,0,4,1,0,144,32,56,33,56,34,56,35,56,0,30,35,0,3,1,1,17,36,88,37,88,38,88,0,0,200,23,35,0,3,1,1,16,36,88,37,88,38,88,0,0,32,18,35,0,3,1,1,17,36,104,37,104,38,104,0,0,64,12,35,0,3,1,1,16,36,104,37,104,38,104,0,0,112,7,35,0,3,1,0,17,36,88,37,88,38,88,0,0,96,2,35,0,3,1,0,16,36,88,37,88,38,88,0,0,248,253,34,0,3,1,0,17,36,104,37,104,38,104,0,0,24,248,34,0,3,1,0,16,36,104,37,104,38,104,0,0,104,242,34,0,3,0,0,17,36,88,37,88,38,88,0,0,248,222,34,0,3,0,0,16,36,88,37,88,38,88,0,0,8,217,34,0,3,0,0,17,36,104,37,104,38,104,0,0,104,211,34,0,3,0,0,16,36,104,37,104,38,104,0,0,176,206,34,0,3,0,0,49,38,88,36,88,37,88,0,0,232,201,34,0,3,0,0,48,38,88,36,88,37,88,0,0,88,198,34,0,3,0,0,49,38,104,36,104,37,104,0,0,72,194,34,0,3,0,0,48,38,104,36,104,37,104,0,0,120,189,34,0,4,0,0,176,34,56,32,56,33,56,35,56,200,185,34,0,4,0,0,177,38,120,36,120,37,120,39,120,136,180,34,0,4,0,0,176,38,120,36,120,37,120,39,120,48,162,34,0,3,2,0,16,32,56,33,56,34,56,0,0,240,156,34,0,3,0,0,32,0,8,0,24,0,8,0,0,248,151,34,0,3,0,0,32,0,8,0,24,0,8,0,0,88,147,34,0,3,0,0,32,0,8,0,24,0,8,0,0,168,142,34,0,3,0,0,32,0,8,0,24,0,8,0,0,128,138,34,0,3,0,0,32,4,24,4,56,4,24,0,0,232,132,34,0,3,0,0,33,4,24,4,56,4,24,0,0,120,128,34,0,3,0,0,32,4,24,4,56,4,24,0,0,120,124,34,0,3,0,0,33,4,24,4,56,4,24,0,0,224,118,34,0,3,0,0,32,4,24,4,56,4,24,0,0,248,101,34,0,3,0,0,33,4,24,4,56,4,24,0,0,168,96,34,0,3,0,0,32,4,24,4,56,4,24,0,0,32,92,34,0,3,0,0,33,4,24,4,56,4,24,0,0,176,208,35,0,168,128,35,0,112,37,29,0,88,214,28,0,200,2,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,0,0,0,0,200,2,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,29,35,0,108,0,0,0,48,45,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,206,0,0,0,0,0,0,0,88,254,32,0,208,28,35,0,0,0,0,0,0,0,0,0,64,35,33,0,88,1,32,0,136,41,31,0,104,122,30,0,16,236,29,0,0,0,0,0,104,235,34,0,0,0,0,0,192,248,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,86,29,0,216,8,0,0,32,166,26,0,100,66,52,0,0,0,0,0,0,0,0,0,90,3,0,0,144,1,0,0,3,0,0,0,84,10,0,0,0,0,0,0,0,0,0,0,0,8,0,0,7,0,0,0,0,16,0,0,5,128,0,0,0,16,0,0,33,16,0,0,0,32,0,0,183,29,193,4,1,32,0,0,32,131,184,237,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,251,76,134,0,200,8,33,0,112,6,0,0,136,216,26,0,100,66,52,0,4,0,0,0,0,0,0,0,4,3,0,0,174,7,0,0,5,0,0,0,8,2,0,0,0,0,0,0,0,0,0,0,32,28,31,0,202,9,0,0,112,96,9,0,100,66,52,0,4,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,48,49,50,51,52,53,54,55,56,57,43,47,0,0,0,0,0,0,0,0,160,76,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,76,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,1,0,0,0,0,0,0,0,0,0,0,146,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,205,204,204,61,0,0,0,0,4,0,3,5,0,0,0,0,192,48,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,38,32,0,64,70,31,0,16,0,0,0,32,82,85,68,255,255,255,255,255,255,255,127,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,240,147,30,0,144,1,30,0,24,0,0,0,32,82,85,68,255,255,255,255,255,255,255,127,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,24,148,29,0,176,53,29,0,72,0,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,152,229,28,0,144,1,30,0,80,0,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,40,224,35,0,168,145,35,0,8,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,88,50,35,0,16,235,34,0,88,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,184,171,34,0,232,111,34,0,96,0,0,0,2,0,0,0,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,232,55,34,0,40,7,34,0,56,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,176,216,33,0,0,180,33,0,64,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,208,146,33,0,40,113,33,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,48,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,1,0,0,0,0,0,0,0,0,0,0,224,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,83,33,0,108,0,0,0,240,48,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,4,4,3,3,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,4,4,4,3,3,3,2,2,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,5,5,5,4,4,4,4,3,3,3,3,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,5,5,4,4,3,3,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,4,4,4,3,3,3,2,2,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,5,5,5,5,5,5,5,3,3,3,3,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,255,0,0,0,0,0,0,0,251,255,0,0,0,249,0,0,0,0,0,0,0,0,0,0,249,0,0,0,0,0,0,0,0,0,251,0,0,0,0,0,0,251,0,0,0,0,249,249,0,0,0,0,0,0,0,0,249,0,0,0,0,0,0,0,254,254,251,0,0,0,0,0,0,0,0,0,254,251,0,0,0,0,0,0,0,0,0,254,251,0,0,0,0,0,251,0,0,0,0,0,0,254,249,254,0,0,0,0,0,0,0,0,0,254,251,0,0,0,0,0,0,251,251,0,0,0,0,0,0,0,251,254,0,0,0,0,255,251,253,254,255,255,0,0,0,254,251,253,253,254,255,255,0,0,0,255,255,255,0,0,0,0,0,255,253,0,0,0,0,0,0,0,255,254,0,0,0,0,0,0,0,255,253,255,0,0,0,0,1,1,255,251,253,253,254,255,0,0,0,255,255,252,254,254,255,255,0,0,255,255,253,254,253,255,255,255,0,255,252,254,253,255,0,0,0,0,0,255,254,254,255,255,0,0,0,0,254,255,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,255,255,253,254,254,255,255,255,0,0,0,0,0,0,0,0,0,0,0,255,253,254,254,255,255,255,0,255,254,0,1,1,1,1,1,1,0,255,1,1,1,1,1,1,1,0,254,1,1,1,1,1,1,1,0,254,0,1,1,1,1,1,1,255,255,0,1,1,1,1,1,1,0,0,255,0,1,1,1,1,1,255,255,1,1,1,1,1,1,1,0,0,255,1,1,1,1,1,1,0,255,0,1,1,1,1,1,1,255,255,255,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,0,0,0,1,1,1,1,1,1,0,255,255,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,0,253,254,1,1,1,1,2,2,253,251,253,2,2,2,2,2,2,255,254,0,2,2,2,2,2,2,255,254,0,1,2,2,2,2,2,0,254,0,2,2,2,2,2,2,255,0,1,2,2,2,2,2,2,0,0,1,2,2,2,2,2,2,0,254,0,1,2,2,2,2,2,0,255,1,2,2,2,2,2,2,255,255,0,2,2,2,2,2,2,255,255,0,1,2,2,2,2,2,255,254,255,2,2,2,2,2,2,0,255,0,2,2,2,2,2,2,1,1,0,1,2,2,2,2,2,0,1,2,2,2,2,2,2,2,1,0,0,1,2,2,2,2,2,0,0,0,1,2,2,2,2,2,255,255,255,1,2,2,2,2,2,0,1,2,3,3,3,3,3,3,1,1,2,3,3,3,3,3,3,255,0,1,2,3,3,3,3,3,0,0,2,3,3,3,3,3,3,255,0,1,3,3,3,3,3,3,0,0,1,3,3,3,3,3,3,1,2,3,3,3,3,3,3,3,1,2,2,3,3,3,3,3,3,0,1,1,3,3,3,3,3,3,0,0,1,2,3,3,3,3,3,255,1,2,3,3,3,3,3,3,255,0,2,3,3,3,3,3,3,2,2,3,3,3,3,3,3,3,1,1,3,3,3,3,3,3,3,0,2,3,3,3,3,3,3,3,0,1,1,2,3,3,3,3,3,0,1,2,3,4,4,4,4,4,1,2,3,4,4,4,4,4,4,0,0,2,3,4,4,4,4,4,1,1,2,4,4,4,4,4,4,0,1,2,4,4,4,4,4,4,255,0,1,3,4,4,4,4,4,0,0,1,3,4,4,4,4,4,1,1,2,3,4,4,4,4,4,0,1,1,3,4,4,4,4,4,2,2,3,4,4,4,4,4,4,1,1,3,4,4,4,4,4,4,1,2,2,4,4,4,4,4,4,255,0,2,3,4,4,4,4,4,0,1,3,4,4,4,4,4,4,1,2,2,3,4,4,4,4,4,0,2,3,4,4,4,4,4,4,1,2,3,4,5,5,5,5,5,0,1,2,3,4,5,5,5,5,0,1,2,3,5,5,5,5,5,1,1,3,4,5,5,5,5,5,1,1,2,4,5,5,5,5,5,1,2,2,4,5,5,5,5,5,1,1,2,3,5,5,5,5,5,2,2,3,4,5,5,5,5,5,0,1,2,4,5,5,5,5,5,2,2,3,5,5,5,5,5,5,1,2,3,5,5,5,5,5,5,0,1,3,4,5,5,5,5,5,1,2,2,3,5,5,5,5,5,2,3,4,5,5,5,5,5,5,0,2,3,4,5,5,5,5,5,1,1,1,3,4,5,5,5,5,1,2,3,4,5,5,5,6,6,1,2,3,4,5,6,6,6,6,2,3,4,5,6,6,6,6,6,1,2,3,4,6,6,6,6,6,2,2,3,4,5,5,5,6,6,1,2,3,4,5,5,6,6,6,2,2,3,4,6,6,6,6,6,2,2,3,4,5,6,6,6,6,2,2,4,5,6,6,6,6,6,2,2,3,5,6,6,6,6,6,1,2,3,5,6,6,6,6,6,2,3,3,5,6,6,6,6,6,1,2,4,5,6,6,6,6,6,2,2,3,4,5,5,6,6,6,2,3,3,4,6,6,6,6,6,1,3,4,5,6,6,6,6,6,0,1,2,6,7,0,0,0,0,1,7,0,0,0,0,0,0,4,12,13,30,31,14,5,0,4,12,30,31,13,14,5,0,4,5,6,7,0,0,0,0,2,3,0,0,0,0,0,1,3,4,4,5,5,4,3,1,3,4,5,5,4,4,3,1,3,3,3,3,0,0,0,1,2,2,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,1,4,2,1,255,255,255,255,144,52,14,0,56,52,14,0,1,4,2,0,255,255,255,255,40,52,14,0,208,51,14,0,1,2,3,1,255,255,255,255,192,51,14,0,136,51,14,0,1,1,3,0,255,255,255,255,128,51,14,0,120,51,14,0,1,2,4,1,255,255,255,255,104,51,14,0,128,50,14,0,1,1,4,0,255,255,255,255,120,50,14,0,104,50,14,0,1,1,6,1,255,255,255,255,88,50,14,0,24,50,14,0,4,4,2,1,255,255,255,255,8,50,14,0,176,49,14,0,1,4,2,0,255,255,255,255,168,49,14,0,80,49,14,0,1,2,3,1,255,255,255,255,64,49,14,0,8,49,14,0,1,2,4,1,255,255,255,255,248,48,14,0,120,48,14,0,1,2,4,1,255,255,255,255,104,48,14,0,128,47,14,0,1,2,4,0,255,255,255,255,112,47,14,0,112,46,14,0,1,1,6,1,255,255,255,255,96,46,14,0,32,46,14,0,1,4,2,1,255,255,255,255,16,46,14,0,184,45,14,0,1,2,3,1,255,255,255,255,168,45,14,0,136,45,14,0,1,2,3,1,255,255,255,255,120,45,14,0,64,45,14,0,1,1,3,0,255,255,255,255,56,45,14,0,0,0,0,0,1,1,3,0,255,255,255,255,48,45,14,0,40,45,14,0,1,2,4,0,255,255,255,255,24,45,14,0,24,44,14,0,1,1,6,1,255,255,255,255,16,44,14,0,208,43,14,0,1,2,2,1,255,255,255,255,200,43,14,0,184,43,14,0,1,4,2,0,255,255,255,255,168,43,14,0,80,43,14,0,1,4,2,0,255,255,255,255,64,43,14,0,64,42,14,0,1,1,3,0,255,255,255,255,56,42,14,0,48,42,14,0,1,2,4,1,255,255,255,255,32,42,14,0,56,41,14,0,1,2,4,0,255,255,255,255,40,41,14,0,40,40,14,0,1,1,6,1,255,255,255,255,32,40,14,0,224,39,14,0,1,4,2,1,255,255,255,255,208,39,14,0,120,39,14,0,1,4,2,0,255,255,255,255,104,39,14,0,16,39,14,0,1,1,3,1,255,255,255,255,8,39,14,0,0,39,14,0,1,2,4,1,255,255,255,255,240,38,14,0,112,38,14,0,1,1,3,0,255,255,255,255,104,38,14,0,96,38,14,0,1,2,4,0,255,255,255,255,88,38,14,0,88,37,14,0,1,1,6,1,255,255,255,255,80,37,14,0,16,37,14,0,1,4,2,1,255,255,255,255,0,37,14,0,168,36,14,0,1,2,3,1,255,255,255,255,152,36,14,0,120,36,14,0,1,1,3,1,255,255,255,255,8,39,14,0,112,36,14,0,1,2,4,1,255,255,255,255,104,36,14,0,232,35,14,0,1,1,3,0,255,255,255,255,224,35,14,0,216,35,14,0,1,1,5,1,255,255,255,255,208,35,14,0,176,35,14,0,1,1,6,1,255,255,255,255,160,35,14,0,96,35,14,0,2,4,2,1,255,255,255,255,80,35,14,0,248,34,14,0,1,2,3,1,255,255,255,255,240,34,14,0,208,34,14,0,1,4,2,0,255,255,255,255,192,34,14,0,192,33,14,0,1,2,4,1,255,255,255,255,184,33,14,0,56,33,14,0,1,1,4,1,255,255,255,255,48,33,14,0,32,33,14,0,1,1,5,1,255,255,255,255,16,33,14,0,240,32,14,0,1,1,6,1,255,255,255,255,224,32,14,0,160,32,14,0,1,2,1,0,255,255,255,255,152,32,14,0,0,0,0,0,2,4,2,0,255,255,255,255,136,32,14,0,48,32,14,0,1,2,3,1,255,255,255,255,32,32,14,0,232,31,14,0,1,2,4,1,255,255,255,255,216,31,14,0,88,31,14,0,1,1,4,1,255,255,255,255,80,31,14,0,64,31,14,0,2,2,4,0,255,255,255,255,48,31,14,0,48,30,14,0,4,1,6,1,6,0,0,0,0,0,0,0,0,0,0,0,4,4,2,1,255,255,255,255,32,30,14,0,200,29,14,0,1,4,2,0,255,255,255,255,184,29,14,0,96,29,14,0,4,2,3,1,255,255,255,255,80,29,14,0,24,29,14,0,1,2,4,1,255,255,255,255,8,29,14,0,136,28,14,0,1,2,4,1,255,255,255,255,120,28,14,0,144,27,14,0,1,1,4,0,5,0,0,0,0,0,0,0,0,0,0,0,1,1,6,1,255,255,255,255,128,27,14,0,64,27,14,0,1,4,2,1,14,0,0,0,0,0,0,0,0,0,0,0,1,4,2,0,255,255,255,255,48,27,14,0,216,26,14,0,1,2,3,1,9,0,0,0,0,0,0,0,0,0,0,0,1,2,4,1,255,255,255,255,200,26,14,0,72,26,14,0,1,2,4,1,11,0,0,0,0,0,0,0,0,0,0,0,1,2,4,0,255,255,255,255,56,26,14,0,56,25,14,0,1,1,6,1,6,0,0,0,0,0,0,0,0,0,0,0,4,4,2,1,28,0,0,0,0,0,0,0,0,0,0,0,4,4,2,0,22,0,0,0,0,0,0,0,0,0,0,0,1,2,3,1,2,0,0,0,0,0,0,0,0,0,0,0,1,2,4,1,31,0,0,0,0,0,0,0,0,0,0,0,2,2,4,1,60,0,0,0,0,0,0,0,0,0,0,0,2,2,4,0,255,255,255,255,40,25,14,0,40,24,14,0,4,1,6,1,6,0,0,0,0,0,0,0,0,0,0,0,1,4,2,1,35,0,0,0,0,0,0,0,0,0,0,0,1,4,2,0,255,255,255,255,24,24,14,0,192,23,14,0,1,4,2,0,255,255,255,255,176,23,14,0,176,22,14,0,2,2,4,1,59,0,0,0,0,0,0,0,0,0,0,0,1,2,4,1,255,255,255,255,160,22,14,0,184,21,14,0,1,2,4,0,75,0,0,0,0,0,0,0,0,0,0,0,1,1,6,1,255,255,255,255,168,21,14,0,104,21,14,0,1,4,2,1,255,255,255,255,88,21,14,0,0,21,14,0,4,2,3,1,255,255,255,255,240,20,14,0,208,20,14,0,1,2,3,1,255,255,255,255,192,20,14,0,136,20,14,0,4,2,4,1,66,0,0,0,0,0,0,0,0,0,0,0,1,1,3,0,32,0,0,0,0,0,0,0,0,0,0,0,1,2,4,0,12,0,0,0,0,0,0,0,0,0,0,0,1,1,6,1,255,255,255,255,120,20,14,0,56,20,14,0,2,4,2,1,42,0,0,0,0,0,0,0,0,0,0,0,1,2,3,1,255,255,255,255,40,20,14,0,8,20,14,0,4,1,3,1,255,255,255,255,0,20,14,0,248,19,14,0,1,1,3,0,17,0,0,0,0,0,0,0,0,0,0,0,1,1,3,0,39,0,0,0,0,0,0,0,0,0,0,0,1,1,5,1,255,255,255,255,232,19,14,0,200,19,14,0,2,1,6,1,62,0,0,0,0,0,0,0,0,0,0,0,1,4,2,1,28,0,0,0,0,0,0,0,0,0,0,0,1,4,2,0,255,255,255,255,184,19,14,0,96,19,14,0,1,1,3,1,255,255,255,255,88,19,14,0,80,19,14,0,1,1,3,0,255,255,255,255,72,19,14,0,64,19,14,0,4,2,4,1,255,255,255,255,48,19,14,0,72,18,14,0,1,2,4,0,255,255,255,255,56,18,14,0,56,17,14,0,1,1,6,1,255,255,255,255,40,17,14,0,232,16,14,0,1,4,2,1,255,255,255,255,216,16,14,0,128,16,14,0,4,4,2,0,78,0,0,0,0,0,0,0,0,0,0,0,4,4,2,0,255,255,255,255,112,16,14,0,112,15,14,0,1,1,4,1,255,255,255,255,104,15,14,0,88,15,14,0,1,2,4,1,255,255,255,255,72,15,14,0,96,14,14,0,1,1,5,1,47,0,0,0,0,0,0,0,0,0,0,0,1,1,6,1,255,255,255,255,80,14,14,0,16,14,14,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,0,0,0,1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,10,10,253,254,255,0,3,5,6,8,40,253,254,0,1,7,9,11,13,20,255,0,0,1,6,8,10,13,41,0,0,0,2,5,5,6,8,14,0,0,0,2,6,7,8,11,47,0,0,1,2,5,7,8,10,32,0,0,1,3,8,10,12,14,47,0,0,2,4,9,10,12,14,40,0,0,3,5,9,10,12,14,22,0,1,3,5,10,14,18,22,31,0,2,5,6,10,10,10,12,46,0,2,5,7,12,14,15,18,44,1,1,4,5,7,7,8,9,15,1,2,2,2,4,5,7,9,26,1,2,2,3,6,7,7,8,47,1,2,2,3,6,8,10,13,22,1,3,4,7,13,17,21,24,41,1,4,0,4,10,12,13,14,17,2,3,3,3,6,8,10,13,48,2,3,3,4,9,12,14,17,47,2,3,3,5,10,12,14,17,25,2,3,5,7,8,9,9,9,13,2,3,5,9,16,21,25,28,33,2,4,5,8,12,14,17,19,26,2,4,6,8,12,13,13,15,20,2,4,7,12,20,26,30,32,35,3,3,5,6,12,14,16,19,34,3,4,4,5,7,9,10,11,48,3,4,5,6,8,9,10,11,16,3,5,5,5,7,9,10,13,35,3,5,5,7,10,12,13,15,49,3,5,7,7,8,7,9,12,21,3,5,7,8,12,14,15,15,24,3,5,7,10,16,21,24,27,44,3,5,8,14,21,26,28,29,42,3,6,10,13,18,19,20,22,27,3,6,11,16,24,27,28,29,31,4,5,4,3,4,6,8,11,18,4,6,5,6,9,10,12,14,20,4,6,7,6,6,6,7,8,46,4,6,7,9,13,16,18,20,48,4,6,7,9,14,17,20,23,31,4,6,9,11,14,15,15,17,21,4,8,13,20,27,32,35,36,38,5,6,6,4,5,6,7,6,6,5,7,7,8,9,9,10,12,49,5,8,9,9,10,11,12,13,42,5,8,10,12,15,16,17,19,42,5,8,12,17,26,31,32,33,44,5,9,13,16,20,22,23,23,35,6,8,8,7,6,5,6,8,15,6,8,8,8,9,10,12,16,24,6,8,8,9,10,10,11,11,13,6,8,10,13,19,21,24,26,32,6,9,10,11,13,13,14,16,49,7,9,9,10,13,14,16,19,27,7,10,12,13,16,16,17,17,27,7,10,12,14,17,19,20,22,48,8,9,10,9,10,11,11,11,19,8,11,12,12,13,13,13,13,17,8,11,13,14,16,17,19,20,27,8,12,17,22,26,28,29,30,33,10,14,16,19,21,22,22,24,28,10,15,17,18,21,22,23,25,43,0,1,2,14,15,3,13,4,5,6,7,9,8,10,11,12,0,1,13,14,15,2,12,3,4,5,6,7,8,9,10,11,0,1,2,62,63,3,61,4,5,6,57,58,59,60,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,0,1,61,62,63,2,60,3,4,5,6,57,58,59,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,0,0,2,0,3,0,12,0,28,0,60,0,124,0,125,0,0,0,126,0,127,0,61,0,29,0,13,0,4,0,5,0,0,0,4,0,12,0,28,0,120,0,121,0,122,0,123,0,0,0,124,0,125,0,126,0,127,0,29,0,13,0,5,0,0,0,2,0,3,0,4,0,5,0,12,0,13,0,56,0,57,0,58,0,59,0,60,0,0,0,61,0,62,0,63,0,0,0,2,0,3,0,24,0,25,0,112,0,204,1,205,1,206,1,207,1,208,1,209,1,210,1,211,1,212,1,213,1,214,1,215,1,216,1,217,1,218,1,219,1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,1,246,1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,1,255,1,113,0,114,0,26,0,27,0,4,0,5,0,0,0,4,0,24,0,25,0,112,0,202,1,203,1,204,1,205,1,206,1,207,1,208,1,209,1,210,1,211,1,212,1,213,1,214,1,215,1,216,1,217,1,218,1,219,1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,1,246,1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,1,255,1,228,0,113,0,26,0,27,0,5,0,0,0,2,0,3,0,4,0,5,0,12,0,13,0,224,0,225,0,226,0,227,0,228,0,229,0,230,0,206,1,207,1,208,1,209,1,210,1,211,1,212,1,213,1,214,1,215,1,216,1,217,1,218,1,219,1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,1,246,1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,1,255,1,2,3,3,4,5,6,7,7,0,7,7,6,5,4,3,3,1,3,4,5,7,7,7,7,0,7,7,7,7,5,4,3,2,3,3,3,3,4,4,6,6,6,6,6,0,6,6,6,2,3,3,5,5,7,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,7,7,5,5,3,3,1,3,5,5,7,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,7,5,5,3,2,3,3,3,3,4,4,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,4,4,5,5,6,7,8,9,10,11,12,13,14,15,0,0,0,1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,9,9,0,1,2,31,3,29,30,4,5,6,27,28,7,24,25,26,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,2,8,1,3,3,1,4,4,16,0,0,0,0,0,0,0,18,19,20,21,22,23,24,25,26,27,28,14,15,16,17,29,9,10,11,12,13,30,4,5,6,7,8,31,0,1,2,3,4,8,11,5,6,6,4,0,8,9,10,11,12,13,14,15,16,17,5,6,7,18,19,20,21,22,4,23,24,25,26,27,0,1,2,3,28,29,30,31,4,8,10,8,6,0,8,0,1,6,1,0,1,2,4,8,0,1,7,2,3,4,5,6,1,6,1,1,1,1,0,4,1,7,1,1,1,1,1,1,2,0,0,0,0,0,0,0,0,1,7,2,6,3,4,5,1,7,1,1,1,1,1,1,2,0,0,0,0,0,0,0,0,1,2,31,3,4,5,6,7,8,29,30,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,1,7,1,0,0,3,2,6,20,0,0,0,0,0,0,0,0,28,29,1,2,3,4,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,30,31,5,6,7,8,9,10,4,6,3,23,6,0,0,0,0,1,31,2,3,4,5,6,7,26,27,28,29,30,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,2,6,1,0,2,11,18,0,2,3,4,5,6,1,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,0,3,8,5,3,2,3,2,16,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,0,2,8,1,2,4,4,4,0,16,0,0,0,0,0,0,0,0,1,15,14,2,13,3,12,4,5,6,7,8,9,10,11,1,9,1,1,1,1,1,0,1,2,8,0,0,0,0,0,0,1,14,15,2,13,3,12,4,5,6,7,8,9,10,11,1,9,1,0,3,1,1,0,2,0,8,0,0,0,0,0,15,14,1,13,2,3,12,4,5,6,7,8,9,10,11,0,1,9,1,1,1,1,1,0,2,0,8,0,0,0,0,0,7,5,8,6,9,4,10,11,0,1,2,3,12,13,14,15,1,7,1,0,2,2,1,2,8,0,0,0,0,0,0,0,0,1,255,2,254,3,4,5,6,7,8,251,252,253,9,10,11,12,246,247,248,249,250,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,243,244,245,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,1,11,1,0,0,2,2,0,9,9,29,104,100,0,0,0,0,5,4,1,0,1,2,3,3,0,4,2,4,0,1,2,1,0,4,3,3,0,2,1,0,3,1,2,4,0,1,2,0,3,2,1,0,1,2,3,0,1,2,4,0,1,2,3,1,4,2,0,0,1,2,3,0,1,2,3,6,7,4,5,0,4,10,11,12,13,14,15,0,2,3,4,5,6,14,15,0,2,6,7,0,0,0,0,1,3,4,4,4,4,4,4,2,3,3,3,3,3,4,4,1,2,3,3,0,0,0,0,0,0,0,2,0,4,0,6,0,8,0,10,0,12,0,14,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,220,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,233,32,0,176,97,30,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,220,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,144,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,54,31,0,108,0,0,0,216,74,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,212,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,0,0,84,1,0,0,0,0,0,0,0,0,0,0,72,152,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,0,0,84,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,202,28,0,192,198,35,0,8,0,0,0,5,0,0,0,216,113,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,64,24,35,0,192,198,35,0,8,0,0,0,5,0,0,0,216,113,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,92,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,62,31,0,108,0,0,0,152,76,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,205,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,38,34,0,240,245,33,0,24,0,0,0,3,0,0,0,154,153,153,153,153,153,169,63,123,20,174,71,225,122,132,63,0,0,0,0,0,0,36,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,205,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,146,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,73,31,0,108,0,0,0,136,78,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,209,34,0,108,0,0,0,176,89,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,132,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,107,32,0,0,0,0,0,0,0,0,0,176,85,32,0,0,0,0,0,4,0,0,0,48,61,32,0,1,0,0,0,8,0,0,0,192,5,32,0,1,0,0,0,12,0,0,0,152,237,31,0,2,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,216,31,0,232,198,31,0,160,176,31,0,36,0,0,0,20,0,0,0,24,0,0,0,72,158,31,0,0,0,0,0,0,0,0,0,208,139,31,0,0,0,0,0,4,0,0,0,88,123,31,0,1,0,0,0,8,0,0,0,160,108,31,0,3,0,0,0,12,0,0,0,32,88,31,0,3,0,0,0,16,0,0,0,112,46,31,0,1,0,0,0,20,0,0,0,48,28,31,0,1,0,0,0,24,0,0,0,224,15,31,0,1,0,0,0,28,0,0,0,224,0,31,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,240,30,0,232,198,31,0,160,176,31,0,36,0,0,0,20,0,0,0,24,0,0,0,72,158,31,0,0,0,0,0,0,0,0,0,208,139,31,0,0,0,0,0,4,0,0,0,88,123,31,0,1,0,0,0,8,0,0,0,160,108,31,0,3,0,0,0,12,0,0,0,32,88,31,0,3,0,0,0,16,0,0,0,112,46,31,0,1,0,0,0,20,0,0,0,48,28,31,0,1,0,0,0,24,0,0,0,224,0,31,0,5,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,69,33,0,232,198,31,0,216,226,30,0,20,0,0,0,28,0,0,0,32,0,0,0,160,213,30,0,1,0,0,0,0,0,0,0,216,198,30,0,4,0,0,0,4,0,0,0,152,183,30,0,4,0,0,0,8,0,0,0,160,176,31,0,0,0,0,0,12,0,0,0,120,165,30,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,100,0,0,0,48,182,33,0,152,148,33,0,214,0,0,0,152,148,33,0,112,115,33,0,214,0,0,0,176,51,33,0,216,10,33,0,214,0,0,0,232,240,32,0,56,213,32,0,158,0,0,0,176,185,32,0,192,163,32,0,158,0,0,0,216,10,33,0,96,139,32,0,214,0,0,0,64,114,32,0,128,91,32,0,214,0,0,0,128,67,32,0,88,12,32,0,214,0,0,0,96,242,31,0,16,222,31,0,214,0,0,0,168,203,31,0,40,182,31,0,214], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1780344);
/* memory initializer */ allocate([200,162,31,0,56,145,31,0,214,0,0,0,136,127,31,0,64,112,31,0,214,0,0,0,184,93,31,0,80,110,140,0,64,1,0,0,32,32,31,0,80,110,140,0,64,0,0,0,120,85,33,0,108,0,0,0,48,121,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,128,150,152,0,200,33,30,0,108,0,0,0,64,90,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,76,31,0,184,154,30,0,4,0,0,0,5,0,0,0,184,7,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,184,152,29,0,184,154,30,0,4,0,0,0,5,0,0,0,184,7,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,92,33,0,108,0,0,0,24,83,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,100,30,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,242,32,0,232,222,31,0,4,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,104,19,31,0,232,222,31,0,4,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,100,30,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,84,31,0,108,0,0,0,80,84,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,150,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,150,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,1,0,0,0,0,0,0,0,0,0,0,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,87,33,0,108,0,0,0,144,121,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,203,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,8,0,0,74,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,223,31,0,8,20,31,0,4,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,224,100,30,0,8,20,31,0,4,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,16,223,29,0,240,114,29,0,24,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,24,28,29,0,240,114,29,0,24,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,203,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,97,31,0,108,0,0,0,32,87,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,95,33,0,108,0,0,0,240,124,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,19,31,0,0,5,31,0,4,0,0,0,5,0,0,0,144,244,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,120,230,30,0,0,5,31,0,4,0,0,0,5,0,0,0,144,244,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,32,217,30,0,80,202,30,0,60,6,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,184,127,31,0,80,202,30,0,60,6,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,220,34,0,108,0,0,0,216,89,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,115,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,8,0,0,212,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,115,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,103,31,0,108,0,0,0,160,90,9,0,100,66,52,0,0,0,0,0,0,0,0,0,104,1,0,0,232,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,24,29,0,40,199,28,0,24,0,0,0,6,0,0,0,0,0,0,0,0,0,57,64,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,110,29,0,108,0,0,0,24,92,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,7,0,0,154,5,0,0,28,5,0,0,184,5,0,0,72,137,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,20,31,0,232,101,30,0,8,0,0,0,3,0,0,0,154,153,153,153,153,153,217,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,96,223,29,0,96,115,29,0,16,0,0,0,3,0,0,0,174,71,225,122,20,174,231,63,0,0,0,0,0,0,0,0,0,0,0,0,101,205,205,65,8,0,1,0,0,0,0,0,200,28,29,0,128,203,28,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,8,0,1,0,0,0,0,0,56,200,35,0,240,114,35,0,32,0,0,0,3,0,0,0,154,153,153,153,153,153,217,63,0,0,0,0,0,0,0,0,174,71,225,122,20,174,239,63,8,0,1,0,0,0,0,0,240,24,35,0,56,213,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,112,153,34,0,128,93,34,0,48,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,112,153,34,0,160,38,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,112,153,34,0,144,246,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,112,153,34,0,104,205,33,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,112,153,34,0,232,166,33,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,112,153,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,137,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,105,31,0,108,0,0,0,48,93,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,220,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,220,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,253,34,0,108,0,0,0,144,127,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,64,0,0,0,0,0,32,0,0,1,0,0,16,0,0,1,0,5,0,0,0,0,0,11,0,0,11,0,0,10,13,0,11,13,15,0,40,153,33,0,108,0,0,0,32,137,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,160,203,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,224,31,0,168,20,31,0,16,0,0,0,1,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,248,101,30,0,112,223,29,0,24,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,112,115,29,0,208,28,29,0,32,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,203,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,106,31,0,108,0,0,0,32,100,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,131,32,0,248,138,31,0,4,0,0,0,5,0,0,0,232,212,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,184,44,30,0,248,138,31,0,4,0,0,0,5,0,0,0,232,212,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,56,186,29,0,16,87,29,0,16,0,0,0,5,0,0,0,56,3,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,184,180,28,0,16,87,29,0,16,0,0,0,5,0,0,0,56,3,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,152,177,35,0,72,82,35,0,24,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,40,2,35,0,72,82,35,0,24,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,48,29,0,108,0,0,0,136,101,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,2,6,1,5,3,7,8,12,10,14,9,13,11,15,0,0,0,0,2,0,0,0,6,0,0,0,12,0,0,0,112,29,9,0,224,28,9,0,64,28,9,0,40,26,9,0,104,25,9,0,152,24,9,0,128,56,9,0,24,55,9,0,0,0,0,0,0,0,0,0,18,24,33,37,41,47,51,59,61,6,6,0,0,0,1,1,12,13,15,17,19,20,26,31,5,0,0,0,0,0,0,0,216,26,9,0,176,22,9,0,136,52,9,0,184,49,9,0,168,46,9,0,248,42,9,0,8,39,9,0,152,34,9,0,248,29,9,0,0,0,0,0,0,0,4,63,0,0,103,63,0,32,202,63,0,220,48,64,0,0,4,191,0,0,103,191,0,32,202,191,0,220,48,192,88,83,33,0,108,0,0,0,184,61,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,115,29,0,0,29,29,0,40,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,64,64,8,0,1,0,0,0,0,0,168,203,28,0,96,200,35,0,48,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,8,0,1,0,168,203,28,0,120,115,35,0,24,25,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,168,203,28,0,120,213,34,0,120,153,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,168,203,28,0,152,93,34,0,176,38,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,168,203,28,0,160,246,33,0,120,205,33,0,52,0,0,0,4,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,114,31,0,108,0,0,0,232,103,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,213,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,0,0,78,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,115,35,0,112,25,35,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,64,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,117,31,0,108,0,0,0,224,105,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,146,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,1,0,0,94,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,146,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,2,0,0,0,0,0,0,0,0,0,0,246,9,0,0,0,0,0,0,1,0,0,0,176,52,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,1,0,1,0,1,0,1,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,5,6,7,8,9,10,12,13,15,17,20,22,25,28,32,36,40,45,50,56,63,71,80,90,101,113,127,144,162,182,203,226,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,3,3,4,4,5,5,6,7,8,9,10,11,12,13,15,16,18,20,22,24,26,28,30,33,33,35,35,36,37,37,39,39,42,44,46,48,50,52,53,54,55,56,57,58,59,60,61,62,63,64,35,0,0,0,43,1,0,0,27,0,0,0,29,0,0,0,28,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,96,201,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,56,153,32,0,208,175,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,32,129,32,0,136,102,32,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,32,129,32,0,112,82,32,0,40,48,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,8,255,31,0,72,233,31,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,152,213,31,0,120,194,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,144,172,31,0,168,154,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,129,32,0,88,137,31,0,152,120,31,0,40,0,0,0,3,0,0,0,205,204,204,204,204,24,134,64,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,72,106,31,0,152,120,31,0,40,0,0,0,3,0,0,0,205,204,204,204,204,24,134,64,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,151,34,0,108,0,0,0,176,108,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,0,0,0,0,4,0,1,3,4,5,6,7,8,9,10,11,12,13,14,15,4,0,1,3,4,5,6,7,8,9,10,11,12,13,14,15,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,4,0,2,4,5,6,7,8,9,10,11,12,13,14,15,16,4,0,2,4,5,6,7,8,9,10,11,12,13,14,15,16,4,0,2,4,5,6,7,8,9,10,11,12,13,14,15,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,2,0,1,16,2,0,1,16,2,0,1,16,2,0,1,16,2,0,1,16,2,0,1,16,2,0,1,16,0,0,0,0,11,0,0,0,2,0,0,0,28,0,0,0,42,0,0,0,36,1,0,0,8,0,0,0,66,0,0,0,32,0,0,0,6,0,0,0,7,0,0,0,35,0,0,0,0,0,0,0,4,0,0,0,44,1,0,0,33,0,0,0,5,0,0,0,43,1,0,0,70,0,0,0,80,0,0,0,76,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,98,0,0,0,100,0,0,0,102,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,110,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,14,0,0,0,13,0,0,0,12,0,0,0,34,0,0,0,255,255,255,255,32,178,30,0,108,0,0,0,168,0,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,157,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,3,0,0,158,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,84,31,0,216,161,30,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,96,13,30,0,216,161,30,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,103,33,0,108,0,0,0,200,114,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,57,33,0,108,0,0,0,176,137,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,47,43,46,45,42,39,35,38,41,44,40,37,34,33,36,32,16,20,17,18,21,24,28,25,22,19,23,26,29,30,27,31,63,59,62,61,58,55,51,54,57,60,56,53,50,49,52,48,64,72,65,66,73,80,88,81,74,67,75,82,89,90,83,91,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,16,20,17,18,21,24,28,25,22,19,23,26,29,30,27,31,155,147,154,153,146,139,131,138,145,152,144,137,130,129,136,128,47,43,46,45,42,39,35,38,41,44,40,37,34,33,36,32,63,59,62,61,58,55,51,54,57,60,56,53,50,49,52,48,96,104,97,98,105,112,120,113,106,99,107,114,121,122,115,123,68,76,69,70,77,84,92,85,78,71,79,86,93,94,87,95,100,108,101,102,109,116,124,117,110,103,111,118,125,126,119,127,187,179,186,185,178,171,163,170,177,184,176,169,162,161,168,160,159,151,158,157,150,143,135,142,149,156,148,141,134,133,140,132,191,183,190,189,182,175,167,174,181,188,180,173,166,165,172,164,184,115,27,0,120,142,27,0,248,115,27,0,184,142,27,0,8,16,19,22,22,26,26,27,16,16,22,22,26,27,27,29,19,22,26,26,27,29,29,35,22,24,27,27,29,32,34,38,26,27,29,29,32,35,38,46,27,29,34,34,35,40,46,56,29,34,34,37,40,48,56,69,34,37,38,40,48,58,69,83,64,0,0,0,32,0,0,0,192,0,0,0,96,0,0,0,1,0,1,0,5,0,245,1,17,0,73,0,0,0,72,0,75,0,53,0,3,0,52,0,201,3,244,1,201,0,74,0,217,15,200,3,16,0,55,0,1,0,200,0,117,0,247,1,203,0,116,0,2,0,246,1,202,0,241,1,240,1,129,31,249,7,128,31,131,31,248,7,119,0,245,0,54,0,251,7,118,0,130,31,244,0,247,0,250,7,113,0,246,0,203,3,202,3,216,15,241,0,245,3,141,31,229,7,19,0,49,0,240,0,219,15,243,0,228,7,48,0,243,1,231,7,244,3,230,7,112,0,25,63,242,1,24,63,218,15,51,0,225,7,253,1,252,1,115,0,255,1,197,15,196,15,199,15,247,3,114,0,5,0,5,0,5,0,121,0,5,0,13,0,29,0,120,0,105,0,4,0,1,0,7,0,104,0,28,0,31,0,4,0,107,0,12,0,4,0,30,0,6,0,106,0,21,0,15,0,20,0,23,0,7,0,22,0,14,0,17,0,9,0,209,0,208,0,129,1,211,0,123,0,16,0,19,0,4,0,210,0,7,0,25,3,8,0,122,0,221,0,25,0,6,0,11,0,101,0,220,0,18,0,100,0,128,1,223,0,6,0,24,0,1,0,222,0,29,0,217,0,27,0,103,0,10,0,216,0,219,0,28,0,24,3,218,0,53,6,131,1,0,0,197,0,102,0,97,0,53,0,196,0,130,1,52,6,27,3,199,0,31,0,5,0,1,0,29,0,193,1,53,0,241,0,109,0,240,0,73,0,0,0,4,0,3,0,243,0,72,0,52,0,108,0,192,1,195,1,7,0,6,0,1,0,111,0,2,0,75,0,110,0,28,0,5,0,105,0,104,0,107,0,55,0,194,1,242,0,149,3,205,1,253,0,106,0,54,0,21,0,204,1,20,0,148,3,74,0,252,0,255,0,23,0,49,0,254,0,207,1,151,3,249,0,206,1,37,7,150,3,22,0,48,0,117,0,36,7,248,0,39,7,51,0,145,3,144,3,17,0,50,0,31,0,251,0,116,0,38,7,250,0,30,0,119,0,25,0,24,0,4,0,16,0,61,0,118,0,113,0,19,0,1,0,13,0,25,0,17,0,21,0,97,0,25,0,20,0,173,1,96,0,24,0,1,0,5,0,27,0,16,0,25,0,5,0,23,0,24,0,22,0,4,0,4,0,19,0,12,0,18,0,26,0,24,0,5,0,15,0,27,0,4,0,29,0,17,0,28,0,16,0,14,0,27,0,19,0,31,0,26,0,41,0,5,0,99,0,30,0,9,0,98,0,8,0,7,0,7,0,25,0,4,0,26,0,24,0,109,0,7,0,27,0,7,0,26,0,108,0,6,0,18,0,5,0,111,0,11,0,110,0,105,0,29,0,89,3,40,0,43,0,42,0,28,0,213,0,88,3,31,0,1,0,30,0,104,0,212,0,215,0,25,0,0,0,185,0,97,0,96,0,184,0,181,2,173,1,187,0,245,10,81,1,1,0,1,0,5,0,0,0,3,0,5,0,4,0,99,0,37,0,186,0,4,0,7,0,98,0,165,0,36,0,109,0,2,0,108,0,180,2,13,0,111,0,39,0,164,0,38,0,172,1,80,1,175,1,174,1,33,0,110,0,183,2,32,0,83,1,35,0,167,0,82,1,166,0,6,0,12,0,34,0,169,1,25,0,45,0,182,2,168,1,15,0,7,0,14,0,161,0,105,0,44,0,1,0,171,1,160,0,177,2,163,0,47,0,244,10,176,2,247,10,179,2,104,0,93,1,246,10,170,1,85,0,92,1,178,2,121,5,120,5,95,1,162,0,5,9,61,1,60,1,4,9,29,18,157,4,156,4,61,36,7,9,237,0,1,0,21,0,65,0,63,1,49,0,20,0,93,2,92,2,62,1,13,0,0,0,64,0,57,1,67,0,48,0,23,0,51,0,6,9,50,0,66,0,236,0,95,2,239,0,94,2,159,4,56,1,1,9,59,1,89,2,28,18,158,4,0,9,88,2,60,36,31,18,3,9,61,0,238,0,91,2,90,2,77,0,58,1,2,9,69,2,233,0,22,0,232,0,153,4,37,1,68,2,76,0,152,4,13,9,235,0,60,0,17,0,155,4,154,4,133,4,234,0,63,0,36,1,12,9,62,0,57,0,149,0,71,2,70,2,132,4,148,0,56,0,9,15,205,0,253,1,145,7,109,30,144,7,217,3,209,60,208,60,117,0,1,0,1,0,53,0,204,0,17,0,0,0,216,3,252,1,219,3,16,0,3,0,207,0,218,3,206,0,116,0,52,0,119,0,147,7,19,0,118,0,113,0,197,3,112,0,255,1,146,7,254,1,249,1,55,0,201,0,8,15,248,1,196,3,200,0,11,15,157,7,199,3,1,0,18,0,115,0,203,0,5,0,54,0,198,3,114,0,125,0,2,0,202,0,156,7,251,1,245,0,49,0,159,7,10,15,53,15,158,7,250,1,108,30,111,30,211,60,153,7,193,3,110,30,210,60,48,0,244,0,124,0,192,3,195,3,152,7,229,1,247,0,165,1,1,0,29,0,33,0,161,0,13,0,97,0,185,6,160,0,96,0,1,0,5,0,12,0,32,0,28,0,4,0,164,1,167,1,163,0,31,0,30,0,35,0,34,0,45,0,44,0,99,0,98,0,129,26,166,1,161,1,184,6,187,6,162,0,186,6,89,13,165,6,160,1,15,0,109,0,164,6,47,0,173,0,108,0,167,6,172,0,88,13,14,0,163,1,175,0,174,0,111,0,162,1,91,13,169,0,25,0,1,0,9,0,168,0,110,0,46,0,0,0,173,1,171,0,170,0,85,3,41,0,128,26,131,26,130,26,84,3,172,1,90,13,141,26,175,1,87,3,69,13,68,13,71,13,140,26,166,6,161,6,1,0,17,0,5,0,117,7,249,0,248,0,49,0,48,0,73,0,251,0,16,0,51,0,201,14,141,3,140,3,250,0,143,3,116,7,72,0,50,0,0,0,213,1,229,0,142,3,228,0,19,0,13,0,137,3,119,7,136,3,139,3,249,29,200,14,201,59,248,29,138,3,181,3,118,7,231,0,200,59,212,1,203,59,203,14,113,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1790584);
/* memory initializer */ allocate([202,14,215,1,180,3,214,1,251,29,245,14,112,7,244,14,202,59,115,7,230,0,183,3,75,0,250,29,182,3,247,14,225,0,246,14,241,14,177,3,209,1,61,0,240,14,114,7,125,7,124,7,60,0,208,1,176,3,211,1,63,0,179,3,210,1,243,14,127,7,224,0,74,0,21,0,73,0,20,0,209,7,253,3,252,3,193,1,192,1,241,0,23,0,1,0,1,0,195,1,72,0,75,0,22,0,49,0,194,1,74,0,17,0,0,0,205,1,240,0,204,1,117,0,16,0,13,0,255,3,207,1,206,1,208,7,129,15,211,7,29,31,128,15,210,7,201,1,254,3,116,0,221,7,243,0,28,31,220,7,249,3,223,7,242,0,253,0,119,0,222,7,217,7,200,1,216,7,131,15,248,3,48,0,118,0,19,0,130,15,252,0,251,3,51,0,250,3,229,3,228,3,203,1,50,0,31,31,231,3,219,7,218,7,61,0,202,1,197,7,230,3,113,0,141,15,196,7,30,31,140,15,225,3,245,1,25,0,101,0,24,0,81,3,80,3,83,3,33,0,32,0,100,0,29,0,5,0,5,0,165,1,35,0,103,0,5,0,102,0,34,0,27,0,4,0,1,0,4,0,28,0,97,0,26,0,5,0,4,0,7,0,45,0,6,0,44,0,164,1,47,0,82,3,93,3,96,0,1,0,46,0,31,0,92,3,0,0,177,6,167,1,41,0,166,1,40,0,99,0,98,0,95,3,161,1,43,0,176,6,179,6,160,1,3,0,109,0,30,0,94,3,108,0,178,6,2,0,163,1,162,1,13,0,5,0,7,0,173,1,111,0,42,0,110,0,4,0,4,0,12,0,7,0,6,0,15,0,14,0,213,0,9,0,6,0,7,0,101,0,129,1,100,0,201,54,213,6,181,13,121,3,128,1,131,1,213,0,29,0,28,0,180,13,130,1,120,3,212,0,215,0,212,6,103,0,31,0,1,0,214,0,209,0,141,1,102,0,1,0,0,0,123,3,215,6,122,3,183,13,200,54,214,6,182,13,121,27,177,13,140,1,101,3,208,0,120,27,211,0,123,27,100,3,209,6,208,6,143,1,142,1,210,0,203,54,103,3,102,3,211,6,176,13,210,6,97,3,221,6,137,1,202,54,96,3,245,54,136,1,179,13,244,54,9,0,8,0,5,0,220,6,221,0,139,1,220,0,4,0,11,0,138,1,97,0,3,0,99,3,223,0,223,6,98,3,10,0,30,0,29,0,97,0,13,0,85,13,185,6,184,6,165,1,33,0,32,0,35,0,12,0,96,0,84,13,173,0,172,0,34,0,175,0,187,6,15,0,28,0,1,0,45,0,99,0,164,1,14,0,1,0,5,0,167,1,186,6,166,1,165,6,87,13,86,13,189,26,81,13,174,0,44,0,169,0,47,0,80,13,161,1,188,26,164,6,167,6,166,6,168,0,161,6,160,1,191,26,83,13,160,6,82,13,190,26,163,6,98,0,46,0,9,0,93,13,163,1,92,13,109,0,171,0,162,6,108,0,31,0,1,0,173,6,41,0,162,1,40,0,4,0,30,0,173,1,111,0,0,0,172,1,175,1,172,6,170,0,110,0,25,0,25,0,125,0,24,0,181,1,13,0,180,1,124,0,127,0,183,1,12,0,27,0,26,0,182,1,15,0,213,0,25,0,126,0,212,0,24,0,27,0,1,0,14,0,17,0,9,0,5,0,5,0,5,0,215,0,177,1,8,0,176,1,121,0,253,6,113,3,112,3,214,0,120,0,179,1,16,0,115,3,19,0,252,6,123,0,122,0,209,0,208,0,211,0,101,0,114,3,255,6,100,0,254,6,125,3,210,0,221,0,103,0,4,0,124,3,18,0,178,1,7,0,102,0,189,1,6,0,97,0,4,0,188,1,26,0,96,0,29,0,4,0,28,0,99,0,1,0,7,0,11,0,0,0,98,0,10,0,5,0,7,0,105,0,69,0,104,0,189,4,85,2,188,4,229,0,228,0,49,0,48,0,25,0,1,0,33,1,231,0,230,0,51,0,225,0,224,0,107,0,24,0,1,0,68,0,50,0,71,0,106,0,27,0,5,0,61,0,70,0,21,0,65,0,32,1,35,1,191,4,34,1,64,0,60,0,227,0,20,0,84,2,67,0,117,9,45,1,226,0,237,0,66,0,236,0,77,0,87,2,86,2,81,2,190,4,116,9,80,2,239,0,238,0,76,0,185,4,44,1,184,4,79,0,187,4,83,2,63,0,23,0,1,0,82,2,233,0,232,0,235,0,0,0,3,0,22,0,2,0,4,0,78,0,62,0,234,0,73,0,13,0,7,0,13,0,189,1,12,0,49,13,48,13,51,13,89,3,88,3,45,0,101,0,29,0,28,0,50,13,91,3,90,3,44,0,188,1,69,3,15,0,31,0,1,0,47,0,100,0,191,1,103,0,1,0,5,0,102,0,46,0,97,0,41,0,149,6,148,6,151,6,150,6,96,0,190,1,61,13,40,0,73,26,68,3,72,26,75,26,60,13,145,6,43,0,185,1,42,0,63,13,144,6,71,3,62,13,74,26,70,3,213,0,65,3,99,0,57,13,64,3,56,13,184,1,59,13,58,13,212,0,98,0,0,0,147,6,187,1,67,3,66,3,30,0,14,0,109,0,9,0,1,0,108,0,215,0,77,3,186,1,8,0,4,0,117,0,205,0,53,0,193,3,192,3,249,7,195,3,141,31,204,0,116,0,17,0,16,0,194,3,217,15,241,1,207,0,205,3,206,0,52,0,1,0,1,0,55,0,201,0,200,0,54,0,0,0,1,0,216,15,204,3,203,0,240,1,248,7,207,3,251,7,250,7,202,0,243,1,206,3,245,0,219,15,244,0,229,7,228,7,231,7,242,1,230,7,201,3,253,1,218,15,140,31,225,7,143,31,142,31,200,3,203,3,119,0,118,0,197,15,202,3,224,7,247,0,196,15,245,3,246,0,252,1,3,0,244,3,113,0,247,3,241,0,19,0,49,0,48,0,112,0,5,0,18,0,115,0,255,1,114,0,125,0,2,0,97,0,85,0,96,0,201,2,200,2,203,2,113,1,181,0,84,0,1,0,1,0,1,0,87,0,1,0,99,0,29,0,98,0,57,0,109,0,0,0,5,0,56,0,86,0,180,0,108,0,3,0,28,0,111,0,59,0,2,0,58,0,112,1,183,0,115,1,81,0,110,0,37,0,80,0,105,0,202,2,36,0,39,0,114,1,182,0,177,0,13,0,12,0,31,0,125,1,38,0,104,0,83,0,124,1,107,0,30,0,15,0,4,0,127,1,106,0,245,2,25,0,33,0,82,0,244,2,247,2,32,0,205,11,229,5,228,5,204,11,35,0,176,0,246,2,179,0,34,0,241,2,240,2,207,11,206,11,126,1,93,0,189,0,37,0,161,1,89,1,153,2,188,0,36,0,5,5,4,5,160,1,1,0,29,0,109,0,28,0,1,0,5,0,39,0,163,1,88,1,31,0,30,0,162,1,38,0,33,0,13,0,32,0,35,0,152,2,108,0,34,0,191,0,190,0,173,1,45,0,155,2,185,0,172,1,184,0,175,1,154,2,111,0,91,1,110,0,133,2,132,2,174,1,25,0,44,0,169,1,168,1,12,0,15,0,90,1,187,0,14,0,0,0,105,0,171,1,24,0,170,1,4,0,85,0,186,0,7,5,69,1,84,0,6,5,165,0,1,5,164,0,87,0,0,5,5,10,68,1,167,0,135,2,134,2,3,5,71,1,4,10,70,1,89,7,65,0,229,0,189,3,157,14,45,1,44,1,29,58,188,3,47,1,13,0,64,0,228,0,191,3,67,0,66,0,88,7,190,3,231,0,1,0,0,0,61,0,230,0,21,0,20,0,23,0,60,0,61,116,46,1,185,3,184,3,156,14,187,3,91,7,28,58,159,14,41,1,225,0,40,1,158,14,43,1,90,7,224,0,153,14,69,7,31,58,186,3,68,7,152,14,13,29,165,3,155,14,60,116,154,14,42,1,77,0,227,0,133,14,213,1,132,14,76,0,71,7,12,29,212,1,63,0,22,0,70,7,164,3,65,7,79,0,62,0,215,1,64,7,12,0,17,0,78,0,226,0,237,0,236,0,73,0,72,0,1,5,4,10,6,8,5,8,8,7,5,7,11,10,9,8,13,11,6,7,3,9,8,10,9,8,5,10,9,10,10,14,12,14,14,12,8,9,7,12,8,14,9,9,12,8,9,11,11,13,9,11,14,12,6,7,9,13,9,12,7,10,12,11,12,8,15,10,15,13,7,12,10,10,8,10,13,13,13,11,8,4,6,5,11,8,10,7,11,9,4,1,4,9,7,7,5,9,10,6,7,4,9,9,10,9,9,6,9,10,9,10,12,12,13,12,11,9,9,8,12,8,14,10,11,12,7,8,10,11,12,9,11,13,12,6,7,8,12,9,12,7,11,10,12,12,9,14,12,15,13,8,12,11,11,10,12,13,15,14,12,9,5,7,6,12,9,11,8,11,10,7,5,7,11,10,9,8,12,12,5,5,1,8,7,10,8,6,4,8,8,8,9,12,11,13,12,11,8,9,8,12,8,13,10,11,11,8,9,11,12,13,11,12,14,13,8,9,10,14,11,14,9,13,13,8,9,6,11,10,14,11,6,10,6,6,4,8,9,10,10,8,5,11,7,8,10,12,9,10,14,12,7,1,5,7,8,6,4,10,9,10,5,4,8,11,8,7,6,7,11,6,7,8,10,8,10,11,9,10,8,9,13,9,12,8,11,12,11,4,7,8,9,6,8,12,9,8,5,8,12,9,10,6,12,11,12,12,10,15,13,13,13,10,13,15,10,9,10,12,13,13,10,9,11,8,8,11,13,10,11,15,12,7,1,4,7,7,5,4,8,9,11,5,5,8,11,9,8,7,8,13,7,8,9,11,9,10,12,10,10,9,8,13,9,12,9,11,12,11,5,7,9,10,6,9,13,10,7,4,7,11,8,9,5,10,11,13,11,9,15,13,15,13,8,12,15,10,10,12,13,14,14,12,11,12,9,9,12,13,11,11,14,12,8,2,5,7,9,6,5,10,10,9,4,2,7,9,7,6,5,6,12,6,7,8,10,8,10,11,9,12,9,10,13,11,12,10,14,13,12,6,8,10,10,7,9,12,10,8,5,8,11,9,10,7,11,12,8,6,5,11,11,11,8,6,9,12,6,6,8,10,10,11,8,6,13,9,10,12,14,12,11,15,15,8,1,5,7,9,6,5,11,10,11,6,5,9,11,9,8,7,8,12,6,8,8,11,8,10,12,10,10,7,9,13,10,11,9,13,12,11,3,6,8,9,4,7,11,8,8,5,9,12,10,9,7,12,13,13,12,10,14,14,15,12,11,14,15,7,9,8,11,11,12,10,9,10,5,6,9,11,7,8,12,11,8,1,4,7,9,6,4,10,10,11,6,6,9,9,9,9,8,8,14,10,10,12,12,11,12,13,12,10,7,8,12,9,11,8,12,11,13,7,10,11,11,8,10,13,11,6,3,7,11,8,9,5,10,11,11,11,9,14,14,14,11,10,13,14,10,11,13,13,13,14,12,12,2,5,3,11,8,8,6,6,7,8,5,6,12,10,10,8,10,11,7,6,2,9,8,10,8,5,4,10,11,10,10,13,12,14,13,10,10,11,8,14,9,14,12,11,12,9,10,9,13,12,11,12,14,11,8,10,7,13,10,12,8,12,12,10,9,6,12,11,11,11,6,9,10,9,6,10,9,12,11,8,7,6,8,6,12,11,11,10,10,9,6,1,3,10,8,8,6,7,10,8,6,3,10,9,10,8,6,5,11,10,10,12,13,12,14,13,12,10,11,8,12,9,14,12,11,12,9,9,8,12,12,10,12,13,11,7,8,6,13,9,11,7,11,11,11,10,7,14,11,12,12,7,10,12,11,8,13,12,14,13,11,10,7,10,7,13,13,13,11,11,10,8,5,6,12,11,10,9,10,11,7,5,1,9,8,10,7,4,4,9,11,9,11,12,11,13,13,10,9,11,8,13,9,14,12,11,12,11,10,10,13,12,11,14,14,12,9,10,8,13,10,14,9,12,12,9,7,4,12,10,11,10,6,7,9,7,4,9,9,11,9,7,5,7,9,7,14,11,12,10,9,9,8,5,5,12,9,10,8,8,11,7,5,2,8,8,9,7,4,4,10,11,10,12,14,11,12,13,12,9,10,8,13,8,13,10,11,11,9,9,8,14,10,10,11,12,11,10,11,9,14,10,14,9,12,14,6,6,3,11,8,9,8,3,6,9,7,4,10,8,11,10,6,5,6,8,7,13,12,12,10,9,9,9,7,8,13,11,11,9,11,12,7,6,1,9,8,10,7,5,4,10,12,10,12,13,13,14,13,11,9,11,9,13,10,14,12,12,12,11,12,10,14,13,12,13,14,12,8,9,7,13,10,13,8,11,12,8,6,3,12,9,10,9,4,6,10,8,5,10,10,12,11,8,6,7,10,7,12,9,12,10,10,12,9,7,7,12,9,11,6,10,11,6,6,1,9,8,9,7,4,5,11,12,9,12,10,14,13,13,11,10,12,8,13,8,14,10,10,11,11,11,10,13,14,10,14,13,11,11,10,7,13,8,12,7,10,12,7,10,4,12,6,10,8,5,8,10,7,4,9,7,10,9,6,5,7,9,7,13,12,13,10,10,8,8,5,6,11,10,10,8,10,10,7,5,2,9,8,9,7,5,3,8,9,7,9,11,11,13,11,9,8,10,7,12,9,14,11,10,10,9,10,9,12,12,12,13,14,12,10,10,9,13,11,13,9,13,12,8,7,4,12,10,10,10,6,6,7,6,3,9,8,10,9,6,3,7,10,7,13,13,13,11,11,9,8,6,6,13,11,11,9,10,11,7,6,1,9,8,10,8,5,4,8,9,8,9,12,12,12,12,8,10,13,9,14,11,14,14,13,12,9,10,9,13,12,11,13,14,11,9,11,8,13,11,13,10,13,13,9,8,5,12,10,11,11,6,7,8,7,3,8,9,11,10,7,4,8,9,7,11,11,12,11,14,9,8,6,6,11,13,10,9,11,9,7,5,1,7,9,9,7,5,3,13,11,9,10,12,11,12,12,9,10,11,9,13,9,12,12,12,10,12,11,10,13,14,12,14,14,11,11,8,8,13,11,12,9,13,11,9,10,5,11,8,11,9,6,7,7,8,4,6,8,10,8,8,5,8,10,8,13,13,13,12,11,10,5,1,3,10,7,8,6,8,9,8,7,4,9,10,11,8,7,6,8,9,7,9,12,11,12,10,8,9,10,8,13,9,9,12,11,11,7,7,6,12,9,8,10,12,8,6,7,4,12,8,13,6,9,10,13,13,9,15,14,14,15,9,11,13,11,9,13,13,15,15,12,10,10,8,9,11,12,10,8,13,13,9,2,5,7,5,4,3,8,9,11,5,5,9,8,8,6,8,8,12,7,8,10,10,9,8,12,10,9,10,9,12,7,11,7,12,12,9,5,8,9,9,6,6,11,10,6,4,7,9,5,9,3,9,10,13,11,9,13,10,13,10,9,13,14,11,10,12,12,13,11,14,11,11,7,8,10,12,9,9,14,10,9,4,7,8,10,7,7,11,10,8,2,2,6,8,5,5,5,6,15,9,10,10,12,10,11,14,12,9,8,9,12,9,11,8,12,11,14,10,11,12,13,10,12,15,12,9,7,8,12,9,12,7,11,13,9,6,5,11,10,11,7,6,9,11,4,5,7,8,8,8,7,7,0,0,0,0,1,1,1,17,0,9,3,16,5,9,1,1,5,17,0,3,33,32,1,1,1,17,9,16,5,0,3,1,1,0,3,33,5,9,32,17,1,9,0,41,8,21,3,11,40,1,1,1,1,0,1,1,3,2,1,1,1,5,0,3,1,9,8,1,1,1,9,1,8,0,3,5,1,1,1,0,5,17,9,16,3,0,0,0,0,0,0,0,0,0,1,1,1,5,1,0,3,9,8,9,1,1,5,17,0,3,33,32,1,1,1,13,5,4,0,7,12,1,1,0,5,17,3,9,33,32,5,1,1,17,0,9,3,33,32,9,1,1,0,5,1,3,17,16,1,1,1,0,1,1,1,3,2,1,1,1,9,0,5,1,3,8,1,1,1,9,17,5,0,16,3,1,0,0,0,0,0,0,0,0,1,0,1,9,8,21,20,11,3,13,1,1,5,12,4,1,0,7,1,1,1,5,0,4,3,1,1,5,1,1,4,25,7,24,13,0,17,9,1,33,5,32,1,0,3,65,1,0,5,64,3,9,33,17,41,1,0,40,9,21,3,8,11,1,0,1,17,9,16,5,1,3,5,1,1,4,13,12,7,0,1,0,0,0,0,0,0,0,0,0,1,0,3,5,17,16,37,36,19,33,1,1,0,17,3,5,32,9,1,1,1,0,9,17,16,5,3,33,5,1,1,9,0,17,32,3,5,1,0,4,1,25,7,24,13,17,1,0,1,9,1,3,16,5,29,1,5,13,12,4,0,28,15,5,25,1,4,0,24,27,26,7,9,1,0,1,5,3,17,16,1,0,0,0,0,0,0,0,0,0,1,0,3,65,5,64,9,17,33,5,1,1,25,4,7,0,24,13,1,1,1,5,1,4,1,0,3,1,5,0,13,1,4,7,25,24,1,1,1,1,1,0,1,3,2,49,1,5,25,4,7,0,48,13,1,0,3,17,1,5,1,9,16,1,5,1,17,1,16,0,3,9,1,9,0,41,3,8,40,21,11,0,0,0,0,0,0,0,0,0,1,1,0,9,21,3,8,20,11,17,1,1,0,9,1,3,16,5,1,0,3,37,17,5,16,36,19,17,1,0,1,9,1,5,16,3,5,1,0,13,12,4,15,29,28,1,1,1,1,0,1,1,3,2,33,1,5,9,17,0,3,65,64,5,1,0,29,28,13,12,15,4,5,1,0,13,49,4,25,48,7,0,0,0,0,0,0,0,0,0,1,1,0,33,5,17,3,9,32,1,1,0,17,3,5,1,9,16,1,1,1,1,1,0,1,3,2,5,1,4,25,7,13,0,49,48,1,1,1,1,1,0,1,3,2,5,1,1,17,9,0,3,33,32,1,1,1,1,1,0,1,3,2,1,1,1,0,1,3,1,1,2,9,1,0,41,8,21,3,40,11,0,0,0,0,0,0,0,0,0,1,1,1,5,1,4,0,1,3,9,1,0,41,40,21,8,3,11,1,0,1,17,5,16,9,1,3,5,4,1,29,13,12,28,0,15,9,17,1,65,0,64,5,3,33,13,5,1,29,28,12,4,0,15,65,9,1,64,0,17,5,3,33,1,1,1,5,1,4,0,1,3,5,4,1,13,1,12,7,1,0,0,0,0,0,0,0,0,0,0,5,4,1,7,25,49,48,13,0,33,1,1,0,17,9,32,5,3,5,1,1,4,7,13,12,0,1,33,9,1,0,32,5,35,34,3,49,13,1,25,5,48,4,7,0,49,5,1,4,25,0,13,48,7,49,1,0,13,5,25,4,48,7,1,1,1,0,1,3,2,1,1,1,0,1,1,5,9,8,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,2,7,4,6,4,7,5,5,1,3,4,6,3,3,7,7,1,4,2,7,6,7,5,4,4,1,3,3,3,7,4,5,7,6,2,4,2,6,4,5,2,4,6,7,2,3,4,7,1,5,7,7,5,1,3,6,5,5,2,7,7,2,5,1,7,3,7,5,5,6,2,4,1,4,5,7,6,7,4,0,0,0,0,0,0,0,0,0,2,1,3,6,5,5,5,7,7,5,1,3,4,6,3,3,7,7,4,1,2,6,5,5,4,5,6,3,1,3,4,6,3,5,7,7,4,1,3,6,3,5,3,7,7,6,1,4,4,5,2,4,7,7,7,1,5,7,4,3,2,7,7,5,3,2,7,5,6,1,5,7,4,1,2,6,7,5,4,7,4,1,0,1,0,0,0,0,0,0,3,3,1,5,5,6,6,5,3,6,2,1,5,6,5,4,4,5,6,4,1,7,6,7,6,3,2,4,3,1,4,6,4,6,5,3,6,5,1,7,4,7,3,3,3,7,2,2,3,7,2,4,6,5,6,2,2,6,4,5,2,4,4,4,4,1,7,6,7,5,2,4,5,4,1,5,6,6,5,4,2,0,0,0,0,0,0,0,0,0,2,2,2,3,5,5,6,6,5,7,1,3,3,6,3,4,7,5,2,4,1,4,6,7,7,5,4,7,4,3,1,5,3,6,7,3,4,3,3,4,1,6,4,6,5,7,4,4,2,6,1,4,7,5,5,2,3,4,4,3,2,5,4,3,5,2,3,2,5,5,5,3,6,4,4,2,5,4,7,7,1,0,0,0,0,0,0,0,0,0,2,2,2,7,3,7,4,5,6,4,1,3,6,4,4,3,6,5,2,4,1,7,3,7,6,6,6,3,4,3,5,1,4,4,6,6,4,5,2,7,1,7,3,7,7,6,2,3,5,3,3,2,6,4,4,4,4,7,2,5,1,6,7,4,5,2,7,1,7,4,4,6,2,4,2,6,2,4,6,5,4,0,0,0,0,0,0,0,0,0,1,3,3,5,6,3,5,6,5,7,1,4,4,6,2,4,7,5,2,2,2,6,5,3,5,6,5,7,4,4,2,6,1,5,7,4,3,2,2,4,4,3,4,5,5,7,2,5,3,7,1,4,7,7,6,2,3,4,5,2,2,7,7,3,2,2,5,5,4,4,4,3,3,2,2,4,6,3,5,6,3,0,0,0,0,0,0,0,0,0,1,3,3,7,4,6,3,5,7,4,1,4,7,4,5,2,6,7,2,4,1,7,5,7,3,7,7,3,2,3,5,3,4,2,6,6,3,5,4,7,2,7,1,7,7,4,1,3,6,5,3,3,7,7,4,2,5,7,3,7,1,7,7,7,4,1,7,3,7,2,5,7,4,2,2,6,4,5,2,6,4,0,0,0,0,0,0,0,0,0,3,4,1,7,6,7,6,2,6,4,2,2,6,6,5,4,2,4,4,4,1,7,5,7,6,2,4,3,3,2,5,4,4,5,2,4,4,5,2,7,2,7,3,2,6,4,3,2,5,5,4,3,2,4,7,4,2,7,2,5,3,2,6,4,6,2,7,3,7,6,1,6,5,5,1,6,4,6,5,2,4,0,0,0,0,0,0,0,0,0,3,3,2,3,5,6,6,4,2,7,1,3,3,6,5,7,4,3,5,4,1,5,5,6,6,4,2,6,4,2,2,6,3,6,6,2,6,4,2,5,3,6,3,3,2,6,3,2,3,5,2,4,6,3,6,2,2,4,3,5,3,6,3,7,5,1,7,4,7,7,3,2,5,5,2,3,6,7,7,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,31,27,30,29,26,23,19,22,25,28,24,21,18,17,20,16,32,36,33,34,37,40,44,41,38,35,39,42,45,46,43,47,63,59,62,61,58,55,51,54,57,60,56,53,50,49,52,48,16,24,17,18,25,32,40,33,26,19,27,34,41,42,35,43,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,20,28,21,22,29,36,44,37,30,23,31,38,45,46,39,47,95,87,94,93,86,79,71,78,85,92,84,77,70,69,76,68,63,59,62,61,58,55,51,54,57,60,56,53,50,49,52,48,91,83,90,89,82,75,67,74,81,88,80,73,66,65,72,64,112,120,113,114,121,128,136,129,122,115,123,130,137,138,131,139,96,100,97,98,101,104,108,105,102,99,103,106,109,110,107,111,116,124,117,118,125,132,140,133,126,119,127,134,141,142,135,143,191,183,190,189,182,175,167,174,181,188,180,173,166,165,172,164,159,155,158,157,154,151,147,150,153,156,152,149,146,145,148,144,187,179,186,185,178,171,163,170,177,184,176,169,162,161,168,160,248,203,28,0,0,201,35,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,200,115,35,0,152,25,35,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,216,213,34,0,24,154,34,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,120,31,0,108,0,0,0,120,143,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,247,32,0,232,225,31,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,48,247,32,0,0,22,31,0,232,225,31,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,48,247,32,0,96,103,30,0,136,224,29,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,48,247,32,0,248,115,29,0,160,29,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,48,247,32,0,32,204,28,0,64,201,35,0,16,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,64,116,35,0,64,201,35,0,16,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,224,25,35,0,104,214,34,0,12,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,184,154,34,0,104,214,34,0,12,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,248,93,34,0,248,38,34,0,32,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,247,33,0,248,38,34,0,32,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,32,206,33,0,32,167,33,0,24,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,184,137,33,0,32,167,33,0,24,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,160,95,33,0,240,33,33,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,64,8,0,1,0,160,95,33,0,120,255,32,0,240,33,33,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,64,8,0,1,0,160,95,33,0,88,229,32,0,240,201,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,48,176,32,0,136,153,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,136,129,32,0,48,103,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,184,82,32,0,248,49,32,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,136,255,31,0,176,233,31,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,48,214,31,0,96,195,31,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,200,172,31,0,24,155,31,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,232,137,31,0,16,121,31,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,168,106,31,0,144,78,31,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,56,40,31,0,72,26,31,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,160,95,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,130,31,0,108,0,0,0,104,144,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,204,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,2,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,22,31,0,104,104,30,0,52,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,72,34,33,0,128,255,32,0,56,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,8,155,34,0,128,255,32,0,56,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,104,229,32,0,16,202,32,0,4,0,0,0,5,0,0,0,80,176,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,8,0,1,0,0,0,0,0,96,206,33,0,16,202,32,0,4,0,0,0,5,0,0,0,80,176,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,8,0,1,0,0,0,0,0,16,154,32,0,168,129,32,0,64,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,80,103,32,0,168,129,32,0,64,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,120,225,29,0,144,116,29,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,72,30,29,0,144,116,29,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,149,31,0,108,0,0,0,192,149,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,255,255,255,255,104,204,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,22,31,0,104,104,30,0,52,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,120,225,29,0,144,116,29,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,72,30,29,0,144,116,29,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,204,28,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,167,33,0,0,0,0,0,14,0,0,0,0,0,0,0,184,248,32,0,108,0,0,0,80,152,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,137,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,10,0,0,24,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,201,35,0,144,116,35,0,4,0,0,0,4,0,0,0,51,51,51,51,51,51,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,56,26,35,0,168,214,34,0,8,0,0,0,4,0,0,0,51,51,51,51,51,51,211,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,216,154,34,0,32,94,34,0,12,0,0,0,5,0,0,0,64,39,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,24,247,33,0,48,206,33,0,16,0,0,0,5,0,0,0,56,167,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,137,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,135,31,0,108,0,0,0,64,154,27,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,240,35,0,108,0,0,0,64,138,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,38,198,245,187,251,17,251,69,43,196,244,45,249,204,254,7,41,198,251,110,250,113,251,121,36,157,246,41,250,18,1,202,41,31,246,236,253,158,251,128,40,122,240,16,251,18,253,86,39,173,241,90,1,95,3,38,40,235,243,55,1,192,253,166,38,206,250,108,250,164,252,48,41,125,248,222,251,53,252,244,42,160,249,183,252,132,250,56,46,119,242,122,6,58,248,100,42,80,253,158,245,13,254,50,41,43,249,109,255,59,249,49,42,20,252,60,253,83,250,92,41,71,254,191,247,72,252,157,39,253,242,186,253,104,250,136,37,226,245,127,1,2,1,158,44,63,243,229,0,248,249,220,40,198,250,55,253,224,249,66,40,71,249,132,249,165,253,108,37,236,248,45,251,219,251,207,44,19,247,175,249,161,253,97,39,79,247,128,250,156,252,219,41,192,245,169,250,64,253,120,41,177,248,46,245,221,255,136,36,220,246,0,252,226,249,57,43,78,250,122,248,33,253,70,44,248,247,239,251,136,251,97,38,0,248,230,252,0,250,74,46,121,245,157,251,157,252,158,41,78,247,157,248,139,254,40,39,235,249,216,252,211,251,134,43,14,251,90,243,128,0,209,45,46,243,254,253,13,252,138,44,210,247,225,246,67,255,211,39,182,241,181,0,173,248,167,44,190,245,108,254,159,250,249,42,228,240,149,253,203,251,142,42,1,246,18,1,34,249,161,37,54,250,51,247,251,252,237,43,7,243,62,3,76,248,40,38,115,245,57,255,189,248,4,41,6,248,13,2,5,248,149,45,27,240,37,1,68,250,232,35,57,248,185,253,195,255,73,39,108,243,33,248,39,254,25,37,245,246,70,246,45,254,215,40,3,244,86,251,17,252,10,39,112,248,196,255,55,251,79,36,148,247,31,249,146,251,101,39,92,241,254,251,197,0,118,36,200,246,36,3,161,254,41,45,7,246,72,5,247,246,37,50,98,240,171,4,90,248,130,39,180,251,146,246,118,254,125,36,30,246,59,1,243,2,147,39,164,243,131,5,94,253,63,37,119,252,241,249,67,2,197,45,17,250,21,244,91,0,96,38,161,244,41,245,192,0,190,37,138,244,207,253,170,5,77,43,192,242,238,250,109,253,251,34,202,247,149,248,191,2,159,33,50,249,4,239,46,3,216,29,241,247,223,241,52,0,162,27,198,252,27,239,23,17,34,30,72,2,114,239,135,7,211,24,72,252,208,236,55,12,157,27,108,253,243,230,247,15,121,32,124,255,108,244,148,252,40,27,114,250,134,240,232,255,83,36,34,253,240,243,249,254,12,37,194,253,95,238,210,1,78,28,165,255,105,241,64,253,133,32,119,250,238,243,238,253,69,25,54,251,107,237,61,3,252,25,144,254,206,233,113,5,35,31,2,251,20,247,181,4,61,28,69,253,28,242,48,7,58,31,4,5,87,245,220,2,45,35,70,253,86,238,141,8,51,27,197,0,89,245,124,1,79,33,135,0,105,240,43,255,136,34,166,3,58,244,201,253,141,39,162,1,44,243,141,254,223,24,105,1,242,246,250,9,212,30,172,0,129,235,65,18,18,26,131,1,208,234,46,17,96,24,172,2,49,240,195,4,162,43,230,252,39,236,171,4,245,45,120,253,135,231,4,8,93,42,249,252,3,241,110,1,208,48,79,253,188,223,234,13,213,30,114,251,148,236,220,3,144,33,28,4,158,232,15,12,109,28,82,7,203,233,251,13,244,26,224,7,55,237,163,13,82,33,155,246,78,243,194,7,210,36,238,1,101,228,174,19,45,40,52,2,238,223,250,20,45,34,97,247,116,240,36,11,181,37,130,245,52,239,120,5,42,38,18,247,225,233,137,16,42,33,252,255,120,228,144,17,17,30,71,251,48,235,111,12,51,25,33,3,28,239,214,253,219,28,14,7,111,235,33,2,26,29,2,247,163,238,138,5,113,34,166,250,61,233,120,8,84,40,154,246,3,234,19,10,159,34,238,245,47,242,211,1,245,26,168,249,159,243,64,13,166,30,156,0,220,228,53,13,248,30,165,251,172,232,208,18,201,23,169,253,240,238,192,254,153,30,222,4,136,240,147,253,227,34,217,9,144,229,4,8,196,34,152,7,226,239,40,0,237,29,222,255,217,244,176,9,241,22,218,1,66,243,128,14,111,29,22,255,165,237,216,0,224,22,143,0,234,235,73,0,240,34,150,255,14,233,79,14,222,27,170,1,9,233,79,11,215,39,243,3,102,237,113,1,6,33,8,1,173,232,11,5,142,30,111,246,19,239,188,17,56,24,58,245,184,245,217,5,182,23,37,239,117,245,158,1,135,27,101,241,118,243,36,4,43,22,39,241,99,245,105,254,181,18,33,240,188,245,24,253,183,15,218,242,195,243,42,253,200,16,153,246,203,242,255,253,36,17,141,244,252,244,232,5,207,17,119,239,107,248,184,7,46,26,120,243,37,249,144,6,64,17,63,242,228,251,168,11,242,27,86,239,77,251,148,14,41,14,110,239,84,243,115,5,118,25,216,244,232,250,71,11,26,24,99,248,58,244,133,15,69,20,109,246,76,240,149,13,74,24,84,244,127,248,4,15,219,18,152,241,120,248,15,13,12,26,105,240,11,245,23,12,177,20,213,243,156,241,86,9,234,20,250,237,154,245,224,5,100,16,237,243,205,239,111,4,212,13,179,244,89,240,100,0,193,21,190,249,89,240,117,7,245,16,213,247,80,239,252,0,183,21,194,244,8,241,242,1,196,17,129,238,174,244,229,255,56,20,66,246,229,237,196,5,222,12,99,242,102,241,204,2,56,19,51,251,157,239,147,254,185,12,66,242,235,242,46,11,166,20,100,248,99,242,246,252,102,25,21,244,104,255,38,11,232,22,160,239,204,251,123,13,48,18,206,243,136,242,179,0,19,23,14,253,196,249,44,12,61,28,160,241,202,249,76,11,243,19,208,240,220,242,38,3,108,26,181,245,134,242,134,0,138,20,245,244,228,244,228,251,166,22,67,249,47,239,205,0,28,21,67,251,222,242,193,1,80,24,78,245,26,244,187,253,127,16,122,246,91,245,161,14,143,18,173,242,181,247,116,0,28,15,72,244,142,240,249,8,163,26,173,244,75,239,9,11,111,16,110,237,8,245,97,3,196,18,42,250,51,248,80,18,162,20,91,247,220,253,231,13,204,21,136,248,202,253,18,17,24,24,215,244,96,253,213,15,183,25,93,238,222,244,134,6,111,25,235,243,108,240,141,5,38,18,2,249,93,250,66,14,27,23,100,252,28,248,128,3,134,30,171,239,176,243,215,7,46,24,66,247,47,237,231,8,129,18,62,240,40,243,43,7,225,31,207,241,161,242,65,12,247,28,209,246,216,247,194,16,10,16,43,246,194,255,89,11,45,19,183,243,154,253,16,16,74,19,47,243,115,254,76,4,83,255,151,3,53,6,13,235,243,255,28,3,217,254,1,230,188,248,195,252,117,4,53,238,250,8,186,252,104,253,115,236,140,252,183,251,26,8,251,237,155,255,25,1,30,11,73,238,142,4,197,1,125,9,234,232,111,3,104,253,66,9,180,234,135,5,142,254,93,249,137,237,123,250,253,4,99,253,7,230,85,8,48,1,56,252,240,237,124,1,74,2,217,247,228,236,56,5,19,1,174,255,99,233,101,246,33,4,222,255,216,234,230,8,34,249,98,3,235,233], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1800824);
/* memory initializer */ allocate([153,7,9,247,107,255,74,235,7,5,59,242,228,3,121,235,249,8,35,3,153,4,77,232,187,0,76,255,149,253,198,231,231,252,23,246,18,6,63,236,113,245,52,255,139,253,35,233,17,252,110,255,57,1,50,234,62,3,101,1,101,3,37,231,28,255,193,253,151,243,175,238,23,252,239,249,114,255,180,233,148,249,147,6,185,6,75,238,125,3,132,7,241,255,97,233,147,8,13,8,250,254,161,234,215,11,14,1,55,1,24,236,120,7,102,6,13,250,187,237,186,243,201,255,253,0,206,236,100,1,112,249,87,1,21,232,63,247,58,249,48,252,205,232,108,247,179,244,35,2,182,236,35,251,126,0,132,248,213,234,7,255,85,241,114,250,38,234,63,2,133,245,122,248,42,238,6,253,93,7,192,0,8,233,213,252,254,245,212,251,131,232,40,247,242,243,48,252,89,237,70,0,65,251,64,11,198,238,202,2,80,241,100,11,173,237,12,255,180,242,204,6,115,238,172,2,239,235,184,254,24,234,239,253,15,241,6,249,73,238,55,253,121,237,162,251,86,234,158,10,52,241,6,7,180,233,153,249,161,241,228,249,49,232,157,6,174,245,147,250,69,238,249,1,219,249,141,249,242,236,189,252,48,247,107,248,24,235,184,5,101,254,201,7,215,230,237,1,144,243,111,255,252,231,123,250,243,1,175,249,177,230,218,254,186,6,117,250,163,233,135,244,8,250,81,255,240,237,174,253,233,232,200,255,254,231,212,254,77,239,132,4,197,232,40,2,173,245,109,10,137,240,137,3,194,239,253,6,79,233,56,5,39,248,60,8,241,232,19,6,240,241,86,4,153,229,242,250,120,242,77,0,60,232,141,251,90,240,10,251,171,239,26,236,32,243,68,4,225,244,129,234,189,244,192,7,237,247,193,237,134,239,119,250,220,239,77,241,22,241,238,4,246,243,244,235,154,242,112,11,40,253,187,232,195,244,227,4,114,246,183,238,241,246,44,255,76,239,199,231,55,248,238,6,122,247,132,234,4,241,153,8,140,250,234,228,226,246,62,9,243,250,20,232,212,239,57,5,71,248,103,230,166,239,220,6,211,250,250,235,22,251,232,2,184,241,209,235,146,250,45,6,177,244,83,238,186,242,125,9,183,248,20,240,145,243,235,7,50,246,209,231,54,243,46,7,234,248,154,238,63,245,163,10,95,251,1,230,67,237,251,0,221,245,68,231,72,247,40,7,217,0,19,233,94,249,134,0,84,1,42,230,235,251,78,8,116,248,5,237,197,247,218,7,125,246,126,231,170,249,248,10,162,250,209,243,119,243,9,2,108,240,212,233,222,247,92,254,105,245,95,228,217,241,184,2,217,246,158,232,128,239,60,2,106,246,12,239,87,238,114,3,45,245,222,231,115,248,23,2,92,250,197,236,189,239,208,6,238,247,246,230,17,250,34,4,133,245,43,236,95,251,88,3,88,247,77,228,116,246,175,2,219,245,92,235,139,247,167,12,31,252,101,237,39,250,197,0,149,243,224,239,162,236,116,254,6,242,66,236,218,240,121,253,144,245,163,228,236,242,143,6,213,249,121,233,7,252,22,10,133,248,99,228,29,245,51,5,234,247,100,234,8,247,194,2,122,244,61,236,41,242,203,252,203,241,17,230,213,248,248,3,72,253,21,234,156,235,74,253,213,242,150,232,13,245,117,11,39,253,196,232,149,253,60,6,140,245,146,234,189,238,153,0,63,243,23,239,144,242,110,6,97,250,13,240,118,240,177,0,15,242,63,239,217,245,200,4,253,243,181,233,75,243,120,7,9,253,50,230,147,242,2,10,197,253,122,235,116,246,1,3,160,254,111,230,174,243,70,2,177,251,48,235,63,247,6,10,17,249,208,227,112,248,2,6,65,248,110,241,109,246,170,1,227,240,10,236,151,250,239,7,111,251,186,230,101,245,13,1,205,243,82,233,80,246,159,255,8,241,157,241,204,236,22,254,22,239,59,231,221,247,99,253,141,255,207,236,17,240,187,252,191,237,54,243,63,246,30,9,164,245,250,250,61,249,246,9,84,241,209,242,147,252,158,3,119,240,35,246,225,247,63,11,191,245,68,235,8,254,39,12,185,249,216,236,204,1,253,15,48,251,55,248,80,6,48,18,135,248,103,242,104,251,47,12,68,247,220,239,34,250,35,9,15,246,18,246,127,4,241,13,10,246,227,238,174,1,75,12,222,247,208,240,99,3,59,15,135,249,211,244,10,5,106,16,69,248,203,240,3,255,59,9,52,245,87,249,176,2,243,14,149,244,81,247,8,9,116,14,180,243,62,248,48,253,157,19,229,252,151,243,242,0,160,7,232,242,194,248,229,5,224,9,25,241,155,243,97,0,155,19,62,253,127,245,111,255,95,5,181,240,26,237,127,254,184,9,133,246,51,238,157,254,67,6,12,244,62,242,40,7,220,12,142,245,71,241,12,3,74,9,112,245,29,239,116,248,86,13,111,251,76,245,134,4,169,10,55,243,193,241,210,0,184,5,180,244,218,246,207,247,233,5,113,241,186,238,38,251,58,12,215,248,228,250,241,251,194,16,173,248,38,249,25,246,226,12,246,246,250,239,70,255,197,15,186,251,16,252,34,6,218,12,171,0,6,243,195,245,231,10,0,250,21,246,219,245,114,13,120,249,173,242,33,248,86,14,106,251,207,247,218,2,205,21,137,250,26,250,182,255,212,18,44,248,10,240,156,252,73,17,253,252,68,252,38,252,56,14,147,244,217,247,30,251,136,13,102,246,20,243,149,246,54,5,173,241,40,247,123,254,164,15,194,248,88,253,239,0,218,15,196,242,179,250,30,0,177,11,182,241,239,241,216,253,153,4,144,251,175,245,186,1,22,17,167,249,35,246,2,3,104,6,201,240,156,243,133,252,53,15,184,249,76,244,13,0,205,12,146,246,125,252,31,4,118,17,59,246,90,254,184,253,147,13,53,241,70,248,175,253,6,10,169,242,178,243,0,251,58,9,25,244,248,241,224,0,2,4,164,240,24,237,91,251,49,14,145,252,144,240,49,247,100,11,222,248,97,249,28,0,18,7,163,254,23,253,76,246,236,12,35,243,8,252,27,6,245,20,225,248,132,247,5,249,170,16,249,250,39,251,97,248,142,15,147,246,39,248,177,245,26,9,104,242,241,19,174,249,228,245,33,248,97,25,13,250,110,243,114,252,126,25,255,246,19,248,2,249,169,20,157,255,148,242,112,254,149,22,169,249,215,249,199,245,139,20,98,253,203,243,92,249,199,24,24,251,181,254,106,243,31,31,90,253,109,247,74,250,231,23,73,253,84,244,254,249,220,23,238,1,225,242,244,249,203,19,201,3,232,246,109,245,171,29,77,254,39,250,248,247,17,27,49,253,140,246,127,249,70,20,72,2,90,244,201,247,218,23,68,254,125,250,77,245,208,21,33,1,244,248,13,245,156,20,227,0,100,251,223,242,120,29,11,250,214,248,67,249,98,23,66,250,210,245,91,249,232,19,3,253,80,249,66,244,47,21,107,255,163,240,123,251,227,29,26,0,115,246,29,250,137,18,48,254,57,249,198,246,232,20,13,252,186,251,49,248,156,24,96,253,226,253,98,248,19,26,4,252,218,250,221,251,50,28,12,248,165,253,98,246,75,30,22,250,130,246,51,251,177,19,193,1,224,251,155,246,54,26,27,247,192,250,20,247,168,26,189,250,50,247,251,0,180,23,191,248,41,252,220,250,227,21,127,247,86,245,59,250,206,22,221,251,236,241,54,252,212,19,235,252,177,254,147,246,47,24,158,249,48,248,175,247,228,19,244,250,17,246,246,251,185,20,179,1,82,249,198,248,252,23,49,2,128,247,180,246,96,26,92,1,64,246,158,248,5,25,17,1,182,251,38,245,30,27,196,250,16,254,155,250,118,20,81,253,106,246,211,246,47,27,142,252,215,248,243,247,148,24,3,255,179,247,105,247,206,22,194,253,9,253,113,243,42,27,52,250,128,253,45,245,74,29,86,249,70,251,150,247,116,26,21,252,45,251,28,246,126,23,228,0,150,247,172,251,31,27,126,247,172,245,158,251,94,28,5,253,16,244,190,251,129,24,58,250,208,251,177,0,126,18,169,1,160,244,101,1,217,27,168,0,255,249,233,246,36,28,78,254,22,253,156,245,223,26,57,0,241,243,226,250,15,18,158,253,50,253,125,242,165,25,225,253,50,248,173,254,144,18,235,254,238,247,131,250,11,29,120,250,144,248,7,254,236,15,150,0,58,251,28,242,170,27,228,255,80,250,106,251,53,23,66,254,210,250,122,251,30,15,144,249,86,246,227,245,90,3,37,0,197,242,119,241,229,13,33,250,128,249,201,242,8,13,76,248,249,243,88,247,114,12,60,0,167,239,161,252,128,13,251,252,6,244,103,246,35,16,111,252,244,247,215,245,79,17,77,253,238,239,52,252,133,13,178,254,160,241,41,249,214,7,53,254,90,247,13,241,42,5,32,0,0,245,125,243,73,17,151,248,25,245,102,248,152,17,23,0,163,242,139,248,18,12,139,252,194,246,64,243,137,12,197,246,110,241,190,252,240,12,65,250,199,241,213,249,88,16,123,249,5,243,32,251,142,8,93,252,26,243,128,244,131,11,27,255,73,237,85,251,228,7,166,249,116,245,203,243,166,8,186,254,0,239,109,249,214,12,197,245,148,246,102,246,232,3,245,245,223,239,146,247,192,9,189,245,229,241,103,250,251,7,113,247,137,247,13,241,11,10,16,246,133,248,106,243,230,7,35,250,240,240,139,247,125,10,100,251,75,250,58,240,74,6,247,246,217,238,107,251,36,9,70,246,137,239,252,253,206,6,201,245,208,241,158,247,11,2,243,250,106,239,118,246,141,14,93,245,58,244,216,249,226,13,155,250,152,239,200,252,11,5,198,249,87,237,106,250,172,5,3,2,112,244,10,241,168,16,130,252,23,243,222,248,46,10,84,250,86,238,58,252,172,4,194,252,57,237,232,248,30,4,249,252,200,245,25,240,110,16,159,1,8,239,148,251,228,11,235,1,226,239,114,248,220,3,123,252,231,242,141,242,193,6,9,244,37,247,214,242,75,15,144,3,83,244,173,246,197,14,44,1,103,246,22,244,152,10,156,3,186,250,74,251,134,16,149,1,217,246,153,2,86,7,151,252,31,255,227,255,182,13,56,0,202,250,164,242,34,11,167,5,165,245,178,243,230,5,62,253,227,239,77,246,43,12,25,3,100,249,202,240,107,10,213,0,99,244,30,245,160,4,176,246,21,244,155,243,91,8,28,3,225,247,143,241,184,5,53,250,114,241,62,245,103,9,132,251,181,240,223,249,52,10,13,249,111,243,33,247,102,9,202,244,135,244,64,246,92,8,126,0,194,241,58,245,136,11,244,251,12,1,113,250,93,0,117,248,255,240,49,242,133,1,119,244,201,242,241,242,204,33,121,234,130,249,53,2,3,29,25,245,25,246,182,252,93,33,99,239,129,250,36,252,82,31,125,243,74,244,105,0,63,28,170,240,66,252,28,5,163,28,150,241,149,254,26,10,147,26,194,241,78,247,121,252,227,31,5,245,35,254,69,247,140,36,22,241,107,249,84,253,18,33,218,244,210,254,70,253,10,33,104,243,5,2,23,1,138,31,197,245,210,250,36,10,75,34,55,245,33,246,71,254,133,25,185,244,125,252,72,253,226,28,255,246,150,249,136,255,89,32,60,241,234,255,25,5,198,35,195,238,245,252,133,3,71,35,136,235,171,251,142,6,13,34,190,241,154,1,205,251,149,28,131,243,206,252,40,247,254,30,175,246,66,251,162,248,64,32,167,238,221,254,181,253,190,28,189,242,66,4,242,254,230,36,210,236,193,250,39,254,251,31,138,237,216,252,142,4,80,29,251,240,209,255,11,1,93,31,158,247,253,250,129,254,37,29,111,245,171,252,15,3,151,36,204,241,123,253,158,254,251,34,111,242,204,254,101,248,228,33,133,245,205,247,205,5,57,29,69,244,153,252,68,254,79,31,233,244,119,249,151,4,35,27,221,237,9,250,233,251,198,29,241,245,119,255,64,252,172,36,73,239,61,253,214,250,190,32,117,235,253,250,203,253,200,26,214,239,250,251,118,2,211,33,245,245,156,251,126,249,59,34,33,241,231,253,239,9,113,31,6,242,118,247,164,253,80,32,209,246,63,248,66,251,199,26,44,241,9,250,161,249,10,28,176,244,192,249,36,249,128,27,184,244,167,255,206,249,117,24,181,242,248,254,230,3,76,30,165,237,249,249,190,252,2,30,242,237,10,253,71,249,135,34,120,239,140,244,167,7,147,36,185,237,92,248,39,0,203,30,224,241,122,250,104,250,124,34,140,243,180,250,224,250,66,30,109,240,135,255,136,246,46,36,72,243,75,253,50,3,246,29,164,242,108,255,176,13,176,28,145,243,96,2,59,6,16,35,213,239,200,248,24,5,52,26,221,239,33,0,172,252,160,30,179,238,29,247,79,0,20,35,238,240,234,244,197,1,135,30,4,238,253,245,176,3,180,32,186,238,9,249,255,11,175,33,248,235,38,249,72,11,38,29,47,243,121,3,152,3,224,32,197,255,216,250,223,248,248,30,48,250,98,254,61,246,174,31,47,252,233,251,6,248,86,32,81,253,195,249,242,249,52,31,82,255,47,252,198,247,161,33,245,249,164,249,9,250,40,35,250,248,78,252,31,249,250,34,152,252,132,250,198,249,235,34,210,1,20,253,68,251,77,37,183,254,79,255,176,250,195,36,238,255,154,251,224,249,155,34,242,252,24,254,198,250,251,34,38,255,213,255,71,251,171,35,187,255,59,254,23,252,109,35,17,250,189,251,81,251,31,36,227,250,202,253,134,251,80,33,175,249,225,254,223,250,83,30,23,253,107,255,8,248,102,32,169,254,1,1,183,245,165,39,131,252,216,253,143,249,182,36,109,252,218,0,6,248,231,37,86,251,93,253,200,249,114,37,68,253,85,254,82,249,226,34,241,1,91,250,62,251,69,36,213,250,93,255,240,249,239,32,247,250,39,252,132,250,5,35,113,253,141,2,53,250,70,37,23,252,73,252,152,251,245,35,121,253,219,255,142,252,155,33,200,255,2,2,255,248,84,36,244,255,212,250,201,253,69,34,238,0,72,255,80,250,213,38,230,250,187,255,0,249,144,36,23,1,136,254,129,248,220,35,227,254,95,0,134,247,194,38,11,254,54,252,222,249,149,32,43,250,168,252,212,247,76,34,43,252,174,252,10,252,249,37,220,253,32,250,186,251,245,38,43,250,226,1,199,247,3,34,179,254,253,251,193,251,138,35,43,254,197,254,69,249,175,34,230,251,107,253,28,248,153,34,90,2,158,252,130,248,241,34,255,251,150,247,209,251,36,33,118,248,44,254,125,247,217,35,145,248,32,255,192,247,204,33,119,255,207,247,66,251,103,35,51,252,131,250,252,252,112,36,56,254,150,2,91,246,117,39,71,253,127,0,191,247,213,37,43,3,201,246,0,252,138,33,162,255,52,254,66,248,244,30,115,255,3,254,47,246,93,30,99,253,149,255,237,244,188,33,216,251,210,255,151,246,20,38,84,2,233,248,187,250,220,34,48,1,35,2,202,245,226,36,234,2,127,251,113,249,238,36,234,254,239,253,72,248,40,33,49,2,224,255,144,247,99,39,193,255,248,249,172,250,174,36,2,251,56,2,149,251,12,38,207,255,51,247,114,252,52,14,169,246,165,251,226,241,126,23,124,243,146,248,240,248,155,22,87,242,164,251,226,245,13,17,26,244,160,249,148,245,125,18,112,247,19,248,92,246,36,21,63,245,159,249,96,246,103,17,209,242,1,253,185,242,104,17,148,249,41,252,231,244,199,15,37,246,38,0,129,240,78,13,154,245,72,0,107,237,183,16,43,248,31,4,209,238,225,16,159,250,164,252,54,241,159,14,149,233,117,253,25,244,200,13,122,234,105,1,36,240,96,25,234,236,120,255,127,245,161,17,122,235,39,2,86,240,157,25,171,242,164,255,9,244,90,16,245,247,187,0,47,0,66,24,235,239,24,251,63,248,150,23,9,239,95,1,180,247,209,16,84,237,227,247,151,248,128,17,25,241,76,247,3,250,206,21,151,241,197,4,155,242,156,21,246,236,171,4,51,245,118,25,219,244,119,252,248,245,91,21,112,247,214,1,237,239,43,16,215,249,240,0,91,242,161,20,122,248,39,253,244,242,94,20,202,244,79,5,63,239,230,11,74,242,0,250,114,243,57,21,191,244,50,251,96,251,253,18,164,240,209,251,25,245,61,22,118,239,142,248,34,250,164,15,161,240,244,248,177,246,144,14,48,241,169,2,91,237,37,14,42,244,97,248,218,245,13,20,193,240,44,0,140,241,233,13,133,242,159,4,75,235,162,19,54,245,219,246,12,249,209,22,68,246,45,254,118,243,215,21,1,249,241,1,88,246,190,19,198,240,226,248,207,247,181,22,24,245,83,0,67,250,80,17,111,238,134,6,183,235,218,20,211,237,171,251,104,247,167,12,207,238,120,253,185,241,99,8,242,241,80,251,110,239,65,17,33,247,240,249,118,243,94,25,248,238,84,3,19,242,89,9,42,231,168,252,84,238,95,19,156,239,177,252,133,250,60,19,194,234,30,255,46,244,158,16,73,235,230,250,136,246,25,16,202,243,226,246,67,248,109,13,165,238,72,250,119,244,131,12,125,242,239,253,13,239,8,23,199,232,31,2,82,243,195,7,131,237,36,255,1,237,6,17,177,238,254,253,247,243,231,17,144,246,20,254,17,247,127,11,85,236,163,1,193,236,238,20,247,235,219,3,43,239,108,17,192,242,216,6,254,233,87,13,231,237,227,5,199,232,43,3,172,237,67,254,29,9,241,3,19,234,191,248,80,5,58,5,104,245,96,245,220,11,234,3,86,241,234,245,40,9,238,2,0,238,226,246,202,2,251,7,121,243,250,244,125,8,116,255,210,237,119,244,101,1,202,255,70,240,184,246,135,10,66,7,98,236,51,253,239,8,16,8,202,240,46,253,183,12,167,10,50,238,180,254,43,10,18,7,254,234,27,1,34,7,95,15,26,239,250,2,55,13,1,253,167,237,50,246,130,7,98,8,40,239,238,243,105,6,54,0,7,233,190,247,153,3,200,7,122,233,128,253,38,6,176,4,5,235,166,251,36,7,157,11,39,235,34,0,218,8,251,5,102,236,255,244,168,4,6,12,38,238,117,0,198,7,156,3,66,239,148,250,153,10,142,0,62,236,224,244,207,5,150,255,220,231,143,252,74,3,161,2,199,234,27,255,60,6,15,3,178,233,32,245,50,2,143,7,159,233,39,248,88,3,102,254,209,242,2,243,174,10,234,0,72,244,188,245,188,12,221,2,179,242,34,241,53,6,3,3,67,239,40,242,34,5,168,4,21,242,136,240,130,8,206,0,77,234,30,251,10,6,126,255,25,241,70,251,225,11,134,2,156,240,119,254,176,11,72,255,189,236,25,249,133,7,186,10,0,236,29,247,184,5,136,9,109,241,232,242,169,10,22,254,178,236,61,241,229,3,68,0,180,245,185,239,194,14,48,0,110,240,234,239,58,8,46,252,146,234,200,250,110,5,102,4,79,235,169,252,128,2,40,254,121,240,218,241,21,6,152,9,32,235,13,250,112,6,250,252,236,233,143,246,123,4,227,3,22,232,212,252,108,4,210,12,37,238,29,249,127,8,71,14,234,240,92,253,240,13,222,11,193,241,120,249,53,13,35,10,108,244,44,245,191,12,80,16,231,242,132,251,2,17,67,6,142,242,36,250,116,13,60,3,174,231,9,249,166,2,141,5,251,242,248,243,75,13,97,4,137,237,124,248,192,7,70,255,37,236,86,253,4,7,51,3,38,245,96,242,18,2,165,1,199,244,8,241,36,10,116,8,89,239,187,249,234,8,73,2,171,238,86,253,21,254,124,253,156,238,123,251,21,9,199,7,53,239,210,0,18,11,87,8,208,241,191,247,153,2,198,226,92,245,154,245,156,250,185,228,138,247,84,241,75,242,83,228,97,250,163,246,216,243,176,225,23,244,9,243,250,244,35,223,56,245,202,238,30,243,149,232,153,240,20,251,90,241,57,225,238,249,120,242,210,245,86,231,14,248,218,240,111,249,111,221,220,247,137,250,49,251,15,228,214,245,152,250,207,252,151,224,245,245,105,254,31,245,178,227,71,247,214,249,4,1,88,227,213,240,35,240,194,250,61,226,188,240,218,246,126,1,20,222,116,241,130,249,41,253,86,225,150,244,22,249,135,242,146,229,14,248,243,250,60,248,17,229,188,247,56,252,96,241,32,228,229,235,198,245,7,245,224,223,116,241,41,246,203,249,201,229,66,245,51,244,37,255,133,224,154,249,178,251,153,243,250,221,25,237,133,240,185,243,109,219,155,236,71,243,22,252,45,232,41,249,171,243,117,254,203,230,112,243,11,238,29,254,57,225,155,234,185,252,178,245,222,227,58,240,242,253,216,244,170,224,52,251,138,248,146,249,99,220,143,250,210,249,25,246,121,220,123,245,132,253,211,245,140,220,236,245,103,242,41,246,121,223,5,237,138,246,83,0,80,223,175,247,236,246,131,247,150,222,45,238,254,240,41,248,34,215,91,239,114,248,220,247,11,218,141,243,10,247,152,248,103,218,207,240,52,244,104,243,127,217,165,236,113,239,120,247,232,217,209,246,27,247,199,243,205,227,234,250,177,245,189,249,203,226,248,238,122,241,209,253,208,233,15,248,234,246,250,243,50,216,84,234,221,237,239,241,41,219,231,239,145,252,81,246,83,223,182,234,28,248,97,250,111,231,198,235,187,249,251,240,129,223,230,240,81,253,24,245,61,224,249,251,232,241,149,240,242,214,0,246,81,251,222,247,249,212,200,241,68,245,31,244,198,221,98,236,145,235,118,251,87,216,101,245,216,237,5,237,6,225,171,235,148,248,240,241,167,218,36,242,52,237,118,241,17,226,155,237,100,251,61,250,143,220,181,233,233,248,92,244,102,222,197,246,141,245,70,241,17,217,18,234,9,242,2,241,124,223,19,252,173,247,74,243,165,215,151,233,10,246,132,244,214,223,230,242,223,242,129,238,52,224,97,248,82,238,63,238,233,229,154,245,20,247,170,239,158,251,22,250,229,230,44,255,54,0,132,249,208,234,132,250,254,0,38,245,154,235,78,3,245,254,131,249,79,230,46,3,207,254,27,248,129,233,204,5,1,249,114,246,45,229,170,255,143,244,170,243,53,230,249,248,145,250,139,243,75,234,227,251,190,249,140,252,145,229,67,251,151,254,194,254,181,231,212,255,18,240,181,245,109,234,79,254,68,252,222,1,226,238,190,5,28,243,98,246,123,232,95,245,196,2,126,246,35,236,228,253,125,246,233,241,241,233,194,247,21,254,146,251,183,237,186,244,87,0,149,242,223,237,86,251,182,253,145,244,80,237,110,1,142,250,234,246,123,232,94,1,97,0,41,246,186,237,184,247,245,249,141,248,51,236,79,244,12,1,116,241,145,237,127,0,197,252,90,251,232,232,120,4,137,240,238,246,14,229,74,248,88,245,76,247,230,230,206,253,56,254,102,253,103,233,183,249,19,2,184,251,157,233,112,253,15,242,80,253,181,240,110,0,112,237,67,249,215,238,135,254,118,243,13,243,208,228,184,252,80,253,168,242,149,236,197,4,215,248,77,0,165,230,126,246,17,255,1,255,62,229,138,252,192,247,46,250,109,231,127,245,248,249,29,238,178,235,19,251,45,245,82,240,112,234,171,2,157,249,243,244,120,234,190,4,66,252,234,245,41,237,56,9,227,247,42,238,222,237,109,1,216,243,138,239,184,232,201,252,93,246,50,246,6,237,187,5,231,249,185,242,66,233,211,0,249,252,199,251,184,238,76,10,17,251,25,0,22,231,144,250,108,242,146,254,215,234,143,250,152,243,60,250,203,239,186,5,81,246,6,2,160,238,255,254,80,244,158,0,204,237,1,251,216,250,224,240,129,238,123,4,61,250,200,254,58,235,27,2,57,242,113,249,28,233,111,249,187,242,146,242,39,234,74,7,7,240,121,246,101,237,251,4,20,253,95,238,177,237,208,255,138,247,77,238,173,237,216,244,175,246,171,252,109,232,141,253,86,251,5,240,136,238,85,248,86,253,94,243,12,240,39,244,73,243,105,236,48,235,244,255,247,246,148,242,7,238,101,255,24,245,242,251,221,228,29,248,36,251,10,250,117,233,166,248,185,237,109,241,126,234,27,1,10,244,190,255,26,242,10,253,225,236,93,251,143,18,144,14,80,226,64,245,248,12,5,18,185,233,97,244,104,15,99,10,148,236,23,251,10,255,136,11,131,239,73,246,166,6,199,16,172,244,7,250,154,9,71,19,59,236,151,1,112,9,210,15,237,228,106,242,201,10,165,8,107,232,175,240,120,12,74,7,31,232,213,252,103,9,198,14,10,233,76,249,183,4,150,13,191,232,219,244,159,8,152,10,105,229,105,243,189,10,11,14,56,243,171,243,109,5,204,14,8,235,144,248,188,7,213,19,189,227,138,250,3,12,196,17,99,237,97,242,195,10,236,10,22,226,173,238,134,10,22,10,171,228,70,239,200,1,248,14,69,234,213,243,193,255,129,14,108,239,132,239,170,5,207,10,39,241,110,247,190,0,207,16,174,234,233,239,166,7,226,8,124,227,115,242,186,13,121,12,14,238,237,247,7,3,144,18,195,242,138,249,184,5,36,21,19,237,101,242,196,3,109,13,137,232,254,244,130,6,51,18,251,221,113,236,221,6,215,12,55,233,219,238,1,4,99,12,100,233,12,249,104,15,77,14,178,238,104,252,146,7,145,18,102,228,191,248,239,17,186,17,35,242,255,253,147,5,197,20,163,226,60,251,67,11,233,11,75,226,129,245,82,7,175,10,242,221,61,240,116,10,146,14,202,224,189,240,161,4,47,10,86,232,48,249,21,13,37,20,190,232,53,2,89,12,178,12,178,230,156,253,138,7,223,8,121,230,91,250,254,255,82,6,253,220,201,239,168,4,204,15,197,227,14,242,64,6,138,16,190,237,79,0,83,2,199,11,122,240,174,1,167,10,17,20,77,235,9,0,130,14,171,18,133,229,117,245,248,255,132,9,152,228,135,251,13,5,6,9,213,228,16,243,254,5,9,7,71,240,228,2,58,7,214,15,139,218,124,242,58,16,150,20,204,238,99,251,202,16,53,20,68,227,25,238,238,255,84,10,140,230,45,251,87,17,90,24,131,242,211,254,248,16,112,17,221,237,250,5,243,12,244,16,33,238,3,246,170,14,98,14,197,241,83,242,3,8,181,11,220,234,85,246,253,8,43,6,42,233,3,1,80,5,44,9,118,235,178,250,26,4,70,3,90,234,37,255,233,24,118,22,175,233,120,244,154,3,131,3,255,247,145,251,86,20,9,4,99,249,162,248,227,18,150,255,216,246,80,242,136,16,243,255,85,246,226,246,179,19,102,4,237,252,11,246,40,15,90,8,169,243,219,246,222,18,71,11,12,249,15,252,96,24,13,8,25,239,221,242,2,11,118,3,208,242,73,245,8,16,207,0,78,243,224,237,158,10,218,5,130,254,205,251,30,17,132,13,144,246,184,239,202,13,48,3,36,249,108,245,253,18,110,2,169,248,207,247,36,20,73,11,64,246,142,246,138,14,111,10,99,245,76,243,13,13,152,7,33,240,5,240,234,12,11,1,35,242,32,241,163,14,74,3,181,245,34,2,162,22,102,7,191,248,159,251,31,17,124,15,78,247,138,247,161,13,94,14,92,242,108,253,203,20,39,4,39,244,198,243,30,17,36,7,113,245,143,253,225,24,35,11,136,249,230,244,232,17,240,253,83,237,194,245,38,17,49,8,99,254,3,248,217,19,219,11,30,241,154,245,180,17,71,4,184,243,190,248,95,20,88,7,22,242,253,248,64,19,158,2,64,237,27,250,69,20,67,7,195,251,8,241,73,16,132,3,79,248,58,243,41,11,62,11,85,239,212,239,104,12,13,7,231,235,113,241,196,13,144,4,190,250,172,248,125,21,212,6,122,236,127,244,115,14,82,1,126,242,232,243,78,13,133,253,41,249,119,243,180,13,139,1,53,246,170,0,99,23,193,2,84,241,208,251,15,22,208,13,202,244,97,250,162,19,140,12,183,240,103,243,85,14,96,8,101,241,226,0,115,22,252,2,252,247,204,252,146,20,21,12,114,243,20,241,105,9,87,9,210,238,228,245,173,13,38,255,124,238,29,249,84,16,58,255,216,242,11,250,10,17,122,255,153,246,224,0,41,19,205,13,167,250,135,244,120,18,252,6,16,237,85,249,63,16,83,3,130,242,43,249,185,16,158,12,58,248,243,240,159,13,199,6,211,243,92,0,11,24,235,15,140,245,88,246,238,15,179,253,245,249,36,248,66,10,43,7,77,239,180,253,216,18,213,2,167,253,55,247,152,14,220,13,36,240,195,255,213,20,25,12,49,239,7,0,151,25,238,11,117,236,251,251,154,22,247,12,6,245,40,253,16,21,199,0,48,251,56,255,108,20,49,12,61,10,165,0,145,231,42,1,85,14,25,2,68,229,28,6,62,6,90,251,165,231,219,9,116,8,224,255,18,229,103,5,85,3,195,249,75,232,169,5,97,5,131,249,110,235,108,0,100,10,48,0,204,235,251,253,111,7,121,254,211,233,242,3,208,14,206,0,102,235,245,255,215,4,216,10,143,244,161,10,231,15,149,0,165,227,53,12,156,5,32,254,244,231,60,255,93,5,88,248,115,236,50,12,85,13,9,251,200,235,211,12,244,11,188,255,161,230,190,8,140,10,229,247,183,237,91,0,112,11,64,249,208,235,66,7,72,17,60,3,137,238,88,0,112,10,212,245,58,240,193,10,103,20,133,255,163,229,247,8,141,16,92,254,94,234,73,5,136,18,255,250,255,239,100,18,79,4,52,245,113,237,232,7,163,14,135,248,185,240,120,15,166,9,120,250,90,234,103,2,239,18,182,250,42,235,197,6,216,20,88,0,87,226,167,15,84,9,192,244,57,237,13,4,143,17,111,5,203,233,117,255,133,20,101,6,206,230,253,5,175,4,27,3,117,234,237,4,117,5,21,251,100,239,254,14,234,2,70,0,16,230,92,2,48,6,166,0,148,236,0,12,124,1,25,252,235,234,219,8,158,11,171,6,86,243,240,20,82,20,109,254,179,234,16,11,134,14,61,249,104,237,202,2,54,16,49,252,72,237,61,0,109,11,206,252,23,237,15,0,181,20,65,2,90,240,187,12,145,20,194,7,209,233,212,11,168,14,136,7,99,238,145,14,206,12,133,7,30,231,223,4,243,19,185,6,11,237,55,12,207,12,166,11,45,246,165,15,14,18,156,2,196,231,247,2,146,23,61,1,125,233,210,18,210,253,57,0,55,241,1,11,124,17,80,6,131,240,184,17,65,23,8,8,233,223,155,10,35,17,53,10,217,226,100,3,202,22,64,4,128,237,60,19,73,25,168,252,177,228,76,16,95,19,219,254,214,235,76,0,171,10,181,252,25,232,7,15,173,12,178,4,79,229,104,2,249,9,103,5,11,241,19,15,236,16,51,8,104,242,38,14,62,8,123,10,88,245,150,15,108,3,143,4,38,243,138,13,151,15,173,6,150,246,237,15,241,19,171,3,232,245,184,12,111,18,176,2,226,249,224,11,208,241,239,16,242,4,25,243,164,236,135,12,32,5,10,245,195,237,67,10,103,10,125,246,70,239,124,14,255,8,34,244,72,238,249,8,81,255,234,242,142,235,199,9,117,255,144,252,118,240,232,5,68,4,221,241,89,238,41,18,83,5,105,246,2,236,60,12,169,7,215,249,180,235,51,13,74,255,158,250,236,230,134,17,93,9,55,248,90,236,182,19,12,5,162,251,49,238,13,10,97,252,130,250,83,242,146,14,179,2,190,236,244,238,198,10,239,3,187,240,70,240,23,11,233,249,220,246,83,236,213,15,68,3,221,249,137,237,16,20,86,4,252,241,131,235,239,10,25,252,140,247,166,236,221,5,166,1,133,240,150,232,166,10,182,5,239,244,11,234,39,20,246,7,48,246,129,236,243,8,125,7,177,243,163,234,30,17,108,255,94,244,30,233,191,7,39,3,96,245,155,237,228,13,184,3,45,254,71,246,58,9,178,6,122,239,147,237,140,19,100,251,168,241,230,232,69,14,79,5,219,250,126,234,179,11,12,3,221,251,89,235,105,15,176,9,11,247,247,240,6,17,66,1,22,249,185,240,242,13,252,0,143,243,180,241,8,20,158,0,121,241,9,238,205,12,9,254,89,245,167,241,176,14,28,251,245,242,215,235,33,9,132,1,105,248,55,242,168,8,108,8,248,243,43,239,235,16,16,7,76,250,82,237,236,14,224,1,56,246,186,239,216,13,134,254,225,249,60,234,162,9,94,254,163,244,48,232,114,11,119,0,170,248,181,232,226,13,243,3,71,247,223,230,239,16,167,3,142,244,116,236,242,12,184,250,154,242,102,232,135,13,16,252,156,240,193,237,166,8,128,253,80,236,21,245,175,14,132,5,37,241,193,241,84,17,217,2,253,253,246,241,9,4,56,0,204,239,164,244,211,11,73,11,99,242,246,242,186,8,57,1,67,239,15,241,145,17,207,253,182,245,233,231,196,11,208,255,179,243,36,237,187,13,55,252,133,238,99,233,197,10,229,253,179,239,108,246,251,11,52,2,103,239,199,236,78,5,51,5,183,244,201,243,143,16,235,251,13,250,84,237,22,9,162,251,138,242,188,240,170,21,152,0,194,245,196,228,160,11,81,1,7,245,25,237,5,18,221,255,19,240,128,250,214,18,131,251,123,236,43,252,115,19,112,252,96,231,206,247,57,22,136,252,194,244,241,242,206,18,111,253,174,238,99,246,17,14,57,252,251,236,164,245,104,15,87,0,112,234,176,251,188,23,174,0,249,230,99,1,250,20,71,249,19,233,218,4,145,17,173,251,29,236,167,255,162,15,45,250,194,235,35,4,61,22,201,249,215,236,43,5,74,18,226,247,96,237,50,3,156,15,219,253,164,234,225,254,177,17,161,3,89,234,105,252,143,21,25,245,228,244,129,250,47,22,39,243,122,240,67,255,130,25,37,242,94,240,124,252,127,27,213,242,9,237,89,244,43,28,149,254,29,237,210,252,103,25,152,255,14,236,174,246,240,26,41,3,201,236,77,3,140,17,96,1,35,230,50,248,69,28,146,249,121,239,204,242,107,24,215,1,31,238,140,248,147,27,84,0,162,233,172,254,202,24,221,252,135,231,25,247,202,22,209,255,231,237,4,250,166,20,44,249,147,248,59,245,44,24,59,254,169,242,25,251,5,25,5,248,43,231,150,3,205,21,135,255,221,233,48,7,216,20,203,252,86,236,85,246,128,19,223,248,224,243,147,246,230,21,3,249,54,239,132,0,8,20,171,246,166,238,223,0,0,25,163,245,122,237,95,253,148,19,168,2,26,238,135,249,224,25,163,254,244,241,13,253,145,24,188,248,118,240,196,253,238,26,102,248,169,235,139,251,148,18,151,245,46,234,207,251,173,16,81,254,66,240,186,0,129,22,148,3,20,233,141,248,228,18,249,3,14,236,61,252,35,13,32,251,52,231,66,243,166,18,230,248,30,233,79,3,228,14,22,246,50,239,57,251,15,23,80,5,153,234,186,251,11,27,36,251,179,246,11,1,132,24,59,253,226,244,99,255,208,22,100,4,86,239,121,3,134,12,114,252,71,235,56,249,16,13,70,2,26,237,203,246,44,22,121,245,123,231,132,248,245,26,38,252,235,234,10,244,140,23,73,253,201,233,44,7,238,13,179,250,150,235,128,247,74,19,134,2,224,240,105,247,239,11,48,255,20,232,20,255,216,11,203,252,51,235,107,240,109,28,203,253,197,240,173,253,10,17,74,0,169,232,172,2,242,22,183,252,184,238,85,245,161,24,171,246,167,234,113,233,45,5,200,255,32,246,139,228,234,253,158,248,50,243,90,233,241,255,82,245,94,247,128,234,82,251,159,254,181,241,41,236,192,3,130,252,16,239,71,232,220,255,123,255,58,244,106,233,253,254,255,251,110,240,69,229,238,4,217,252,153,249,113,235,106,252,38,243,189,253,24,237,205,1,146,247,235,253,130,232,206,255,148,253,248,1,45,233,241,0,177,250,230,254,246,232,65,2,1,3,57,243,79,229,78,252,46,254,237,242,118,232,179,5,0,254,39,253,63,227,235,2,124,254,170,251,9,231,94,8,120,251,47,246,173,228,48,1,242,1,143,245,155,229,167,2,126,254,79,254,154,235,152,6,187,251,248,251,101,236,63,2,184,0,213,241,115,239,116,2,77,242,37,251,201,226,56,254,70,249,50,250,192,230,201,2,7,251,127,251,145,231,146,6,162,253,233,241,135,228,217,5,185,255,93,248,218,229,20,6,71,249,114,243,30,232,156,254,45,3,241,245,68,235,120,2,197,248,156,249,146,233,113,252,59,249,127,1,61,232,125,254,247,246,145,252,121,230,238,253,31,250,221,247,224,236,199,4,66,245,232,248,8,231,49,254,81,243,211,247,3,235,240,4,110,245,30,244,202,240,146,250,4,252,133,252,221,231,144,4,82,248,126,248,214,235,132,6,175,249,132,248,203,230,152,3,111,251,128,246,14,232,213,7,232,253,17,250,104,230,158,255,250,253,110,248,152,226,99,1,179,251,20,249,143,233,98,2,9,255,176,250,165,228,177,0,240,247,90,248,212,228,198,253,84,247,127,239,106,225,23,3,142,250,42,245,46,226,224,1,157,243,128,239,23,225,130,4,162,254,179,246,57,236,168,6,244,248,95,244,233,236,244,253,113,245,188,0,81,234,150,1,172,249,9,244,59,228,62,5,125,1,51,244,66,229,119,2,54,254,186,242,2,238,163,253,11,0,166,240,58,224,31,255,54,249,168,245,125,228,146,1,82,245,13,244,7,227,33,7,15,246,219,238,197,228,20,255,249,251,103,253,136,233,63,8,160,249,32,241,20,226,178,255,144,253,193,243,42,231,107,2,97,248,185,240,58,224,152,1,113,248,145,241,65,231,119,7,192,246,103,238,52,228,115,8,168,254,63,245,53,9,136,17,172,8,206,233,105,5,134,12,252,8,71,235,139,5,253,9,83,20,68,242,6,1,219,16,80,15,201,248,244,12,115,12,76,6,23,234,193,6,46,9,137,6,76,232,67,6,238,23,187,5,233,244,197,250,244,12,107,14,54,242,205,253,10,18,108,12,60,238,207,1,16,18,39,12,18,234,222,4,79,21,28,13,168,233,224,1,101,8,46,21,179,244,232,6,219,18,145,3,53,234,107,255,5,21,14,17,31,243,217,3,88,14,84,10,164,255,254,254,95,11,185,22,91,247,100,13,217,12,23,13,43,242,102,253,223,12,119,18,203,244,35,0,241,25,64,16,44,240,111,2,131,26,84,12,48,238,94,10,8,17,68,18,232,237,106,5,126,20,226,18,111,238,160,13,222,17,16,15,198,232,127,1,129,17,72,16,242,239,217,6,68,14,192,16,2,243,64,5,41,19,204,9,204,237,44,6,10,16,32,12,80,247,235,7,174,19,147,6,238,249,190,1,115,14,240,22,59,244,29,18,247,15,250,13,102,236,69,10,232,13,211,20,220,236,247,5,18,26,219,9,221,239,99,250,244,10,224,9,144,238,27,255,27,13,224,7,95,234,82,14,90,13,22,17,27,238,168,4,215,14,155,3,60,230,248,7,140,11,192,1,54,235,164,9,136,22,189,15,19,233,110,13,116,25,201,13,245,229,177,10,119,21,168,2,97,234,56,15,95,22,9,7,162,236,124,19,93,19,8,14,138,230,226,253,64,17,162,22,29,245,40,16,2,17,16,8,168,237,251,11,48,23,183,4,188,242,229,10,102,19,101,9,242,240,195,6,198,12,179,12,217,251,231,6,161,21,36,8,211,246,209,1,44,12,180,17,187,252,219,5,67,10,2,18,92,247,122,0,23,12,58,14,32,242,238,9,50,11,145,10,254,230,62,12,227,16,186,2,79,237,219,2,67,7,40,12,134,235,249,9,164,11,169,12,18,237,49,5,190,20,71,6,32,230,164,9,66,7,148,13,246,251,84,255,132,19,208,7,70,234,61,10,124,16,38,6,198,242,179,254,40,7,34,13,235,239,121,8,106,26,249,11,175,231,28,11,152,21,151,12,99,237,14,2,55,20,108,6,85,239,106,11,74,17,110,9,206,245,196,1,119,5,92,238,180,245,56,11,184,6,197,237,101,250,255,4,190,2,208,234,64,248,139,8,102,3,99,236,195,250,71,2,112,255,236,237,96,246,3,0,189,8,92,235,245,244,237,255,237,3,172,234,229,248,81,11,36,8,3,233,253,253,112,254,42,13,105,234,125,244,225,5,33,10,114,234,246,248,61,5,182,17,26,236,149,248,169,12,86,14,139,234,28,251,249,250,153,3,150,232,117,249,115,2,152,1,4,230,148,254,252,254,103,4,15,237,81,243,115,1,72,13,168,232,19,247,253,5,30,6,27,231,158,253,158,9,178,16,216,231,26,251,246,6,35,13,178,231,155,250,60,2,42,18,215,233,62,245,114,10,86,13,148,238,150,247,30,14,236,14,29,229,114,254,112,4,255,255,121,234,168,251,19,249,113,4,241,233,183,246,15,253,56,8,59,232,251,245,52,255,209,11,133,237,118,250,50,250,158,5,228,238,40,255,46,1,90,3,102,233,248,254,158,13,215,5,142,235,241,252,120,3,23,9,161,242,120,241,253,254,4,3,60,230,225,250,83,251,25,8,202,235,222,248,220,5,142,13,146,238,171,245,0,12,168,7,51,243,40,247,49,7,184,3,28,239,220,246,202,7,152,8,156,240,149,244,10,249,163,6,197,237,205,251,72,250,90,11,116,242,137,254,110,1,76,9,93,241,187,5,223,253,109,6,245,237,120,1,188,6,46,9,186,246,72,242,112,12,68,10,76,244,53,243,222,2,218,7,161,231,57,250,12,2,172,14,112,238,65,243,212,5,242,13,90,242,240,241,92,252,106,2,243,234,178,244,123,255,113,8,13,240,61,243,18,3,6,3,49,243,109,241,54,4,35,3,253,240,65,244,180,254,77,13,237,242,40,0,239,255,6,0,91,240,150,241,67,255,20,17,120,238,255,245,62,254,6,15,50,241,166,250,106,1,164,8,104,235,241,255,7,250,23,3,110,229,8,247,97,8,145,16,134,238,120,1,21,7,122,9,140,244,90,245,226,253,205,17,188,243,200,251,168,4,200,14,237,238,236,255,224,10,68,20,1,231,142,250,175,1,209,17,167,241,138,250,102,5,24,12,13,240,229,4,185,4,128,16,142,244,220,5,238,10,124,10,236,229,162,253,164,246,230,5,251,234,103,245,191,245,238,9,64,240,192,244,49,251,127,15,254,239,186,244,143,250,70,9,234,240,83,238,65,246,129,6,155,249,187,234,242,240,223,6,42,249,176,236,187,246,132,6,216,244,149,231,148,245,189,7,138,252,51,238,145,244,75,17,133,242,228,231,123,248,36,10,168,237,33,246,126,243,31,11,168,240,248,232,252,242,129,6,95,236,172,242,116,243,43,12,197,239,34,240,11,252,133,12,243,235,89,241,26,248,243,17,149,240,21,234,28,242,219,6,125,241,4,247,8,249,18,16,93,245,19,249,254,241,241,15,83,245,178,236,184,249,101,14,198,239,35,238,216,242,202,15,156,238,173,231,129,250,41,15,159,233,121,241,65,245,209,12,43,236,121,236,49,241,106,9,214,236,88,235,38,253,255,8,135,239,85,241,236,248,7,9,140,234,131,241,158,253,240,16,181,240,57,241,231,244,241,16,74,239,178,238,130,249,58,18,203,237,132,240,179,253,89,20,197,236,158,241,197,239,186,8,20,240,134,239,145,240,210,10,151,245,11,245,2,247,156,12,123,241,140,248,199,243,21,17,40,247,221,244,65,254,83,5,6,242,29,239,168,245,141,16,169,243,1,244,24,240,169,12,43,242,3,238,101,238,130,13,221,246,2,241,146,249,229,3,194,236,126,240,47,244,78,6,156,240,38,251,199,250,220,6,165,243,103,234,125,243,73,7,46,243,254,238,146,249,70,8,101,247,126,232,174,0,79,7,109,245,225,237,209,245,205,5,86,237,114,237,105,247,151,15,194,243,241,236,110,244,251,12,0,245,141,246,90,235,191,9,60,238,237,234,6,245,126,14,30,247,141,239,182,254,190,11,79,244,186,237,93,251,107,9,73,245,180,235,104,253,193,15,227,243,247,233,78,250,18,14,0,245,5,235,236,239,59,19,7,243,2,234,187,239,224,9,224,245,66,237,57,245,8,12,227,246,169,233,219,235,195,11,106,234,52,231,233,243,78,8,7,233,118,239,231,238,9,15,240,241,45,232,54,248,83,19,141,235,111,237,213,251,88,2,70,243,243,235,128,236,230,12,96,247,69,236,207,242,165,11,137,249,49,237,3,243,142,9,5,249,28,232,219,246,177,10,88,243,53,231,46,247,108,241,126,14,45,251,234,249,247,240,134,10,60,244,169,253,27,237,234,11,121,244,58,247,199,234,238,10,138,248,49,247,131,236,188,12,14,1,46,244,23,235,133,10,244,251,129,251,47,232,73,4,58,241,193,242,132,232,82,8,233,250,222,244,186,238,47,13,32,254,142,251,61,241,211,5,190,239,217,253,204,240,203,14,222,247,107,243,164,241,72,12,78,251,49,244,180,235,90,10,93,2,36,249,159,233,86,10,65,1,123,245,199,238,238,1,67,237], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1811064);
/* memory initializer */ allocate([135,248,35,238,44,13,62,249,3,251,236,241,221,15,31,252,92,254,127,236,71,5,68,237,20,244,43,235,155,5,38,251,166,253,86,236,29,15,139,251,124,246,184,237,129,6,53,244,159,245,182,241,179,5,193,242,60,251,154,231,189,10,243,253,2,241,20,237,217,8,57,249,33,251,209,233,28,13,119,250,107,252,184,234,14,13,105,0,36,249,73,229,228,8,210,246,100,254,170,235,228,6,45,242,97,250,253,228,162,5,90,241,155,250,169,238,23,15,230,254,102,242,167,236,166,10,176,254,160,250,213,232,178,6,61,248,76,249,203,238,48,10,105,0,202,249,185,235,92,10,112,245,155,247,214,230,149,9,17,251,158,242,8,241,30,9,219,248,69,245,196,232,58,9,83,255,125,246,61,243,150,11,82,249,117,240,70,239,145,10,249,252,156,254,114,239,240,9,9,239,173,250,185,230,1,11,212,248,194,244,3,236,218,0,179,243,45,242,180,235,174,6,204,246,184,244,71,238,186,10,91,249,178,248,169,238,216,5,231,239,50,250,196,242,21,13,159,247,251,242,214,239,187,5,196,244,167,254,36,235,244,3,90,251,120,249,128,236,241,8,251,251,158,247,104,234,222,11,133,253,196,254,184,241,98,13,176,243,121,245,76,233,32,9,254,247,237,247,92,232,225,2,70,243,152,245,147,239,162,254,14,251,151,253,226,234,80,0,11,237,142,246,15,241,61,7,210,250,87,248,13,239,71,2,37,239,41,250,235,235,123,255,171,235,120,243,216,230,155,6,235,247,184,245,207,241,21,9,55,245,192,245,218,233,228,4,164,241,153,241,24,234,175,2,239,244,8,243,181,233,16,0,219,240,78,245,32,232,84,0,241,235,229,8,227,233,4,12,75,3,19,6,119,233,5,11,140,235,24,2,19,231,91,2,210,236,222,2,255,237,242,12,4,240,44,7,61,238,195,12,30,239,243,255,168,232,168,14,185,249,143,5,82,231,32,9,142,1,109,1,157,225,218,5,234,253,56,8,82,223,130,11,191,250,143,0,87,234,106,7,84,241,143,2,60,229,150,5,148,0,4,0,3,230,93,9,197,255,42,9,148,232,210,17,90,252,205,4,64,228,147,11,170,253,240,253,120,228,71,11,2,249,171,5,55,229,60,15,155,249,42,2,126,232,8,13,9,0,206,12,130,233,194,15,129,0,213,13,23,228,41,19,217,249,35,9,5,229,136,13,211,254,215,10,123,227,131,6,202,240,27,2,49,225,223,3,196,239,67,8,3,227,59,12,253,243,243,10,158,222,4,10,52,233,53,11,55,233,84,6,47,238,31,10,143,227,143,12,145,237,52,251,227,222,194,2,82,237,175,7,133,235,205,18,108,248,189,2,158,228,225,8,203,240,147,3,234,222,126,7,12,234,162,255,197,229,156,0,223,240,50,4,25,234,37,17,7,252,179,10,105,230,203,4,63,242,213,2,101,225,141,10,245,250,19,254,205,226,215,8,205,251,100,254,148,230,168,11,24,253,153,2,181,234,141,14,124,245,219,5,63,224,236,13,232,247,54,11,67,231,135,17,196,247,194,2,113,236,71,15,104,255,30,254,44,222,203,5,172,244,177,9,60,230,214,9,77,249,123,5,242,230,118,5,245,234,140,2,133,231,71,2,202,232,182,2,140,226,134,2,128,231,227,8,66,226,0,1,105,236,136,5,1,218,108,7,175,243,200,10,223,230,35,15,69,241,21,9,68,212,134,8,221,235,199,4,203,212,97,5,23,236,108,0,149,214,51,1,168,236,138,255,180,223,114,6,220,249,47,7,249,224,219,6,156,253,197,9,160,220,213,3,103,244,86,11,228,222,211,5,108,233,203,7,89,212,49,6,197,241,184,2,236,223,60,3,86,246,246,5,55,222,100,5,70,251,205,1,171,227,150,12,75,247,150,11,63,222,25,16,57,243,65,3,105,232,57,9,194,251,237,13,112,227,188,7,205,234,34,11,33,222,176,14,202,248,83,10,143,227,115,8,83,255,135,13,134,241,196,243,101,252,35,5,15,241,141,242,2,0,34,10,13,240,25,241,158,2,34,7,61,239,75,245,101,255,100,3,91,241,177,239,214,254,216,7,115,239,199,240,251,253,218,4,91,242,17,239,201,250,168,255,210,239,194,242,7,250,128,8,96,242,18,241,49,252,170,6,188,235,169,242,131,253,157,10,241,231,227,246,142,252,252,4,118,240,247,238,25,2,167,9,76,234,206,244,48,255,31,3,191,237,10,240,56,0,109,7,78,237,51,242,14,1,220,11,194,240,234,241,179,254,201,8,11,243,33,239,112,255,34,10,145,239,199,247,142,244,168,15,90,237,190,245,122,252,14,4,181,241,88,242,106,246,165,10,243,241,30,243,1,250,126,6,85,233,3,245,175,0,193,2,83,241,143,242,52,250,68,7,157,232,251,244,138,252,202,14,202,236,105,247,119,248,99,14,117,239,13,246,249,250,227,9,224,236,116,244,199,249,237,3,47,234,4,243,76,255,89,6,147,235,36,249,198,241,214,5,79,236,83,244,131,245,158,10,209,237,104,243,157,252,70,9,16,230,47,249,97,244,85,8,220,230,83,246,37,250,41,7,190,238,61,242,24,250,104,4,210,236,158,245,174,251,177,2,87,237,241,244,219,247,9,14,96,235,189,245,197,254,192,12,69,241,143,245,187,248,130,12,30,234,151,246,146,1,40,2,246,237,83,247,70,244,23,12,20,235,150,245,197,251,73,13,255,237,182,243,45,0,235,11,202,237,112,247,72,247,238,10,80,234,98,246,107,248,50,9,73,233,81,247,197,245,192,0,132,241,9,245,158,245,94,7,126,239,186,248,55,242,222,9,120,240,253,244,228,246,41,6,226,240,105,245,10,245,8,5,44,234,202,242,133,250,151,10,233,234,228,249,75,243,179,5,140,234,82,247,190,254,7,11,29,236,186,244,8,3,231,13,67,233,195,247,176,250,51,6,69,231,56,245,139,248,91,8,163,235,198,244,184,247,38,5,15,239,145,241,206,247,53,3,137,238,199,248,203,253,1,13,82,237,67,249,167,255,70,2,206,236,247,239,161,251,161,1,208,239,24,240,31,246,57,255,37,241,51,245,54,240,171,10,69,239,161,247,1,0,95,11,213,231,97,248,188,247,37,6,50,232,19,254,234,244,33,8,241,228,160,252,117,243,34,4,110,225,79,0,148,254,75,12,62,234,84,253,46,252,244,13,32,233,36,4,32,7,119,4,210,229,58,250,82,1,37,9,204,227,168,255,4,1,55,14,51,229,156,2,47,3,179,8,132,231,86,249,190,1,62,13,62,232,159,254,22,5,99,4,124,226,43,251,82,254,193,6,194,225,217,2,38,255,177,5,138,229,75,2,67,2,249,1,249,228,199,253,115,1,82,4,179,227,78,0,158,0,195,10,167,229,158,251,82,1,253,11,104,232,121,250,218,3,126,8,104,228,106,250,229,254,110,5,78,222,66,254,41,244,206,13,22,229,81,254,35,2,219,8,110,218,219,1,78,244,88,14,7,226,75,0,141,255,83,8,120,226,74,251,18,253,156,11,203,226,83,253,250,254,68,6,19,230,96,253,187,2,130,6,103,226,191,253,16,255,55,6,102,230,146,247,162,255,44,9,114,231,159,254,99,4,225,7,150,221,100,254,243,248,76,11,199,229,27,249,214,253,196,9,84,229,53,248,83,251,37,15,17,230,32,255,137,249,88,9,64,225,165,255,179,254,234,13,54,227,236,253,236,244,248,9,66,226,164,0,243,248,222,3,40,232,218,0,182,1,142,3,75,225,56,1,85,251,192,5,73,231,116,1,128,253,40,6,25,228,65,248,181,252,166,1,55,226,55,254,234,254,5,7,172,222,149,1,13,252,64,4,28,227,18,255,27,247,137,12,159,229,105,250,232,247,57,10,73,229,100,0,243,245,15,10,131,222,125,254,140,243,34,14,197,228,90,251,191,254,157,8,63,227,97,249,40,248,169,11,103,231,184,5,155,4,244,10,114,227,29,4,82,1,82,5,70,232,117,251,184,252,8,13,75,231,254,248,21,0,20,11,83,224,50,3,183,254,231,10,9,233,48,2,10,6,88,9,80,232,135,0,100,0,46,7,206,231,84,2,61,4,134,7,165,226,98,254,219,236,153,12,126,227,78,251,91,251,120,15,122,226,109,253,49,253,114,13,9,230,100,249,185,251,53,13,215,230,6,1,138,252,151,5,42,224,94,251,130,250,84,1,206,222,106,255,125,252,188,11,43,224,252,254,71,252,189,10,45,230,51,2,105,3,9,230,211,250,91,238,173,237,139,232,135,249,7,240,43,241,171,243,76,2,163,235,4,244,17,243,111,250,71,231,114,241,22,233,205,252,239,240,72,245,119,236,249,248,205,251,243,237,46,235,166,245,144,245,200,237,190,236,229,253,197,246,86,240,88,244,10,0,233,240,139,233,225,251,198,247,127,241,85,239,156,234,10,254,73,239,152,230,145,235,249,249,102,236,231,230,242,235,149,254,163,243,11,236,143,240,253,252,245,239,7,231,145,247,205,253,188,241,34,235,208,240,239,246,105,252,63,236,44,251,171,253,117,239,159,239,43,240,163,2,245,243,226,231,23,245,191,251,236,234,124,242,72,244,212,255,95,247,81,230,248,242,5,250,39,239,216,235,177,247,128,0,13,237,148,241,7,243,136,0,237,247,228,233,161,235,124,5,234,238,252,238,69,245,144,1,60,231,149,241,170,240,169,253,15,235,114,236,197,244,224,245,233,235,4,240,129,236,90,248,54,235,229,236,155,236,218,250,4,230,43,235,200,236,101,249,196,242,71,234,196,241,230,242,128,245,162,232,44,236,105,252,45,238,88,244,30,232,250,0,212,240,181,240,82,240,232,2,123,240,124,248,89,234,239,251,75,234,249,240,153,237,184,250,239,233,213,245,222,242,7,3,71,235,241,236,119,236,107,0,30,242,184,244,142,231,141,249,44,231,90,230,79,238,151,1,117,236,231,240,222,235,38,2,98,235,167,234,157,239,45,254,154,248,199,243,98,236,103,4,235,242,14,243,69,232,226,4,39,239,247,233,139,245,21,247,248,246,241,232,239,239,193,0,85,251,31,237,156,240,232,251,147,250,41,236,137,241,149,3,53,240,157,238,218,242,121,239,2,250,144,234,2,243,1,242,213,247,217,236,232,235,230,4,28,246,171,236,162,232,154,252,15,246,53,238,171,240,99,255,9,235,23,247,237,230,22,253,220,233,237,238,101,233,6,2,72,228,83,233,94,239,186,3,203,230,31,239,93,237,73,253,194,239,153,249,90,228,8,253,181,235,11,233,76,227,83,0,251,239,22,238,130,246,184,0,198,244,113,249,20,247,153,240,148,244,86,236,244,248,7,249,70,244,154,237,209,238,44,245,233,248,227,237,60,231,190,245,248,244,185,235,122,236,208,235,104,242,113,7,138,240,140,234,193,249,43,6,89,246,85,241,236,254,110,12,39,244,109,233,217,251,18,6,136,244,35,237,246,250,82,9,213,248,47,236,21,244,19,5,68,249,69,241,161,240,20,9,50,236,10,246,148,241,0,3,26,239,43,235,215,254,86,7,112,242,13,234,234,243,224,3,45,244,224,238,34,244,217,8,127,243,44,235,67,0,152,8,111,249,235,238,101,248,157,9,107,243,255,242,114,239,4,10,18,251,104,244,157,244,155,12,165,242,170,248,211,242,62,8,60,247,49,234,36,248,8,5,77,248,110,235,34,252,20,7,97,244,38,245,60,254,223,15,106,247,115,251,30,243,149,11,82,237,226,236,97,237,152,2,142,232,146,240,10,245,233,7,186,243,166,243,213,244,223,12,66,243,244,242,229,239,60,6,82,240,178,240,93,248,33,13,92,249,121,242,190,250,121,13,107,239,163,238,121,237,108,6,172,239,127,240,111,254,209,12,34,245,136,235,235,239,132,4,144,233,56,240,97,250,142,13,57,236,201,237,189,254,100,12,77,238,9,243,180,252,148,15,174,231,251,235,240,247,160,11,213,243,61,243,5,250,58,15,236,237,187,238,208,244,248,10,49,238,83,244,142,242,232,7,17,249,121,238,112,253,173,9,152,245,183,248,164,248,241,15,220,248,241,245,202,240,50,13,215,230,163,241,23,248,141,6,211,239,148,247,89,251,146,13,62,237,169,249,65,249,112,8,158,234,71,245,61,250,194,9,176,241,224,251,73,248,187,9,192,237,10,244,69,247,117,11,147,239,184,232,223,244,237,5,125,236,180,233,53,249,13,7,228,236,64,232,71,237,104,3,82,239,180,239,89,239,137,8,177,237,66,250,167,244,255,3,210,230,103,236,177,240,232,3,98,232,94,234,153,240,214,7,116,232,90,241,143,240,3,3,185,232,26,238,96,236,56,3,70,233,240,245,55,247,46,5,229,233,31,235,161,251,196,9,238,242,197,239,94,2,189,10,208,233,37,237,59,246,46,7,207,231,17,246,241,250,72,3,41,229,195,236,72,242,9,7,27,234,4,249,153,248,11,3,174,240,176,233,220,237,254,1,119,237,227,240,75,238,99,0,88,244,213,236,113,254,217,5,55,7,34,254,245,11,76,233,98,17,164,251,25,14,86,230,67,12,99,0,191,11,100,234,30,10,58,241,66,12,94,237,89,7,180,4,146,22,180,242,47,14,12,8,190,21,82,236,133,13,169,7,47,20,40,241,131,11,17,1,184,17,219,238,101,17,62,249,156,22,238,238,192,15,13,7,106,10,74,238,159,13,80,252,9,9,116,232,33,5,34,0,114,16,29,240,0,22,34,250,193,22,33,233,56,30,221,253,15,19,156,234,42,19,24,250,152,18,128,233,3,15,191,1,67,4,162,236,166,11,145,251,66,21,222,238,251,13,15,1,215,11,142,229,92,15,45,255,80,18,125,234,59,17,184,6,83,9,48,234,3,21,33,254,223,17,120,231,29,14,150,254,220,7,235,236,160,14,35,248,141,17,47,236,61,22,109,0,27,17,222,242,99,21,147,253,197,20,111,240,11,25,95,253,76,22,112,237,69,19,228,252,94,28,62,239,244,10,188,1,132,24,185,241,24,16,251,253,190,23,77,238,255,19,73,3,158,13,186,240,130,18,3,6,197,13,102,244,222,19,114,1,7,23,248,233,139,16,156,10,237,17,76,236,107,14,170,2,55,24,164,237,223,23,198,253,127,24,128,230,51,10,253,4,172,14,62,237,43,17,202,3,223,14,9,233,105,20,251,8,170,12,19,239,24,20,242,6,82,19,87,234,173,11,56,244,175,12,137,234,167,11,152,3,23,8,85,232,150,20,121,252,82,17,210,246,15,25,183,253,130,15,30,242,26,15,59,255,96,20,188,244,183,14,238,250,46,26,13,243,155,24,60,10,164,20,88,229,254,25,134,2,69,14,193,236,162,18,231,11,40,20,113,231,244,20,178,1,103,11,169,235,182,11,64,5,193,18,104,246,56,15,245,3,189,14,184,248,67,8,143,2,183,11,56,231,50,20,43,252,33,11,144,238,175,10,145,247,157,10,112,233,126,9,96,248,40,17,49,238,255,23,100,251,75,14,118,237,114,19,53,250,190,6,245,236,158,13,177,246,234,12,51,239,154,5,164,250,75,16,94,237,26,13,189,245,245,5,27,236,134,26,82,9,155,15,235,232,195,5,142,245,123,13,148,239,207,7,90,242,109,14,76,234,156,18,224,244,40,11,43,234,163,241,11,20,11,11,138,244,228,244,166,27,36,11,4,242,194,240,34,25,22,16,137,248,23,249,106,29,164,13,43,242,111,248,47,22,65,254,153,251,104,246,72,18,100,16,153,246,38,245,49,32,162,6,64,239,196,244,216,23,62,20,173,246,14,245,173,28,111,17,134,244,255,251,123,24,144,18,127,243,211,246,37,21,249,7,46,241,52,247,33,32,40,11,83,239,71,250,103,19,112,19,60,246,132,253,141,29,189,13,119,239,143,248,242,21,64,15,130,244,210,254,160,26,15,13,12,243,94,247,60,16,1,11,73,242,51,253,168,25,71,7,121,244,223,240,50,22,116,8,193,253,194,244,203,22,184,1,219,245,100,243,21,30,50,10,46,246,232,241,184,34,49,13,92,246,234,245,245,37,215,9,202,243,138,235,58,24,50,11,241,244,156,242,202,28,240,11,177,254,111,249,132,34,186,4,38,248,52,243,68,26,132,4,166,240,130,252,213,31,59,3,22,251,107,244,183,33,245,9,216,250,135,240,246,26,253,13,55,0,154,248,65,30,214,6,183,252,203,252,188,26,82,3,92,253,160,253,36,27,252,255,160,250,103,2,124,25,65,4,133,251,100,244,36,22,67,4,23,254,99,255,41,18,88,11,99,254,161,2,1,20,218,5,190,255,122,254,14,23,75,6,11,255,211,246,102,21,164,18,216,250,88,0,142,26,180,7,189,248,67,251,0,20,175,11,200,0,213,246,152,23,23,11,120,1,190,253,88,23,36,13,252,248,145,250,240,22,186,11,59,252,204,253,144,17,106,15,94,251,5,247,242,24,63,12,128,247,173,247,9,22,219,7,199,4,252,252,175,22,100,4,127,3,235,244,102,26,249,8,28,253,237,243,154,24,135,5,178,247,155,239,148,23,51,7,50,244,215,255,59,25,92,0,88,1,63,247,204,26,47,8,212,238,117,248,176,27,69,8,169,247,185,246,70,17,152,6,159,243,50,249,18,26,2,6,137,255,46,237,69,30,96,16,215,249,44,248,40,22,193,0,82,254,15,241,154,23,80,8,150,248,172,251,97,31,71,8,59,244,190,246,77,21,185,6,10,1,222,249,222,27,102,2,178,245,17,250,48,34,175,13,22,239,254,247,5,15,91,11,154,251,221,19,60,17,177,254,125,248,34,14,143,5,155,253,84,240,129,17,145,14,77,2,233,237,174,16,144,12,29,249,160,243,145,16,4,7,91,249,20,245,179,18,34,9,25,254,201,241,99,11,101,13,147,253,111,237,55,20,124,6,15,251,105,243,184,16,217,15,84,253,17,240,116,19,67,17,81,250,97,245,60,21,160,9,131,1,155,239,155,17,178,15,97,4,14,243,132,23,97,9,99,254,127,243,104,16,205,14,179,254,3,245,109,20,189,9,86,251,170,248,219,22,135,10,20,254,12,247,111,22,216,12,71,253,59,251,60,22,52,10,211,3,77,247,221,19,19,8,22,4,66,251,91,12,192,8,206,247,149,242,108,20,106,7,145,0,163,246,228,22,136,15,94,254,200,244,120,23,71,13,3,4,78,242,30,16,243,7,73,7,131,252,255,20,12,14,255,1,198,246,145,7,213,5,172,252,134,255,145,13,241,18,35,2,213,245,23,18,161,11,117,4,24,249,5,24,234,11,185,255,162,248,229,15,1,17,223,254,107,250,68,11,201,4,148,250,109,1,109,21,214,9,21,255,197,253,192,4,23,17,163,5,142,1,124,19,34,12,107,0,101,250,159,17,241,10,51,1,68,254,163,12,34,17,71,1,92,253,7,8,124,14,121,6,207,254,207,22,70,9,34,1,151,250,246,19,233,12,144,7,146,239,16,25,104,11,82,1,80,245,22,13,8,11,11,251,215,240,232,18,23,7,208,1,186,0,95,9,4,13,238,0,214,4,188,13,83,5,46,6,176,2,254,13,82,7,154,0,94,237,189,12,62,11,118,3,27,1,37,15,98,10,185,254,116,3,55,16,108,13,125,8,149,244,8,14,90,14,1,5,241,250,209,17,146,14,166,251,45,249,243,17,41,14,210,253,193,253,17,10,44,9,219,8,120,0,122,20,227,12,32,0,172,242,168,16,53,14,197,2,240,246,156,25,242,13,186,252,88,246,113,22,174,15,84,252,75,248,253,21,123,17,221,1,0,243,149,20,127,12,146,6,243,243,80,17,112,9,121,4,29,243,113,17,201,9,114,8,118,247,35,18,77,19,168,255,187,244,216,17,111,20,40,2,181,240,35,22,3,12,130,250,109,244,42,21,139,20,253,252,254,244,0,255,61,225,255,1,41,254,235,248,221,224,88,254,116,254,206,254,162,228,94,3,26,1,254,246,234,230,96,250,252,1,11,255,125,229,119,1,156,255,227,250,79,232,236,255,11,3,136,249,97,232,127,253,27,5,40,250,134,230,196,3,214,2,13,247,68,230,54,255,27,3,6,253,158,226,174,5,210,253,34,247,164,228,190,252,188,253,141,251,90,228,3,1,106,1,25,246,112,226,240,251,49,0,54,241,144,227,166,3,36,254,248,242,32,231,94,2,32,4,238,241,244,228,52,0,202,2,26,247,106,230,138,6,204,0,217,244,123,233,162,3,250,5,183,244,99,227,41,255,49,1,67,245,64,232,19,255,172,5,39,252,245,229,41,6,144,1,12,248,61,232,124,1,243,4,227,247,220,226,124,1,226,255,17,249,249,227,4,6,126,254,7,244,241,228,221,3,168,0,236,244,78,226,117,0,192,242,222,251,4,231,81,2,250,243,180,252,82,232,231,3,20,255,67,243,217,228,211,5,48,253,118,247,220,222,75,0,249,250,190,244,180,225,200,1,2,254,248,248,33,229,192,3,97,251,6,246,183,227,78,6,62,250,208,245,71,235,136,1,83,3,99,244,94,230,165,252,90,3,176,245,155,232,7,4,96,254,47,252,82,223,193,2,102,250,67,251,15,227,179,255,146,250,201,250,255,229,77,8,133,255,16,246,50,229,60,7,31,253,93,243,234,230,216,6,153,255,236,250,123,226,171,3,164,254,108,242,101,226,202,0,147,255,78,246,84,230,241,2,107,2,6,246,56,224,120,253,83,254,12,252,66,225,253,255,91,254,236,241,153,231,32,0,226,243,50,250,153,227,221,7,3,252,190,253,113,229,245,253,149,1,231,244,196,232,108,6,143,3,149,246,207,226,60,4,28,254,66,247,111,232,38,1,221,251,125,242,186,230,55,255,234,252,21,248,135,232,41,7,37,3,103,250,145,224,251,5,38,249,70,243,52,225,251,2,114,250,248,249,240,228,39,253,222,1,246,246,33,223,74,0,83,241,127,243,204,233,95,0,90,247,137,246,10,222,213,2,209,241,39,242,97,228,138,4,250,248,218,254,66,218,147,1,30,247,14,247,172,234,172,4,146,1,189,249,199,229,135,3,197,246,25,16,187,9,186,243,78,246,148,17,233,12,169,241,225,249,85,23,100,12,188,250,234,253,222,18,51,13,243,249,131,2,94,20,98,15,175,245,2,247,31,18,218,18,100,234,177,252,7,22,171,10,134,247,61,252,196,23,159,13,59,242,190,250,83,23,82,12,114,247,244,246,242,21,1,19,241,228,116,0,225,20,240,13,33,227,197,2,53,21,214,19,29,241,12,250,48,27,245,7,69,242,184,251,180,27,227,9,51,238,180,253,173,23,151,16,237,233,34,254,243,17,100,14,213,236,197,252,73,29,141,12,24,244,88,254,108,23,89,8,230,243,47,249,54,24,79,20,81,247,30,247,232,26,35,11,48,245,117,249,226,23,114,16,244,246,70,252,215,27,146,16,31,244,128,250,238,23,84,14,19,250,109,250,101,24,241,23,127,239,94,251,160,26,141,12,203,247,60,252,225,20,156,20,173,245,177,252,192,25,57,18,14,239,228,1,90,26,167,14,141,242,124,0,77,21,188,7,78,245,46,10,54,18,131,8,126,239,221,251,195,21,136,12,30,242,174,0,136,20,95,17,233,248,55,250,24,21,10,10,70,251,235,0,144,27,245,9,142,245,62,1,222,17,244,16,180,244,126,255,59,24,235,17,55,243,207,254,239,19,133,7,101,245,167,247,65,15,200,16,92,249,247,0,69,17,253,17,29,243,43,3,39,22,249,4,226,240,100,252,110,21,13,7,219,236,133,0,37,25,18,10,220,248,150,255,154,21,133,20,62,236,199,4,208,18,233,7,65,251,163,5,129,13,197,13,104,246,145,12,244,12,35,10,172,251,155,9,252,11,226,14,97,247,134,7,207,24,60,21,186,230,88,2,180,24,144,16,11,235,112,9,243,18,166,18,21,240,86,7,36,19,95,14,178,235,54,4,155,32,49,14,43,238,85,255,124,20,86,22,243,240,173,0,120,15,164,13,133,244,57,8,182,23,145,13,209,246,161,0,36,32,218,11,224,242,123,252,94,27,145,15,108,248,122,248,211,27,73,18,51,239,146,252,2,20,1,16,197,248,63,254,56,24,12,8,53,247,25,4,194,27,4,15,215,227,65,10,196,27,42,13,178,229,21,2,203,26,33,11,104,240,80,5,82,21,230,8,75,243,107,4,208,251,195,247,175,18,207,251,193,254,212,245,161,16,142,246,162,9,20,5,148,13,198,254,31,11,34,250,176,20,115,255,131,6,7,251,183,21,91,245,61,11,182,242,34,25,204,0,53,0,179,245,155,20,99,251,67,4,89,247,171,22,243,249,93,9,102,252,231,16,158,4,219,0,93,241,39,18,228,249,227,255,111,245,204,18,253,4,219,5,208,245,16,22,127,5,91,8,161,246,106,16,231,10,86,254,240,247,152,21,151,0,0,10,13,245,35,24,10,245,185,17,81,246,213,14,71,4,120,3,227,242,221,20,97,254,108,17,234,248,12,21,53,251,80,15,60,243,220,24,65,253,15,13,166,237,58,17,16,3,53,1,151,248,162,24,199,4,190,3,10,243,158,16,161,243,157,255,60,6,130,23,65,248,83,254,171,252,7,25,110,3,146,4,214,250,146,24,95,254,240,8,7,254,159,24,49,248,240,12,118,249,93,26,66,246,97,254,183,242,113,18,141,254,67,255,70,251,236,18,46,248,120,3,210,239,25,17,130,0,165,9,227,238,22,21,68,246,63,11,160,244,230,19,218,245,51,253,151,253,18,22,83,253,190,5,233,240,232,20,108,249,95,15,160,255,239,14,38,253,185,14,82,254,96,12,182,2,252,9,129,1,211,13,0,2,77,0,121,250,247,19,95,10,164,10,146,247,59,26,202,252,40,7,233,3,9,21,148,248,132,3,150,8,112,17,209,253,185,1,69,0,33,23,49,249,119,251,226,2,76,26,204,254,1,1,243,7,251,15,224,2,71,6,8,5,3,17,233,255,243,255,36,5,84,16,136,6,231,5,56,5,241,11,155,5,141,8,27,241,178,17,171,3,48,14,62,253,86,10,95,5,170,16,79,241,145,16,53,4,29,12,85,254,153,20,78,251,245,8,20,1,202,18,199,254,102,13,197,248,29,12,253,7,125,13,93,244,22,20,174,3,147,6,47,243,194,18,210,7,114,15,149,237,235,21,66,2,248,4,101,255,221,19,198,1,128,0,62,255,231,19,129,5,52,3,112,3,165,22,158,245,185,251,144,2,142,22,71,4,45,3,123,249,224,16,77,243,137,255,6,2,228,24,117,253,106,11,53,239,227,23,147,252,109,16,79,239,164,15,82,10,69,251,204,240,224,0,55,12,222,255,237,238,41,5,14,9,77,0,74,231,177,4,60,3,155,15,65,241,166,7,161,12,178,0,27,243,193,7,246,12,26,9,39,241,9,4,123,12,133,5,96,234,58,3,173,6,164,9,85,242,69,14,47,14,229,2,247,237,187,6,216,7,222,4,29,244,162,11,109,15,169,254,44,239,210,8,141,8,86,253,224,237,198,1,224,8,212,4,35,237,187,9,106,6,0,254,74,241,158,4,236,11,119,0,157,240,128,14,203,3,135,251,240,237,80,5,233,8,101,0,118,237,50,11,231,4,36,250,177,234,27,2,101,6,55,252,235,232,134,5,104,4,19,251,181,236,25,255,230,7,30,255,31,235,183,4,193,2,152,10,11,236,133,12,74,7,36,254,231,232,17,1,184,4,9,248,144,238,112,2,241,9,209,246,166,240,227,7,113,10,141,245,15,237,242,5,198,7,12,250,123,242,166,5,132,12,221,1,62,235,174,6,41,6,144,2,111,241,42,9,207,9,38,2,227,232,183,7,16,4,192,6,160,237,251,11,34,4,247,255,129,235,250,1,224,6,194,253,241,235,139,6,136,6,81,8,59,241,116,13,9,9,120,4,169,238,166,8,225,9,12,5,192,239,113,12,41,7,141,9,66,243,230,9,155,12,218,8,207,238,231,7,96,9,181,253,238,241,80,13,19,8,139,252,169,236,156,12,150,4,40,253,105,245,247,10,224,13,251,3,29,244,123,12,138,11,96,7,249,237,116,4,150,9,148,2,16,234,242,2,32,3,73,248,5,235,113,6,49,6,248,249,196,234,118,9,57,4,90,254,6,233,86,9,238,2,56,5,75,234,137,9,206,4,136,0,95,240,11,1,38,11,246,253,39,243,178,8,168,10,53,252,28,238,167,9,196,2,192,2,70,235,228,12,233,3,69,1,120,242,227,13,94,9,26,3,154,241,80,3,97,12,148,2,55,244,232,17,170,12,50,250,118,240,122,8,108,6,177,249,214,237,128,10,52,7,238,2,30,238,26,2,191,8,132,6,39,233,175,5,7,4,158,13,183,237,238,7,135,8,82,10,203,234,160,6,225,6,139,17,106,238,210,13,207,10,217,13,80,238,186,13,166,11,197,12,164,241,198,10,126,15,196,21,122,4,209,0,205,242,35,29,29,4,81,2,152,248,128,17,200,0,202,254,93,239,201,21,85,252,242,0,104,240,206,31,186,1,233,4,245,243,66,21,237,4,144,5,92,243,116,24,73,255,53,12,28,246,11,28,121,3,82,6,12,246,16,25,164,3,75,9,73,246,182,27,0,10,193,3,192,242,154,28,207,1,172,10,105,241,232,25,41,6,120,7,56,243,168,24,69,5,212,11,124,242,217,23,130,1,189,4,47,252,102,21,134,4,90,4,26,254,93,25,154,1,150,6,124,247,234,24,89,7,53,5,64,247,79,22,44,3,166,7,236,250,188,26,109,3,218,2,91,251,168,26,11,255,201,8,48,248,91,29,241,5,227,4,14,244,41,26,27,4,20,5,43,249,76,25,145,5,43,3,43,245,182,28,209,1,180,255,223,244,63,27,47,8,55,2,68,246,83,18,200,6,100,10,15,247,157,30,176,5,84,1,49,245,250,30,251,1,70,3,230,247,218,23,222,5,254,2,170,251,27,19,109,253,67,3,142,240,82,28,141,0,89,5,13,250,227,29,67,0,115,6,6,247,196,28,207,254,89,2,196,243,11,28,193,0,187,9,201,244,104,25,240,254,119,8,214,250,104,17,215,3,252,8,91,254,209,18,201,1,159,6,115,1,2,27,43,2,82,3,169,243,16,23,6,4,202,0,89,248,114,24,112,3,185,8,105,238,141,23,10,0,82,8,240,241,49,25,217,3,105,4,133,240,216,25,238,255,145,255,43,243,144,17,7,3,49,3,76,239,246,23,34,9,190,5,99,244,255,26,152,0,174,1,102,248,213,15,223,3,146,12,87,251,59,21,5,5,52,12,148,246,131,21,44,7,143,7,60,248,120,20,177,2,141,8,146,245,238,25,183,6,94,2,249,248,180,21,76,255,129,0,221,245,12,22,126,7,1,5,36,239,10,25,64,4,230,254,211,243,103,25,49,7,56,1,70,242,35,27,20,0,78,5,210,240,88,21,61,8,94,9,134,243,240,21,105,254,92,8,14,254,233,23,147,10,75,9,0,240,135,28,54,7,218,8,1,240,68,21,214,1,158,10,239,249,185,22,123,253,213,12,187,250,249,21,147,5,79,4,57,248,153,23,218,252,172,4,129,244,234,11,166,233,230,15,172,234,92,13,222,238,238,15,221,235,132,23,114,240,100,28,127,245,78,29,35,239,214,30,123,240,60,16,26,242,127,20,36,239,117,18,207,238,122,28,252,249,32,26,254,235,24,32,118,243,216,35,80,230,60,36,157,236,2,34,180,233,51,31,243,237,148,27,49,242,132,25,20,243,224,21,97,245,243,20,224,249,53,18,13,245,119,24,148,237,89,14,204,241,3,24,151,242,185,20,231,245,185,23,178,245,190,29,86,248,191,23,110,235,104,26,218,242,214,28,30,239,241,24,213,240,189,18,183,250,246,31,0,236,202,16,223,237,170,35,202,231,111,19,9,244,253,28,196,234,200,21,127,241,155,13,222,236,67,21,71,245,43,19,245,233,246,24,247,239,183,31,160,228,56,31,148,229,128,25,22,232,55,27,42,234,2,23,162,239,224,25,200,233,159,26,2,225,107,28,176,234,58,21,46,239,49,20,254,234,12,17,220,230,0,21,212,245,216,31,180,242,25,23,72,236,47,31,1,237,166,16,99,246,87,31,212,231,94,24,58,236,97,26,148,241,95,15,117,241,170,26,104,237,212,12,45,240,56,28,1,227,140,17,221,240,248,26,226,245,187,25,152,231,218,23,104,248,177,28,126,234,92,19,82,244,128,30,182,243,252,26,27,229,61,23,248,250,250,27,86,232,91,13,183,242,103,27,88,228,251,26,54,244,59,27,80,229,14,22,55,243,78,31,86,234,95,21,248,249,136,26,84,247,241,19,193,244,46,33,122,240,56,17,97,240,119,37,254,236,139,23,50,238,144,20,215,235,213,23,30,253,171,22,3,232,77,20,145,235,49,18,90,229,160,12,187,235,183,18,241,235,225,14,199,237,220,23,17,236,75,9,223,240,72,18,187,240,162,12,27,236,170,22,243,240,211,14,136,236,8,17,197,226,194,18,219,240,53,21,163,226,23,23,123,241,210,26,24,247,16,19,230,237,147,39,236,237,62,17,4,240,59,42,187,235,66,30,39,235,31,22,19,221,167,20,208,233,87,31,153,232,235,28,20,245,197,37,249,228,125,25,188,236,107,28,44,241,98,19,13,246,144,34,58,237,45,22,248,243,192,31,44,239,69,30,87,230,192,15,180,235,234,8,161,231,193,25,188,2,27,255,48,1,68,32,27,2,190,255,21,251,205,25,176,0,210,252,147,255,121,31,0,0,255,255,120,255,214,28,218,255,28,254,151,251,181,32,95,252,170,2,58,254,250,29,178,2,2,251,34,2,158,28,251,253,150,1,253,250,188,29,77,249,113,251,151,4,142,33,185,1,242,252,58,253,124,33,78,251,221,254,4,1,140,28,109,255,7,249,158,1,131,26,159,254,96,253,166,3,57,20,123,255,179,0,82,0,65,16,222,255,191,1,217,5,109,23,122,252,253,5,135,255,95,22,153,252,166,250,177,3,194,32,4,255,37,1,201,252,173,25,182,250,170,2,104,2,226,29,208,247,213,2,201,1,186,31,78,0,124,2,136,250,229,32,172,1,172,249,131,0,173,28,244,250,51,253,186,0,62,31,207,255,48,253,10,1,99,23,161,254,157,2,76,3,146,28,172,249,250,0,165,253,51,28,230,249,196,253,202,7,234,33,154,254,222,254,124,254,178,22,155,0,78,255,175,4,78,28,244,255,18,4,238,252,189,28,101,252,188,5,37,254,121,30,109,2,44,255,44,253,226,20,254,253,186,4,76,5,11,33,36,0,129,255,245,252,222,26,131,246,86,3,214,6,112,28,135,250,183,250,29,11,155,29,156,247,73,250,39,8,237,25,178,3,152,252,238,2,199,18,180,251,9,5,42,10,143,17,219,0,15,6,104,4,215,29,250,1,190,1,173,251,215,24,188,0,241,3,141,255,241,25,228,248,119,6,211,2,18,21,178,246,68,6,238,9,133,23,172,245,92,9,127,5,90,18,114,3,245,0,245,5,167,31,61,2,226,252,163,254,109,31,249,253,229,3,188,251,147,29,134,255,227,0,174,254,227,20,80,251,118,2,182,6,158,27,22,3,218,0,224,253,16,29,216,2,241,253,236,255,2,25,157,254,197,0,32,253,191,15,3,3,98,3,103,7,121,23,128,3,189,1,225,255,40,20,74,4,168,252,248,6,44,31,138,252,243,250,116,5,174,24,175,250,119,9,252,0,123,29,69,253,133,0,250,1,114,33,216,246,172,3,8,1,2,23,163,4,111,250,146,8,158,25,123,253,225,250,61,10,26,18,121,249,27,8,87,6,238,21,105,0,208,252,72,9,246,25,22,6,171,250,118,2,86,27,126,4,187,247,34,252,155,25,7,9,187,251,9,249,26,26,150,5,169,246,108,248,181,30,19,6,95,244,92,251,89,26,187,6,53,254,219,247,80,29,205,4,126,249,244,247,1,31,159,2,176,247,7,250,227,27,223,3,33,253,184,245,211,26,56,6,233,250,236,246,1,25,182,8,60,249,52,246,33,28,136,8,135,247,60,248,236,25,142,8,29,252,232,244,196,29,2,9,215,247,117,253,160,29,83,7,98,250,137,253,254,35,25,6,96,246,141,251,10,24,38,5,43,251,155,244,237,30,31,11,251,248,193,249,117,32,237,7,5,246,47,254,12,32,2,5,184,253,155,246,248,32,11,4,133,251,143,251,195,27,66,7,196,255,224,249,125,26,96,11,151,252,73,250,179,29,36,5,193,254,31,251,153,30,55,5,178,255,199,248,250,30,117,4,8,252,73,253,203,30,74,6,7,252,222,250,133,31,129,5,237,248,60,255,127,32,7,4,186,253,202,249,60,23,1,6,151,247,187,246,236,33,147,4,177,248,174,252,165,32,180,9,149,246,244,250,116,25,44,8,63,255,113,251,224,23,161,6,22,0,243,253,249,27,191,2,166,253,169,248,159,23,47,9,217,252,37,255,136,31,62,7,231,248,239,249,44,27,24,5,76,0,13,252,207,25,201,5,224,253,94,255,46,27,237,9,247,254,110,248,16,25,210,9,247,252,174,252,104,28,62,8,125,252,109,251,61,30,105,8,229,254,202,245,82,25,249,7,34,249,59,251,106,26,172,3,186,248,23,247,234,21,170,4,101,249,231,249,153,30,116,8,201,252,96,248,84,21,158,5,176,252,165,4,123,23,97,5,253,252,235,249,255,29,32,2,146,251,90,247,41,28,12,5,102,245,228,249,191,21,176,4,108,254,87,255,221,22,181,5,71,250,250,253,126,26,177,2,180,252,164,252,162,28,57,5,128,251,185,255,21,28,226,5,115,253,83,253,204,26,68,8,133,250,16,255,100,34,236,5,145,250,32,249,42,28,129,10,38,250,35,252,118,27,206,11,95,250,221,247,17,22,44,7,105,254,13,2,27,29,27,12,51,253,96,246,216,28,120,6,41,248,142,1,104,25,195,2,129,248,122,255,197,248,55,14,25,247,73,253,59,240,108,6,179,255,49,5,71,240,168,7,227,249,201,253,154,242,191,9,229,252,112,1,93,237,176,9,225,3,244,2,153,242,10,8,21,246,53,252,38,241,90,13,124,1,217,0,254,243,22,13,140,249,224,251,135,241,70,1,142,249,255,5,206,243,1,5,88,251,71,6,7,238,87,5,56,252,53,0,32,241,190,3,44,0,0,10,225,247,226,9,51,250,142,4,133,241,87,1,183,244,180,0,127,235,151,5,225,255,176,2,130,236,125,0,64,253,246,4,45,245,54,5,114,246,234,2,12,247,226,3,9,250,70,10,19,251,254,11,41,246,12,1,16,246,50,15,223,251,216,253,187,238,255,0,68,248,18,2,121,244,198,1,243,255,59,14,42,247,23,7,142,254,64,11,177,246,73,14,119,253,64,2,43,242,95,255,147,250,246,9,111,239,39,6,45,5,1,10,49,245,197,15,197,4,42,6,92,241,137,10,124,4,9,7,178,237,81,9,36,255,0,0,5,250,109,6,65,245,47,5,211,255,192,15,225,252,250,8,157,244,232,8,197,2,191,9,81,251,206,12,106,254,42,9,89,246,116,0,110,245,12,8,120,246,125,8,178,244,168,254,209,242,239,8,245,6,154,12,151,247,240,13,35,7,102,11,162,252,219,8,166,249,223,9,118,245,111,4,45,1,143,16,196,246,75,8,242,3,126,14,113,246,209,12,175,255,128,5,156,245,127,18,216,1,2,1,227,251,25,12,122,10,94,9,218,242,243,251,128,251,156,252,125,253,146,16,164,8,235,4,203,3,151,15,166,3,131,2,175,249,210,7,91,8,147,8,223,236,204,3,16,3,183,6,5,251,176,11,15,4,237,14,120,254,109,19,47,255,29,7,252,251,110,18,57,250,119,255,50,0,74,15,41,2,162,8,166,2,12,17,103,1,23,5,186,253,47,19,2,2,135,6,252,4,74,15,28,251,118,11,40,250,144,15,89,3,26,9,4,3,136,18,113,253,28,9,225,252,163,20,73,254,112,2,61,5,121,11,138,2,235,7,53,249,28,19,251,4,166,6,132,252,36,10,105,255,111,15,52,242,66,4,12,5,32,0,65,1,74,12,87,10,195,5,8,1,103,16,201,249,37,5,60,254,203,246,218,8,96,16,206,11,247,251,171,246,46,22,118,251,194,250,215,13,126,19,38,254,59,250,57,251,152,19,69,253,215,244,132,3,251,14,51,254,49,247,139,255,18,18,180,4,242,247,69,251,51,17,144,8,37,244,175,254,126,15,108,0,193,252,23,1,11,22,177,5,148,253,164,244,156,20,33,246,178,255,61,4,84,21,70,248,130,248,75,252,125,18,32,0,111,1,144,248,46,20,98,7,127,249,184,1,144,18,250,253,164,254,0,11,27,19,111,14,70,246,162,250,251,17,246,0,83,248,221,13,129,15,76,4,217,243,144,2,153,14,157,250,102,3,98,254,223,17,116,2,155,254,53,251,35,24,151,251,218,250,103,246,224,17,87,254,158,255,183,255,192,24,111,1,137,252,174,11,111,16,43,8,29,251,140,9,229,13,33,249,182,249,254,7,153,20,138,12,134,5,236,255,56,10,231,12,180,245,237,3,141,16,185,254,221,243,128,253,103,14,59,255,252,2,60,2,110,21,134,2,1,253,108,5,88,21,104,0,182,10,28,255,67,15,20,255,37,7,189,253,233,17,154,247,38,254,11,250,166,15,233,255,184,245,160,246,52,15,244,255,53,249,162,244,3,19,250,246,144,254,154,255,231,17,57,248,243,247,21,2,179,17,44,15,90,250,103,255,41,17,32,6,14,0,223,254,148,20,160,250,3,255,19,245,89,13,121,12,239,245,171,9,238,13,90,13,105,2,70,5,65,7,208,14,232,255,240,254,42,13,153,0,135,4,90,11,61,11,255,1,114,8,12,6,181,10,6,1,51,3,25,245,150,14,136,16,33,248,206,5,149,13,127,11,170,251,10,252,104,21,26,11,113,1,191,2,148,13,195,11,98,6,91,252,225,13,60,17,244,249,82,252,157,19,131,250,81,2,68,9,147,20,45,8,81,8,128,3,61,9,237,18,68,248,0,0,239,14,164,247,81,0,206,12,5,22,204,5,105,10,188,254,69,14,10,0,192,0,84,6,171,20,104,8,226,2,35,247,136,19,54,8,188,10,140,249,99,18,39,11,173,247,125,254,68,20,149,4,164,2,58,5,205,12,36,9,231,246,240,247,255,15,93,3,24,248,16,5,191,19,141,8,153,12,73,253,66,10,52,24,89,228,151,7,202,252,195,17,51,237,189,12,64,7,147,16,8,229,115,13,192,1,229,17,177,226,178,3,250,1,226,25,182,225,99,13,214,1,79,13,128,220,197,12,40,250,239,15,192,230,0,9,9,3,245,21,136,219,124,10,0,253,231,20,192,230,118,20,42,255,73,23,185,224,188,6,237,243,117,16,125,224,91,2,10,255,40,28,21,227,96,12,54,249,210,23,236,225,73,1,157,250,125,25,177,229,152,16,208,251,185,23,159,231,119,8,182,246,1,18,254,219,235,11,247,251,157,26,141,227,45,6,151,248,238,23,125,231,229,10,169,2,71,17,118,230,85,6,100,249,128,24,150,223,95,12,193,248,28,24,146,222,146,17,111,251,236,18,116,222,111,6,146,254,65,24,153,221,45,6,143,254,13,21,133,224,38,2,64,255,254,25,209,217,200,9,217,251,191,27,194,224,38,3,18,2,30,22,176,229,29,6,220,241,69,16,164,218,95,16,173,247,174,17,243,227,64,2,197,244,25,18,81,222,247,10,122,237,125,14,142,225,23,7,34,0,50,14,82,222,9,9,198,252,79,27,1,223,15,8,130,243,77,30,242,218,207,8,210,253,53,16,158,225,120,18,96,249,135,22,253,226,89,4,195,2,240,17,139,231,25,9,72,7,87,12,254,214,141,6,79,239,206,13,206,220,133,9,19,242,127,17,187,213,155,10,178,236,135,12,179,217,238,11,210,240,19,18,3,224,202,11,206,246,151,21,186,214,172,12,67,245,250,16,113,216,7,13,244,243,244,23,155,216,244,12,228,250,253,21,24,218,130,8,14,244,19,14,166,222,222,4,144,253,153,14,216,222,139,1,161,243,89,21,106,211,250,10,224,237,186,20,191,225,161,10,108,240,88,27,105,220,159,6,127,250,7,26,195,225,162,9,17,240,243,15,249,227,44,7,33,237,29,14,58,217,62,5,129,242,188,25,159,224,201,1,254,254,112,18,90,224,17,0,71,251,246,28,251,221,14,5,168,254,61,21,210,216,203,15,88,249,254,18,191,219,22,6,105,250,144,26,253,230,249,19,94,3,15,18,206,223,107,10,28,255,31,23,37,236,20,13,87,8,97,23,71,221,173,10,15,236,165,19,121,233,55,17,207,2,98,1,242,231,186,252,71,244,95,1,201,232,200,247,2,250,135,253,234,227,231,255,66,237,197,249,189,227,28,241,136,250,103,0,203,231,139,244,178,255,70,249,100,236,143,242,19,239,85,248,244,233,243,238,242,254,178,252,145,233,107,242,196,0,65,255,28,235,42,240,43,254,45,246,182,225,89,242,206,252,214,247,202,229,115,245,117,0,222,253,132,228,138,250,163,0,234,254,77,228,154,245,232,253,146,253,230,224,85,245,72,250,237,249,74,224,228,241,247,247], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1821304);
/* memory initializer */ allocate([186,251,120,231,246,246,249,1,4,246,166,222,72,240,57,247,109,0,34,228,221,243,225,248,124,252,214,228,244,242,51,253,163,253,55,228,184,241,150,247,69,3,137,231,117,243,127,247,95,254,78,233,225,240,67,250,218,250,239,233,145,239,130,243,157,1,147,229,222,247,223,255,227,243,206,230,246,238,2,253,243,2,167,230,105,244,178,252,93,4,62,228,108,246,184,250,78,251,61,223,0,244,175,244,147,254,226,236,23,242,135,244,188,246,184,221,247,254,167,238,56,251,26,222,128,252,46,236,13,253,144,216,168,253,33,230,44,1,242,223,31,255,40,238,104,251,88,229,183,245,57,242,42,248,189,234,10,250,39,233,165,251,92,234,197,246,79,237,35,4,100,229,17,246,162,245,72,248,51,229,10,244,124,234,133,254,48,235,239,246,216,241,196,247,28,233,90,238,133,248,133,254,51,225,207,250,174,253,6,3,243,234,187,253,163,235,215,245,37,236,199,248,199,236,80,255,52,234,74,0,45,236,52,255,132,229,66,255,168,231,162,1,86,226,61,248,204,252,175,248,175,222,146,244,183,249,60,5,38,231,105,252,145,236,65,2,202,224,4,248,175,248,244,245,11,227,47,249,80,247,11,248,138,228,75,250,30,228,1,246,204,221,9,248,52,233,225,247,148,229,71,251,219,233,179,249,135,225,42,248,83,253,183,248,73,230,46,253,55,242,179,253,42,231,159,250,21,252,228,253,166,226,205,250,42,242,163,1,208,231,115,249,193,236,30,245,197,221,106,244,55,236,132,247,37,223,66,249,189,237,202,242,151,217,87,242,166,233,127,246,71,216,227,247,113,233,88,254,21,219,184,251,182,241,231,253,182,222,114,252,151,248,82,234,247,10,147,6,75,253,5,231,123,2,245,13,34,251,136,226,232,8,92,8,44,0,209,221,112,4,135,11,230,252,27,234,149,10,4,8,148,3,30,226,142,2,101,3,135,0,229,228,199,3,129,5,102,3,102,225,75,8,238,12,206,3,233,228,2,11,250,4,114,249,27,234,185,8,245,3,215,1,73,228,57,7,112,6,198,0,20,230,98,6,200,2,219,255,145,227,210,3,40,1,197,254,16,226,176,13,220,12,40,255,100,225,185,4,197,4,255,254,23,225,153,8,229,6,7,250,91,228,199,14,72,10,129,250,67,234,109,6,130,5,146,253,162,230,63,11,157,4,9,253,95,228,65,12,194,11,38,2,175,227,47,7,79,3,219,252,26,230,149,8,26,1,184,251,124,221,37,6,196,7,190,251,127,225,250,4,68,3,82,251,41,225,154,11,183,13,183,251,208,228,128,6,76,5,118,246,74,230,50,11,225,8,51,1,203,227,53,3,35,11,101,250,129,232,167,6,209,7,193,246,110,224,10,4,55,8,239,0,192,232,120,7,45,1,47,254,45,232,73,3,123,1,55,2,57,231,50,0,238,1,146,2,70,230,215,3,79,2,131,252,132,234,101,3,139,8,81,246,174,230,60,0,9,6,45,252,207,229,3,2,182,7,203,255,196,230,219,6,45,5,5,251,51,232,57,10,161,9,145,253,94,227,113,8,82,2,189,247,100,227,250,2,57,6,44,248,15,231,167,2,230,5,46,246,241,231,241,0,160,11,161,249,121,222,214,11,205,15,94,255,101,231,66,0,161,8,201,247,204,234,255,4,195,12,202,248,218,230,55,5,168,10,161,249,180,224,46,4,124,9,129,251,199,231,221,10,45,9,130,248,226,232,115,4,49,12,108,255,86,231,177,9,65,12,240,248,244,227,186,6,131,9,190,249,162,229,37,7,179,14,135,251,199,229,241,6,173,8,188,4,201,226,43,7,43,14,33,254,125,227,10,0,102,9,199,249,199,223,57,12,228,3,202,244,74,223,254,5,53,5,166,248,173,226,25,13,62,6,5,247,45,227,141,10,22,9,113,251,8,223,228,8,236,10,226,253,148,215,247,5,89,10,115,251,8,224,30,14,14,10,54,249,93,234,38,6,197,6,114,4,188,36,28,226,67,0,79,0,206,33,124,240,78,5,196,255,169,33,70,237,117,0,14,9,206,30,103,238,248,6,176,4,188,33,19,232,39,15,21,252,182,37,76,229,24,7,205,0,158,36,103,230,145,3,83,7,84,31,250,231,110,4,86,9,106,30,150,236,30,8,191,248,243,33,25,232,199,2,196,2,79,35,64,234,128,11,146,248,227,38,72,236,153,5,167,253,153,31,241,228,21,12,226,244,39,33,144,228,111,9,19,0,172,36,89,235,249,13,161,245,143,33,53,227,252,8,28,252,144,35,101,237,173,5,2,246,191,29,175,234,84,2,164,0,132,38,121,228,105,13,154,253,52,34,204,238,187,8,60,252,246,36,204,237,43,1,226,248,135,39,82,234,129,10,7,251,163,42,209,226,145,10,17,252,169,44,78,228,130,5,82,251,154,38,249,226,149,11,153,248,204,29,157,235,1,3,155,245,233,31,58,235,214,8,70,0,142,34,80,231,147,7,14,253,235,27,39,234,224,4,53,252,156,41,147,234,167,3,137,0,98,30,123,230,4,10,116,248,174,34,203,235,190,4,151,254,100,38,177,236,26,1,254,1,58,39,10,232,55,15,134,248,29,31,26,230,238,13,79,254,125,33,106,238,246,13,71,251,206,32,63,237,7,4,189,250,152,39,164,225,52,10,11,6,162,38,144,227,232,6,197,251,215,32,71,230,62,253,198,255,40,31,98,226,229,0,125,255,241,40,94,221,142,4,109,255,162,42,10,239,117,12,148,246,200,40,178,235,152,255,171,251,219,43,126,230,77,9,111,246,39,33,128,224,62,4,230,0,247,38,21,232,167,252,122,255,147,32,158,230,208,4,223,246,34,43,102,238,95,4,206,247,19,49,40,234,45,7,242,247,25,46,42,234,120,2,240,250,168,39,15,234,231,5,131,248,120,30,183,230,51,0,199,250,5,31,72,234,134,9,58,243,154,25,6,241,52,8,196,5,105,35,112,234,30,255,160,251,42,42,48,228,13,255,122,0,189,40,200,228,16,1,218,252,238,34,46,221,162,5,120,254,241,38,69,236,241,7,119,244,107,28,200,239,242,11,192,255,119,43,144,234,237,17,101,243,154,37,246,229,179,10,114,244,31,27,14,235,118,17,240,3,224,226,57,252,120,11,22,252,82,222,179,254,50,27,46,10,194,226,192,242,84,14,7,5,139,224,197,252,28,20,73,4,46,230,198,1,88,19,96,0,235,225,66,248,89,12,44,254,117,227,148,251,231,15,220,255,67,224,241,254,79,20,22,15,34,220,98,248,253,10,86,7,129,217,72,252,186,18,194,11,183,227,151,5,106,16,164,9,82,218,157,0,158,18,22,4,101,219,206,4,121,23,142,11,6,211,192,255,182,33,128,20,146,229,53,2,206,10,92,8,22,223,247,255,36,11,247,4,229,211,167,251,223,19,121,11,151,223,44,8,143,17,240,4,1,217,223,2,225,14,205,255,168,220,24,252,119,12,204,254,93,227,61,248,95,10,111,5,24,228,235,255,237,16,113,8,112,232,252,249,215,13,128,3,205,224,244,251,193,7,249,5,208,219,212,7,74,20,34,1,212,211,184,252,122,22,118,6,86,220,162,246,196,16,157,11,152,231,70,3,235,13,199,4,93,229,56,245,183,13,119,0,211,227,42,248,12,17,250,2,201,234,233,251,181,17,166,0,70,228,127,253,229,7,127,2,76,222,55,247,4,14,143,1,48,231,38,250,232,13,120,253,135,228,114,247,6,19,2,10,19,227,210,255,188,14,187,253,40,232,28,3,23,20,173,7,101,233,175,3,152,22,214,11,81,223,185,5,24,28,1,16,189,223,21,3,62,22,171,7,138,214,149,248,116,22,85,10,190,223,219,252,114,14,227,8,35,229,52,252,31,25,88,12,173,230,107,1,106,27,57,12,117,231,178,250,71,20,244,5,107,221,171,243,23,16,205,6,58,232,245,254,43,15,189,252,170,227,8,4,213,25,177,15,50,211,234,242,41,18,98,13,169,229,225,1,4,24,215,4,238,234,90,255,189,20,93,12,234,224,44,4,172,16,16,255,232,214,208,8,236,30,12,11,244,235,252,255,107,22,152,4,61,222,120,0,183,12,139,253,97,218,182,7,166,34,10,17,89,214,59,251,149,14,77,2,224,223,205,248,174,22,95,10,166,223,231,4,199,33,150,13,233,207,31,250,83,35,112,24,208,211,168,252,224,27,73,18,88,209,46,253,5,31,237,12,68,225,49,254,190,26,100,16,25,222,15,255,242,28,227,20,103,26,184,237,4,254,196,4,56,20,33,232,176,3,121,0,187,26,221,233,168,250,235,253,240,21,4,233,65,250,73,253,142,23,31,236,240,248,84,252,20,29,169,234,204,255,89,7,111,16,65,232,6,254,35,6,129,26,198,238,119,253,12,12,230,18,162,235,234,7,182,11,105,16,98,233,133,2,19,7,18,27,247,235,108,248,162,6,188,24,237,237,180,2,211,11,141,24,38,239,150,255,60,14,111,24,182,234,73,248,230,2,103,16,188,237,53,254,4,7,216,21,132,234,65,5,20,5,6,17,76,234,68,247,114,0,12,18,13,233,229,249,120,3,28,19,130,226,185,254,93,254,126,18,83,228,7,0,101,2,43,15,70,234,79,248,56,4,234,21,130,236,52,255,66,3,21,16,174,230,9,251,85,1,185,25,13,236,124,3,145,4,232,25,157,241,46,1,186,11,182,24,25,235,41,252,30,251,30,17,232,227,38,253,98,255,107,20,116,230,61,254,99,4,92,21,184,230,154,252,65,250,71,20,254,230,171,250,129,255,239,28,83,231,51,252,176,254,3,18,126,230,204,252,68,248,99,19,217,235,254,247,58,252,62,17,197,233,45,255,26,252,66,23,15,233,238,2,43,249,42,17,68,237,12,251,254,0,249,27,186,231,14,252,177,2,101,19,242,241,68,9,175,6,104,24,220,231,213,3,96,3,73,25,40,235,13,2,168,253,239,17,48,229,149,251,124,252,170,24,216,230,3,252,137,254,206,22,191,231,81,251,176,3,188,20,93,235,204,247,243,4,246,16,28,233,155,249,180,250,48,22,220,238,53,251,152,255,36,19,254,239,169,5,206,15,69,18,68,239,150,255,118,12,150,29,227,231,176,252,67,7,93,25,217,227,125,255,214,2,137,21,115,235,187,247,4,0,47,24,72,227,63,255,7,254,253,22,19,239,68,1,122,255,18,24,63,232,200,254,4,248,120,16,200,231,238,248,196,253,20,22,133,228,72,253,59,255,219,27,235,227,146,254,196,255,168,19,61,237,22,250,16,11,218,28,254,237,162,253,161,13,115,16,89,236,197,4,231,11,210,15,211,237,48,6,189,5,196,26,74,235,187,248,206,0,56,30,48,237,254,248,31,13,146,24,145,242,242,5,150,9,232,6,102,23,72,234,222,245,63,15,206,20,6,250,35,250,168,9,154,14,187,247,112,239,188,12,72,21,120,252,131,237,155,5,129,28,164,241,250,239,0,16,63,23,112,253,16,243,130,8,121,23,182,243,116,241,203,14,117,21,159,234,159,249,182,11,118,28,250,242,13,242,78,11,176,25,156,237,12,245,62,3,19,24,66,239,236,242,147,18,193,21,62,249,77,245,252,17,177,23,22,242,211,245,189,10,21,20,110,240,41,245,102,15,11,19,161,247,244,242,3,11,69,33,44,248,92,245,98,8,154,24,79,253,235,243,76,20,104,25,191,242,61,250,59,7,194,32,44,249,116,250,146,13,124,33,50,242,128,245,151,17,136,29,23,242,59,247,81,17,75,24,167,246,217,249,178,13,80,28,29,247,71,248,162,13,241,28,181,243,164,253,118,16,47,25,64,242,4,2,107,2,122,27,195,252,87,249,196,6,227,28,156,254,96,247,202,4,84,20,34,243,108,241,235,7,243,21,235,248,206,239,6,12,245,22,47,0,165,245,118,6,82,21,168,1,86,253,91,12,88,21,22,248,242,254,68,11,255,20,83,253,238,253,134,11,118,28,221,255,105,244,194,7,202,19,171,253,226,1,131,13,212,16,251,240,227,246,83,12,125,27,190,250,7,239,145,8,40,26,51,253,217,250,93,14,225,19,204,240,25,254,138,8,16,20,166,239,44,250,5,3,164,22,107,252,49,3,185,9,146,25,14,242,187,247,199,4,69,25,174,250,223,255,15,1,173,23,70,250,67,249,236,9,51,20,201,248,8,4,244,9,131,20,119,245,141,6,3,3,176,29,0,253,136,253,102,18,247,25,128,237,5,251,89,5,29,23,101,244,224,251,163,0,119,20,85,242,29,247,56,8,189,16,117,243,42,243,83,4,243,28,76,248,121,249,148,8,94,28,250,246,122,248,12,255,39,25,47,249,185,252,221,12,248,14,182,244,72,244,163,1,43,25,133,254,105,254,5,12,66,19,124,251,203,244,83,8,242,22,230,246,224,0,178,2,138,25,92,247,231,244,66,6,69,17,45,246,6,6,246,12,157,36,40,244,107,242,14,22,38,29,223,235,73,250,43,16,225,27,253,249,7,243,153,13,117,35,147,249,187,241,189,225,119,1,150,255,225,253,117,222,157,250,182,253,51,254,94,216,132,252,46,8,182,2,89,224,126,1,248,1,187,254,156,222,164,255,94,0,112,253,220,226,38,0,152,0,132,1,182,223,241,254,53,254,141,252,1,225,104,253,254,251,222,252,107,223,147,255,85,3,161,0,158,221,181,250,75,4,118,2,3,221,250,255,84,4,99,253,164,227,16,250,213,255,105,254,125,226,82,255,156,2,254,245,202,220,130,255,227,0,89,251,8,224,1,3,34,1,161,250,252,218,55,0,194,3,8,250,25,222,29,2,243,2,250,251,142,217,166,249,70,3,204,249,191,222,66,253,20,3,50,248,139,216,234,249,146,254,207,248,57,224,78,0,199,5,235,248,88,220,58,254,57,1,6,249,126,226,196,251,63,3,118,246,104,226,67,253,20,8,127,249,145,225,55,250,51,6,240,248,211,229,172,253,159,255,34,3,6,227,241,255,172,2,61,252,41,228,35,254,117,255,86,254,95,224,146,255,220,255,248,254,60,226,126,248,178,253,155,255,33,226,79,251,23,1,148,2,80,225,74,248,246,2,33,247,208,222,89,255,184,8,137,251,198,222,177,250,112,2,28,253,150,227,228,251,38,4,117,255,136,225,39,255,91,0,254,248,138,228,98,249,69,252,103,2,196,220,184,248,101,0,122,247,72,219,28,253,86,2,101,253,0,223,96,251,232,7,8,251,148,221,198,253,127,252,176,246,193,214,250,250,26,2,0,250,232,221,136,252,191,251,139,250,88,228,95,251,124,2,28,251,104,217,233,0,40,9,242,252,240,224,210,250,134,254,101,248,217,227,134,254,128,5,67,247,237,222,247,249,134,3,61,248,53,220,62,250,156,3,53,249,33,224,32,252,179,255,72,245,105,223,148,0,89,254,219,249,111,220,119,253,2,255,66,251,21,221,200,1,25,1,143,248,123,221,179,0,118,254,182,245,71,220,245,2,11,6,217,250,209,217,45,253,185,1,112,249,50,221,82,253,249,5,11,250,236,218,146,251,16,8,86,252,33,232,81,252,165,2,225,255,13,227,155,253,210,252,46,0,249,218,102,252,82,254,243,247,222,211,12,251,38,5,163,251,2,224,64,3,159,2,90,247,43,215,218,253,136,6,138,252,20,4,137,36,141,249,209,234,10,4,213,31,57,254,234,231,249,2,101,32,114,243,26,237,170,3,141,31,164,0,246,235,15,5,225,33,22,10,142,234,198,254,37,31,165,246,145,235,5,254,52,35,63,246,113,233,92,9,122,32,2,252,191,237,20,250,53,33,158,7,151,236,204,254,233,28,13,6,254,236,144,255,148,32,187,11,200,236,206,255,99,36,91,5,222,233,109,253,233,36,192,9,85,234,13,10,188,35,34,247,81,237,62,3,192,27,74,254,189,240,10,2,176,41,91,253,173,230,90,251,124,39,2,254,138,230,85,254,79,32,189,253,85,231,66,6,177,31,121,248,190,238,38,247,244,31,192,1,186,235,159,249,112,34,30,255,117,233,247,2,9,37,151,255,75,233,206,8,23,26,46,254,226,233,168,255,34,27,127,3,186,232,87,249,25,39,114,5,58,234,236,2,7,31,28,2,220,229,131,5,97,27,232,0,255,231,185,2,122,28,59,251,34,235,28,249,84,41,152,7,115,240,202,250,164,35,171,4,193,240,119,252,83,39,123,2,81,236,152,2,184,41,49,0,239,237,94,5,64,37,247,252,249,241,252,0,226,37,171,253,141,244,56,3,204,35,10,252,160,247,134,9,73,41,15,247,184,238,53,8,190,27,251,1,226,241,38,1,115,31,80,254,18,250,103,253,97,40,35,2,220,244,144,4,213,46,20,254,205,234,64,5,16,25,46,1,59,236,65,249,232,47,227,5,65,238,162,2,137,42,122,252,235,241,186,253,32,37,44,1,222,241,129,2,230,29,177,2,195,247,17,8,27,36,252,1,241,238,31,4,181,32,176,2,184,243,127,253,249,31,218,3,21,243,96,4,2,29,249,6,83,241,124,6,134,31,175,253,224,243,210,7,251,36,70,249,109,242,57,9,176,32,100,0,131,241,252,252,165,30,155,253,132,236,205,5,6,29,104,7,17,232,80,254,143,30,77,252,190,244,57,1,114,43,8,253,249,236,156,1,220,32,229,254,121,239,49,6,162,40,164,248,61,243,65,1,40,27,5,3,56,244,151,255,54,35,121,0,55,247,49,6,73,40,47,252,52,237,83,6,93,46,26,5,36,229,112,251,182,34,175,255,60,246,117,254,134,42,221,2,166,230,171,236,178,16,152,15,226,251,111,239,179,20,166,16,208,249,106,245,22,15,200,17,119,249,0,238,168,9,88,14,77,249,229,244,0,11,163,15,234,246,147,235,148,11,4,22,90,0,196,236,114,13,151,19,184,251,255,250,241,12,161,21,238,247,32,241,147,7,255,16,105,252,133,248,25,10,75,19,178,249,114,242,51,7,186,21,86,253,40,241,102,3,195,22,144,0,135,236,172,5,120,18,59,253,95,241,190,10,52,28,3,1,173,248,108,7,114,25,198,252,23,239,38,6,24,28,24,5,224,234,164,5,64,24,119,2,1,243,192,20,75,22,251,249,202,228,6,13,194,15,4,4,196,226,149,16,122,16,44,255,89,230,207,22,187,17,0,254,173,233,47,23,163,14,94,251,246,230,17,19,28,13,182,249,230,235,30,10,34,11,124,8,180,235,255,15,9,10,139,254,77,236,137,23,222,16,180,2,107,234,20,19,185,13,114,1,108,229,109,29,180,22,24,254,231,233,176,9,221,15,210,4,173,243,192,5,183,23,164,4,157,242,97,20,114,13,90,3,166,237,197,11,141,21,26,10,159,238,178,8,42,21,252,13,5,231,219,13,111,21,236,7,84,242,155,19,179,18,1,0,58,240,18,10,1,12,79,12,66,245,163,7,117,17,16,15,192,233,123,6,230,23,165,9,2,239,217,4,184,26,54,12,67,234,194,19,76,20,34,5,150,249,94,16,108,15,95,2,47,251,12,16,242,18,128,253,27,252,100,13,167,12,98,5,168,230,181,10,14,27,232,10,164,239,179,14,139,16,226,7,118,243,152,12,14,22,147,5,106,234,253,26,206,19,141,253,1,245,154,15,97,13,111,7,141,247,174,10,47,21,145,0,203,239,151,16,51,9,222,2,102,254,217,9,42,16,240,255,149,246,81,9,63,19,57,8,67,232,7,14,42,12,82,2,166,239,226,18,38,23,20,252,109,227,41,13,78,23,192,1,126,228,89,22,139,22,238,0,142,238,67,15,207,13,41,249,188,247,130,15,19,24,144,250,185,227,95,8,215,32,46,14,201,234,134,17,86,25,214,255,174,248,81,6,189,24,7,2,178,230,69,10,26,18,7,254,152,225,38,9,48,28,85,5,126,251,152,5,223,18,8,6,156,236,87,233,5,7,250,1,172,238,7,229,35,4,43,251,232,234,26,229,116,3,222,254,141,231,65,228,11,2,29,255,45,237,206,230,132,5,62,254,40,240,187,231,189,6,81,252,246,233,53,232,77,5,93,2,156,239,210,233,139,8,83,255,138,237,250,235,166,9,65,1,14,230,29,236,227,5,19,252,72,235,126,235,152,7,43,6,245,227,112,234,188,5,87,254,111,232,225,236,84,7,69,252,61,230,233,235,159,8,11,5,128,239,177,236,54,7,0,7,40,228,218,228,27,2,212,2,239,238,219,236,30,10,79,4,11,227,192,233,176,6,160,5,3,233,91,229,162,1,103,3,84,229,33,234,198,2,229,249,21,232,71,233,78,5,95,6,85,235,10,234,66,2,90,8,253,227,140,232,91,1,160,8,61,232,125,235,84,8,169,1,23,239,167,233,151,1,79,244,50,235,64,236,95,4,211,248,147,234,32,233,185,0,171,246,127,230,198,235,147,1,71,253,193,229,196,238,166,10,103,3,250,235,3,234,43,7,253,252,10,234,247,238,157,11,90,3,94,235,249,232,45,0,177,254,251,238,232,233,160,6,234,249,29,228,253,229,115,2,103,254,193,238,72,231,35,0,26,5,41,226,34,232,110,4,197,0,214,241,40,234,227,7,133,3,37,242,56,236,152,4,202,6,45,236,197,240,39,8,10,1,10,240,89,231,199,5,104,1,190,231,156,235,57,255,59,250,186,240,57,236,76,5,241,255,64,226,143,236,205,1,97,9,26,232,13,232,234,4,205,253,17,232,152,236,6,5,229,255,231,239,36,233,89,4,196,5,219,235,239,236,138,4,106,253,227,237,89,236,155,4,197,2,123,234,180,234,115,254,200,4,11,238,51,229,134,2,211,1,153,231,53,240,212,1,22,1,40,235,191,230,106,3,64,250,170,228,54,231,78,0,250,248,205,236,78,238,196,10,53,255,96,232,235,238,188,5,28,4,79,239,68,228,174,3,189,254,104,230,65,239,47,9,69,0,214,228,251,237,210,2,241,5,151,239,15,235,251,2,230,249,31,229,36,234,20,253,157,2,217,229,37,242,222,255,19,5,115,240,160,233,84,0,111,0,201,237,55,237,125,8,249,251,57,230,67,232,23,5,0,1,84,226,87,239,97,233,212,239,46,230,58,245,88,235,160,240,8,233,231,240,93,230,240,243,196,227,122,234,3,226,184,240,106,221,103,230,130,223,15,235,110,219,127,235,243,230,33,239,190,238,218,243,32,231,250,238,88,234,149,239,49,229,107,236,16,244,36,239,65,234,147,243,250,243,145,232,69,236,159,245,4,233,108,231,132,233,83,240,39,237,59,238,97,234,43,240,165,238,18,232,60,235,168,250,124,240,59,231,46,232,130,245,137,233,35,245,234,234,170,231,142,238,9,232,62,234,161,241,61,239,152,232,20,242,187,235,235,227,179,238,145,227,62,232,44,236,175,238,68,245,10,235,175,231,247,244,79,229,225,233,83,244,72,237,136,240,116,238,100,225,163,225,214,225,147,233,97,230,185,233,44,233,43,234,68,226,194,234,216,239,66,241,134,239,176,239,65,230,227,246,27,237,57,236,75,230,66,1,66,230,154,232,92,244,249,240,74,234,101,244,143,234,116,248,167,228,53,235,145,236,95,249,170,237,128,245,8,229,28,244,193,222,253,234,121,233,11,246,132,226,220,234,134,230,244,245,59,230,147,236,233,230,6,251,241,230,74,240,208,235,208,251,104,234,102,234,206,227,215,246,19,237,59,237,201,232,53,251,95,232,18,228,168,229,143,247,155,220,125,227,162,222,233,238,110,236,86,234,216,234,174,255,217,239,147,239,11,236,211,242,17,243,19,233,89,240,59,236,151,232,184,230,134,240,146,237,106,244,56,233,251,244,95,231,13,237,224,235,237,247,166,240,220,241,167,238,222,242,52,233,139,238,155,235,74,238,40,234,74,240,65,231,31,239,37,232,221,236,105,238,244,243,115,241,118,238,172,223,244,237,164,231,65,230,10,239,59,227,33,240,158,230,63,236,79,234,229,1,84,232,102,245,75,228,208,239,201,231,162,225,74,228,39,240,144,226,232,230,241,230,87,239,241,226,106,246,52,231,37,237,43,235,115,226,191,238,225,237,255,238,65,228,155,239,127,245,147,235,107,230,247,235,108,229,15,232,235,225,140,235,28,237,115,229,113,240,212,240,202,238,32,230,141,238,119,237,68,236,4,243,84,226,96,245,103,230,159,234,116,231,88,249,97,238,221,239,161,227,148,243,180,235,52,228,67,234,115,242,173,2,142,232,123,232,238,240,64,2,184,243,245,223,245,250,78,254,48,232,141,228,92,240,73,5,153,240,227,225,216,246,220,255,98,238,145,229,174,245,119,2,183,241,235,210,246,245,112,240,185,232,106,221,203,250,157,252,213,229,94,221,186,249,168,254,4,241,231,224,226,246,20,248,154,242,147,224,35,244,96,253,228,240,32,220,205,241,229,248,94,239,156,220,195,245,16,252,245,241,11,222,26,248,16,253,35,238,144,224,162,243,194,245,12,237,33,225,131,250,0,1,17,238,111,228,232,249,197,3,205,228,25,226,44,252,40,3,197,235,15,230,228,242,172,4,66,228,227,228,18,245,75,8,45,229,54,233,8,243,254,252,167,232,55,227,60,246,246,252,240,231,0,231,90,252,17,246,171,229,72,226,157,254,247,250,56,229,190,230,103,250,149,249,78,237,108,231,150,236,120,1,225,234,94,221,49,247,112,254,26,241,150,230,149,250,220,241,122,236,7,232,80,251,4,240,253,235,171,218,223,244,230,250,93,239,212,230,213,238,174,254,155,235,102,229,141,252,201,4,7,232,185,231,139,247,42,2,201,240,99,230,152,243,219,248,210,240,4,224,169,255,70,252,181,227,205,229,88,247,196,254,40,234,74,226,85,0,80,254,139,240,247,224,8,254,112,255,247,237,56,226,218,0,200,254,67,237,223,221,180,252,229,251,130,238,188,222,135,250,58,254,51,238,110,228,210,254,228,246,33,230,200,225,241,254,206,255,171,243,148,226,169,251,97,247,250,241,124,227,9,251,5,2,166,238,118,227,5,254,78,2,198,230,156,226,9,245,154,2,129,236,238,222,221,242,239,252,206,226,139,226,224,251,209,248,179,226,132,223,86,252,76,255,47,235,197,225,189,253,219,246,59,238,105,228,80,255,45,242,185,235,92,222,32,250,102,239,245,243,110,228,53,247,32,0,93,240,125,228,187,251,233,252,109,234,99,224,90,253,142,255,50,244,231,215,234,247,219,243,191,240,126,231,74,255,188,241,59,243,255,219,217,253,166,245,190,243,158,219,66,249,88,249,188,238,157,215,48,249,125,242,189,239,95,222,6,247,239,239,66,234,151,230,39,251,49,254,198,243,238,217,208,246,236,236,111,225,145,242,171,5,68,250,253,222,10,243,56,9,77,254,242,222,222,239,158,5,0,252,47,219,44,238,48,5,79,253,250,212,126,243,230,8,32,8,179,223,55,245,110,255,72,254,183,226,198,245,90,255,157,1,198,223,12,244,10,2,171,247,83,223,10,235,67,5,61,254,115,222,117,240,127,11,202,2,81,224,244,245,248,4,44,249,106,225,183,235,93,2,52,250,73,224,128,237,93,8,0,1,212,225,95,237,183,5,212,252,61,227,185,240,236,9,4,0,218,224,187,242,59,9,86,5,65,227,148,239,216,6,66,252,58,226,79,242,148,2,148,3,50,217,175,241,93,12,60,3,239,221,190,239,62,0,182,6,39,219,96,237,162,10,210,4,232,224,112,238,138,0,248,5,250,223,130,242,69,254,119,2,180,225,58,247,143,2,113,4,119,221,183,243,89,4,61,3,119,225,30,243,227,4,230,0,59,219,83,245,67,1,186,248,64,219,184,239,246,4,13,6,179,220,204,240,82,252,27,1,193,223,247,240,21,5,226,6,159,220,109,240,215,255,86,253,31,219,165,239,227,7,145,255,244,217,150,243,66,6,153,252,104,223,86,246,181,5,226,5,232,217,147,244,204,7,219,4,17,220,44,241,180,0,25,2,156,220,155,246,116,4,230,249,124,219,184,246,53,1,94,255,222,213,146,243,251,255,36,250,50,224,68,238,78,254,198,252,152,226,219,246,80,4,183,255,112,219,158,245,246,11,56,0,181,223,225,246,208,7,87,251,119,208,174,243,7,5,128,253,122,211,184,247,178,3,117,251,20,221,49,238,72,1,96,249,239,212,139,239,253,10,72,3,248,219,3,242,176,8,247,7,17,221,247,242,224,4,238,250,36,225,54,240,229,1,224,247,251,219,101,248,143,8,144,252,246,213,248,248,212,9,188,254,145,216,66,247,213,3,201,250,124,209,8,245,183,12,133,2,112,214,247,239,3,5,173,253,17,226,209,244,163,9,227,252,40,214,242,240,126,14,2,6,185,213,179,244,128,5,223,252,110,217,8,241,0,1,154,249,102,215,193,242,11,9,162,255,251,210,17,240,57,16,74,8,182,218,216,247,5,6,225,1,229,221,127,246,18,4,112,8,84,225,119,240,166,250,141,6,160,27,164,242,118,5,51,249,36,24,72,248,0,5,27,242,12,30,255,248,28,11,92,249,171,32,19,249,32,12,137,245,253,35,62,243,172,14,42,242,178,37,172,245,146,5,218,250,32,30,20,245,102,14,73,248,148,28,67,242,5,11,146,253,10,29,222,245,1,9,40,247,69,28,251,248,255,0,214,243,215,33,65,248,58,5,16,244,216,25,72,252,219,15,164,245,119,34,209,250,82,5,180,250,210,38,70,249,7,5,198,246,39,28,223,251,121,7,221,250,84,29,207,249,102,3,66,248,25,32,160,241,137,5,158,243,137,32,19,246,148,6,183,253,126,31,225,246,252,0,16,245,12,32,244,239,25,12,247,245,21,30,217,242,64,2,64,244,182,28,238,252,110,9,175,247,36,27,248,245,71,6,31,255,4,30,173,246,28,5,135,242,114,32,126,242,90,9,82,250,246,32,35,245,19,4,174,250,215,35,228,247,96,8,61,248,155,32,107,245,161,13,51,239,64,22,183,246,54,11,83,3,121,34,37,251,171,8,213,245,97,34,178,249,72,2,47,246,221,32,128,254,141,5,60,247,12,36,22,244,207,12,140,247,198,24,118,245,219,13,149,255,69,39,84,246,21,11,160,243,15,29,164,253,105,12,105,240,69,30,216,251,233,16,9,237,207,33,127,247,204,8,65,242,42,33,28,255,166,7,95,243,17,41,104,244,119,7,220,246,210,31,162,252,92,7,69,249,108,30,102,253,188,11,181,244,105,30,172,249,37,16,167,242,22,40,109,241,127,13,101,244,122,33,119,252,167,17,215,237,169,35,254,245,207,1,95,246,235,36,253,241,112,7,16,244,149,25,68,247,194,11,85,238,7,28,132,245,151,11,126,242,144,38,50,243,30,4,88,246,193,35,93,252,193,4,251,245,85,34,115,242,241,2,248,245,27,26,49,241,5,7,128,240,145,26,71,248,7,9,60,254,192,24,220,249,52,10,64,243,60,31,16,252,218,2,108,244,97,29,221,251,37,6,146,241,212,31,123,240,40,10,12,242,85,30,4,250,224,9,240,240,236,28,178,240,120,17,113,255,190,34,138,250,227,12,155,241,136,22,7,248,207,5,131,253,11,20,207,244,159,9,213,252,39,25,224,249,172,13,242,249,82,221,114,229,57,235,84,250,68,231,15,218,216,243,34,252,4,223,84,231,146,241,81,253,21,232,168,213,203,241,250,238,80,237,148,218,31,238,235,245,36,232,237,214,5,237,36,246,75,226,162,226,233,246,19,245,66,218,185,221,93,246,38,248,162,230,157,226,149,237,138,255,158,223,234,220,120,249,195,254,162,221,213,212,208,240,110,250,127,231,33,230,121,229,114,255,135,223,12,226,163,247,5,251,203,230,36,223,251,241,250,239,165,229,186,225,198,233,62,246,122,225,219,229,154,243,114,246,113,215,110,216,165,240,196,246,146,214,237,222,93,234,44,245,253,218,241,229,23,243,33,247,234,220,15,219,253,233,91,240,129,216,227,224,141,230,172,239,123,227,177,230,12,235,208,2,185,218,217,220,15,225,112,252,194,218,142,222,115,242,128,254,79,226,152,215,123,243,153,251,104,224,84,222,166,236,184,244,246,223,42,223,130,228,65,241,112,227,124,223,250,242,17,249,138,222,210,219,121,224,178,239,100,228,220,211,59,234,165,244,153,223,8,221,242,238,248,249,160,212,30,216,19,247,128,254,163,235,160,226,112,236,197,250,255,232,252,224,157,232,151,250,192,213,247,223,199,239,51,250,219,215,41,221,85,231,140,249,0,233,176,215,19,241,59,249,255,214,243,227,61,232,40,244,215,225,4,218,65,230,40,235,200,233,42,225,98,242,8,246,226,216,252,214,81,243,204,252,99,231,195,221,102,238,149,244,187,223,89,225,187,231,240,249,28,216,199,226,79,224,142,240,230,228,134,213,70,232,161,237,241,227,40,213,162,238,19,249,48,228,23,220,82,248,51,246,166,231,209,219,247,246,68,239,201,222,127,217,131,246,160,253,100,219,92,225,57,223,184,247,241,224,11,228,121,230,245,255,168,227,255,218,132,247,108,253,177,216,116,218,45,246,241,255,228,229,82,220,35,232,146,239,244,223,100,209,156,235,254,246,18,218,206,229,237,239,53,243,57,229,90,228,151,246,161,238,80,227,7,226,129,238,236,239,109,221,70,229,193,236,124,244,33,221,44,215,255,233,110,247,77,222,214,220,248,227,217,249,239,223,6,218,147,228,4,243,70,241,247,215,217,241,48,237,9,224,215,226,6,240,134,2,29,224,19,228,200,0,242,1,159,223,134,231,174,2,50,255,210,216,159,231,248,251,184,248,167,221,121,223,251,252,87,255,67,220,185,231,201,3,241,255,145,223,29,233,249,255,214,7,46,218,141,227,255,0,42,5,179,219,197,227,71,0,25,255,179,222,185,231,31,1,187,252,19,215,253,234,135,4,169,5,26,214,80,225,126,255,102,0,10,222,219,226,70,251,178,2,105,219,52,235,79,4,98,12,66,214,137,224,193,252,97,6,15,220,39,229,112,245,210,8,27,223,18,235,131,250,226,0,150,220,58,233,205,254,221,249,114,212,43,227,70,245,124,252,6,217,219,232,42,248,75,254,8,219,123,237,239,254,37,4,209,214,228,229,167,251,124,6,167,216,56,234,59,4,243,254,134,221,125,233,64,6,206,5,51,215,145,220,27,251,192,255,203,208,89,233,2,0,1,3,117,205,249,229,114,6,157,5,76,213,222,230,28,251,119,253,126,210,110,225,251,247,198,2,166,208,179,229,159,248,37,253,123,220,49,232,97,246,182,252,31,213,244,238,213,1,164,1,32,211,4,229,247,253,125,3,59,218,154,234,182,252,81,1,146,214,173,235,136,253,175,250,42,216,116,231,126,6,253,4,105,216,84,235,131,9,165,13,237,212,95,230,143,2,56,0,31,213,90,236,103,4,154,254,34,206,110,240,68,5,177,254,92,200,205,225,8,1,61,1,236,196,187,215,4,254,167,5,235,205,66,222,160,253,137,0,236,204,11,222,220,244,81,254,108,212,86,234,52,247,192,249,12,222,58,227,205,252,57,251,37,207,168,217,78,249,135,255,40,214,246,229,32,2,21,13,82,207,254,232,69,246,242,246,76,207,198,227,181,1,232,0,220,211,150,235,20,8,175,2,38,209,128,223,142,253,168,10,66,208,156,234,118,4,18,0,219,215,70,224,142,246,211,7,150,203,29,232,21,242,14,245,89,198,150,217,37,251,21,0,125,202,223,233,245,5,251,1,115,192,252,218,67,253,163,0,123,206,195,234,9,255,5,252,205,209,57,239,75,255,37,251,209,205,112,238,168,11,99,4,220,201,21,225,114,251,221,253,12,208,47,224,14,247,9,250,103,211,34,237,167,11,62,7,239,209,142,232,139,4,148,7,179,44,200,236,93,243,79,12,36,44,40,230,30,250,151,4,238,35,236,237,244,247,86,9,36,41,69,240,125,253,144,3,174,38,11,242,186,249,47,5,181,37,48,242,64,247,77,7,220,38,205,235,89,254,102,10,28,48,92,240,59,248,25,1,93,47,64,237,15,251,93,255,154,41,199,245,223,246,182,5,181,38,152,236,184,246,148,3,144,50,217,237,90,248,204,1,188,50,93,235,139,251,41,0,33,48,157,244,219,241,1,4,185,44,178,244,88,245,95,1,55,47,31,244,46,248,224,255,38,45,65,240,193,250,113,254,183,50,100,241,68,242,221,4,67,47,45,246,64,245,225,0,227,48,119,242,115,245,38,2,91,57,98,236,104,235,180,11,228,47,201,242,65,251,240,253,242,53,210,234,117,246,142,4,109,52,254,234,162,248,209,2,161,50,93,239,222,245,28,3,234,47,200,247,96,237,55,6,211,52,154,237,27,244,62,5,149,48,205,247,22,234,69,8,74,46,121,247,87,242,149,2,243,47,160,240,171,253,71,253,171,48,123,235,251,253,224,253,35,50,2,240,214,250,88,255,24,56,211,233,23,243,67,7,81,54,56,238,43,239,69,8,39,45,172,242,201,248,175,255,67,52,161,243,124,233,186,10,134,46,158,249,10,239,28,4,118,49,122,237,71,0,50,252,1,51,74,243,184,238,169,6,198,58,182,233,13,237,203,11,82,55,210,239,118,234,27,11,220,49,203,248,228,229,72,11,146,53,186,246,98,225,17,15,239,51,129,249,155,223,233,15,48,39,200,239,181,242,141,5,190,42,246,234,82,247,182,3,36,41,15,231,42,249,133,7,33,40,172,232,2,250,131,2,109,41,82,237,97,249,27,0,236,42,223,235,157,251,171,254,109,45,4,233,220,251,48,0,201,40,51,240,129,246,55,1,36,42,245,241,181,239,15,7,78,47,202,233,177,247,208,3,226,45,91,237,177,245,123,3,21,45,77,235,41,244,196,6,152,44,1,246,17,235,150,8,63,45,0,235,64,253,165,2,176,40,114,243,68,242,104,3,179,37,197,234,174,249,183,12,245,38,243,235,28,252,83,15,187,45,221,237,82,254,228,252,242,42,107,245,253,241,254,8,220,41,2,236,123,253,14,1,20,55,182,215,71,4,251,5,144,50,143,224,81,4,27,253,220,51,133,228,1,254,18,1,184,54,170,227,229,254,139,0,74,45,120,230,165,255,135,6,212,45,59,222,234,2,15,0,21,57,83,228,214,249,159,4,27,51,176,231,18,253,252,255,164,54,144,231,200,249,52,3,86,57,21,222,185,1,126,0,211,60,88,221,247,253,115,4,26,61,195,218,85,1,185,2,88,62,142,218,88,255,97,4,104,60,1,216,153,5,255,255,86,58,49,225,234,251,56,4,148,59,50,226,149,248,92,6,125,60,64,223,46,251,204,5,90,62,66,222,233,248,139,7,117,64,88,214,142,1,143,4,18,63,95,216,155,1,150,3,237,56,205,226,71,253,89,2,222,55,196,224,28,0,1,1,177,57,120,229,18,247,38,6,64,55,7,232,135,247,233,4,178,57,129,231,217,243,141,7,30,55,136,223,59,4,237,253,131,59,177,228,79,244,126,8,166,51,83,233,35,2,133,252,204,57,198,221,230,4,10,255,168,62,35,220,19,252,15,6,103,64,154,216,139,254,140,5,229,58,249,218,198,3,51,0,226,50,188,230,164,3,200,251,159,49,248,231,223,255,195,253,25,61,102,229,224,239,58,11,226,51,7,226,47,6,253,250,85,48,18,228,232,5,107,252,192,50,185,225,90,253,15,3,155,42,54,229,199,254,37,10,226,50,253,220,125,0,104,8,226,49,38,217,165,7,7,254,194,48,63,229,12,251,65,3,222,53,219,231,118,255,233,254,165,49,66,223,252,7,227,0,212,47,26,230,203,0,55,254,129,55,96,229,248,251,120,2,30,59,181,223,224,254,128,2,51,53,243,231,190,251,100,1,220,54,11,227,213,2,28,254,158,50,183,225,25,10,68,248,132,51,52,223,2,9,234,249,43,56,4,217,84,8,80,253,195,55,127,217,138,4,179,0,122,53,56,222,85,6,135,252,250,45,83,229,22,253,22,1,188,49,246,223,30,1,90,0,62,53,94,216,75,7,49,255,40,47,220,221,19,5,123,253,52,50,236,218,202,4,62,0,16,46,42,227,202,255,140,255,211,53,202,220,231,1,95,1,175,46,207,225,121,0,66,3,194,46,203,217,228,8,252,255,136,49,208,224,227,10,237,252,244,51,104,199,8,25,121,248,67,53,5,196,193,35,255,243,4,50,2,203,141,21,167,249,240,64,154,213,154,6,28,0,163,79,156,183,18,24,251,254,131,64,158,206,64,13,249,253,184,61,169,212,103,8,54,255,184,65,242,209,115,6,87,2,196,68,99,204,3,10,26,2,228,69,159,200,234,13,147,0,91,66,121,211,101,3,28,4,107,66,88,207,138,9,9,1,153,84,210,170,238,35,30,251,185,65,227,203,140,15,82,253,117,68,86,206,95,7,37,3,35,64,230,212,192,4,105,2,195,81,29,178,45,29,84,253,20,72,226,195,221,17,65,255,186,57,163,216,25,11,71,251,250,67,249,203,226,11,160,0,165,75,254,185,175,27,219,251,170,63,91,209,250,10,161,254,143,74,208,192,167,18,172,255,2,69,255,207,170,3,200,4,149,72,234,193,12,20,82,254,111,77,179,190,46,16,33,2,248,77,33,180,208,32,44,250,29,74,79,190,18,23,174,253,135,74,185,195,200,13,247,1,27,65,59,207,115,17,234,250,79,77,123,186,52,24,239,253,37,78,58,187,234,20,236,255,155,78,89,183,230,26,40,253,124,74,43,198,90,9,81,4,107,56,101,202,255,21,19,248,138,57,105,200,255,21,86,250,217,62,169,193,103,28,19,248,161,52,64,212,164,12,100,252,77,56,106,213,43,9,245,254,2,69,26,183,117,44,88,242,157,57,222,212,233,12,237,254,200,59,10,215,77,7,16,255,217,57,162,208,41,13,152,253,0,66,79,191,139,28,203,248,166,61,0,200,4,21,16,251,11,64,96,195,15,25,204,249,113,53,150,212,24,10,192,254,164,55,218,207,128,17,160,249,143,59,193,204,169,16,126,252,163,54,197,208,141,13,171,253,117,54,30,206,144,16,185,252,203,53,197,202,132,20,152,250,162,58,54,193,168,29,55,247,236,61,182,188,171,33,161,245,233,73,236,189,219,26,35,250,61,58,98,210,208,10,217,254,44,74,79,184,232,32,234,247,97,60,24,197,74,24,23,250,68,58,104,195,37,27,165,248,188,70,146,198,73,18,67,253,192,68,139,194,240,21,249,252,246,54,141,202,72,25,190,245,8,54,118,209,81,20,72,247,158,73,191,181,232,35,87,248,51,209,14,213,76,231,40,247,32,213,169,220,110,230,12,241,232,211,220,214,154,228,161,239,101,216,51,216,137,225,128,245,197,214,252,216,35,220,8,248,180,210,181,211,218,216,109,245,168,203,173,203,214,211,146,239,210,217,7,208,214,226,219,239,166,213,187,204,183,221,164,236,68,209,22,197,205,217,25,236,90,219,52,216,163,220,193,236,214,210,224,211,189,241,39,252,185,219,157,216,18,225,27,240,235,205,84,191,110,211,205,231,172,206,1,221,87,238,167,251,235,201,195,210,191,241,87,253,115,206,227,215,149,234,5,251,116,197,182,205,13,236,91,251,63,202,153,211,198,231,244,248,87,204,15,212,116,225,230,242,39,198,40,209,126,243,200,254,252,194,97,195,30,216,151,242,102,205,40,216,189,243,157,253,240,210,3,217,92,235,101,252,22,205,127,207,252,237,182,251,241,189,111,195,21,232,184,250,12,188,235,186,118,223,133,247,216,200,244,213,39,247,157,255,202,206,57,227,226,234,54,242,193,200,7,206,99,213,150,235,156,198,25,190,150,210,78,234,219,206,67,212,22,220,3,241,144,190,170,190,238,217,8,245,152,214,138,215,96,230,53,251,19,199,0,204,3,221,191,242,68,216,241,222,125,222,197,242,102,211,123,207,110,234,206,248,177,209,132,200,243,229,191,245,4,204,1,224,155,240,110,247,233,216,22,208,98,236,237,248,36,203,101,194,231,218,153,243,16,210,116,212,157,215,103,234,139,208,37,206,66,212,143,241,3,209,169,208,149,222,0,249,157,189,11,178,73,211,113,242,168,204,88,199,252,216,137,243,46,217,200,212,5,232,166,243,87,221,226,210,154,223,106,230,169,219,46,205,250,231,105,245,153,195,27,215,26,249,86,255,143,193,83,210,65,244,118,253,10,189,81,214,102,250,47,0,65,193,222,201,47,237,222,251,10,180,113,179,134,218,96,246,148,177,200,182,135,223,159,248,57,197,43,193,90,226,54,247,87,203,189,192,152,222,74,244,251,201,235,197,208,229,116,248,27,192,204,183,182,217,113,244,201,214,55,223,169,219,50,236,175,211,60,220,247,233,221,243,95,204,119,203,202,219,67,238,44,209,92,202,245,216,26,231,1,213,209,218,208,235,245,239,202,38,78,225,125,31,233,238,82,32,69,225,104,23,208,247,220,37,53,218,197,29,170,241,117,37,82,224,109,25,62,244,73,49,56,209,138,39,16,235,91,46,65,221,12,31,53,235,148,40,14,215,18,36,28,239,252,31,228,223,130,30,79,245,167,40,173,221,198,18,118,248,108,40,115,221,17,36,42,230,206,36,77,228,212,18,194,244,30,38,188,217,208,21,48,247,204,39,198,224,227,20,241,242,125,43,225,226,175,15,254,246,180,41,8,214,205,23,187,245], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1831544);
/* memory initializer */ allocate([2,45,104,208,168,30,209,242,101,34,101,217,197,20,1,244,26,37,74,218,155,25,248,241,248,40,184,224,226,15,28,251,253,43,30,221,180,23,78,245,148,47,99,215,163,19,5,250,178,35,173,222,17,14,89,248,171,31,68,223,106,19,243,247,9,38,64,204,38,25,199,245,170,43,73,215,62,10,246,253,100,37,172,207,79,20,29,248,25,47,144,208,51,16,181,251,87,35,59,217,212,9,103,253,38,42,162,224,250,22,222,238,31,28,22,223,193,24,231,244,98,30,163,223,201,13,142,242,135,29,183,214,156,13,204,250,188,36,77,224,60,29,91,234,112,30,56,209,170,21,243,245,97,36,232,215,237,29,181,235,45,26,27,214,18,17,8,249,54,19,159,211,155,17,81,238,27,20,239,207,138,15,76,234,125,25,85,217,129,17,199,243,114,29,201,205,172,23,38,237,211,33,177,208,247,27,178,238,248,32,216,211,195,17,45,249,0,36,90,213,179,13,85,251,21,24,218,219,163,18,187,237,203,35,245,212,5,22,185,236,129,52,11,211,20,26,126,246,232,30,74,219,7,26,48,240,203,45,79,202,195,31,204,239,177,23,239,215,141,19,73,231,98,45,127,207,216,20,154,248,187,34,156,201,215,32,13,232,150,37,237,206,228,30,11,236,215,44,181,215,157,32,105,240,156,45,233,200,211,25,230,246,175,46,7,221,245,14,242,249,246,40,148,224,253,40,224,232,25,46,239,213,35,38,71,235,221,23,28,222,195,22,190,250,118,27,117,218,248,21,127,233,8,50,170,205,235,33,204,239,157,51,32,215,237,24,139,243,20,46,143,202,207,41,69,232,167,37,243,224,153,37,152,240,90,33,171,228,189,20,197,1,255,255,255,255,255,255,255,255,1,2,4,6,8,10,13,16,255,255,255,255,255,255,255,255,1,2,4,6,8,10,13,16,255,255,1,2,255,255,1,2,255,2,255,2,0,0,0,0,144,22,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,247,32,0,136,226,31,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,22,31,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,1,0,0,0,0,0,0,0,0,0,0,252,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,137,31,0,108,0,0,0,176,28,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,69,0,0,0,255,255,255,255,70,0,0,0,255,255,255,255,169,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,16,80,1,0,255,255,255,255,41,80,1,0,255,255,255,255,29,80,1,0,255,255,255,255,83,85,80,79,255,255,255,255,1,0,1,0,255,255,255,255,13,0,1,0,255,255,255,255,9,0,1,0,255,255,255,255,19,80,1,0,255,255,255,255,0,48,1,0,255,255,255,255,1,48,1,0,255,255,255,255,20,80,1,0,255,255,255,255,45,80,1,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,3,216,5,167,0,0,255,174,254,217,255,120,255,255,255,252,255,250,255,183,255,248,255,241,255,12,0,23,0,2,0,16,0,30,0,3,0,251,255,50,254,82,253,237,1,15,10,55,1,243,255,228,255,242,255,108,254,251,255,237,255,13,0,20,0,72,0,107,0,179,255,8,0,13,0,247,255,208,255,203,5,144,0,16,3,160,3,219,4,122,255,255,255,219,255,204,255,162,255,243,255,185,255,250,255,172,255,248,255,212,255,144,255,246,255,197,255,186,255,179,255,19,1,194,13,32,4,26,251,0,0,252,255,11,253,188,255,161,255,1,0,16,0,197,255,4,0,239,255,29,255,251,255,21,0,13,1,80,0,131,255,216,255,248,254,125,1,163,19,0,0,0,0,252,255,248,255,250,249,0,0,254,255,0,0,2,0,0,0,6,0,38,0,12,0,81,0,139,255,138,0,76,1,167,8,14,10,59,5,255,255,250,255,213,254,108,254,147,255,254,255,238,255,212,255,235,255,204,255,164,254,245,255,229,255,75,255,46,255,101,14,67,11,137,252,98,3,153,249,196,252,5,254,208,255,211,255,92,255,120,253,199,0,156,0,62,255,104,255,46,0,112,1,32,1,168,255,86,0,116,5,98,8,187,8,89,1,174,3,138,255,231,254,207,254,249,255,202,255,74,255,66,255,220,254,227,255,211,255,209,255,176,255,133,255,128,255,237,255,13,0,123,17,221,13,220,252,113,253,0,0,58,251,0,253,217,255,230,255,253,255,254,255,55,252,0,0,219,0,174,0,0,0,179,0,141,0,224,255,44,253,254,0,242,0,161,23,158,9,224,255,253,255,253,255,71,247,142,254,11,0,10,0,253,255,11,1,162,255,167,255,108,0,218,255,220,255,115,252,114,2,79,249,233,23,209,17,219,251,233,255,77,255,17,247,10,251,188,255,65,0,23,255,128,2,82,255,221,1,88,249,40,0,145,255,140,1,39,1,162,254,111,5,49,31,255,1,107,254,249,255,138,255,204,240,241,255,246,255,29,0,170,0,90,253,10,0,213,255,7,255,248,255,34,0,197,0,12,0,72,12,239,253,96,2,226,9,38,15,165,253,239,255,234,255,122,254,106,252,101,0,140,255,19,0,27,254,81,0,163,255,24,253,125,0,112,255,169,253,29,10,79,253,229,11,227,21,108,254,103,254,227,255,202,253,132,248,246,255,108,0,31,254,128,0,139,252,235,0,239,251,63,0,239,255,75,0,138,0,35,12,1,2,94,5,246,241,198,236,179,253,240,255,141,255,236,252,58,250,159,255,252,254,213,255,169,2,112,0,45,1,165,3,154,0,157,1,201,251,164,9,122,23,83,4,122,254,169,7,140,254,100,247,182,255,247,255,22,255,119,252,90,255,106,254,58,0,143,0,26,0,217,254,49,253,124,255,46,0,165,18,206,10,64,9,254,18,52,240,146,250,45,254,170,254,93,250,26,252,218,252,78,253,113,254,120,250,203,252,66,253,154,4,170,2,72,2,176,4,129,6,169,248,163,5,165,6,114,33,87,255,41,255,129,255,80,255,133,238,190,0,110,255,165,0,84,255,195,0,107,255,154,252,214,3,14,253,135,252,156,10,51,35,17,252,243,2,7,249,62,254,164,236,195,255,222,255,62,255,43,250,167,0,42,2,131,255,97,254,46,0,40,1,214,3,147,255,82,0,89,245,124,29,5,5,170,3,92,13,59,254,106,242,156,255,203,255,54,253,232,4,213,0,176,253,156,0,80,254,183,255,57,2,216,249,244,254,60,255,93,14,114,3,210,15,178,4,19,9,199,252,209,255,23,252,168,255,183,254,58,255,115,252,38,255,243,254,192,255,215,254,247,253,131,255,194,253,86,255,254,7,15,253,122,0,118,39,91,2,1,255,222,255,0,0,171,231,234,255,94,0,241,255,5,0,19,251,208,1,181,255,181,255,27,0,252,255,140,254,193,1,233,248,194,41,30,15,241,253,244,255,55,255,192,228,110,252,240,255,49,0,219,254,160,4,150,255,172,1,35,246,14,0,198,255,88,1,124,0,83,252,48,9,185,19,66,14,77,10,202,255,175,254,236,249,211,252,88,254,135,0,34,1,43,253,209,0,244,253,155,251,151,0,134,254,212,252,181,253,169,248,28,3,45,12,97,37,108,254,41,255,218,255,175,253,43,234,247,255,91,0,101,1,105,255,73,4,48,254,227,248,210,255,19,0,76,0,236,0,77,249,251,7,208,247,218,38,161,15,77,255,2,255,244,254,106,232,47,252,213,0,37,255,5,1,17,4,40,251,248,4,162,1,14,254,255,1,131,246,116,233,150,253,175,240,28,1,173,243,15,248,233,255,86,252,252,255,161,253,38,255,155,250,108,255,100,0,10,0,68,0,169,251,137,255,13,253,54,0,126,1,140,18,67,31,240,247,150,8,248,255,160,250,187,240,252,254,218,254,146,255,70,255,241,246,48,0,86,2,240,3,205,255,131,253,207,251,21,1,157,252,199,11,150,46,117,249,179,3,211,255,213,253,23,222,85,255,202,255,159,0,119,2,109,247,168,255,52,1,195,4,50,0,82,255,78,253,96,0,187,236,80,254,101,26,187,14,72,5,51,250,245,255,30,245,157,252,145,255,126,255,242,7,178,0,111,4,99,0,237,249,151,1,35,0,211,253,201,254,152,0,254,37,135,16,120,248,210,5,255,255,114,233,188,251,30,255,121,255,166,255,217,255,49,246,17,0,120,4,242,1,243,255,140,252,128,254,175,0,208,9,193,0,73,35,241,20,180,243,127,254,254,255,140,236,38,249,163,253,227,255,151,250,150,255,202,252,193,255,116,244,226,1,37,0,199,6,6,4,16,33,28,11,12,0,37,2,84,8,235,238,19,254,0,0,238,255,235,254,67,250,250,255,254,255,228,254,161,255,0,0,179,251,142,254,255,255,185,255,93,8,214,245,254,27,86,35,186,250,233,254,99,254,194,243,126,236,145,255,84,1,88,252,114,4,98,251,156,5,139,240,176,0,42,255,78,2,233,2,12,255,22,1,251,51,203,4,95,255,253,255,252,255,200,213,165,255,255,255,4,0,198,0,30,255,18,0,236,255,27,252,254,255,2,0,131,0,12,0,101,248,25,32,125,24,149,3,1,246,25,255,231,239,161,246,205,255,113,254,208,3,233,2,184,243,108,0,52,254,162,254,208,254,3,5,211,3,143,0,238,248,13,8,35,245,168,23,74,39,56,255,253,254,40,254,66,247,226,231,227,0,205,254,93,1,157,2,7,253,4,4,87,4,15,251,171,6,123,241,147,30,201,35,175,242,169,9,26,250,101,241,254,235,59,253,139,254,117,255,232,238,92,6,114,7,99,251,154,250,2,2,209,2,76,3,198,254,228,0,106,250,121,32,69,37,117,244,90,6,132,255,134,239,76,234,235,253,95,255,213,2,64,3,23,237,255,254,219,5,185,6,142,0,199,252,77,252,37,1,3,11,105,239,15,21,225,33,196,10,27,254,179,251,18,249,17,238,49,254,218,2,97,252,117,5,44,250,200,8,218,244,38,254,202,2,117,252,77,250,141,0,216,56,178,2,1,1,144,255,255,255,130,205,227,255,252,255,0,0,131,255,251,255,155,253,254,255,28,255,246,255,0,0,99,0,4,0,1,0,162,46,189,248,14,7,62,252,140,252,5,222,45,255,57,255,200,255,209,255,75,5,220,250,205,0,189,2,147,255,106,0,132,2,156,255,97,0,205,255,144,14,190,7,216,8,232,17,59,12,176,252,17,255,200,254,254,250,170,253,61,254,253,253,239,254,237,251,214,253,135,253,56,253,134,254,80,254,148,252,99,251,254,2,208,2,223,55,40,255,171,255,221,255,225,255,58,207,254,255,55,0,51,0,223,255,7,4,100,253,140,253,241,255,10,0,9,0,189,0,223,238,218,18,128,39,33,6,60,13,107,251,115,250,158,231,106,255,68,253,11,5,146,10,93,244,164,1,50,254,55,252,138,3,26,252,213,247,188,254,64,254,140,7,231,60,206,248,145,2,244,255,29,255,11,198,49,255,230,255,52,0,171,1,210,248,206,255,217,0,217,6,18,0,179,255,142,253,74,0,211,239,52,7,122,15,141,21,76,24,234,251,49,255,66,252,190,248,199,246,210,1,233,3,66,254,114,5,147,253,202,250,36,6,68,253,32,250,210,247,217,2,5,247,163,57,73,14,72,252,224,255,190,254,24,204,208,252,201,255,102,0,112,253,23,8,94,255,1,2,34,243,42,0,123,255,89,3,212,0,151,250,169,22,27,52,191,243,64,5,139,255,250,247,147,213,168,253,146,255,234,1,103,4,141,237,247,254,87,4,250,9,113,0,36,254,186,251,1,1,102,18,189,37,49,4,93,246,202,12,182,250,191,233,186,255,141,254,114,253,39,245,204,254,135,253,197,2,175,5,161,0,83,252,118,248,42,255,237,1,51,7,216,241,134,48,242,26,233,249,49,255,222,252,53,219,168,244,108,255,151,1,139,250,188,10,249,252,246,5,146,235,175,0,168,254,158,4,144,2,153,5,90,9,203,9,100,5,76,34,131,255,163,254,129,254,140,255,159,237,47,255,37,255,146,254,136,255,55,255,45,255,0,253,253,250,193,250,28,253,80,249,115,50,251,22,107,247,223,3,77,255,59,216,192,247,218,254,196,255,70,5,103,2,226,237,27,255,196,6,21,3,103,0,243,252,156,254,133,0,224,58,110,8,35,251,142,3,16,254,215,201,228,254,162,255,206,255,241,255,62,248,121,4,164,0,187,252,137,255,69,0,200,1,65,0,219,255,27,0,47,18,151,28,52,19,74,2,203,242,214,250,58,243,61,250,236,255,71,253,225,247,140,250,108,247,90,255,251,254,81,255,192,3,230,5,246,3,120,0,167,4,164,247,0,20,186,52,118,250,170,255,233,254,192,249,143,212,134,255,155,0,140,254,157,2,43,252,227,6,134,239,103,0,71,255,187,1,144,4,6,250,207,252,255,31,160,37,84,250,113,255,216,255,1,240,225,233,128,255,180,255,253,2,152,1,132,3,224,1,49,237,121,255,184,255,214,2,86,3,92,243,95,2,160,6,198,247,221,44,129,253,234,255,81,255,242,254,141,224,119,0,79,1,194,255,96,254,78,0,218,0,220,8,87,254,91,251,196,5,131,12,145,248,187,252,207,37,145,27,142,253,35,255,214,255,170,233,33,244,116,1,163,0,159,255,156,248,100,4,238,1,156,250,51,3,104,1,183,239,213,0,113,253,119,66,108,2,128,254,254,255,230,255,249,186,233,255,247,255,8,0,35,255,169,2,248,255,24,0,124,253,5,0,241,255,143,1,14,0,224,19,35,0,245,242,142,14,40,33,212,249,0,0,88,253,177,252,211,238,246,255,13,4,7,0,123,251,248,255,247,2,180,245,238,255,194,6,118,248,36,252,174,5,128,245,191,58,122,10,197,255,127,255,71,254,19,202,73,254,87,0,94,255,238,0,139,3,201,250,163,9,161,0,18,255,184,1,98,246,255,236,230,244,203,255,119,21,123,25,91,250,19,254,0,0,205,248,219,245,180,252,240,255,247,255,96,6,185,3,18,0,145,7,107,4,21,0,116,247,4,12,221,58,158,244,18,7,53,252,191,253,220,201,250,253,56,255,199,255,243,244,35,2,120,10,173,254,127,249,66,1,182,0,125,3,84,255,107,0,31,5,235,20,46,43,251,8,186,241,151,255,42,249,222,226,190,254,210,252,84,254,139,252,227,241,72,255,17,253,241,249,36,1,170,4,161,9,0,2,195,15,243,21,10,18,23,7,120,7,30,252,121,248,235,250,55,255,33,255,152,250,143,251,209,249,65,254,146,253,1,254,41,254,112,253,229,253,45,255,173,247,194,10,107,238,79,50,8,29,235,254,49,254,44,251,116,216,213,242,102,1,183,253,244,2,139,6,139,247,210,13,199,3,31,251,250,7,46,233,242,21,253,253,147,12,203,239,249,18,122,248,240,255,136,253,230,251,96,250,176,0,176,251,101,0,142,5,126,255,47,3,126,249,152,0,70,252,206,4,46,7,83,249,115,4,227,65,204,2,50,255,78,255,177,255,42,188,225,255,191,0,129,255,118,0,156,248,223,6,107,251,176,255,74,0,207,255,31,253,186,7,251,240,66,39,78,46,68,246,18,255,122,252,236,231,128,222,133,254,208,1,67,251,54,9,105,250,222,10,153,227,45,1,183,253,249,5,11,7,216,245,238,43,25,44,193,241,183,5,100,254,216,225,158,225,212,252,126,255,248,6,255,6,187,225,190,253,200,9,209,9,232,0,20,252,16,252,69,1,114,13,139,3,165,10,10,35,54,14,45,253,206,255,59,254,209,236,216,252,66,255,196,253,106,255,164,248,16,254,44,250,4,253,55,255,163,253,56,248,130,255,90,68,153,13,45,248,66,4,0,0,255,182,29,253,12,255,184,255,135,0,26,0,123,241,241,255,91,8,169,1,8,0,115,251,25,255,133,0,234,248,24,4,140,247,230,15,144,63,56,255,189,255,227,254,13,252,224,192,116,0,17,255,138,0,194,1,252,254,25,2,9,7,239,251,101,8,54,240,138,36,36,49,165,248,194,3,151,253,35,235,68,218,40,255,200,255,233,255,241,227,51,4,166,5,219,253,30,253,110,0,96,1,218,1,185,255,36,0,172,6,103,16,219,28,191,24,235,3,78,255,204,251,254,242,111,246,195,255,75,254,254,252,155,248,108,253,169,249,216,244,152,255,255,254,60,254,124,254,192,245,247,21,158,67,207,246,80,2,92,254,118,248,144,184,174,254,235,255,132,3,212,10,203,232,136,254,39,3,182,9,94,0,53,255,143,253,85,0,187,4,174,252,169,4,122,248,120,62,167,255,212,255,170,255,30,255,7,195,62,0,168,255,61,0,142,0,156,255,140,0,98,251,62,3,115,251,88,7,143,15,250,247,242,44,237,255,38,14,56,252,255,254,112,224,0,0,223,252,243,1,19,245,162,5,4,0,254,255,13,0,144,252,198,1,16,246,4,0,238,252,182,250,220,62,78,28,127,249,219,255,145,255,67,194,123,243,87,255,191,255,4,3,50,5,92,1,87,2,51,228,176,255,119,255,100,6,224,2,36,239,1,254,18,26,145,45,25,18,143,251,241,255,97,245,143,223,226,250,122,255,222,6,208,0,1,12,108,1,112,237,196,4,144,0,161,248,29,243,232,30,205,17,145,7,93,7,125,27,19,241,13,251,27,255,40,255,50,244,104,247,89,252,230,253,114,252,244,253,34,255,186,242,91,248,192,252,215,252,106,13,151,11,235,22,4,32,62,34,48,253,231,253,203,247,252,239,174,237,146,253,50,251,218,251,74,249,52,250,137,244,211,248,204,249,189,243,223,238,249,22,216,35,183,31,94,15,27,13,193,247,237,235,73,240,80,252,81,253,34,243,158,244,61,238,124,250,101,247,99,248,76,251,169,248,130,249,219,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,3,212,0,203,2,158,2,41,3,220,255,254,255,225,255,229,255,217,255,246,255,223,255,247,255,225,255,248,255,227,255,218,255,246,255,221,255,223,255,16,5,36,5,88,255,192,254,209,252,154,255,151,255,255,255,250,255,216,255,152,255,13,0,13,0,25,0,25,0,253,255,64,0,65,0,248,255,241,255,179,253,168,2,174,9,52,1,172,253,235,255,228,255,137,254,251,255,235,255,24,0,89,0,154,255,11,0,244,255,210,255,235,255,24,0,90,0,11,0,33,253,25,254,251,255,132,11,212,1,223,255,242,255,0,0,238,253,243,255,235,255,0,0,0,0,132,0,87,0,0,0,21,0,13,0,0,0,172,255,18,4,194,6,44,4,77,1,114,2,190,255,74,255,187,255,250,255,233,255,146,255,189,255,144,255,235,255,221,255,235,255,217,255,190,255,216,255,244,255,230,1,255,252,234,15,9,11,173,251,242,255,220,255,11,252,25,254,182,255,22,0,136,255,191,0,173,255,132,0,66,253,32,0,204,255,19,1,191,0,241,5,1,253,132,255,224,16,2,4,115,255,221,255,0,0,141,251,192,255,71,0,11,0,251,255,111,254,202,0,32,0,161,255,48,0,7,0,242,254,121,9,243,4,111,13,165,255,114,251,153,254,158,255,46,253,0,0,173,255,69,255,3,254,246,254,13,0,7,0,19,0,172,0,90,0,244,0,250,255,29,251,207,3,173,0,199,15,213,7,161,255,198,255,255,255,28,252,11,255,74,0,13,0,246,255,52,1,16,255,214,255,153,0,137,255,235,255,18,254,28,7,120,2,42,5,14,8,7,4,54,255,232,255,150,255,253,254,192,255,186,255,110,255,205,255,27,255,177,255,90,255,142,255,217,255,173,255,127,255,65,254,40,19,244,0,197,254,10,248,244,255,69,250,253,255,250,255,3,255,134,0,6,0,183,255,248,255,94,0,4,0,201,255,98,2,30,0,217,255,48,255,178,251,207,1,64,254,21,22,254,255,182,255,243,255,244,255,98,248,242,255,5,0,31,0,251,255,226,255,12,0,71,0,124,1,97,255,154,0,131,18,40,10,184,248,88,3,238,249,165,250,100,254,44,255,212,255,109,255,16,253,27,2,39,1,9,255,121,255,97,0,193,1,246,0,80,255,81,0,102,7,205,13,35,0,230,255,97,8,37,255,6,253,0,0,0,0,232,254,104,254,252,255,249,255,3,0,5,0,0,0,8,255,50,254,252,255,3,0,117,245,49,7,232,15,139,9,46,6,68,254,49,255,12,252,148,254,104,255,47,1,158,2,55,254,146,1,238,254,161,253,4,1,79,255,119,254,20,255,180,252,30,13,218,23,221,251,231,253,213,255,80,253,29,247,188,255,239,255,173,0,58,1,29,251,202,255,217,0,139,1,229,255,110,0,200,0,222,255,227,4,248,3,204,11,162,8,165,5,161,255,193,255,212,253,214,254,129,255,179,255,26,255,69,255,88,255,119,255,105,254,146,255,167,255,246,254,62,255,51,8,229,8,198,15,205,13,202,244,243,254,196,254,29,252,6,253,9,254,221,254,251,253,207,253,60,254,21,254,153,252,111,1,143,1,195,2,107,2,144,1,166,251,68,33,118,9,163,251,247,255,181,255,182,238,154,254,180,255,27,0,48,255,67,2,197,255,164,0,21,251,27,0,181,255,68,2,165,0,210,238,37,248,72,15,153,246,210,8,100,251,9,255,90,252,159,254,201,254,228,253,26,4,224,1,122,253,217,254,63,2,94,2,21,1,229,253,75,1,231,6,89,250,144,16,16,24,11,253,66,255,129,255,183,251,244,246,221,255,156,0,55,254,118,1,104,253,32,2,198,249,81,0,190,255,195,0,28,1,58,6,73,250,11,4,26,27,128,7,101,255,126,255,191,255,134,244,31,255,142,0,156,255,92,0,93,253,107,2,74,254,70,255,171,0,135,255,211,252,206,253,108,18,245,15,177,253,117,9,237,255,179,250,6,252,235,255,155,254,162,0,140,0,105,251,236,255,170,0,147,0,83,0,72,253,165,253,87,0,16,6,74,34,89,252,98,1,112,250,109,255,161,237,203,255,249,255,133,255,193,252,88,0,245,1,223,255,67,255,20,0,134,0,251,2,175,255,30,0,223,18,177,238,41,0,57,250,96,244,112,250,82,251,0,0,123,255,228,253,26,5,244,255,11,0,180,1,112,254,3,0,109,3,220,252,7,0,244,254,42,8,168,4,238,3,109,6,245,18,246,254,170,255,195,255,91,255,99,250,104,255,128,255,183,255,46,255,137,255,155,255,149,253,159,254,214,254,25,254,82,9,80,22,146,5,162,255,70,5,165,254,57,248,132,255,0,0,145,255,192,252,49,255,15,254,13,0,32,0,8,0,60,255,42,254,139,255,7,0,187,250,67,4,123,6,187,34,57,1,145,255,184,255,88,255,39,237,251,255,89,0,136,0,146,255,220,2,176,253,124,252,25,0,236,255,225,255,86,255,252,38,148,3,131,254,216,252,88,0,64,232,205,255,248,255,217,255,0,0,210,253,232,0,21,0,236,1,45,0,238,255,203,255,252,255,2,0,4,0,34,9,249,251,8,255,88,15,84,25,179,254,192,255,253,255,82,252,250,245,147,0,35,0,241,255,208,253,247,0,59,0,99,252,152,1,98,0,237,249,22,24,40,251,175,254,88,14,3,251,240,246,163,255,250,255,201,252,157,255,210,1,126,0,231,255,154,250,22,1,75,0,224,1,160,255,230,255,30,1,25,17,124,255,228,245,165,6,1,19,111,251,255,255,103,254,80,255,92,250,35,0,179,2,236,255,58,254,13,0,12,1,237,250,39,0,0,3,7,254,34,10,223,12,104,15,201,5,170,2,102,254,106,253,75,252,123,255,228,255,247,253,144,253,231,252,22,255,215,254,156,254,148,255,119,255,92,255,195,255,55,16,112,2,47,3,133,17,181,8,228,251,233,255,216,255,52,251,209,254,98,255,50,255,225,255,144,251,86,255,33,255,203,253,172,255,145,255,158,253,9,242,151,254,60,19,231,10,90,18,244,252,249,255,56,250,37,254,189,250,178,255,50,4,108,0,97,2,61,0,185,252,1,4,103,0,124,250,224,252,42,246,207,14,175,33,59,1,161,9,125,254,147,252,70,238,250,255,142,254,70,2,45,5,53,248,48,0,183,255,90,255,122,1,198,253,239,250,209,255,77,253,173,11,229,38,91,254,138,251,227,255,223,253,93,232,246,255,177,255,126,0,164,1,231,248,239,255,76,0,0,1,208,255,208,0,182,2,227,255,130,248,104,0,138,243,174,242,168,238,32,255,0,0,147,253,59,253,77,251,12,0,139,254,20,0,113,254,21,0,104,253,249,253,28,0,160,252,100,252,225,242,124,249,62,7,27,27,150,5,80,253,87,255,47,255,133,244,132,255,171,254,124,1,188,0,142,5,194,2,239,252,37,1,145,0,95,255,162,253,42,0,234,37,92,12,72,252,139,3,0,0,138,233,157,253,201,255,206,255,231,255,248,255,174,248,2,0,52,2,183,0,254,255,231,253,81,255,52,0,71,6,17,3,46,11,231,16,235,12,99,255,219,255,12,254,137,251,101,253,179,255,232,254,119,255,88,254,49,255,12,253,188,254,98,255,191,253,151,252,145,26,88,13,179,8,146,6,111,243,249,244,56,253,210,254,84,255,137,253,118,250,100,252,48,254,70,253,162,254,28,255,55,5,158,2,181,1,74,1,131,13,58,15,108,1,161,30,176,245,38,253,97,252,248,255,87,241,87,254,201,252,180,255,170,255,137,249,183,248,82,255,45,2,116,2,58,0,239,4,242,232,126,242,95,246,162,248,238,16,178,247,38,253,141,254,39,255,134,251,35,251,136,252,248,253,89,253,114,254,229,254,25,6,147,3,140,2,243,1,130,241,109,4,169,30,115,13,41,255,184,252,178,255,80,241,45,253,254,255,0,1,241,6,225,253,11,3,18,255,143,249,208,255,14,0,103,0,45,0,36,16,12,11,2,0,140,239,236,239,238,251,24,254,0,0,197,251,246,251,55,253,0,0,0,0,38,4,215,2,0,0,14,4,198,2,0,0,222,251,243,22,48,33,252,248,96,5,6,249,197,247,202,238,59,255,141,255,62,255,25,244,132,2,163,3,19,254,55,253,150,0,128,2,158,3,61,255,150,0,71,12,155,13,218,13,231,252,137,17,165,253,28,253,1,253,218,255,50,251,100,253,88,253,14,253,152,0,168,0,171,0,163,252,70,252,53,252,217,0,29,11,29,31,111,14,200,234,138,15,18,254,223,240,191,252,247,248,58,252,153,250,127,253,252,248,175,3,81,10,201,4,77,253,114,248,127,252,39,5,2,6,150,0,227,27,1,8,25,12,112,255,255,255,218,243,0,255,183,253,242,255,98,253,191,255,64,255,238,255,132,252,222,254,228,255,187,250,125,254,106,2,96,29,121,18,18,255,211,242,233,255,132,242,171,250,253,255,74,253,229,254,78,255,134,247,8,0,109,0,68,0,127,0,12,6,205,3,207,255,149,11,59,244,232,30,164,27,51,248,232,253,214,253,19,241,16,244,13,255,33,2,105,250,175,5,0,251,21,5,167,242,105,1,145,254,196,3,94,3,139,9,95,252,167,251,205,37,42,16,148,254,204,255,181,255,172,233,235,251,138,0,166,0,193,255,93,250,37,2,145,2,151,253,234,0,25,1,116,246,174,7,237,12,101,39,185,242,57,8,20,255,100,253,193,231,63,253,242,254,115,254,70,251,11,248,152,1,174,2,44,8,4,255,87,254,241,250,180,1,144,255,168,250,164,34,214,18,0,8,0,0,142,255,64,237,117,250,0,255,247,255,61,0,228,2,33,0,146,1,206,245,14,0,171,0,172,251,166,253,219,245,182,1,209,248,85,24,98,28,101,254,245,255,50,255,192,246,105,243,69,0,221,254,49,0,219,3,90,255,187,2,128,4,62,255,48,3,53,245,126,13,41,2,167,35,82,19,36,234,40,253,238,255,36,236,43,250,137,248,140,255,124,248,204,254,238,251,90,255,61,245,155,4,188,0,45,12,153,6,236,253,105,253,230,47,191,9,20,252,239,255,230,255,39,220,132,254,195,255,235,255,142,1,240,1,81,0,101,0,181,248,224,255,216,255,239,2,152,0,204,247,37,5,27,250,161,44,181,11,243,254,151,255,117,255,225,224,220,253,168,0,63,255,121,0,184,5,106,252,28,4,128,1,16,255,20,1,214,247,169,4,119,245,251,43,253,20,5,253,170,255,68,254,199,225,30,249,221,255,196,0,205,252,61,7,121,254,116,3,148,241,55,0,131,255,13,2,250,0,101,9,41,254,71,43,203,0,14,3,159,254,243,255,189,226,254,255,219,255,69,0,166,249,62,1,227,255,5,0,119,255,142,255,22,0,239,253,247,255,177,248,53,22,26,44,154,245,73,5,43,255,76,248,156,225,80,254,145,255,137,2,9,5,179,240,208,254,155,3,42,7,154,0,43,254,92,252,220,0,72,241,39,23,235,243,177,19,92,20,158,252,160,247,184,253,241,249,134,249,83,5,57,253,95,4,135,4,224,248,183,3,174,4,163,248,216,3,189,249,14,246,30,37,81,23,120,246,136,7,117,254,121,234,129,247,149,254,30,255,197,5,159,3,122,242,133,254,135,5,121,3,43,1,162,251,66,253,31,1,157,236,240,13,240,17,132,21,123,13,33,250,247,252,249,250,197,248,41,253,56,4,111,5,24,252,132,6,81,251,249,249,21,4,17,253,57,252,120,251,209,6,230,245,143,15,147,42,241,249,70,255,104,254,56,252,174,227,110,255,19,1,88,254,116,2,119,251,184,6,167,245,165,0,12,255,121,1,8,4,99,3,56,254,41,253,41,13,46,46,211,255,244,255,224,255,76,253,173,222,24,0,38,0,236,255,78,255,93,0,149,0,143,253,73,1,13,2,129,246,111,29,118,9,134,7,125,5,63,6,118,242,154,254,30,255,136,255,100,255,166,251,138,252,228,254,122,253,49,255,91,255,33,253,20,255,68,255,119,255,17,4,33,253,114,255,153,51,235,5,190,255,223,255,255,255,103,214,116,255,46,0,9,0,250,255,185,252,81,2,114,0,160,255,68,0,13,0,58,251,14,31,89,26,92,250,16,252,161,10,239,240,39,245,129,255,194,255,60,254,55,243,188,2,82,2,233,1,159,1,168,255,216,250,160,251,239,0,167,0,110,237,157,250,170,17,190,253,155,233,157,250,140,255,32,251,236,255,42,248,112,254,32,5,124,1,89,255,208,255,159,0,129,249,30,254,46,6,54,255,148,12,90,23,35,23,126,9,127,245,135,253,123,247,163,247,152,254,71,254,105,251,116,251,143,247,35,254,138,252,146,252,16,2,213,3,204,3,142,1,121,1,32,5,154,54,66,250,165,2,248,255,151,255,107,209,124,255,228,255,226,255,191,254,161,251,33,0,117,0,230,4,241,255,202,255,191,253,60,0,149,242,114,26,58,1,139,252,54,22,48,253,19,245,250,255,209,255,75,248,139,5,65,0,127,255,71,255,110,1,16,0,168,4,211,246,147,255,51,1,99,12,70,34,44,247,119,10,253,11,155,253,165,237,200,254,74,254,193,253,94,249,181,1,186,4,250,253,101,250,113,1,174,253,149,249,167,1,11,254,181,21,229,5,31,21,131,255,38,227,164,248,117,255,8,249,0,0,254,242,1,254,214,248,14,254,42,0,11,0,41,0,201,9,168,2,134,9,200,255,234,244,35,10,172,51,15,1,1,7,21,254,101,254,72,214,252,255,60,255,193,1,243,8,209,247,47,0,214,255,37,255,54,1,228,254,89,250,227,255,152,2,234,254,118,58,183,3,57,253,230,255,252,255,152,202,201,255,226,255,11,0,162,253,253,0,218,255,16,0,155,252,28,0,244,255,138,2,41,0,40,3,234,6,210,33,231,22,50,250,217,255,65,255,32,238,206,247,122,255,169,255,85,254,89,252,223,254,135,253,230,243,73,0,160,0,17,3,19,2,247,11,3,6,208,7,226,253,104,37,196,253,112,255,12,255,239,255,35,234,225,254,138,254,68,255,101,0,51,0,66,0,2,249,124,252,111,251,61,1,2,2,3,55,189,254,128,3,133,252,240,255,182,208,250,255,207,255,208,255,70,254,10,0,21,1,228,255,254,252,17,0,27,0,254,2,239,255,48,0,124,3,158,0,117,20,49,43,189,249,208,255,255,255,118,249,218,226,100,255,248,255,227,254,206,255,166,253,150,255,50,242,87,0,15,0,0,2,58,4,180,249,4,10,56,239,238,48,78,22,98,255,111,254,154,251,152,218,58,248,252,0,90,254,160,2,208,4,88,248,212,12,49,2,131,252,217,5,243,238,25,19,34,229,100,2,221,23,145,18,77,250,185,244,234,255,27,247,157,250,4,8,74,255,1,1,225,248,4,10,28,255,118,250,203,7,79,255,20,249,237,11,6,254,99,9,153,37,42,5,199,253,241,255,160,254,233,233,150,255,94,0,64,254,74,0,254,248,41,1,124,250,10,255,40,0,62,255,247,252,14,253,104,50,128,17,191,247,191,5,222,255,77,216,55,251,240,254,124,255,82,2,206,0,55,242,159,255,128,6,65,2,67,0,121,251,110,254,189,0,159,16,196,5,191,19,89,9,96,11,175,251,124,255,233,249,163,254,251,253,129,254,223,250,57,254,147,253,41,255,30,253,12,253,250,254,126,252,87,254,165,250,23,2,137,5,12,57,27,252,142,255,239,255,134,255,39,205,196,255,44,0,118,0,210,255,198,4,35,254,17,251,173,255,32,0,86,0,120,3,248,20,48,249,243,15,44,251,169,14,34,249,71,255,7,252,163,255,164,252,59,2,198,250,178,1,149,1,125,255,52,1,51,251,143,1,89,252,27,1,52,6,231,243,79,56,115,14,109,251,102,255,183,253,117,206,189,252,173,255,44,1,139,250,165,10,154,254,187,2,73,243,113,0,35,255,6,4,8,1,212,0,53,31,255,36,240,242,217,7,254,255,201,240,157,234,86,253,10,255,153,255,133,255,246,237,43,0,94,6,141,7,230,255,45,252,119,251,154,1,88,3,246,8,141,253,18,27,17,27,212,255,191,254,232,255,141,244,142,244,137,255,32,0,87,0,150,254,54,252,9,1,150,254,54,252,9,1,141,244,53,9,165,239,250,27,3,30,43,13,173,254,210,251,197,243,237,241,75,253,90,2,250,251,38,7,175,251,171,7,225,242,27,254,93,3,62,250,211,249,94,1,233,17,229,54,21,241,194,4,249,255,253,250,234,208,134,252,166,255,159,255,212,254,163,240,81,0,44,4,203,12,230,255,171,254,235,251,28,1,80,243,203,13,219,1,89,8,191,45,124,253,7,253,243,255,234,254,76,223,188,2,94,0,154,255,167,1,52,254,194,255,18,9,36,246,172,254,8,250,55,244,12,15,189,6,248,32,137,20,213,253,119,252,75,255,4,239,106,249,197,2,61,1,107,254,18,6,64,248,135,252,200,3,44,251,215,253,108,245,115,252,124,12,152,60,32,246,42,4,206,255,145,253,162,198,122,254,187,255,177,0,93,3,46,244,116,255,237,1,89,9,59,0,48,255,15,252,164,0,191,3,214,242,145,37,73,37,31,249,200,255,75,253,243,233,71,234,67,255,197,0,205,253,186,7,210,253,171,7,29,234,103,0,150,254,10,4,2,4,151,29,20,46,19,237,180,12,89,249,82,242,211,222,103,250,123,253,79,255,178,234,192,8,160,13,33,250,219,246,193,3,19,3,202,4,9,254,82,1,9,25,186,6,228,6,161,239,127,23,53,246,75,255,67,255,208,251,96,247,95,253,78,253,71,255,103,6,184,1,195,1,207,246,136,253,121,253,2,6,140,246,129,47,174,19,6,5,206,247,155,254,189,220,243,249,156,255,244,254,4,7,232,2,100,241,190,0,70,252,117,254,202,254,21,6,133,2,164,0,72,247,195,250,78,28,254,36,71,248,208,254,147,255,124,243,158,234,18,255,74,255,219,3,81,2,10,5,7,3,164,239,243,254,95,255,106,3,119,4,6,4,122,27,135,16,15,6,5,12,192,255,53,244,187,251,110,255,191,253,70,254,246,254,232,248,159,255,102,253,112,254,63,255,215,250,230,252,221,254,1,20,59,46,35,254,43,249,250,8,191,249,155,222,243,255,70,255,190,254,141,241,149,0,88,1,34,2,240,4,206,255,50,253,132,249,66,0,245,0,0,243,243,14,33,23,248,38,235,251,92,253,130,252,164,247,69,232,190,255,9,3,179,4,153,250,235,7,230,246,235,241,44,255,244,0,121,1,124,2,229,14,86,22,198,237,172,242,42,22,137,252,53,248,207,250,58,253,83,248,205,250,62,4,92,6,26,3,167,4,52,252,216,250,68,248,80,6,157,4,68,5,168,241,98,51,26,27,102,249,146,255,201,252,191,214,134,244,82,255,46,1,198,251,132,11,198,253,19,6,62,234,139,0,133,254,77,5,204,2,103,8,254,241,37,27,99,47,56,251,230,254,239,252,125,244,234,220,165,255,214,1,112,252,241,5,200,249,95,10,231,235,160,0,244,254,7,2,138,3,183,244,175,37,36,40,88,245,227,3,3,254,208,233,211,230,58,254,196,255,165,6,20,7,93,232,31,254,70,6,175,6,175,0,182,253,144,253,165,0,33,24,136,8,43,2,193,7,189,25,231,246,221,254,238,255,16,255,166,245,201,252,47,255,182,255,20,253,248,254,189,255,76,246,146,252,33,255,226,252,20,254,135,1,14,67,87,253,240,0,242,255,247,255,189,185,228,255,253,255,11,0,3,2,102,254,236,255,16,0,201,2,7,0,251,255,4,255,10,0,84,49,72,21,186,245,195,11,121,245,251,217,237,248,90,254,215,253,69,254,153,239,235,7,106,3,239,246,23,252,227,1,29,8,128,3,80,254,239,1,212,241,234,253,119,13,90,27,95,26,221,252,239,255,43,253,80,244,34,245,138,255,251,2,112,0,14,6,228,0,63,250,215,5,220,0,116,250,187,244,137,235,13,23,171,31,66,14,238,18,117,249,179,247,84,240,211,252,103,250,95,7,32,10,152,244,143,4,221,250,242,248,14,6,47,249,162,246,200,251,13,24,22,26,3,16,206,251,44,9,246,246,94,245,255,251,186,255,176,254,51,246,252,249,122,249,147,1,181,1,12,1,142,252,67,252,181,253,153,0,55,4,227,62,242,0,143,252,154,6,185,255,52,194,253,255,209,255,82,255,220,251,240,255,18,255,58,0,97,3,13,0,145,255,131,249,231,255,90,0,234,254,227,0,241,251,100,6,49,66,252,255,253,255,191,255,93,255,138,187,3,0,239,255,14,0,27,0,234,255,103,0,31,1,22,255,50,4,99,249,162,61,82,250,62,2,165,253,149,255,165,196,127,255,236,255,234,255,0,0,120,5,215,253,51,0,69,2,203,255,21,0,103,0,247,255,3,0,253,255,102,9,188,252,168,51,57,31,86,239,159,254,214,255,79,214,197,240,169,251,122,0,106,248,162,2,106,251,151,1,205,230,114,2,39,255,115,13,33,8,112,12,32,56,248,242,207,8,247,248,149,253,200,206,89,253,202,254,58,255,23,245,136,2,110,11,74,254,71,248,203,1,94,1,44,6,146,254,247,0,94,249,180,66,200,9,229,253,122,253,80,255,122,186,130,254,239,255,231,255,234,6,3,1,206,245,201,255,49,2,82,0,189,255,161,2,98,0,235,255,71,9,227,252,120,245,147,56,7,21,168,254,218,255,69,254,253,205,23,249,115,0,135,1,125,255,204,247,193,2,80,9,244,252,6,1,118,3,105,237,125,245,250,9,88,238,101,37,159,41,70,254,114,254,33,251,38,234,238,228,163,1,26,253,192,2,36,6,44,250,81,10,214,6,131,249,123,11,174,231,20,239,209,238,135,249,16,19,207,28,135,251,99,251,89,255,83,250,9,243,117,251,74,254,68,254,10,5,30,5,237,1,158,7,188,7,233,2,108,247,86,242,237,28,227,38,133,10,101,244,22,253,237,242,95,232,70,254,230,253,45,6,77,8,109,238,63,2,63,251,156,249,134,253,62,5,13,7,232,1,61,26,48,241,59,30,238,10,161,13,62,245,147,252,185,241,35,254,25,253,18,6,155,243,255,6,133,251,135,2,215,250,106,250,39,3,144,249,173,253,143,20,42,38,135,13,45,4,125,240,102,249,62,233,36,253,187,255,62,252,190,243,168,251,239,247,169,254,131,253,30,255,251,4,64,9,71,3,3,1,219,4,182,245,132,65,79,7,76,1,162,255,89,254,239,188,43,255,250,255,199,0,7,251,136,10,114,255,44,1,133,248,231,255,53,0,173,254,219,255,131,10,20,11,33,12,79,22,209,18,70,254,21,254,180,253,57,248,120,250,47,254,2,254,231,253,86,252,36,252,198,251,233,252,190,252,111,252,113,249,14,17,128,11,42,28,43,14,137,4,117,251,239,253,156,243,221,252,174,255,240,252,127,248,241,250,58,252,117,253,196,249,203,254,48,255,1,254,255,254,64,54,111,15,97,253,255,246,26,13,3,210,71,252,229,255,188,254,82,253,235,242,57,2,161,0,162,7,44,2,162,255,229,244,215,252,137,0,216,1,141,27,215,22,113,11,186,32,70,237,36,244,218,247,245,253,68,239,133,250,43,246,19,251,235,251,233,241,82,244,38,250,16,8,175,6,89,3,147,9,113,247,38,50,222,35,181,240,81,6,219,254,181,216,230,235,89,252,97,255,181,6,204,4,229,227,245,253,252,11,146,8,216,0,13,251,118,252,130,1,239,236,58,51,135,22,77,254,59,16,82,250,254,214,18,248,245,255,226,251,67,15,182,6,248,237,127,255,92,1,153,0,214,4,2,243,74,250,110,0,163,30,30,251,210,0,194,27,173,235,86,241,161,255,254,255,246,243,140,249,86,2,156,255,16,0,182,242,30,2,165,255,187,9,115,254,66,0,209,8,97,246,232,31,215,56,188,240,36,7,142,254,24,240,133,205,92,252,52,255,204,4,140,8,170,227,181,253,156,7,143,13,18,1,113,252,169,249,180,1,213,249,91,1,240,254,81,245,159,62,104,255,249,255,252,255,56,254,186,194,33,0,230,255,5,0,249,254,58,0,211,255,9,6,172,254,10,1,116,10,73,231,48,5,229,19,41,236,193,29,117,246,149,255,209,249,218,249,43,242,1,2,175,7,99,254,87,248,155,1,42,6,125,11,151,253,193,246,57,9,214,12,99,238,42,44,17,43,193,245,109,253,39,251,134,225,5,227,92,254,136,3,37,247,40,12,93,247,218,11,72,226,14,2,46,253,18,7,229,6,191,21,189,69,86,241,142,4,249,253,156,248,1,180,164,252,173,255,240,255,77,232,251,4,250,15,116,254,9,251,11,1,176,0,54,2,137,255,37,0,168,247,88,254,188,59,244,19,144,249,234,254,246,255,63,200,199,249,91,255,201,255,201,7,140,1,154,2,132,0,96,237,42,255,214,255,2,6,2,2,219,8,31,243,245,9,179,64,233,252,199,254,105,253,116,254,151,190,218,255,200,1,160,254,1,2,13,247,5,13,240,245,109,0,97,255,123,0,31,3,71,14,107,7,220,242,135,24,222,48,209,252,36,255,78,253,154,246,176,218,89,254,238,2,134,1,136,250,40,253,9,5,25,245,86,250,8,10,70,237,116,31,237,8,207,231,18,20,115,23,139,240,194,254,219,246,181,249,105,247,157,251,228,11,96,3,35,246,52,253,150,7,122,244,187,252,221,8,166,248,126,254,13,247,255,29,27,60,93,245,247,255,192,254,241,241,140,199,60,254,202,255,181,0,50,4,106,1,104,8,212,227,192,255,132,254,252,4,253,9,217,10,107,251,144,15,23,51,204,9,42,254,172,255,55,252,56,215,128,254,198,0,93,253], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1841784);
/* memory initializer */ allocate([29,1,87,247,168,3,148,243,87,254,179,0,158,253,46,248,169,248,235,6,132,245,65,65,41,7,41,255,65,255,73,254,120,189,51,255,203,0,204,254,34,1,124,7,243,248,176,10,210,0,58,255,44,1,179,248,28,4,143,17,159,60,187,5,64,240,189,255,47,251,148,198,125,255,32,252,224,254,27,252,95,239,162,255,110,254,147,250,3,1,82,4,235,14,105,1,194,11,240,9,57,27,135,29,204,7,215,253,117,254,108,244,97,242,13,255,45,254,0,251,198,251,148,250,106,251,113,243,146,254,202,254,175,252,103,252,167,235,181,248,9,34,111,40,13,6,136,249,44,255,230,237,116,230,110,255,175,253,210,10,225,3,219,12,156,4,127,234,236,1,176,0,200,252,45,252,38,239,65,33,145,3,123,29,93,245,145,251,185,238,206,255,108,242,60,254,193,8,240,0,38,254,195,7,175,240,92,254,51,253,135,5,151,0,230,4,129,50,61,251,144,9,221,6,159,24,36,216,166,255,147,254,68,255,135,246,194,3,116,248,182,0,150,250,130,0,250,254,146,236,213,1,83,252,92,253,65,25,36,16,95,12,88,12,65,22,9,246,238,251,156,253,159,253,67,248,162,249,31,251,226,252,33,251,227,252,157,253,56,247,99,250,179,251,181,251,204,241,251,18,226,73,201,250,42,3,217,252,95,250,180,170,148,255,216,255,54,4,102,16,23,234,216,254,140,1,5,6,179,0,16,255,88,252,66,0,140,34,184,30,142,2,33,240,208,233,90,237,66,241,230,255,17,252,79,248,107,239,159,254,198,254,145,8,158,7,162,0,250,11,166,10,226,0,128,250,67,7,74,10,12,36,228,3,248,36,45,255,89,254,179,235,196,255,165,234,213,254,233,251,53,250,143,255,96,255,207,253,206,251,15,250,46,235,193,253,133,11,228,47,50,40,15,254,153,240,238,253,42,220,193,230,241,255,75,252,98,247,196,248,236,225,89,0,116,1,56,1,197,2,134,11,172,9,137,255,169,244,16,6,19,58,242,38,16,254,254,253,109,255,77,203,76,232,241,255,19,1,74,10,128,250,230,6,80,252,169,220,169,255,47,0,194,1,46,1,171,12,42,32,162,29,45,13,103,8,126,253,214,239,72,242,74,253,230,254,162,249,35,250,28,241,101,253,97,249,231,249,87,254,199,251,28,252,70,254,97,218,60,0,173,13,239,20,166,39,226,233,0,0,20,253,40,249,112,231,35,0,10,8,244,255,78,12,237,255,135,251,79,23,219,255,135,247,8,243,38,229,7,246,186,234,109,247,95,225,188,244,115,254,238,248,218,254,87,241,209,251,19,247,176,252,103,252,170,254,39,253,38,243,59,251,210,245,230,251,171,242,139,251,22,18,44,53,217,30,57,253,177,255,228,250,210,211,34,241,19,255,196,3,66,1,20,11,180,3,249,240,109,6,38,2,73,247,95,230,58,17,210,233,70,31,104,240,227,14,93,251,80,248,184,240,51,252,138,252,248,5,149,247,215,10,50,4,153,250,159,7,255,251,41,5,186,248,160,3,27,22,15,45,155,8,60,254,1,28,94,248,71,224,216,254,244,255,191,243,112,240,7,253,241,249,156,0,62,1,60,0,84,246,72,236,60,252,197,0,98,11,158,244,157,13,131,240,107,53,250,253,250,253,27,253,65,252,106,211,6,2,148,253,108,2,193,2,63,253,75,3,127,246,128,9,163,244,238,12,163,30,115,7,254,3,178,34,36,31,85,241,34,255,193,255,49,237,217,240,111,252,23,254,137,255,100,239,246,251,214,253,24,241,96,252,15,254,30,239,239,53,59,37,156,5,76,6,243,6,140,210,88,234,131,255,98,255,63,255,160,224,70,251,189,252,178,250,86,252,115,255,37,250,245,251,100,255,81,255,52,53,39,235,74,21,41,247,187,6,198,211,54,249,235,248,200,254,75,255,84,17,77,238,239,6,89,7,31,253,240,2,104,250,49,2,195,253,238,0,177,20,182,32,168,34,14,30,138,25,80,249,72,239,60,237,227,241,207,245,109,245,204,244,74,238,73,246,164,240,186,239,191,247,243,242,44,242,2,244,104,116,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,22,31,0,248,109,140,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,40,225,29,0,248,109,140,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,116,29,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,138,31,0,108,0,0,0,160,70,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,177,15,176,15,166,15,163,15,161,15,160,15,147,15,145,15,144,15,129,15,128,15,113,15,112,15,97,15,96,15,81,15,225,0,193,0,177,0,161,0,160,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,222,0,46,7,118,5,110,0,117,0,85,0,19,0,51,0,13,0,7,0,210,7,82,0,101,0,206,0,131,1,62,0,1,0,46,0,53,15,3,0,67,2,26,0,6,0,165,1,67,0,18,0,67,14,182,0,22,0,53,1,118,1,67,6,53,0,30,0,53,7,131,2,37,1,174,0,210,0,101,1,3,1,3,6,229,0,67,12,181,2,165,4,165,0,67,4,101,2,118,4,18,2,18,1,118,3,46,1,210,2,131,0,131,4,94,1,165,6,53,3,94,0,37,0,210,1,246,0,210,3,46,3,181,3,90,0,3,2,165,2,210,11,78,0,50,0,181,1,181,0,101,10,37,2,118,2,14,0,10,0,229,3,67,1,229,1,54,0,146,0,5,0,9,0,101,6,118,0,195,0,58,0,21,0,35,0,2,0,11,0,0,0,8,11,11,7,7,7,6,6,4,3,11,8,10,8,9,6,4,9,12,10,11,7,5,9,11,10,12,8,6,10,11,12,9,7,12,10,9,8,10,9,9,11,9,12,10,11,11,12,12,11,10,9,10,10,10,11,11,9,11,11,9,10,10,8,12,11,10,7,11,11,12,8,6,10,10,12,10,10,7,5,10,9,10,8,8,6,4,11,11,8,6,7,6,5,4,2,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,177,15,176,15,166,15,163,15,161,15,160,15,147,15,145,15,144,15,131,15,129,15,128,15,113,15,112,15,97,15,96,15,81,15,80,15,65,15,241,0,209,0,193,0,177,0,176,0,161,0,160,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,238,0,165,3,115,11,78,0,53,0,21,0,35,0,19,0,13,0,7,0,115,6,243,1,254,2,150,0,51,1,30,0,1,0,22,1,245,0,245,3,115,4,82,0,26,0,213,1,37,0,115,0,51,6,134,0,54,0,46,1,85,1,6,0,85,0,14,0,6,1,62,2,146,1,117,0,115,1,174,1,213,0,245,8,46,0,254,1,6,4,174,0,62,14,6,2,62,1,115,3,85,13,62,6,51,14,62,3,245,1,115,2,62,0,165,6,146,0,213,3,245,4,62,5,22,0,254,0,165,7,37,1,6,5,146,2,190,0,37,4,115,15,245,2,86,0,51,2,165,2,37,12,126,0,38,0,85,3,51,0,85,5,165,1,6,3,70,0,10,0,37,2,110,0,165,0,18,0,243,0,5,0,9,0,62,7,115,7,179,0,50,0,101,0,3,0,2,0,11,0,0,0,0,0,0,0,0,0,8,11,12,7,7,7,6,6,4,3,11,9,10,8,9,6,4,9,12,10,11,7,5,10,11,11,12,8,6,9,11,11,9,7,11,11,9,8,10,9,9,12,9,9,11,9,12,10,11,12,12,12,12,11,10,11,10,11,10,10,11,11,9,10,11,9,11,10,8,12,12,10,7,11,11,12,8,6,10,10,12,10,10,7,5,10,8,10,8,9,6,4,11,12,8,6,7,6,5,4,2,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,178,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,150,15,147,15,145,15,144,15,131,15,129,15,128,15,115,15,113,15,112,15,97,15,96,15,81,15,80,15,65,15,64,15,49,15,225,0,209,0,193,0,192,0,177,0,176,0,161,0,160,0,147,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,69,0,68,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,42,0,197,4,163,2,74,0,21,0,5,0,3,0,19,0,13,0,7,0,113,1,50,0,113,3,118,0,66,0,17,0,14,0,170,0,213,4,163,3,163,6,98,0,26,0,213,6,242,7,35,2,213,12,106,0,1,0,246,0,35,6,242,3,234,7,241,1,33,0,213,3,194,8,246,7,242,0,227,0,234,15,197,2,170,1,130,0,163,4,182,0,113,0,178,3,35,0,182,1,163,8,2,0,178,11,197,0,234,2,35,12,246,15,35,4,178,7,197,1,213,7,234,1,234,6,194,2,246,1,213,1,178,1,178,0,241,4,234,3,162,1,162,2,213,2,35,1,213,0,242,1,85,0,178,5,194,4,2,1,97,0,213,5,194,0,241,0,163,0,69,0,22,0,163,1,194,1,213,8,197,3,234,0,10,0,6,0,162,0,54,0,241,2,114,0,34,0,37,0,9,0,246,3,163,10,99,0,18,0,49,0,53,0,51,0,11,0,0,0,0,0,0,0,8,11,12,7,7,7,6,6,4,3,10,8,10,8,8,6,4,9,12,10,11,7,5,11,11,11,12,8,6,9,11,11,12,9,7,11,12,12,9,8,12,10,9,8,11,9,9,12,11,9,12,9,12,11,11,12,12,12,11,10,11,10,11,10,10,11,11,9,11,11,9,10,11,9,12,10,8,11,11,9,7,11,12,11,12,8,6,10,9,12,10,10,7,5,10,8,10,8,8,6,4,11,12,8,6,7,6,6,4,2,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,178,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,150,15,147,15,145,15,144,15,131,15,129,15,128,15,115,15,113,15,112,15,97,15,96,15,81,15,80,15,64,15,49,15,48,15,33,15,33,1,241,0,225,0,209,0,208,0,193,0,192,0,177,0,176,0,163,0,161,0,160,0,147,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,97,0,3,4,177,13,18,0,113,0,86,0,53,0,35,0,13,0,7,0,67,2,211,1,106,2,161,0,162,0,17,0,14,0,170,1,49,5,147,0,34,2,50,0,6,0,242,7,211,4,67,12,114,0,1,0,67,3,242,5,170,4,242,3,49,0,69,0,67,1,170,0,49,11,242,0,195,0,147,6,242,11,3,2,225,0,177,3,211,2,177,0,106,5,210,1,138,0,106,4,226,1,3,0,3,1,177,1,226,2,147,2,106,1,226,4,67,4,33,5,33,3,67,0,211,0,226,0,3,7,210,0,49,7,147,10,147,3,3,8,34,4,131,3,138,1,106,0,33,0,106,9,3,3,82,0,226,12,49,13,138,3,19,0,242,1,147,14,131,0,5,0,210,2,33,1,34,0,234,0,54,0,34,1,147,1,49,3,131,1,170,2,74,0,26,0,49,1,42,0,106,3,10,0,98,0,37,0,9,0,226,6,177,5,83,0,2,0,22,0,21,0,51,0,11,0,0,0,0,0,0,0,8,11,12,7,7,7,6,6,4,3,10,9,10,8,8,6,4,9,12,10,10,7,5,11,11,12,8,6,10,11,11,12,9,7,10,11,12,9,8,12,12,10,8,10,10,9,11,9,9,11,9,12,10,11,11,12,12,12,12,11,10,11,11,11,11,10,11,12,10,12,11,10,10,11,9,12,11,8,12,12,10,8,11,12,9,7,10,11,11,8,6,9,10,12,10,10,7,5,11,8,10,8,8,6,4,11,12,8,6,7,6,6,4,2,0,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,150,15,149,15,147,15,145,15,144,15,134,15,131,15,129,15,128,15,115,15,113,15,112,15,99,15,97,15,96,15,81,15,80,15,65,15,64,15,48,15,33,15,32,15,17,1,1,1,241,0,225,0,224,0,209,0,208,0,193,0,192,0,179,0,177,0,176,0,163,0,161,0,160,0,147,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,246,0,118,6,182,14,243,0,86,0,106,0,57,0,3,0,13,0,7,0,162,0,115,1,202,0,37,0,130,0,25,0,1,0,182,0,118,2,227,2,178,0,98,0,26,0,117,1,227,1,229,11,74,0,41,0,165,7,227,0,10,3,118,1,35,0,66,0,202,5,165,0,66,1,82,0,165,4,2,11,34,13,117,3,101,0,34,5,227,13,10,1,245,0,54,1,117,2,178,1,245,3,227,3,2,0,227,8,162,1,54,11,10,2,118,0,227,12,229,7,10,7,165,3,182,2,54,0,229,1,165,2,227,5,182,7,245,7,54,7,165,11,117,0,2,3,229,15,182,1,2,1,227,4,34,0,165,8,202,1,229,0,10,15,229,5,150,0,118,10,54,3,54,2,18,0,182,3,245,11,115,0,53,0,178,2,10,0,118,4,34,1,22,0,9,0,34,3,245,1,229,3,165,1,202,3,114,0,6,0,165,6,50,0,202,2,138,0,194,0,21,0,14,0,2,7,182,6,99,0,51,0,42,0,5,0,19,0,11,0,0,0,0,0,0,0,0,0,8,11,12,8,7,7,6,6,4,3,9,9,10,8,8,6,4,10,12,10,10,7,5,10,11,12,8,6,11,12,11,9,7,9,11,12,9,7,11,12,12,10,8,12,12,10,9,10,10,9,12,10,9,12,9,12,10,11,12,12,12,12,11,10,11,11,12,11,11,11,12,10,12,12,10,10,12,9,12,11,9,12,11,8,12,12,10,7,11,12,9,7,10,10,11,11,8,6,10,10,12,10,10,7,5,11,8,10,8,8,6,4,11,12,8,7,7,6,6,4,2,0,0,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,150,15,149,15,147,15,145,15,144,15,134,15,129,15,128,15,115,15,113,15,112,15,99,15,97,15,96,15,83,15,81,15,80,15,65,15,64,15,49,15,48,15,32,15,16,15,1,15,0,15,33,1,17,1,1,1,0,1,241,0,240,0,225,0,224,0,209,0,208,0,195,0,193,0,192,0,177,0,176,0,163,0,161,0,160,0,147,0,145,0,144,0,129,0,128,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,83,0,154,0,226,14,211,0,106,0,82,0,58,0,53,0,13,0,7,0,98,0,37,1,66,1,25,0,243,1,41,0,14,0,130,0,218,10,227,2,226,0,34,0,6,0,101,0,227,5,101,7,50,0,57,0,153,15,226,5,153,0,51,0,98,3,153,7,101,15,115,0,74,0,165,2,98,1,66,7,165,1,217,0,66,3,90,0,170,0,243,14,130,1,218,1,130,3,90,3,243,0,115,6,101,1,229,0,243,6,37,2,66,8,90,2,227,7,153,3,165,7,42,7,42,15,227,9,115,2,154,4,229,2,153,11,226,2,115,14,98,5,243,2,42,3,66,15,218,0,153,9,42,1,101,3,165,0,227,0,153,1,227,3,154,1,226,1,115,1,229,6,89,0,227,1,218,2,42,0,10,0,218,6,165,15,66,0,229,1,19,0,226,3,90,1,165,3,66,4,26,0,5,0,165,4,101,2,165,8,37,0,154,2,114,0,22,0,153,5,194,0,66,2,178,0,2,0,21,0,1,0,227,11,226,6,99,0,35,0,18,0,9,0,3,0,11,0,0,0,0,0,0,0,0,0,8,11,12,8,7,7,6,6,4,3,9,9,10,8,9,6,4,9,12,10,10,7,5,10,11,12,8,6,12,11,9,7,10,12,12,10,7,10,11,12,10,8,11,10,8,12,10,9,10,10,10,12,10,10,12,10,12,10,11,12,12,12,12,12,11,11,11,12,11,12,11,11,11,12,10,12,10,11,12,10,12,12,9,11,9,11,8,12,12,9,7,11,12,12,9,7,10,10,11,11,8,6,11,10,12,10,10,7,5,11,8,10,8,8,6,4,12,12,8,7,7,6,6,4,2,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,177,15,176,15,166,15,163,15,161,15,160,15,150,15,149,15,147,15,145,15,144,15,134,15,133,15,129,15,128,15,118,15,113,15,112,15,99,15,97,15,96,15,83,15,81,15,80,15,67,15,65,15,64,15,49,15,48,15,32,15,16,15,0,15,240,14,225,14,49,1,33,1,32,1,17,1,16,1,1,1,0,1,241,0,240,0,227,0,225,0,224,0,209,0,208,0,195,0,192,0,179,0,177,0,176,0,161,0,160,0,145,0,144,0,129,0,128,0,117,0,113,0,112,0,101,0,99,0,97,0,96,0,86,0,85,0,83,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,34,0,178,11,66,9,43,0,114,0,2,0,26,0,57,0,13,0,7,0,123,0,142,0,219,6,234,0,91,1,46,0,6,0,89,9,123,2,14,10,171,1,138,0,18,0,30,0,117,5,91,0,171,2,194,0,21,0,106,3,178,4,153,0,27,0,25,5,25,12,219,0,78,0,66,0,89,1,178,3,14,3,235,0,82,2,171,14,138,1,226,0,171,6,66,2,123,1,82,4,25,3,82,1,91,2,106,1,171,0,82,0,178,5,14,1,142,3,138,2,89,3,25,0,138,7,82,12,142,13,217,14,217,2,98,6,25,1,178,9,171,11,25,13,91,12,178,0,66,5,138,11,178,2,66,1,91,6,142,5,98,0,142,1,138,3,217,0,25,4,98,1,171,3,117,0,178,7,50,0,14,2,171,7,107,0,91,4,178,1,153,1,42,0,117,3,117,7,171,10,217,1,59,0,14,6,66,3,117,1,98,2,10,0,5,0,89,5,106,0,89,13,25,2,14,0,74,0,9,0,25,7,89,0,219,2,210,0,219,1,37,0,1,0,217,6,245,0,53,0,251,0,58,0,11,0,3,0,0,0,0,0,0,0,7,12,12,8,7,7,6,6,4,3,10,9,11,8,9,6,4,12,10,12,10,10,7,5,11,11,12,8,6,10,11,9,7,12,12,10,7,10,12,12,10,8,10,12,10,8,12,10,9,12,11,9,11,10,10,11,11,10,10,10,10,11,11,12,12,12,11,11,11,12,12,12,12,11,11,12,10,12,11,12,10,11,12,10,12,9,12,9,11,8,12,11,8,12,12,9,7,11,11,12,9,7,11,10,11,11,8,6,12,9,12,10,10,7,5,11,9,11,8,9,6,4,12,8,7,8,6,6,4,2,0,0,0,0,0,0,0,16,248,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,177,15,176,15,163,15,161,15,160,15,150,15,147,15,145,15,144,15,134,15,133,15,129,15,128,15,118,15,117,15,113,15,112,15,102,15,97,15,96,15,81,15,80,15,67,15,65,15,64,15,51,15,49,15,48,15,35,15,33,15,32,15,17,15,16,15,0,15,240,14,224,14,193,14,192,14,81,1,65,1,64,1,49,1,33,1,32,1,17,1,16,1,3,1,0,1,240,0,224,0,211,0,208,0,195,0,193,0,192,0,177,0,176,0,161,0,160,0,145,0,144,0,129,0,128,0,117,0,113,0,112,0,101,0,97,0,96,0,86,0,85,0,83,0,82,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,1,0,98,13,189,0,34,0,155,0,50,0,25,0,5,0,7,0,77,3,154,0,43,1,82,0,107,0,58,0,6,0,253,6,125,1,26,8,27,3,26,3,18,0,17,0,2,2,253,0,27,5,210,0,29,0,26,1,130,7,141,1,123,0,125,6,125,3,33,0,141,14,98,5,141,0,187,0,61,5,42,8,2,0,13,0,2,3,125,0,59,5,59,0,77,10,125,2,253,1,42,4,194,1,26,4,130,1,77,1,98,1,194,0,42,3,154,13,42,1,2,1,125,8,43,7,154,3,98,3,154,1,98,12,194,4,27,13,141,2,98,7,125,14,65,14,154,5,77,2,59,9,43,5,27,1,77,6,61,1,130,3,98,2,65,6,98,4,77,0,194,12,59,3,141,6,65,1,43,13,27,0,65,0,193,0,65,12,226,1,235,0,42,6,130,0,97,0,253,2,125,4,59,1,42,0,61,0,91,0,42,2,194,2,65,2,98,0,170,0,11,0,226,0,26,0,61,3,26,2,106,0,9,0,43,3,43,0,253,4,66,0,107,1,45,0,14,0,65,4,205,0,90,0,171,0,10,0,57,0,3,0,0,0,7,12,8,7,8,6,6,4,3,10,9,11,8,9,6,4,11,10,12,10,10,7,5,10,11,12,8,6,10,11,9,7,12,10,7,12,12,10,8,11,12,10,8,10,12,11,9,12,11,9,11,9,11,10,10,11,11,10,12,10,10,12,11,10,11,11,12,12,12,11,11,12,12,12,12,12,12,11,11,11,11,10,12,12,10,12,10,12,9,12,9,11,8,12,9,8,11,9,7,11,11,12,12,9,7,11,10,11,11,8,6,9,12,10,10,7,5,11,9,11,8,9,6,4,12,8,7,8,6,6,4,2,0,0,0,0,0,16,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,177,15,176,15,165,15,163,15,161,15,160,15,147,15,145,15,144,15,129,15,128,15,118,15,113,15,112,15,102,15,97,15,96,15,86,15,81,15,80,15,65,15,64,15,49,15,48,15,35,15,33,15,32,15,19,15,17,15,16,15,3,15,1,15,0,15,241,14,240,14,224,14,208,14,192,14,176,14,145,1,129,1,128,1,113,1,97,1,64,1,48,1,35,1,32,1,16,1,0,1,243,0,240,0,224,0,208,0,192,0,177,0,176,0,161,0,160,0,145,0,144,0,133,0,129,0,128,0,117,0,113,0,112,0,102,0,101,0,99,0,97,0,96,0,86,0,85,0,83,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,107,0,190,0,82,0,243,0,91,0,58,0,9,0,7,0,218,0,251,3,35,1,179,0,179,1,46,0,6,0,10,3,90,0,74,0,74,3,114,0,5,0,218,2,115,1,251,4,50,0,19,0,155,3,155,11,30,1,2,0,251,0,30,2,155,0,126,0,26,14,202,3,123,0,251,2,51,0,171,3,99,4,138,0,115,7,30,4,43,0,27,3,90,6,26,1,10,6,218,1,99,9,35,3,171,11,158,5,10,1,171,5,251,12,27,7,158,7,158,15,99,2,155,7,99,5,158,1,171,1,99,14,155,2,202,4,171,13,99,6,27,11,10,2,30,10,26,2,99,0,30,6,251,6,90,2,99,1,115,5,10,0,35,2,27,1,26,12,90,1,99,8,171,0,202,2,178,0,10,10,202,1,163,0,115,11,35,0,18,0,158,3,26,0,202,12,251,1,94,0,155,10,202,0,115,3,158,0,34,0,171,7,30,0,251,14,154,0,11,0,26,4,155,1,99,3,74,1,106,0,21,0,155,6,115,0,35,5,27,0,43,1,3,0,1,0,26,6,62,0,42,0,227,0,59,0,14,0,13,0,0,0,0,0,7,8,7,8,7,6,4,3,10,10,11,9,9,6,4,10,10,9,10,7,5,10,11,12,8,6,12,12,9,6,11,12,10,7,12,10,8,11,8,12,11,8,11,11,9,12,11,9,11,9,12,10,12,11,10,12,12,11,12,12,11,11,11,11,11,12,12,12,12,12,12,12,12,11,12,11,12,11,12,11,10,10,10,12,9,12,9,10,8,12,10,8,12,10,7,11,11,12,10,7,12,11,12,9,6,11,11,12,8,6,12,10,10,10,7,5,11,9,11,9,9,6,4,12,8,7,8,7,6,4,2,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,212,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,178,15,177,15,176,15,165,15,163,15,161,15,160,15,149,15,147,15,145,15,144,15,133,15,131,15,129,15,128,15,113,15,112,15,102,15,97,15,96,15,86,15,81,15,80,15,70,15,65,15,64,15,54,15,49,15,48,15,38,15,33,15,32,15,17,15,16,15,1,15,0,15,243,14,241,14,240,14,227,14,225,14,224,14,211,14,209,14,208,14,193,14,192,14,177,14,176,14,160,14,144,14,128,14,112,14,225,1,209,1,208,1,193,1,177,1,161,1,128,1,112,1,99,1,96,1,80,1,64,1,48,1,35,1,32,1,19,1,16,1,0,1,240,0,224,0,209,0,208,0,193,0,192,0,177,0,176,0,161,0,160,0,149,0,145,0,144,0,133,0,129,0,128,0,118,0,117,0,115,0,113,0,112,0,102,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,29,0,124,8,232,10,58,0,28,0,8,0,12,0,50,0,6,0,3,0,165,3,236,1,165,1,128,0,48,0,5,0,1,0,64,0,252,3,212,2,84,1,252,2,60,0,21,0,26,5,0,0,236,2,124,7,210,0,24,0,232,3,236,4,124,2,250,1,34,0,101,7,165,14,84,0,16,0,236,8,172,10,186,3,66,0,93,6,212,10,92,0,40,0,192,3,229,0,92,3,250,4,220,0,165,6,92,7,200,0,165,5,212,4,186,0,192,1,232,5,44,1,232,0,176,1,176,0,93,2,44,0,82,10,92,2,232,1,250,0,72,3,82,6,124,11,101,3,26,3,82,14,26,1,0,2,186,1,172,2,212,6,252,1,186,5,252,13,72,2,232,14,26,11,252,12,101,15,92,11,192,13,124,0,72,5,165,8,252,0,176,3,72,1,172,6,82,2,26,7,232,2,64,2,172,0,26,2,64,1,232,8,172,1,236,0,82,1,165,0,104,0,26,0,108,0,192,5,92,1,37,0,176,5,124,1,20,0,124,4,212,0,232,6,192,0,2,0,93,10,232,4,124,10,212,1,32,0,165,4,176,7,124,3,93,1,42,0,93,0,72,0,124,6,122,0,4,0,252,4,250,2,72,6,0,1,82,0,90,0,13,0,101,1,101,0,165,2,112,0,240,0,61,0,9,0,252,5,72,14,154,0,18,0,221,0,52,0,10,0,14,0,7,0,0,0,0,0,7,12,12,8,7,7,6,6,4,3,10,9,11,8,8,6,4,10,10,12,9,10,7,5,11,10,10,11,8,5,10,11,12,9,6,12,12,9,6,12,12,10,7,11,12,10,7,10,8,12,11,8,12,11,8,11,11,9,11,11,9,12,11,9,12,9,12,10,11,11,10,12,12,11,12,12,11,10,11,12,11,11,11,12,11,12,12,12,12,12,12,12,11,12,11,11,11,11,12,11,12,10,10,10,9,12,9,12,9,12,8,10,8,12,10,8,11,10,7,11,11,12,9,7,12,11,12,9,6,11,11,12,9,6,10,10,11,8,5,12,10,12,9,10,7,5,10,9,11,8,8,6,4,12,12,8,7,8,6,6,4,3,0,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,178,15,177,15,176,15,165,15,163,15,161,15,160,15,149,15,147,15,145,15,144,15,129,15,128,15,117,15,113,15,112,15,97,15,96,15,81,15,80,15,65,15,64,15,54,15,49,15,48,15,38,15,33,15,32,15,22,15,17,15,16,15,6,15,1,15,0,15,241,14,240,14,225,14,224,14,208,14,192,14,179,14,177,14,176,14,163,14,161,14,160,14,144,14,129,14,128,14,113,14,112,14,97,14,96,14,80,14,64,14,48,14,16,14,0,14,65,2,64,2,49,2,208,1,192,1,179,1,176,1,160,1,144,1,128,1,112,1,96,1,80,1,64,1,48,1,32,1,16,1,0,1,240,0,224,0,209,0,208,0,193,0,192,0,177,0,176,0,165,0,161,0,160,0,150,0,149,0,145,0,144,0,134,0,133,0,129,0,128,0,117,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,52,0,156,5,128,2,28,0,76,0,189,0,32,0,60,0,10,0,3,0,253,0,140,0,50,3,213,1,85,0,62,0,1,0,228,7,100,2,178,0,162,0,92,0,5,0,162,2,29,1,50,1,108,7,18,0,24,0,228,1,228,5,178,2,50,4,125,1,14,0,93,5,85,9,100,1,40,0,98,13,36,11,222,2,30,0,64,3,20,0,85,5,128,1,221,0,178,1,146,0,108,3,236,0,228,0,192,0,100,12,93,9,222,1,228,10,50,12,162,1,228,6,50,8,164,1,93,1,50,7,29,3,156,15,226,3,226,9,253,2,36,2,29,5,228,2,156,1,178,5,85,3,100,0,108,1,140,3,128,8,128,4,178,6,64,5,128,0,93,7,85,1,36,4,128,6,98,10,128,10,140,7,156,13,140,15,98,5,242,15,100,4,85,11,226,1,50,0,242,7,64,1,228,3,98,6,85,7,128,3,108,2,50,2,29,0,64,0,226,0,93,3,242,0,98,1,253,1,242,3,12,0,162,14,242,5,114,0,228,4,50,15,140,1,157,0,36,3,156,7,108,0,84,0,93,15,29,2,21,0,36,0,162,6,156,0,4,0,98,0,108,5,98,2,0,0,46,0,242,1,36,1,156,3,94,0,16,0,36,7,164,0,222,0,98,3,82,0,13,0,178,3,125,0,226,5,213,0,93,0,53,0,9,0,156,9,34,0,44,0,61,0,8,0,2,0,6,0,7,0,0,0,0,0,0,0,6,12,12,8,7,8,6,6,4,3,10,9,11,9,9,6,4,11,10,10,10,7,5,11,11,10,11,8,5,11,11,11,12,9,6,11,12,9,6,12,12,10,7,10,7,11,10,8,11,8,11,8,11,8,12,12,9,12,12,9,11,12,9,12,12,10,12,10,12,10,10,11,12,12,11,12,11,11,11,12,11,11,11,12,12,12,11,11,12,12,12,12,12,12,12,12,12,12,12,12,11,11,11,11,10,10,10,10,9,9,11,9,11,9,11,8,12,11,8,11,12,10,8,12,12,10,7,12,10,7,11,12,9,6,10,11,12,8,6,11,10,11,8,5,11,9,10,10,7,5,10,9,11,9,9,6,4,12,8,7,8,6,6,4,3,0,0,0,0,16,248,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,178,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,149,15,147,15,145,15,144,15,133,15,129,15,128,15,113,15,112,15,97,15,96,15,81,15,80,15,69,15,65,15,64,15,49,15,48,15,33,15,32,15,17,15,16,15,1,15,0,15,241,14,240,14,225,14,224,14,208,14,198,14,192,14,182,14,176,14,160,14,144,14,128,14,112,14,96,14,80,14,64,14,51,14,49,14,48,14,32,14,16,14,0,14,240,13,225,13,224,13,192,13,176,13,160,13,80,2,64,2,240,1,224,1,208,1,192,1,176,1,160,1,144,1,128,1,112,1,96,1,80,1,64,1,48,1,32,1,17,1,16,1,1,1,0,1,241,0,240,0,225,0,224,0,209,0,208,0,198,0,193,0,192,0,177,0,176,0,161,0,160,0,149,0,145,0,144,0,133,0,129,0,128,0,117,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,25,0,125,2,132,0,68,0,157,0,61,0,10,0,2,0,3,0,234,0,253,2,122,1,198,1,182,0,38,0,14,0,149,0,96,2,42,3,96,3,6,0,5,0,182,5,106,3,246,6,4,7,250,0,16,0,121,2,212,4,246,0,106,6,29,0,41,0,249,5,70,8,246,4,212,1,56,0,70,4,96,1,29,3,117,0,84,0,212,2,90,0,253,5,64,0,234,6,85,0,96,4,154,0,42,5,160,0,216,0,128,3,125,1,42,9,249,0,122,13,121,1,4,3,42,0,4,1,160,1,128,7,125,0,249,3,70,12,234,3,106,14,4,2,253,1,29,5,170,2,234,5,170,0,128,0,125,6,234,9,149,12,249,9,182,7,182,13,42,1,4,9,84,4,182,15,96,9,212,8,149,4,128,15,96,5,4,11,122,5,121,0,149,7,125,14,96,0,106,7,182,3,149,3,128,1,160,2,106,0,149,1,149,2,70,6,253,3,249,1,84,1,249,13,198,0,149,15,246,1,128,4,0,0,121,10,170,4,224,0,70,2,26,0,121,4,21,0,96,13,128,2,24,0,234,1,122,3,58,0,29,1,253,0,53,0,125,10,160,4,70,1,36,0,182,1,4,5,70,0,32,0,9,0,212,0,170,3,121,6,106,2,54,0,8,0,246,2,170,1,106,1,84,2,57,0,13,0,4,0,118,1,234,2,122,0,118,0,22,0,1,0,121,8,88,0,20,0,213,0,93,0,52,0,12,0,7,0,0,0,0,0,0,0,6,12,8,7,8,7,6,4,3,10,10,11,9,9,6,4,11,10,10,10,7,5,12,11,11,11,8,5,12,11,11,12,9,6,12,12,11,9,6,12,12,10,7,11,10,7,11,7,11,8,11,8,11,11,8,11,9,12,9,12,9,12,9,12,9,12,10,10,12,10,12,10,11,11,10,11,11,11,12,12,12,12,12,12,12,12,11,12,12,12,12,12,12,12,12,12,12,12,11,11,11,11,10,10,10,10,10,11,10,12,9,12,9,12,9,11,8,12,11,8,11,8,11,8,12,10,7,12,10,7,11,10,7,12,11,9,6,11,11,12,8,6,12,10,11,11,8,5,11,10,10,10,7,5,10,9,11,9,9,6,4,12,8,7,8,7,6,4,3,0,0,0,0,0,0,0,0,16,248,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,178,15,177,15,176,15,165,15,163,15,161,15,160,15,149,15,145,15,144,15,131,15,129,15,128,15,115,15,113,15,112,15,97,15,96,15,81,15,80,15,69,15,65,15,64,15,49,15,48,15,33,15,32,15,16,15,0,15,240,14,224,14,213,14,209,14,208,14,192,14,176,14,160,14,144,14,128,14,112,14,96,14,80,14,64,14,48,14,32,14,16,14,0,14,240,13,224,13,208,13,192,13,176,13,160,13,144,13,128,13,96,13,209,12,128,2,112,2,96,2,80,2,64,2,48,2,32,2,16,2,0,2,240,1,224,1,208,1,192,1,176,1,161,1,160,1,144,1,128,1,112,1,96,1,80,1,64,1,48,1,33,1,32,1,17,1,16,1,1,1,0,1,241,0,240,0,225,0,224,0,209,0,208,0,193,0,192,0,177,0,176,0,165,0,161,0,160,0,145,0,144,0,129,0,128,0,117,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,31,0,113,13,63,1,108,0,167,0,103,0,28,0,8,0,5,0,241,6,44,0,186,4,114,0,170,1,2,0,6,0,172,6,175,2,239,6,143,1,10,0,9,0,172,2,42,4,225,6,143,6,177,0,0,0,23,3,23,12,18,6,15,1,17,0,186,15,42,0,114,1,12,0,172,5,215,3,55,0,143,14,242,2,65,0,225,11,127,5,74,0,175,0,111,0,170,6,151,0,1,1,18,0,129,0,113,5,146,0,175,14,191,1,215,0,49,0,1,0,242,1,23,15,58,5,191,0,143,3,23,2,113,3,241,1,186,1,42,2,191,2,143,2,143,0,241,3,225,0,186,0,242,0,191,14,175,6,143,4,225,15,113,2,186,7,58,13,18,12,172,8,23,7,172,0,18,4,1,9,225,4,225,7,23,4,175,12,172,4,172,1,242,4,186,3,215,5,241,7,215,1,175,4,239,4,172,3,170,0,225,1,113,0,241,0,44,1,239,3,42,8,18,1,225,3,250,1,172,13,49,1,18,14,15,0,23,11,127,0,239,10,122,0,170,2,97,0,113,6,39,0,58,1,143,5,255,0,58,3,50,0,1,3,33,0,143,12,127,3,119,0,241,2,225,2,58,0,60,0,18,2,23,8,225,12,63,0,7,0,23,0,1,5,186,2,191,6,87,0,16,0,239,2,23,1,127,1,239,0,106,0,25,0,113,1,239,1,186,6,42,1,250,0,34,0,14,0,225,10,175,1,82,0,47,0,79,0,26,0,4,0,3,0,6,12,9,7,8,7,6,4,3,11,9,11,9,9,6,4,11,11,11,11,7,5,11,11,11,12,8,5,12,12,12,9,6,12,12,9,6,12,10,7,12,10,7,12,11,7,11,8,11,8,12,11,8,12,8,12,9,9,9,9,9,12,12,10,10,10,10,10,10,10,11,11,11,11,11,11,11,12,12,12,12,11,12,12,12,12,12,12,12,12,12,12,12,12,11,11,11,11,11,11,11,12,11,10,10,10,10,10,9,10,12,9,12,9,12,9,12,9,12,9,12,8,11,8,11,8,11,11,8,10,7,10,7,12,10,7,11,12,9,6,11,12,12,9,6,12,11,11,12,8,5,12,10,11,11,7,5,11,10,11,9,9,6,4,12,9,7,8,7,6,4,3,0,0,0,0,255,163,112,63,0,60,91,63,0,220,33,63,254,215,172,62,0,0,114,61,1,48,6,190,3,48,76,190,254,95,34,190,0,192,102,189,255,255,66,61,2,160,218,61,252,95,212,61,0,64,85,61,252,255,120,188,0,128,130,189,0,224,150,189,0,128,62,189,0,0,128,186,1,128,28,61,0,192,89,61], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1852024);
/* memory initializer */ allocate([255,255,35,61,0,0,25,60,0,128,177,188,0,192,26,189,255,255,7,189,2,0,85,188,253,255,46,60,2,0,212,60,255,127,215,60,5,0,98,60,254,255,111,187,1,128,137,188,2,128,162,188,3,0,81,188,0,0,16,186,255,255,36,60,255,255,102,60,253,255,46,60,1,0,44,59,1,0,176,187,0,0,25,188,0,0,5,188,255,255,79,187,0,0,24,59,255,255,183,59,0,0,182,59,255,255,59,59,1,0,32,186,1,0,68,187,2,0,92,187,255,255,3,187,254,255,255,184,252,255,175,58,253,255,223,58,0,0,152,58,254,255,127,57,0,0,224,185,1,0,32,186,0,0,224,185,254,255,255,184,1,0,128,56,254,255,255,56,1,0,128,56,0,0,0,0,0,0,0,0,0,0,0,0,3,255,16,0,3,255,24,0,2,255,4,1,3,255,8,1,5,255,32,0,4,255,16,1,2,0,0,4,2,0,0,8,2,0,0,12,3,0,0,16,3,0,0,24,2,0,1,3,3,0,1,7,2,255,16,0,2,255,20,0,2,255,24,0,2,255,28,0,4,255,32,0,4,255,48,0,2,255,4,1,3,255,8,1,4,255,16,1,2,0,0,4,3,0,0,8,4,0,0,16,2,0,1,3,3,0,1,7,0,0,0,0,0,0,3,0,16,0,5,0,114,0,7,0,113,0,7,0,84,1,9,0,171,10,12,0,168,10,12,0,20,0,5,0,112,0,7,0,2,0,3,0,3,0,3,0,12,0,4,0,11,0,4,0,3,0,4,0,17,0,5,0,115,0,7,0,84,0,7,0,171,0,8,0,171,2,10,0,83,21,13,0,82,21,13,0,85,21,13,0,84,21,13,0,13,0,4,0,30,0,5,0,18,0,5,0,62,0,6,0,43,0,6,0,2,0,4,0,63,0,6,0,29,0,5,0,19,0,5,0,3,0,3,0,31,0,5,0,41,0,6,0,61,0,6,0,12,0,7,0,105,0,10,0,69,3,13,0,2,0,5,0,40,0,6,0,2,0,3,0,1,0,3,0,14,0,4,0,12,0,4,0,21,0,5,0,7,0,6,0,27,0,8,0,107,0,10,0,106,0,10,0,68,3,13,0,71,3,13,0,70,3,13,0,161,1,12,0,160,1,12,0,11,0,4,0,26,0,5,0,18,0,5,0,0,0,5,0,60,0,6,0,8,0,4,0,27,0,5,0,19,0,5,0,1,0,5,0,4,0,3,0,4,0,4,0,63,0,6,0,20,0,5,0,86,0,7,0,92,1,9,0,213,21,13,0,60,0,6,0,42,0,6,0,0,0,3,0,1,0,3,0,14,0,4,0,13,0,4,0,12,0,5,0,175,0,8,0,187,2,10,0,212,21,13,0,215,21,13,0,214,21,13,0,209,21,13,0,208,21,13,0,211,21,13,0,210,21,13,0,11,0,4,0,25,0,5,0,13,0,5,0,62,0,6,0,49,0,6,0,7,0,4,0,5,0,4,0,61,0,6,0,48,0,6,0,5,0,3,0,8,0,4,0,26,0,5,0,0,0,4,0,54,0,6,0,17,0,8,0,6,1,12,0,10,0,7,0,110,0,7,0,2,0,3,0,3,0,3,0,3,0,4,0,2,0,4,0,111,0,7,0,33,0,9,0,15,2,13,0,14,2,13,0,1,1,12,0,0,1,12,0,3,1,12,0,2,1,12,0,5,1,12,0,4,1,12,0,12,0,4,0,30,0,5,0,3,0,5,0,62,0,6,0,63,0,6,0,9,0,4,0,14,0,4,0,11,0,7,0,9,0,7,0,2,0,3,0,14,0,4,0,30,0,5,0,12,0,4,0,31,0,5,0,110,0,7,0,173,0,10,0,175,0,10,0,20,0,7,0,4,0,3,0,3,0,3,0,26,0,5,0,23,0,5,0,42,0,8,0,118,5,13,0,239,10,14,0,238,10,14,0,113,5,13,0,112,5,13,0,115,5,13,0,114,5,13,0,117,5,13,0,116,5,13,0,3,0,4,0,22,0,5,0,4,0,5,0,54,0,6,0,11,0,6,0,10,0,4,0,0,0,3,0,111,0,7,0,172,0,10,0,4,0,3,0,5,0,4,0,3,0,3,0,1,0,3,0,4,0,4,0,47,0,6,0,38,5,11,0,149,20,13,0,166,0,8,0,7,0,3,0,6,0,3,0,45,0,6,0,44,0,6,0,148,20,13,0,151,20,13,0,150,20,13,0,145,20,13,0,144,20,13,0,147,20,13,0,146,20,13,0,61,41,14,0,60,41,14,0,63,41,14,0,0,0,3,0,40,0,6,0,165,0,8,0,72,1,9,0,167,0,8,0,46,0,6,0,21,0,5,0,78,10,12,0,62,41,14,0,4,0,3,0,5,0,4,0,3,0,3,0,1,0,3,0,4,0,4,0,47,0,6,0,38,5,11,0,149,20,13,0,166,0,8,0,7,0,3,0,6,0,3,0,45,0,6,0,44,0,6,0,148,20,13,0,151,20,13,0,150,20,13,0,145,20,13,0,144,20,13,0,147,20,13,0,146,20,13,0,61,41,14,0,60,41,14,0,63,41,14,0,0,0,3,0,40,0,6,0,165,0,8,0,72,1,9,0,167,0,8,0,46,0,6,0,21,0,5,0,78,10,12,0,62,41,14,0,4,0,3,0,5,0,4,0,3,0,3,0,1,0,3,0,4,0,4,0,47,0,6,0,38,5,11,0,149,20,13,0,166,0,8,0,7,0,3,0,6,0,3,0,45,0,6,0,44,0,6,0,148,20,13,0,151,20,13,0,150,20,13,0,145,20,13,0,144,20,13,0,147,20,13,0,146,20,13,0,61,41,14,0,60,41,14,0,63,41,14,0,0,0,3,0,40,0,6,0,165,0,8,0,72,1,9,0,167,0,8,0,46,0,6,0,21,0,5,0,78,10,12,0,62,41,14,0,3,0,3,0,17,0,5,0,32,0,6,0,116,0,7,0,13,1,9,0,99,8,12,0,96,8,12,0,10,0,5,0,117,0,7,0,1,0,3,0,0,0,3,0,11,0,4,0,10,0,4,0,24,0,5,0,56,0,6,0,66,0,7,0,15,1,9,0,14,1,9,0,25,2,10,0,195,16,13,0,194,16,13,0,197,16,13,0,196,16,13,0,15,0,4,0,4,0,4,0,25,0,5,0,11,0,5,0,57,0,6,0,9,0,4,0,27,0,5,0,26,0,5,0,59,0,6,0,5,0,3,0,1,0,4,0,62,0,6,0,1,0,5,0,226,0,8,0,111,28,13,0,217,56,14,0,57,0,6,0,31,0,6,0,2,0,3,0,1,0,3,0,9,0,4,0,8,0,4,0,0,0,5,0,112,0,7,0,199,1,9,0,140,3,10,0,26,7,11,0,216,56,14,0,219,56,14,0,218,56,14,0,221,56,14,0,220,56,14,0,13,0,4,0,29,0,5,0,14,0,5,0,63,0,6,0,60,0,6,0,12,0,4,0,6,0,4,0,61,0,6,0,30,0,6,0,6,0,3,0,11,0,4,0,17,0,5,0,30,0,5,0,116,0,7,0,170,3,10,0,92,29,13,0,1,0,6,0,33,0,6,0,1,0,3,0,2,0,3,0,7,0,4,0,6,0,4,0,62,0,6,0,235,0,8,0,212,1,9,0,175,14,12,0,187,58,14,0,186,58,14,0,89,29,13,0,88,29,13,0,91,29,13,0,90,29,13,0,10,0,4,0,28,0,5,0,1,0,5,0,63,0,6,0,59,0,6,0,1,0,4,0,9,0,4,0,32,0,6,0,0,0,6,0,4,0,3,0,10,0,4,0,23,0,5,0,4,0,4,0,22,0,6,0,106,1,9,0,177,22,13,0,23,0,7,0,91,0,7,0,6,0,3,0,7,0,3,0,1,0,4,0,0,0,4,0,10,0,6,0,215,2,10,0,90,11,12,0,176,22,13,0,179,22,13,0,178,22,13,0,109,45,14,0,108,45,14,0,111,45,14,0,110,45,14,0,6,0,4,0,10,0,5,0,4,0,5,0,44,0,6,0,23,0,6,0,3,0,4,0,7,0,4,0,22,0,7,0,180,0,8,0,5,0,3,0,13,0,4,0,5,0,4,0,9,0,4,0,51,0,6,0,147,1,9,0,44,25,13,0,97,0,8,0,49,0,7,0,0,0,2,0,7,0,3,0,16,0,5,0,17,0,5,0,200,0,8,0,47,25,13,0,91,50,14,0,90,50,14,0,41,25,13,0,40,25,13,0,43,25,13,0,42,25,13,0,93,50,14,0,92,50,14,0,24,0,5,0,26,0,6,0,27,0,6,0,101,0,7,0,25,0,6,0,4,0,4,0,7,0,4,0,96,0,8,0,36,3,10,0,6,0,3,0,0,0,3,0,2,0,4,0,15,0,4,0,57,0,6,0,217,1,9,0,130,29,13,0,97,7,11,0,190,3,10,0,1,0,2,0,2,0,2,0,15,0,6,0,14,0,6,0,98,7,11,0,7,59,14,0,6,59,14,0,29,59,14,0,28,59,14,0,31,59,14,0,30,59,14,0,25,59,14,0,24,59,14,0,27,59,14,0,56,0,6,0,222,1,9,0,237,0,8,0,191,3,10,0,238,0,8,0,58,0,6,0,6,0,5,0,192,14,12,0,26,59,14,0,0,0,2,0,2,0,3,0,15,0,5,0,6,0,4,0,28,0,6,0,208,1,10,0,140,14,13,0,27,29,14,0,26,29,14,0,3,0,2,0,2,0,2,0,234,0,9,0,233,0,9,0,137,14,13,0,136,14,13,0,139,14,13,0,138,14,13,0,101,29,14,0,100,29,14,0,103,29,14,0,102,29,14,0,97,29,14,0,96,29,14,0,173,3,11,0,99,29,14,0,98,29,14,0,29,29,14,0,28,29,14,0,59,0,7,0,215,1,10,0,31,29,14,0,30,29,14,0,2,0,2,0,15,0,4,0,28,0,5,0,12,0,4,0,59,0,6,0,172,1,9,0,216,26,13,0,179,53,14,0,178,53,14,0,1,0,2,0,0,0,2,0,105,0,7,0,104,0,7,0,189,53,14,0,188,53,14,0,191,53,14,0,190,53,14,0,185,53,14,0,184,53,14,0,187,53,14,0,186,53,14,0,181,53,14,0,180,53,14,0,169,1,9,0,168,1,9,0,90,3,10,0,215,0,8,0,213,0,8,0,58,0,6,0,27,0,5,0,183,53,14,0,182,53,14,0,3,0,4,0,9,0,6,0,208,0,8,0,163,1,9,0,68,3,10,0,20,13,12,0,43,26,13,0,4,0,4,0,21,0,7,0,0,0,3,0,15,0,4,0,11,0,4,0,12,0,4,0,14,0,4,0,9,0,4,0,27,0,5,0,10,0,5,0,20,0,5,0,13,0,5,0,42,0,6,0,20,0,7,0,139,6,11,0,42,26,13,0,8,0,4,0,11,0,5,0,43,0,6,0,11,0,6,0,105,0,7,0,53,0,6,0,8,0,6,0,7,0,4,0,12,0,5,0,10,0,4,0,60,0,6,0,50,0,7,0,48,0,7,0,197,0,9,0,33,6,12,0,32,6,12,0,31,0,5,0,51,0,7,0,1,0,3,0,0,0,3,0,14,0,4,0,13,0,4,0,12,0,4,0,4,0,4,0,13,0,5,0,38,0,6,0,39,0,6,0,20,0,6,0,99,0,8,0,137,1,10,0,35,6,12,0,34,6,12,0,11,0,4,0,18,0,5,0,61,0,6,0,34,0,6,0,21,0,6,0,11,0,5,0,35,0,6,0,7,0,4,0,16,0,5,0,15,0,4,0,12,0,5,0,67,0,7,0,16,0,6,0,68,0,8,0,20,1,10,0,85,4,12,0,24,0,5,0,35,0,7,0,1,0,3,0,0,0,3,0,14,0,4,0,13,0,4,0,9,0,4,0,25,0,5,0,9,0,5,0,23,0,6,0,22,0,6,0,66,0,7,0,139,0,9,0,84,4,12,0,87,4,12,0,86,4,12,0,11,0,4,0,21,0,5,0,10,0,5,0,41,0,6,0,32,0,6,0,13,0,5,0,40,0,6,0,7,0,4,0,17,0,5,0,1,0,3,0,26,0,5,0,41,0,6,0,42,0,6,0,160,0,8,0,133,2,10,0,37,20,13,0,2,0,5,0,0,0,7,0,2,0,3,0,3,0,3,0,12,0,4,0,11,0,4,0,8,0,4,0,18,0,5,0,1,0,6,0,81,0,7,0,1,0,7,0,67,1,9,0,8,5,11,0,36,20,13,0,39,20,13,0,38,20,13,0,15,0,4,0,28,0,5,0,3,0,5,0,55,0,6,0,43,0,6,0,19,0,5,0,54,0,6,0,29,0,5,0,1,0,5,0,4,0,3,0,31,0,5,0,61,0,6,0,6,0,5,0,22,0,7,0,83,0,9,0,74,1,11,0,52,0,6,0,42,0,8,0,2,0,3,0,3,0,3,0,11,0,4,0,12,0,4,0,28,0,5,0,55,0,6,0,23,0,7,0,43,0,8,0,40,0,8,0,164,0,10,0,45,5,13,0,44,5,13,0,47,5,13,0,46,5,13,0,0,0,3,0,29,0,5,0,7,0,5,0,4,0,5,0,53,0,6,0,20,0,5,0,54,0,6,0,21,0,5,0,60,0,6,0,4,0,3,0,10,0,4,0,7,0,5,0,29,0,5,0,9,0,6,0,243,1,9,0,199,7,11,0,8,0,6,0,240,1,9,0,3,0,3,0,2,0,3,0,13,0,4,0,12,0,4,0,23,0,5,0,125,0,7,0,242,1,9,0,198,7,11,0,197,7,11,0,18,31,13,0,39,62,14,0,38,62,14,0,17,31,13,0,16,31,13,0,0,0,3,0,30,0,5,0,6,0,5,0,57,0,6,0,56,0,6,0,63,0,6,0,44,0,6,0,5,0,5,0,45,0,6,0,2,0,3,0,7,0,4,0,24,0,5,0,3,0,4,0,5,0,5,0,53,0,7,0,79,0,9,0,18,0,7,0,229,4,13,0,5,0,3,0,4,0,3,0,13,0,4,0,14,0,4,0,51,0,6,0,38,0,8,0,157,0,10,0,228,4,13,0,231,4,13,0,230,4,13,0,225,4,13,0,224,4,13,0,227,4,13,0,226,4,13,0,0,0,3,0,31,0,5,0,12,0,5,0,61,0,6,0,60,0,6,0,50,0,6,0,52,0,7,0,27,0,6,0,8,0,6,0,0,0,3,0,4,0,4,0,28,0,5,0,15,0,4,0,2,0,4,0,7,0,5,0,117,0,7,0,232,0,8,0,42,29,13,0,5,0,3,0,4,0,3,0,13,0,4,0,12,0,4,0,119,0,7,0,150,14,12,0,87,58,14,0,86,58,14,0,93,58,14,0,92,58,14,0,95,58,14,0,94,58,14,0,41,29,13,0,40,29,13,0,3,0,3,0,6,0,5,0,10,0,5,0,44,0,7,0,23,0,6,0,118,0,7,0,211,1,9,0,164,3,10,0,45,0,7,0,10,0,4,0,36,0,6,0,191,0,8,0,133,0,8,0,17,2,10,0,66,8,12,0,135,16,13,0,24,0,5,0,32,0,6,0,1,0,3,0,2,0,3,0,14,0,4,0,13,0,4,0,7,0,4,0,19,0,5,0,37,0,6,0,94,0,7,0,67,0,7,0,190,0,8,0,9,1,9,0,134,16,13,0,65,8,12,0,64,8,12,0,15,0,4,0,1,0,4,0,17,0,5,0,0,0,5,0,46,0,6,0,25,0,5,0,1,0,5,0,6,0,4,0,22,0,5,0,2,0,3,0,15,0,5,0,111,0,7,0,97,0,7,0,116,3,10,0,168,27,13,0,83,55,14,0,18,0,5,0,54,0,6,0,0,0,3,0,1,0,3,0,10,0,4,0,11,0,4,0,26,0,5,0,49,0,6,0,96,0,7,0,220,0,8,0,187,1,9,0,235,6,11,0,171,27,13,0,82,55,14,0,85,55,14,0,84,55,14,0,14,0,4,0,6,0,4,0,19,0,5,0,14,0,5,0,62,0,6,0,8,0,4,0,30,0,5,0,25,0,5,0,63,0,6,0,3,0,3,0,28,0,5,0,37,0,6,0,36,0,6,0,218,1,9,0,189,29,13,0,124,59,14,0,60,0,6,0,61,0,6,0,0,0,3,0,1,0,3,0,11,0,4,0,10,0,4,0,11,0,5,0,119,0,7,0,236,0,8,0,182,3,10,0,110,7,11,0,191,29,13,0,251,118,15,0,250,118,15,0,121,59,14,0,120,59,14,0,13,0,4,0,31,0,5,0,19,0,5,0,10,0,5,0,8,0,5,0,12,0,4,0,8,0,4,0,9,0,5,0,58,0,6,0,5,0,3,0,3,0,4,0,4,0,5,0,16,0,5,0,143,0,8,0,117,4,11,0,209,17,13,0,121,0,7,0,39,0,6,0,2,0,3,0,3,0,3,0,1,0,4,0,0,0,4,0,38,0,6,0,70,0,7,0,28,1,9,0,119,4,11,0,237,8,12,0,208,17,13,0,211,17,13,0,210,17,13,0,217,17,13,0,216,17,13,0,13,0,4,0,31,0,5,0,18,0,5,0,5,0,5,0,61,0,6,0,12,0,4,0,14,0,4,0,34,0,6,0,120,0,7,0,5,0,3,0,12,0,4,0,27,0,5,0,0,0,4,0,6,0,6,0,226,3,10,0,61,62,14,0,15,0,7,0,52,0,6,0,3,0,3,0,2,0,3,0,30,0,5,0,29,0,5,0,125,0,7,0,240,1,9,0,198,7,11,0,60,62,14,0,63,62,14,0,62,62,14,0,57,62,14,0,56,62,14,0,59,62,14,0,58,62,14,0,8,0,4,0,28,0,5,0,2,0,5,0,63,0,6,0,53,0,6,0,9,0,4,0,1,0,3,0,14,0,7,0,249,0,8,0,4,0,3,0,11,0,4,0,1,0,4,0,10,0,4,0,30,0,6,0,224,0,9,0,30,14,13,0,113,0,8,0,57,0,7,0,7,0,3,0,6,0,3,0,13,0,5,0,12,0,5,0,32,0,7,0,194,1,10,0,63,28,14,0,62,28,14,0,25,14,13,0,24,14,13,0,27,14,13,0,26,14,13,0,29,14,13,0,28,14,13,0,0,0,4,0,9,0,5,0,29,0,6,0,31,0,6,0,17,0,6,0,5,0,4,0,1,0,3,0,67,0,8,0,66,0,8,0,4,0,3,0,13,0,4,0,7,0,4,0,2,0,3,0,20,0,5,0,108,1,9,0,209,22,13,0,223,2,10,0,110,1,9,0,0,0,2,0,7,0,3,0,44,0,6,0,43,0,6,0,222,2,10,0,208,22,13,0,211,22,13,0,210,22,13,0,181,45,14,0,180,45,14,0,183,45,14,0,182,45,14,0,217,22,13,0,216,22,13,0,12,0,5,0,42,0,6,0,90,0,7,0,27,0,6,0,26,0,6,0,23,0,5,0,12,0,4,0,183,5,11,0,181,5,11,0,2,0,2,0,15,0,4,0,28,0,5,0,12,0,4,0,59,0,6,0,172,1,9,0,216,26,13,0,179,53,14,0,178,53,14,0,1,0,2,0,0,0,2,0,105,0,7,0,104,0,7,0,189,53,14,0,188,53,14,0,191,53,14,0,190,53,14,0,185,53,14,0,184,53,14,0,187,53,14,0,186,53,14,0,181,53,14,0,180,53,14,0,169,1,9,0,168,1,9,0,90,3,10,0,215,0,8,0,213,0,8,0,58,0,6,0,27,0,5,0,183,53,14,0,182,53,14,0,11,0,5,0,43,0,7,0,84,0,8,0,183,1,9,0,217,6,11,0,177,13,12,0,176,13,12,0,2,0,4,0,171,0,9,0,9,0,4,0,10,0,4,0,7,0,4,0,8,0,4,0,15,0,4,0,12,0,4,0,3,0,4,0,29,0,5,0,4,0,4,0,11,0,4,0,6,0,4,0,26,0,5,0,3,0,6,0,170,0,9,0,1,0,4,0,0,0,5,0,20,0,6,0,108,0,7,0,218,0,8,0,2,0,6,0,109,3,10,0,28,0,5,0,55,0,6,0,29,0,5,0,4,0,6,0,182,0,8,0,106,0,8,0,185,5,11,0,225,22,13,0,224,22,13,0,7,0,4,0,111,1,9,0,12,0,4,0,13,0,4,0,9,0,4,0,8,0,4,0,15,0,4,0,10,0,4,0,3,0,4,0,23,0,5,0,2,0,4,0,4,0,4,0,28,0,5,0,44,0,6,0,107,0,8,0,113,11,12,0,5,0,4,0,3,0,5,0,27,0,6,0,90,0,7,0,52,0,7,0,5,0,6,0,221,2,10,0,0,0,4,0,12,0,5,0,3,0,4,0,127,0,7,0,161,0,8,0,160,0,8,0,12,2,10,0,52,8,12,0,107,16,13,0,7,0,4,0,130,0,8,0,14,0,4,0,13,0,4,0,11,0,4,0,12,0,4,0,0,0,3,0,9,0,4,0,2,0,4,0,17,0,5,0,30,0,5,0,21,0,5,0,62,0,6,0,64,0,7,0,27,4,11,0,106,16,13,0,6,0,4,0,10,0,5,0,41,0,6,0,126,0,7,0,81,0,7,0,33,0,6,0,7,1,9,0,4,0,4,0,11,0,5,0,7,0,4,0,27,0,6,0,246,0,8,0,233,0,8,0,161,3,10,0,64,7,11,0,130,14,12,0,31,0,5,0,239,1,9,0,1,0,3,0,2,0,3,0,11,0,4,0,12,0,4,0,13,0,4,0,8,0,4,0,28,0,5,0,3,0,5,0,18,0,5,0,2,0,5,0,117,0,7,0,209,1,9,0,7,29,13,0,6,29,13,0,10,0,4,0,19,0,5,0,59,0,6,0,26,0,6,0,122,0,7,0,60,0,6,0,238,1,9,0,0,0,4,0,12,0,5,0,13,0,4,0,61,0,6,0,66,0,7,0,55,0,7,0,217,0,9,0,98,3,11,0,198,6,12,0,31,0,5,0,134,0,8,0,1,0,3,0,2,0,3,0,12,0,4,0,11,0,4,0,10,0,4,0,1,0,4,0,15,0,5,0,37,0,6,0,60,0,6,0,26,0,6,0,135,0,8,0,176,1,10,0,143,13,13,0,142,13,13,0,14,0,4,0,19,0,5,0,12,0,5,0,36,0,6,0,32,0,6,0,17,0,5,0,109,0,8,0,0,0,4,0,14,0,5,0,0,0,3,0,18,0,5,0,118,0,7,0,119,0,7,0,77,1,9,0,51,5,11,0,201,20,13,0,19,0,5,0,165,0,8,0,2,0,3,0,3,0,3,0,11,0,4,0,12,0,4,0,8,0,4,0,26,0,5,0,43,0,6,0,117,0,7,0,116,0,7,0,167,0,8,0,152,2,10,0,200,20,13,0,203,20,13,0,202,20,13,0,15,0,4,0,28,0,5,0,7,0,5,0,42,0,6,0,40,0,6,0,27,0,5,0,164,0,8,0,2,0,4,0,6,0,5,0,2,0,3,0,26,0,5,0,43,0,6,0,58,0,6,0,237,0,8,0,131,2,10,0,10,10,12,0,4,0,5,0,161,0,8,0,4,0,3,0,3,0,3,0,11,0,4,0,12,0,4,0,31,0,5,0,6,0,5,0,119,0,7,0,163,0,8,0,162,0,8,0,64,1,9,0,23,20,13,0,22,20,13,0,9,10,12,0,8,10,12,0,0,0,3,0,30,0,5,0,7,0,5,0,42,0,6,0,41,0,6,0,28,0,5,0,236,0,8,0,27,0,5,0,5,0,5,0,2,0,3,0,2,0,4,0,24,0,5,0,29,0,5,0,53,0,6,0,228,0,8,0,207,1,11,0,29,0,7,0,114,0,9,0,4,0,3,0,5,0,3,0,6,0,4,0,7,0,4,0,6,0,5,0,115,0,7,0,56,0,8,0,206,1,11,0,155,3,12,0,152,3,12,0,51,7,13,0,50,7,13,0,53,7,13,0,52,7,13,0,0,0,3,0,31,0,5,0,27,0,5,0,52,0,6,0,15,0,6,0,30,0,5,0,229,0,8,0,25,0,5,0,56,0,6,0,22,0,5,0,80,0,7,0,114,1,9,0,231,2,10,0,50,23,13,0,103,46,14,0,102,46,14,0,6,0,4,0,81,0,7,0,1,0,3,0,0,0,3,0,13,0,4,0,12,0,4,0,9,0,4,0,28,0,5,0,9,0,5,0,28,0,6,0,29,0,6,0,93,0,7,0,184,0,8,0,205,5,11,0,49,23,13,0,48,23,13,0,15,0,4,0,5,0,4,0,15,0,5,0,8,0,5,0,41,0,6,0,29,0,5,0,47,0,6,0,8,0,4,0,21,0,5,0,9,0,4,0,33,0,6,0,64,0,7,0,173,0,8,0,176,2,10,0,137,21,13,0,136,21,13,0,28,0,5,0,95,0,7,0,0,0,3,0,15,0,4,0,13,0,4,0,12,0,4,0,6,0,4,0,17,0,5,0,42,0,6,0,87,0,7,0,94,0,7,0,65,0,7,0,89,1,9,0,99,5,11,0,139,21,13,0,138,21,13,0,1,0,3,0,5,0,4,0,20,0,5,0,59,0,6,0,46,0,6,0,4,0,4,0,58,0,6,0,7,0,4,0,22,0,5,0,14,0,4,0,7,0,5,0,70,0,7,0,69,0,7,0,100,0,9,0,42,3,12,0,87,6,13,0,24,0,5,0,13,0,6,0,0,0,3,0,15,0,4,0,10,0,4,0,11,0,4,0,26,0,5,0,54,0,6,0,71,0,7,0,68,0,7,0,24,0,7,0,51,0,8,0,203,0,10,0,86,6,13,0,41,3,12,0,40,3,12,0,2,0,3,0,6,0,4,0,25,0,5,0,14,0,5,0,55,0,6,0,9,0,4,0,15,0,5,0,2,0,4,0,16,0,5,0,3,0,3,0,24,0,5,0,35,0,6,0,119,0,7,0,148,1,9,0,86,25,13,0,175,50,14,0,58,0,6,0,118,0,7,0,2,0,3,0,1,0,3,0,31,0,5,0,30,0,5,0,20,0,5,0,34,0,6,0,100,0,7,0,151,1,9,0,150,1,9,0,43,3,10,0,84,6,11,0,174,50,14,0,85,25,13,0,84,25,13,0,0,0,3,0,9,0,4,0,28,0,5,0,21,0,5,0,16,0,5,0,13,0,4,0,23,0,5,0,22,0,5,0,51,0,6,0,5,0,3,0,6,0,4,0,62,0,6,0,16,0,5,0,72,0,7,0,63,9,12,0,250,36,14,0,50,0,6,0,103,0,7,0,2,0,3,0,1,0,3,0,27,0,5,0,30,0,5,0,52,0,6,0,102,0,7,0,146,0,8,0,38,1,9,0,78,2,10,0,158,4,11,0,247,73,15,0,246,73,15,0,249,36,14,0,248,36,14,0,0,0,3,0,7,0,4,0,24,0,5,0,17,0,5,0,63,0,6,0,14,0,4,0,19,0,5,0,53,0,6,0,37,0,6,0,5,0,3,0,8,0,4,0,18,0,5,0,28,0,5,0,28,0,6,0,234,0,9,0,117,29,14,0,30,0,6,0,102,0,7,0,1,0,3,0,2,0,3,0,27,0,5,0,26,0,5,0,31,0,6,0,59,0,7,0,116,0,8,0,214,1,10,0,175,3,11,0,116,29,14,0,119,29,14,0,118,29,14,0,185,14,13,0,184,14,13,0,15,0,4,0,6,0,4,0,19,0,5,0,59,0,6,0,58,0,6,0,0,0,3,0,24,0,5,0,50,0,6,0,103,0,7,0,4,0,3,0,10,0,4,0,27,0,5,0,12,0,4,0,13,0,5,0,230,0,8,0,132,6,11,0,114,0,7,0,231,0,8,0,2,0,3,0,1,0,3,0,23,0,5,0,22,0,5,0,24,0,6,0,209,0,8,0,160,1,9,0,134,6,11,0,15,13,12,0,10,13,12,0,23,26,13,0,22,26,13,0,29,26,13,0,28,26,13,0,15,0,4,0,29,0,5,0,14,0,5,0,53,0,6,0,56,0,6,0,0,0,3,0,15,0,5,0,25,0,6,0,105,0,7,0,3,0,3,0,12,0,4,0,27,0,5,0,0,0,3,0,3,0,4,0,46,0,6,0,81,0,9,0,188,0,8,0,83,0,9,0,4,0,3,0,2,0,3,0,22,0,5,0,21,0,5,0,21,0,7,0,80,0,9,0,164,0,10,0,148,2,12,0,43,5,13,0,42,5,13,0,45,5,13,0,44,5,13,0,47,5,13,0,46,5,13,0,14,0,4,0,26,0,5,0,4,0,5,0,40,0,6,0,41,0,6,0,15,0,4,0,11,0,6,0,95,0,7,0,189,0,8,0,8,0,5,0,37,0,7,0,122,1,9,0,247,2,10,0,219,11,12,0,180,23,13,0,107,47,14,0,29,0,5,0,106,47,14,0,8,0,4,0,7,0,4,0,1,0,4,0,2,0,4,0,10,0,4,0,6,0,4,0,0,0,4,0,28,0,5,0,9,0,4,0,13,0,4,0,15,0,4,0,12,0,4,0,3,0,4,0,10,0,5,0,22,0,5,0,19,0,6,0,93,0,7,0,36,0,7,0,188,0,8,0,92,0,7,0,236,5,11,0,11,0,5,0,95,0,7,0,15,0,5,0,16,0,6,0,75,0,8,0,198,0,8,0,29,3,10,0,113,12,12,0,112,12,12,0,1,0,4,0,115,12,12,0,8,0,4,0,9,0,4,0,2,0,4,0,3,0,4,0,11,0,4,0,6,0,4,0,0,0,4,0,28,0,5,0,5,0,4,0,13,0,4,0,15,0,4,0,10,0,4,0,25,0,5,0,19,0,6,0,29,0,5,0,48,0,6,0,98,0,7,0,36,0,7,0,74,0,8,0,143,1,9,0,114,12,12,0,14,0,5,0,17,0,6,0,27,0,5,0,3,0,6,0,141,0,8,0,64,0,7,0,57,2,10,0,113,4,11,0,224,8,12,0,3,0,4,0,195,17,13,0,10,0,4,0,9,0,4,0,4,0,4,0,5,0,4,0,14,0,4,0,7,0,4,0,1,0,4,0,30,0,5,0,6,0,4,0,12,0,4,0,11,0,4,0,2,0,4,0,0,0,5,0,65,0,7,0,31,0,5,0,34,0,6,0,2,0,6,0,143,0,8,0,140,0,8,0,29,1,9,0,194,17,13,0,26,0,5,0,33,0,6,0,31,0,5,0,3,0,6,0,3,0,7,0,67,0,7,0,11,0,9,0,21,0,10,0,81,0,12,0,3,0,4,0,80,0,12,0,13,0,4,0,12,0,4,0,4,0,4,0,6,0,4,0,14,0,4,0,10,0,4,0,1,0,4,0,30,0,5,0,5,0,4,0,9,0,4,0,7,0,4,0,17,0,5,0,2,0,6,0,4,0,8,0,2,0,4,0,45,0,6,0,32,0,6,0,66,0,7,0,1,0,7,0,0,0,7,0,41,0,11,0,23,0,5,0,44,0,6,0,3,0,4,0,31,0,6,0,58,0,7,0,93,0,7,0,115,1,9,0,228,2,10,0,45,23,13,0,4,0,4,0,44,23,13,0,15,0,4,0,14,0,4,0,9,0,4,0,8,0,4,0,12,0,4,0,10,0,4,0,1,0,4,0,22,0,5,0,2,0,4,0,5,0,4,0,26,0,5,0,47,0,6,0,56,0,7,0,202,5,11,0,6,0,4,0,55,0,6,0,30,0,6,0,59,0,7,0,57,0,7,0,184,0,8,0,151,11,12,0,0,0,4,0,54,0,6,0,6,0,4,0,55,0,6,0,93,0,7,0,12,0,6,0,185,0,8,0,227,2,10,0,196,5,11,0,4,0,4,0,21,23,13,0,0,0,3,0,15,0,4,0,8,0,4,0,7,0,4,0,12,0,4,0,9,0,4,0,29,0,5,0,22,0,5,0,28,0,5,0,26,0,5,0,11,0,5,0,94,0,7,0,112,1,9,0,20,23,13,0,10,0,4,0,10,0,5,0,54,0,6,0,95,0,7,0,27,0,7,0,26,0,7,0,139,11,12,0,2,0,4,0,7,0,5,0,12,0,4,0,11,0,5,0,121,0,7,0,34,0,6,0,240,0,8,0,25,1,9,0,48,2,10,0,29,0,5,0,196,8,12,0,1,0,3,0,0,0,3,0,10,0,4,0,9,0,4,0,11,0,4,0,7,0,4,0,28,0,5,0,61,0,6,0,13,0,5,0,8,0,5,0,21,0,6,0,141,0,8,0,139,17,13,0,138,17,13,0,13,0,4,0,16,0,5,0,9,0,5,0,20,0,6,0,71,0,7,0,241,0,8,0,99,4,11,0,31,0,5,0,12,0,5,0,0,0,3,0,26,0,5,0,51,0,6,0,12,0,5,0,70,0,7,0,227,1,9,0,197,3,10,0,23,0,5,0,33,30,13,0,2,0,3,0,1,0,3,0,9,0,4,0,10,0,4,0,7,0,4,0,27,0,5,0,61,0,6,0,27,0,6,0,34,0,6,0,121,0,7,0,240,0,8,0,32,30,13,0,35,30,13,0,34,30,13,0,14,0,4,0,22,0,5,0,24,0,5,0,50,0,6,0,26,0,6,0,71,0,7,0,137,7,11,0,31,0,5,0,16,0,5,0,29,0,5,0,97,0,7,0,78,0,8,0,158,0,9,0,124,2,11,0,245,9,13,0,244,9,13,0,3,0,4,0,96,0,7,0,0,0,3,0,15,0,4,0,11,0,4,0,10,0,4,0,9,0,4,0,5,0,4,0,13,0,5,0,49,0,6,0,8,0,5,0,56,0,6,0,18,0,6,0,38,0,7,0,63,1,10,0,251,4,12,0,13,0,4,0,2,0,4,0,12,0,5,0,57,0,6,0,28,0,6,0,15,0,5,0,29,0,6,0,8,0,4,0,25,0,5,0,7,0,4,0,25,0,6,0,171,0,8,0,170,0,8,0,25,1,10,0,97,4,12,0,96,4,12,0,27,0,5,0,71,0,8,0,1,0,3,0,0,0,3,0,12,0,4,0,11,0,4,0,9,0,4,0,5,0,4,0,13,0,5,0,53,0,6,0,61,0,6,0,60,0,6,0,24,0,6,0,34,0,7,0,141,0,9,0,49,2,11,0,14,0,4,0,31,0,5,0,9,0,5,0,43,0,6,0,16,0,6,0,52,0,6,0,84,0,7,0,8,0,4,0,20,0,5,0,12,0,4,0,5,0,5,0,8,0,6,0,91,0,7,0,77,0,9,0,49,1,11,0,97,2,12,0,26,0,5,0,18,0,7,0,0,0,3,0,15,0,4,0,10,0,4,0,9,0,4,0,6,0,4,0,27,0,5,0,6,0,5,0,28,0,6,0,44,0,6,0,21,0,6,0,90,0,7,0,39,0,8,0,153,0,10,0,96,2,12,0,14,0,4,0,4,0,4,0,15,0,5,0,7,0,5,0,29,0,6,0,11,0,5,0,20,0,6,0,8,0,4,0,23,0,5,0,15,0,4,0,19,0,5,0,117,0,7,0,36,0,6,0,149,0,8,0,81,2,10,0,160,4,11,0,16,0,5,0,200,0,8,0,2,0,3,0,1,0,3,0,1,0,4,0,0,0,4,0,26,0,5,0,17,0,5,0,44,0,6,0,101,0,7,0,116,0,7,0,75,0,7,0,201,0,8,0,41,1,9,0,67,9,12,0,66,9,12,0,3,0,3,0,10,0,4,0,28,0,5,0,24,0,5,0,51,0,6,0,23,0,5,0,45,0,6,0,27,0,5,0,59,0,6,0,3,0,3,0,26,0,5,0,45,0,6,0,56,0,6,0,40,0,7,0,149,3,10,0,81,14,12,0,55,0,6,0,228,0,8,0,1,0,3,0,0,0,3,0,31,0,5,0,30,0,5,0,23,0,5,0,58,0,6,0,115,0,7,0,42,0,7,0,43,0,7,0,41,0,7,0,203,1,9,0,41,7,11,0,161,28,13,0,160,28,13,0,4,0,3,0,10,0,4,0,4,0,4,0,24,0,5,0,54,0,6,0,11,0,5,0,44,0,6,0,25,0,5,0,59,0,6,0,4,0,3,0,4,0,4,0,63,0,6,0,23,0,5,0,117,0,7,0,245,1,9,0,209,7,11,0,23,0,6,0,246,1,9,0,1,0,3,0,0,0,3,0,27,0,5,0,26,0,5,0,10,0,5,0,50,0,6,0,116,0,7,0,248,0,8,0,249,0,8,0,247,1,9,0,233,3,10,0,160,15,12,0,67,31,13,0,66,31,13,0,3,0,3,0,10,0,4,0,30,0,5,0,28,0,5,0,59,0,6,0,24,0,5,0,22,0,6,0,22,0,5,0,51,0,6,0,4,0,3,0,7,0,4,0,24,0,5,0,30,0,5,0,54,0,6,0,49,0,7,0,119,1,9,0,119,0,7,0,118,1,9,0,1,0,3,0,0,0,3,0,26,0,5,0,25,0,5,0,58,0,6,0,25,0,6,0,92,0,7,0,186,0,8,0,97,0,8,0,193,0,9,0,128,1,10,0,2,3,11,0,7,6,12,0,6,6,12,0,2,0,3,0,10,0,4,0,31,0,5,0,28,0,5,0,55,0,6,0,22,0,5,0,118,0,7,0,13,0,5,0,47,0,6,0,0,0,3,0,10,0,4,0,26,0,5,0,12,0,4,0,29,0,5,0,57,0,6,0,120,0,7,0,94,0,7,0,147,3,11,0,2,0,3,0,1,0,3,0,22,0,5,0,15,0,5,0,46,0,6,0,95,0,7,0,115,0,8,0,229,0,9,0,200,1,10,0,74,14,13,0,151,28,14,0,150,28,14,0,73,14,13,0,72,14,13,0,4,0,3,0,6,0,4,0,31,0,5,0,27,0,5,0,29,0,6,0,56,0,6,0,56,0,7,0,61,0,6,0,121,0,7,0,120,241,29,0,108,0,0,0,8,140,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,241,29,0,108,0,0,0,136,147,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,131,29,0,160,41,29,0,92,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,168,217,28,0,192,212,35,0,12,0,0,0,4,0,0,0,21,183,49,10,254,6,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,120,133,35,0,184,38,35,0,16,0,0,0,4,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,224,224,34,0,24,163,34,0,28,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,192,91,64,9,0,0,0,0,0,0,0,8,103,34,0,192,47,34,0,32,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,8,103,34,0,168,0,34,0,136,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,103,34,0,64,173,33,0,248,141,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,103,34,0,240,107,33,0,0,43,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,103,34,0,88,4,33,0,88,233,32,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,248,206,32,0,232,179,32,0,4,0,0,0,1,0,0,0,225,255,255,255,255,255,255,255,0,0,0,0,0,0,63,192,0,0,0,0,0,0,240,191,9,0,0,0,0,0,0,0,120,158,32,0,136,132,32,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,120,158,32,0,168,0,34,0,136,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,120,158,32,0,192,107,32,0,240,85,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,120,158,32,0,224,61,32,0,72,6,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,120,158,32,0,240,237,31,0,88,217,31,0,40,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,88,199,31,0,216,176,31,0,48,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,88,199,31,0,168,0,34,0,136,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,199,31,0,152,158,31,0,56,140,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,199,31,0,160,123,31,0,248,108,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,199,31,0,232,88,31,0,184,46,31,0,52,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,96,28,31,0,96,16,31,0,56,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,40,1,31,0,184,240,30,0,60,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,48,227,30,0,16,214,30,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,72,199,30,0,16,184,30,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,72,199,30,0,168,0,34,0,136,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,72,199,30,0,192,107,32,0,232,165,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,72,199,30,0,224,61,32,0,24,126,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,72,199,30,0,8,111,30,0,224,97,30,0,76,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,8,111,30,0,168,0,34,0,136,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,111,30,0,192,107,32,0,56,84,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,111,30,0,224,61,32,0,144,67,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,111,30,0,120,56,30,0,144,45,30,0,80,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,120,56,30,0,208,35,30,0,48,28,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,120,56,30,0,160,16,30,0,104,238,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,120,56,30,0,16,229,29,0,200,220,29,0,96,0,0,0,1,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1862264);
/* memory initializer */ allocate([240,63,9,0,0,0,0,0,0,0,216,211,29,0,24,203,29,0,100,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,216,211,29,0,152,194,29,0,48,187,29,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,216,211,29,0,128,179,29,0,168,171,29,0,104,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,46,64,9,0,0,0,128,179,29,0,152,194,29,0,48,187,29,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,128,179,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,131,29,0,200,41,29,0,92,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,184,217,28,0,216,212,35,0,12,0,0,0,4,0,0,0,21,183,49,10,254,6,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,136,133,35,0,208,38,35,0,16,0,0,0,4,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,240,224,34,0,40,163,34,0,28,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,192,91,64,9,0,0,0,0,0,0,0,56,103,34,0,208,47,34,0,32,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,56,103,34,0,184,0,34,0,160,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,56,103,34,0,72,173,33,0,8,142,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,56,103,34,0,248,107,33,0,32,43,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,56,103,34,0,104,4,33,0,104,233,32,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,80,207,32,0,8,180,32,0,4,0,0,0,1,0,0,0,225,255,255,255,255,255,255,255,0,0,0,0,0,0,63,192,0,0,0,0,0,0,240,191,9,0,0,0,0,0,0,0,216,158,32,0,184,132,32,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,216,158,32,0,184,0,34,0,160,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,216,158,32,0,200,107,32,0,8,86,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,216,158,32,0,232,61,32,0,104,6,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,216,158,32,0,0,238,31,0,144,217,31,0,40,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,104,199,31,0,248,176,31,0,48,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,104,199,31,0,184,0,34,0,160,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,104,199,31,0,160,158,31,0,80,140,31,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,104,199,31,0,168,123,31,0,16,109,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,104,199,31,0,248,88,31,0,208,46,31,0,52,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,112,28,31,0,128,16,31,0,56,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,56,1,31,0,208,240,30,0,60,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,64,227,30,0,48,214,30,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,88,199,30,0,40,184,30,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,88,199,30,0,184,0,34,0,160,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,199,30,0,200,107,32,0,8,166,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,199,30,0,232,61,32,0,56,126,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,199,30,0,24,111,30,0,248,97,30,0,76,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,24,111,30,0,184,0,34,0,160,210,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,24,111,30,0,200,107,32,0,80,84,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,24,111,30,0,232,61,32,0,176,67,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,24,111,30,0,136,56,30,0,192,45,30,0,80,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,136,56,30,0,224,35,30,0,72,28,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,56,30,0,168,16,30,0,112,238,29,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,56,30,0,40,229,29,0,224,220,29,0,96,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,0,212,29,0,48,203,29,0,100,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,212,29,0,160,194,29,0,72,187,29,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,212,29,0,144,179,29,0,192,171,29,0,104,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,46,64,9,0,0,0,144,179,29,0,160,194,29,0,72,187,29,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,144,179,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,163,30,0,200,14,30,0,92,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,32,159,29,0,240,63,29,0,28,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,192,91,64,9,0,0,0,0,0,0,0,112,239,28,0,104,233,35,0,32,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,112,239,28,0,24,155,35,0,248,58,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,112,239,28,0,96,242,34,0,120,180,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,112,239,28,0,216,118,34,0,184,62,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,112,239,28,0,240,13,34,0,56,222,33,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,224,185,33,0,160,151,33,0,4,0,0,0,1,0,0,0,225,255,255,255,255,255,255,255,0,0,0,0,0,0,63,192,0,0,0,0,0,0,240,191,9,0,0,0,0,0,0,0,48,119,33,0,200,54,33,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,48,119,33,0,24,155,35,0,248,58,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,48,119,33,0,56,13,33,0,248,242,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,48,119,33,0,144,215,32,0,216,188,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,48,119,33,0,120,165,32,0,192,140,32,0,40,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,208,115,32,0,0,93,32,0,48,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,208,115,32,0,24,155,35,0,248,58,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,208,115,32,0,168,69,32,0,224,13,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,208,115,32,0,144,243,31,0,120,223,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,208,115,32,0,136,204,31,0,16,183,31,0,52,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,8,164,31,0,72,146,31,0,56,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,72,128,31,0,240,112,31,0,60,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,184,94,31,0,88,52,31,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,224,32,31,0,200,19,31,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,224,32,31,0,24,155,35,0,248,58,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,32,31,0,56,13,33,0,152,5,31,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,32,31,0,144,215,32,0,64,245,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,32,31,0,0,231,30,0,160,217,30,0,76,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,231,30,0,24,155,35,0,248,58,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,231,30,0,56,13,33,0,240,202,30,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,231,30,0,144,215,32,0,224,186,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,231,30,0,56,171,30,0,24,130,30,0,80,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,56,171,30,0,104,113,30,0,176,100,30,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,56,171,30,0,32,87,30,0,40,70,30,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,56,171,30,0,144,59,30,0,152,48,30,0,96,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,72,38,30,0,224,29,30,0,100,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,72,38,30,0,0,20,30,0,56,242,29,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,72,38,30,0,48,231,29,0,224,222,29,0,104,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,46,64,9,0,0,0,48,231,29,0,0,20,30,0,56,242,29,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,48,231,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,51,31,0,88,129,30,0,0,0,0,0,0,0,0,0,248,51,31,0,152,129,30,0,0,0,0,0,0,0,0,0,184,104,33,0,248,58,32,0,0,0,0,0,0,0,0,0,2,7,7,2,0,0,0,0,0,0,4,4,0,0,0,0,0,0,0,0,2,7,7,2,0,0,0,0,0,0,2,7,5,5,7,2,0,0,0,0,2,7,7,2,6,6,0,0,0,0,2,7,5,5,7,2,8,8,0,0,2,7,7,2,6,7,7,6,0,0,2,7,5,5,7,2,6,7,7,6,160,16,31,0,108,0,0,0,144,109,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,7,8,11,12,255,255,255,255,255,255,0,0,0,0,0,0,1,3,5,7,10,12,13,255,255,255,255,255,255,0,0,0,0,1,2,2,9,13,15,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,2,2,6,9,11,12,13,255,255,255,255,0,0,0,0,0,0,0,0,2,2,6,9,11,12,13,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,2,2,6,9,11,12,13,255,255,255,255,0,0,0,0,0,0,0,0,2,2,6,9,11,12,13,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,3,2,10,11,11,12,12,14,255,0,0,0,0,0,0,0,0,0,0,3,2,10,11,11,12,12,14,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,3,2,10,11,11,12,12,14,255,0,0,0,0,0,0,0,0,0,0,3,2,10,11,11,12,12,14,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,1,6,8,11,12,12,255,255,0,0,0,0,0,0,0,0,0,0,0,1,6,8,11,12,12,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,12,16,32,48,48,48,48,48,48,48,48,48,48,48,48,48,0,0,0,16,20,36,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,32,40,60,60,60,60,60,60,60,60,60,60,60,60,60,60,0,0,0,0,0,0,0,20,24,32,48,48,48,48,48,48,48,48,48,0,0,0,0,0,0,4,24,28,36,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,20,44,52,60,60,60,60,60,60,60,60,60,60,0,0,0,0,0,0,0,0,0,16,24,32,40,48,48,48,48,48,48,0,0,0,0,0,0,0,0,4,20,28,36,44,56,56,56,56,56,56,0,0,0,0,0,0,0,0,20,40,48,60,60,60,60,60,60,60,60,0,0,0,0,0,0,0,0,0,0,12,24,32,48,48,48,48,48,48,0,0,0,0,0,0,0,0,0,0,16,28,36,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,32,48,60,60,60,60,60,60,60,0,0,0,0,0,0,0,0,0,0,0,8,20,32,40,48,48,48,48,0,0,0,0,0,0,0,0,0,0,0,12,24,36,44,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,28,44,60,60,60,60,60,60,0,0,0,80,237,35,0,64,157,35,0,20,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,8,61,35,0,160,243,34,0,48,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,181,34,0,0,120,34,0,28,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,63,34,0,240,14,34,0,36,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,152,222,33,0,88,186,33,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,145,35,0,108,0,0,0,80,165,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,234,35,0,0,0,0,0,8,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,176,155,35,0,0,0,0,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,200,59,35,0,0,0,0,0,60,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,144,242,34,0,0,0,0,0,80,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,160,180,34,0,0,0,0,0,64,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,61,32,0,108,0,0,0,160,166,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,10,12,13,15,17,19,0,3,5,7,9,13,17,25,0,72,39,35,0,224,225,34,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,72,39,35,0,184,163,34,0,232,103,34,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,72,39,35,0,104,48,34,0,80,1,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,72,39,35,0,32,211,33,0,24,174,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,72,39,35,0,88,142,33,0,216,110,140,0,8,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,9,0,0,0,88,142,33,0,144,43,33,0,8,5,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,142,33,0,200,233,32,0,144,207,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,142,33,0,112,180,32,0,40,159,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,142,33,0,64,133,32,0,16,108,32,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,88,142,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,134,35,0,108,0,0,0,0,168,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,29,0,108,0,0,0,224,110,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,1,3,0,0,0,0,0,0,0,0,1,1,0,1,1,1,3,0,0,0,0,0,0,0,0,1,1,0,1,1,1,3,3,0,4,0,0,0,0,0,1,1,0,1,1,1,1,1,2,3,3,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,55,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,2,0,1,0,0,0,2,0,1,3,0,0,2,0,1,3,4,0,2,0,1,4,5,3,0,0,0,0,1,0,0,0,0,1,1,0,0,0,2,0,1,0,0,3,0,1,0,0,3,0,1,1,0,4,0,1,1,3,0,0,0,3,3,3,3,9,9,8,8,13,13,17,0,0,0,0,0,1,1,2,2,4,4,7,7,12,12,16,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,255,255,255,104,55,43,112,164,178,111,61,134,88,141,67,53,40,121,184,199,111,111,79,37,67,57,0,154,103,89,68,68,68,108,108,108,154,210,132,108,94,181,149,149,149,116,111,0,0,0,0,0,0,66,105,116,115,32,112,101,114,32,115,97,109,112,108,101,32,100,105,102,102,101,114,44,32,116,104,105,115,32,98,108,111,99,107,58,32,37,105,44,32,104,101,97,100,101,114,32,98,108,111,99,107,58,32,37,105,10,0,0,0,0,0,0,0,100,114,97,119,32,97,32,112,111,105,110,116,32,102,111,114,32,101,97,99,104,32,115,97,109,112,108,101,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,119,116,118,101,110,99,46,99,0,0,0,0,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,120,109,118,0,0,0,0,0,117,110,107,110,111,119,110,32,102,111,114,109,97,116,116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,120,97,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,105,115,99,111,110,115,105,110,95,67,101,110,0,44,0,0,0,0,0,0,0,37,48,50,108,108,100,58,37,48,50,108,108,100,46,37,48,51,108,108,100,0,0,0,0,37,117,58,37,117,46,37,117,0,0,0,0,0,0,0,0,119,118,0,0,0,0,0,0,100,115,54,52,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,105,115,99,111,110,115,105,110,95,78,111,114,116,104,0,0,0,0,0,0,0,111,114,105,103,105,110,97,116,111,114,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,105,116,114,97,116,101,32,112,101,114,32,99,104,97,110,110,101,108,32,37,100,10,0,101,110,99,111,100,101,95,97,117,100,105,111,32,37,100,46,37,100,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,83,0,0,0,0,0,0,0,119,118,0,0,0,0,0,0,110,108,118,108,32,102,114,111,109,32,37,100,44,32,110,108,118,108,32,116,111,32,37,100,10,0,0,0,0,0,0,0,103,111,116,32,97,32,118,97,108,105,100,32,105,110,116,101,103,101,114,32,40,37,108,100,41,10,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,78,0,0,0,0,0,0,0,105,100,51,118,50,32,118,101,114,58,37,100,32,102,108,97,103,115,58,37,48,50,88,32,108,101,110,58,37,100,10,0,80,67,83,95,78,65,68,50,55,95,87,97,115,104,105,110,103,116,111,110,95,83,111,117,116,104,0,0,0,0,0,0,119,116,118,0,0,0,0,0,115,101,116,32,99,104,97,110,110,101,108,32,100,105,115,112,108,97,121,32,109,111,100,101,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,97,115,104,105,110,103,116,111,110,95,78,111,114,116,104,0,0,0,0,0,0,70,111,114,109,97,116,32,37,115,32,100,101,116,101,99,116,101,100,32,111,110,108,121,32,119,105,116,104,32,108,111,119,32,115,99,111,114,101,32,111,102,32,37,100,44,32,109,105,115,100,101,116,101,99,116,105,111,110,32,112,111,115,115,105,98,108,101,33,10,0,0,0,44,32,48,120,37,48,56,120,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,86,105,114,103,105,110,105,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,65,32,115,116,114,105,110,103,32,100,101,115,99,114,105,98,105,110,103,32,102,114,97,109,101,32,115,105,122,101,44,32,115,117,99,104,32,97,115,32,54,52,48,120,52,56,48,32,111,114,32,104,100,55,50,48,46,0,0,0,0,0,0,0,121,117,118,97,52,52,52,112,49,48,98,101,0,0,0,0,77,101,100,105,117,109,80,117,114,112,108,101,0,0,0,0,44,0,0,0,0,0,0,0,115,101,108,101,99,116,32,108,111,119,32,115,104,105,98,97,116,97,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,116,114,117,101,0,0,0,0,80,67,83,95,78,65,68,50,55,95,86,105,114,103,105,110,105,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,99,100,32,33,61,32,40,105,99,111,110,118,95,116,41,45,49,0,0,0,0,0,0,0,71,67,83,95,68,101,105,114,95,101,122,95,90,111,114,0,118,105,100,101,111,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,100,105,97,109,111,110,100,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,97,108,105,97,115,32,102,111,114,32,69,80,90,83,41,0,0,0,0,0,0,101,109,105,116,32,109,97,99,114,111,98,108,111,99,107,32,105,110,102,111,32,102,111,114,32,82,70,67,32,50,49,57,48,32,112,97,99,107,101,116,105,122,97,116,105,111,110,44,32,116,104,101,32,112,97,114,97,109,101,116,101,114,32,118,97,108,117,101,32,105,115,32,116,104,101,32,109,97,120,105,109,117,109,32,112,97,121,108,111,97,100,32,115,105,122,101,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,116,97,103,58,32,37,100,10,0,0,0,0,0,0,0,0,104,109,109,44,32,115,101,101,109,115,32,116,104,101,32,104,101,97,100,101,114,115,32,97,114,101,32,110,111,116,32,99,111,109,112,108,101,116,101,44,32,116,114,121,105,110,103,32,116,111,32,103,117,101,115,115,32,116,105,109,101,95,105,110,99,114,101,109,101,110,116,95,98,105,116,115,10,0,0,0,111,118,101,114,114,101,97,100,32,37,100,10,0,0,0,0,37,115,10,0,0,0,0,0,104,45,62,97,118,99,116,120,45,62,115,97,109,112,108,101,95,97,115,112,101,99,116,95,114,97,116,105,111,46,100,101,110,0,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,71,114,97,112,104,105,99,115,32,40,83,77,67,41,0,0,0,0,0,0,0,0,65,99,111,117,115,116,105,99,0,0,0,0,0,0,0,0,83,101,103,109,101,110,116,32,102,105,110,105,115,104,101,100,32,97,116,32,112,116,115,61,37,108,108,100,10,0,0,0,80,67,83,95,78,65,68,50,55,95,86,101,114,109,111,110,116,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,117,98,116,105,116,108,101,115,32,99,111,100,101,99,58,32,37,115,10,0,0,0,0,0,0,0,0,98,97,100,32,68,84,83,32,115,121,110,99,119,111,114,100,32,48,120,37,120,10,0,0,80,67,83,95,78,65,68,50,55,95,85,116,97,104,95,83,111,117,116,104,0,0,0,0,114,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,60,83,109,111,111,116,104,83,116,114,101,97,109,105,110,103,77,101,100,105,97,32,77,97,106,111,114,86,101,114,115,105,111,110,61,34,50,34,32,77,105,110,111,114,86,101,114,115,105,111,110,61,34,48,34,32,68,117,114,97,116,105,111,110,61,34,37,108,108,117,34,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,37,120,10,0,0,0,0,0,0,116,98,99,0,0,0,0,0,119,116,118,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,116,97,104,95,67,101,110,116,114,97,108,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,111,114,99,101,100,32,102,114,97,109,101,115,32,97,114,114,97,121,10,0,119,115,118,113,97,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,0,0,0,0,119,115,97,117,100,0,0,0,80,67,83,95,78,65,68,50,55,95,85,116,97,104,95,78,111,114,116,104,0,0,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,73,80,52,0,0,0,0,0,65,117,100,105,111,32,101,110,99,111,100,105,110,103,32,102,97,105,108,101,100,32,40,97,118,99,111,100,101,99,95,101,110,99,111,100,101,95,97,117,100,105,111,50,41,10,0,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,83,111,117,116,104,0,0,0,83,116,97,114,116,32,116,105,109,101,32,105,103,110,111,114,101,100,32,105,110,32,97,32,112,117,114,101,108,121,32,114,101,108,97,116,105,118,101,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,0,0,119,101,98,118,116,116,0,0,102,105,108,101,110,97,109,101,32,37,115,44,32,108,101,110,32,37,100,10,0,0,0,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,83,111,117,116,104,95,67,101,110,0,0,0,0,0,0,0,84,82,75,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,105,76,66,67,32,98,108,111,99,107,32,115,105,122,101,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,65,82,77,111,118,105,101,10,0,0,0,0,0,0,0,0,97,117,100,105,111,47,120,45,112,110,45,114,101,97,108,97,117,100,105,111,0,0,0,0,82,101,97,108,77,101,100,105,97,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,67,101,110,116,114,97,108,0,115,101,116,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,103,101,110,114,101,0,0,0,37,117,58,37,117,58,37,117,46,37,117,0,0,0,0,0,119,101,98,118,116,116,0,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,78,111,114,116,104,95,67,101,110,0,0,0,0,0,0,0,121,117,118,52,50,48,112,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,78,111,114,116,104,0,0,0,119,99,51,109,111,118,105,101,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,115,104,111,119,119,97,118,101,115,0,0,0,0,0,0,0,114,97,119,32,100,97,116,97,0,0,0,0,0,0,0,0,109,106,112,103,44,109,106,112,101,103,44,109,112,111,0,0,121,117,118,97,52,50,50,112,49,48,108,101,0,0,0,0,77,101,100,105,117,109,79,114,99,104,105,100,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,101,110,100,32,97,116,111,109,10,0,108,111,119,95,115,104,105,98,97,116,97,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,84,101,110,110,101,115,115,101,101,0,0,0,0,0,112,32,60,61,32,101,110,100,0,0,0,0,0,0,0,0,71,67,83,95,67,111,116,101,95,100,95,73,118,111,105,114,101,0,0,0,0,0,0,0,70,105,108,101,32,101,110,100,115,32,98,101,102,111,114,101,32,102,105,114,115,116,32,112,97,99,107,101,116,10,0,0,112,99,109,95,117,51,50,98,101,0,0,0,0,0,0,0,100,105,97,0,0,0,0,0,109,98,95,105,110,102,111,0,98,101,102,111,114,101,32,116,105,109,101,95,105,110,99,114,101,109,101,110,116,0,0,0,109,98,95,98,105,116,109,97,115,107,95,115,105,122,101,32,109,105,115,109,97,116,99,104,101,115,10,0,0,0,0,0,33,112,105,99,45,62,104,119,97,99,99,101,108,95,112,105,99,116,117,114,101,95,112,114,105,118,97,116,101,0,0,0,115,109,99,0,0,0,0,0,69,97,115,121,32,76,105,115,116,101,110,105,110,103,0,0,80,67,83,95,78,65,68,50,55,95,83,111,117,116,104,95,68,97,107,111,116,97,95,83,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,80,67,83,95,78,65,68,50,55,95,83,111,117,116,104,95,68,97,107,111,116,97,95,78,0,0,0,0,0,0,0,0,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,115,104,97,114,101,47,102,102,109,112,101,103,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,114,101,99,111,114,100,32,111,114,32,116,114,97,110,115,99,111,100,101,32,34,100,117,114,97,116,105,111,110,34,32,115,101,99,111,110,100,115,32,111,102,32,97,117,100,105,111,47,118,105,100,101,111,0,0,0,116,98,110,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,83,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,115,101,108,101,99,116,32,115,116,114,101,97,109,32,109,97,116,99,104,105,110,103,32,105,100,101,110,116,105,102,105,101,114,32,39,37,115,39,10,0,0,0,0,0,0,0,119,97,118,0,0,0,0,0,102,108,117,115,104,95,112,97,99,107,101,116,115,0,0,0,70,105,108,101,32,105,115,32,101,110,99,114,121,112,116,101,100,10,0,0,0,0,0,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,51,100,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,78,0,0,0,0,0,0,79,112,117,115,0,0,0,0,101,110,99,111,100,101,114,32,60,45,32,116,121,112,101,58,97,117,100,105,111,32,102,114,97,109,101,95,112,116,115,58,37,115,32,102,114,97,109,101,95,112,116,115,95,116,105,109,101,58,37,115,32,116,105,109,101,95,98,97,115,101,58,37,100,47,37,100,10,0,0,0,80,67,83,95,78,65,68,50,55,95,82,104,111,100,101,95,73,115,108,97,110,100,0,0,102,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,111,114,32,114,101,112,108,97,99,101,32,115,116,114,101,97,109,10,0,0,0,0,0,118,111,108,117,109,101,32,37,115,44,32,108,101,110,32,37,100,10,0,0,0,0,0,0,37,100,47,37,100,0,0,0,80,67,83,95,78,65,68,50,55,95,80,101,110,110,115,121,108,118,97,110,105,97,95,83,0,0,0,0,0,0,0,0,84,80,51,0,0,0,0,0,114,101,97,100,95,116,105,109,101,115,116,97,109,112,40,88,44,37,100,44,37,108,108,100,44,37,108,108,100,41,10,0,99,111,100,105,110,103,32,37,115,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,80,101,110,110,115,121,108,118,97,110,105,97,95,78,0,0,0,0,0,0,0,0,119,97,118,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,79,114,101,103,111,110,95,83,111,117,116,104,0,0,105,110,118,97,108,105,100,32,101,110,99,111,100,101,100,32,116,114,105,112,108,101,116,10,0,0,0,0,0,0,0,0,109,117,108,116,105,112,108,101,32,118,105,100,101,111,32,115,116,114,101,97,109,115,32,115,117,112,112,111,114,116,0,0,80,67,83,95,78,65,68,50,55,95,79,114,101,103,111,110,95,78,111,114,116,104,0,0,69,110,99,111,100,101,114,32,100,105,100,32,110,111,116,32,112,114,111,100,117,99,101,32,112,114,111,112,101,114,32,112,116,115,44,32,109,97,107,105,110,103,32,115,111,109,101,32,117,112,46,10,0,0,0,0,121,117,118,97,52,50,50,112,49,48,98,101,0,0,0,0,77,101,100,105,117,109,66,108,117,101,0,0,0,0,0,0,115,101,108,101,99,116,32,115,104,105,98,97,116,97,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,79,107,108,97,104,111,109,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,102,102,95,97,118,99,111,100,101,99,95,108,111,99,107,101,100,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,71,67,83,95,67,111,114,114,101,103,111,95,65,108,101,103,114,101,0,0,0,0,0,0,116,101,115,97,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1872518);
/* memory initializer */ allocate([0,0,72,46,50,54,51,32,101,110,99,111,100,101,114,0,0,0,108,111,119,95,100,101,108,97,121,32,102,108,97,103,32,105,110,99,111,114,114,101,99,116,108,121,44,32,99,108,101,97,114,105,110,103,32,105,116,10,0,0,0,0,0,0,0,0,99,111,109,112,117,116,101,95,112,99,114,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,33,112,105,99,45,62,102,46,100,97,116,97,91,48,93,0,81,117,105,99,107,84,105,109,101,32,56,66,80,83,32,118,105,100,101,111,0,0,0,0,77,80,69,71,45,50,32,80,83,32,40,83,86,67,68,41,0,0,0,0,0,0,0,0,67,104,111,114,117,115,0,0,80,67,83,95,78,65,68,50,55,95,79,107,108,97,104,111,109,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,73,68,88,0,0,0,0,0,85,110,107,110,111,119,110,32,115,116,114,101,97,109,32,118,101,114,115,105,111,110,32,37,100,10,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,79,104,105,111,95,83,111,117,116,104,0,0,0,0,72,79,77,69,0,0,0,0,84,80,69,49,0,0,0,0,117,115,101,32,116,97,98,108,101,32,111,102,32,99,111,110,116,101,110,116,115,0,0,0,116,0,0,0,0,0,0,0,116,98,114,0,0,0,0,0,118,113,102,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,79,104,105,111,95,78,111,114,116,104,0,0,0,0,102,111,114,109,97,116,32,37,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,118,112,108,97,121,101,114,0,80,67,83,95,78,65,68,50,55,95,78,111,114,116,104,95,68,97,107,111,116,97,95,83,0,0,0,0,0,0,0,0,112,107,116,46,115,105,122,101,32,124,124,32,33,112,107,116,46,100,97,116,97,0,0,0,65,76,66,85,77,65,82,84,73,83,84,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,111,114,116,104,95,68,97,107,111,116,97,95,78,0,0,0,0,0,0,0,0,109,117,108,116,105,112,108,101,32,101,100,105,116,32,108,105,115,116,32,101,110,116,114,105,101,115,44,32,97,47,118,32,100,101,115,121,110,99,32,109,105,103,104,116,32,111,99,99,117,114,44,32,112,97,116,99,104,32,119,101,108,99,111,109,101,10,0,0,0,0,0,0,118,111,99,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,111,114,116,104,95,67,97,114,111,108,105,110,97,0,0,0,0,0,0,0,0,84,80,50,0,0,0,0,0,73,103,110,111,114,105,110,103,32,109,105,100,45,115,116,114,101,97,109,32,99,104,97,110,103,101,32,105,110,32,97,117,100,105,111,32,99,111,100,101,99,10,0,0,0,0,0,0,123,37,42,100,125,123,125,37,99,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,89,111,114,107,95,76,111,110,103,95,73,115,0,0,0,0,0,0,35,102,111,114,109,97,116,58,32,102,114,97,109,101,32,99,104,101,99,107,115,117,109,115,10,0,0,0,0,0,0,0,109,107,97,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,89,111,114,107,95,87,101,115,116,0,49,46,50,46,53,0,0,0,111,110,108,121,32,49,54,45,44,32,50,48,45,44,32,50,52,45,32,97,110,100,32,51,50,45,98,105,116,32,80,67,77,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,89,111,114,107,95,67,101,110,116,114,97,108,0,0,0,0,0,0,118,105,118,111,0,0,0,0,76,65,84,77,47,76,79,65,83,32,109,117,120,101,114,0,121,117,118,97,52,50,48,112,49,48,108,101,0,0,0,0,77,101,100,105,117,109,65,113,117,97,77,97,114,105,110,101,0,0,0,0,0,0,0,0,68,73,82,69,67,84,73,86,69,0,0,0,0,0,0,0,81,80,50,76,65,77,66,68,65,0,0,0,0,0,0,0,118,99,49,116,101,115,116,0,115,104,105,98,97,116,97,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,89,111,114,107,95,69,97,115,116,0,33,102,102,95,97,118,99,111,100,101,99,95,108,111,99,107,101,100,0,0,0,0,0,0,71,67,83,95,67,104,117,97,0,0,0,0,0,0,0,0,118,99,49,116,101,115,116,0,116,101,115,97,0,0,0,0,87,114,105,116,101,32,115,108,105,99,101,32,115,116,97,114,116,32,112,111,115,105,116,105,111,110,32,97,116,32,101,118,101,114,121,32,71,79,66,32,104,101,97,100,101,114,32,105,110,115,116,101,97,100,32,111,102,32,106,117,115,116,32,71,79,66,32,110,117,109,98,101,114,46,0,0,0,0,0,0,100,105,118,120,32,115,116,121,108,101,32,112,97,99,107,101,100,32,98,32,102,114,97,109,101,115,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,114,99,45,62,102,46,98,117,102,91,48,93,0,0,0,56,98,112,115,0,0,0,0,66,105,103,32,66,97,110,100,0,0,0,0,0,0,0,0,102,111,114,99,101,32,108,111,111,112,32,111,118,101,114,32,105,110,112,117,116,32,102,105,108,101,32,115,101,113,117,101,110,99,101,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,77,101,120,105,99,111,95,87,101,115,116,0,0,0,0,0,0,0,45,100,0,0,0,0,0,0,112,112,109,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,77,101,120,105,99,111,95,67,101,110,116,0,0,0,0,0,0,0,70,70,77,80,69,71,95,68,65,84,65,68,73,82,0,0,105,110,112,117,116,95,102,105,108,101,95,105,110,100,101,120,0,0,0,0,0,0,0,0,102,112,115,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,77,101,120,105,99,111,95,69,97,115,116,0,0,0,0,0,0,0,83,101,108,101,99,116,101,100,32,115,116,114,101,97,109,32,105,100,58,37,100,32,116,121,112,101,58,37,115,10,0,0,101,110,99,111,100,101,100,95,98,121,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,37,115,10,0,0,0,35,69,88,84,45,88,45,69,78,68,76,73,83,84,10,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,74,101,114,115,101,121,0,0,0,0,37,100,0,0,0,0,0,0,9,60,115,116,114,101,97,109,84,121,112,101,62,37,115,60,47,115,116,114,101,97,109,84,121,112,101,62,10,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,72,97,109,112,115,104,105,114,101,0,48,0,0,0,0,0,0,0,69,88,84,58,47,80,68,82,47,100,101,102,97,117,108,116,47,0,0,0,0,0,0,0,102,114,101,101,0,0,0,0,85,110,107,110,111,119,110,32,77,79,86,32,102,105,101,108,100,32,111,114,100,101,114,32,48,120,37,48,52,120,10,0,109,97,116,101,114,105,97,108,32,100,97,116,97,32,108,111,110,103,101,114,32,116,104,97,110,32,109,97,112,32,100,97,116,97,10,0,0,0,0,0,100,101,102,97,117,108,116,32,100,101,108,97,121,32,98,101,116,119,101,101,110,32,102,114,97,109,101,115,32,40,105,110,32,104,117,110,100,114,101,100,116,104,115,32,111,102,32,115,101,99,111,110,100,41,0,0,56,57,97,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,118,97,100,97,95,87,101,115,116,0,0,0,84,80,49,0,0,0,0,0,77,97,108,102,111,114,109,101,100,32,65,65,67,32,98,105,116,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,58,32,117,115,101,32,97,117,100,105,111,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,39,97,97,99,95,97,100,116,115,116,111,97,115,99,39,32,116,111,32,102,105,120,32,105,116,32,40,39,45,98,115,102,58,97,32,97,97,99,95,97,100,116,115,116,111,97,115,99,39,32,111,112,116,105,111,110,32,119,105,116,104,32,102,102,109,112,101,103,41,10,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,118,97,100,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,0,111,110,84,101,120,116,68,97,116,97,0,0,0,0,0,0,119,114,105,116,101,95,104,101,97,100,101,114,0,0,0,0,59,70,70,77,69,84,65,68,65,84,65,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,118,97,100,97,95,69,97,115,116,0,0,0,59,70,70,77,69,84,65,68,65,84,65,0,0,0,0,0,117,110,107,110,111,119,110,32,83,67,72,108,32,104,101,97,100,101,114,105,100,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,98,114,97,115,107,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,121,117,118,97,52,50,48,112,49,48,98,101,0,0,0,0,77,97,114,111,111,110,0,0,69,0,0,0,0,0,0,0,115,101,108,101,99,116,32,108,105,112,115,104,105,116,122,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,0,0,0,102,102,99,111,110,99,97,116,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,98,114,97,115,107,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,78,111,32,108,111,99,107,32,109,97,110,97,103,101,114,32,105,115,32,115,101,116,44,32,112,108,101,97,115,101,32,115,101,101,32,97,118,95,108,111,99,107,109,103,114,95,114,101,103,105,115,116,101,114,40,41,10,0,0,0,0,0,0,0,71,67,83,95,67,97,114,116,104,97,103,101,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,101,115,97,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,97,108,105,97,115,32,102,111,114,32,102,117,108,108,41,0,0,115,116,114,117,99,116,117,114,101,100,95,115,108,105,99,101,115,0,0,0,0,0,0,0,100,105,118,120,95,112,97,99,107,101,100,0,0,0,0,0,109,106,112,101,103,58,32,101,114,114,111,114,44,32,100,101,99,111,100,101,95,97,112,112,32,112,97,114,115,101,114,32,114,101,97,100,32,111,118,101,114,32,116,104,101,32,101,110,100,10,0,0,0,0,0,0,33,100,115,116,45,62,102,46,98,117,102,91,48,93,0,0,105,100,32,81,117,97,107,101,32,73,73,32,67,73,78,32,118,105,100,101,111,0,0,0,83,108,111,119,32,82,111,99,107,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,111,110,116,97,110,97,95,83,111,117,116,104,0,65,114,116,119,111,114,120,32,68,97,116,97,32,70,111,114,109,97,116,32,100,101,109,117,120,101,114,0,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,105,110,100,101,120,32,116,97,98,108,101,10,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,111,110,116,97,110,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,114,101,97,100,105,110,103,32,102,105,108,101,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,44,32,83,65,82,32,37,100,58,37,100,32,68,65,82,32,37,100,58,37,100,0,0,0,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,43,45,46,0,0,0,0,0,0,0,115,101,116,32,99,104,97,112,116,101,114,115,32,109,97,112,112,105,110,103,0,0,0,0,73,110,118,97,108,105,100,32,114,105,102,102,32,105,110,100,101,120,32,37,100,32,62,32,37,100,10,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,111,110,116,97,110,97,95,78,111,114,116,104,0,39,101,120,116,39,32,108,105,115,116,32,116,121,112,101,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,32,105,110,32,102,97,118,111,114,32,111,102,32,39,99,115,118,39,10,0,83,107,105,112,105,110,103,32,102,111,114,101,105,103,110,32,115,116,114,101,97,109,32,37,100,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,111,111,112,101,110,100,32,99,97,110,39,116,32,98,101,32,108,101,115,115,32,111,114,32,101,113,117,97,108,32,116,111,32,108,111,111,112,115,116,97,114,116,10,0,0,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,53,0,78,85,76,76,0,0,0,0,99,111,109,109,101,110,116,0,102,102,32,97,115,102,32,98,97,100,32,110,111,110,32,122,101,114,111,10,0,0,0,0,115,101,116,32,116,104,101,32,109,111,118,105,101,32,102,114,97,109,101,32,114,97,116,101,0,0,0,0,0,0,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,52,0,65,117,100,105,111,32,102,105,108,116,101,114,32,103,114,97,112,104,32,111,117,116,112,117,116,32,105,115,32,110,111,116,32,110,111,114,109,97,108,105,122,101,100,32,97,110,100,32,101,110,99,111,100,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,112,97,114,97,109,101,116,101,114,32,99,104,97,110,103,101,115,10,0,0,0,0,0,83,107,105,112,112,105,110,103,32,98,105,110,97,114,121,32,116,97,103,32,39,37,115,39,46,10,0,0,0,0,0,0,114,101,115,101,114,118,101,100,95,109,111,111,118,95,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,44,32,110,101,101,100,101,100,32,37,108,108,100,32,97,100,100,105,116,105,111,110,97,108,10,0,0,0,0,0,0,0,0,68,101,99,111,100,105,110,103,32,102,105,108,101,32,45,32,118,37,100,46,37,48,50,100,44,32,99,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,37,117,10,0,99,111,109,112,97,116,105,98,108,101,95,98,114,97,110,100,115,0,0,0,0,0,0,0,33,102,115,45,62,105,110,91,105,110,93,46,104,97,118,101,95,110,101,120,116,0,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,51,0,84,69,78,0,0,0,0,0,100,101,102,97,117,108,116,0,100,111,117,98,108,101,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,50,0,108,97,118,102,105,46,115,105,108,101,110,99,101,95,115,116,97,114,116,0,0,0,0,0,69,120,112,101,99,116,101,100,32,105,110,32,99,104,97,110,110,101,108,32,110,97,109,101,44,32,103,111,116,32,34,37,46,56,115,34,10,0,0,0,77,105,115,115,105,110,103,32,115,101,112,97,114,97,116,111,114,32,39,45,39,32,105,110,32,99,104,97,110,110,101,108,32,109,97,112,32,39,37,115,39,10,0,0,0,0,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,49,0,115,101,116,32,112,111,105,110,116,115,32,111,102,32,116,114,97,110,115,102,101,114,32,102,117,110,99,116,105,111,110,0,109,97,112,0,0,0,0,0,80,67,83,95,66,101,108,103,101,95,76,97,109,98,101,114,116,95,55,50,0,0,0,0,65,112,112,108,121,32,97,32,116,119,111,45,112,111,108,101,32,66,117,116,116,101,114,119,111,114,116,104,32,98,97,110,100,45,114,101,106,101,99,116,32,102,105,108,116,101,114,46,0,0,0,0,0,0,0,0,121,117,118,97,52,52,52,112,57,108,101,0,0,0,0,0,77,97,103,101,110,116,97,0,80,73,0,0,0,0,0,0,108,105,112,115,104,105,116,122,0,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,116,101,109,112,111,46,99,0,80,67,83,95,77,71,73,95,65,117,115,116,114,105,97,95,69,97,115,116,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,116,104,114,101,97,100,32,108,111,99,107,105,110,103,32,97,114,111,117,110,100,32,97,118,99,111,100,101,99,95,111,112,101,110,47,99,108,111,115,101,40,41,10,0,0,0,0,0,0,0,0,101,120,112,114,0,0,0,0,71,67,83,95,67,97,112,101,0,0,0,0,0,0,0,0,112,99,109,95,117,50,52,108,101,0,0,0,0,0,0,0,82,77,83,32,116,114,111,117,103,104,32,100,66,58,32,37,102,10,0,0,0,0,0,0,101,115,97,0,0,0,0,0,117,115,101,32,111,118,101,114,108,97,112,112,101,100,32,98,108,111,99,107,32,109,111,116,105,111,110,32,99,111,109,112,101,110,115,97,116,105,111,110,46,0,0,0,0,0,0,0,37,108,108,100,0,0,0,0,49,47,52,32,115,117,98,112,101,108,32,77,67,0,0,0,109,106,112,101,103,58,32,65,112,112,108,101,32,77,74,80,69,71,45,65,32,104,101,97,100,101,114,32,102,111,117,110,100,10,0,0,0,0,0,0,110,111,32,102,114,97,109,101,32,98,117,102,102,101,114,32,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,105,100,99,105,110,0,0,0,83,121,109,112,104,111,110,105,99,32,82,111,99,107,0,0,80,67,83,95,77,71,73,95,65,117,115,116,114,105,97,95,67,101,110,116,114,97,108,0,111,99,104,0,0,0,0,0,115,101,116,32,100,101,108,97,121,32,105,110,32,109,105,108,108,105,115,101,99,111,110,100,115,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,80,67,83,95,77,71,73,95,65,117,115,116,114,105,97,95,87,101,115,116,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,105,108,101,32,98,117,102,102,101,114,10,0,105,110,37,100,0,0,0,0,115,97,109,112,108,101,95,102,109,116,115,0,0,0,0,0,58,32,37,115,0,0,0,0,109,97,112,95,99,104,97,112,116,101,114,115,0,0,0,0,115,116,97,114,116,95,115,97,109,112,108,101,0,0,0,0,80,67,83,95,90,97,110,100,101,114,105,106,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,0,0,0,0,0,102,102,99,97,116,44,102,102,99,111,110,99,97,116,0,0,37,102,0,0,0,0,0,0,100,101,102,97,117,108,116,0,80,67,83,95,89,111,102,102,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,0,109,97,120,105,109,117,109,32,98,117,102,102,101,114,105,110,103,32,100,117,114,97,116,105,111,110,32,102,111,114,32,105,110,116,101,114,108,101,97,118,105,110,103,0,0,0,0,0,71,101,110,101,114,97,116,101,32,82,71,66,32,116,101,115,116,32,112,97,116,116,101,114,110,46,0,0,0,0,0,0,80,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,85,84,77,95,51,50,78,0,102,105,108,116,101,114,32,45,62,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,116,105,109,101,95,98,97,115,101,58,37,100,47,37,100,10,0,0,0,114,0,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,115,101,99,111,110,100,32,112,97,115,115,58,32,109,111,118,105,110,103,32,116,104,101,32,109,111,111,118,32,97,116,111,109,32,116,111,32,116,104,101,32,98,101,103,105,110,110,105,110,103,32,111,102,32,116,104,101,32,102,105,108,101,10,0,0,0,0,0,0,0,0,109,105,110,111,114,95,118,101,114,115,105,111,110,0,0,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,115,105,122,101,32,105,115,32,37,100,120,37,100,32,119,104,105,99,104,32,99,97,110,110,111,116,32,99,111,110,116,97,105,110,32,116,104,101,32,112,114,111,118,105,100,101,100,32,102,105,108,101,32,115,105,122,101,32,111,102,32,37,100,120,37,100,10,0,0,0,0,0,0,0,80,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,85,84,77,95,51,49,78,0,84,84,50,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,115,101,110,100,32,111,110,101,32,102,114,97,109,101,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,44,32,98,117,116,32,115,107,105,112,32,115,112,97,116,105,97,108,32,105,110,116,101,114,108,97,99,105,110,103,32,99,104,101,99,107,0,0,0,0,0,0,0,100,101,105,110,116,101,114,108,97,99,101,32,97,108,108,32,102,114,97,109,101,115,0,0,80,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,85,84,77,95,51,48,78,0,114,0,0,0,0,0,0,0,108,117,109,97,95,97,109,111,117,110,116,0,0,0,0,0,80,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,85,84,77,95,50,57,78,0,114,111,116,97,116,101,32,99,111,117,110,116,101,114,45,99,108,111,99,107,119,105,115,101,0,0,0,0,0,0,0,0,109,97,114,103,105,110,0,0,115,101,108,101,99,116,32,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,0,80,67,83,95,66,101,114,110,95,49,57,51,56,95,83,119,105,115,115,95,78,101,119,0,109,97,114,107,32,97,115,32,116,111,112,45,102,105,101,108,100,45,102,105,114,115,116,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,0,0,0,121,117,118,97,52,52,52,112,57,98,101,0,0,0,0,0,76,105,110,101,110,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,10,0,0,0,0,0,0,115,101,108,101,99,116,32,116,114,105,97,110,103,117,108,97,114,32,100,105,116,104,101,114,32,119,105,116,104,32,104,105,103,104,32,112,97,115,115,0,80,67,83,95,86,111,105,114,111,108,95,85,110,105,102,105,101,95,83,95,65,108,103,101,114,105,101,0,0,0,0,0,71,67,83,95,67,97,109,112,111,95,73,110,99,104,97,117,115,112,101,0,0,0,0,0,119,58,37,115,32,104,58,37,115,32,102,108,97,103,115,58,39,37,115,39,32,105,110,116,101,114,108,58,37,100,10,0,69,80,90,83,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,0,0,111,98,109,99,0,0,0,0,113,117,97,114,116,101,114,95,115,97,109,112,108,101,0,0,65,116,116,101,109,112,116,32,116,111,32,115,116,97,114,116,32,97,32,102,114,97,109,101,32,111,117,116,115,105,100,101,32,83,69,84,85,80,32,115,116,97,116,101,10,0,0,0,111,117,116,95,119,0,0,0,77,105,99,114,111,115,111,102,116,32,86,105,100,101,111,32,49,0,0,0,0,0,0,0,80,115,121,99,104,101,100,101,108,105,99,32,82,111,99,107,0,0,0,0,0,0,0,0,77,97,115,107,32,105,109,97,103,101,32,115,105,122,101,32,37,100,120,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,119,105,116,104,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,80,67,83,95,86,111,105,114,111,108,95,85,110,105,102,105,101,95,78,95,65,108,103,101,114,105,101,0,0,0,0,0,110,58,37,108,108,100,32,109,115,101,95,97,118,103,58,37,48,46,50,102,32,0,0,0,104,0,0,0,0,0,0,0,117,110,99,111,100,101,100,102,114,97,109,101,99,114,99,0,80,67,83,95,86,111,105,114,111,108,95,83,95,65,108,103,101,114,105,101,95,97,110,99,105,101,110,0,0,0,0,0,73,79,32,101,114,114,111,114,58,32,37,115,10,0,0,0,72,0,0,0,0,0,0,0,44,32,37,100,44,32,37,100,47,37,100,0,0,0,0,0,116,120,100,0,0,0,0,0,111,117,116,102,105,108,101,91,44,109,101,116,97,100,97,116,97,93,58,105,110,102,105,108,101,91,44,109,101,116,97,100,97,116,97,93,0,0,0,0,80,67,83,95,86,111,105,114,111,108,95,78,95,65,108,103,101,114,105,101,95,97,110,99,105,101,110,0,0,0,0,0,97,108,108,102,0,0,0,0,73,110,118,97,108,105,100,32,116,105,109,101,32,100,117,114,97,116,105,111,110,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,39,37,115,39,32,102,111,114,32,115,101,103,109,101,110,116,95,116,105,109,101,32,111,112,116,105,111,110,10,0,0,0,0,0,0,0,115,101,116,32,105,110,112,117,116,32,116,111,32,111,117,116,112,117,116,32,112,108,97,110,101,32,109,97,112,112,105,110,103,0,0,0,0,0,0,0,80,67,83,95,84,67,95,49,57,52,56,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,0,0,0,0,0,0,115,101,108,101,99,116,32,105,110,116,101,114,112,111,108,97,116,105,111,110,32,109,111,100,101,0,0,0,0,0,0,0,115,104,111,119,115,112,101,99,116,114,117,109,0,0,0,0,109,97,120,95,105,110,116,101,114,108,101,97,118,101,95,100,101,108,116,97,0,0,0,0,116,116,121,0,0,0,0,0,118,97,108,0,0,0,0,0,100,0,0,0,0,0,0,0,80,67,83,95,84,67,95,49,57,52,56,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,0,0,0,0,0,0,69,114,114,111,114,32,105,110,32,97,118,95,98,117,102,102,101,114,115,105,110,107,95,103,101,116,95,102,114,97,109,101,95,102,108,97,103,115,40,41,58,32,37,115,10,0,0,0,83,105,110,103,108,101,32,102,114,97,109,101,58,37,115,44,32,77,117,108,116,105,32,102,114,97,109,101,58,37,115,10,0,0,0,0,0,0,0,0,116,116,97,0,0,0,0,0,109,97,106,111,114,95,98,114,97,110,100,0,0,0,0,0,114,0,0,0,0,0,0,0,119,97,118,101,102,111,114,109,0,0,0,0,0,0,0,0,116,109,118,0,0,0,0,0,80,67,83,95,84,114,105,110,105,100,97,100,95,49,57,48,51,95,84,114,105,110,105,100,97,100,0,0,0,0,0,0,84,65,76,0,0,0,0,0,116,105,101,114,116,101,120,115,101,113,0,0,0,0,0,0,86,105,101,119,115,32,97,114,101,32,111,110,101,32,97,102,116,101,114,32,116,104,101,32,111,116,104,101,114,0,0,0,115,101,116,32,114,111,117,110,100,105,110,103,32,109,101,116,104,111,100,32,102,111,114,32,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,116,104,112,0,0,0,0,0,80,67,83,95,84,77,54,53,95,73,114,105,115,104,95,78,97,116,95,71,114,105,100,0,83,107,105,112,112,105,110,103,32,37,115,46,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,111,110,111,119,0,0,0,80,67,83,95,84,105,109,98,97,108,97,105,95,49,57,52,56,95,85,84,77,95,53,48,78,0,0,0,0,0,0,0,102,109,45,62,112,114,118,50,32,38,38,32,102,109,45,62,115,114,99,50,32,38,38,32,102,109,45,62,110,120,116,50,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,37,89,37,109,37,100,0,0,65,86,95,76,79,71,95,70,79,82,67,69,95,50,53,54,67,79,76,79,82,0,0,0,83,72,65,53,49,50,47,50,50,52,0,0,0,0,0,0,116,0,0,0,0,0,0,0,99,111,115,0,0,0,0,0,68,101,99,111,100,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,70,67,0,0,0,0,0,0,115,101,116,32,108,117,109,97,32,112,108,97,110,101,0,0,80,67,83,95,84,105,109,98,97,108,97,105,95,49,57,52,56,95,85,84,77,95,52,57,78,0,0,0,0,0,0,0,70,111,114,99,105,110,103,32,102,117,108,108,32,105,110,116,101,114,110,97,108,32,72,32,99,104,114,111,109,97,32,100,117,101,32,116,111,32,105,110,112,117,116,32,104,97,118,105,110,103,32,110,111,110,32,115,117,98,115,97,109,112,108,101,100,32,99,104,114,111,109,97,10,0,0,0,0,0,0,0,102,105,114,115,116,76,117,109,83,114,99,89,32,62,61,32,108,97,115,116,73,110,76,117,109,66,117,102,32,45,32,118,76,117,109,66,117,102,83,105,122,101,32,43,32,49,0,0,115,101,116,32,116,104,101,32,114,97,110,100,111,109,32,115,101,101,100,0,0,0,0,0,110,101,97,114,101,115,116,32,110,101,105,103,104,98,111,114,0,0,0,0,0,0,0,0,105,99,104,0,0,0,0,0,84,114,101,97,116,105,110,103,32,37,115,32,97,115,32,109,111,110,111,10,0,0,0,0,121,117,118,97,52,50,50,112,57,108,101,0,0,0,0,0,76,105,109,101,71,114,101,101,110,0,0,0,0,0,0,0,97,108,108,0,0,0,0,0,116,114,105,97,110,103,117,108,97,114,95,104,112,0,0,0,114,97,110,103,101,32,60,61,32,49,54,32,124,124,32,33,115,45,62,109,115,109,112,101,103,52,95,118,101,114,115,105,111,110,0,0,0,0,0,0,119,105,100,116,104,0,0,0,115,45,62,97,118,99,116,120,45,62,99,111,100,101,99,95,105,100,32,33,61,32,65,86,95,67,79,68,69,67,95,73,68,95,72,50,54,52,0,0,80,67,83,95,84,105,109,98,97,108,97,105,95,49,57,52,56,95,66,111,114,110,101,111,0,0,0,0,0,0,0,0,87,76,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,112,111,115,61,37,100,44,32,118,97,108,61,37,100,33,10,0,92,97,108,112,104,97,38,72,37,50,88,38,37,49,91,92,125,93,37,110,0,0,0,0,71,67,83,95,67,97,109,97,99,117,112,97,0,0,0,0,92,37,99,0,0,0,0,0,115,97,109,112,108,101,32,99,111,117,110,116,32,109,105,115,109,97,116,99,104,58,32,37,117,32,33,61,32,37,100,10,0,0,0,0,0,0,0,0,70,114,97,109,101,32,115,105,122,101,32,115,104,111,117,108,100,32,98,101,32,37,100,32,103,111,116,32,37,100,10,0,65,68,80,67,77,32,89,97,109,97,104,97,0,0,0,0,121,0,0,0,0,0,0,0,116,101,101,0,0,0,0,0,101,112,122,115,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,0,0,0,85,115,101,32,97,108,116,101,114,110,97,116,105,118,101,32,105,110,116,101,114,32,86,76,67,46,0,0,0,0,0,0,77,80,69,71,52,32,86,105,100,101,111,32,68,101,99,111,100,101,114,0,0,0,0,0,109,106,112,101,103,58,32,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,69,88,73,70,32,100,97,116,97,10,0,0,0,0,0,0,0,0,99,101,110,116,101,114,95,109,105,120,108,101,118,0,0,0,99,101,110,116,101,114,95,109,105,120,108,101,118,0,0,0,97,108,116,101,114,110,97,116,101,32,98,105,116,115,116,114,101,97,109,32,115,121,110,116,97,120,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,114,101,100,117,99,101,100,32,115,97,109,112,108,101,114,97,116,101,115,46,32,119,114,105,116,105,110,103,32,111,102,32,101,120,116,101,110,100,101,100,32,98,105,116,115,116,114,101,97,109,32,105,110,102,111,114,109,97,116,105,111,110,32,119,105,108,108,32,98,101,32,100,105,115,97,98,108,101,100,46,10,0,0,0,0,0,84,69,77,80,0,0,0,0,80,114,101,102,101,114,114,101,100,32,83,116,101,114,101,111,32,68,111,119,110,109,105,120,32,77,111,100,101,0,0,0,32,100,117,112,0,0,0,0,84,111,111,32,109,97,110,121,32,98,105,116,115,32,112,101,114,32,102,114,97,109,101,32,114,101,113,117,101,115,116,101,100,10,0,0,0,0,0,0,109,115,118,105,100,101,111,49,0,0,0,0,0,0,0,0,78,111,116,32,101,118,97,108,117,97,116,105,110,103,32,97,32,102,117,114,116,104,101,114,32,112,114,111,103,114,97,109,95,99,111,110,102,105,103,95,101,108,101,109,101,110,116,32,97,115,32,116,104,105,115,32,99,111,110,115,116,114,117,99,116,32,105,115,32,100,117,98,105,111,117,115,32,97,116,32,98,101,115,116,46,10,0,0,73,110,118,97,108,105,100,32,99,111,100,101,99,32,105,100,32,37,100,46,10,0,0,0,80,114,111,103,114,101,115,115,105,118,101,32,82,111,99,107,0,0,0,0,0,0,0,0,115,101,116,32,99,111,101,102,102,105,99,105,101,110,116,32,102,97,99,116,111,114,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,80,67,83,95,84,97,110,97,110,97,114,105,118,101,95,85,84,77,95,51,57,83,0,0,108,111,115,116,32,99,32,102,114,97,109,101,32,37,100,10,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,120,111,102,102,115,101,116,32,37,100,0,0,0,0,0,0,123,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,56,0,0,0,73,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,32,40,115,104,111,117,108,100,32,98,101,32,52,54,41,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,119,109,97,112,114,111,100,101,99,46,99,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,112,97,100,100,105,110,103,32,98,105,116,115,32,105,110,32,114,97,119,32,80,67,77,32,116,105,108,101,10,0,105,62,61,48,0,0,0,0,112,114,101,118,95,98,108,111,99,107,95,108,101,110,95,98,105,116,115,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,60,98,62,0,0,0,0,0,105,110,118,97,108,105,100,32,84,73,70,70,32,104,101,97,100,101,114,32,105,110,32,69,120,105,102,32,100,97,116,97,10,0,0,0,0,0,0,0,106,111,105,110,116,0,0,0,66,108,111,99,107,32,115,105,122,101,32,37,105,32,105,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,99,98,112,48,32,99,104,117,110,107,32,116,111,111,32,108,97,114,103,101,32,40,37,117,32,98,121,116,101,115,41,10,0,0,0,0,0,0,0,0,82,101,115,101,114,118,101,100,32,98,105,116,32,115,104,111,117,108,100,32,98,101,32,122,101,114,111,10,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,116,105,116,105,111,110,115,10,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,99,117,114,118,101,115,46,99,0,107,101,121,0,0,0,0,0,98,111,111,107,45,62,100,105,109,101,110,115,105,111,110,115,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,100,101,98,111,111,107,32,105,110,32,118,111,114,98,105,115,95,102,108,111,111,114,95,100,101,99,111,100,101,46,10,0,0,0,0,0,0,0,37,100,32,109,111,100,101,115,32,40,101,105,116,104,101,114,32,97,32,102,97,108,115,101,32,112,111,115,105,116,105,118,101,32,111,114,32,97,32,115,97,109,112,108,101,32,102,114,111,109,32,97,110,32,117,110,107,110,111,119,110,32,101,110,99,111,100,101,114,41,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,108,111,99,107,32,116,121,112,101,32,48,120,37,48,56,88,10,0,0,108,105,98,97,118,99,111,100,101,99,47,118,109,100,97,118,46,99,0,0,0,0,0,0,112,105,99,116,95,116,121,112,101,58,32,37,99,10,0,0,80,67,83,95,84,97,110,97,110,97,114,105,118,101,95,85,84,77,95,51,56,83,0,0,67,97,110,110,111,116,32,114,101,97,100,32,102,105,108,101,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,104,0,0,0,0,0,0,0,79,108,100,32,87,77,86,51,32,118,101,114,115,105,111,110,32,100,101,116,101,99,116,101,100,44,32,115,111,109,101,32,102,114,97,109,101,115,32,109,97,121,32,98,101,32,100,101,99,111,100,101,100,32,105,110,99,111,114,114,101,99,116,108,121,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,52,58,50,58,48,32,118,105,100,101,111,32,114,101,113,117,105,114,101,115,32,101,118,101,110,32,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,46,10,0,0,0,0,80,108,97,110,101,32,104,97,115,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,115,121,109,98,111,108,32,121,101,116,32,97,32,115,108,105,99,101,32,104,97,115,32,97,32,108,101,110,103,116,104,32,111,102,32,122,101,114,111,46,10,0,0,0,0,0,0,0,116,101,100,99,97,112,116,105,111,110,115,0,0,0,0,0,48,0,0,0,0,0,0,0,40,37,115,41,0,0,0,0,115,101,116,32,116,104,101,32,97,108,112,104,97,32,103,97,105,110,32,102,111,114,32,116,104,101,32,114,101,100,32,99,104,97,110,110,101,108,0,0,115,97,109,112,108,101,95,114,97,116,101,32,116,111,111,32,108,97,114,103,101,10,0,0,73,110,118,97,108,105,100,32,115,108,105,99,101,32,115,105,122,101,32,40,37,100,47,37,100,41,10,0,0,0,0,0,49,46,50,46,53,0,0,0,110,111,116,32,101,110,111,117,103,104,32,115,112,97,99,101,32,102,111,114,32,108,101,110,32,108,101,102,116,10,0,0,105,110,118,97,108,105,100,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,40,37,100,41,10,0,0,67,111,109,112,114,101,115,115,105,110,103,32,102,97,105,108,101,100,10,0,0,0,0,0,80,67,83,95,84,97,110,97,110,97,114,105,118,101,95,76,97,98,111,114,100,101,0,0,115,101,116,32,109,101,116,97,100,97,116,97,32,105,110,102,111,114,109,97,116,105,111,110,32,111,102,32,111,117,116,102,105,108,101,32,102,114,111,109,32,105,110,102,105,108,101,0,115,101,116,32,114,101,100,32,109,105,100,116,111,110,101,115,0,0,0,0,0,0,0,0,86,105,100,101,111,32,111,112,116,105,111,110,115,58,0,0,50,0,0,0,0,0,0,0,116,97,107,0,0,0,0,0,71,101,111,103,65,110,103,117,108,97,114,85,110,105,116,115,71,101,111,75,101,121,0,0,10,0,0,0,0,0,0,0,114,112,115,32,37,100,32,105,110,118,97,108,105,100,10,0,107,101,101,112,95,97,115,115,95,109,97,114,107,117,112,0,82,97,110,32,111,117,102,32,111,102,32,100,97,116,97,32,98,101,102,111,114,101,32,101,110,100,45,111,102,45,105,109,97,103,101,10,0,0,0,0,117,110,100,101,114,114,101,97,100,10,0,0,0,0,0,0,78,0,0,0,0,0,0,0,119,101,105,114,100,32,112,114,101,100,105,99,116,105,111,110,10,0,0,0,0,0,0,0,117,115,101,108,101,115,115,32,99,111,108,111,114,109,97,112,32,102,111,117,110,100,32,111,114,32,102,105,108,101,32,105,115,32,99,111,114,114,117,112,116,101,100,44,32,116,114,121,105,110,103,32,116,111,32,114,101,99,111,118,101,114,10,0,60,47,37,99,37,115,62,0,92,78,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,83,111,110,105,99,32,118,101,114,115,105,111,110,44,32,112,108,101,97,115,101,32,114,101,112,111,114,116,10,0,0,0,0,0,0,0,80,67,83,95,83,117,100,97,110,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,99,111,101,102,95,115,117,109,32,60,32,48,120,55,102,102,102,102,102,102,102,0,0,0,69,114,114,111,114,32,115,45,62,109,97,120,95,114,101,102,95,102,114,97,109,101,115,32,105,115,32,37,100,10,0,0,115,101,116,32,116,104,101,32,112,105,120,101,108,32,98,108,97,99,107,32,116,104,114,101,115,104,111,108,100,0,0,0,115,101,116,32,111,117,116,112,117,116,32,116,105,109,101,115,116,97,109,112,32,111,102,102,115,101,116,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,67,97,110,110,111,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1882758);
/* memory initializer */ allocate([32,98,117,105,108,100,32,86,76,67,32,116,97,98,108,101,10,0,109,105,115,115,105,110,103,32,115,104,111,114,116,101,110,32,109,97,103,105,99,32,39,97,106,107,103,39,10,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,32,102,111,114,32,102,114,97,109,101,10,0,0,0,0,123,92,105,49,125,37,115,123,92,105,48,125,92,78,0,0,108,97,118,102,105,46,98,98,111,120,46,121,49,0,0,0,83,108,105,99,101,32,105,110,100,105,99,97,116,101,115,32,77,66,32,111,102,102,115,101,116,32,37,100,44,32,103,111,116,32,37,100,10,0,0,0,82,101,97,108,86,105,100,101,111,32,50,46,48,0,0,0,83,108,105,99,101,32,116,121,112,101,32,109,105,115,109,97,116,99,104,10,0,0,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,109,99,86,97,114,0,0,0,76,83,68,58,0,0,0,0,115,97,114,95,100,101,110,0,116,111,111,32,109,97,110,121,32,112,97,99,107,101,116,32,98,121,116,101,115,0,0,0,67,108,97,105,109,101,100,32,98,105,116,114,97,116,101,32,97,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,109,105,115,109,97,116,99,104,46,10,0,0,0,0,0,0,110,111,0,0,0,0,0,0,117,110,107,110,111,119,110,32,112,114,111,102,105,108,101,32,37,100,44,32,117,115,101,32,91,48,32,45,32,97,112,99,111,44,32,49,32,45,32,97,112,99,115,44,32,50,32,45,32,97,112,99,110,32,40,100,101,102,97,117,108,116,41,44,32,51,32,45,32,97,112,99,104,93,10,0,0,0,0,0,115,108,105,99,101,32,116,97,98,108,101,32,116,111,111,32,115,109,97,108,108,10,0,0,101,114,114,111,114,44,32,119,114,111,110,103,32,112,105,99,116,117,114,101,32,100,97,116,97,32,115,105,122,101,10,0,80,66,77,32,40,80,111,114,116,97,98,108,101,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,80,65,77,32,40,80,111,114,116,97,98,108,101,32,65,110,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,83,101,116,32,105,109,97,103,101,32,114,101,115,111,108,117,116,105,111,110,32,40,105,110,32,100,111,116,115,32,112,101,114,32,105,110,99,104,41,0,119,105,100,116,104,61,37,100,32,104,101,105,103,104,116,61,37,100,32,100,101,112,116,104,61,37,100,32,99,111,108,111,114,95,116,121,112,101,61,37,100,32,99,111,109,112,114,101,115,115,105,111,110,95,116,121,112,101,61,37,100,32,102,105,108,116,101,114,95,116,121,112,101,61,37,100,32,105,110,116,101,114,108,97,99,101,95,116,121,112,101,61,37,100,10,0,80,71,83,32,115,117,98,116,105,116,108,101,32,100,101,99,111,100,101,114,0,0,0,0,80,67,83,95,83,117,100,97,110,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,102,102,109,112,101,103,46,99,0,0,0,0,0,0,0,0,101,110,100,95,112,116,115,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,105,101,115,32,111,102,32,52,10,0,0,0,0,0,0,0,116,103,112,32,109,117,120,101,114,0,0,0,0,0,0,0,73,83,79,58,32,70,105,108,101,32,84,121,112,101,32,77,97,106,111,114,32,66,114,97,110,100,58,32,37,46,52,115,10,0,0,0,0,0,0,0,115,101,116,32,115,116,114,101,97,109,32,105,110,100,101,120,0,0,0,0,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,80,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,115,32,115,116,111,114,101,100,32,105,110,32,83,79,70,32,97,110,100,32,77,88,77,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,115,119,102,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,83,107,105,112,32,98,108,111,99,107,32,105,110,32,105,110,116,114,97,32,102,114,97,109,101,10,0,0,0,0,0,0,104,101,97,100,101,114,32,101,114,114,111,114,10,0,0,0,67,111,100,101,100,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,80,67,83,95,83,99,104,119,97,114,122,101,99,107,95,85,84,77,95,51,51,83,0,0,32,37,46,50,115,58,37,46,50,115,0,0,0,0,0,0,117,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,67,66,80,0,0,0,0,0,0,0,0,78,58,37,108,108,100,32,80,84,83,58,37,115,32,84,58,37,102,32,80,79,83,58,37,115,0,0,0,0,0,0,0,98,105,116,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,0,0,0,0,0,0,98,105,116,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,0,0,0,0,0,0,65,68,85,32,40,65,112,112,108,105,99,97,116,105,111,110,32,68,97,116,97,32,85,110,105,116,41,32,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,65,68,85,32,40,65,112,112,108,105,99,97,116,105,111,110,32,68,97,116,97,32,85,110,105,116,41,32,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,97,108,116,101,114,110,97,116,101,95,115,99,97,110,0,0,77,105,115,109,97,116,99,104,101,100,32,39,91,39,32,102,111,117,110,100,32,105,110,32,116,104,101,32,102,111,108,108,111,119,105,110,103,58,32,34,37,115,34,46,10,0,0,0,109,97,114,107,101,114,32,109,105,115,115,105,110,103,32,97,102,116,101,114,32,102,105,114,115,116,32,80,32,112,97,114,116,105,116,105,111,110,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,103,111,112,95,116,105,109,101,99,111,100,101,0,0,0,0,77,97,105,110,0,0,0,0,73,83,58,32,37,100,44,32,77,83,83,58,32,37,100,44,32,84,71,58,32,37,100,44,32,76,70,76,58,32,37,100,44,32,98,97,110,100,115,58,32,37,100,10,0,0,0,0,80,67,83,95,83,97,112,112,101,114,95,72,105,108,108,95,85,84,77,95,50,49,83,0,80,97,114,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,46,10,0,0,0,115,111,102,48,58,32,112,105,99,116,117,114,101,58,32,37,100,120,37,100,10,0,0,0,100,104,116,32,111,102,102,115,58,32,48,120,37,120,10,0,115,45,62,114,111,111,116,46,110,101,120,116,0,0,0,0,123,92,102,110,125,0,0,0,108,111,115,115,121,58,37,105,44,32,118,101,114,115,105,111,110,58,37,105,44,32,109,111,100,101,58,32,37,105,10,0,115,119,102,0,0,0,0,0,68,101,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,73,110,118,97,108,105,100,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,116,105,109,101,98,97,115,101,46,10,0,0,66,85,71,33,32,85,110,107,110,111,119,110,32,99,111,100,101,99,32,105,110,32,102,114,97,109,101,32,100,101,99,111,100,101,114,32,99,111,109,112,114,101,115,115,105,111,110,32,115,119,105,116,99,104,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,114,111,98,97,98,105,108,105,116,121,32,101,110,99,111,117,110,116,101,114,101,100,46,10,0,0,0,0,0,0,0,75,77,86,67,32,115,117,112,112,111,114,116,115,32,102,114,97,109,101,115,32,60,61,32,51,50,48,120,50,48,48,10,0,0,0,0,0,0,0,0,83,101,103,109,101,110,116,97,116,105,111,110,32,115,121,109,98,111,108,32,118,97,108,117,101,32,105,110,99,111,114,114,101,99,116,10,0,0,0,0,123,92,97,110,50,125,0,0,97,102,116,101,114,32,116,105,101,114,50,10,0,0,0,0,69,109,112,116,121,32,98,97,110,100,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,0,32,76,79,79,80,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,57,10,0,104,50,54,51,105,0,0,0,73,110,118,97,108,105,100,32,71,79,80,32,104,101,97,100,101,114,44,32,115,107,105,112,112,105,110,103,32,102,114,97,109,101,115,46,10,0,0,0,100,101,102,97,117,108,116,0,84,114,97,110,115,102,111,114,109,32,37,100,0,0,0,0,77,111,116,105,111,110,32,118,101,99,116,111,114,115,32,112,111,105,110,116,32,111,117,116,32,111,102,32,116,104,101,32,102,114,97,109,101,46,10,0,80,67,83,95,83,97,112,112,101,114,95,72,105,108,108,95,85,84,77,95,50,48,83,0,66,105,116,32,97,108,108,111,99,97,116,105,111,110,115,32,102,97,105,108,101,100,10,0,110,111,116,32,101,110,111,117,103,104,32,101,120,116,114,97,100,97,116,97,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,117,102,102,121,117,118,100,101,99,46,99,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,68,101,99,111,100,105,110,103,32,83,80,83,10,0,0,0,37,48,50,120,0,0,0,0,114,105,103,104,116,95,108,101,102,116,0,0,0,0,0,0,97,118,95,98,117,102,102,101,114,95,103,101,116,95,114,101,102,95,99,111,117,110,116,40,104,45,62,114,101,102,95,108,105,115,116,91,108,105,115,116,93,91,105,110,100,101,120,93,46,102,46,98,117,102,91,48,93,41,32,62,32,48,0,0,112,116,115,0,0,0,0,0,116,111,111,32,109,97,110,121,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,32,37,100,10,0,0,0,103,114,97,121,32,99,104,114,111,109,97,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,72,46,50,54,51,32,47,32,72,46,50,54,51,45,49,57,57,54,44,32,72,46,50,54,51,43,32,47,32,72,46,50,54,51,45,49,57,57,56,32,47,32,72,46,50,54,51,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,116,121,112,101,32,105,110,100,101,120,32,37,100,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,103,105,102,102,108,97,103,115,0,0,0,0,0,0,0,0,115,101,116,32,97,108,108,32,111,117,116,112,117,116,32,102,114,97,109,101,115,32,114,101,97,100,45,111,110,108,121,0,97,118,99,116,120,45,62,115,97,109,112,108,101,95,114,97,116,101,32,62,32,48,0,0,112,111,115,116,102,105,108,116,101,114,32,111,110,47,111,102,102,0,0,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,53,83,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,0,67,104,97,110,103,101,32,102,105,101,108,100,32,111,114,100,101,114,0,0,0,0,0,0,112,105,120,101,108,95,99,111,117,110,116,100,111,119,110,32,60,32,48,32,40,37,100,41,10,0,0,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,115,104,111,117,108,100,32,98,101,32,48,45,57,44,32,110,111,116,32,37,100,10,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,100,101,102,108,97,116,101,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,105,110,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,113,117,101,117,101,58,37,100,32,45,62,32,102,114,97,109,101,32,116,105,109,101,58,37,102,10,0,0,0,0,0,0,117,110,100,101,114,114,101,97,100,58,32,37,100,32,111,114,105,103,32,115,105,122,101,58,32,37,100,10,0,0,0,0,98,108,111,99,107,105,110,103,32,115,116,114,97,116,101,103,121,32,99,104,97,110,103,101,32,100,101,116,101,99,116,101,100,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,0,0,101,120,116,114,97,100,97,116,97,32,99,111,110,116,97,105,110,115,32,37,100,32,98,121,116,101,115,32,116,111,111,32,109,97,110,121,46,10,0,0,115,117,98,118,105,101,119,101,114,0,0,0,0,0,0,0,102,115,45,62,115,108,105,99,101,95,99,111,100,105,110,103,95,109,111,100,101,32,61,61,32,48,0,0,0,0,0,0,98,121,116,101,115,116,114,101,97,109,32,101,110,100,32,109,105,115,109,97,116,99,104,105,110,103,32,98,121,32,37,100,10,0,0,0,0,0,0,0,76,97,121,101,114,32,37,115,46,37,115,32,109,97,116,99,104,101,100,10,0,0,0,0,114,111,111,109,95,116,121,112,101,0,0,0,0,0,0,0,121,117,118,97,52,50,50,112,57,98,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,76,105,109,101,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,105,110,0,0,0,0,0,99,111,108,111,114,32,60,32,52,0,0,0,0,0,0,0,37,100,120,37,100,0,0,0,73,110,118,97,108,105,100,32,99,108,117,116,32,100,101,112,116,104,32,48,120,37,120,33,10,0,0,0,0,0,0,0,116,98,58,37,100,47,37,100,32,115,97,109,112,108,101,102,109,116,58,37,115,32,115,97,109,112,108,101,114,97,116,101,58,37,100,32,99,104,108,97,121,111,117,116,58,37,115,10,0,0,0,0,0,0,0,0,115,101,108,101,99,116,32,116,114,105,97,110,103,117,108,97,114,32,100,105,116,104,101,114,0,0,0,0,0,0,0,0,80,97,99,107,105,110,103,32,116,111,32,51,50,98,105,116,32,114,101,113,117,105,114,101,100,10,0,0,0,0,0,0,99,104,97,110,110,101,108,115,32,104,97,118,101,32,100,105,102,102,101,114,105,110,103,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,10,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,98,105,116,32,100,101,112,116,104,32,109,105,115,109,97,116,99,104,101,115,32,37,100,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,113,117,97,110,116,10,0,0,68,83,87,49,0,0,0,0,78,111,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,115,112,101,99,105,102,105,101,100,46,32,84,104,101,32,101,110,99,111,100,101,114,32,119,105,108,108,32,103,117,101,115,115,32,116,104,101,32,108,97,121,111,117,116,44,32,98,117,116,32,105,116,32,109,105,103,104,116,32,98,101,32,105,110,99,111,114,114,101,99,116,46,10,0,0,0,0,0,88,57,54,32,101,120,116,101,110,115,105,111,110,32,102,111,117,110,100,32,97,116,32,37,100,32,98,105,116,115,10,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,78,101,99,101,115,115,97,114,121,32,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,33,10,0,0,0,71,67,83,95,66,117,107,105,116,95,82,105,109,112,97,104,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,97,117,100,105,111,32,102,114,97,109,101,115,44,32,97,110,100,32,109,97,107,101,32,116,104,101,109,32,97,118,97,105,108,97,98,108,101,32,116,111,32,116,104,101,32,101,110,100,32,111,102,32,116,104,101,32,102,105,108,116,101,114,32,103,114,97,112,104,46,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,115,117,98,118,105,101,119,101,114,49,0,0,0,0,0,0,102,117,108,108,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,115,108,111,119,101,115,116,41,0,0,0,0,0,0,0,0,97,105,118,0,0,0,0,0,65,100,118,97,110,99,101,100,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,0,109,106,112,101,103,58,32,105,110,118,97,108,105,100,32,84,73,70,70,32,104,101,97,100,101,114,32,105,110,32,69,88,73,70,32,100,97,116,97,10,0,0,0,0,0,0,0,0,72,46,50,54,51,32,47,32,72,46,50,54,51,45,49,57,57,54,44,32,72,46,50,54,51,43,32,47,32,72,46,50,54,51,45,49,57,57,56,32,47,32,72,46,50,54,51,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,83,80,65,84,0,0,0,0,66,108,111,99,107,101,100,32,89,85,86,0,0,0,0,0,77,97,120,32,101,120,116,114,97,32,99,111,100,101,98,111,111,107,32,114,101,99,97,108,99,117,108,97,116,105,111,110,32,112,97,115,115,101,115,44,32,109,111,114,101,32,105,115,32,98,101,116,116,101,114,32,97,110,100,32,115,108,111,119,101,114,0,0,0,0,0,0,105,108,108,101,103,97,108,32,105,110,116,101,114,32,99,98,112,32,37,100,10,0,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,100,97,116,97,10,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,102,114,97,109,101,32,100,97,116,97,10,0,0,0,0,0,0,66,77,80,32,99,111,100,105,110,103,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,77,105,99,114,111,115,111,102,116,32,82,76,69,0,0,0,115,116,97,116,101,32,61,61,32,118,108,99,0,0,0,0,68,67,32,118,97,108,117,101,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,58,32,37,100,10,0,0,0,0,0,0,0,0,71,111,116,104,105,99,32,82,111,99,107,0,0,0,0,0,67,97,110,110,111,116,32,115,101,108,101,99,116,32,115,97,109,112,108,101,32,114,97,116,101,32,102,111,114,32,116,104,101,32,108,105,110,107,32,98,101,116,119,101,101,110,32,102,105,108,116,101,114,115,32,37,115,32,97,110,100,32,37,115,46,10,0,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,91,56,45,57,93,32,37,100,10,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,0,0,66,108,111,99,107,32,108,101,110,103,116,104,32,105,115,32,110,111,116,32,101,118,101,110,108,121,32,100,105,118,105,115,105,98,108,101,32,98,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,117,98,98,108,111,99,107,115,46,10,0,0,0,0,0,0,0,88,45,68,105,115,112,111,115,105,116,105,111,110,0,0,0,99,104,101,99,107,101,114,98,111,97,114,100,95,108,114,0,77,101,116,97,108,0,0,0,99,111,109,109,101,110,116,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,65,73,70,67,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,111,110,102,105,103,117,114,101,32,105,110,112,117,116,32,112,97,100,32,111,110,32,37,115,10,0,0,0,0,69,120,116,101,110,115,105,111,110,32,102,108,97,103,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,68,84,83,10,0,0,52,50,50,112,49,54,0,0,73,110,118,97,108,105,100,32,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,37,100,32,102,111,114,32,37,100,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,114,98,0,0,0,0,0,0,91,48,120,37,120,93,0,0,109,97,112,95,109,101,116,97,100,97,116,97,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,49,83,0,0,115,101,103,109,101,110,116,95,116,105,109,101,44,32,115,101,103,109,101,110,116,95,116,105,109,101,115,44,32,97,110,100,32,115,101,103,109,101,110,116,95,102,114,97,109,101,115,32,111,112,116,105,111,110,115,32,97,114,101,32,109,117,116,117,97,108,108,121,32,101,120,99,108,117,115,105,118,101,44,32,115,101,108,101,99,116,32,106,117,115,116,32,111,110,101,32,111,102,32,116,104,101,109,10,0,0,0,0,0,0,0,0,115,114,116,0,0,0,0,0,115,114,116,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,48,83,0,0,111,117,116,112,117,116,95,116,115,95,111,102,102,115,101,116,0,0,0,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,57,83,0,0,111,115,116,45,62,115,111,117,114,99,101,95,105,110,100,101,120,32,62,61,32,48,0,0,109,112,52,32,109,117,120,101,114,0,0,0,0,0,0,0,113,116,32,32,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,56,83,0,0,84,73,77,0,0,0,0,0,115,112,100,105,102,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,55,83,0,0,80,97,99,107,101,116,32,110,111,116,32,101,110,100,105,110,103,32,97,116,32,97,32,49,54,45,98,105,116,32,98,111,117,110,100,97,114,121,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,115,111,120,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,99,111,110,99,97,116,0,0,115,111,120,0,0,0,0,0,115,111,108,0,0,0,0,0,121,117,118,97,52,50,48,112,57,108,101,0,0,0,0,0,76,105,103,104,116,89,101,108,108,111,119,0,0,0,0,0,109,97,120,0,0,0,0,0,116,114,105,97,110,103,117,108,97,114,0,0,0,0,0,0,115,109,117,115,104,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,0,0,0,71,67,83,95,66,111,103,111,116,97,0,0,0,0,0,0,112,99,109,95,117,50,52,98,101,0,0,0,0,0,0,0,102,117,108,108,0,0,0,0,85,115,101,32,117,110,108,105,109,105,116,101,100,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,46,0,0,0,83,105,109,112,108,101,32,83,116,117,100,105,111,32,80,114,111,102,105,108,101,0,0,0,99,0,0,0,0,0,0,0,109,115,114,108,101,0,0,0,65,118,97,110,116,103,97,114,100,101,0,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,102,105,108,116,101,114,0,0,45,37,45,49,55,115,32,32,37,115,10,0,0,0,0,0,67,97,110,110,111,116,32,100,101,116,101,114,109,105,110,101,32,99,117,115,116,111,109,32,115,97,109,112,108,105,110,103,32,114,97,116,101,10,0,0,105,110,100,101,120,32,60,32,87,84,86,95,70,73,76,69,83,0,0,0,0,0,0,0,112,111,105,110,116,0,0,0,32,32,32,32,83,116,114,101,97,109,32,35,37,100,58,37,100,0,0,0,0,0,0,0,102,111,114,109,97,116,32,98,117,102,102,101,114,32,115,105,122,101,32,117,110,100,101,114,102,108,111,119,10,0,0,0,80,67,83,95,82,68,95,78,101,116,104,101,114,108,97,110,100,115,95,78,101,119,0,0,102,105,108,101,46,115,116,114,101,97,109,46,99,104,97,110,110,101,108,91,58,115,121,110,99,102,105,108,101,46,115,121,110,99,115,116,114,101,97,109,93,0,0,0,0,0,0,0,37,108,108,100,58,0,0,0,37,117,58,37,117,58,37,117,46,37,117,0,0,0,0,0,80,67,83,95,82,68,95,78,101,116,104,101,114,108,97,110,100,115,95,79,108,100,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,98,121,116,101,115,32,116,111,32,98,101,32,119,114,105,116,116,101,110,32,97,115,32,112,97,100,100,105,110,103,32,105,110,32,97,32,109,101,116,97,100,97,116,97,32,104,101,97,100,101,114,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,73,110,118,97,108,105,100,32,114,97,116,101,32,102,108,97,103,32,37,100,10,0,0,0,80,67,83,95,81,97,116,97,114,95,78,97,116,105,111,110,97,108,95,71,114,105,100,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,112,115,112,32,109,117,120,101,114,0,0,0,0,0,0,0,104,97,110,100,108,101,114,95,110,97,109,101,0,0,0,0,115,109,111,111,116,104,115,116,114,101,97,109,105,110,103,0,104,101,97,100,101,114,58,32,39,37,115,39,32,61,32,39,37,115,39,10,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,51,50,78,0,0,0,84,73,77,69,0,0,0,0,115,109,106,112,101,103,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,51,49,78,0,0,0,109,111,100,101,0,0,0,0,115,109,106,112,101,103,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,51,48,78,0,0,0,97,97,99,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,117,110,99,111,100,101,100,102,114,97,109,101,99,114,99,101,110,99,46,99,0,0,0,0,0,0,0,0,115,109,107,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,57,78,0,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,121,117,118,97,52,50,48,112,57,98,101,0,0,0,0,0,76,105,103,104,116,83,116,101,101,108,66,108,117,101,0,0,100,101,102,97,117,108,116,0,37,115,37,115,0,0,0,0,115,101,108,101,99,116,32,114,101,99,116,97,110,103,117,108,97,114,32,100,105,116,104,101,114,0,0,0,0,0,0,0,102,97,108,115,101,0,0,0,115,105,102,102,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,56,78,0,0,0,44,32,109,97,120,46,32,37,100,32,107,98,47,115,0,0,116,66,97,75,0,0,0,0,71,67,83,95,66,101,114,110,95,49,56,57,56,0,0,0,119,97,114,110,105,110,103,58,32,70,108,97,115,104,32,80,108,97,121,101,114,32,108,105,109,105,116,32,111,102,32,49,54,48,48,48,32,102,114,97,109,101,115,32,114,101,97,99,104,101,100,10,0,0,0,0,122,101,114,111,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,102,97,115,116,101,115,116,41,0,0,0,0,0,0,0,0,117,109,118,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,115,119,102,100,101,99,46,99,0,0,0,0,65,100,118,97,110,99,101,100,32,83,99,97,108,97,98,108,101,32,84,101,120,116,117,114,101,32,80,114,111,102,105,108,101,0,0,0,0,0,0,0,95,74,80,83,74,80,83,95,10,0,0,0,0,0,0,0,91,83,84,89,76,69,93,0,32,73,68,82,0,0,0,0,87,101,115,116,119,111,111,100,32,83,116,117,100,105,111,115,32,86,81,65,32,40,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,100,32,65,110,105,109,97,116,105,111,110,41,32,118,105,100,101,111,0,66,108,117,101,103,114,97,115,115,0,0,0,0,0,0,0,118,109,100,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,55,78,0,0,0,83,82,84,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,97,32,115,105,110,103,108,101,32,115,117,98,116,105,116,108,101,115,32,115,116,114,101,97,109,46,10,0,0,0,73,110,112,117,116,32,108,105,110,107,32,37,115,32,112,97,114,97,109,101,116,101,114,115,32,40,115,105,122,101,32,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,32,100,111,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,111,117,116,112,117,116,32,108,105,110,107,32,37,115,32,112,97,114,97,109,101,116,101,114,115,32,40,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,10,0,0,0,115,116,114,97,121,32,68,84,83,45,72,68,32,102,114,97,109,101,10,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,54,78,0,0,0,109,117,120,101,114,0,0,0,60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,110,99,111,100,105,110,103,61,34,117,116,102,45,56,34,63,62,10,0,77,117,108,116,105,112,108,101,32,118,105,100,101,111,32,115,116,114,101,97,109,115,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,70,105,108,101,32,99,111,110,116,97,105,110,115,32,110,111,32,102,114,97,109,101,115,32,63,63,63,10,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,53,78,0,0,0,37,115,37,115,0,0,0,0,109,97,112,32,97,110,32,97,117,100,105,111,32,99,104,97,110,110,101,108,32,102,114,111,109,32,111,110,101,32,115,116,114,101,97,109,32,116,111,32,97,110,111,116,104,101,114,0,115,101,116,32,99,111,110,116,97,105,110,101,114,32,102,111,114,109,97,116,32,117,115,101,100,32,102,111,114,32,116,104,101,32,115,101,103,109,101,110,116,115,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,52,78,0,0,0,109,101,116,97,100,97,116,97,95,104,101,97,100,101,114,95,112,97,100,100,105,110,103,0,114,97,116,101,0,0,0,0,109,97,105,110,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,49,50,55,46,48,46,48,46,49,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,51,78,0,0,0,78,111,32,109,111,114,101,32,105,110,112,117,116,115,32,116,111,32,114,101,97,100,32,102,114,111,109,44,32,102,105,110,105,115,104,105,110,103,46,10,0,0,0,0,0,0,0,0,84,111,110,101,45,115,101,116,32,34,37,46,42,115,34,32,110,111,116,32,100,101,102,105,110,101,100,10,0,0,0,0,116,103,50,32,109,117,120,101,114,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,50,78,0,0,0,45,37,46,50,115,45,37,46,50,115,0,0,0,0,0,0,77,117,108,116,105,115,116,114,101,97,109,32,111,112,117,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,82,84,80,10,0,0,37,108,108,100,32,44,32,37,108,108,100,32,59,32,37,108,108,100,0,0,0,0,0,0,84,104,101,32,65,117,100,105,111,32,83,116,114,101,97,109,0,0,0,0,0,0,0,0,114,109,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,49,78,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,73,71,78,82,0,0,0,0,101,110,100,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,48,78,0,0,0,115,101,116,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,57,78,0,0,0,52,52,49,48,48,0,0,0,100,97,116,97,0,0,0,0,114,97,119,32,77,74,80,69,71,32,118,105,100,101,111,0,103,98,114,112,49,54,108,101,0,0,0,0,0,0,0,0,76,105,103,104,116,83,108,97,116,101,71,114,97,121,0,0,37,100,37,42,49,91,58,47,93,37,100,37,99,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,39,114,101,100,49,39,32,97,116,111,109,10,0,0,0,0,0,114,101,99,116,97,110,103,117,108,97,114,0,0,0,0,0,97,117,100,105,111,32,100,97,116,97,32,99,111,114,114,117,112,116,105,111,110,10,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,56,78,0,0,0,44,32,37,100,32,107,98,47,115,0,0,0,0,0,0,0,71,67,83,95,66,101,114,109,117,100,97,95,49,57,53,55,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,122,101,114,111,0,0,0,0,72,46,50,54,51,112,32,101,110,99,111,100,101,114,0,0,65,100,118,97,110,99,101,100,32,67,111,114,101,32,80,114,111,102,105,108,101,0,0,0,32,102,105,120,0,0,0,0,119,115,95,118,113,97,0,0,67,101,108,116,105,99,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,55,78,0,0,0,115,51,50,98,101,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,54,78,0,0,0,100,101,109,117,120,101,114,0,115,51,50,98,101,0,0,0,115,101,103,109,101,110,116,0,37,99,0,0,0,0,0,0,102,105,108,109,95,99,112,107,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,53,78,0,0,0,73,110,118,97,108,105,100,32,115,101,103,109,101,110,116,32,102,105,108,101,110,97,109,101,32,116,101,109,112,108,97,116,101,32,39,37,115,39,10,0,115,100,114,50,0,0,0,0,109,97,112,95,99,104,97,110,110,101,108,0,0,0,0,0,102,102,108,97,103,115,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,116,97,103,32,37,100,32,102,111,114,32,119,114,105,116,101,10,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,37,100,33,10,0,0,67,72,65,80,84,69,82,37,48,51,100,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,52,78,0,0,0,101,110,97,98,108,101,32,102,108,117,115,104,105,110,103,32,111,102,32,116,104,101,32,73,47,79,32,99,111,110,116,101,120,116,32,97,102,116,101,114,32,101,97,99,104,32,112,97,99,107,101,116,0,0,0,0,110,117,116,45,62,104,101,97,100,101,114,95,108,101,110,91,48,93,32,61,61,32,48,0,111,112,117,115,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,51,78,0,0,0,79,117,116,112,117,116,32,102,105,108,101,32,105,115,32,101,109,112,116,121,44,32,110,111,116,104,105,110,103,32,119,97,115,32,101,110,99,111,100,101,100,32,40,99,104,101,99,107,32,45,115,115,32,47,32,45,116,32,47,32,45,102,114,97,109,101,115,32,112,97,114,97,109,101,116,101,114,115,32,105,102,32,117,115,101,100,41,10,0,0,0,0,0,0,0,0,111,103,103,32,112,97,103,101,44,32,117,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,10,0,0,105,112,111,100,32,109,117,120,101,114,0,0,0,0,0,0,86,101,114,115,105,111,110,32,37,100,0,0,0,0,0,0,68,105,115,112,111,115,105,116,105,111,110,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,50,78,0,0,0,84,68,65,0,0,0,0,0,110,111,32,115,121,110,99,112,111,105,110,116,32,97,116,32,98,97,99,107,112,116,114,32,112,111,115,10,0,0,0,0,109,117,45,108,97,119,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,49,78,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,48,78,0,0,0,98,97,100,32,115,105,122,101,58,32,37,105,10,0,0,0,78,111,32,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,102,111,117,110,100,10,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,57,78,0,0,0,0,45,45,37,115,13,10,0,0,103,98,114,112,49,54,98,101,0,0,0,0,0,0,0,0,76,105,103,104,116,83,107,121,66,108,117,101,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,105,109,97,103,101,32,115,105,122,101,10,0,0,0,0,0,0,0,0,115,101,116,32,100,105,116,104,101,114,32,109,101,116,104,111,100,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,56,78,0,0,0,0,44,32,112,97,115,115,32,50,0,0,0,0,0,0,0,0,71,67,83,95,66,101,108,103,101,95,49,57,53,48,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,115,101,116,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,109,101,116,104,111,100,0,0,0,0,109,115,109,112,101,103,52,118,50,32,101,110,99,111,100,101,114,0,0,0,0,0,0,0,65,100,118,97,110,99,101,100,32,67,111,100,105,110,103,32,80,114,111,102,105,108,101,0,109,112,101,103,116,115,114,97,119,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,88,70,82,77,32,37,100,10,0,0,0,0,0,0,0,0,118,105,100,101,111,0,0,0,66,0,0,0,0,0,0,0,67,105,110,101,112,97,107,0,115,118,99,100,0,0,0,0,82,101,118,105,118,97,108,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,55,78,0,0,0,0,84,104,101,32,105,110,112,117,116,32,105,110,100,101,120,32,102,105,108,101,110,97,109,101,32,105,115,32,116,111,111,32,115,104,111,114,116,32,116,111,32,103,117,101,115,115,32,116,104,101,32,97,115,115,111,99,105,97,116,101,100,32,46,83,85,66,32,102,105,108,101,10,0,0,0,0,0,0,0,0,83,116,114,101,97,109,32,104,101,97,100,101,114,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,54,78,0,0,0,0,101,110,99,111,100,101,114,0,84,73,84,50,0,0,0,0,117,115,101,116,111,99,0,0,32,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,53,78,0,0,0,0,49,0,0,0,0,0,0,0,91,45,93,105,110,112,117,116,95,102,105,108,101,95,105,100,91,58,115,116,114,101,97,109,95,115,112,101,99,105,102,105,101,114,93,91,44,115,121,110,99,95,102,105,108,101,95,105,100,91,58,115,116,114,101,97,109,95,115,112,101,99,105,102,105,101,114,93,93,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,52,78,0,0,0,0,99,111,114,114,101,99,116,32,115,105,110,103,108,101,32,116,105,109,101,115,116,97,109,112,32,111,118,101,114,102,108,111,119,115,0,0,0,0,0,0,105,110,118,97,108,105,100,32,101,108,105,115,105,111,110,32,104,101,97,100,101,114,10,0,51,71,80,32,40,51,71,80,80,32,102,105,108,101,32,102,111,114,109,97,116,41], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1892998);
/* memory initializer */ allocate([0,0,115,98,103,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,51,50,0,0,0,0,0,0,0,118,105,100,101,111,58,37,49,46,48,102,107,66,32,97,117,100,105,111,58,37,49,46,48,102,107,66,32,115,117,98,116,105,116,108,101,58,37,49,46,48,102,32,100,97,116,97,58,37,49,46,48,102,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,58,37,49,46,48,102,107,66,32,109,117,120,105,110,103,32,111,118,101,114,104,101,97,100,32,37,102,37,37,10,0,0,0,0,0,0,105,115,109,118,32,109,117,120,101,114,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,109,100,104,100,63,10,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,51,49,0,0,0,0,0,0,0,83,65,85,67,69,48,48,0,97,118,101,99,116,111,114,115,99,111,112,101,0,0,0,0,84,68,65,84,0,0,0,0,109,111,111,118,32,97,116,111,109,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,89,97,109,97,104,97,32,83,77,65,70,32,115,116,101,114,101,111,32,105,115,32,101,120,112,101,114,105,109,101,110,116,97,108,44,32,97,100,100,32,39,45,115,116,114,105,99,116,32,37,100,39,32,105,102,32,121,111,117,32,119,97,110,116,32,116,111,32,117,115,101,32,105,116,46,10,0,0,0,0,123,68,69,70,65,85,76,84,125,123,125,0,0,0,0,0,123,37,100,125,123,37,99,0,115,97,109,105,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,51,48,0,0,0,0,0,0,0,37,48,50,120,0,0,0,0,97,117,100,105,111,47,120,45,109,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,57,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,115,105,122,101,32,98,117,116,32,110,111,32,100,97,116,97,32,105,110,32,104,101,97,100,101,114,115,116,114,105,112,10,0,0,0,0,83,101,110,100,105,110,103,32,78,65,76,32,37,120,32,111,102,32,108,101,110,32,37,100,32,77,61,37,100,10,0,0,111,110,108,121,32,116,105,103,104,116,108,121,32,112,97,99,107,101,100,32,80,67,77,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,56,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,115,112,108,105,116,32,72,50,54,51,32,112,97,99,107,101,116,44,32,117,115,101,32,45,109,98,95,105,110,102,111,32,37,100,32,111,114,32,108,111,119,101,114,46,10,0,77,117,120,105,110,103,32,77,80,69,71,45,52,32,65,79,84,32,37,100,32,105,110,32,76,65,84,77,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,103,98,114,112,49,48,108,101,0,0,0,0,0,0,0,0,76,105,103,104,116,83,101,97,71,114,101,101,110,0,0,0,67,76,79,67,75,80,65,85,83,69,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,118,105,100,101,111,32,114,97,116,101,10,0,0,0,0,0,0,0,0,100,105,116,104,101,114,95,109,101,116,104,111,100,0,0,0,83,101,108,101,99,116,32,98,111,116,104,32,99,104,97,110,110,101,108,115,0,0,0,0,114,116,112,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,55,0,0,0,0,0,0,0,44,32,112,97,115,115,32,49,0,0,0,0,0,0,0,0,71,67,83,95,66,101,105,106,105,110,103,95,49,57,53,52,0,0,0,0,0,0,0,0,112,99,109,95,117,49,54,108,101,0,0,0,0,0,0,0,109,101,95,109,101,116,104,111,100,0,0,0,0,0,0,0,109,115,109,112,101,103,52,118,51,32,101,110,99,111,100,101,114,0,0,0,0,0,0,0,67,111,100,101,32,83,99,97,108,97,98,108,101,32,80,114,111,102,105,108,101,0,0,0,84,0,0,0,0,0,0,0,99,105,110,101,112,97,107,0,76,97,116,105,110,0,0,0,69,82,82,79,82,58,32,121,117,118,52,109,112,101,103,32,99,97,110,32,111,110,108,121,32,104,97,110,100,108,101,32,121,117,118,52,52,52,112,44,32,121,117,118,52,50,50,112,44,32,121,117,118,52,50,48,112,44,32,121,117,118,52,49,49,112,32,97,110,100,32,103,114,97,121,56,32,112,105,120,101,108,32,102,111,114,109,97,116,115,46,32,65,110,100,32,117,115,105,110,103,32,39,115,116,114,105,99,116,32,45,49,39,32,97,108,115,111,32,121,117,118,52,52,52,112,57,44,32,121,117,118,52,50,50,112,57,44,32,121,117,118,52,50,48,112,57,44,32,121,117,118,52,52,52,112,49,48,44,32,121,117,118,52,50,50,112,49,48,44,32,121,117,118,52,50,48,112,49,48,44,32,121,117,118,52,52,52,112,49,50,44,32,121,117,118,52,50,50,112,49,50,44,32,121,117,118,52,50,48,112,49,50,44,32,121,117,118,52,52,52,112,49,52,44,32,121,117,118,52,50,50,112,49,52,44,32,121,117,118,52,50,48,112,49,52,44,32,121,117,118,52,52,52,112,49,54,44,32,121,117,118,52,50,50,112,49,54,44,32,121,117,118,52,50,48,112,49,54,32,97,110,100,32,103,114,97,121,49,54,32,112,105,120,101,108,32,102,111,114,109,97,116,115,46,32,85,115,101,32,45,112,105,120,95,102,109,116,32,116,111,32,115,101,108,101,99,116,32,111,110,101,46,10,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,54,0,0,0,0,0,0,0,108,111,111,112,0,0,0,0,71,117,101,115,115,101,100,32,67,104,97,110,110,101,108,32,76,97,121,111,117,116,32,102,111,114,32,32,73,110,112,117,116,32,83,116,114,101,97,109,32,35,37,100,46,37,100,32,58,32,37,115,10,0,0,0,109,110,103,0,0,0,0,0,97,114,116,105,115,116,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,53,0,0,0,0,0,0,0,100,101,99,111,100,101,114,0,32,32,32,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,52,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,101,115,101,110,100,95,104,101,97,100,101,114,115,0,0,84,69,78,67,0,0,0,0,80,78,71,32,105,110,32,105,99,111,32,114,101,113,117,105,114,101,115,32,112,105,120,101,108,32,102,111,114,109,97,116,32,116,111,32,98,101,32,114,103,98,97,10,0,0,0,0,115,101,116,32,105,110,112,117,116,32,115,116,114,101,97,109,32,109,97,112,112,105,110,103,0,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,114,116,112,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,51,0,0,0,0,0,0,0,99,111,114,114,101,99,116,95,116,115,95,111,118,101,114,102,108,111,119,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,108,111,97,100,105,110,103,32,102,105,114,115,116,32,115,101,103,109,101,110,116,32,39,37,115,39,10,0,0,69,114,114,111,114,32,110,117,116,45,62,104,101,97,100,101,114,95,108,101,110,91,105,93,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,9,60,105,100,62,37,115,60,47,105,100,62,10,0,0,0,114,115,111,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,50,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,103,120,102,101,110,99,46,99,0,0,0,0,10,0,0,0,0,0,0,0,79,118,101,114,114,105,100,101,32,109,97,106,111,114,32,98,114,97,110,100,0,0,0,0,70,111,117,110,100,32,100,117,112,108,105,99,97,116,101,100,32,77,79,79,86,32,65,116,111,109,46,32,83,107,105,112,112,101,100,32,105,116,10,0,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,111,114,32,105,110,118,97,108,105,100,32,109,97,112,32,112,114,101,97,109,98,108,101,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,95,100,101,108,97,121,0,0,0,114,115,111,0,0,0,0,0,71,73,70,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,49,0,0,0,0,0,0,0,84,89,69,0,0,0,0,0,114,115,100,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,102,108,118,101,110,99,46,99,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,48,0,0,0,0,0,0,0,65,117,100,105,111,32,99,111,100,101,99,32,40,37,120,41,0,0,0,0,0,0,0,0,102,108,97,99,32,109,117,120,101,114,0,0,0,0,0,0,114,112,108,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,57,0,0,0,0,0,0,0,69,120,112,101,99,116,101,100,32,99,104,97,112,116,101,114,32,101,110,100,32,116,105,109,101,115,116,97,109,112,44,32,102,111,117,110,100,32,37,115,46,10,0,0,0,0,0,0,117,110,107,110,111,119,110,32,49,83,78,104,32,104,101,97,100,101,114,105,100,0,0,0,115,109,112,116,101,49,55,48,109,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,56,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,100,118,32,112,99,109,32,102,114,97,109,101,115,10,0,114,109,0,0,0,0,0,0,103,98,114,112,49,48,98,101,0,0,0,0,0,0,0,0,76,105,103,104,116,83,97,108,109,111,110,0,0,0,0,0,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,115,101,116,32,100,105,116,104,101,114,32,115,99,97,108,101,0,0,0,0,0,0,0,0,76,105,110,101,32,37,100,58,32,105,110,118,97,108,105,100,32,100,117,114,97,116,105,111,110,32,39,37,115,39,10,0,98,111,116,104,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,55,0,0,0,0,0,0,0,44,32,0,0,0,0,0,0,71,67,83,95,66,101,100,117,97,114,97,109,0,0,0,0,102,114,109,97,97,108,97,99,0,0,0,0,0,0,0,0,83,104,111,119,32,97,108,108,32,102,114,97,109,101,115,32,98,101,102,111,114,101,32,116,104,101,32,102,105,114,115,116,32,107,101,121,102,114,97,109,101,0,0,0,0,0,0,0,119,109,118,49,32,101,110,99,111,100,101,114,0,0,0,0,65,100,118,97,110,99,101,100,32,82,101,97,108,32,84,105,109,101,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,0,0,0,0,0,0,0,67,79,76,82,32,37,100,10,0,0,0,0,0,0,0,0,115,107,105,112,112,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,58,32,37,88,10,0,0,0,0,0,70,0,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,118,105,100,101,111,32,40,82,80,90,65,41,0,0,66,101,98,111,98,0,0,0,87,97,114,110,105,110,103,58,32,103,101,110,101,114,97,116,105,110,103,32,110,111,110,32,115,116,97,110,100,97,114,100,32,89,85,86,32,115,116,114,101,97,109,46,32,77,106,112,101,103,116,111,111,108,115,32,119,105,108,108,32,110,111,116,32,119,111,114,107,46,10,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,54,0,0,0,0,0,0,0,65,114,116,119,111,114,120,32,68,97,116,97,32,70,111,114,109,97,116,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,109,111,114,101,32,116,104,97,110,32,50,53,54,32,97,117,100,105,111,32,116,114,97,99,107,115,32,40,37,100,41,10,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,53,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,32,37,48,50,120,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,112,116,105,111,110,115,32,115,116,114,105,110,103,32,37,115,10,0,0,0,0,0,0,0,0,108,111,103,105,99,97,108,45,102,105,108,101,105,110,102,111,0,0,0,0,0,0,0,0,112,98,45,62,115,101,101,107,97,98,108,101,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,52,0,0,0,0,0,0,0,114,108,50,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,115,101,103,109,101,110,116,32,39,37,115,39,10,0,0,0,0,117,110,107,110,111,119,110,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,116,97,103,58,32,37,117,0,0,0,0,109,97,112,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,51,0,0,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,98,121,116,101,115,32,116,111,32,115,107,105,112,32,98,101,102,111,114,101,32,114,101,97,100,105,110,103,32,104,101,97,100,101,114,32,97,110,100,32,102,114,97,109,101,115,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,69,114,114,111,114,32,110,117,116,45,62,104,101,97,100,101,114,95,99,111,117,110,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,102,102,32,97,115,102,32,98,97,100,32,104,101,97,100,101,114,32,37,120,32,32,97,116,58,37,108,108,100,10,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,50,0,0,0,0,0,0,0,115,117,98,102,112,115,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,65,80,69,32,116,97,103,32,107,101,121,32,39,37,115,39,46,10,0,0,0,0,0,0,98,114,97,110,100,0,0,0,70,105,108,101,32,116,114,117,110,99,97,116,101,100,10,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,49,0,0,0,0,0,0,0,84,89,69,82,0,0,0,0,104,105,115,116,111,103,114,97,109,95,37,100,100,98,58,32,37,108,108,100,10,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,100,10,0,0,0,0,0,0,0,0,102,108,111,97,116,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,48,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,37,108,102,37,110,32,42,37,110,0,0,0,0,0,0,0,84,104,105,115,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,39,124,39,32,116,111,32,115,101,112,97,114,97,116,101,32,116,104,101,32,109,97,112,112,105,110,103,115,46,10,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,57,0,0,0,0,0,0,0,0,112,111,105,110,116,115,0,0,37,100,37,110,0,0,0,0,98,116,52,55,48,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,56,0,0,0,0,0,0,0,0,98,97,110,100,114,101,106,101,99,116,0,0,0,0,0,0,73,65,82,84,0,0,0,0,103,98,114,112,57,108,101,0,102,108,97,103,115,61,48,120,37,88,0,0,0,0,0,0,76,105,103,104,116,80,105,110,107,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,37,115,10,0,0,0,0,0,0,0,0,100,105,116,104,101,114,95,115,99,97,108,101,0,0,0,0,115,116,97,114,116,95,104,101,114,101,32,60,61,32,115,116,111,112,95,104,101,114,101,32,38,38,32,102,114,97,103,45,62,112,111,115,105,116,105,111,110,91,49,93,32,60,61,32,115,116,97,114,116,95,104,101,114,101,0,0,0,0,0,0,83,101,108,101,99,116,32,83,117,98,47,82,105,103,104,116,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,55,0,0,0,0,0,0,0,0,44,32,37,100,32,72,122,0,116,50,0,0,0,0,0,0,71,67,83,95,66,97,114,98,97,100,111,115,0,0,0,0,82,77,83,32,112,101,97,107,32,100,66,58,32,37,102,10,0,0,0,0,0,0,0,0,115,104,111,119,97,108,108,0,72,121,98,114,105,100,32,80,114,111,102,105,108,101,0,0,37,46,54,103,0,0,0,0,114,101,100,115,112,97,114,107,0,0,0,0,0,0,0,0,115,108,105,99,101,58,37,100,32,37,115,32,109,98,58,37,100,32,37,99,37,115,37,115,32,112,112,115,58,37,117,32,102,114,97,109,101,58,37,100,32,112,111,99,58,37,100,47,37,100,32,114,101,102,58,37,100,47,37,100,32,113,112,58,37,100,32,108,111,111,112,58,37,100,58,37,100,58,37,100,32,119,101,105,103,104,116,58,37,100,37,115,32,37,115,10,0,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,114,112,122,97,0,0,0,0,70,97,115,116,32,70,117,115,105,111,110,0,0,0,0,0,39,37,115,39,32,105,115,32,110,111,116,32,97,32,111,102,102,105,99,105,97,108,32,121,117,118,52,109,112,101,103,112,105,112,101,32,112,105,120,101,108,32,102,111,114,109,97,116,46,32,85,115,101,32,39,45,115,116,114,105,99,116,32,45,49,39,32,116,111,32,101,110,99,111,100,101,32,116,111,32,116,104,105,115,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,54,0,0,0,0,0,0,0,0,105,99,104,0,0,0,0,0,100,101,108,97,121,0,0,0,116,97,114,103,101,116,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,105,110,32,116,104,101,32,97,117,100,105,111,32,115,116,114,101,97,109,0,0,0,0,78,117,109,98,101,114,32,111,102,32,105,110,112,117,116,115,46,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,53,0,0,0,0,0,0,0,0,37,115,37,115,0,0,0,0,114,101,97,108,116,101,120,116,0,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,113,117,101,117,101,46,104,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,58,32,37,115,46,10,0,0,0,0,0,0,37,48,56,120,32,0,0,0,102,97,100,101,45,111,117,116,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,52,0,0,0,0,0,0,0,0,37,108,108,100,0,0,0,0,124,0,0,0,0,0,0,0,65,116,32,108,101,97,115,116,32,111,110,101,32,100,101,108,97,121,32,62,48,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,0,0,0,102,109,116,58,37,115,32,99,108,58,37,115,32,45,62,32,102,109,116,58,37,115,32,99,108,58,37,115,10,0,0,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,112,114,101,115,101,116,0,0,99,0,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,56,0,0,0,115,107,105,112,95,105,110,105,116,105,97,108,95,98,121,116,101,115,0,0,0,0,0,0,110,117,116,45,62,102,114,97,109,101,95,99,111,100,101,91,39,78,39,93,46,102,108,97,103,115,32,61,61,32,70,76,65,71,95,73,78,86,65,76,73,68,0,0,0,0,0,0,114,103,98,116,101,115,116,115,114,99,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,55,0,0,0,101,110,100,0,0,0,0,0,50,53,0,0,0,0,0,0,115,101,116,32,116,105,109,101,115,99,97,108,101,32,111,102,32,97,108,108,32,118,105,100,101,111,32,116,114,97,99,107,115,0,0,0,0,0,0,0,37,89,45,37,109,45,37,100,32,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,104,58,37,100,32,109,97,120,95,119,58,37,100,10,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,54,0,0,0,115,105,110,101,0,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,71,69,79,66,32,102,114,97,109,101,44,32,100,97,116,97,32,116,114,117,110,99,97,116,101,100,46,10,0,0,0,0,0,0,37,100,32,37,99,10,0,0,115,101,110,100,95,102,114,97,109,101,95,110,111,115,112,97,116,105,97,108,0,0,0,0,97,108,108,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,53,0,0,0,112,116,115,0,0,0,0,0,108,121,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,52,0,0,0,99,99,108,111,99,107,0,0,115,101,116,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,32,116,111,32,114,101,110,100,101,114,0,0,0,115,109,112,116,101,50,52,48,109,0,0,0,0,0,0,0,116,111,112,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,51,0,0,0,37,108,108,100,0,0,0,0,116,102,102,0,0,0,0,0,100,101,102,97,117,108,116,0,103,98,114,112,57,98,101,0,76,105,103,104,116,71,114,101,121,0,0,0,0,0,0,0,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,102,111,114,99,101,32,114,101,115,97,109,112,108,105,110,103,0,0,0,0,0,0,0,0,115,117,98,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,50,0,0,0,44,32,113,61,37,100,45,37,100,0,0,0,0,0,0,0,71,67,83,95,66,97,116,97,118,105,97,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,105,104,0,0,0,0,0,0,70,114,97,109,101,32,100,97,116,97,32,109,105,103,104,116,32,98,101,32,115,112,108,105,116,32,105,110,116,111,32,109,117,108,116,105,112,108,101,32,99,104,117,110,107,115,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,55,0,0,0,66,97,115,105,99,32,65,110,105,109,97,116,101,100,32,84,101,120,116,117,114,101,32,80,114,111,102,105,108,101,0,0,117,110,107,110,111,119,110,32,99,111,108,111,114,115,112,97,99,101,32,37,100,10,0,0,80,111,115,115,105,98,108,121,32,116,111,111,32,109,97,110,121,32,115,108,105,99,101,115,32,40,37,100,32,62,61,32,37,100,41,44,32,105,110,99,114,101,97,115,101,32,77,65,88,95,83,76,73,67,69,83,32,97,110,100,32,114,101,99,111,109,112,105,108,101,32,105,102,32,116,104,101,114,101,32,97,114,101,32,97,114,116,105,102,97,99,116,115,10,0,0,105,104,0,0,0,0,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,86,32,47,32,88,120,97,110,0,0,0,0,0,0,0,0,83,119,105,110,103,0,0,0,100,101,102,97,117,108,116,0,87,97,114,110,105,110,103,58,32,103,101,110,101,114,97,116,105,110,103,32,114,97,114,101,108,121,32,117,115,101,100,32,52,58,49,58,49,32,89,85,86,32,115,116,114,101,97,109,44,32,115,111,109,101,32,109,106,112,101,103,116,111,111,108,115,32,109,105,103,104,116,32,110,111,116,32,119,111,114,107,46,10,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,49,0,0,0,108,97,118,102,105,46,112,115,110,114,46,112,115,110,114,95,97,118,103,0,0,0,0,0,105,104,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,48,0,0,0,37,45,49,50,115,0,0,0,109,97,105,110,95,104,0,0,32,32,115,105,122,101,61,37,100,10,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,52,57,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,102,108,97,103,115,0,0,37,46,54,103,0,0,0,0,109,97,112,112,105,110,103,0,105,110,116,101,114,112,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,52,56,0,0,0,115,104,105,102,116,32,116,105,109,101,115,116,97,109,112,115,32,115,111,32,116,104,101,121,32,97,114,101,32,110,111,110,32,110,101,103,97,116,105,118,101,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,115,116,114,101,97,109,32,110,117,109,98,101,114,10,0,0,110,101,103,97,116,101,95,97,108,112,104,97,58,37,100,10,0,0,0,0,0,0,0,0,97,99,51,0,0,0,0,0,100,101,105,110,116,101,114,108,101,97,118,101,0,0,0,0,80,67,83,95,80,111,105,110,116,95,78,111,105,114,101,95,85,84,77,95,51,50,83,0,100,101,102,97,117,108,116,0,112,114,111,103,114,101,115,115,61,37,115,10,0,0,0,0,118,105,100,101,111,95,116,114,97,99,107,95,116,105,109,101,115,99,97,108,101,0,0,0,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,32,97,108,114,101,97,100,121,32,115,101,116,32,116,111,32,37,100,58,37,100,44,32,105,103,110,111,114,105,110,103,32,39,112,97,115,112,39,32,97,116,111,109,32,40,37,100,58,37,100,41,10,0,112,116,115,0,0,0,0,0,115,116,97,110,100,97,114,100,32,104,105,115,116,111,103,114,97,109,0,0,0,0,0,0,80,67,83,95,66,114,105,116,105,115,104,95,78,97,116,105,111,110,97,108,95,71,114,105,100,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,32,37,100,32,98,121,116,101,115,10,0,0,0,0,0,0,0,102,114,97,109,101,115,101,113,0,0,0,0,0,0,0,0,114,111,117,110,100,0,0,0,80,67,83,95,78,84,70,95,83,117,100,95,70,114,97,110,99,101,0,0,0,0,0,0,100,101,102,97,117,108,116,0,97,116,116,97,99,104,109,101,110,116,0,0,0,0,0,0,84,105,109,101,99,111,100,101,32,102,114,97,109,101,32,114,97,116,101,32,37,100,47,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,103,114,97,121,0,0,0,0,80,67,83,95,78,84,70,95,67,101,110,116,114,101,95,70,114,97,110,99,101,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,102,105,101,108,100,109,97,116,99,104,46,99,0,0,0,0,0,37,89,45,37,109,45,37,100,0,0,0,0,0,0,0,0,115,101,108,101,99,116,32,98,111,116,116,111,109,32,102,105,101,108,100,0,0,0,0,0,65,86,95,76,79,71,95,70,79,82,67,69,95,67,79,76,79,82,0,0,0,0,0,0,83,72,65,50,53,54,0,0,39,105,110,39,32,111,114,32,39,111,117,116,39,32,102,111,114,32,102,97,100,101,45,105,110,47,102,97,100,101,45,111,117,116,0,0,0,0,0,0,115,105,110,0,0,0,0,0,68,69,67,79,68,69,82,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,102,99,99,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,102,114,111,110,116,32,114,105,103,104,116,0,0,0,0,0,121,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,110,118,101,114,115,105,111,110,32,116,111,32,112,108,97,110,97,114,32,82,71,66,32,37,115,32,45,62,32,37,115,10,0,0,80,67,83,95,78,84,70,95,78,111,114,100,95,70,114,97,110,99,101,0,0,0,0,0,70,111,114,99,105,110,103,32,102,117,108,108,32,105,110,116,101,114,110,97,108,32,72,32,99,104,114,111,109,97,32,100,117,101,32,116,111,32,111,100,100,32,111,117,116,112,117,116,32,115,105,122,101,10,0,0,115,101,101,100,0,0,0,0,110,101,105,103,104,98,111,114,0,0,0,0,0,0,0,0,116,115,102,0,0,0,0,0,10,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,99,111,109,98,101,100,32,112,105,120,101,108,115,32,105,110,115,105,100,101,32,97,110,121,32,111,102,32,116,104,101,32,98,108,111,99,107,121,32,98,121,32,98,108,111,99,107,120,32,115,105,122,101,32,98,108,111,99,107,115,32,111,110,32,116,104,101,32,102,114,97,109,101,32,102,111,114,32,116,104,101,32,102,114,97,109,101,32,116,111,32,98,101,32,100,101,116,101,99,116,101,100,32,97,115,32,99,111,109,98,101,100,0,0,0,0,0,0,103,98,114,112,0,0,0,0,76,105,103,104,116,71,114,101,101,110,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,99,111,108,111,114,10,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,114,101,115,0,0,0,0,0,115,45,62,112,105,99,116,95,116,121,112,101,61,61,65,86,95,80,73,67,84,85,82,69,95,84,89,80,69,95,80,0,115,101,116,32,118,101,114,116,105,99,97,108,32,111,102,102,115,101,116,0,0,0,0,0,83,101,108,101,99,116,32,77,97,105,110,47,76,101,102,116,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,78,84,70,95,70,114,97,110,99,101,95,73,73,73,0,0,0,0,0,0,87,76,32,109,111,100,101,32,49,58,32,105,110,118,97,108,105,100,32,112,111,115,105,116,105,111,110,33,10,0,0,0,44,32,37,100,47,37,100,0,92,97,108,112,104,97,37,49,91,92,125,93,37,110,0,0,71,67,83,95,65,114,99,95,49,57,54,48,0,0,0,0,123,125,92,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,58,32,37,100,10,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,32,37,100,10,0,97,100,112,99,109,95,121,97,109,97,104,97,0,0,0,0,112,99,109,95,117,49,54,98,101,0,0,0,0,0,0,0,115,101,116,32,120,32,102,111,114,32,116,104,101,32,114,101,99,116,97,110,103,117,108,97,114,32,115,101,97,114,99,104,32,97,114,101,97,0,0,0,114,51,100,0,0,0,0,0,99,104,117,110,107,115,0,0,97,100,112,99,109,95,101,97,0,0,0,0,0,0,0,0,119,109,118,49,0,0,0,0,83,105,109,112,108,101,32,70,97,99,101,32,65,110,105,109,97,116,105,111,110,32,80,114,111,102,105,108,101,0,0,0,80,101,103,97,115,117,115,32,108,111,115,115,108,101,115,115,32,106,112,101,103,32,104,101,97,100,101,114,32,102,111,117,110,100,10,0,0,0,0,0,65,108,108,111,119,32,67,104,97,110,103,105,110,103,32,77,101,116,97,100,97,116,97,32,80,101,114,45,70,114,97,109,101,0,0,0,0,0,0,0,65,108,108,111,119,32,67,104,97,110,103,105,110,103,32,77,101,116,97,100,97,116,97,32,80,101,114,45,70,114,97,109,101,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,105,120,105,110,103,32,108,101,118,101,108,46,32,109,117,115,116,32,98,101,32,98,101,116,119,101,101,110,32,56,48,100,66,32,97,110,100,32,49,49,49,100,66,10,0,0,0,68,101,98,108,111,99,107,105,110,103,32,115,119,105,116,99,104,101,100,32,105,110,115,105,100,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,100,109,105,120,95,109,111,100,101,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,58,32,37,100,10,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,114,111,102,105,108,101,32,37,100,10,0,120,97,110,95,119,99,52,0,99,104,97,110,110,101,108,32,101,108,101,109,101,110,116,32,37,100,46,37,100,32,105,115,32,110,111,116,32,97,108,108,111,99,97,116,101,100,10,0,56,83,86,88,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,109,111,114,101,32,116,104,97,110,32,50,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,78,97,116,105,111,110,97,108,32,70,111,108,107,0,0,0,69,82,82,79,82,58,32,79,110,108,121,32,114,97,119,118,105,100,101,111,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,80,67,83,95,78,84,70,95,70,114,97,110,99,101,95,73,73,0,0,0,0,0,0,0,101,120,112,114,0,0,0,0,115,105,122,101,115,32,105,110,118,97,108,105,100,10,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,69,114,114,111,114,33,32,71,111,116,32,110,111,32,102,111,114,109,97,116,32,111,114,32,110,111,32,107,101,121,102,114,97,109,101,33,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,118,97,108,105,100,32,112,105,120,109,97,112,32,100,101,112,116,104,10,0,0,0,91,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,51,100,45,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,51,100,93,0,0,0,0,0,0,0,113,99,112,0,0,0,0,0,10,13,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,119,109,118,50,0,0,0,0,115,45,62,115,117,98,102,114,97,109,101,95,108,101,110,32,60,61,32,40,49,32,60,60,32,49,51,41,0,0,0,0,69,120,112,101,99,116,32,119,114,111,110,103,32,111,117,116,112,117,116,32,115,105,110,99,101,32,105,110,118,101,114,115,101,32,76,80,67,32,102,105,108,116,101,114,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,119,109,97,101,110,99,46,99,0,0,0,0,0,108,101,110,32,37,100,32,105,110,118,97,108,105,100,10,0,123,92,105,48,125,0,0,0,69,88,73,70,32,99,104,117,110,107,32,112,114,101,115,101,110,116,44,32,98,117,116,32,69,120,105,102,32,98,105,116,32,110,111,116,32,115,101,116,32,105,110,32,116,104,101,32,86,80,56,88,32,104,101,97,100,101,114,10,0,0,0,0,71,111,116,32,105,110,99,111,114,114,101,99,116,32,98,108,111,99,107,32,37,48,50,88,32,119,105,116,104,32,115,105,122,101,32,37,105,10,0,0,112,114,111,98,108,101,109,58,32,102,111,117,110,100,32,98,111,116,104,32,67,66,80,48,32,97,110,100,32,67,66,80,90,32,99,104,117,110,107,115,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,109,97,114,107,101,114,10,0,0,0,85,110,115,112,101,99,105,102,105,101,100,32,99,111,108,111,114,115,112,97,99,101,10,0,112,111,105,110,116,45,62,110,101,120,116,0,0,0,0,0,32,86,80,51,32,37,115,102,114,97,109,101,32,35,37,100,58,32,81,32,105,110,100,101,120,32,61,32,37,100,10,0,33,40,112,115,105,122,101,32,37,32,98,111,111,107,45,62,110,100,105,109,101,110,115,105,111,110,115,41,0,0,0,0,112,118,102,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,111,114,98,105,115,100,101,99,46,99,0,0,73,110,118,97,108,105,100,32,83,101,116,117,112,32,104,101,97,100,101,114,10,0,0,0,73,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,115,105,122,101,58,32,37,105,120,37,105,43,37,105,120,37,105,32,111,102,32,37,105,120,37,105,10,0,0,0,0,0,97,118,99,116,120,45,62,98,108,111,99,107,95,97,108,105,103,110,32,42,32,115,105,108,101,110,116,95,99,104,117,110,107,115,32,60,61,32,102,114,97,109,101,45,62,110,98,95,115,97,109,112,108,101,115,32,42,32,97,118,99,116,120,45,62,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,69,114,114,111,114,32,105,110,32,87,86,67,49,32,105,110,116,101,114,108,97,99,101,100,32,102,114,97,109,101,10,0,80,67,83,95,78,84,70,95,70,114,97,110,99,101,95,73,0,0,0,0,0,0,0,0,112,114,101,115,101,116,32,110,97,109,101,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,112,114,105,116,101,32,102,101,97,116,117,114,101,10,0,0,0,0,0,105,104,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,67,97,110,110,111,116,32,98,117,105,108,100,32,72,117,102,102,109,97,110,32,99,111,100,101,115,10,0,0,0,0,0,32,32,112,116,115,61,0,0,73,110,118,97,108,105,100,32,119,105,110,100,111,119,32,116,121,112,101,44,32,98,114,111,107,101,110,32,115,97,109,112,108,101,63,10,0,0,0,0,114,97,0,0,0,0,0,0,73,110,118,97,108,105,100,47,117,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,46,10,0,0,0,0,0,78,111,110,45,115,107,105,112,32,114,111,119,32,119,105,116,104,32,122,101,114,111,32,115,105,122,101,10,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,116,111,107,101,110,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,73,110,116,101,114,112,111,108,97,116,101,100,32,102,114,97,109,101,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,116,105,102,102,101,110,99,46,99,0,0,0,0,80,67,83,95,65,84,70,95,78,111,114,100,95,100,101,95,71,117,101,114,114,101,0,0,112,118,97,0,0,0,0,0,114,109,0,0,0,0,0,0,97,110,117,108,108,115,114,99,0,0,0,0,0,0,0,0,78,79,80,84,83,0,0,0,112,115,120,115,116,114,0,0,71,101,111,103,76,105,110,101,97,114,85,110,105,116,83,105,122,101,71,101,111,75,101,121,0,0,0,0,0,0,0,0,44,32,0,0,0,0,0,0,73,109,97,103,101,32,100,97,116,97,32,115,105,122,101,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,0,115,117,98,118,105,101,119,101,114,49,32,100,101,99,111,100,101,114,0,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,97,118,97,105,108,97,98,108,101,32,102,111,114,32,105,109,97,103,101,10,0,0,0,0,111,118,101,114,114,101,97,100,10,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,112,114,101,0,0,0,0,0,80,67,83,95,68,97,116,117,109,95,55,51,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,0,0,0,0,0,108,117,109,97,32,112,114,101,100,105,99,116,105,111,110,58,37,100,10,0,0,0,0,0,105,110,118,97,108,105,100,32,100,101,112,116,104,10,0,0,116,97,103,32,115,116,97,99,107,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,123,92,97,110,49,125,123,92,112,111,115,40,37,100,44,37,100,41,125,0,0,0,0,0,78,111,32,109,97,110,100,97,116,111,114,121,32,104,101,97,100,101,114,115,32,112,114,101,115,101,110,116,10,0,0,0,65,100,118,97,110,99,101,100,32,112,101,114,45,102,105,108,101,32,111,112,116,105,111,110,115,58,0,0,0,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,32,115,112,97,99,101,10,0,0,0,0,0,0,0,0,83,77,86,74,80,69,71,32,100,101,99,111,100,101,114,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,112,105,120,101,108,95,98,108,97,99,107,95,116,104,0,0,109,97,107,101,95,110,111,110,95,110,101,103,97,116,105,118,101,0,0,0,0,0,0,0,115,97,109,112,108,101,32,102,111,114,109,97,116,32,109,105,115,109,97,116,99,104], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1903238);
/* memory initializer */ allocate([10,0,77,111,100,101,58,32,37,115,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,76,69,32,98,117,102,102,101,114,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,60,66,82,0,0,0,0,0,83,105,122,101,32,109,105,115,109,97,116,99,104,10,0,0,108,97,118,102,105,46,98,98,111,120,46,120,50,0,0,0,114,112,114,32,116,111,111,32,108,97,114,103,101,10,0,0,114,118,50,48,0,0,0,0,67,79,85,78,84,32,69,82,82,79,82,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,105,108,108,101,103,97,108,32,99,111,117,110,116,32,37,100,32,97,116,32,37,100,10,0,105,67,111,117,110,116,0,0,68,101,99,111,100,101,114,39,115,32,115,116,111,109,97,99,104,32,105,115,32,99,114,121,105,110,103,44,32,105,116,32,97,116,101,32,116,111,111,32,109,97,110,121,32,115,97,109,112,108,101,115,10,0,0,0,102,97,105,108,101,100,32,116,111,32,115,101,101,107,32,116,111,32,108,97,115,116,32,112,97,114,116,105,116,105,111,110,32,64,32,48,120,37,108,108,120,32,40,37,108,108,100,41,32,45,32,112,97,114,116,105,97,108,32,102,105,108,101,63,10,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,98,97,100,32,112,97,99,107,101,116,32,99,104,101,99,107,115,117,109,10,0,0,0,0,70,114,97,109,101,32,35,37,100,44,32,73,70,81,58,32,37,115,10,0,0,0,0,0,121,101,115,0,0,0,0,0,101,110,99,111,100,105,110,103,32,119,105,116,104,32,80,114,111,82,101,115,32,115,116,97,110,100,97,114,100,32,40,97,112,99,110,41,32,112,114,111,102,105,108,101,10,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,108,105,99,101,115,10,0,0,0,0,0,0,0,101,114,114,111,114,44,32,119,114,111,110,103,32,112,105,99,116,117,114,101,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,0,0,0,112,109,112,0,0,0,0,0,112,98,109,0,0,0,0,0,97,108,112,104,97,0,0,0,112,97,109,0,0,0,0,0,100,112,105,0,0,0,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,115,105,122,101,10,0,0,0,0,0,116,111,111,32,109,117,99,104,32,82,76,69,32,100,97,116,97,10,0,0,0,0,0,0,101,120,112,101,99,116,101,100,32,112,97,108,101,116,116,101,32,97,102,116,101,114,32,105,109,97,103,101,32,100,97,116,97,10,0,0,0,0,0,0,80,67,83,95,71,68,52,57,95,83,111,117,116,104,95,73,115,108,97,110,100,95,71,114,105,100,0,0,0,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,114,101,115,101,114,118,101,100,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,40,37,100,41,10,0,0,0,0,37,115,32,32,32,32,13,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,84,105,109,101,115,116,97,109,112,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,32,112,97,115,115,101,100,0,0,0,0,0,117,115,101,32,101,100,105,116,32,108,105,115,116,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,102,105,101,108,100,32,115,105,122,101,32,37,100,10,0,0,0,112,106,115,0,0,0,0,0,115,116,114,101,97,109,95,105,110,100,101,120,0,0,0,0,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,10,0,0,0,0,78,111,110,45,107,101,121,32,102,114,97,109,101,32,104,97,115,32,110,111,32,77,88,77,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,98,117,102,102,101,114,32,110,111,116,32,102,117,108,108,121,32,99,111,110,115,117,109,101,100,10,0,0,0,0,0,0,68,105,115,112,108,97,121,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,0,0,0,0,0,0,77,83,32,82,76,69,58,32,101,110,100,101,100,32,102,114,97,109,101,32,100,101,99,111,100,101,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,108,101,102,116,32,111,118,101,114,10,0,0,0,0,0,80,67,83,95,71,68,52,57,95,78,111,114,116,104,95,73,115,108,97,110,100,95,71,114,105,100,0,0,0,0,0,0,13,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,32,37,122,117,32,98,121,116,101,115,10,0,0,0,0,0,0,99,98,112,95,114,100,0,0,84,66,58,37,102,32,70,82,65,77,69,95,82,65,84,69,58,37,102,32,83,65,77,80,76,69,95,82,65,84,69,58,37,102,10,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,111,110,116,101,120,116,32,115,99,114,97,116,99,104,32,98,117,102,102,101,114,115,46,10,0,0,0,0,83,97,109,112,108,105,110,103,32,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,83,97,109,112,108,105,110,103,32,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,109,112,51,97,100,117,102,108,111,97,116,0,0,0,0,0,109,112,51,97,100,117,0,0,85,115,101,32,100,97,116,97,32,112,97,114,116,105,116,105,111,110,105,110,103,46,0,0,66,97,100,32,40,101,109,112,116,121,63,41,32,108,97,98,101,108,32,102,111,117,110,100,32,105,110,32,116,104,101,32,102,111,108,108,111,119,105,110,103,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,109,97,114,107,101,114,32,109,105,115,115,105,110,103,32,97,102,116,101,114,32,102,105,114,115,116,32,73,32,112,97,114,116,105,116,105,111,110,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,109,112,101,103,50,118,105,100,101,111,32,101,110,99,111,100,101,114,0,0,0,0,0,0,83,78,82,32,83,99,97,108,97,98,108,101,0,0,0,0,84,111,111,32,109,97,110,121,32,98,97,110,100,115,58,32,37,105,10,0,0,0,0,0,80,67,83,95,71,68,52,57,95,78,90,95,77,97,112,95,71,114,105,100,0,0,0,0,73,110,100,105,99,97,116,101,100,32,101,110,100,32,111,102,102,115,101,116,32,111,102,32,115,117,98,115,116,114,101,97,109,32,37,100,32,100,97,116,97,32,105,115,32,115,109,97,108,108,101,114,32,116,104,97,110,32,99,97,108,99,117,108,97,116,101,100,32,115,116,97,114,116,32,111,102,102,115,101,116,46,10,0,0,0,0,0,65,77,86,32,86,105,100,101,111,0,0,0,0,0,0,0,108,111,119,114,101,115,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,32,119,105,116,104,32,108,111,115,115,108,101,115,115,32,106,112,101,103,10,0,0,0,0,0,0,100,104,116,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,0,0,0,0,0,0,123,92,99,125,0,0,0,0,114,101,113,117,101,115,116,95,115,97,109,112,108,101,115,32,99,104,97,110,103,101,100,32,98,101,102,111,114,101,32,116,104,101,32,98,117,102,102,101,114,32,119,97,115,32,114,101,116,117,114,110,101,100,46,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,108,111,114,115,112,97,99,101,44,32,105,110,100,101,120,32,61,32,37,105,10,0,49,46,50,46,53,0,0,0,100,101,102,97,117,108,116,0,66,85,71,33,32,85,110,107,110,111,119,110,32,77,83,90,72,32,99,111,109,112,114,101,115,115,105,111,110,32,105,110,32,102,114,97,109,101,32,100,101,99,111,100,101,114,46,10,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,122,101,114,111,115,32,114,101,109,97,105,110,105,110,103,46,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,74,80,69,71,45,76,83,0,104,101,105,103,104,116,32,60,61,32,54,52,0,0,0,0,123,92,97,110,49,125,0,0,116,105,101,114,50,10,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,98,97,110,100,32,104,101,97,100,101,114,58,32,37,100,10,0,0,0,32,77,81,0,0,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,65,10,0,73,110,118,97,108,105,100,32,97,115,112,101,99,116,32,114,97,116,105,111,46,10,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,58,32,37,100,32,10,0,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,32,115,105,122,101,33,10,0,0,0,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,0,0,80,67,83,95,78,97,112,97,114,105,109,97,95,85,84,77,95,50,48,78,0,0,0,0,115,99,97,108,101,102,97,99,116,111,114,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,0,0,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,62,32,56,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,105,32,60,32,40,49,32,60,60,32,49,49,41,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,118,112,115,95,109,97,120,95,110,117,109,95,114,101,111,114,100,101,114,95,112,105,99,115,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,10,0,0,0,0,0,0,0,114,111,119,95,105,110,116,101,114,108,101,97,118,101,100,95,108,114,0,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,112,105,99,116,117,114,101,44,32,100,101,102,97,117,108,116,32,105,115,32,37,100,10,0,0,0,0,0,0,0,84,66,0,0,0,0,0,0,105,108,108,101,103,97,108,32,80,79,67,32,116,121,112,101,32,37,100,10,0,0,0,0,99,98,112,32,116,111,111,32,108,97,114,103,101,32,40,37,117,41,32,97,116,32,37,100,32,37,100,10,0,0,0,0,98,116,55,48,57,0,0,0,68,101,99,111,100,105,110,103,32,112,112,115,32,37,100,32,102,114,111,109,32,97,118,99,67,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,80,67,83,95,78,97,104,114,119,97,110,95,49,57,54,55,95,85,84,77,95,52,48,78,0,0,0,0,0,0,0,0,104,50,54,51,0,0,0,0,105,108,108,101,103,97,108,32,109,98,97,32,97,116,32,37,100,32,37,100,10,0,0,0,76,90,87,32,100,101,99,111,100,101,32,102,97,105,108,101,100,10,0,0,0,0,0,0,71,73,70,32,101,110,99,111,100,101,114,0,0,0,0,0,114,111,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,112,111,115,116,102,105,108,116,101,114,0,0,0,0,0,0,97,110,117,108,108,115,105,110,107,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,37,100,10,0,0,99,104,97,110,103,101,95,102,105,101,108,100,95,111,114,100,101,114,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,112,108,97,110,101,32,37,105,10,0,0,0,0,0,0,0,0,112,105,120,101,108,95,99,111,117,110,116,100,111,119,110,32,60,32,48,32,40,37,100,41,32,97,116,32,108,105,110,101,32,37,100,10,0,0,0,0,71,101,110,101,114,97,116,101,100,32,100,101,102,97,117,108,116,32,112,97,108,101,116,116,101,10,0,0,0,0,0,0,67,97,110,110,111,116,32,100,101,116,101,114,109,105,110,101,32,100,101,102,108,97,116,101,32,98,117,102,102,101,114,32,115,105,122,101,46,10,0,0,105,110,118,97,108,105,100,32,112,97,114,116,105,116,105,111,110,32,111,114,100,101,114,115,58,32,109,105,110,61,37,100,32,109,97,120,61,37,100,10,0,0,0,0,0,0,0,0,80,97,114,97,109,101,116,101,114,115,32,102,111,114,32,105,110,112,117,116,32,108,105,110,107,32,37,115,32,40,115,105,122,101,32,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,32,100,111,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,111,117,116,112,117,116,32,108,105,110,107,32,112,97,114,97,109,101,116,101,114,115,32,40,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,10,0,0,111,118,101,114,114,101,97,100,58,32,37,100,10,0,0,0,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,32,99,104,97,110,103,101,32,100,101,116,101,99,116,101,100,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,0,0,0,0,101,120,116,114,97,100,97,116,97,32,78,85,76,76,32,111,114,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,115,108,105,99,101,32,100,97,116,97,46,10,0,98,121,116,101,115,32,60,32,40,49,32,60,60,32,50,52,41,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,99,111,109,98,112,101,108,0,77,105,120,105,110,103,32,76,101,118,101,108,0,0,0,0,118,100,97,95,118,108,100,0,83,108,105,99,101,32,115,105,122,101,115,32,109,105,115,109,97,116,99,104,58,32,103,111,116,32,37,100,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,0,0,0,0,76,105,103,104,116,71,111,108,100,101,110,82,111,100,89,101,108,108,111,119,0,0,0,0,85,110,107,110,111,119,110,32,111,112,99,111,100,101,32,37,100,10,0,0,0,0,0,0,86,97,108,117,101,32,37,100,32,102,111,114,32,112,97,114,97,109,101,116,101,114,32,39,37,115,39,32,111,117,116,32,111,102,32,37,115,32,102,111,114,109,97,116,32,114,97,110,103,101,32,91,37,100,32,45,32,37,100,93,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,105,122,101,58,0,0,0,68,86,66,83,117,98,32,101,114,114,111,114,58,32,108,105,110,101,32,111,118,101,114,102,108,111,119,10,0,0,0,0,83,105,110,103,108,101,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,46,42,115,39,32,105,115,32,105,110,116,101,114,112,114,101,116,101,100,32,97,115,32,97,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,44,32,115,119,105,116,99,104,32,116,111,32,116,104,101,32,115,121,110,116,97,120,32,39,37,46,42,115,99,39,32,111,116,104,101,114,119,105,115,101,32,105,116,32,119,105,108,108,32,98,101,32,105,110,116,101,114,112,114,101,116,101,100,32,97,115,32,97,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,110,117,109,98,101,114,32,105,110,32,97,32,108,97,116,101,114,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,0,78,101,105,116,104,101,114,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,110,111,114,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,0,0,0,115,119,114,95,102,108,97,103,115,0,0,0,0,0,0,0,68,101,115,99,114,105,112,116,111,114,32,37,100,0,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,100,110,120,104,100,101,110,99,46,99,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,105,100,32,37,100,10,0,0,0,0,0,110,117,109,95,114,101,102,115,32,111,102,32,51,10,0,0,109,97,105,110,0,0,0,0,84,68,76,84,0,0,0,0,117,115,101,100,95,97,98,105,116,115,32,33,61,32,49,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,88,67,104,32,101,120,116,101,110,115,105,111,110,10,0,0,0,80,67,83,95,78,97,104,114,119,97,110,95,49,57,54,55,95,85,84,77,95,51,57,78,0,0,0,0,0,0,0,0,68,101,99,111,100,101,100,32,100,97,116,97,32,101,120,99,101,101,100,101,100,32,108,105,110,101,115,105,122,101,33,10,0,0,0,0,0,0,0,0,100,101,99,111,117,112,108,101,32,118,97,108,117,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,32,91,83,65,82,32,37,100,58,37,100,32,68,65,82,32,37,100,58,37,100,93,0,0,71,67,83,95,65,114,99,95,49,57,53,48,0,0,0,0,66,117,102,102,101,114,32,118,105,100,101,111,32,102,114,97,109,101,115,44,32,97,110,100,32,109,97,107,101,32,116,104,101,109,32,97,118,97,105,108,97,98,108,101,32,116,111,32,116,104,101,32,101,110,100,32,111,102,32,116,104,101,32,102,105,108,116,101,114,32,103,114,97,112,104,46,0,0,0,0,112,108,97,99,101,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,32,97,116,32,101,118,101,114,121,32,107,101,121,102,114,97,109,101,32,105,110,115,116,101,97,100,32,111,102,32,105,110,32,101,120,116,114,97,100,97,116,97,0,0,83,99,97,108,97,98,108,101,32,84,101,120,116,117,114,101,32,80,114,111,102,105,108,101,0,0,0,0,0,0,0,0,104,50,54,51,0,0,0,0,67,97,110,110,111,116,32,112,97,114,97,108,108,101,108,105,122,101,32,100,101,98,108,111,99,107,105,110,103,32,116,121,112,101,32,49,44,32,100,101,99,111,100,105,110,103,32,115,117,99,104,32,102,114,97,109,101,115,32,105,110,32,115,101,113,117,101,110,116,105,97,108,32,111,114,100,101,114,10,0,84,111,111,32,109,97,110,121,32,86,76,67,115,32,40,37,100,41,32,116,111,32,98,101,32,114,101,97,100,46,10,0,109,97,120,95,101,120,116,114,97,95,99,98,95,105,116,101,114,97,116,105,111,110,115,0,73,110,118,97,108,105,100,32,109,98,95,116,121,112,101,32,37,100,32,105,110,32,66,32,102,114,97,109,101,10,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,100,97,116,97,10,0,0,0,83,99,114,101,101,110,32,111,102,102,115,101,116,32,100,97,116,97,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,66,77,80,32,104,101,97,100,101,114,10,0,0,0,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,73,73,32,47,32,88,97,110,0,0,0,0,0,0,0,0,110,101,101,100,101,100,32,37,100,32,104,97,100,32,37,100,10,0,0,0,0,0,0,0,82,117,110,32,118,97,108,117,101,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,70,111,108,107,45,82,111,99,107,0,0,0,0,0,0,0,112,105,99,107,105,110,103,32,37,115,32,111,117,116,32,111,102,32,37,100,32,114,101,102,58,37,115,32,97,108,112,104,97,58,37,100,10,0,0,0,37,115,32,87,37,100,32,72,37,100,32,70,37,100,58,37,100,32,73,37,99,32,65,37,100,58,37,100,37,115,10,0,80,67,83,95,78,97,104,114,119,97,110,95,49,57,54,55,95,85,84,77,95,51,56,78,0,0,0,0,0,0,0,0,91,48,45,49,93,32,37,100,10,0,0,0,0,0,0,0,37,100,44,37,108,100,44,37,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,99,111,117,110,116,58,32,37,117,46,10,0,0,0,0,0,0,68,97,109,97,103,101,100,32,99,104,97,110,110,101,108,32,100,97,116,97,46,10,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,99,104,101,99,107,101,114,98,111,97,114,100,95,114,108,0,84,68,65,84,0,0,0,0,74,97,122,122,0,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,100,97,116,97,46,10,0,0,0,87,77,47,67,111,109,112,111,115,101,114,0,0,0,0,0,86,105,100,101,111,32,115,111,117,114,99,101,32,102,105,108,116,101,114,115,32,109,117,115,116,32,115,101,116,32,116,104,101,105,114,32,111,117,116,112,117,116,32,108,105,110,107,39,115,32,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,10,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,67,79,77,77,32,116,97,103,32,111,114,32,105,110,118,97,108,105,100,32,98,108,111,99,107,95,97,108,105,103,110,32,118,97,108,117,101,10,0,0,0,83,99,97,108,97,98,108,101,32,99,111,110,102,105,103,117,114,97,116,105,111,110,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,68,84,83,10,0,0,0,0,0,0,0,0,52,50,48,112,49,54,0,0,100,112,100,115,32,99,104,117,110,107,32,115,105,122,101,32,37,108,108,100,32,105,110,118,97,108,105,100,10,0,0,0,120,111,98,88,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,111,117,114,105,95,87,101,115,116,0,37,45,49,50,115,37,115,10,0,0,0,0,0,0,0,0,37,48,46,51,102,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,111,117,114,105,95,67,101,110,116,114,97,108,0,0,0,0,0,0,32,45,62,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,100,116,115,58,37,115,32,100,116,115,95,116,105,109,101,58,37,115,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,111,117,114,105,95,69,97,115,116,0,109,97,107,101,95,122,101,114,111,0,0,0,0,0,0,0,102,54,52,98,101,0,0,0,116,105,109,101,32,98,97,115,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,102,105,108,101,32,105,115,32,110,111,116,32,115,101,101,107,97,98,108,101,32,45,32,110,111,116,32,112,97,114,115,105,110,103,32,108,97,115,116,32,112,97,114,116,105,116,105,111,110,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,105,115,115,105,112,112,105,95,87,101,115,116,0,0,0,0,0,0,100,114,111,112,95,102,114,97,109,101,115,61,37,100,10,0,117,115,101,95,101,100,105,116,108,105,115,116,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,95,99,111,117,110,116,61,37,100,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,105,115,115,105,112,112,105,95,69,97,115,116,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,100,101,115,99,114,105,112,116,105,111,110,46,10,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,110,110,101,115,111,116,97,95,83,111,117,116,104,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,110,110,101,115,111,116,97,95,67,101,110,116,0,0,0,0,0,0,0,0,98,116,54,48,49,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,110,110,101,115,111,116,97,95,78,111,114,116,104,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,121,45,97,120,105,115,32,115,105,122,101,32,111,102,32,116,104,101,32,119,105,110,100,111,119,32,117,115,101,100,32,100,117,114,105,110,103,32,99,111,109,98,101,100,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,0,0,0,0,121,117,118,52,50,50,112,57,108,101,0,0,0,0,0,0,76,105,103,104,116,67,121,97,110,0,0,0,0,0,0,0,100,111,119,110,109,105,120,0,115,101,116,32,102,108,97,103,115,0,0,0,0,0,0,0,97,117,116,111,115,101,108,101,99,116,105,111,110,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,99,104,105,103,97,110,95,83,111,117,116,104,0,0,0,0,0,0,0,0,44,32,37,100,120,37,100,0,71,67,83,95,65,114,97,116,117,0,0,0,0,0,0,0,108,111,99,97,108,95,104,101,97,100,101,114,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,51,0,0,0,0,0,0,0,78,45,98,105,116,32,80,114,111,102,105,108,101,0,0,0,109,106,112,101,103,58,32,65,100,111,98,101,32,104,101,97,100,101,114,32,102,111,117,110,100,44,32,116,114,97,110,115,102,111,114,109,61,37,100,10,0,0,0,0,0,0,0,0,100,101,98,108,111,99,107,105,110,103,32,102,105,108,116,101,114,32,112,97,114,97,109,101,116,101,114,115,32,37,100,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,0,0,0,120,97,110,95,119,99,51,0,70,111,108,107,0,0,0,0,32,67,52,52,52,112,49,54,32,88,89,83,67,83,83,61,52,52,52,80,49,54,0,0,80,67,83,95,78,65,68,56,51,95,77,105,99,104,105,103,97,110,95,67,101,110,116,114,97,108,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,99,104,105,103,97,110,95,78,111,114,116,104,0,0,0,0,0,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,0,0,0,99,111,100,101,99,0,0,0,32,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,105,110,102,111,32,115,105,122,101,32,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,32,32,100,116,115,61,0,0,115,101,108,101,99,116,32,100,105,115,112,108,97,121,32,109,111,100,101,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,104,117,110,107,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,73,115,0,0,0,0,0,0,115,116,114,101,97,109,58,37,100,32,115,116,97,114,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,100,116,115,58,37,115,32,100,116,115,95,116,105,109,101,58,37,115,0,0,0,0,0,0,0,32,37,46,42,115,0,0,0,10,9,32,0,0,0,0,0,116,105,116,108,101,0,0,0,99,111,100,101,99,32,110,97,109,101,0,0,0,0,0,0,78,79,78,69,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,115,115,97,99,104,117,115,101,116,116,115,0,100,111,32,110,111,116,32,99,104,97,110,103,101,32,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,0,0,69,114,114,111,114,32,110,117,116,45,62,116,105,109,101,95,98,97,115,101,91,105,93,46,100,101,110,32,105,115,32,40,37,108,108,100,41,10,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,105,116,101,109,95,110,117,109,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,67,79,77,77,32,116,97,103,32,110,111,116,32,102,111,117,110,100,33,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,114,121,108,97,110,100,0,0,0,0,0,0,100,117,112,95,102,114,97,109,101,115,61,37,100,10,0,0,78,117,109,98,101,114,32,111,102,32,108,111,111,107,97,104,101,97,100,32,101,110,116,114,105,101,115,32,102,111,114,32,73,83,77,32,102,105,108,101,115,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,73,110,118,97,108,105,100,32,83,97,109,112,108,101,68,101,108,116,97,32,37,100,32,105,110,32,83,84,84,83,44,32,97,116,32,37,100,32,115,116,58,37,100,10,0,0,0,0,102,54,52,98,101,0,0,0,109,105,115,115,105,110,103,32,99,111,108,111,110,32,105,110,32,107,101,121,58,118,97,108,117,101,32,112,97,105,114,32,39,37,115,39,10,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,105,110,101,95,87,101,115,116,0,0,0,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,116,121,112,101,32,37,100,46,10,0,0,0,0,0,0,112,97,102,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,105,110,101,95,69,97,115,116,0,0,0,0,115,101,116,32,115,108,105,100,105,110,103,32,109,111,100,101,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,76,111,117,105,115,105,97,110,97,95,83,111,117,116,104,0,0,0,0,0,0,0,97,117,100,105,111,47,97,97,99,112,0,0,0,0,0,0,111,118,115,117,98,0,0,0,33,34,114,101,97,99,104,101,100,34,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,76,111,117,105,115,105,97,110,97,95,78,111,114,116,104,0,0,0,0,0,0,0,83,101,101,107,32,116,97,98,108,101,32,67,82,67,32,101,114,114,111,114,10,0,0,0,98,108,111,99,107,121,0,0,121,117,118,52,50,50,112,57,98,101,0,0,0,0,0,0,76,105,103,104,116,67,111,114,97,108,0,0,0,0,0,0,111,99,116,97,103,111,110,97,108,0,0,0,0,0,0,0,102,108,97,103,115,0,0,0,32,98,115,102,115,58,0,0,97,117,116,111,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,75,101,110,116,117,99,107,121,95,83,111,117,116,104,0,0,0,0,0,0,0,0,37,115,41,0,0,0,0,0,101,110,99,111,100,101,114,32,118,101,114,115,105,111,110,58,32,37,48,88,10,0,0,0,71,67,83,95,76,105,115,98,111,110,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,115,119,102,101,110,99,46,99,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,105,103,110,111,114,101,32,99,114,111,112,112,105,110,103,32,105,110,102,111,114,109,97,116,105,111,110,32,102,114,111,109,32,115,112,115,0,0,0,0,109,115,109,112,101,103,52,0,48,0,0,0,0,0,0,0,77,97,105,110,32,80,114,111,102,105,108,101,0,0,0,0,104,97,114,100,119,97,114,101,32,97,99,99,101,108,101,114,97,116,111,114,32,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,112,105,99,116,117,114,101,10,0,0,91,70,79,78,84,93,0,0,100,101,98,108,111,99,107,105,110,103,95,102,105,108,116,101,114,95,105,100,99,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,42,42,42,42,42,42,42,42,32,83,84,65,82,84,32,83,67,82,73,80,84,32,42,42,42,42,42,42,42,42,0,0,73,110,116,101,114,112,108,97,121,32,77,86,69,32,118,105,100,101,111,0,0,0,0,0,72,97,114,100,32,82,111,99,107,0,0,0,0,0,0,0,32,67,52,50,50,112,49,54,32,88,89,83,67,83,83,61,52,50,50,80,49,54,0,0,80,67,83,95,78,65,68,56,51,95,75,101,110,116,117,99,107,121,95,78,111,114,116,104,0,0,0,0,0,0,0,0,10,10,0,0,0,0,0,0,111,117,116,58,37,99,37,100,0,0,0,0,0,0,0,0,37,105,32,115,97,109,112,108,101,115,32,105,110,32,65,65,67,32,102,114,97,109,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,80,67,83,95,78,65,68,56,51,95,75,97,110,115,97,115,95,83,111,117,116,104,0,0,37,99,37,99,37,99,37,99,37,99,32,37,45,49,54,115,32,32,32,32,32,32,32,37,100,32,32,32,32,32,32,32,32,32,32,32,32,37,50,100,10,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,37,115,32,102,111,114,32,119,114,105,116,105,110,103,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,97,117,100,105,111,32,115,116,114,101,97,109,115,0,0,32,32,100,117,114,97,116,105,111,110,61,37,48,46,51,102,10,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,104,101,97,100,101,114,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,10,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,75,97,110,115,97,115,95,78,111,114,116,104,0,0,115,101,103,109,101,110,116,58,39,37,115,39,32,115,116,97,114,116,115,32,119,105,116,104,32,112,97,99,107,101,116,32,115,116,114,101,97,109,58,37,100,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,102,114,97,109,101,58,37,100,10,0,0,115,101,103,109,101,110,116,95,102,111,114,109,97,116,0,0,80,67,83,95,78,65,68,56,51,95,73,111,119,97,95,83,111,117,116,104,0,0,0,0,100,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,108,105,115,115,97,106,111,117,115,95,120,121,0,0,0,0,69,114,114,111,114,32,110,117,116,45,62,116,105,109,101,95,98,97,115,101,91,105,93,46,110,117,109,32,105,115,32,40,37,108,108,100,41,10,0,0,80,114,105,109,101,114,32,112,97,99,107,32,105,116,101,109,32,108,101,110,103,116,104,32,37,100,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,111,119,97,95,78,111,114,116,104,0,0,0,0,32,100,117,112,61,37,100,32,100,114,111,112,61,37,100,0,82,101,99,117,114,115,105,111,110,32,108,111,111,112,32,111,110,32,34,37,46,42,115,34,10,0,0,0,0,0,0,0,105,115,109,95,108,111,111,107,97,104,101,97,100,0,0,0,99,111,109,109,101,110,116,0,50,55,48,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,110,100,105,97,110,97,95,87,101,115,116,0,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,109,105,109,101,116,121,112,101,58,32,37,115,44,32,115,107,105,112,112,105,110,103,46,10,0,0,0,0,0,0,0,67,97,110,110,111,116,32,114,101,115,112,101,99,116,32,109,97,120,32,100,101,108,97,121,58,32,102,114,97,109,101,32,115,105,122,101,32,61,32,48,10,0,0,0,0,0,0,0,68,111,110,39,116,32,107,110,111,119,32,104,111,119,32,116,111,32,115,112,108,105,116,32,102,114,97,109,101,115,32,102,111,114,32,118,105,100,101,111,32,102,111,114,109,97,116,32,37,105,46,32,86,105,100,101,111,32,115,116,114,101,97,109,32,119,105,108,108,32,98,101,32,98,114,111,107,101,110,33,10,0,0,0,0,0,0,0,65,86,70,111,114,109,97,116,67,111,110,116,101,120,116,0,108,105,98,97,118,102,111,114,109,97,116,47,114,109,100,101,99,46,99,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,110,100,105,97,110,97,95,69,97,115,116,0,0,115,116,114,105,99,116,0,0,98,0,0,0,0,0,0,0,100,97,116,101,0,0,0,0,111,109,97,0,0,0,0,0,98,101,103,105,110,0,0,0,80,67,83,95,78,65,68,56,51,95,73,108,108,105,110,111,105,115,95,87,101,115,116,0,112,105,120,101,108,95,102,111,114,109,97,116,0,0,0,0,111,104,115,117,98,0,0,0,80,67,83,95,78,65,68,56,51,95,73,108,108,105,110,111,105,115,95,69,97,115,116,0,99,97,118,115,0,0,0,0,115,101,116,32,115,97,109,112,108,101,32,114,97,116,101,0,115,101,116,32,116,104,101,32,120,45,97,120,105,115,32,115,105,122,101,32,111,102,32,116,104,101,32,119,105,110,100,111,119,32,117,115,101,100,32,100,117,114,105,110,103,32,99,111,109,98,101,100,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,0,0,0,0,109,106,112,101,103,0,0,0,121,117,118,52,52,52,112,49,48,108,101,0,0,0,0,0,76,105,103,104,116,66,108,117,101,0,0,0,0,0,0,0,37,103,0,0,0,0,0,0,55,46,49,40,119,105,100,101,45,115,105,100,101,41,0,0,115,101,116,32,114,101,109,97,116,114,105,120,32,109,97,120,118,97,108,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,39,114,101,100,49,39,32,97,116,111,109,10,0,0,0,0,0,0,83,101,108,101,99,116,32,116,104,101,32,99,104,97,110,110,101,108,32,116,111,32,100,101,99,111,100,101,32,102,111,114,32,100,117,97,108,32,109,111,110,111,0,0,0,0,0,0,104,101,97,100,101,114,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,100,97,104,111,95,87,101,115,116,0,0,0,0,37,115,44,32,0,0,0,0,98,111,116,116,111,109,0,0,71,67,83,95,65,103,97,100,101,122,0,0,0,0,0,0,69,110,99,111,117,110,116,101,114,101,100,32,69,79,70,32,119,104,105,108,101,32,114,101,97,100,105,110,103,32,105,110,100,101,120,46,10,0,0,0,112,99,109,95,117,56,0,0,105,103,110,111,114,101,99,114,111,112,0,0,0,0,0,0,67,111,114,101,32,80,114,111,102,105,108,101,0,0,0,0,118,98,118,32,98,117,102,102,101,114,58,32,37,100,44,32,98,105,116,114,97,116,101,58,37,100,10,0,0,0,0,0,109,106,112,101,103,58,32,74,70,73,70,32,104,101,97,100,101,114,32,102,111,117,110,100,32,40,118,101,114,115,105,111,110,58,32,37,120,46,37,120,41,32,83,65,82,61,37,100,47,37,100,10,0,0,0,0,81,80,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,111,109,97,0,0,0,0,0,105,110,116,101,114,112,108,97,121,118,105,100,101,111,0,0,82,111,99,107,32,38,32,82,111,108,108,0,0,0,0,0,32,67,52,50,48,112,49,54,32,88,89,83,67,83,83,61,52,50,48,80,49,54,0,0,80,67,83,95,78,65,68,56,51,95,73,100,97,104,111,95,67,101,110,116,114,97,108,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,79,86,80,56,48,0,0,0,80,67,83,95,78,65,68,56,51,95,73,100,97,104,111,95,69,97,115,116,0,0,0,0,99,0,0,0,0,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,32,32,107,101,121,102,114,97,109,101,61,37,100,10,0,0,77,69,84,65,68,65,84,65,95,66,76,79,67,75,95,80,73,67,84,85,82,69,0,0,80,67,83,95,78,65,68,56,51,95,71,101,111,114,103,105,97,95,87,101,115,116,0,0,102,102,99,111,110,99,97,116,32,118,101,114,115,105,111,110,32,49,46,48,10,0,0,0,115,101,116,32,112,97,99,107,101,116,32,115,105,122,101,0,65,84,82,65,67,51,58,32,85,110,115,117,112,112,111,114,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,10,0,0,0,0,0,128,116,104,101,111,114,97,0,73,110,118,97,108,105], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1913478);
/* memory initializer */ allocate([100,32,65,84,82,65,67,45,88,32,99,104,97,110,110,101,108,32,105,100,58,32,37,100,10,0,110,101,118,101,114,32,111,118,101,114,119,114,105,116,101,32,111,117,116,112,117,116,32,102,105,108,101,115,0,0,0,0,80,67,83,95,78,65,68,56,51,95,71,101,111,114,103,105,97,95,69,97,115,116,0,0,67,104,97,110,110,101,108,32,99,104,97,110,103,101,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,101,110,97,98,108,101,100,32,119,104,101,110,32,114,101,113,117,105,114,101,100,32,98,121,32,116,97,114,103,101,116,32,102,111,114,109,97,116,0,0,83,112,101,101,120,32,32,32,0,0,0,0,0,0,0,0,46,47,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,0,0,0,0,0,0,69,114,114,111,114,32,110,117,116,45,62,116,105,109,101,95,98,97,115,101,95,99,111,117,110,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,37,105,10,0,0,0,0,0,102,105,115,104,101,97,100,0,115,112,120,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,53,0,99,97,110,110,111,116,32,102,105,110,100,32,115,121,110,99,32,119,111,114,100,10,0,0,111,117,116,95,116,105,109,101,61,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,54,100,10,0,0,0,77,97,120,105,109,117,109,32,102,114,97,103,109,101,110,116,32,115,105,122,101,0,0,0,49,56,48,0,0,0,0,0,79,112,117,115,72,101,97,100,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,52,0,84,88,88,0,0,0,0,0,83,80,58,32,37,108,108,100,10,0,0,0,0,0,0,0,117,108,97,119,0,0,0,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,51,0,1,118,105,100,101,111,0,0,112,97,99,107,97,103,101,32,116,121,112,101,58,37,100,10,0,0,0,0,0,0,0,0,127,70,76,65,67,0,0,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,50,0,117,110,97,98,108,101,32,116,111,32,99,111,109,112,117,116,101,32,116,104,101,32,115,105,122,101,32,111,102,32,116,104,101,32,108,97,115,116,32,112,97,99,107,101,116,10,0,0,66,66,67,68,0,0,0,0,67,69,76,84,32,32,32,32,0,0,0,0,0,0,0,0,97,117,100,105,111,32,99,111,109,112,114,101,115,115,105,111,110,32,37,105,32,40,102,111,114,109,97,116,32,37,105,44,32,119,105,100,116,104,32,37,105,41,0,0,0,0,0,0,118,115,117,98,0,0,0,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,49,0,68,101,108,97,121,32,98,101,116,119,101,101,110,32,116,104,101,32,102,105,114,115,116,32,112,97,99,107,101,116,32,97,110,100,32,108,97,115,116,32,112,97,99,107,101,116,32,105,110,32,116,104,101,32,109,117,120,105,110,103,32,113,117,101,117,101,32,105,115,32,37,108,108,100,32,62,32,37,108,108,100,58,32,102,111,114,99,105,110,103,32,111,117,116,112,117,116,10,0,0,0,0,0,0,70,79,82,77,65,84,61,0,91,37,108,108,100,93,91,93,37,99,0,0,0,0,0,0,102,102,115,101,114,118,101,114,0,0,0,0,0,0,0,0,98,108,111,99,107,120,0,0,121,117,118,52,52,52,112,49,48,98,101,0,0,0,0,0,76,101,109,111,110,67,104,105,102,102,111,110,0,0,0,0,45,68,66,76,95,77,73,78,0,0,0,0,0,0,0,0,55,46,49,40,119,105,100,101,41,0,0,0,0,0,0,0,114,101,109,97,116,114,105,120,95,109,97,120,118,97,108,0,100,117,97,108,95,109,111,110,111,95,109,111,100,101,0,0,80,67,83,95,78,65,68,56,51,95,70,108,111,114,105,100,97,95,78,111,114,116,104,0,112,99,44,32,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,112,101,103,116,115,101,110,99,46,99,0,116,111,112,0,0,0,0,0,71,67,83,95,65,102,103,111,111,121,101,0,0,0,0,0,115,107,105,112,32,98,105,116,115,116,114,101,97,109,32,101,110,99,111,100,105,110,103,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,83,105,109,112,108,101,32,83,99,97,108,97,98,108,101,32,80,114,111,102,105,108,101,0,115,101,113,117,101,110,99,101,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,0,0,0,0,0,0,0,99,104,97,110,103,105,110,103,32,112,97,99,107,101,116,32,115,105,122,101,32,116,111,32,37,100,10,0,0,0,0,0,99,97,98,97,99,95,105,110,105,116,95,105,100,99,32,37,117,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,105,100,32,82,111,81,32,118,105,100,101,111,0,0,0,0,77,117,115,105,99,97,108,0,77,80,69,71,45,50,32,80,83,32,40,86,79,66,41,0,32,67,52,52,52,112,49,52,32,88,89,83,67,83,83,61,52,52,52,80,49,52,0,0,80,67,83,95,78,65,68,56,51,95,70,108,111,114,105,100,97,95,87,101,115,116,0,0,112,101,115,95,101,120,116,32,37,88,32,105,115,32,105,110,118,97,108,105,100,10,0,0,78,111,116,32,97,32,77,117,115,101,112,97,99,107,56,32,102,105,108,101,10,0,0,0,80,67,83,95,78,65,68,56,51,95,70,108,111,114,105,100,97,95,69,97,115,116,0,0,37,45,51,50,115,32,35,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,73,68,51,0,0,0,0,0,111,103,103,0,0,0,0,0,115,116,114,101,97,109,32,35,37,100,58,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,68,101,108,97,119,97,114,101,0,0,0,0,0,0,35,69,88,84,45,88,45,84,65,82,71,69,84,68,85,82,65,84,73,79,78,58,37,108,108,100,10,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,111,110,110,101,99,116,105,99,117,116,0,0,0,97,117,116,111,0,0,0,0,110,0,0,0,0,0,0,0,109,97,120,95,100,105,115,116,97,110,99,101,32,37,100,10,0,0,0,0,0,0,0,0,111,103,103,0,0,0,0,0,105,110,118,97,108,105,100,32,75,65,71,83,105,122,101,32,37,105,32,45,32,103,117,101,115,115,105,110,103,32,0,0,51,103,112,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,111,108,111,114,97,100,111,95,83,111,117,116,104,0,0,0,0,0,0,0,0,111,117,116,95,116,105,109,101,95,109,115,61,37,108,108,100,10,0,0,0,0,0,0,0,110,117,118,0,0,0,0,0,102,114,97,103,95,115,105,122,101,0,0,0,0,0,0,0,57,48,0,0,0,0,0,0,109,97,116,114,111,115,107,97,32,109,117,120,101,114,0,0,80,67,83,95,78,65,68,56,51,95,67,111,108,111,114,97,100,111,95,67,101,110,116,114,97,108,0,0,0,0,0,0,84,88,88,88,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,104,101,97,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,44,32,115,117,112,112,111,114,116,101,100,32,97,114,101,32,52,48,48,48,44,32,56,48,48,48,44,32,49,49,48,50,53,44,32,50,50,48,53,48,32,97,110,100,32,52,52,49,48,48,10,0,0,0,69,120,97,99,116,108,121,32,111,110,101,32,77,105,99,114,111,68,86,68,32,115,116,114,101,97,109,32,105,115,32,110,101,101,100,101,100,46,10,0,123,37,100,125,123,37,100,125,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,111,108,111,114,97,100,111,95,78,111,114,116,104,0,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,100,53,101,110,99,46,99,0,0,0,0,77,97,116,114,111,115,107,97,32,65,117,100,105,111,0,0,80,67,83,95,78,65,68,56,51,95,65,114,107,97,110,115,97,115,95,83,111,117,116,104,0,0,0,0,0,0,0,0,110,117,116,0,0,0,0,0,68,105,97,108,111,103,117,101,58,32,37,115,44,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,37,115,13,10,0,0,0,104,115,117,98,0,0,0,0,103,111,116,32,97,117,100,105,111,32,112,97,99,107,101,116,44,32,98,117,116,32,110,111,32,97,117,100,105,111,32,115,116,114,101,97,109,32,112,114,101,115,101,110,116,10,0,0,80,67,83,95,78,65,68,56,51,95,65,114,107,97,110,115,97,115,95,78,111,114,116,104,0,0,0,0,0,0,0,0,66,85,71,58,32,65,76,83,32,111,102,102,115,101,116,32,105,115,32,110,111,116,32,98,121,116,101,45,97,108,105,103,110,101,100,10,0,0,0,0,115,101,116,32,119,104,101,116,104,101,114,32,111,114,32,110,111,116,32,99,104,114,111,109,97,32,105,115,32,99,111,110,115,105,100,101,114,101,100,32,105,110,32,116,104,101,32,99,111,109,98,101,100,32,102,114,97,109,101,32,100,101,99,105,115,105,111,110,0,0,0,0,121,117,118,52,52,52,112,57,108,101,0,0,0,0,0,0,76,97,119,110,71,114,101,101,110,0,0,0,0,0,0,0,45,68,66,76,95,77,65,88,0,0,0,0,0,0,0,0,37,100,37,42,49,91,46,58,93,37,100,37,42,49,91,46,58,93,37,100,37,42,49,91,46,58,93,37,100,0,0,0,55,46,49,0,0,0,0,0,114,101,109,97,116,114,105,120,95,118,111,108,117,109,101,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,65,65,67,32,100,101,99,111,100,101,114,0,0,0,0,0,73,77,65,95,65,68,80,67,77,95,83,111,117,110,100,0,80,67,83,95,78,65,68,56,51,95,65,114,105,122,111,110,97,95,87,101,115,116,0,0,116,118,44,32,0,0,0,0,70,105,114,115,116,32,105,110,112,117,116,32,108,105,110,107,32,37,115,32,112,97,114,97,109,101,116,101,114,115,32,40,115,105,122,101,32,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,32,100,111,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,115,101,99,111,110,100,32,105,110,112,117,116,32,108,105,110,107,32,37,115,32,112,97,114,97,109,101,116,101,114,115,32,40,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,10,0,0,0,0,0,0,0,71,67,83,95,65,105,110,95,101,108,95,65,98,100,0,0,110,111,111,117,116,0,0,0,109,115,109,112,101,103,52,118,50,0,0,0,0,0,0,0,83,105,109,112,108,101,32,80,114,111,102,105,108,101,0,0,97,115,112,101,99,116,32,114,97,116,105,111,32,104,97,115,32,102,111,114,98,105,100,100,101,110,32,48,32,118,97,108,117,101,10,0,0,0,0,0,112,111,108,97,114,105,116,121,32,37,100,10,0,0,0,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,102,105,108,101,32,58,32,37,115,10,0,0,0,0,0,0,0,102,105,114,115,116,95,109,98,95,105,110,95,115,108,105,99,101,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,114,111,113,0,0,0,0,0,82,101,116,114,111,0,0,0,32,67,52,50,50,112,49,52,32,88,89,83,67,83,83,61,52,50,50,80,49,52,0,0,80,67,83,95,78,65,68,56,51,95,65,114,105,122,111,110,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,50,53,0,0,0,0,0,0,79,112,116,105,111,110,32,37,115,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,112,110,115,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,105,76,66,67,32,102,105,108,101,32,104,101,97,100,101,114,10,0,0,99,111,109,109,101,110,116,0,80,67,83,95,78,65,68,56,51,95,65,114,105,122,111,110,97,95,69,97,115,116,0,0,110,97,109,101,0,0,0,0,105,110,118,97,108,105,100,32,99,104,97,110,110,101,108,115,58,32,37,117,10,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,58,32,37,115,46,10,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,54,0,0,78,79,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,66,77,80,32,109,117,115,116,32,98,101,32,49,98,105,116,44,32,52,98,105,116,44,32,56,98,105,116,44,32,49,54,98,105,116,44,32,50,52,98,105,116,44,32,111,114,32,51,50,98,105,116,10,0,0,0,35,69,88,84,73,78,70,58,37,100,44,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,53,0,0,115,104,105,102,116,32,116,105,109,101,115,116,97,109,112,115,32,115,111,32,116,104,101,121,32,115,116,97,114,116,32,97,116,32,48,0,0,0,0,0,111,118,101,114,119,114,105,116,101,32,111,117,116,112,117,116,32,102,105,108,101,115,0,0,69,109,112,116,121,32,112,108,97,121,108,105,115,116,10,0,69,114,114,111,114,32,115,116,114,101,97,109,95,99,111,117,110,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,117,110,107,110,111,119,110,32,111,112,101,114,97,116,105,111,110,97,108,32,112,97,116,116,101,114,110,58,32,37,48,50,120,104,32,37,48,50,120,104,32,45,32,103,117,101,115,115,105,110,103,32,79,80,49,97,10,0,0,0,0,0,0,0,60,109,97,110,105,102,101,115,116,32,120,109,108,110,115,61,34,104,116,116,112,58,47,47,110,115,46,97,100,111,98,101,46,99,111,109,47,102,52,109,47,49,46,48,34,62,10,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,52,0,0,115,105,122,101,32,60,32,115,105,122,101,111,102,40,98,117,102,102,101,114,41,0,0,0,116,111,116,97,108,95,115,105,122,101,61,37,108,108,100,10,0,0,0,0,0,0,0,0,77,105,110,105,109,117,109,32,102,114,97,103,109,101,110,116,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,114,111,116,97,116,101,0,0,109,97,112,32,112,97,99,107,101,116,32,110,111,116,32,102,111,117,110,100,10,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,65,65,67,32,101,120,116,114,97,100,97,116,97,44,32,117,110,97,98,108,101,32,116,111,32,100,101,116,101,114,109,105,110,101,32,115,97,109,112,108,101,114,97,116,101,46,10,0,0,0,109,105,110,105,109,117,109,32,118,97,108,105,100,32,100,101,108,97,121,32,98,101,116,119,101,101,110,32,102,114,97,109,101,115,32,40,105,110,32,104,117,110,100,114,101,100,116,104,115,32,111,102,32,115,101,99,111,110,100,41,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,103,105,102,46,99,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,51,0,0,37,100,0,0,0,0,0,0,115,105,122,101,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,50,0,0,86,105,100,101,111,32,99,111,100,101,99,32,40,37,120,41,0,0,0,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,110,117,116,0,0,0,0,0,69,78,68,61,37,108,108,100,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,49,0,0,110,117,108,108,0,0,0,0,69,78,68,61,37,108,108,100,0,0,0,0,0,0,0,0,110,115,118,0,0,0,0,0,99,104,117,110,107,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,10,0,0,0,100,97,114,0,0,0,0,0,37,100,32,102,114,97,109,101,40,115,41,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,49,48,0,0,0,0,0,0,0,0,68,101,116,101,99,116,101,100,32,116,105,109,101,99,111,100,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,99,104,114,111,109,97,0,0,121,117,118,52,52,52,112,57,98,101,0,0,0,0,0,0,76,97,118,101,110,100,101,114,66,108,117,115,104,0,0,0,68,66,76,95,77,73,78,0,55,46,48,40,102,114,111,110,116,41,0,0,0,0,0,0,115,101,116,32,114,101,109,97,116,114,105,120,32,118,111,108,117,109,101,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,76,105,110,101,32,37,100,58,32,100,117,114,97,116,105,111,110,32,119,105,116,104,111,117,116,32,102,105,108,101,10,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,57,0,37,100,32,98,112,99,44,32,0,0,0,0,0,0,0,0,105,110,112,117,116,115,32,109,117,115,116,32,98,101,32,111,102,32,115,97,109,101,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,71,67,83,95,65,71,68,56,52,0,0,0,0,0,0,0,77,117,120,105,110,103,32,118,97,114,105,97,98,108,101,32,112,97,99,107,101,116,32,115,105,122,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,111,110,32,110,111,110,32,115,101,101,107,97,98,108,101,32,111,117,116,112,117,116,10,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,105,110,118,97,108,105,100,32,65,76,65,67,32,109,97,103,105,99,32,99,111,111,107,105,101,10,0,0,0,0,0,0,102,108,97,103,115,50,0,0,100,99,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,10,0,0,73,110,118,97,108,105,100,32,104,111,114,105,122,111,110,116,97,108,32,111,114,32,118,101,114,116,105,99,97,108,32,115,105,122,101,32,118,97,108,117,101,46,10,0,0,0,0,0,86,101,114,115,105,111,110,32,37,100,46,37,100,0,0,0,70,114,97,109,101,32,110,117,109,32,103,97,112,32,37,100,32,37,100,10,0,0,0,0,83,111,110,121,32,80,108,97,121,83,116,97,116,105,111,110,32,77,68,69,67,32,40,77,111,116,105,111,110,32,68,69,67,111,100,101,114,41,0,0,80,111,108,107,97,0,0,0,32,67,52,50,48,112,49,52,32,88,89,83,67,83,83,61,52,50,48,80,49,52,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,56,0,97,100,102,0,0,0,0,0,66,105,110,107,32,50,32,118,105,100,101,111,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,0,0,110,105,115,116,115,112,104,101,114,101,0,0,0,0,0,0,110,99,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,55,0,37,45,51,50,115,32,35,82,82,71,71,66,66,10,0,0,108,101,110,32,62,61,32,109,97,120,95,98,117,102,102,101,114,95,115,105,122,101,0,0,109,120,103,0,0,0,0,0,48,0,0,0,0,0,0,0,75,101,121,32,39,37,115,39,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,0,97,118,105,45,62,102,114,97,109,101,115,95,104,100,114,95,97,108,108,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,54,0,89,69,83,0,0,0,0,0,83,101,101,107,32,102,97,105,108,101,100,10,0,0,0,0,73,110,118,97,108,105,100,32,110,101,103,97,116,105,118,101,32,100,97,116,97,32,115,105,122,101,32,39,37,100,39,32,102,111,117,110,100,10,0,0,109,117,120,105,110,103,32,65,68,80,67,77,32,65,70,67,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,91,69,118,101,110,116,115,93,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,53,0,97,118,111,105,100,95,110,101,103,97,116,105,118,101,95,116,115,0,0,0,0,0,0,0,97,117,116,104,111,114,0,0,121,0,0,0,0,0,0,0,79,80,65,116,111,109,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,115,102,100,101,99,46,99,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,52,0,97,113,116,100,101,99,0,0,78,111,110,32,65,83,67,73,73,32,107,101,121,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,10,0,116,111,116,97,108,95,115,105,122,101,61,78,47,65,10,0,109,105,110,95,102,114,97,103,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,115,101,101,107,32,101,110,116,114,105,101,115,32,105,115,32,108,101,115,115,32,116,104,97,110,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,58,32,37,122,117,32,118,115,46,32,37,117,10,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,116,114,101,120,10,0,0,0,0,0,0,109,120,102,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,69,114,114,111,114,32,108,111,97,100,105,110,103,32,105,109,97,103,101,32,102,105,108,101,32,39,37,115,39,10,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,51,0,40,37,100,41,0,0,0,0,109,97,120,95,118,111,108,117,109,101,58,32,37,46,49,102,32,100,66,10,0,0,0,0,102,105,120,101,100,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,50,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,102,111,114,109,97,116,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,114,101,112,108,97,121,103,97,105,110,46,99,0,0,0,0,0,83,121,110,116,97,120,32,101,114,114,111,114,32,97,102,116,101,114,32,99,104,97,110,110,101,108,32,110,97,109,101,32,105,110,32,34,37,46,56,115,34,10,0,0,0,0,0,0,33,115,45,62,105,110,112,117,116,95,102,114,97,109,101,115,91,105,93,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,49,0,48,46,56,0,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,105,115,32,110,111,116,32,115,101,116,32,97,110,100,32,99,97,110,110,111,116,32,98,101,32,103,117,101,115,115,101,100,32,102,114,111,109,32,116,104,101,32,109,97,112,115,46,10,0,0,115,97,114,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,98,97,109,97,95,87,101,115,116,0,0,65,112,112,108,121,32,97,32,116,119,111,45,112,111,108,101,32,66,117,116,116,101,114,119,111,114,116,104,32,98,97,110,100,45,112,97,115,115,32,102,105,108,116,101,114,46,0,0,115,101,116,32,116,104,101,32,97,114,101,97,32,99,111,109,98,105,110,103,32,116,104,114,101,115,104,111,108,100,32,117,115,101,100,32,102,111,114,32,99,111,109,98,101,100,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,0,0,121,117,118,52,50,50,112,49,48,108,101,0,0,0,0,0,76,97,118,101,110,100,101,114,0,0,0,0,0,0,0,0,68,66,76,95,77,65,88,0,55,46,48,0,0,0,0,0,102,102,109,112,101,103,95,102,105,108,116,101,114,46,99,0,114,109,118,111,108,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,98,97,109,97,95,69,97,115,116,0,0,44,32,37,115,0,0,0,0,116,49,0,0,0,0,0,0,100,101,102,97,117,108,116,0,71,67,83,95,65,71,68,54,54,0,0,0,0,0,0,0,112,99,109,95,115,51,50,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,82,77,83,32,108,101,118,101,108,32,100,66,58,32,37,102,10,0,0,0,0,0,0,0,97,108,108,111,119,32,110,111,110,45,115,112,101,99,45,99,111,109,112,108,105,97,110,116,32,115,112,101,101,100,117,112,32,116,114,105,99,107,115,0,72,46,50,54,51,43,32,47,32,72,46,50,54,51,45,49,57,57,56,32,47,32,72,46,50,54,51,32,118,101,114,115,105,111,110,32,50,0,0,0,105,108,108,101,103,97,108,32,100,99,32,118,108,99,10,0,118,98,118,95,100,101,108,97,121,32,37,100,44,32,114,101,102,32,37,100,32,116,121,112,101,58,37,100,10,0,0,0,78,79,80,84,83,0,0,0,65,80,80,120,32,40,37,115,32,47,32,37,56,88,41,32,108,101,110,61,37,100,10,0,70,111,117,110,100,32,114,101,102,101,114,101,110,99,101,32,97,110,100,32,110,111,110,45,114,101,102,101,114,101,110,99,101,32,102,105,101,108,100,115,32,105,110,32,116,104,101,32,115,97,109,101,32,102,114,97,109,101,44,32,119,104,105,99,104,0,0,0,0,0,0,0,112,97,100,32,108,97,115,116,32,102,114,97,109,101,32,119,105,116,104,32,122,101,114,111,115,0,0,0,0,0,0,0,109,100,101,99,0,0,0,0,65,99,105,100,32,74,97,122,122,0,0,0,0,0,0,0,32,67,52,52,52,112,49,50,32,88,89,83,67,83,83,61,52,52,52,80,49,50,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,50,51,78,0,0,100,101,102,97,117,108,116,0,115,101,116,32,111,117,116,112,117,116,32,103,97,105,110,0,119,104,111,108,101,95,108,101,110,0,0,0,0,0,0,0,105,110,112,117,116,115,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,32,37,99,37,99,37,99,32,37,45,49,54,115,32,37,45,49,48,115,32,37,115,10,0,113,117,101,117,101,45,62,97,118,97,105,108,97,98,108,101,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,37,89,32,45,32,37,109,32,45,32,37,100,84,37,72,58,37,77,58,37,83,0,0,0,111,117,116,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,35,69,88,84,45,88,45,65,76,76,79,87,45,67,65,67,72,69,58,37,115,10,0,0,110,98,95,101,99,104,111,101,115,58,37,100,10,0,0,0,68,101,108,97,121,32,109,117,115,116,32,98,101,32,110,111,110,32,110,101,103,97,116,105,118,101,32,110,117,109,98,101,114,46,10,0,0,0,0,0,100,101,102,97,117,108,116,0,109,120,102,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,115,101,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,0,0,0,117,115,101,32,119,97,108,108,99,108,111,99,107,32,97,115,32,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,102,111,117,114,99,99,32,108,101,110,103,116,104,32,37,100,10,0,0,0,79,80,49,97,0,0,0,0,71,101,110,101,114,97,116,101,32,116,101,115,116,32,112,97,116,116,101,114,110,46,0,0,109,118,105,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,116,105,109,101,100,32,73,68,51,32,109,101,116,97,100,97,116,97,0,0,0,0,0,0,115,101,116,32,102,114,97,109,101,32,114,97,116,101,0,0,77,97,120,105,109,117,109,32,102,114,97,103,109,101,110,116,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,98,105,116,114,97,116,101,61,37,54,46,49,102,107,98,105,116,115,47,115,0,0,0,0,119,114,111,110,103,32,99,104,117,110,107,32,99,111,117,110,116,32,37,100,10,0,0,0,78,111,32,119,97,118,32,99,111,100,101,99,32,116,97,103,32,102,111,117,110,100,32,102,111,114,32,99,111,100,101,99,32,37,115,10,0,0,0,0,115,58,37,100,120,37,100,32,114,58,37,100,47,37,100,32,114,117,108,101,58,37,115,32,115,116,97,121,95,114,117,108,101,58,37,100,32,98,111,114,110,95,114,117,108,101,58,37,100,32,115,116,105,116,99,104,58,37,100,32,115,101,101,100,58,37,117,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,116,105,109,101,100,95,105,100,51,0,0,0,0,0,0,0,84,67,79,0,0,0,0,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,119,105,100,116,104,32,105,115,32,37,100,32,119,104,105,99,104,32,99,97,110,110,111,116,32,99,111,110,116,97,105,110,32,116,104,101,32,112,114,111,118,105,100,101,100,32,115,116,114,105,110,103,32,119,105,100,116,104,32,111,102,32,37,100,10,0,115,101,110,100,32,111,110,101,32,102,114,97,109,101,32,102,111,114,32,101,97,99,104,32,102,105,101,108,100,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,115,112,101,99,105,102,121,32,119,104,105,99,104,32,102,114,97,109,101,115,32,116,111,32,100,101,105,110,116,101,114,108,97,99,101,0,0,0,0,0,68,86,68,32,78,97,118,32,112,97,99,107,101,116,0,0,112,105,120,101,108,32,102,111,114,109,97,116,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,110,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,115,101,116,32,108,117,109,97,32,109,97,116,114,105,120,32,118,101,114,116,105,99,97,108,32,115,105,122,101,0,0,0,100,118,100,95,110,97,118,95,112,97,99,107,101,116,0,0,114,111,116,97,116,101,32,99,108,111,99,107,119,105,115,101,0,0,0,0,0,0,0,0,110,98,95,102,114,97,109,101,115,0,0,0,0,0,0,0,102,114,97,109,101,32,105,100,32,35,37,100,32,40,112,116,115,95,116,105,109,101,61,37,102,41,32,115,101,108,101,99,116,101,100,32,102,114,111,109,32,97,32,115,101,116,32,111,102,32,37,100,32,105,109,97,103,101,115,10,0,0,0,0,97,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,102,105,101,108,100,0,0,0,83,77,80,84,69,32,51,51,54,77,32,75,101,121,45,76,101,110,103,116,104,45,86,97,108,117,101,32,40,75,76,86,41,32,109,101,116,97,100,97,116,97,0,0,0,0,0,0,37,46,54,103,0,0,0,0,109,118,0,0,0,0,0,0,109,97,114,107,32,97,115,32,98,111,116,116,111,109,45,102,105,101,108,100,45,102,105,114,115,116,0,0,0,0,0,0,99,116,104,114,101,115,104,0,121,117,118,52,50,50,112,49,48,98,101,0,0,0,0,0,75,104,97,107,105,0,0,0,45,70,76,84,95,77,73,78,0,0,0,0,0,0,0,0,54,46,49,40,102,114,111,110,116,41,0,0,0,0,0,0,115,101,116,32,76,70,69,32,109,105,120,32,108,101,118,101,108,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,107,108,118,0,0,0,0,0,32,40,37,115,32,47,32,48,120,37,48,52,88,41,0,0,114,101,112,101,97,116,32,108,97,115,116,32,98,111,116,116,111,109,32,102,114,97,109,101,0,0,0,0,0,0,0,0,71,67,83,95,65,100,105,110,100,97,110,0,0,0,0,0,102,97,115,116,0,0,0,0,105,119,0,0,0,0,0,0,104,50,54,51,112,0,0,0,100,99,32,111,118,101,114,102,108,111,119,32,97,116,32,37,100,120,37,100,10,0,0,0,112,114,111,102,105,108,101,58,32,37,100,44,32,108,101,118,101,108,58,32,37,100,32,112,115,58,32,37,100,32,99,102,58,37,100,32,118,98,118,32,98,117,102,102,101,114,58,32,37,100,44,32,98,105,116,114,97,116,101,58,37,100,10,0,77,101,116,97,115,111,102,116,32,77,74,80,69,71,32,67,111,100,101,99,0,0,0,0,73,110,118,97,108,105,100,32,102,105,101,108,100,32,109,111,100,101,32,99,111,109,98,105,110,97,116,105,111,110,32,37,100,47,37,100,10,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,105,110,95,104,0,0,0,0,67,105,114,114,117,115,32,76,111,103,105,99,32,65,99,99,117,80,97,107,0,0,0,0,65,99,105,100,32,80,117,110,107,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,32,67,52,50,50,112,49,50,32,88,89,83,67,83,83,61,52,50,50,80,49,50,0,0,105,67,69,68,114,97,119,32,116,101,120,116,0,0,0,0,108,97,118,102,105,46,112,115,110,114,46,112,115,110,114,46,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,115,101,116,32,116,104,101,32,112,97,100,32,97,114,101,97,32,104,101,105,103,104,116,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,105,100,102,0,0,0,0,0,102,109,116,0,0,0,0,0,87,0,0,0,0,0,0,0,37,89,32,45,32,37,109,32,45,32,37,100,32,37,72,58,37,77,58,37,83,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,101,88,116,101,110,100,101,100,32,66,73,78,97,114,121,32,116,101,120,116,0,0,0,0,97,108,108,95,102,108,97,103,115,0,0,0,0,0,0,0,35,69,88,84,45,88,45,77,69,68,73,65,45,83,69,81,85,69,78,67,69,58,37,100,10,0,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,111,117,116,112,117,116,32,102,111,114,109,97,116,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,115,117,105,116,97,98,108,101,32,111,117,116,112,117,116,32,102,111,114,109,97,116,10,0,0,0,105,110,37,100,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,99,111,110,116,105,110,117,101,32,97,112,112,108,121,105,110,103,32,116,104,101,32,108,97,115,116,32,99,108,117,116,32,97,102,116,101,114,32,101,111,115,0,0,0,0,0,0,0,120,98,105,110,0,0,0,0,117,115,101,95,119,97,108,108,99,108,111,99,107,95,97,115,95,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,109,116,118,0,0,0,0,0,115,116,114,101,97,109,32,104,101,97,100,101,114,32,37,100,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,78,101,103,97,116,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,34,79,80,65,116,111,109,34,32,119,105,116,104,32,37,117,32,69,67,115,32,45,32,97,115,115,117,109,105,110,103,32,37,115,10,0,0,0,0,0,109,115,110,119,99,116,99,112,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,57,78,0,0,0,105,0,0,0,0,0,0,0,66,105,110,97,114,121,32,116,101,120,116,0,0,0,0,0,115,101,116,32,112,114,111,103,114,101,115,115,105,118,101,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,102,114,97,103,95,100,117,114,97,116,105,111,110,0,0,0,98,105,116,114,97,116,101,61,78,47,65,0,0,0,0,0,101,114,114,111,114,32,117,110,97,108,105,103,110,101,100,32,99,104,117,110,107,10,0,0,110,0,0,0,0,0,0,0,78,111,32,98,109,112,32,99,111,100,101,99,32,116,97,103,32,102,111,117,110,100,32,102,111,114,32,99,111,100,101,99,32,37,115,10,0,0,0,0,109,112,115,117,98,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,56,78,0,0,0,108,101,118,101,108,115,0,0,98,105,110,116,101,120,116,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,102,114,97,109,101,32,37,115,44,32,115,107,105,112,112,101,100,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,86,105,101,119,115,32,97,114,101,32,112,97,99,107,101,100,32,111,110,32,116,111,112,32,111,102,32,101,97,99,104,32,111,116,104,101,114,0,0,0,109,112,108,50,0,0,0,0,65,115,115,117,109,101,32,116,104,101,32,102,105,114,115,116,32,80,84,83,32,115,104,111,117,108,100,32,98,101,32,116,104,105,115,32,118,97,108,117,101,46,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,55,78,0,0,0,70,111,114,109,97,116,32,110,97,109,101,32,116,111,111,32,108,111,110,103,10,0,0,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,0,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,115,99,97,108,101,0,0,0,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,68,114,111,112,32,102,114,97,109,101,32,105,115,32,111,110,108,121,32,97,108,108,111,119,101,100,32,119,105,116,104,32,51,48,48,48,48,47,49,48,48,49,32,111,114,32,54,48,48,48,48,47,49,48,48,49,32,70,80,83,10,0,0,0,109,112,106,112,101,103,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,54,78,0,0,0,121,117,118,52,49,49,112,0,119,101,98,118,116,116,0,0,102,109,45,62,112,114,118,32,38,38,32,102,109,45,62,115,114,99,32,38,38,32,102,109,45,62,110,120,116,0,0,0,73,110,118,97,108,105,100,32,97,108,112,104,97,32,118,97,108,117,101,32,115,112,101,99,105,102,105,101,114,32,39,37,115,39,32,105,110,32,39,37,115,39,10,0,0,0,0,0,98,111,116,116,111,109,0,0,109,112,101,103,118,105,100,101,111,0,0,0,0,0,0,0,84,69,82,77,0,0,0,0,83,72,65,50,50,52,0,0,116,121,112,101,0,0,0,0,70,73,76,69,0,0,0,0,116,97,110,104,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,0,0,0,0,0,0,0,0,111,104,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,53,78,0,0,0,70,82,0,0,0,0,0,0,102,108,97,103,115,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,108,97,110,97,114,32,82,71,66,32,99,111,110,118,101,114,115,105,111,110,32,37,115,32,45,62,32,37,115,10,0,0,0,0,0,86,80,108,97,121,101,114,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,37,100,120,37,100,32,45,62,32,37,100,120,37,100,32,105,115,32,105,110,118,97,108,105,100,32,115,99,97,108,105,110,103,32,100,105,109,101,110,115,105,111,110,10,0,0,0,0,87,97,114,110,105,110,103,58,32,100,115,116,83,116,114,105,100,101,32,105,115,32,110,111,116,32,97,108,105,103,110,101,100,33,10,32,32,32,32,32,32,32,32,32,45,62,99,97,110,110,111,116,32,100,111,32,97,108,105,103,110,101,100,32,109,101,109,111,114,121,32,97,99,99,101,115,115,101,115,32,97,110,121,109,111,114,101,10,0,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,101,120,112,101,114,105,109,101,110,116,97,108,0,0,0,0,105,115,114,0,0,0,0,0,37,102,32,0,0,0,0,0,99,97,108,99,117,108,97,116,101,32,112,47,99,47,110,47,117,47,98,0,0,0,0,0,121,117,118,52,50,48,112,49,48,108,101,0,0,0,0,0,73,118,111,114,121,0,0,0,45,70,76,84,95,77,65,88,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,97,120,118,97,108,58,32,37,100,10,0,0,0,0,0,54,46,49,0,0,0,0,0,108,102,101,95,109,105,120,95,108,101,118,101,108,0,0,0,115,45,62,117,118,108,105,110,101,115,105,122,101,32,61,61,32,99,45,62,117,118,115,116,114,105,100,101,0,0,0,0,121,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,52,78,0,0,0,117,110,107,110,111,119,110,32,88,65,45,65,68,80,67,77,32,102,105,108,116,101,114,32,37,100,0,0,0,0,0,0,99,111,110,99,101,97,108,105,110,103,32,37,100,32,68,67,44,32,37,100,32,65,67,44,32,37,100,32,77,86,32,101,114,114,111,114,115,32,105,110,32,37,99,32,102,114,97,109,101,10,0,0,0,0,0,0,118,112,108,97,121,101,114,0,84,114,121,105,110,103,32,116,111,32,114,101,109,111,118,101,32,37,100,32,109,111,114,101,32,115,97,109,112,108,101,115,32,116,104,97,110,32,116,104,101,114,101,32,97,114,101,32,105,110,32,116,104,101,32,113,117,101,117,101,10,0,0,0,83,70,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,112,111,115,61,37,100,44,32,118,97,108,61,37,100,33,10,0,32,40,37,115,41,0,0,0,114,101,112,101,97,116,108,97,115,116,0,0,0,0,0,0,92,37,49,91,49,50,51,52,93,99,38,72,37,88,38,37,49,91,92,125,93,37,110,0,65,110,103,117,108,97,114,95,68,77,83,95,72,101,109,105,115,112,104,101,114,101,0,0,92,78,0,0,0,0,0,0,98,112,115,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,58,32,37,100], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1923718);
/* memory initializer */ allocate([10,0,73,110,118,97,108,105,100,32,118,101,114,115,105,111,110,32,37,100,10,0,0,0,0,0,65,68,80,67,77,32,83,104,111,99,107,119,97,118,101,32,70,108,97,115,104,0,0,0,120,0,0,0,0,0,0,0,79,117,116,112,117,116,32,101,118,101,110,32,112,111,116,101,110,116,105,97,108,108,121,32,99,111,114,114,117,112,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,68,84,75,0,0,0,0,0,72,46,50,54,51,32,47,32,72,46,50,54,51,45,49,57,57,54,0,0,0,0,0,0,110,101,120,116,61,37,108,108,100,44,32,110,101,119,61,37,108,108,100,10,0,0,0,0,100,99,60,48,32,97,116,32,37,100,120,37,100,10,0,0,115,100,101,32,119,58,37,100,44,32,104,58,37,100,10,0,73,110,116,101,108,40,82,41,32,74,80,69,71,32,76,105,98,114,97,114,121,44,32,118,101,114,115,105,111,110,32,49,0,0,0,0,0,0,0,0,112,101,114,95,102,114,97,109,101,95,109,101,116,97,100,97,116,97,0,0,0,0,0,0,112,101,114,95,102,114,97,109,101,95,109,101,116,97,100,97,116,97,0,0,0,0,0,0,109,105,120,105,110,103,95,108,101,118,101,108,32,109,117,115,116,32,98,101,32,115,101,116,32,105,102,32,114,111,111,109,95,116,121,112,101,32,105,115,32,115,101,116,10,0,0,0,117,110,115,101,116,32,99,117,114,95,112,105,99,95,112,116,114,32,111,110,32,115,108,105,99,101,32,37,100,10,0,0,112,101,114,99,101,110,116,97,103,101,32,111,102,32,100,121,110,97,109,105,99,32,114,97,110,103,101,32,99,111,109,112,114,101,115,115,105,111,110,32,116,111,32,97,112,112,108,121,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,32,115,99,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,51,78,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,0,0,0,99,108,106,114,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,105,110,100,101,120,32,37,100,10,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,101,120,116,114,97,100,97,116,97,46,10,0,0,0,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,101,109,112,116,121,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,0,84,114,105,98,97,108,0,0,32,67,52,50,48,112,49,50,32,88,89,83,67,83,83,61,52,50,48,80,49,50,0,0,83,117,98,86,105,101,119,101,114,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,99,102,114,109,32,105,110,32,118,101,114,115,105,111,110,32,37,100,10,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,98,108,111,99,107,32,111,118,101,114,108,97,112,112,105,110,103,32,112,105,120,101,108,115,0,0,49,46,50,46,53,0,0,0,73,110,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,80,97,108,101,116,116,101,32,112,97,114,97,109,101,116,101,114,115,32,105,110,118,97,108,105,100,44,32,104,101,97,100,101,114,32,112,114,111,98,97,98,108,121,32,99,111,114,114,117,112,116,10,0,0,0,0,73,103,110,111,114,105,110,103,32,105,110,118,97,108,105,100,32,99,111,114,114,101,99,116,105,111,110,32,98,108,111,99,107,32,112,111,115,105,116,105,111,110,10,0,0,0,0,0,105,110,118,97,108,105,100,32,112,105,120,109,97,112,32,102,111,114,109,97,116,10,0,0,84,105,109,101,32,99,111,100,101,32,62,61,32,49,48,48,32,104,111,117,114,115,46,10,0,0,0,0,0,0,0,0,32,125,59,10,0,0,0,0,85,110,107,110,111,119,110,32,100,101,102,105,110,101,32,39,37,115,39,10,0,0,0,0,79,118,101,114,108,97,112,112,105,110,103,32,99,111,112,121,10,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,56,0,0,0,10,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,105,110,116,114,97,32,98,108,111,99,107,58,32,37,100,32,120,32,37,100,32,40,37,100,41,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,119,109,97,118,111,105,99,101,46,99,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,87,97,105,116,105,110,103,32,102,111,114,32,115,101,101,107,97,98,108,101,32,116,105,108,101,10,0,0,0,0,0,0,40,112,117,116,95,98,105,116,115,95,99,111,117,110,116,40,38,115,45,62,112,98,41,32,38,32,55,41,32,61,61,32,48,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,108,97,115,116,32,102,114,97,109,101,32,98,105,116,32,111,102,102,115,101,116,32,37,100,32,62,32,98,117,102,32,115,105,122,101,32,37,100,32,40,37,100,41,10,0,0,0,0,60,47,105,62,0,0,0,0,73,103,110,111,114,105,110,103,32,101,120,116,114,97,32,69,88,73,70,32,99,104,117,110,107,10,0,0,0,0,0,0,106,111,105,110,116,95,115,116,101,114,101,111,0,0,0,0,77,105,115,109,97,116,99,104,105,110,103,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,105,110,32,97,32,115,101,113,117,101,110,99,101,58,32,37,100,32,97,110,100,32,37,100,10,0,112,114,111,98,108,101,109,58,32,110,111,32,86,80,84,90,32,99,104,117,110,107,32,102,111,117,110,100,10,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,98,105,116,115,116,114,101,97,109,32,114,101,97,100,101,114,10,0,0,85,112,115,99,97,108,105,110,103,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,68,97,116,97,32,112,97,99,107,101,116,32,119,105,116,104,111,117,116,32,112,114,105,111,114,32,118,97,108,105,100,32,104,101,97,100,101,114,115,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,99,45,62,116,121,112,101,32,61,61,32,48,32,124,124,32,114,99,45,62,116,121,112,101,32,61,61,32,50,0,0,80,67,83,95,78,65,68,95,77,105,99,104,105,103,97,110,95,77,105,99,104,105,103,97,110,95,87,101,115,116,0,0,109,111,100,101,95,110,117,109,98,101,114,0,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,98,105,103,101,110,100,105,97,110,32,102,108,97,103,32,61,32,37,105,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,111,100,100,32,100,105,109,101,110,115,105,111,110,115,32,40,37,100,32,120,32,37,100,41,32,115,117,112,112,111,114,116,0,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,32,73,109,97,103,101,32,118,50,0,0,115,117,98,118,105,101,119,101,114,0,0,0,0,0,0,0,102,111,114,99,101,32,102,111,114,109,97,116,0,0,0,0,82,65,78,71,69,82,69,68,32,115,104,111,117,108,100,32,98,101,32,115,101,116,32,116,111,32,48,32,105,110,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,10,0,0,115,101,116,32,116,104,101,32,104,101,105,103,104,116,32,99,114,111,112,32,97,114,101,97,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,117,115,116,111,109,32,86,50,49,48,32,115,116,114,105,100,101,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,0,114,101,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,103,110,111,114,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,115,101,116,32,105,110,118,97,108,105,100,32,116,105,109,101,98,97,115,101,32,37,100,47,37,100,32,102,111,114,32,115,116,58,37,100,10,0,0,0,0,0,0,0,86,81,70,32,84,119,105,110,86,81,32,115,104,111,117,108,100,32,104,97,118,101,32,111,110,108,121,32,111,110,101,32,102,114,97,109,101,32,112,101,114,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,98,108,117,101,32,103,97,105,110,32,102,111,114,32,116,104,101,32,114,101,100,32,99,104,97,110,110,101,108,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,114,97,116,101,10,0,0,0,0,0,84,111,111,32,102,101,119,32,115,108,105,99,101,32,112,114,111,112,101,114,116,105,101,115,32,40,37,100,32,47,32,37,100,41,10,0,0,0,0,0,67,97,109,116,97,115,105,97,32,101,114,114,111,114,58,32,117,110,107,110,111,119,110,32,100,101,112,116,104,32,37,105,32,98,112,112,10,0,0,0,82,101,97,100,32,116,111,107,101,110,32,102,114,111,109,32,115,116,114,101,97,109,32,37,105,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,37,105,62,61,37,105,41,10,0,0,0,0,0,0,0,70,114,97,109,101,32,119,105,116,104,32,115,112,114,105,116,101,0,0,0,0,0,0,0,115,45,62,110,117,109,95,101,110,116,114,105,101,115,32,60,32,51,50,0,0,0,0,0,80,67,83,95,78,65,68,95,77,105,99,104,105,103,97,110,95,77,105,99,104,105,103,97,110,95,79,108,100,95,67,101,110,116,114,97,108,0,0,0,115,101,116,32,98,108,117,101,32,115,104,97,100,111,119,115,0,0,0,0,0,0,0,0,83,117,98,86,105,101,119,101,114,32,118,49,32,115,117,98,116,105,116,108,101,0,0,0,35,69,88,84,45,88,45,86,69,82,83,73,79,78,58,51,10,0,0,0,0,0,0,0,71,101,111,103,76,105,110,101,97,114,85,110,105,116,115,71,101,111,75,101,121,0,0,0,73,109,97,103,101,32,100,97,116,97,32,105,115,32,109,105,115,115,105,110,103,10,0,0,83,117,98,86,105,101,119,101,114,49,32,115,117,98,116,105,116,108,101,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,116,111,32,114,101,97,100,32,112,97,108,101,116,116,101,10,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,47,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,10,0,0,80,67,83,95,78,65,68,95,77,105,99,104,105,103,97,110,95,77,105,99,104,105,103,97,110,95,69,97,115,116,0,0,83,72,0,0,0,0,0,0,102,114,97,109,101,32,110,117,109,32,37,100,32,108,101,102,116,32,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,115,118,113,49,101,110,99,46,99,0,0,0,0,114,108,101,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,40,99,111,109,112,114,101,115,115,105,111,110,41,32,116,121,112,101,10,0,13,10,13,10,0,0,0,0,102,54,52,98,101,32,100,101,109,117,120,101,114,0,0,0,123,92,97,110,49,125,123,92,109,111,118,101,40,37,100,44,37,100,44,37,100,44,37,100,41,125,0,0,0,0,0,0,83,111,110,105,99,58,32,118,101,114,58,32,37,100,46,37,100,32,108,115,58,32,37,100,32,100,114,58,32,37,100,32,116,97,112,115,58,32,37,100,32,98,108,111,99,107,58,32,37,100,32,102,114,97,109,101,58,32,37,100,32,100,111,119,110,115,97,109,112,58,32,37,100,10,0,0,0,0,0,0,109,112,101,103,116,115,0,0,115,117,98,118,105,101,119,101,114,49,0,0,0,0,0,0,98,45,62,112,97,114,101,110,116,61,61,48,76,32,124,124,32,98,45,62,112,97,114,101,110,116,45,62,115,116,114,105,100,101,32,61,61,32,98,45,62,115,116,114,105,100,101,42,50,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,32,115,117,98,115,97,109,112,108,101,32,109,111,100,101,32,37,100,32,37,100,10,0,77,74,80,69,71,32,99,111,100,101,99,32,102,97,105,108,101,100,32,116,111,32,111,112,101,110,10,0,0,0,0,0,48,120,70,48,32,111,112,99,111,100,101,0,0,0,0,0,112,105,99,95,116,104,0,0,99,111,110,115,105,100,101,114,32,116,104,105,110,103,115,32,116,104,97,116,32,97,32,115,97,110,101,32,101,110,99,111,100,101,114,32,115,104,111,117,108,100,110,39,116,32,100,111,32,97,115,32,97,110,32,101,114,114,111,114,0,0,0,0,99,104,97,110,110,101,108,115,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,95,97,108,105,103,110,58,32,37,100,46,32,77,111,100,101,32,37,115,32,103,117,101,115,115,101,100,32,98,97,115,101,100,32,111,110,32,98,105,116,114,97,116,101,58,32,37,100,10,0,0,105,110,118,97,108,105,100,32,112,114,101,100,95,111,114,100,101,114,32,37,100,10,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,99,111,117,110,116,46,10,0,0,0,115,117,98,99,111,100,101,99,32,37,100,0,0,0,0,0,38,110,98,115,112,59,0,0,83,108,105,99,101,32,116,121,112,101,32,109,105,115,109,97,116,99,104,10,0,0,0,0,73,110,99,111,114,114,101,99,116,32,105,110,116,114,97,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,10,0,0,0,0,0,0,0,0,108,97,118,102,105,46,98,98,111,120,46,120,49,0,0,0,115,45,62,108,111,111,112,95,102,105,108,116,101,114,61,61,49,0,0,0,0,0,0,0,80,79,83,32,69,82,82,79,82,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,87,104,101,116,104,101,114,32,116,111,32,114,101,115,112,101,99,116,32,107,110,111,119,110,32,108,105,109,105,116,97,116,105,111,110,115,32,105,110,32,81,117,97,107,101,32,51,32,100,101,99,111,100,101,114,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,99,104,97,110,110,101,108,115,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,68,105,109,101,110,115,105,111,110,115,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,49,54,10,0,0,0,0,102,67,111,100,101,0,0,0,83,105,114,44,32,73,32,103,111,116,32,99,97,114,115,105,99,107,32,105,110,32,121,111,117,114,32,111,102,102,105,99,101,46,32,78,111,116,32,100,101,99,111,100,105,110,103,32,116,104,101,32,114,101,115,116,32,111,102,32,112,97,99,107,101,116,46,10,0,0,0,0,80,114,101,118,105,111,117,115,80,97,114,116,105,116,105,111,110,32,112,111,105,110,116,115,32,116,111,32,116,104,105,115,32,112,97,114,116,105,116,105,111,110,32,111,114,32,102,111,114,119,97,114,100,10,0,0,114,97,116,105,111,0,0,0,98,97,100,32,115,117,112,101,114,98,108,111,99,107,32,116,121,112,101,10,0,0,0,0,66,97,100,108,121,32,114,101,99,101,105,118,101,100,32,112,97,99,107,101,116,115,32,105,110,32,102,114,97,109,101,46,0,0,0,0,0,0,0,0,112,114,111,102,105,108,101,32,37,100,44,32,37,100,32,115,108,105,99,101,115,44,32,105,110,116,101,114,108,97,99,105,110,103,58,32,37,115,44,32,37,100,32,98,105,116,115,32,112,101,114,32,77,66,10,0,102,114,97,109,101,32,119,105,100,116,104,32,110,101,101,100,115,32,116,111,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,50,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,115,108,105,99,101,32,100,105,109,101,110,115,105,111,110,58,32,37,100,32,120,32,37,100,10,0,0,0,97,99,32,116,101,120,32,100,97,109,97,103,101,100,32,37,100,44,32,37,100,10,0,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,111,117,114,105,95,87,101,115,116,0,109,97,105,110,0,0,0,0,80,66,77,32,40,80,111,114,116,97,98,108,101,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,80,78,71,32,101,110,99,111,100,101,114,0,0,0,0,0,112,110,103,58,32,116,97,103,61,37,99,37,99,37,99,37,99,32,108,101,110,103,116,104,61,37,117,10,0,0,0,0,82,101,97,108,84,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,66,105,116,109,97,112,32,100,105,109,101,110,115,105,111,110,115,32,108,97,114,103,101,114,32,116,104,97,110,32,118,105,100,101,111,46,10,0,0,0,105,109,97,103,101,32,100,97,116,97,32,112,111,115,115,105,98,108,121,32,99,111,114,114,117,112,116,101,100,10,0,0,80,101,114,45,102,105,108,101,32,109,97,105,110,32,111,112,116,105,111,110,115,58,0,0,112,99,109,95,102,51,50,108,101,0,0,0,0,0,0,0,80,67,77,32,68,86,68,32,117,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,100,101,112,116,104,32,37,105,10,0,0,0,0,114,101,115,101,114,118,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,100,41,10,0,0,0,0,0,0,80,55,10,87,73,68,84,72,32,37,100,10,72,69,73,71,72,84,32,37,100,10,68,69,80,84,72,32,37,100,10,77,65,88,86,65,76,32,37,100,10,84,85,80,76,84,89,80,69,32,37,115,10,69,78,68,72,68,82,10,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,115,116,97,114,116,95,112,116,115,0,0,0,0,0,0,0,105,111,100,115,32,118,105,100,101,111,32,112,114,111,102,105,108,101,32,97,116,111,109,46,0,0,0,0,0,0,0,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,32,0,0,0,0,119,114,111,110,103,32,115,97,109,112,108,101,32,99,111,117,110,116,10,0,0,0,0,0,99,111,100,101,99,32,37,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,105,115,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,117,110,99,111,109,112,114,101,115,115,101,100,32,102,114,97,109,101,32,116,111,111,32,115,104,111,114,116,10,0,0,0,111,117,116,112,117,116,37,100,0,0,0,0,0,0,0,0,70,105,114,115,116,32,112,105,99,116,117,114,101,32,104,97,115,32,110,111,32,83,79,70,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,111,117,114,105,95,67,101,110,116,114,97,108,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,68,67,84,32,98,108,111,99,107,32,37,100,44,37,100,10,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,32,37,100,44,37,100,10,0,0,0,0,0,77,105,115,115,105,110,103,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,0,0,37,100,32,102,114,101,101,32,99,111,108,111,117,114,40,115,41,10,0,0,0,0,0,0,77,83,32,82,76,69,58,32,102,114,97,109,101,32,112,116,114,32,106,117,115,116,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,114,117,110,41,10,0,0,0,0,0,0,0,0,114,101,97,108,116,101,120,116,0,0,0,0,0,0,0,0,92,78,0,0,0,0,0,0,78,111,32,65,86,70,111,114,109,97,116,67,111,110,116,101,120,116,44,32,115,107,105,112,112,101,100,32,73,68,51,32,99,104,97,112,116,101,114,32,100,97,116,97,10,0,0,0,85,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,113,112,32,115,101,108,101,99,116,105,111,110,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,101,110,99,111,100,105,110,103,32,37,100,32,99,104,97,110,110,101,108,40,115,41,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,0,0,101,110,99,111,100,105,110,103,32,37,100,32,99,104,97,110,110,101,108,40,115,41,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,0,0,100,97,116,97,95,112,97,114,116,105,116,105,111,110,105,110,103,0,0,0,0,0,0,0,93,0,0,0,0,0,0,0,115,108,105,99,101,32,98,101,108,111,119,32,109,111,110,105,116,111,114,32,46,46,46,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,111,117,114,105,95,69,97,115,116,0,83,112,97,116,105,97,108,108,121,32,83,99,97,108,97,98,108,101,0,0,0,0,0,0,84,111,111,32,115,109,97,108,108,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,40,37,105,41,33,10,0,10,0,0,0,0,0,0,0,83,65,77,73,32,115,117,98,116,105,116,108,101,0,0,0,73,110,100,105,99,97,116,101,100,32,108,101,110,103,116,104,32,111,102,32,115,117,98,115,116,114,101,97,109,32,37,100,32,100,97,116,97,32,103,111,101,115,32,111,102,102,32,101,110,100,32,111,102,32,112,97,99,107,101,116,46,10,0,0,97,109,118,0,0,0,0,0,115,99,97,108,101,114,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,99,108,97,115,115,61,37,100,32,105,110,100,101,120,61,37,100,32,110,98,95,99,111,100,101,115,61,37,100,10,0,0,100,113,116,32,111,102,102,115,58,32,48,120,37,120,10,0,78,111,32,115,117,99,104,32,98,97,99,107,114,101,102,101,114,101,110,99,101,33,32,66,117,103,103,121,32,115,97,109,112,108,101,46,10,0,0,0,105,98,117,115,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,102,105,102,111,46,99,0,0,0,0,0,0,76,79,67,79,32,99,111,100,101,99,32,118,101,114,115,105,111,110,32,37,105,0,0,0,108,105,98,97,118,99,111,100,101,99,47,108,99,108,101,110,99,46,99,0,0,0,0,0,68,101,99,111,100,101,100,32,115,105,122,101,32,100,105,102,102,101,114,115,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,0,0,0,0,0,116,98,0,0,0,0,0,0,122,101,114,111,95,114,117,110,95,108,105,110,101,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,106,112,101,103,108,115,0,0,108,105,98,97,118,99,111,100,101,99,47,106,112,101,103,50,48,48,48,100,101,99,46,99,0,0,0,0,0,0,0,0,74,82,0,0,0,0,0,0,97,102,116,101,114,32,114,97,116,101,32,99,111,110,116,114,111,108,10,0,0,0,0,0,66,97,110,100,32,98,117,102,102,101,114,32,112,111,105,110,116,115,32,116,111,32,110,111,32,100,97,116,97,33,10,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,105,115,115,105,112,112,105,95,87,101,115,116,0,0,0,0,0,0,32,65,73,86,0,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,68,10,0,73,110,118,97,108,105,100,32,109,97,114,107,101,114,10,0,73,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,33,10,0,0,0,0,73,110,118,97,108,105,100,47,117,110,115,117,112,112,111,114,116,101,100,32,109,118,32,114,101,115,111,108,117,116,105,111,110,58,32,37,100,33,10,0,115,101,116,32,99,111,109,109,97,110,100,115,32,102,105,108,101,0,0,0,0,0,0,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,111,117,116,32,111,102,32,97,114,114,97,121,10,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,115,97,109,105,0,0,0,0,103,111,116,32,37,88,46,10,0,0,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,101,120,116,114,97,32,112,108,97,110,101,115,32,98,101,121,111,110,100,32,56,10,0,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,118,112,115,95,109,97,120,95,100,101,99,95,112,105,99,95,98,117,102,102,101,114,105,110,103,95,109,105,110,117,115,49,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,32,33,61,32,0,0,0,0,114,111,119,95,105,110,116,101,114,108,101,97,118,101,100,95,114,108,0,0,0,0,0,0,114,101,102,101,114,101,110,99,101,32,112,105,99,116,117,114,101,32,109,105,115,115,105,110,103,32,100,117,114,105,110,103,32,114,101,111,114,100,101,114,10,0,0,0,0,0,0,0,112,111,99,95,99,121,99,108,101,95,108,101,110,103,116,104,32,111,118,101,114,102,108,111,119,32,37,117,10,0,0,0,111,117,116,112,117,116,37,100,0,0,0,0,0,0,0,0,114,101,102,32,37,117,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,0,111,117,116,95,104,0,0,0,68,101,99,111,100,105,110,103,32,115,112,115,32,37,100,32,102,114,111,109,32,97,118,99,67,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,105,115,115,105,112,112,105,95,69,97,115,116,0,0,0,0,0,0,69,114,114,111,114,32,97,116,32,77,66,58,32,37,100,10,0,0,0,0,0,0,0,0,76,90,87,32,105,110,105,116,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,103,105,102,46,99,0,0,0,0,0,0,0,0,79,110,108,121,32,109,111,110,111,32,115,111,117,110,100,32,105,115,32,115,117,112,112,111,114,116,101,100,32,40,114,101,113,117,101,115,116,101,100,32,99,104,97,110,110,101,108,115,58,32,37,100,41,46,10,0,100,111,32,110,111,116,104,105,110,103,0,0,0,0,0,0,83,97,109,112,108,101,32,114,97,116,101,115,32,111,116,104,101,114,32,116,104,97,110,32,56,107,72,122,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,119,104,101,110,32,116,104,101,32,99,111,109,112,108,105,97,110,99,101,32,108,101,118,101,108,32,105,115,32,104,105,103,104,101,114,32,116,104,97,110,32,117,110,111,102,102,105,99,105,97,108,46,32,82,101,115,97,109,112,108,101,32,111,114,32,114,101,100,117,99,101,32,116,104,101,32,99,111,109,112,108,105,97,110,99,101,32,108,101,118,101,108,46,10,0,0,0,0,0,71,46,55,50,51,46,49,32,100,101,99,111,100,101,114,0,80,74,83,32,40,80,104,111,101,110,105,120,32,74,97,112,97,110,105,109,97,116,105,111,110,32,83,111,99,105,101,116,121,41,32,115,117,98,116,105,116,108,101,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,102,114,119,117,32,68,101,99,111,100,101,114,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,0,0,112,105,120,101,108,95,99,111,117,110,116,100,111,119,110,32,60,32,48,32,40,37,100,41,32,40,108,105,110,101,97,37,100,41,10,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,105,110,118,97,108,105,100,32,99,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,58,32,37,100,10,0,0,100,101,102,97,117,108,116,0,67,82,67,32,101,114,114,111,114,32,97,116,32,80,84,83,32,37,108,108,100,10,0,0,115,97,109,112,108,101,32,114,97,116,101,32,99,104,97,110,103,101,32,100,101,116,101,99,116,101,100,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,104,101,97,100,101,114,32,99,114,99,32,109,105,115,109,97,116,99,104,10,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,102,114,97,109,101,32,100,97,116,97,32,116,111,32,100,101,99,111,100,101,46,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,102,118,49,101,110,99,46,99,0,0,0,0,97,116,32,37,108,108,100,10,0,0,0,0,0,0,0,0,99,104,108,105,115,116,0,0,66,105,116,114,97,116,101,32,98,121,116,101,32,105,115,32,109,105,115,115,105,110,103,44,32,103,117,101,115,115,105,110,103,32,116,104,101,32,98,105,116,114,97,116,101,32,102,114,111,109,32,112,97,99,107,101,116,32,115,105,122,101,46,10,0,0,0,0,0,0,0,0,77,86,32,37,100,32,37,100,32,111,117,116,32,111,102,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,0,112,99,110,117,98,0,0,0,109,105,120,105,110,103,95,108,101,118,101,108,0,0,0,0,121,117,118,52,50,48,112,49,48,98,101,0,0,0,0,0,105,110,118,97,108,105,100,32,115,108,105,99,101,32,115,105,122,101,32,37,100,10,0,0,73,110,100,105,103,111,0,0,77,86,32,37,100,32,37,100,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,70,76,84,95,77,73,78,0,115,117,98,116,105,116,108,101,95,112,97,99,107,101,116,32,115,105,122,101,61,37,116,100,10,0,0,0,0,0,0,0,10,13,0,0,0,0,0,0,85,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,98,108,111,99,107,32,48,120,37,120,10,0,0,0,104,101,120,97,103,111,110,97,108,0,0,0,0,0,0,0,115,101,116,32,115,117,114,114,111,117,110,100,32,109,105,120,32,76,101,118,101,108,0,0,77,105,115,109,97,116,99,104,105,110,103,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,37,100,32,97,110,100,32,108,97,121,111,117,116,32,39,37,115,39,32,40,37,100,32,99,104,97,110,110,101,108,115,41,10,0,0,0,0,0,69,110,99,111,100,105,110,103,32,37,100,0,0,0,0,0,68,80,67,77,32,88,97,110,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,110,110,101,115,111,116,97,95,83,111,117,116,104,0,0,0,0,0,0,0,105,110,100,101,120,32,62,61,32,48,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,98,32,115,99,97,110,32,105,110,100,101,120,10,0,0,78,111,116,104,105,110,103,32,99,111,110,115,117,109,101,100,10,0,0,0,0,0,0,0,102,114,97,109,101,108,105,115,116,32,102,117,108,108,10,0,87,68,76,84,0,0,0,0,40,113,117,97,110,116,95,108,101,118,101,108,115,91,97,98,105,116,115,93,32,45,32,49,41,32,47,32,50,32,62,61,32,113,117,97,110,116,105,122,101,95,118,97,108,117,101,40,112,101,97,107,44,32,42,113,117,97,110,116,41,0,0,0,88,67,104,32,119,105,116,104,32,102,101,119,101,114,32,116,104,97,110,32,50,32,98,97,115,101,32,99,104,97,110,110,101,108,115,0,0,0,0,0,112,106,115,0,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,87,114,111,110,103,32,108,105,110,101,32,108,101,110,103,116,104,32,37,100,32,111,114,32,108,105,110,101,32,110,111,116,32,116,101,114,109,105,110,97,116,101,100,32,112,114,111,112,101,114,108,121,32,40,102,111,117,110,100,32,48,120,37,48,50,120,41,33,10,0,0,0,73,110,118,97,108,105,100,32,113,117,97,110,116,105,122,101,114,32,37,100,32,97,116,32,112,111,115,105,116,105,111,110,32,37,100,44,32,111,117,116,115,105,100,101,32,91,45,54,51,44,32,54,51,93,32,114,97,110,103,101,10,0,0,0,117,110,107,110,111,119,110,0,102,111,114,99,101,32,116,101,114,109,105,110,97,116,105,111,110,32,119,104,101,110,32,116,104,101,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,32,116,101,114,109,105,110,97,116,101,115,0,0,0,0,65,110,103,117,108,97,114,95,68,77,83,0,0,0,0,0,33,115,116,114,99,109,112,40,99,116,120,45,62,102,105,108,116,101,114,45,62,110,97,109,101,44,32,34,98,117,102,102,101,114,115,105,110,107,34,41,32,124,124,32,33,115,116,114,99,109,112,40,99,116,120,45,62,102,105,108,116,101,114,45,62,110,97,109,101,44,32,34,102,102,98,117,102,102,101,114,115,105,110,107,34,41,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,111,117,116,112,117,116,95,99,111,114,114,117,112,116,0,0,104,50,54,51,0,0,0,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,105,110,116,114,97,32,109,97,116,114,105,120,32,115,112,101,99,105,102,105,101,115,32,105,110,118,97,108,105,100,32,68,67,32,113,117,97,110,116,105,122,101,114,32,37,100,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,0,0,67,83,61,73,84,85,54,48,49,0,0,0,0,0,0,0,72,46,50,54,49,0,0,0,67,104,97,110,103,105,110,103,32,102,105,101,108,100,32,109,111,100,101,32,40,37,100,32,45,62,32,37,100,41,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,99,111,100,101,32,116,97,98,108,101,32,37,100,46,10,0,0,109,105,110,105,109,97,108,32,110,117,109,98,101,114,32,111,102,32,115,116,114,105,112,115,32,99,97,110,32,110,111,116,32,101,120,99,101,101,100,32,109,97,120,105,109,97,108,32,40,103,111,116,32,37,105,32,97,110,100,32,37,105,41,10,0,0,0,0,0,0,0,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,115,99,114,111,108,108,105,110,103,10,0,105,108,108,101,103,97,108,32,112,105,99,116,117,114,101,32,116,121,112,101,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,80,97,108,101,116,116,101,32,105,115,32,110,111,116,32,105,110,32,48,82,71,66,32,102,111,114,109,97,116,10,0,0,80,67,83,95,78,65,68,50,55,95,77,105,110,110,101,115,111,116,97,95,67,101,110,116,0,0,0,0,0,0,0,0,80,97,108,101,116,116,101,32,100,97,116,97,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,66,77,80,32,102,105,108,101,44,32,112,97,116,99,104,32,119,101,108,99,111,109,101,10,0,0,0,0,65,84,73,32,86,67,82,49,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,100,101,32,105,110,32,105,110,105,116,95,118,108,99,10,0,0,0,0,0,0,0,102,111,110,116,32,104,101,105,103,104,116,32,37,105,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,67,111,112,121,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,64,37,100,44,32,37,100,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,76,111,45,70,105,0,0,0,113,117,101,114,121,95,102,111,114,109,97,116,115,32,110,111,116,32,102,105,110,105,115,104,101,100,10,0,0,0,0,0,32,67,52,52,52,112,49,48,32,88,89,83,67,83,83,61,52,52,52,80,49,48,0,0,74,65,67,79,115,117,98,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,58,32,37,100,33,10,0,67,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,101,114,114,111,114,33,10,0,0,0,65,83,83,32,101,110,99,111,100,101,114,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,111,110,101,32,65,83,83,32,114,101,99,116,97,110,103,108,101,32,102,105,101,108,100,46,10,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,111,102,102,115,101,116,32,112,97,115,115,101,100,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,118,97,108,105,100,32,109,97,115,116,101,114,32,99,104,97,110,110,101,108,46,10,0,0,0,0,0,0,0,0,88,45,76,97,110,103,117,97,103,101,0,0,0,0,0,0,116,111,112,95,98,111,116,116,111,109,0,0,0,0,0,0,37,46,50,115,37,46,50,115,0,0,0,0,0,0,0,0,72,105,112,45,72,111,112,0,73,110,118,97,108,105,100,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,115,105,122,101,58,32,37,100,46,10,0,0,0,0,0,99,111,109,109,101,110,116,0,78,111,32,97,117,100,105,111,32,115,116,114,101,97,109,32,112,114,101,115,101,110,116,46,10,0,0,0,0,0,0,0,102,105,108,101,32,105,115,32,110,111,116,32,115,101,101,107,97,98,108,101,10,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,110,110,101,115,111,116,97,95,78,111,114,116,104,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,111,110,102,105,103,117,114,101,32,111,117,116,112,117,116,32,112,97,100,32,111,110,32,37,115,10,0,0,0,57,54,48,47,49,50,48,32,77,68,67,84,32,119,105,110,100,111,119,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,68,84,83,10,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,99,51,100,101,99,46,99,0,0,0,0,52,50,48,112,97,108,100,118,0,0,0,0,0,0,0,0,100,112,100,115,32,99,104,117,110,107,32,115,105,122,101,32,37,108,108,100,32,110,111,116,32,100,105,118,105,115,105,98,108,101,32,98,121,32,52,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,115,32,102,111,114,32,97,117,100,105,111,32,116,114,97,99,107,32,37,100,46,10,0,106,97,99,111,115,117,98,0,102,0,0,0,0,0,0,0,115,116,58,37,100,32,104,97,115,32,116,111,111,32,108,97,114,103,101,32,116,105,109,101,98,97,115,101,44,32,114,101,100,117,99,105,110,103,10,0,80,67,83,95,78,65,68,50,55,95,77,105,99,104,105,103,97,110,95,83,111,117,116,104,0,0,0,0,0,0,0,0,109,112,101,103,0,0,0,0,69,73,65,45,54,48,56,32,99,108,111,115,101,100,32,99,97,112,116,105,111,110,115,0,35,69,88,84,77,51,85,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,99,104,105,103,97,110,95,67,101,110,116,114,97,108,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,112,99,109,100,101,99,46,99,0,0,0,0,101,105,97,95,54,48,56,0,97,103,103,114,101,115,115,105,118,101,0,0,0,0,0,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,115,97,109,112,108,101,95,114,97,116,101,32,105,115,32,40,37,108,108,100,41,10,0,105,110,99,111,110,115,105,115,116,101,110,116,32,70,111,111,116,101,114,80,97,114,116,105,116,105,111,110,32,118,97,108,117,101,58,32,37,108,108,117,32,33,61,32,37,108,108,117,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,99,104,105,103,97,110,95,78,111,114,116,104,0,0,0,0,0,0,0,0,77,80,76,50,32,115,117,98,116,105,116,108,101,0,0,0,105,111,100,115,95,118,105,100,101,111,95,112,114,111,102,105,108,101,0,0,0,0,0,0,115,105,122,101,61,37,56,46,48,102,107,66,32,116,105,109,101,61,0,0,0,0,0,0,83,84,83,90,32,115,97,109,112,108,101,32,115,105,122,101,32,37,100,32,105,110,118,97,108,105,100,32,40,116,111,111,32,115,109,97,108,108,41,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,32,102,111,117,110,100,44,32,65,76,65,67,32,101,120,112,101,99,116,115,32,97,32,51,54,45,98,121,116,101,32,81,117,105,99,107,84,105,109,101,32,97,116,111,109,46,0,80,67,83,95,78,65,68,50,55,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,73,115,0,0,0,0,0,0,109,112,108,50,0,0,0,0,85,110,107,110,111,119,110,32,101,110,99,111,100,105,110,103,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,97,115,115,97,99,104,117,115,101,116,116,115,0,77,105,99,114,111,68,86,68,32,115,117,98,116,105], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1933958);
/* memory initializer */ allocate([116,108,101,0,0,0,0,0,0,0,109,112,101,103,0,0,0,0,37,100,58,37,100,58,48,120,37,88,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,97,114,121,108,97,110,100,0,0,0,0,0,0,109,105,99,114,111,100,118,100,0,0,0,0,0,0,0,0,109,112,99,56,0,0,0,0,111,119,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,97,105,110,101,95,87,101,115,116,0,0,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,109,112,99,0,0,0,0,0,99,97,108,99,117,108,97,116,101,32,112,47,99,47,110,0,121,117,118,52,50,48,112,57,108,101,0,0,0,0,0,0,73,110,100,105,97,110,82,101,100,0,0,0,0,0,0,0,70,76,84,95,77,65,88,0,54,46,48,40,102,114,111,110,116,41,0,0,0,0,0,0,115,117,114,114,111,117,110,100,95,109,105,120,95,108,101,118,101,108,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,97,105,110,101,95,69,97,115,116,0,0,0,0,77,105,115,115,105,110,103,32,99,111,101,102,102,32,116,97,98,108,101,10,0,0,0,0,67,111,117,112,108,105,110,103,32,83,116,97,114,116,32,66,97,110,100,0,0,0,0,0,67,111,117,112,108,105,110,103,32,83,116,97,114,116,32,66,97,110,100,0,0,0,0,0,115,117,98,114,105,112,0,0,37,115,58,32,37,115,0,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,65,110,103,117,108,97,114,95,71,111,110,0,0,0,0,0,112,99,109,95,115,51,50,108,101,0,0,0,0,0,0,0,99,108,111,115,101,100,32,71,79,80,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,118,105,100,101,111,95,101,110,99,46,99,0,0,0,0,0,0,124,108,101,118,101,108,124,32,111,118,101,114,102,108,111,119,32,105,110,32,51,46,32,101,115,99,44,32,113,112,61,37,100,10,0,0,0,0,0,0,109,97,116,114,105,120,32,100,97,109,97,103,101,100,10,0,65,86,73,68,0,0,0,0,84,104,105,115,32,115,116,114,101,97,109,32,119,97,115,32,103,101,110,101,114,97,116,101,100,32,98,121,32,97,32,98,114,111,107,101,110,32,101,110,99,111,100,101,114,44,32,105,110,118,97,108,105,100,32,56,120,56,32,105,110,102,101,114,101,110,99,101,10,0,0,0,80,67,83,95,78,65,68,50,55,95,76,111,117,105,115,105,97,110,97,95,83,111,117,116,104,0,0,0,0,0,0,0,118,99,114,49,0,0,0,0,84,114,97,105,108,101,114,0,32,67,52,50,50,112,49,48,32,88,89,83,67,83,83,61,52,50,50,80,49,48,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,32,119,105,116,104,32,101,109,98,101,100,100,101,100,32,116,105,109,105,110,103,0,0,0,0,80,67,83,95,78,65,68,50,55,95,76,111,117,105,115,105,97,110,97,95,78,111,114,116,104,0,0,0,0,0,0,0,115,114,116,0,0,0,0,0,100,111,32,110,111,116,32,115,104,111,119,32,112,114,111,103,114,97,109,32,98,97,110,110,101,114,0,0,0,0,0,0,108,111,110,103,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,99,104,97,110,110,101,108,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,0,105,109,97,103,101,47,106,112,101,103,0,0,0,0,0,0,115,116,58,37,100,32,114,101,109,111,118,105,110,103,32,99,111,109,109,111,110,32,102,97,99,116,111,114,32,37,100,32,102,114,111,109,32,116,105,109,101,98,97,115,101,10,0,0,109,111,100,101,0,0,0,0,80,67,83,95,78,65,68,50,55,95,75,101,110,116,117,99,107,121,95,83,111,117,116,104,0,0,0,0,0,0,0,0,101,110,99,114,121,112,116,101,100,32,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,32,40,115,116,58,37,100,41,44,32,100,101,99,111,100,105,110,103,32,119,105,108,108,32,108,105,107,101,108,121,32,102,97,105,108,10,0,0,0,68,86,66,32,116,101,108,101,116,101,120,116,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,115,101,103,109,101,110,116,32,108,105,115,116,32,39,37,115,39,10,0,0,0,0,0,0,0,99,61,73,78,32,37,115,32,37,115,13,10,0,0,0,0,32,45,45,62,32,0,0,0,109,112,50,0,0,0,0,0,13,10,0,0,0,0,0,0,32,32,117,110,114,101,99,111,103,110,105,122,101,100,32,87,67,51,32,99,104,117,110,107,58,32,37,99,37,99,37,99,37,99,32,40,48,120,37,48,50,88,37,48,50,88,37,48,50,88,37,48,50,88,41,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,75,101,110,116,117,99,107,121,95,78,111,114,116,104,0,0,0,0,0,0,0,0,115,116,45,62,99,111,100,101,99,45,62,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,62,32,48,0,0,0,0,100,118,98,95,116,101,108,101,116,101,120,116,0,0,0,0,37,115,32,99,111,100,101,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,99,111,110,115,105,100,101,114,32,97,108,108,32,115,112,101,99,32,110,111,110,32,99,111,109,112,108,105,97,110,99,105,101,115,32,97,115,32,101,114,114,111,114,115,0,0,0,0,105,110,118,97,108,105,100,32,97,115,112,101,99,116,32,114,97,116,105,111,32,37,100,47,37,100,10,0,0,0,0,0,104,105,100,101,95,98,97,110,110,101,114,0,0,0,0,0,117,110,107,110,111,119,110,32,103,117,105,100,58,32,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,70,97,105,108,101,100,32,114,101,97,100,105,110,103,32,85,73,68,10,0,0,0,0,0,109,112,51,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,75,97,110,115,97,115,95,83,111,117,116,104,0,0,115,105,122,101,0,0,0,0,72,68,77,86,32,80,114,101,115,101,110,116,97,116,105,111,110,32,71,114,97,112,104,105,99,32,83,116,114,101,97,109,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,58,32,61,0,0,0,0,0,105,111,100,115,32,97,117,100,105,111,32,112,114,111,102,105,108,101,32,97,116,111,109,46,0,0,0,0,0,0,0,0,68,69,83,67,82,73,80,84,73,79,78,0,0,0,0,0,115,105,122,101,61,78,47,65,32,116,105,109,101,61,0,0,83,84,83,90,32,115,97,109,112,108,101,32,115,105,122,101,32,37,100,32,105,110,118,97,108,105,100,32,40,116,111,111,32,108,97,114,103,101,41,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,0,79,110,108,121,32,97,117,100,105,111,44,32,118,105,100,101,111,44,32,97,110,100,32,115,117,98,116,105,116,108,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,77,97,116,114,111,115,107,97,46,10,0,0,0,85,110,97,98,108,101,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,104,105,110,116,105,110,103,32,111,102,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,13,10,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,75,97,110,115,97,115,95,78,111,114,116,104,0,0,104,100,109,118,95,112,103,115,95,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,66,79,77,32,118,97,108,117,101,10,0,0,0,0,80,67,83,95,78,65,68,50,55,95,66,76,77,95,49,55,78,95,102,101,101,116,0,0,77,79,86,32,116,101,120,116,0,0,0,0,0,0,0,0,98,117,102,102,101,114,115,105,110,107,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,73,111,119,97,95,83,111,117,116,104,0,0,0,0,109,111,118,95,116,101,120,116,0,0,0,0,0,0,0,0,115,108,105,100,101,0,0,0,109,105,109,101,95,116,121,112,101,0,0,0,0,0,0,0,111,117,116,95,119,0,0,0,47,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,66,76,77,95,49,54,78,95,102,101,101,116,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,99,104,97,114,115,95,112,101,114,95,102,114,97,109,101,0,116,111,116,97,108,102,114,97,109,101,115,32,37,100,32,105,110,118,97,108,105,100,10,0,110,111,32,102,111,114,99,101,100,32,99,97,108,99,117,108,97,116,105,111,110,0,0,0,121,117,118,52,50,48,112,57,98,101,0,0,0,0,0,0,72,111,116,80,105,110,107,0,73,54,52,95,77,73,78,0,54,46,48,0,0,0,0,0,115,101,116,32,115,117,114,114,111,117,110,100,32,109,105,120,32,108,101,118,101,108,0,0,32,32,32,32,115,116,114,101,97,109,58,37,100,32,99,111,100,101,99,58,37,115,32,116,121,112,101,58,37,115,0,0,80,67,83,95,78,65,68,50,55,95,73,111,119,97,95,78,111,114,116,104,0,0,0,0,69,82,82,79,82,58,32,115,116,101,112,95,105,110,100,101,120,32,61,32,37,105,10,0,99,112,108,95,115,116,97,114,116,95,98,97,110,100,0,0,99,112,108,95,115,116,97,114,116,95,98,97,110,100,0,0,115,116,97,114,116,84,105,109,101,0,0,0,0,0,0,0,115,115,97,0,0,0,0,0,91,37,100,93,0,0,0,0,10,0,0,0,0,0,0,0,115,101,116,32,111,112,97,99,105,116,121,32,102,111,114,32,97,108,108,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,65,110,103,117,108,97,114,95,71,114,97,100,0,0,0,0,116,97,103,95,108,101,110,32,60,32,48,120,51,102,0,0,99,103,111,112,0,0,0,0,118,98,118,95,100,101,108,97,121,32,60,32,48,120,70,70,70,70,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,50,46,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,105,110,32,51,46,32,101,115,99,10,0,0,0,0,0,0,0,0,112,100,101,32,40,37,100,44,37,100,41,32,40,37,100,44,37,100,41,32,40,37,100,44,37,100,41,10,0,0,0,0,99,111,109,109,101,110,116,58,32,39,37,115,39,10,0,0,91,83,73,90,69,93,0,0,67,97,110,110,111,116,32,40,114,101,45,41,105,110,105,116,105,97,108,105,122,101,32,99,111,110,116,101,120,116,32,100,117,114,105,110,103,32,112,97,114,97,108,108,101,108,32,100,101,99,111,100,105,110,103,46,10,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,66,76,77,95,49,53,78,95,102,101,101,116,0,0,52,88,32,77,111,118,105,101,0,0,0,0,0,0,0,0,83,104,111,119,116,117,110,101,115,0,0,0,0,0,0,0,32,67,52,50,48,112,49,48,32,88,89,83,67,83,83,61,52,50,48,80,49,48,0,0,65,83,83,32,40,65,100,118,97,110,99,101,100,32,83,83,65,41,32,115,117,98,116,105,116,108,101,0,0,0,0,0,10,0,0,0,0,0,0,0,87,114,111,110,103,32,65,65,67,32,102,105,108,101,32,102,111,114,109,97,116,10,0,0,99,111,109,109,101,110,116,0,80,67,83,95,78,65,68,50,55,95,73,110,100,105,97,110,97,95,87,101,115,116,0,0,97,115,115,0,0,0,0,0,37,115,47,77,97,110,105,102,101,115,116,46,116,109,112,0,117,110,115,117,112,112,111,114,116,101,100,32,97,117,100,105,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,32,9,13,10,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,37,105,32,98,121,116,101,115,32,111,102,32,101,120,116,114,97,100,97,116,97,10,0,0,72,101,97,100,101,114,32,99,104,117,110,107,32,115,105,122,101,32,105,115,32,105,110,99,111,114,114,101,99,116,10,0,80,67,83,95,78,65,68,50,55,95,66,76,77,95,49,52,78,95,102,101,101,116,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,102,114,97,109,101,32,114,101,99,111,114,100,10,0,0,0,0,88,83,85,66,0,0,0,0,34,44,10,13,0,0,0,0,99,61,73,78,32,37,115,32,37,115,47,37,100,13,10,0,80,67,83,95,78,65,68,50,55,95,73,110,100,105,97,110,97,95,69,97,115,116,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,117,116,111,0,0,0,0,120,115,117,98,0,0,0,0,99,111,109,112,108,105,97,110,116,0,0,0,0,0,0,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,104,101,105,103,104,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,102,108,97,103,115,0,0,0,117,110,107,110,111,119,110,32,112,97,114,116,105,116,105,111,110,32,116,121,112,101,32,37,105,10,0,0,0,0,0,0,116,105,116,108,101,0,0,0,80,67,83,95,78,65,68,50,55,95,73,108,108,105,110,111,105,115,95,87,101,115,116,0,114,97,119,32,85,84,70,45,56,32,116,101,120,116,0,0,78,111,32,101,118,101,110,116,115,32,105,110,32,115,99,114,105,112,116,10,0,0,0,0,105,111,100,115,95,97,117,100,105,111,95,112,114,111,102,105,108,101,0,0,0,0,0,0,115,116,114,101,97,109,95,37,100,95,37,100,95,112,115,110,114,95,97,108,108,61,37,50,46,50,102,10,0,0,0,0,67,79,77,78,84,0,0,0,85,115,105,110,103,32,97,98,115,111,108,117,116,101,32,112,97,116,104,32,111,110,32,117,115,101,114,32,114,101,113,117,101,115,116,44,32,116,104,105,115,32,105,115,32,97,32,112,111,115,115,105,98,108,101,32,115,101,99,117,114,105,116,121,32,105,115,115,117,101,10,0,60,83,65,77,73,62,0,0,83,117,98,116,105,116,108,101,32,99,111,100,101,99,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,80,67,83,95,78,65,68,50,55,95,73,108,108,105,110,111,105,115,95,69,97,115,116,0,116,101,120,116,0,0,0,0,67,97,110,110,111,116,32,114,101,97,100,32,66,79,77,32,118,97,108,117,101,44,32,105,110,112,117,116,32,116,111,111,32,115,104,111,114,116,10,0,77,97,120,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,32,116,111,111,32,108,111,119,10,0,0,0,0,0,65,68,80,67,77,32,105,110,32,82,83,79,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,65,117,100,105,111,32,102,111,114,109,97,116,32,37,105,0,80,67,83,95,78,65,68,50,55,95,73,100,97,104,111,95,87,101,115,116,0,0,0,0,114,109,45,62,97,117,100,105,111,95,112,107,116,95,99,110,116,32,62,32,48,0,0,0,68,86,66,32,115,117,98,116,105,116,108,101,115,0,0,0,37,100,0,0,0,0,0,0,117,110,107,110,111,119,110,32,115,117,98,102,111,114,109,97,116,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,0,115,101,116,32,116,104,101,32,98,101,101,112,32,102,101,113,117,101,110,99,121,32,102,97,99,116,111,114,0,0,0,0,73,67,82,68,0,0,0,0,80,67,83,95,78,65,68,50,55,95,73,100,97,104,111,95,67,101,110,116,114,97,108,0,60,116,105,109,101,0,0,0,100,118,98,95,115,117,98,116,105,116,108,101,0,0,0,0,115,101,116,32,102,114,97,109,101,32,115,105,122,101,0,0,105,110,95,104,0,0,0,0,80,67,83,95,78,65,68,50,55,95,73,100,97,104,111,95,69,97,115,116,0,0,0,0,68,86,68,32,115,117,98,116,105,116,108,101,115,0,0,0,114,97,119,32,67,104,105,110,101,115,101,32,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,118,105,100,101,111,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,100,98,103,108,118,108,0,0,114,97,119,32,76,79,65,83,47,76,65,84,77,0,0,0,98,103,114,52,56,108,101,0,72,111,110,101,121,68,101,119,0,0,0,0,0,0,0,0,73,54,52,95,77,65,88,0,53,46,49,40,115,105,100,101,41,0,0,0,0,0,0,0,115,119,115,99,97,108,101,114,0,0,0,0,0,0,0,0,115,108,101,118,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,97,116,111,109,10,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,71,101,111,114,103,105,97,95,87,101,115,116,0,0,112,101,114,45,99,104,97,110,110,101,108,32,115,97,109,112,108,101,32,99,111,117,110,116,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,85,110,107,110,111,119,110,32,101,110,116,114,121,32,37,100,61,62,37,100,32,105,110,32,114,97,116,101,45,109,97,112,45,116,97,98,108,101,46,10,32,0,0,0,0,0,0,0,83,101,108,101,99,116,101,100,32,98,121,32,116,104,101,32,69,110,99,111,100,101,114,0,83,101,108,101,99,116,101,100,32,98,121,32,116,104,101,32,69,110,99,111,100,101,114,0,100,118,100,95,115,117,98,116,105,116,108,101,0,0,0,0,101,120,112,101,99,116,101,100,32,110,111,110,32,101,109,112,116,121,32,115,105,103,110,97,108,101,100,32,80,69,83,32,112,97,99,107,101,116,44,32,116,114,121,105,110,103,32,116,111,32,114,101,99,111,118,101,114,10,0,0,0,0,0,0,37,99,0,0,0,0,0,0,97,108,108,95,111,112,97,99,105,116,121,0,0,0,0,0,65,110,103,117,108,97,114,95,65,114,99,95,83,101,99,111,110,100,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,97,117,100,105,111,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,101,100,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,49,46,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,105,110,32,51,46,32,101,115,99,10,0,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,44,32,103,117,101,115,115,105,110,103,32,109,105,115,115,105,110,103,32,118,97,108,117,101,115,10,0,0,0,0,114,101,115,116,97,114,116,32,105,110,116,101,114,118,97,108,58,32,37,100,10,0,0,0,104,50,54,52,95,115,108,105,99,101,95,104,101,97,100,101,114,95,105,110,105,116,40,41,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,71,101,111,114,103,105,97,95,69,97,115,116,0,0,52,120,109,0,0,0,0,0,82,97,118,101,0,0,0,0,32,67,52,52,52,112,57,32,88,89,83,67,83,83,61,52,52,52,80,57,0,0,0,0,83,77,86,32,40,83,101,108,101,99,116,97,98,108,101,32,77,111,100,101,32,86,111,99,111,100,101,114,41,0,0,0,102,51,50,108,101,0,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,53,0,69,86,82,67,32,40,69,110,104,97,110,99,101,100,32,86,97,114,105,97,98,108,101,32,82,97,116,101,32,67,111,100,101,99,41,0,0,0,0,0,32,37,45,50,48,115,32,37,115,0,0,0,0,0,0,0,102,51,50,108,101,0,0,0,37,48,42,100,0,0,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,52,0,101,118,114,99,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,115,101,103,109,101,110,116,46,99,0,0,0,67,97,110,110,111,116,32,66,97,115,101,54,52,45,101,110,99,111,100,101,32,37,116,100,32,37,116,100,33,10,0,0,112,97,99,107,101,116,115,105,122,101,0,0,0,0,0,0,65,84,82,65,67,51,32,105,110,32,79,77,65,32,105,115,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,50,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,37,100,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,51,0,102,54,52,108,101,32,100,101,109,117,120,101,114,0,0,0,86,111,120,119,97,114,101,32,77,101,116,97,83,111,117,110,100,0,0,0,0,0,0,0,1,118,111,114,98,105,115,0,99,111,110,115,105,100,101,114,32,116,104,105,110,103,115,32,116,104,97,116,32,118,105,111,108,97,116,101,32,116,104,101,32,115,112,101,99,44,32,97,114,101,32,102,97,115,116,32,116,111,32,99,104,101,99,107,32,97,110,100,32,104,97,118,101,32,110,111,116,32,98,101,101,110,32,115,101,101,110,32,105,110,32,116,104,101,32,119,105,108,100,32,97,115,32,101,114,114,111,114,115,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,119,105,100,116,104,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,102,111,114,99,101,32,115,112,101,99,105,102,105,99,32,99,112,117,32,102,108,97,103,115,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,50,0,97,117,100,105,111,47,111,103,103,0,0,0,0,0,0,0,109,101,116,97,115,111,117,110,100,0,0,0,0,0,0,0,80,97,103,101,32,97,116,32,37,108,108,100,32,105,115,32,109,105,115,115,105,110,103,32,103,114,97,110,117,108,101,10,0,0,0,0,0,0,0,0,83,107,105,112,32,119,114,105,116,105,110,103,32,105,111,100,115,32,97,116,111,109,46,0,42,58,37,50,46,50,102,32,0,0,0,0,0,0,0,0,46,46,47,0,0,0,0,0,65,95,77,83,47,65,67,77,0,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,110,117,116,101,110,99,46,99,0,0,0,0,40,110,111,110,101,41,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,49,0,84,65,75,32,40,84,111,109,39,115,32,108,111,115,115,108,101,115,115,32,65,117,100,105,111,32,75,111,109,112,114,101,115,115,111,114,41,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,109,101,109,111,114,121,32,115,116,114,101,97,109,10,0,0,0,0,83,69,69,75,84,79,58,32,37,108,108,100,10,0,0,0,80,67,83,95,78,65,68,50,55,95,70,108,111,114,105,100,97,95,78,111,114,116,104,0,97,108,97,119,0,0,0,0,116,97,107,0,0,0,0,0,37,115,124,0,0,0,0,0,109,105,115,115,105,110,103,32,102,114,97,109,101,115,10,0,80,67,83,95,78,65,68,50,55,95,70,108,111,114,105,100,97,95,87,101,115,116,0,0,82,70,67,32,51,51,56,57,32,67,111,109,102,111,114,116,32,78,111,105,115,101,0,0,102,97,105,108,101,100,32,116,111,32,102,105,110,100,32,97,98,115,111,108,117,116,101,32,111,102,102,115,101,116,32,111,102,32,37,108,108,88,32,105,110,32,66,111,100,121,83,73,68,32,37,105,32,45,32,112,97,114,116,105,97,108,32,102,105,108,101,63,10,0,0,0,109,117,108,116,105,112,108,101,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,115,117,112,112,111,114,116,0,0,105,110,95,119,0,0,0,0,80,67,83,95,78,65,68,50,55,95,70,108,111,114,105,100,97,95,69,97,115,116,0,0,99,111,109,102,111,114,116,110,111,105,115,101,0,0,0,0,40,40,65,86,70,114,97,109,101,32,42,41,112,107,116,45,62,100,97,116,97,41,45,62,98,117,102,0,0,0,0,0,70,79,82,77,65,84,61,84,73,77,69,0,0,0,0,0,91,37,108,108,100,93,91,37,108,108,100,93,37,99,0,0,13,10,45,45,37,115,13,10,0,0,0,0,0,0,0,0,101,110,97,98,108,101,32,99,111,109,98,32,100,101,98,117,103,0,0,0,0,0,0,0,98,103,114,52,56,98,101,0,71,114,101,101,110,89,101,108,108,111,119,0,0,0,0,0,85,73,78,84,51,50,95,77,65,88,0,0,0,0,0,0,53,46,49,0,0,0,0,0,101,114,114,111,114,32,100,105,102,102,117,115,105,111,110,0,99,101,110,116,101,114,95,109,105,120,95,108,101,118,101,108,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,68,101,108,97,119,97,114,101,0,0,0,0,0,0,69,82,82,79,82,58,32,115,116,101,112,95,105,110,100,101,120,32,61,32,37,105,47,37,105,10,0,0,0,0,0,0,97,117,116,111,0,0,0,0,97,117,116,111,0,0,0,0,79,112,117,115,32,40,79,112,117,115,32,73,110,116,101,114,97,99,116,105,118,101,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,117,110,107,110,111,119,110,95,99,111,100,101,99,0,0,0,112,107,116,91,51,93,32,38,32,48,120,50,48,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,51,32,111,112,97,99,105,116,121,0,0,65,110,103,117,108,97,114,95,65,114,99,95,77,105,110,117,116,101,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,105,108,109,101,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,110,101,103,97,116,105,118,101,32,98,105,116,115,10,0,0,114,101,118,101,114,115,101,32,101,115,99,32,109,105,115,115,105,110,103,10,0,0,0,0,0,84,77,80,71,69,88,83,0,0,0,0,0,0,0,0,109,97,120,32,114,101,115,121,110,99,32,115,105,122,101,32,114,101,97,99,104,101,100,44,32,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,115,121,110,99,32,98,121,116,101,10,0,0,0,0,0,0,85,115,101,32,101,120,116,101,114,110,97,108,32,104,117,102,102,109,97,110,32,116,97,98,108,101,46,0,0,0,0,0,82,101,105,110,105,116,32,99,111,110,116,101,120,116,32,116,111,32,37,100,120,37,100,44,32,112,105,120,95,102,109,116,58,32,37,115,10,0,0,0,80,67,83,95,78,65,68,50,55,95,67,111,110,110,101,99,116,105,99,117,116,0,0,0,70,70,109,112,101,103,32,118,105,100,101,111,32,99,111,100,101,99,32,35,49,0,0,0,80,115,121,99,104,97,100,101,108,105,99,0,0,0,0,0,118,111,98,0,0,0,0,0,32,67,52,50,50,112,57,32,88,89,83,67,83,83,61,52,50,50,80,57,0,0,0,0,111,112,117,115,0,0,0,0,70,117,114,116,104,101,114,32,102,108,97,103,115,32,115,101,116,32,98,117,116,32,110,111,32,98,121,116,101,115,32,108,101,102,116,10,0,0,0,0,83,101,101,107,32,116,97,98,108,101,32,105,115,32,116,111,111,32,98,105,103,10,0,0,67,111,110,116,97,105,110,101,114,32,114,101,112,111,114,116,115,32,110,111,32,102,114,97,109,101,115,10,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,111,108,111,114,97,100,111,95,83,111,117,116,104,0,0,0,0,0,0,0,0,65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,65,117,100,105,111,0,0,0,0,0,0,83,0,0,0,0,0,0,0,78,111,32,112,97,99,107,101,116,115,32,119,101,114,101,32,115,101,110,116,32,102,111,114,32,115,111,109,101,32,111,102,32,116,104,101,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,115,46,10,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,100,101,116,101,114,109,105,110,101,32,102,105,108,101,32,115,105,122,101,44,32,115,107,105,112,112,105,110,103,32,84,79,67,32,116,97,98,108,101,46,10,0,0,0,0,0,0,0,0,32,32,78,111,32,80,114,111,103,114,97,109,10,0,0,0,80,67,83,95,78,65,68,50,55,95,67,111,108,111,114,97,100,111,95,67,101,110,116,114,97,108,0,0,0,0,0,0,65,112,112,108,105,99,97,116,105,111,110,32,112,114,111,118,105,100,101,100,32,100,117,114,97,116,105,111,110,58,32,37,108,108,100,32,47,32,116,105,109,101,115,116,97,109,112,58,32,37,108,108,100,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,102,111,114,32,109,111,118,47,109,112,52,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,112,97,102,95,97,117,100,105,111,0,0,0,0,0,0,0,33,34,73,110,118,97,108,105,100,32,108,105,115,116,32,116,121,112,101,34,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,116,104,101,32,112,97,114,97,109,101,116,101,114,32,115,101,116,115,46,10,0,80,67,83,95,78,65,68,50,55,95,67,111,108,111,114,97,100,111,95,78,111,114,116,104,0,0,0,0,0,0,0,0,102,51,50,98,101,32,100,101,109,117,120,101,114,0,0,0,83,111,110,105,99,32,108,111,115,115,108,101,115,115,0,0,99,97,114,101,102,117,108,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,101,120,116,114,97,100,97,116,97,95,115,105,122,101,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,37,89,45,37,109,45,37,100,32,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,99,112,117,102,108,97,103,115,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,114,107,97,110,115,97,115,95,83,111,117,116,104,0,0,0,0,0,0,0,0,115,111,110,105,99,108,115,0,81,117,105,99,107,84,105,109,101,32,47,32,77,79,86,0,115,107,105,112,95,105,111,100,115,0,0,0,0,0,0,0,115,116,114,101,97,109,95,37,100,95,37,100,95,112,115,110,114,95,37,99,61,37,50,46,50,102,10,0,0,0,0,0,115,116,114,101,97,109,32,37,100,44,32,101,114,114,111,114,32,111,112,101,110,105,110,103,32,97,108,105,97,115,58,32,112,97,116,104,61,39,37,115,39,44,32,100,105,114,61,39,37,115,39,44,32,102,105,108,101,110,97,109,101,61,39,37,115,39,44,32,118,111,108,117,109,101,61,39,37,115,39,44,32,110,108,118,108,95,102,114,111,109,61,37,100,44,32,110,108,118,108,95,116,111,61,37,100,10,0,0,0,0,0,0,79,118,101,114,102,108,111,119,32,105,110,32,100,105,115,112,108,97,121,32,119,105,100,116,104,10,0,0,0,0,0,0,119,101,98,109,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,114,107,97,110,115,97,115,95,78,111,114,116,104,0,0,0,0,0,0,0,0,83,111,110,105,99,0,0,0,80,82,73,86,0,0,0,0,67,97,110,110,111,116,32,97,112,112,101,110,100,32,112,97,108,101,116,116,101,32,116,111,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,0,86,78,58,76,97,118,102,53,53,46,51,51,46,49,48,48,44,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,101,118,101,110,116,32,34,37,115,34,32,97,116,32,108,105,110,101,32,37,100,10,0,0,80,67,83,95,78,65,68,50,55,95,65,114,105,122,111,110,97,95,87,101,115,116,0,0,115,111,110,105,99,0,0,0,108,101,110,32,62,32,48,32,38,38,32,108,101,110,32,60,61,32,115,105,122,101,111,102,40,109,100,53,41,0,0,0,116,114,105,109,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,114,105,122,111,110,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,87,97,118,101,32,115,121,110,116,104,101,115,105,115,32,112,115,101,117,100,111,45,99,111,100,101,99,0,0,0,0,0,118,105,100,101,111,47,119,101,98,109,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,32,119,97,118,112,97,99,107,32,98,108,111,99,107,46,10,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,46,10,77,97,121,98,101,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,111,117,116,95,119,58,39,37,115,39,32,111,114,32,102,111,114,32,111,117,116,95,104,58,39,37,115,39,32,105,115,32,115,101,108,102,45,114,101,102,101,114,101,110,99,105,110,103,46,10,0,0,80,67,83,95,78,65,68,50,55,95,65,114,105,122,111,110,97,95,69,97,115,116,0,0,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,119,97,118,101,115,121,110,116,104,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,46,10,0,0,99,111,109,98,100,98,103,0,103,114,97,121,56,97,0,0,71,114,101,101,110,0,0,0,73,78,84,95,77,73,78,0,64,37,117,32,64,37,117,32,37,110,0,0,0,0,0,0,52,46,49,0,0,0,0,0,101,100,0,0,0,0,0,0,115,101,116,32,99,101,110,116,101,114,32,109,105,120,32,108,101,118,101,108,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,86,73,73,0,0,0,0,0,0,0,0,69,82,82,79,82,58,32,98,108,111,99,107,95,112,114,101,100,105,99,116,111,114,91,49,93,32,61,32,37,100,10,0,67,104,97,110,110,101,108,32,67,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,67,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,112,97,99,107,101,116,95,115,105,122,101,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,76,117,99,97,115,65,114,116,115,32,86,73,77,65,32,97,117,100,105,111,0,0,0,0,67,111,100,101,99,32,48,120,37,120,32,105,115,32,110,111,116,32,105,110,32,116,104,101,32,102,117,108,108,32,108,105,115,116,46,10,0,0,0,0,99,51,95,111,112,97,99,105,116,121,0,0,0,0,0,0,65,110,103,117,108,97,114,95,68,101,103,114,101,101,0,0,112,99,109,95,115,51,50,98,101,0,0,0,0,0,0,0,72,46,50,54,51,32,97,100,118,97,110,99,101,100,32,105,110,116,114,97,32,99,111,100,105,110,103,32,47,32,77,80,69,71,45,52,32,65,67,32,112,114,101,100,105,99,116,105,111,110,0,0,0,0,0,0,118,98,118,32,98,117,102,102,101,114,32,111,118,101,114,102,108,111,119,10,0,0,0,0,50,46,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,105,110,32,114,118,108,99,32,101,115,99,10,0,0,0,0,0,0,71,79,80,32,40,37,115,41,32,99,108,111,115,101,100,95,103,111,112,61,37,100,32,98,114,111,107,101,110,95,108,105,110,107,61,37,100,10,0,0,101,120,116,101,114,110,95,104,117,102,102,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,103,101,116,32,102,114,97,109,101,32,102,105,108,101,110,97,109,101,32,110,117,109,98,101,114,32,37,100,32,102,114,111,109,32,112,97,116,116,101,114,110,32,39,37,115,39,32,40,101,105,116,104,101,114,32,115,101,116,32,117,112,100,97,116,101,102,105,114,115,116,32,111,114,32,117,115,101,32,97,32,112,97,116,116,101,114,110,32,108,105,107,101,32,37,37,48,51,100,32,119,105,116,104,105,110,32,116,104,101,32,102,105,108,101,110,97,109,101,32,112,97,116,116,101,114,110,41,10,0,0,0,0,0,0,99,104,97,110,103,105,110,103,32,119,105,100,116,104,32,37,100,32,45,62,32,37,100,32,47,32,104,101,105,103,104,116,32,37,100,32,45,62,32,37,100,32,111,110,32,115,108,105,99,101,32,37,100,10,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,86,73,0,102,102,118,49,0,0,0,0,78,101,119,32,87,97,118,101,0,0,0,0,0,0,0,0,32,67,52,50,48,112,57,32,88,89,83,67,83,83,61,52,50,48,80,57,0,0,0,0,118,105,109,97,0,0,0,0,115,101,116,32,116,104,101,32,118,105,100,101,111,32,102,114,97,109,101,114,97,116,101,0,112,110,103,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,109,111,100,101,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,86,0,0,99,111,108,111,114,32,102,111,114,109,97,116,32,37,46,49,54,115,0,0,0,0,0,0,105,76,66,67,32,40,73,110,116,101,114,110,101,116,32,76,111,119,32,66,105,116,114,97,116,101,32,67,111,100,101,99,41,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,121,116,101,115,32,112,101,114,32,115,97,109,112,108,101,58,32,37,117,10,0,0,0,32,32,80,114,111,103,114,97,109,32,37,100,32,37,115,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,73,86,0,105,108,98,99,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,97,110,110,111,116,32,111,112,101,110,32,116,104,101,32,104,50,54,52,95,109,112,52,116,111,97,110,110,101,120,98,32,66,83,70,33,10,0,0,84,67,79,80,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,73,73,73,0,0,0,0,0,0,0,0,35,69,88,84,45,88,45,77,69,68,73,65,45,83,69,81,85,69,78,67,69,58,37,108,108,100,10,0,0,0,0,0,102,51,50,108,101,32,100,101,109,117,120,101,114,0,0,0,73,65,67,32,40,73,110,100,101,111,32,65,117,100,105,111,32,67,111,100,101,114,41,0,97,98,111,114,116,32,100,101,99,111,100,105,110,103,32,111,110,32,109,105,110,111,114,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,0,104,101,97,100,101,114,115,0,69,114,114,111,114,32,115,116,99,45,62,100,101,99,111,100,101,95,100,101,108,97,121,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,117,105,100,0,0,0,0,0,60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,110,99,111,100,105,110,103,61,34,117,116,102,45,56,34,63,62,10,0,98,121,116,101,115,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,73,73,0,105,97,99,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,101,110,100,32,82,84,67,80,32,66,89,69,32,112,97,99,107,101,116,115,32,119,104,101,110,32,102,105,110,105,115,104,105,110,103,0,0,0,0,37,99,58,37,50,46,50,102,32,0,0,0,0,0,0,0,115,116,114,101,97,109,32,37,100,44,32,109,105,115,115,105,110,103,32,109,97,110,100,97,116,111,114,121,32,97,116,111,109,115,44,32,98,114,111,107,101,110,32,104,101,97,100,101,114,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,105,110,100,101,120,32,108,101,110,103,116,104,10,0,0,0,97,108,112,104,97,95,109,111,100,101,0,0,0,0,0,0,109,105,110,95,100,101,108,97,121,0,0,0,0,0,0,0,109,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,73,0,0,118,105,100,101,111,95,101,110,99,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,80,65,76,56,0,0,0,82,101,97,108,65,117,100,105,111,32,76,111,115,115,108,101,115,115,0,0,0,0,0,0,67,72,65,80,0,0,0,0,10,0,0,0,0,0,0,0,109,109,102,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,49,48,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,97,108,102,0,0,0,0,97,112,97,100,0,0,0,0,79,109,110,105,97,32,65,47,88,69,0,0,0,0,0,0,102,102,109,112,101,103,0,0,109,109,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,57,0,83,84,65,82,84,61,37,108,108,100,10,0,0,0,0,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,32,97,117,100,105,111,0,0,69,120,112,101,99,116,101,100,32,99,104,97,112,116,101,114,32,115,116,97,114,116,32,116,105,109,101,115,116,97,109,112,44,32,102,111,117,110,100,32,37,115,46,10,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,102,102,109,101,110,99,46,99,0,0,0,0,109,107,118,116,105,109,101,115,116,97,109,112,95,118,50,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,98,121,116,101,115,32,112,101,114,32,115,97,109,112,108,101,58,32,37,100,10,0,119,58,37,100,32,104,58,37,100,32,102,109,116,58,37,115,32,115,97,114,58,37,100,47,37,100,32,45,62,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1944198);
/* memory initializer */ allocate([119,58,37,100,32,104,58,37,100,32,102,109,116,58,37,115,32,115,97,114,58,37,100,47,37,100,32,102,108,97,103,115,58,48,120,37,48,120,10,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,56,0,70,105,108,101,32,99,111,110,116,97,105,110,115,32,110,111,32,102,114,97,109,101,115,32,63,63,63,10,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,98,109,118,95,97,117,100,105,111,0,0,0,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,109,105,99,114,111,100,118,100,0,0,0,0,0,0,0,0,101,110,97,98,108,101,32,99,111,109,98,109,97,116,99,104,105,110,103,32,97,108,108,32,116,104,101,32,116,105,109,101,0,0,0,0,0,0,0,0,98,103,114,52,52,52,98,101,0,0,0,0,0,0,0,0,71,114,97,121,0,0,0,0,73,78,84,95,77,65,88,0,53,46,48,40,115,105,100,101,41,0,0,0,0,0,0,0,98,97,121,101,114,32,100,105,116,104,101,114,0,0,0,0,99,108,101,118,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,55,0,69,82,82,79,82,58,32,98,108,111,99,107,95,112,114,101,100,105,99,116,111,114,91,48,93,32,61,32,37,100,10,0,99,104,97,110,110,101,108,95,99,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,95,99,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,56,83,86,88,32,102,105,98,111,110,97,99,99,105,0,0,110,111,110,101,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,50,32,111,112,97,99,105,116,121,0,0,65,110,103,117,108,97,114,95,82,97,100,105,97,110,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,97,105,99,0,0,0,0,0,105,110,118,97,108,105,100,32,65,65,67,32,109,97,103,105,99,32,99,111,111,107,105,101,10,0,0,0,0,0,0,0,115,116,117,102,102,105,110,103,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,49,46,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,105,110,32,114,118,108,99,32,101,115,99,10,0,0,0,0,0,0,104,97,114,100,119,97,114,101,32,97,99,99,101,108,101,114,97,116,111,114,32,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,102,105,114,115,116,32,102,105,101,108,100,10,0,0,0,0,0,0,77,74,80,69,71,32,100,101,99,111,100,101,114,0,0,0,115,107,105,112,112,105,110,103,32,97,100,100,105,116,111,110,97,108,32,65,68,80,67,32,99,104,117,110,107,10,0,0,110,111,110,45,101,120,105,115,116,105,110,103,32,83,80,83,32,37,117,32,114,101,102,101,114,101,110,99,101,100,10,0,109,105,99,114,111,100,118,100,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,54,0,65,83,85,83,32,86,50,0,67,97,98,97,114,101,116,0,32,67,52,52,52,32,88,89,83,67,83,83,61,52,52,52,0,0,0,0,0,0,0,0,56,115,118,120,95,102,105,98,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,105,110,118,97,108,105,100,32,102,112,115,32,40,37,100,47,37,100,41,10,0,0,0,0,85,115,105,110,103,32,100,101,102,97,117,108,116,32,118,105,100,101,111,32,116,105,109,101,32,98,97,115,101,32,115,105,110,99,101,32,104,97,118,105,110,103,32,110,111,32,97,117,100,105,111,32,112,97,99,107,101,116,32,98,101,102,111,114,101,32,116,104,101,32,102,105,114,115,116,32,118,105,100,101,111,32,112,97,99,107,101,116,0,0,0,0,0,0,0,0,109,103,115,116,115,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,53,0,56,83,86,88,32,101,120,112,111,110,101,110,116,105,97,108,0,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,83,116,97,116,105,115,116,105,99,115,58,32,37,108,108,100,32,98,121,116,101,115,32,114,101,97,100,44,32,37,100,32,115,101,101,107,115,10,0,0,110,97,109,101,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,111,112,101,110,32,116,104,101,32,39,37,115,39,32,112,114,111,116,111,99,111,108,32,102,111,114,32,119,114,105,116,105,110,103,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,52,0,108,105,98,97,118,102,111,114,109,97,116,47,97,118,105,101,110,99,46,99,0,0,0,0,56,115,118,120,95,101,120,112,0,0,0,0,0,0,0,0,102,105,108,101,32,37,115,10,0,0,0,0,0,0,0,0,104,50,54,52,95,109,112,52,116,111,97,110,110,101,120,98,0,0,0,0,0,0,0,0,40,105,110,116,54,52,95,116,41,115,116,50,45,62,116,105,109,101,95,98,97,115,101,46,110,117,109,32,42,32,97,115,116,50,45,62,114,97,116,101,32,61,61,32,40,105,110,116,54,52,95,116,41,115,116,50,45,62,116,105,109,101,95,98,97,115,101,46,100,101,110,32,42,32,97,115,116,50,45,62,115,99,97,108,101,0,0,0,111,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,51,0,115,51,50,98,101,32,100,101,109,117,120,101,114,0,0,0,69,120,97,99,116,108,121,32,111,110,101,32,65,83,83,47,83,83,65,32,115,116,114,101,97,109,32,105,115,32,110,101,101,100,101,100,46,10,0,0,71,46,55,50,57,0,0,0,101,120,112,108,111,100,101,0,116,105,116,108,101,0,0,0,69,114,114,111,114,32,115,116,99,45,62,109,115,98,95,112,116,115,95,115,104,105,102,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,109,100,53,0,0,0,0,0,103,101,110,101,114,97,116,105,111,110,95,117,105,100,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,50,0,97,115,102,45,62,112,97,99,107,101,116,95,115,105,122,101,95,108,101,102,116,32,60,32,70,82,65,77,69,95,72,69,65,68,69,82,95,83,73,90,69,32,124,124,32,97,115,102,45,62,112,97,99,107,101,116,95,115,101,103,109,101,110,116,115,32,60,32,49,0,0,0,103,55,50,57,0,0,0,0,45,45,62,62,32,37,100,0,115,101,110,100,95,98,121,101,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,102,114,97,109,101,115,58,32,37,117,10,0,0,0,0,80,83,78,82,61,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,116,114,97,99,107,32,105,100,32,37,100,10,0,0,0,0,0,0,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,115,116,101,114,101,111,32,109,111,100,101,32,105,115,32,110,111,116,32,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,70,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,105,109,97,103,101,32,102,114,111,109,32,102,105,108,101,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,49,0,71,46,55,50,51,46,49,0,80,73,67,0,0,0,0,0,109,101,97,110,95,118,111,108,117,109,101,58,32,37,46,49,102,32,100,66,10,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,98,97,109,97,95,87,101,115,116,0,0,118,111,108,117,109,101,58,37,102,32,118,111,108,117,109,101,95,100,66,58,37,102,10,0,103,55,50,51,95,49,0,0,115,101,116,32,109,105,110,105,109,117,109,32,100,117,114,97,116,105,111,110,32,105,110,32,115,101,99,111,110,100,115,0,45,97,112,97,100,32,105,115,32,102,111,114,119,97,114,100,101,100,32,116,111,32,108,97,118,102,105,32,115,105,109,105,108,97,114,108,121,32,116,111,32,45,97,102,32,97,112,97,100,61,37,115,46,10,0,0,105,32,60,32,40,115,105,122,101,111,102,40,102,114,101,113,105,110,102,111,115,41,32,47,32,115,105,122,101,111,102,40,40,102,114,101,113,105,110,102,111,115,41,91,48,93,41,41,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,117,116,32,99,104,97,110,110,101,108,32,110,97,109,101,32,34,37,46,56,115,34,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,98,97,109,97,95,69,97,115,116,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,106,111,105,110,46,99,0,0,0,67,111,110,115,116,114,97,105,110,101,100,32,69,110,101,114,103,121,32,76,97,112,112,101,100,32,84,114,97,110,115,102,111,114,109,32,40,67,69,76,84,41,0,0,0,0,0,0,115,101,116,32,116,105,109,101,32,111,118,101,114,32,119,104,105,99,104,32,100,101,99,114,101,97,115,101,32,111,102,32,118,111,108,117,109,101,32,105,115,32,100,101,116,101,114,109,105,110,101,100,0,0,0,0,100,101,102,97,117,108,116,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,37,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,109,97,112,112,101,100,32,37,100,46,10,0,0,0,0,0,0,100,115,116,95,118,95,99,104,114,95,112,111,115,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,99,101,108,116,0,0,0,0,98,97,110,100,112,97,115,115,0,0,0,0,0,0,0,0,102,117,108,108,0,0,0,0,98,103,114,52,52,52,108,101,0,0,0,0,0,0,0,0,71,111,108,100,101,110,82,111,100,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,53,46,48,0,0,0,0,0,98,97,121,101,114,0,0,0,111,117,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,48,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,100,101,102,97,117,108,116,0,69,82,82,79,82,58,32,115,116,101,112,95,105,110,100,101,120,91,37,100,93,32,61,32,37,105,10,0,0,0,0,0,83,116,101,114,101,111,32,82,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,83,116,101,114,101,111,32,82,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,85,110,107,110,111,119,110,32,69,82,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,37,100,0,0,0,0,0,81,68,101,115,105,103,110,32,77,117,115,105,99,0,0,0,73,110,118,97,108,105,100,32,85,84,70,45,56,32,105,110,32,100,101,99,111,100,101,100,32,115,117,98,116,105,116,108,101,115,32,116,101,120,116,59,32,109,97,121,98,101,32,109,105,115,115,105,110,103,32,45,115,117,98,95,99,104,97,114,101,110,99,32,111,112,116,105,111,110,10,0,0,0,0,0,115,50,0,0,0,0,0,0,99,50,95,111,112,97,99,105,116,121,0,0,0,0,0,0,76,105,110,101,97,114,95,77,105,108,101,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,78,97,117,116,105,99,97,108,0,0,0,0,0,0,80,101,97,107,32,108,101,118,101,108,32,100,66,58,32,37,102,10,0,0,0,0,0,0,117,115,101,32,111,110,108,121,32,98,105,116,101,120,97,99,116,32,102,117,110,99,116,105,111,110,115,32,40,101,120,99,101,112,116,32,40,73,41,68,67,84,41,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,73,32,99,98,112,121,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,102,105,114,115,116,32,102,105,101,108,100,32,109,105,115,115,105,110,103,10,0,0,0,0,93,10,0,0,0,0,0,0,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,84,72,80,32,118,105,100,101,111,0,0,0,0,0,84,105,109,101,32,98,97,115,101,32,105,115,32,105,110,97,99,99,117,114,97,116,101,10,0,0,0,0,0,0,0,0,80,80,83,32,99,104,97,110,103,101,32,102,114,111,109,32,37,100,32,116,111,32,37,100,32,102,111,114,98,105,100,100,101,110,10,0,0,0,0,0,109,105,100,95,115,105,100,101,0,0,0,0,0,0,0,0,67,111,117,112,108,105,110,103,32,83,116,97,114,116,32,66,97,110,100,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,112,97,100,0,0,0,0,0,97,115,118,50,0,0,0,0,78,97,116,105,118,101,32,65,109,101,114,105,99,97,110,0,32,67,52,50,50,32,88,89,83,67,83,83,61,52,50,50,0,0,0,0,0,0,0,0,113,100,109,99,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,111,117,116,95,103,97,105,110,0,0,0,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,111,102,32,115,105,108,101,110,99,101,32,116,111,32,97,100,100,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,109,105,120,46,99,0,0,0,65,65,67,32,76,65,84,77,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,32,76,65,84,77,32,115,121,110,116,97,120,41,0,0,0,0,115,101,116,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,97,32,115,105,110,103,108,101,32,97,108,108,111,99,97,116,101,100,32,98,108,111,99,107,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,115,46,10,0,32,32,32,32,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,102,97,100,101,45,105,110,0,109,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,97,97,99,95,108,97,116,109,0,0,0,0,0,0,0,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,108,105,115,116,32,101,110,116,114,121,32,39,37,115,39,32,105,110,32,108,105,115,116,32,102,105,108,101,10,0,0,0,0,0,59,32,99,111,110,102,105,103,61,0,0,0,0,0,0,0,100,101,99,97,121,91,37,100,93,58,32,37,102,32,105,115,32,111,117,116,32,111,102,32,97,108,108,111,119,101,100,32,114,97,110,103,101,58,32,40,48,44,32,49,93,10,0,0,37,102,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,115,51,50,108,101,32,100,101,109,117,120,101,114,0,0,0,66,105,110,107,32,65,117,100,105,111,32,40,68,67,84,41,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,100,101,116,101,99,116,32,105,109,112,114,111,112,101,114,32,98,105,116,115,116,114,101,97,109,32,108,101,110,103,116,104,0,0,0,0,0,0,0,0,69,114,114,111,114,32,115,116,99,45,62,116,105,109,101,95,98,97,115,101,95,105,100,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,95,112,108,97,116,102,111,114,109,0,0,0,0,116,101,115,116,115,114,99,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,109,97,120,95,97,108,108,111,99,0,0,0,0,0,0,0,98,105,110,107,97,117,100,105,111,95,100,99,116,0,0,0,114,97,116,101,0,0,0,0,85,115,101,32,109,111,100,101,32,48,32,102,111,114,32,72,50,54,52,32,105,110,32,82,84,80,0,0,0,0,0,0,37,88,0,0,0,0,0,0,103,101,116,95,119,97,118,95,104,101,97,100,101,114,32,102,97,105,108,101,100,10,0,0,86,95,77,83,47,86,70,87,47,70,79,85,82,67,67,0,37,89,45,37,109,45,37,100,32,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,77,111,108,100,32,99,111,108,111,114,32,105,115,32,115,101,116,32,119,104,105,108,101,32,109,111,108,100,32,105,115,110,39,116,44,32,105,103,110,111,114,105,110,103,32,116,104,101,32,99,111,108,111,114,46,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,66,105,110,107,32,65,117,100,105,111,32,40,82,68,70,84,41,0,0,0,0,0,0,0,71,69,79,66,0,0,0,0,119,58,37,100,10,0,0,0,115,101,110,100,95,102,105,101,108,100,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,100,101,105,110,116,0,0,0,98,105,110,107,97,117,100,105,111,95,114,100,102,116,0,0,97,102,111,114,109,97,116,0,104,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,108,117,109,97,95,109,115,105,122,101,95,121,0,0,0,0,65,84,82,65,67,49,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,41,0,0,0,0,0,99,108,111,99,107,0,0,0,54,120,53,0,0,0,0,0,100,101,102,97,117,108,116,0,100,115,116,95,104,95,99,104,114,95,112,111,115,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,115,101,108,101,99,116,32,102,105,114,115,116,32,102,105,101,108,100,0,0,0,0,0,0,97,116,114,97,99,49,0,0,78,79,80,84,83,0,0,0,98,102,102,0,0,0,0,0,101,110,97,98,108,101,32,99,111,109,98,109,97,116,99,104,105,110,103,32,111,110,108,121,32,111,110,32,115,99,101,110,101,32,99,104,97,110,103,101,0,0,0,0,0,0,0,0,114,103,98,52,52,52,98,101,0,0,0,0,0,0,0,0,71,111,108,100,0,0,0,0,34,37,115,34,0,0,0,0,51,46,49,0,0,0,0,0,108,101,97,118,101,32,99,104,111,105,99,101,32,116,111,32,115,119,115,0,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,0,0,0,0,109,97,116,114,111,115,107,97,44,119,101,98,109,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,109,105,115,109,97,116,99,104,32,105,110,32,99,111,100,101,100,32,115,97,109,112,108,101,32,99,111,117,110,116,10,0,115,116,101,114,101,111,95,114,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,115,116,101,114,101,111,95,114,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,105,110,105,116,105,97,108,105,122,105,110,103,32,108,97,116,109,99,116,120,10,0,0,0,100,101,102,97,117,108,116,0,77,80,69,71,45,52,32,65,117,100,105,111,32,76,111,115,115,108,101,115,115,32,67,111,100,105,110,103,32,40,65,76,83,41,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,101,100,105,97,32,116,121,112,101,32,102,111,114,32,115,117,98,116,105,116,108,101,115,10,0,0,0,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,49,32,111,112,97,99,105,116,121,0,0,76,105,110,101,97,114,95,70,97,116,104,111,109,0,0,0,109,52,118,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,98,105,116,101,120,97,99,116,0,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,112,105,99,116,117,114,101,32,115,105,122,101,32,111,102,32,37,100,120,37,100,32,105,115,32,110,111,116,32,118,97,108,105,100,32,102,111,114,32,116,104,101,32,72,46,50,54,51,32,99,111,100,101,99,46,10,86,97,108,105,100,32,115,105,122,101,115,32,97,114,101,32,49,50,56,120,57,54,44,32,49,55,54,120,49,52,52,44,32,51,53,50,120,50,56,56,44,32,55,48,52,120,53,55,54,44,32,97,110,100,32,49,52,48,56,120,49,49,53,50,46,32,84,114,121,32,72,46,50,54,51,43,46,10,0,0,0,0,73,32,99,98,112,99,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,99,32,99,111,100,101,32,97,116,10,0,0,0,0,0,116,104,112,0,0,0,0,0,110,111,110,45,101,120,105,115,116,105,110,103,32,80,80,83,32,37,117,32,114,101,102,101,114,101,110,99,101,100,10,0,114,105,103,104,116,95,115,105,100,101,0,0,0,0,0,0,99,112,108,95,115,116,97,114,116,95,98,97,110,100,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,105,119,0,0,0,0,0,0,65,83,85,83,32,86,49,0,74,117,110,103,108,101,0,0,115,101,116,32,98,105,116,109,97,112,32,102,105,108,101,110,97,109,101,0,0,0,0,0,32,67,52,50,48,106,112,101,103,32,88,89,83,67,83,83,61,52,50,48,74,80,69,71,0,0,0,0,0,0,0,0,109,112,52,97,108,115,0,0,108,97,118,102,105,46,112,115,110,114,46,109,115,101,95,97,118,103,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,57,78,0,0,0,104,101,105,103,104,116,0,0,84,114,117,101,72,68,0,0,46,0,0,0,0,0,0,0,108,120,102,0,0,0,0,0,109,97,105,110,95,119,0,0,101,110,100,32,37,102,10,0,108,118,102,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,56,78,0,0,0,116,114,117,101,104,100,0,0,97,108,108,115,0,0,0,0,35,69,88,84,73,78,70,58,37,102,44,10,37,115,10,0,108,111,97,115,0,0,0,0,84,111,111,32,109,117,99,104,32,101,120,116,114,97,100,97,116,97,33,10,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,109,101,114,103,101,112,108,97,110,101,115,46,99,0,0,0,0,108,109,108,109,52,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,55,78,0,0,0,115,50,52,98,101,32,100,101,109,117,120,101,114,0,0,0,114,101,112,101,97,116,108,97,115,116,0,0,0,0,0,0,86,81,70,32,84,119,105,110,86,81,0,0,0,0,0,0,98,117,102,102,101,114,0,0,85,110,107,110,111,119,110,32,99,111,100,101,99,32,116,97,103,32,39,48,120,37,48,52,120,39,32,102,111,114,32,115,116,114,101,97,109,32,110,117,109,98,101,114,32,37,100,10,0,0,0,0,0,0,0,0,110,101,103,97,116,101,0,0,109,111,100,105,102,105,99,97,116,105,111,110,95,100,97,116,101,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,54,78,0,0,0,105,110,116,101,114,108,101,97,118,101,0,0,0,0,0,0,116,119,105,110,118,113,0,0,112,114,111,103,95,116,104,114,101,115,0,0,0,0,0,0,104,50,54,52,95,109,111,100,101,48,0,0,0,0,0,0,108,97,116,109,0,0,0,0,76,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,102,111,114,32,99,109,111,118,32,97,116,111,109,32,33,10,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,37,115,10,0,0,0,0,0,0,0,86,95,81,85,73,67,75,84,73,77,69,0,0,0,0,0,83,83,82,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,53,78,0,0,0,115,101,116,32,104,105,115,116,111,103,114,97,109,32,109,111,100,101,0,0,0,0,0,0,77,80,49,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,49,41,0,0,0,0,0,0,0,0,71,69,79,0,0,0,0,0,84,104,101,32,110,101,105,103,104,98,111,114,104,111,111,100,32,116,111,32,102,105,116,32,116,104,101,32,103,114,97,100,105,101,110,116,32,116,111,46,0,0,0,0,0,0,0,0,106,118,0,0,0,0,0,0,116,97,98,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,52,78,0,0,0,115,116,97,114,116,95,116,105,109,101,0,0,0,0,0,0,106,97,99,111,115,117,98,0,100,101,102,97,117,108,116,0,109,112,49,0,0,0,0,0,116,102,102,0,0,0,0,0,97,117,100,105,111,32,102,111,114,109,97,116,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,100,97,116,97,0,0,0,0,84,105,109,101,99,111,100,101,32,102,114,97,109,101,32,114,97,116,101,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,10,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,51,78,0,0,0,121,117,118,52,49,48,112,0,82,101,97,108,65,117,100,105,111,32,83,73,80,82,32,47,32,65,67,69,76,80,46,78,69,84,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,97,110,110,111,116,32,102,105,110,100,32,99,111,108,111,114,32,39,37,115,39,10,0,115,101,108,101,99,116,32,116,111,112,32,102,105,101,108,100,0,0,0,0,0,0,0,0,65,86,95,76,79,71,95,70,79,82,67,69,95,78,79,67,79,76,79,82,0,0,0,0,73,77,71,85,84,73,76,83,0,0,0,0,0,0,0,0,83,72,65,49,54,48,0,0,89,67,103,67,111,0,0,0,0,0,0,255,0,0,0,0,99,111,115,104,0,0,0,0,66,85,70,70,69,82,95,84,79,79,95,83,77,65,76,76,0,0,0,0,0,0,0,0,115,114,99,95,118,95,99,104,114,95,112,111,115,0,0,0,80,67,83,95,77,95,112,111,114,97,108,111,107,111,95,85,84,77,95,51,50,83,0,0,102,114,111,110,116,32,108,101,102,116,0,0,0,0,0,0,115,101,116,32,112,108,97,110,101,115,0,0,0,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,37,115,32,45,62,32,37,115,32,99,111,110,118,101,114,116,101,114,10,0,0,0,0,0,0,115,105,112,114,0,0,0,0,69,120,97,99,116,108,121,32,111,110,101,32,115,99,97,108,101,114,32,97,108,103,111,114,105,116,104,109,32,109,117,115,116,32,98,101,32,99,104,111,115,101,110,44,32,103,111,116,32,37,88,10,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,115,101,116,32,109,97,120,32,110,117,109,98,101,114,32,111,102,32,115,116,101,112,115,32,117,115,101,100,32,116,111,32,99,111,109,112,117,116,101,32,116,104,101,32,109,97,112,112,105,110,103,0,0,0,0,0,98,105,99,117,98,105,99,0,106,97,99,111,115,117,98,0,100,101,102,97,117,108,116,0,105,115,102,0,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,115,99,0,0,0,0,0,0,114,103,98,52,52,52,108,101,0,0,0,0,0,0,0,0,71,104,111,115,116,87,104,105,116,101,0,0,0,0,0,0,37,108,108,88,0,0,0,0,69,78,68,72,68,82,0,0,113,117,97,100,40,115,105,100,101,41,0,0,0,0,0,0,97,117,116,111,0,0,0,0,105,110,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,0,115,45,62,108,105,110,101,115,105,122,101,32,61,61,32,99,45,62,115,116,114,105,100,101,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,80,67,83,95,77,95,112,111,114,97,108,111,107,111,95,85,84,77,95,51,50,78,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,105,110,32,112,97,99,107,101,116,10,0,0,0,0,72,68,67,68,0,0,0,0,72,68,67,68,0,0,0,0,97,117,100,105,111,32,99,111,110,102,105,103,32,99,104,97,110,103,101,100,10,0,0,0,105,118,102,0,0,0,0,0,10,0,0,0,0,0,0,0,115,101,116,32,80,104,111,116,111,115,104,111,112,32,99,117,114,118,101,115,32,102,105,108,101,32,110,97,109,101,0,0,65,84,83,67,32,65,47,53,50,66,32,40,65,67,45,51,44,32,69,45,65,67,45,51,41,0,0,0,0,0,0,0,97,102,113,45,62,114,101,109,97,105,110,105,110,103,95,115,97,109,112,108,101,115,32,61,61,32,97,102,113,45,62,114,101,109,97,105,110,105,110,103,95,100,101,108,97,121,0,0,83,70,32,109,111,100,101,32,49,58,32,105,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,115,33,10,0,100,105,115,99,97,114,100,32,37,100,47,37,100,32,115,97,109,112,108,101,115,10,0,0,99,49,95,111,112,97,99,105,116,121,0,0,0,0,0,0,92,37,49,91,49,50,51,52,93,99,37,49,91,92,125,93,37,110,0,0,0,0,0,0,76,105,110,101,97,114,95,89,97,114,100,95,73,110,100,105,97,110,0,0,0,0,0,0,13,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,70,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,97,108,108,32,99,104,97,110,110,101,108,115,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,97,100,112,99,109,95,115,119,102,0,0,0,0,0,0,0,112,99,109,95,115,50,52,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,99,120,58,32,37,100,44,32,99,121,58,32,37,100,44,32,99,119,58,32,37,100,44,32,99,104,58,32,37,100,44,32,114,120,58,32,37,100,44,32,114,121,58,32,37,100,44,32,101,100,103,101,58,32,37,100,32,98,108,111,99,107,115,105,122,101,58,32,37,100,32,99,111,110,116,114,97,115,116,58,32,37,100,32,115,101,97,114,99,104,58,32,37,100,10,0,112,108,97,99,101,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,32,105,110,32,101,120,116,114,97,100,97,116,97,32,105,110,115,116,101,97,100,32,111,102,32,101,118,101,114,121,32,107,101,121,102,114,97,109,101,0,0,0,0,0,97,100,112,99,109,95,100,116,107,0,0,0,0,0,0,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,112,105,99,116,117,114,101,32,115,105,122,101,32,111,102,32,37,100,120,37,100,32,105,115,32,110,111,116,32,118,97,108,105,100,32,102,111,114,32,116,104,101,32,72,46,50,54,49,32,99,111,100,101,99,46,10,86,97,108,105,100,32,115,105,122,101,115,32,97,114,101,32,49,55,54,120,49,52,52,44,32,51,53,50,120,50,56,56,10,0,37,108,108,100,9,0,0,0,105,108,108,101,103,97,108,32,77,66,95,116,121,112,101,10,0,0,0,0,0,0,0,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,77,74,80,69,71,32,40,77,111,116,105,111,110,32,74,80,69,71,41,0,0,0,0,0,65,67,45,51,32,69,110,99,111,100,101,114,0,0,0,0,70,105,120,101,100,45,80,111,105,110,116,32,65,67,45,51,32,69,110,99,111,100,101,114,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,97,117,100,105,111,32,115,101,114,118,105,99,101,32,116,121,112,101,32,102,111,114,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,0,112,112,115,95,105,100,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,100,114,99,95,115,99,97,108,101,0,0,0,0,0,0,0,108,101,102,116,95,115,105,100,101,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,83,101,108,101,99,116,101,100,32,98,121,32,116,104,101,32,69,110,99,111,100,101,114,0,105,118,102,0,0,0,0,0,80,67,83,95,77,111,110,116,101,95,77,97,114,105,111,95,73,116,97,108,121,95,50,0,32,32,35,37,100,58,32,116,111,116,100,105,102,102,61,37,48,56,108,108,120,32,109,97,120,98,100,105,102,102,61,37,48,56,108,108,120,37,115,37,115,37,115,37,115,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,10,0,0,0,0,0,97,115,118,49,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,65,65,67,32,102,114,97,109,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,80,111,112,47,70,117,110,107,0,0,0,0,0,0,0,0,32,67,52,50,48,109,112,101,103,50,32,88,89,83,67,83,83,61,52,50,48,77,80,69,71,50,0,0,0,0,0,0,101,97,99,51,0,0,0,0,111,118,101,114,108,97,112,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,112,105,99,116,117,114,101,46,10,0,0,0,0,0,0,0,0,70,111,114,109,97,116,32,37,105,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,105,110,102,108,97,116,101,58,32,37,100,46,10,0,0,0,0,0,0,77,105,115,115,105,110,103,32,111,114,32,105,110,99,111,109,112,108,101,116,101,32,101,120,116,114,97,100,97,116,97,46,10,0,0,0,0,0,0,0,67,104,114,111,109,97,32,117,110,112,97,99,107,105,110,103,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,114,101,100,32,37,48,120,44,32,103,114,101,101,110,32,37,48,120,44,32,98,108,117,101,32,37,48,120,10,0,0,0,67,111,108,111,114,32,105,110,100,101,120,32,48,32,105,115,32,110,111,116,32,116,114,97,110,115,112,97,114,101,110,116,46,32,84,114,97,110,115,112,97,114,101,110,99,121,32,119,105,108,108,32,98,101,32,109,101,115,115,101,100,32,117,112,46,10,0,0,0,0,0,0,10,0,0,0,0,0,0,0,95,119,105,100,116,104,0,0,118,101,99,116,111,114,95,115,101,103,109,101,110,116,32,111,118,101,114,114,101,97,100,10,0,0,0,0,0,0,0,0,119,109,118,50,0,0,0,0,10,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,105,110,116,101,114,32,98,108,111,99,107,58,32,37,100,32,120,32,37,100,32,40,37,100,41,10,0,0,0,0,0,0,0,0,115,105,122,101,32,60,61,32,49,54,48,32,47,32,50,0,82,101,115,101,114,118,101,100,32,98,105,116,0,0,0,0,65,114,105,116,104,109,101,116,105,99,32,99,111,100,105,110,103,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,110,98,95,102,114,97,109,101,115,32,105,115,32,37,100,10,0,0,0,0,0,0,0,0,123,92,105,49,125,0,0,0,115,107,105,112,112,105,110,103,32,117,110,115,117,112,112,111,114,116,101,100,32,65,76,80,72,65,32,99,104,117,110,107,10,0,0,0,0,0,0,0,87,97,118,80,97,99,107,32,101,110,99,111,100,101,114,0,67,111,110,116,101,120,116,32,102,111,114,32,98,108,111,99,107,32,37,100,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,10,0,0,0,0,112,114,111,98,108,101,109,58,32,67,66,70,48,32,99,104,117,110,107,32,116,111,111,32,108,97,114,103,101,32,40,48,120,37,88,32,98,121,116,101,115,41,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,112,57,46,99,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,97,114,116,32,99,111,100,101,32,48,120,37,120,10,0,0,0,0,0,0,0,0,73,110,116,101,114,108,97,99,105,110,103,0,0,0,0,0,105,118,56,0,0,0,0,0,105,110,102,105,110,105,116,121,0,0,0,0,0,0,0,0,72,101,97,100,101,114,32,112,97,99,107,101,116,32,112,97,115,115,101,100,32,116,111,32,102,114,97,109,101,32,100,101,99,111,100,101,114,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,0,32,37,48,50,88,0,0,0,114,101,97,108,95,99,104,32,61,61,32,50,0,0,0,0,80,67,83,95,77,111,110,116,101,95,77,97,114,105,111,95,73,116,97,108,121,95,49,0,78,111,116,32,97,32,86,111,114,98,105,115,32,73,32,97,117,100,105,111,32,112,97,99,107,101,116,46,10,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,103,110,97,116,117,114,101,32,105,110,32,83,101,116,117,112,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,68,101,112,116,104,32,109,105,115,109,97,116,99,104,46,32,67,111,110,116,97,105,110,101,114,32,37,105,32,98,112,112,44,32,70,114,97,109,101,32,100,97,116,97,58,32,37,105,32,98,112,112,10,0,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,98,121,116,101,115,116,114,101,97,109,95,101,110,100,32,45,32,98,121,116,101,115,116,114,101,97,109,32,62,61,32,97,118,99,116,120,45,62,119,105,100,116,104,32,47,32,50,0,118,99,49,105,109,97,103,101,0,0,0,0,0,0,0,0,65,84,82,65,67,51,43,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,32,51,43,41,0,103,101,110,101,114,97,116,101,32,97,32,114,101,112,111,114,116,0,0,0,0,0,0,0,49,32,102,111,114,32,114,101,115,101,114,118,101,100,32,82,69,83,95,84,82,65,78,83,84,65,66,32,105,115,32,102,111,114,98,105,100,100,101,110,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,112,99,111,100,101,32,115,101,101,110,32,64,37,100,10,0,0,0,0,0,0,0,0,111,117,116,95,104,0,0,0,98,105,116,115,32,112,101,114,32,114,97,119,32,115,97,109,112,108,101,58,32,37,100,32,33,61,32,49,48,45,98,105,116,10,0,0,0,0,0,0,99,117,115,116,111,109,95,115,116,114,105,100,101,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,114,97,109,101,32,119,105,116,104,32,103,114,97,100,105,101,110,116,32,112,114,101,100,105,99,116,105,111,110,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,10,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,115,116,97,114,116,32,37,102,44,32,0,0,0,0,0,0,84,104,105,115,32,118,101,114,115,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,37,100,32,107,72,122,32,45,32,37,100,32,107,98,105,116,47,115,47,99,104,32,109,111,100,101,46,10,0,0,0,0,0,0,114,98,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,84,111,111,32,109,97,110,121,32,115,108,105,99,101,32,112,114,111,112,101,114,116,105,101,115,10,0,0,0,0,0,0,105,115,115,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,77,86,32,111,117,116,32,111,102,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,32,116,121,112,101,32,40,37,100,41,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,77,104,97,115,116,95,85,84,77,95,122,111,110,101,95,51,50,83,0,0,98,115,0,0,0,0,0,0,97,116,114,97,99,51,112,0,44,37,102,44,37,102,10,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,116,104,101,32,99,111,110,102,105,103,32,105,110,102,111,46,10,0,0,0,0,117,110,100,0,0,0,0,0,71,101,111,103,80,114,105,109,101,77,101,114,105,100,105,97,110,71,101,111,75,101,121,0,37,115,32,102,105,108,101,115,32,104,97,118,101,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1954438);
/* memory initializer */ allocate([101,120,97,99,116,108,121,32,111,110,101,32,115,116,114,101,97,109,10,0,0,0,0,0,0,0,87,114,105,116,105,110,103,32,109,101,116,97,100,97,116,97,32,119,105,116,104,32,107,101,121,32,39,37,115,39,32,102,97,105,108,101,100,10,0,0,115,117,98,118,105,101,119,101,114,49,0,0,0,0,0,0,80,97,108,101,116,116,101,32,101,110,116,114,121,32,115,105,122,101,32,37,105,32,98,105,116,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,0,0,0,80,67,83,95,77,105,110,110,97,95,78,105,103,101,114,105,97,95,69,97,115,116,0,0,83,87,0,0,0,0,0,0,102,114,97,109,101,32,110,117,109,32,37,100,32,105,110,99,111,109,112,108,101,116,101,32,112,105,99,32,120,32,37,100,32,121,32,37,100,32,108,101,102,116,32,37,100,10,0,0,98,101,115,116,95,118,101,99,116,111,114,95,109,101,97,110,32,33,61,32,45,57,57,57,0,0,0,0,0,0,0,0,99,111,100,101,114,0,0,0,105,110,118,97,108,105,100,32,99,111,108,111,114,109,97,112,32,116,121,112,101,10,0,0,13,10,0,0,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,65,83,83,32,101,118,101,110,116,46,10,0,0,0,0,0,0,0,0,115,50,52,108,101,32,100,101,109,117,120,101,114,0,0,0,123,92,102,110,125,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,76,111,115,115,108,101,115,115,0,0,0,0,82,101,115,111,108,117,116,105,111,110,32,116,111,111,32,108,111,119,10,0,0,0,0,0,69,114,114,111,114,32,115,45,62,115,112,97,116,105,97,108,95,100,101,99,111,109,112,111,115,105,116,105,111,110,95,99,111,117,110,116,32,105,115,32,37,100,10,0,0,0,0,0,49,0,0,0,0,0,0,0,101,110,99,111,117,110,116,101,114,101,100,32,114,101,112,101,97,116,32,98,108,111,99,107,32,111,112,99,111,100,101,32,40,37,48,50,88,41,32,98,117,116,32,110,111,116,32,101,110,111,117,103,104,32,98,108,111,99,107,115,32,114,101,110,100,101,114,101,100,32,121,101,116,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,112,105,99,116,117,114,101,32,98,108,97,99,107,32,114,97,116,105,111,32,116,104,114,101,115,104,111,108,100,0,0,0,100,101,116,101,99,116,32,98,105,116,115,116,114,101,97,109,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,100,101,118,105,97,116,105,111,110,115,0,0,0,0,0,0,0,83,111,117,110,100,58,32,110,111,32,100,97,116,97,10,0,105,114,99,97,109,0,0,0,53,107,48,0,0,0,0,0,111,118,101,114,114,101,97,100,58,32,37,100,10,0,0,0,119,114,111,110,103,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,10,0,0,0,115,117,98,99,111,100,101,99,32,37,100,58,32,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,102,114,97,109,101,10,0,0,0,0,0,0,73,68,61,34,83,111,117,114,99,101,34,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,111,114,32,117,110,107,110,111,119,110,32,115,108,105,99,101,32,104,101,97,100,101,114,10,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,105,110,116,114,97,32,112,114,101,100,105,99,116,105,111,110,32,99,111,100,101,10,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,115,45,62,109,111,100,105,102,105,101,100,95,113,117,97,110,116,61,61,49,0,0,0,0,72,69,65,68,69,82,32,69,82,82,79,82,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,113,117,97,107,101,51,95,99,111,109,112,97,116,0,0,0,117,110,107,110,111,119,110,32,115,116,114,101,97,109,32,99,108,97,115,115,32,40,37,100,41,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,109,118,0,0,0,0,0,0,73,39,109,32,112,101,100,97,108,105,110,103,32,98,97,99,107,119,97,114,100,115,10,0,112,114,111,100,117,99,116,95,117,105,100,0,0,0,0,0,65,118,105,100,32,49,58,49,32,49,48,45,98,105,116,32,82,71,66,32,80,97,99,107,101,114,0,0,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,48,0,0,0,0,0,0,0,118,97,108,117,101,32,37,100,32,105,110,32,113,100,109,50,95,103,101,116,95,118,108,99,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,112,105,116,99,104,32,102,105,108,116,101,114,46,0,105,114,99,97,109,0,0,0,116,111,111,32,108,97,114,103,101,32,113,117,97,110,116,105,115,101,114,44,32,109,97,120,105,109,117,109,32,105,115,32,54,52,10,0,0,0,0,0,110,101,101,100,32,89,85,86,52,50,50,80,49,48,10,0,112,105,99,116,117,114,101,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,105,110,118,97,108,105,100,32,112,108,97,110,101,32,100,97,116,97,32,115,105,122,101,10,0,0,0,0,0,0,0,0,80,67,83,95,77,105,110,110,97,95,78,105,103,101,114,105,97,95,77,105,100,95,66,101,108,116,0,0,0,0,0,0,80,80,77,32,40,80,111,114,116,97,98,108,101,32,80,105,120,101,108,77,97,112,41,32,105,109,97,103,101,0,0,0,112,98,109,0,0,0,0,0,73,110,112,117,116,32,102,114,97,109,101,32,115,105,122,101,115,32,100,111,32,110,111,116,32,109,97,116,99,104,32,40,37,100,120,37,100,32,118,115,32,37,100,120,37,100,41,46,10,0,0,0,0,0,0,0,79,110,108,121,32,111,110,101,32,111,102,32,39,100,112,105,39,32,111,114,32,39,100,112,109,39,32,111,112,116,105,111,110,115,32,115,104,111,117,108,100,32,98,101,32,115,101,116,10,0,0,0,0,0,0,0,99,104,117,110,107,32,116,111,111,32,98,105,103,10,0,0,83,117,98,116,105,116,108,101,32,111,117,116,32,111,102,32,118,105,100,101,111,32,98,111,117,110,100,115,46,32,120,32,61,32,37,100,44,32,121,32,61,32,37,100,44,32,118,105,100,101,111,32,119,105,100,116,104,32,61,32,37,100,44,32,118,105,100,101,111,32,104,101,105,103,104,116,32,61,32,37,100,46,10,0,0,0,0,0,70,105,108,101,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,114,101,112,111,114,116,0,0,119,109,97,108,111,115,115,108,101,115,115,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,117,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,100,101,112,116,104,32,40,37,100,41,10,0,0,82,71,66,95,65,76,80,72,65,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,105,109,101,115,116,97,109,112,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,100,114,111,112,112,101,100,32,97,103,97,105,110,0,0,0,0,0,0,0,105,112,109,111,118,105,101,0,68,111,110,39,116,32,115,101,110,100,32,82,84,67,80,32,115,101,110,100,101,114,32,114,101,112,111,114,116,115,0,0,102,112,115,61,37,46,49,102,10,0,0,0,0,0,0,0,115,121,115,116,101,109,66,105,116,114,97,116,101,61,34,0,79,110,108,121,32,86,80,56,44,86,80,57,32,118,105,100,101,111,32,97,110,100,32,86,111,114,98,105,115,44,79,112,117,115,40,101,120,112,101,114,105,109,101,110,116,97,108,44,32,117,115,101,32,45,115,116,114,105,99,116,32,45,50,41,32,97,117,100,105,111,32,97,110,100,32,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,87,101,98,77,46,10,0,0,0,0,76,67,0,0,0,0,0,0,115,101,116,32,102,111,114,109,97,116,32,110,97,109,101,0,85,110,107,110,111,119,110,32,115,101,99,111,110,100,97,114,121,32,102,114,97,109,101,32,104,101,97,100,101,114,32,40,119,114,111,110,103,32,99,111,100,101,99,95,116,97,103,63,41,10,0,0,0,0,0,0,67,97,110,32,110,111,116,32,112,114,111,99,101,115,115,32,83,79,83,32,119,105,116,104,111,117,116,32,83,79,70,32,100,97,116,97,44,32,115,107,105,112,112,105,110,103,10,0,100,101,102,97,117,108,116,0,80,67,83,95,77,105,110,110,97,95,78,105,103,101,114,105,97,95,87,101,115,116,0,0,98,117,102,102,101,114,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,0,69,109,112,116,121,32,102,114,97,109,101,32,102,111,117,110,100,32,98,117,116,32,105,116,32,105,115,32,110,111,116,32,97,32,115,107,105,112,32,102,114,97,109,101,46,10,0,0,75,101,121,102,114,97,109,101,32,119,105,116,104,111,117,116,32,100,97,116,97,32,102,111,117,110,100,10,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,57,32,80,114,111,102,101,115,115,105,111,110,97,108,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,115,115,50,46,99,0,0,0,0,0,0,0,105,110,103,101,110,105,101,110,116,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,103,101,97,98,108,101,32,112,97,108,101,116,116,101,32,101,110,116,114,105,101,115,58,32,37,100,10,0,0,0,0,0,77,83,32,82,76,69,58,32,102,114,97,109,101,47,115,116,114,101,97,109,32,112,116,114,32,106,117,115,116,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,99,111,112,121,41,10,0,0,0,0,0,0,0,0,65,100,118,97,110,99,101,100,32,103,108,111,98,97,108,32,111,112,116,105,111,110,115,58,0,0,0,0,0,0,0,0,123,92,114,125,0,0,0,0,99,111,109,109,101,110,116,0,113,112,95,114,100,0,0,0,115,114,99,45,62,102,46,98,117,102,91,48,93,0,0,0,80,84,83,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,97,117,100,105,111,101,110,99,95,116,101,109,112,108,97,116,101,46,99,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,97,117,100,105,111,101,110,99,95,116,101,109,112,108,97,116,101,46,99,0,0,0,0,0,0,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,0,0,0,0,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,0,0,0,0,77,80,69,71,52,32,101,110,99,111,100,101,114,0,0,0,67,97,110,110,111,116,32,99,114,101,97,116,101,32,116,104,101,32,108,105,110,107,32,37,115,58,37,100,32,45,62,32,37,115,58,37,100,10,0,0,69,114,114,111,114,44,32,118,105,100,101,111,32,112,97,99,107,101,116,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,40,98,95,99,111,100,101,61,48,41,10,0,0,77,80,69,71,45,50,32,118,105,100,101,111,0,0,0,0,80,67,83,95,77,105,110,110,97,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,72,105,103,104,0,0,0,0,73,110,105,116,105,110,103,32,86,76,67,10,0,0,0,0,37,100,32,99,104,97,110,110,101,108,115,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,111,118,116,101,120,116,101,110,99,46,99,0,119,109,97,112,114,111,0,0,73,110,118,97,108,105,100,32,110,111,110,114,101,115,116,97,114,116,95,115,117,98,115,116,114,46,10,0,0,0,0,0,77,74,80,69,71,32,40,77,111,116,105,111,110,32,74,80,69,71,41,0,0,0,0,0,113,115,99,97,108,101,91,37,100,93,58,32,37,100,10,0,100,113,116,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,46,10,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,61,37,115,58,0,0,0,0,0,68,111,110,39,116,32,116,114,121,32,116,111,32,114,101,115,121,110,99,104,114,111,110,105,122,101,32,98,121,32,108,111,111,107,105,110,103,32,102,111,114,32,97,32,99,101,114,116,97,105,110,32,111,112,116,105,111,110,97,108,32,115,116,97,114,116,32,99,111,100,101,0,123,92,37,99,48,125,0,0,102,105,102,111,45,62,114,111,111,116,46,110,101,120,116,0,73,110,118,97,108,105,100,32,119,105,110,100,111,119,32,116,121,112,101,44,32,98,114,111,107,101,110,32,115,97,109,112,108,101,63,10,0,0,0,0,69,120,116,114,97,100,97,116,97,32,115,105,122,101,32,109,117,115,116,32,98,101,32,62,61,32,49,50,32,105,110,115,116,101,97,100,32,111,102,32,37,105,10,0,0,0,0,0,97,118,99,116,120,45,62,119,105,100,116,104,32,38,38,32,97,118,99,116,120,45,62,104,101,105,103,104,116,0,0,0,77,116,104,114,101,97,100,50,32,100,101,99,111,100,101,100,32,115,105,122,101,32,100,105,102,102,101,114,115,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,0,0,0,0,105,110,116,98,0,0,0,0,73,110,118,97,108,105,100,32,122,101,114,111,32,114,117,110,32,101,115,99,97,112,101,32,99,111,100,101,33,32,40,37,35,120,41,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,49,54,98,105,116,32,120,102,114,109,0,0,0,0,0,0,119,105,100,116,104,32,60,61,32,54,52,0,0,0,0,0,74,76,0,0,0,0,0,0,114,97,116,101,32,99,111,110,116,114,111,108,10,0,0,0,66,117,102,102,101,114,32,99,111,110,116,97,105,110,115,32,73,80,32,102,114,97,109,101,115,33,10,0,0,0,0,0,80,67,83,95,77,105,110,110,97,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,32,65,73,67,0,0,0,0,73,110,118,97,108,105,100,32,100,101,99,111,100,101,32,116,121,112,101,44,32,99,111,114,114,117,112,116,101,100,32,104,101,97,100,101,114,63,10,0,66,97,100,32,118,97,108,117,101,32,102,111,114,32,114,101,115,101,114,118,101,100,32,102,105,101,108,100,10,0,0,0,84,111,111,32,109,97,110,121,32,99,111,114,114,101,99,116,105,111,110,115,58,32,37,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,97,110,100,32,104,101,97,100,101,114,32,115,101,113,117,101,110,99,101,33,10,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,101,108,108,58,32,120,61,37,100,44,32,121,61,37,100,44,32,119,61,37,100,44,32,104,61,37,100,10,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,86,111,105,99,101,0,0,0,0,0,0,0,102,114,97,109,101,32,104,101,97,100,101,114,32,99,104,101,99,107,32,102,97,105,108,101,100,33,10,0,0,0,0,0,98,105,116,109,97,112,32,40,99,111,109,112,114,101,115,115,105,111,110,32,37,105,44,32,98,112,112,32,37,105,44,32,104,97,109,32,37,105,41,0,37,108,108,117,32,0,0,0,66,71,82,50,52,32,111,117,116,112,117,116,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,10,0,0,0,0,65,116,116,101,109,112,116,105,110,103,32,116,111,32,119,114,105,116,101,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,118,112,115,95,109,97,120,95,115,117,98,95,108,97,121,101,114,115,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,109,105,115,109,97,116,99,104,105,110,103,32,99,104,101,99,107,115,117,109,32,111,102,32,112,108,97,110,101,32,37,100,32,45,32,0,0,0,0,0,99,111,108,95,105,110,116,101,114,108,101,97,118,101,100,95,108,114,0,0,0,0,0,0,105,108,108,101,103,97,108,32,114,101,111,114,100,101,114,105,110,103,95,111,102,95,112,105,99,95,110,117,109,115,95,105,100,99,10,0,0,0,0,0,105,109,97,103,101,50,0,0,108,111,103,50,95,109,97,120,95,112,111,99,95,108,115,98,32,40,37,100,41,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,115,99,101,110,101,0,0,0,80,32,115,117,98,95,109,98,95,116,121,112,101,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,32,97,116,32,37,100,32,37,100,10,0,115,114,99,95,104,95,99,104,114,95,112,111,115,0,0,0,97,118,99,67,32,37,100,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,80,67,83,95,77,97,115,115,97,119,97,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,0,0,0,0,0,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,46,102,46,112,105,99,116,95,116,121,112,101,32,61,61,32,115,45,62,112,105,99,116,95,116,121,112,101,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,32,97,108,105,103,110,109,101,110,116,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,46,10,0,0,0,0,0,0,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,80,65,76,56,0,0,0,0,0,0,0,112,105,116,99,104,95,100,101,108,97,121,95,105,110,116,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,37,100,10,0,0,0,0,0,0,110,111,110,101,0,0,0,0,69,120,112,101,99,116,101,100,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,32,45,32,115,107,105,112,112,105,110,103,32,112,97,99,107,101,116,10,0,0,0,0,119,109,97,118,111,105,99,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,100,105,115,112,108,97,121,32,105,110,102,111,32,115,105,122,101,32,37,100,10,0,0,0,102,114,119,117,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,10,0,0,70,114,97,112,115,58,32,112,108,97,110,101,32,37,105,32,111,102,102,115,101,116,32,105,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,70,76,73,95,76,67,32,99,104,117,110,107,32,105,110,32,110,111,110,45,112,97,108,101,116,116,105,122,101,100,32,70,76,67,10,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,98,108,111,99,107,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,0,67,117,115,116,111,109,32,112,97,108,101,116,116,101,0,0,37,100,32,72,122,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,100,101,99,111,100,101,95,102,114,97,109,101,40,41,32,102,97,105,108,101,100,10,0,0,110,0,0,0,0,0,0,0,99,114,99,32,99,104,101,99,107,32,102,97,105,108,101,100,32,102,114,111,109,32,111,102,102,115,101,116,32,37,105,32,40,102,114,97,109,101,32,37,108,108,100,41,32,116,111,32,37,105,32,40,102,114,97,109,101,32,37,108,108,100,41,10,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,115,97,109,112,108,101,32,114,97,116,101,32,99,111,100,101,32,37,100,10,0,0,0,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,100,97,116,97,32,115,105,122,101,46,10,0,0,0,0,0,0,98,121,116,101,115,32,60,32,112,107,116,45,62,115,105,122,101,32,47,32,102,45,62,115,108,105,99,101,95,99,111,117,110,116,0,0,0,0,0,0,97,116,32,37,102,32,115,101,99,111,110,100,115,10,0,0,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,116,104,101,32,99,108,97,105,109,101,100,32,98,105,116,114,97,116,101,46,10,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,102,111,114,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,98,105,116,115,58,32,37,100,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,100,105,115,97,98,108,101,32,99,111,109,98,109,97,116,99,104,105,110,103,0,0,0,0,65,108,108,111,119,32,67,104,97,110,103,105,110,103,32,77,101,116,97,100,97,116,97,32,80,101,114,45,70,114,97,109,101,0,0,0,0,0,0,0,100,120,118,97,50,95,118,108,100,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,108,105,99,101,32,115,105,122,101,32,37,100,32,40,111,110,108,121,32,37,100,32,98,121,116,101,115,32,108,101,102,116,41,10,0,0,0,0,0,71,97,105,110,115,98,111,114,111,0,0,0,0,0,0,0,85,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,37,100,10,0,0,0,0,0,0,0,0,32,40,100,101,102,97,117,108,116,32,0,0,0,0,0,0,100,118,100,95,115,117,98,116,105,116,108,101,32,116,111,111,32,98,105,103,10,0,0,0,10,0,0,0,0,0,0,0,56,45,98,105,116,32,112,105,120,101,108,32,115,116,114,105,110,103,32,105,110,32,37,100,45,98,105,116,32,114,101,103,105,111,110,33,10,0,0,0,113,117,97,100,0,0,0,0,115,101,116,32,100,105,116,104,101,114,105,110,103,32,97,108,103,111,114,105,116,104,109,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,37,115,46,10,0,0,0,0,0,80,97,99,107,105,110,103,32,37,100,0,0,0,0,0,0,120,97,110,95,100,112,99,109,0,0,0,0,0,0,0,0,37,102,0,0,0,0,0,0,80,67,83,95,77,101,114,99,104,105,99,104,95,83,97,104,97,114,97,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,98,32,104,101,105,103,104,116,32,116,111,111,32,98,105,103,58,32,37,100,10,0,0,65,68,80,67,77,32,89,97,109,97,104,97,0,0,0,0,104,100,99,100,0,0,0,0,104,100,99,100,0,0,0,0,68,114,111,112,112,105,110,103,32,102,114,97,109,101,32,119,105,116,104,111,117,116,32,115,101,113,117,101,110,99,101,32,104,101,97,100,101,114,10,0,78,111,110,45,98,121,116,101,45,97,108,105,103,110,101,100,32,97,117,100,105,111,45,115,112,101,99,105,102,105,99,32,99,111,110,102,105,103,0,0,66,68,76,84,0,0,0,0,112,101,97,107,95,99,98,32,62,61,32,45,50,48,52,55,0,0,0,0,0,0,0,0,112,115,102,105,108,101,0,0,88,67,104,32,101,120,116,101,110,115,105,111,110,32,97,109,111,100,101,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,0,83,112,101,101,120,0,0,0,67,97,109,83,116,117,100,105,111,32,99,111,100,101,99,32,101,114,114,111,114,58,32,105,110,118,97,108,105,100,32,100,101,112,116,104,32,37,105,32,98,112,112,10,0,0,0,0,70,114,97,109,101,32,101,110,100,101,100,32,101,110,101,120,112,101,99,116,101,100,108,121,33,10,0,0,0,0,0,0,115,117,98,112,97,99,107,101,116,91,37,105,93,32,37,105,32,37,105,10,0,0,0,0,67,111,117,108,100,32,110,111,116,32,117,112,100,97,116,101,32,116,105,109,101,115,116,97,109,112,115,32,102,111,114,32,100,105,115,99,97,114,100,101,100,32,115,97,109,112,108,101,115,46,10,0,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,48,32,111,112,97,99,105,116,121,0,0,76,105,110,101,97,114,95,89,97,114,100,95,83,101,97,114,115,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,115,105,110,107,46,99,0,0,0,0,0,0,0,0,103,108,111,98,97,108,95,104,101,97,100,101,114,0,0,0,116,105,109,101,98,97,115,101,32,37,100,47,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,77,80,69,71,32,52,32,115,116,97,110,100,97,114,100,44,32,116,104,101,32,109,97,120,105,109,117,109,32,97,100,109,105,116,116,101,100,32,118,97,108,117,101,32,102,111,114,32,116,104,101,32,116,105,109,101,98,97,115,101,32,100,101,110,111,109,105,110,97,116,111,114,32,105,115,32,37,100,10,0,99,98,112,99,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,105,110,118,97,108,105,100,32,99,98,112,32,37,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,109,106,112,101,103,0,0,0,104,50,54,49,0,0,0,0,65,32,110,111,110,45,105,110,116,114,97,32,115,108,105,99,101,32,105,110,32,97,110,32,73,68,82,32,78,65,76,32,117,110,105,116,46,10,0,0,85,110,107,110,111,119,110,32,99,111,100,105,110,103,32,116,121,112,101,58,32,37,100,46,10,0,0,0,0,0,0,0,82,101,115,111,108,117,116,105,111,110,32,108,97,114,103,101,114,32,116,104,97,110,32,98,117,102,102,101,114,32,115,105,122,101,46,32,73,110,118,97,108,105,100,32,104,101,97,100,101,114,63,10,0,0,0,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,101,115,32,111,102,32,102,111,117,114,32,40,103,111,116,32,37,105,120,37,105,41,10,0,105,110,100,101,112,0,0,0,116,105,108,101,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,97,117,116,111,0,0,0,0,78,111,32,115,101,113,117,101,110,99,101,32,104,101,97,100,101,114,32,100,101,99,111,100,101,100,32,121,101,116,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,104,101,97,100,101,114,32,108,101,110,103,116,104,10,0,0,80,67,83,95,77,101,114,99,104,105,99,104,95,83,117,100,95,77,97,114,111,99,0,0,67,111,109,109,97,110,100,32,100,97,116,97,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,100,101,99,108,97,114,101,100,32,102,105,108,101,32,115,105,122,101,32,105,115,32,108,101,115,115,32,116,104,97,110,32,104,101,97,100,101,114,32,115,105,122,101,32,40,37,100,32,60,32,37,100,41,10,0,0,84,104,101,111,114,97,0,0,84,111,111,32,108,111,110,103,32,86,76,67,32,40,37,100,41,32,105,110,32,105,110,105,116,95,118,108,99,10,0,0,110,111,116,32,101,110,111,117,103,104,32,101,120,116,114,97,100,97,116,97,10,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,73,110,99,111,114,114,101,99,116,32,49,54,120,49,54,32,98,108,111,99,107,32,116,121,112,101,32,37,100,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,67,104,114,105,115,116,105,97,110,32,82,97,112,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,118,102,105,108,116,101,114,103,114,97,112,104,46,99,0,0,0,0,0,32,67,52,50,48,112,97,108,100,118,32,88,89,83,67,83,83,61,52,50,48,80,65,76,68,86,0,0,0,0,0,0,115,112,101,101,120,0,0,0,48,0,0,0,0,0,0,0,98,108,111,99,107,95,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,10,0,79,102,102,115,101,116,32,111,102,32,37,100,0,0,0,0,105,108,108,101,103,97,108,32,113,115,99,97,108,101,32,48,10,0,0,0,0,0,0,0,65,86,83,117,98,116,105,116,108,101,32,114,101,99,116,97,110,103,108,101,32,97,115,115,32,34,37,115,34,32,100,111,101,115,32,110,111,116,32,108,111,111,107,32,108,105,107,101,32,97,32,83,83,65,32,109,97,114,107,117,112,10,0,0,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,110,111,116,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,46,32,101,120,116,114,97,32,98,121,116,101,115,32,97,116,32,116,104,101,32,101,110,100,32,119,105,108,108,32,98,101,32,115,107,105,112,112,101,100,46,10,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,109,117,108,116,105,45,99,104,97,110,110,101,108,32,65,77,82,0,0,0,0,0,0,0,109,117,108,116,105,45,99,104,97,110,110,101,108,32,65,77,82,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,114,114,101,108,97,116,105,111,110,46,10,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,98,111,116,116,111,109,95,116,111,112,0,0,0,0,0,0,84,89,69,82,0,0,0,0,71,114,117,110,103,101,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,100,101,115,99,114,105,112,116,105,111,110,46,10,0,0,0,0,68,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,79,110,108,121,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,97,110,100,32,112,105,99,116,117,114,101,115,32,97,114,101,32,97,108,108,111,119,101,100,32,105,110,32,65,73,70,70,46,10,0,0,0,99,111,109,109,101,110,116,0,80,67,83,95,77,101,114,99,104,105,99,104,95,78,111,114,100,95,77,97,114,111,99,0,83,111,117,114,99,101,32,102,105,108,116,101,114,115,32,97,110,100,32,102,105,108,116,101,114,115,32,119,105,116,104,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,105,110,112,117,116,32,109,117,115,116,32,115,101,116,32,99,111,110,102,105,103,95,112,114,111,112,115,40,41,32,99,97,108,108,98,97,99,107,115,32,111,110,32,97,108,108,32,111,117,116,112,117,116,115,10,0,0,0,69,115,99,97,112,101,32,115,97,109,112,108,101,32,114,97,116,101,32,105,110,100,101,120,32,105,108,108,101,103,97,108,32,105,110,32,65,68,84,83,10,0,0,0,0,0,0,0,112,104,100,114,45,62,102,114,97,109,101,95,115,105,122,101,32,60,61,32,115,105,122,101,111,102,40,98,117,102,51,41,0,0,0,0,0,0,0,0,98,105,116,115,32,117,110,115,112,101,99,105,102,105,101,100,32,102,111,114,32,110,111,110,32,65,68,80,67,77,10,0,52,50,48,109,112,101,103,50,0,0,0,0,0,0,0,0,116,119,111,32,100,112,100,115,32,99,104,117,110,107,115,32,112,114,101,115,101,110,116,10,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,53,46,49,32,65,68,80,67,77,32,97,117,100,105,111,32,115,116,114,101,97,109,32,40,48,120,37,48,52,88,41,10,0,0,0,0,77,117,115,101,112,97,99,107,32,83,86,56,0,0,0,0,69,0,0,0,0,0,0,0,32,32,32,32,67,104,97,112,116,101,114,32,35,37,100,46,37,100,58,32,0,0,0,0,80,67,83,95,77,97,108,111,110,103,111,95,49,57,56,55,95,85,84,77,95,51,50,83,0,0,0,0,0,0,0,0,109,117,115,101,112,97,99,107,56,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,105,109,97,103,101,50,0,0,114,97,119,32,86,67,45,49,32,118,105,100,101,111,0,0,80,67,83,95,77,97,107,97,115,115,97,114,95,78,69,73,69,90,0,0,0,0,0,0,115,49,54,98,101,32,100,101,109,117,120,101,114,0,0,0,78,101,108,108,121,109,111,115,101,114,32,65,115,97,111,0,98,105,116,115,116,114,101,97,109,0,0,0,0,0,0,0,69,114,114,111,114,32,115,116,114,101,97,109,95,105,100,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,112,114,111,100,117,99,116,95,118,101,114,115,105,111,110,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,86,0,110,101,108,108,121,109,111,115,101,114,0,0,0,0,0,0,118,0,0,0,0,0,0,0,115,107,105,112,95,114,116,99,112,0,0,0,0,0,0,0,102,114,97,109,101,61,37,100,10,0,0,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,68,95,87,69,66,86,84,84,47,83,85,66,84,73,84,76,69,83,0,0,0,0,0,0,77,65,73,78,0,0,0,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,73,86,0,0,0,0,0,0,0,0,77,111,110,107,101,121,39,115,32,65,117,100,105,111,0,0,65,80,73,67,0,0,0,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,73,73,73,0,0,0,0,0,0,0,97,112,101,0,0,0,0,0,110,111,95,114,101,115,121,110,99,95,115,101,97,114,99,104,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,115,61,37,115,58,0,0,0,0,0,0,0,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,73,73,0,0,0,0,0,0,0,0,86,111,120,119,97,114,101,32,82,84,50,57,32,77,101,116,97,115,111,117,110,100,0,0,106,112,101,103,0,0,0,0,100,115,116,95,102,111,114,109,97,116,0,0,0,0,0,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,73,0,118,111,120,119,97,114,101,0,110,111,110,101,0,0,0,0,118,100,112,97,117,95,109,112,101,103,52,0,0,0,0,0,105,108,98,99,0,0,0,0,70,117,99,104,115,105,97,0,41,0,0,0,0,0,0,0,52,46,48,0,0,0,0,0,115,119,115,95,100,105,116,104,101,114,0,0,0,0,0,0,115,101,116,32,105,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,0,0,0,0,0,38,72,37,56,120,0,0,0,80,67,83,95,76,111,109,101,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,0,97,100,112,99,109,95,121,97,109,97,104,97,0,0,0,0,83,116,97,110,100,97,114,100,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,83,116,97,110,100,97,114,100,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,108,97,121,101,114,115,0,115,101,116,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,32,102,111,114,32,97,108,108,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,0,0,0,65,84,82,65,67,51,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,32,51,41,0,0,0,115,107,105,112,32,37,100,47,37,100,32,115,97,109,112,108,101,115,10,0,0,0,0,0,99,48,95,111,112,97,99,105,116,121,0,0,0,0,0,0,76,105,110,101,97,114,95,67,104,97,105,110,95,83,101,97,114,115,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,111,114,99,101,32,108,111,119,32,100,101,108,97,121,0,105,110,116,114,97,95,113,117,97,110,116,95,98,105,97,115,32,61,32,37,100,32,105,110,116,101,114,95,113,117,97,110,116,95,98,105,97,115,32,61,32,37,100,10,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,0,0,0,48,48,32,109,111,116,105,111,110,95,116,121,112,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,83,105,110,103,108,101,32,102,105,101,108,100,10,0,0,0,115,108,105,99,101,32,116,121,112,101,32,37,100,32,116,111,111,32,108,97,114,103,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,67,104,97,110,110,101,108,32,67,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,80,67,83,95,76,101,105,103,111,110,95,71,104,97,110,97,95,71,114,105,100,0,0,0,116,104,101,111,114,97,0,0,84,111,112,32,52,48,0,0,32,67,52,49,49,32,88,89,83,67,83,83,61,52,49,49,0,0,0,0,0,0,0,0,97,116,114,97,99,51,0,0,105,102,102,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,80,101,114,117,95,101,97,115,116,95,122,111,110,101,0,0,0,0,0,0,0,114,111,113,0,0,0,0,0,71,83,77,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,0,0,0,68,0,0,0,0,0,0,0,100,97,116,101,0,0,0,0,67,97,110,110,111,116,32,100,101,116,101,114,109,105,110,101,32,97,100,100,105,116,105,111,110,97,108,32,112,97,114,97,109,101,116,101,114,115,10,0,87,77,47,77,101,100,105,97,84,104,117,109,98,84,121,112,101,0,0,0,0,0,0,0,114,111,113,0,0,0,0,0,10,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,80,101,114,117,95,99,101,110,116,114,97,108,0,78,65,82,0,0,0,0,0,103,115,109,95,109,115,0,0,115,101,103,109,101,110,116,58,39,37,115,39,32,99,111,117,110,116,58,37,100,32,101,110,100,101,100,10,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,32,102,111,114,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,115,116,114,105,110,103,10,0,0,0,0,0,37,46,42,115,10,0,0,0,105,100,99,105,110,0,0,0,45,45,62,0,0,0,0,0,32,32,102,114,111,110,115,97,121,58,32,37,115,10,0,0,118,99,49,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,80,101,114,117,95,119,101,115,116,95,122,111,110,101,0,0,0,0,0,0,0,115,49,54,108,101,32,100,101,109,117,120,101,114,0,0,0,77,76,80,32,40,77,101,114,105,100,105,97,110,32,76,111,115,115,108,101,115,115,32,80,97,99,107,105,110,103,41,0,118,101,114,105,102,121,32,101,109,98,101,100,100,101,100,32,67,82,67,115,0,0,0,0,105,110,100,101,120,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,119,97,118,101,32,103,117,105,100,10,0,0,0,0,0,0,0,112,114,111,100,117,99,116,95,110,97,109,101,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,50,48,83,0,37,100,0,0,0,0,0,0,109,108,112,0,0,0,0,0,37,42,100,58,37,42,100,58,37,42,100,46,37,42,100,37,99,0,0,0,0,0,0,0,115,101,116,32,108,111,103,103,105,110,103,32,108,101,118,101,108,0,0,0,0,0,0,0,85,115,101,32,82,70,67,32,50,49,57,48,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,105,110,115,116,101,97,100,32,111,102,32,82,70,67,32,52,54,50,57,32,102,111,114,32,72,46,50,54,51,0,0,0,0,0,0,0,0,100,105,115,99,0,0,0,0,99,100,101,99,0,0,0,0,102,114,97,109,101,61,37,53,100,32,102,112,115,61,37,51,46,42,102,32,113,61,37,51,46,49,102,32,0,0,0,0,68,95,87,69,66,86,84,84,47,77,69,84,65,68,65,84,65,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,116,111,111,32,98,105,103,32,104,101,97,100,101,114,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,57,83,0,77,117,115,101,112,97,99,107,32,83,86,55,0,0,0,0,80,117,98,108,105,115,104,101,114,47,83,116,117,100,105,111,32,108,111,103,111,116,121,112,101,0,0,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,56,83,0,109,117,115,101,112,97,99,107,55,0,0,0,0,0,0,0,97,115,102,32,100,101,109,117,120,101,114,0,0,0,0,0,115,97,109,112,108,101,95,102,109,116,115,61,37,115,58,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,55,83,0,73,77,67,32,40,73,110,116,101,108,32,77,117,115,105,99,32,67,111,100,101,114,41,0,115,0,0,0,0,0,0,0,83,112,101,99,105,102,105,101,100,32,112,114,111,98,101,32,115,105,122,101,32,118,97,108,117,101,32,37,117,32,99,97,110,110,111,116,32,98,101,32,60,32,37,117,10,0,0,0,100,115,116,104,0,0,0,0,46,46,0,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,50,49,78,0,44,32,37,100,32,115,97,109,112,108,101,115,0,0,0,0,105,109,99], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1964678);
/* memory initializer */ allocate([84,84,89,32,100,101,109,117,120,101,114,0,0,0,0,0,72,101,97,100,101,114,32,67,82,67,32,101,114,114,111,114,10,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,101,97,116,117,114,101,115,32,48,120,37,48,50,120,10,0,0,0,0,99,111,109,98,109,97,116,99,104,105,110,103,0,0,0,0,121,117,118,52,52,52,112,49,54,98,101,0,0,0,0,0,70,111,114,101,115,116,71,114,101,101,110,0,0,0,0,0,32,116,111,32,0,0,0,0,51,46,48,40,98,97,99,107,41,0,0,0,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,104,111,114,105,122,111,110,116,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,105,110,116,101,114,110,97,108,95,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,102,105,108,101,110,97,109,101,58,39,37,115,39,32,102,111,114,109,97,116,58,37,115,10,0,0,0,0,0,0,0,0,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,0,0,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,50,48,78,0,65,68,80,67,77,32,67,68,82,79,77,32,88,65,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,112,114,111,103,114,97,109,115,0,0,0,0,0,0,0,97,108,108,0,0,0,0,0,99,111,110,116,101,110,116,0,84,104,105,114,100,32,104,101,97,100,101,114,32,105,115,32,110,111,116,32,116,104,101,32,115,101,116,117,112,32,104,101,97,100,101,114,46,10,0,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,32,97,117,100,105,111,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,117,112,100,97,116,101,32,116,105,109,101,115,116,97,109,112,115,32,102,111,114,32,115,107,105,112,112,101,100,32,115,97,109,112,108,101,115,46,10,0,0,0,0,0,0,0,37,48,50,120,0,0,0,0,115,101,116,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,97,108,108,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,115,0,76,105,110,101,97,114,95,67,104,97,105,110,95,66,101,110,111,105,116,0,0,0,0,0,85,110,107,110,111,119,110,45,37,100,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,108,111,119,95,100,101,108,97,121,0,0,0,0,0,0,0,113,109,105,110,32,97,110,100,32,111,114,32,113,109,97,120,32,97,114,101,32,105,110,118,97,108,105,100,44,32,116,104,101,121,32,109,117,115,116,32,98,101,32,48,32,60,32,109,105,110,32,60,61,32,109,97,120,10,0,0,0,0,0,0,109,112,101,103,52,0,0,0,70,97,105,108,101,100,32,116,111,32,117,110,99,111,109,112,114,101,115,115,32,111,110,101,32,98,105,116,109,97,112,10,0,0,0,0,0,0,0,0,77,84,95,68,77,86,32,105,110,32,112,114,111,103,114,101,115,115,105,118,101,95,115,101,113,117,101,110,99,101,10,0,100,101,99,111,100,101,32,102,114,97,109,101,32,117,110,117,115,101,100,32,37,116,100,32,98,121,116,101,115,10,0,0,91,67,79,76,70,93,0,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,66,32,37,100,32,37,100,10,0,0,83,116,101,114,101,111,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,109,111,100,101,0,0,0,0,0,0,0,99,104,97,110,110,101,108,95,99,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,91,37,100,58,37,100,58,37,100,93,0,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,57,78,0,79,110,50,32,86,80,51,0,71,97,110,103,115,116,97,0,32,67,109,111,110,111,49,54,0,0,0,0,0,0,0,0,100,115,105,99,105,110,97,117,100,105,111,0,0,0,0,0,32,32,88,49,58,37,48,51,100,32,88,50,58,37,48,51,100,32,89,49,58,37,48,51,100,32,89,50,58,37,48,51,100,0,0,0,0,0,0,0,105,110,37,100,58,37,99,37,100,0,0,0,0,0,0,0,84,111,111,32,108,97,114,103,101,32,84,114,117,101,72,68,32,102,114,97,109,101,32,111,102,32,37,100,32,98,121,116,101,115,0,0,0,0,0,0,68,97,116,97,32,116,121,112,101,32,48,120,37,48,52,120,32,105,110,32,73,69,67,32,54,49,57,51,55,0,0,0,105,110,118,97,108,105,100,32,99,111,100,101,99,59,32,117,115,101,32,112,99,109,95,115,51,50,108,101,32,111,114,32,112,99,109,95,115,51,50,98,101,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,10,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,56,78,0,87,97,118,80,97,99,107,0,32,37,115,37,115,32,37,45,49,53,115,32,37,115,10,0,37,115,47,70,114,97,103,109,101,110,116,115,40,37,115,61,37,108,108,117,41,0,0,0,32,61,32,0,0,0,0,0,101,114,114,111,114,32,119,104,101,110,32,114,101,97,100,105,110,103,32,99,111,109,109,101,110,116,10,0,0,0,0,0,37,100,32,107,98,47,115,0,84,111,111,32,109,97,110,121,32,102,114,97,109,101,115,58,32,37,105,10,0,0,0,0,72,101,97,100,101,114,32,99,104,117,110,107,32,105,115,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,0,80,67,83,95,76,97,95,67,97,110,111,97,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,0,0,0,0,0,118,109,100,45,62,102,114,97,109,101,95,99,111,117,110,116,32,42,32,118,109,100,45,62,102,114,97,109,101,115,95,112,101,114,95,98,108,111,99,107,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,119,97,118,112,97,99,107,0,35,69,88,84,45,88,45,69,78,68,76,73,83,84,10,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,116,104,100,0,0,0,0,0,80,67,83,95,76,97,95,67,97,110,111,97,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,0,0,0,0,0,81,67,69,76,80,32,47,32,80,117,114,101,86,111,105,99,101,0,0,0,0,0,0,0,115,56,32,100,101,109,117,120,101,114,0,0,0,0,0,0,115,101,116,32,114,101,102,101,114,101,110,99,101,32,115,116,114,101,97,109,0,0,0,0,105,0,0,0,0,0,0,0,99,114,99,99,104,101,99,107,0,0,0,0,0,0,0,0,110,32,60,61,32,115,121,110,99,112,111,105,110,116,95,99,111,117,110,116,32,43,32,49,0,0,0,0,0,0,0,0,99,111,109,112,97,110,121,95,110,97,109,101,0,0,0,0,108,105,115,115,97,106,111,117,115,0,0,0,0,0,0,0,98,61,65,83,58,37,100,13,10,0,0,0,0,0,0,0,80,67,83,95,75,101,114,116,97,117,95,85,84,77,95,122,111,110,101,95,52,56,78,0,113,99,101,108,112,0,0,0,105,110,112,117,116,32,102,105,108,101,0,0,0,0,0,0,84,121,112,101,32,37,100,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,114,102,99,50,49,57,48,0,108,111,103,108,101,118,101,108,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,0,37,42,88,32,37,88,32,37,88,32,37,88,0,0,0,0,115,116,114,101,97,109,95,37,100,95,37,100,95,113,61,37,46,49,102,10,0,0,0,0,83,116,97,114,116,0,0,0,68,95,87,69,66,86,84,84,47,68,69,83,67,82,73,80,84,73,79,78,83,0,0,0,37,115,47,37,115,0,0,0,80,67,83,95,75,101,114,116,97,117,95,85,84,77,95,122,111,110,101,95,52,55,78,0,83,109,97,99,107,101,114,32,97,117,100,105,111,0,0,0,84,65,76,66,0,0,0,0,111,117,116,112,117,116,32,102,105,108,101,0,0,0,0,0,66,97,110,100,47,97,114,116,105,115,116,32,108,111,103,111,116,121,112,101,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,37,115,10,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,109,117,115,116,32,98,101,32,60,32,54,53,53,51,54,10,0,0,0,0,86,105,100,101,111,32,102,111,114,109,97,116,32,37,105,0,80,67,83,95,75,101,114,116,97,117,95,83,105,110,103,97,112,111,114,101,95,71,114,105,100,0,0,0,0,0,0,0,115,109,97,99,107,97,117,100,105,111,0,0,0,0,0,0,83,117,99,99,101,115,115,102,117,108,108,121,32,111,112,101,110,101,100,32,116,104,101,32,102,105,108,101,46,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,99,111,0,0,0,0,0,116,111,111,32,109,97,110,121,32,115,116,114,101,97,109,115,10,0,0,0,0,0,0,0,112,97,110,0,0,0,0,0,112,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,102,105,108,101,32,119,104,105,108,101,32,114,101,97,100,105,110,103,32,73,78,70,79,32,116,97,103,10,0,0,0,99,108,105,112,112,105,110,103,10,0,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,98,101,101,112,95,102,97,99,116,111,114,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,86,98,0,84,84,65,32,40,84,114,117,101,32,65,117,100,105,111,41,0,0,0,0,0,0,0,0,105,99,111,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,37,115,32,102,105,108,101,32,37,115,46,10,0,0,0,0,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,104,110,109,0,0,0,0,0,100,115,116,119,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,73,73,98,0,0,0,0,0,0,0,0,116,116,97,0,0,0,0,0,79,112,101,110,105,110,103,32,97,110,32,37,115,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,0,99,97,118,115,118,105,100,101,111,0,0,0,0,0,0,0,99,108,0,0,0,0,0,0,115,101,116,32,99,111,109,98,109,97,116,99,104,105,110,103,32,109,111,100,101,0,0,0,121,117,118,52,52,52,112,49,54,108,101,0,0,0,0,0,108,97,116,109,0,0,0,0,70,108,111,114,97,108,87,104,105,116,101,0,0,0,0,0,32,40,102,114,111,109,32,0,51,46,48,0,0,0,0,0,100,115,116,95,104,95,99,104,114,95,112,111,115,0,0,0,115,101,116,32,105,110,116,101,114,110,97,108,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,118,105,100,101,111,32,112,97,99,107,101,116,10,0,0,0,0,0,37,100,0,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,73,98,0,97,100,112,99,109,95,120,97,0,0,0,0,0,0,0,0,65,47,68,32,67,111,110,118,101,114,116,101,114,32,84,121,112,101,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,100,101,99,32,71,85,73,68,46,10,0,0,0,0,65,47,68,32,67,111,110,118,101,114,116,101,114,32,84,121,112,101,0,0,0,0,0,0,68,83,80,32,71,114,111,117,112,32,84,114,117,101,83,112,101,101,99,104,0,0,0,0,102,114,97,109,101,32,108,101,110,103,116,104,32,109,105,115,109,97,116,99,104,32,37,100,32,60,60,32,37,100,10,0,98,0,0,0,0,0,0,0,70,105,114,115,116,32,104,101,97,100,101,114,32,105,115,32,110,111,116,32,116,104,101,32,105,100,32,104,101,97,100,101,114,46,10,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,112,116,105,111,110,115,32,102,111,114,32,37,115,32,102,105,108,101,32,37,115,46,10,0,0,105,110,118,97,108,105,100,32,112,97,121,108,111,97,100,32,108,101,110,103,116,104,32,37,117,10,0,0,0,0,0,0,115,107,105,112,32,119,104,111,108,101,32,102,114,97,109,101,44,32,115,107,105,112,32,108,101,102,116,58,32,37,100,10,0,0,0,0,0,0,0,0,97,108,108,95,101,120,112,114,0,0,0,0,0,0,0,0,76,105,110,101,97,114,95,76,105,110,107,95,83,101,97,114,115,0,0,0,0,0,0,0,85,115,101,114,45,68,101,102,105,110,101,100,0,0,0,0,65,65,67,32,110,111,116,32,121,101,116,32,99,111,114,114,101,99,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,37,108,108,100,44,37,108,108,100,44,37,99,0,0,0,0,112,99,109,95,115,50,52,108,101,0,0,0,0,0,0,0,117,115,101,32,105,110,116,101,114,108,97,99,101,100,32,68,67,84,0,0,0,0,0,0,114,101,109,111,118,105,110,103,32,99,111,109,109,111,110,32,102,97,99,116,111,114,115,32,102,114,111,109,32,102,114,97,109,101,114,97,116,101,10,0,33,115,45,62,112,114,111,103,114,101,115,115,105,118,101,95,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,77,111,110,111,32,115,116,114,101,97,109,32,119,105,116,104,32,50,32,115,117,98,115,116,114,101,97,109,115,44,32,105,103,110,111,114,105,110,103,32,50,110,100,10,0,0,0,0,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,74,52,52,52,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,52,52,52,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,74,52,50,50,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,52,50,50,80,0,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,66,32,37,100,32,37,100,44,32,98,121,116,101,115,116,114,101,97,109,32,37,116,100,10,0,0,99,104,95,109,111,100,101,0,83,116,101,114,101,111,32,82,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,86,97,0,118,112,51,0,0,0,0,0,116,114,117,101,115,112,101,101,99,104,0,0,0,0,0,0,67,117,108,116,0,0,0,0,32,67,109,111,110,111,0,0,73,110,118,97,108,105,100,32,99,97,110,118,97,115,32,115,105,122,101,58,32,37,115,46,10,0,0,0,0,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,104,108,115,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,73,73,97,0,0,0,0,0,0,0,0,67,111,111,107,32,47,32,67,111,111,107,101,114,32,47,32,71,101,99,107,111,32,40,82,101,97,108,65,117,100,105,111,32,71,50,41,0,0,0,0,110,0,0,0,0,0,0,0,48,48,48,0,0,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,44,32,98,105,116,114,97,116,101,58,32,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,73,97,0,99,111,111,107,0,0,0,0,83,117,112,112,111,114,116,101,100,32,104,119,97,99,99,101,108,115,58,32,0,0,0,0,70,97,105,108,117,114,101,32,111,99,99,117,114,114,101,100,32,119,104,101,110,32,101,110,100,105,110,103,32,115,101,103,109,101,110,116,32,39,37,115,39,10,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,88,105,112,104,32,99,111,100,101,99,32,73,68,10,0,0,0,0,0,0,115,101,116,32,112,114,111,98,105,110,103,32,115,105,122,101,0,0,0,0,0,0,0,0,114,97,119,32,84,114,117,101,72,68,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,0,0,0,81,68,101,115,105,103,110,32,77,117,115,105,99,32,67,111,100,101,99,32,50,0,0,0,117,51,50,98,101,32,100,101,109,117,120,101,114,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,104,119,97,99,99,101,108,58,32,37,115,46,10,0,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,99,111,109,109,101,110,116,32,104,101,97,100,101,114,44,32,37,105,32,99,111,109,109,101,110,116,115,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,115,101,116,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,32,102,108,97,103,115,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,102,105,115,98,111,110,101,32,102,111,114,32,116,104,101,32,115,97,109,101,32,115,116,114,101,97,109,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,107,101,121,102,114,97,109,101,32,98,101,102,111,114,101,32,102,105,114,115,116,32,115,121,110,99,112,111,105,110,116,32,105,110,32,105,110,100,101,120,10,0,0,0,0,0,0,0,68,117,112,108,105,99,97,116,101,32,115,111,110,121,95,109,112,101,103,52,95,101,120,116,114,97,100,97,116,97,10,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,48,0,0,0,113,100,109,50,0,0,0,0,83,112,101,101,120,0,0,0,97,117,116,111,0,0,0,0,67,111,100,101,99,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,85,115,101,32,77,80,52,65,45,76,65,84,77,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,105,110,115,116,101,97,100,32,111,102,32,77,80,69,71,52,45,71,69,78,69,82,73,67,32,102,111,114,32,65,65,67,0,0,0,0,105,84,117,110,83,77,80,66,0,0,0,0,0,0,0,0,113,61,37,50,46,49,102,32,0,0,0,0,0,0,0,0,104,108,115,44,97,112,112,108,101,104,116,116,112,0,0,0,68,95,87,69,66,86,84,84,47,67,65,80,84,73,79,78,83,0,0,0,0,0,0,0,110,117,115,45,62,107,101,121,102,114,97,109,101,95,112,116,115,91,107,93,32,62,32,108,97,115,116,95,112,116,115,0,83,107,105,112,112,105,110,103,32,105,110,118,97,108,105,100,32,116,97,103,32,119,105,116,104,32,110,111,32,84,97,103,78,97,109,101,46,10,0,0,80,67,83,95,74,65,68,54,57,95,74,97,109,97,105,99,97,95,71,114,105,100,0,0,71,83,77,0,0,0,0,0,104,101,118,99,0,0,0,0,110,111,110,101,0,0,0,0,73,108,108,117,115,116,114,97,116,105,111,110,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,110,117,116,100,101,99,46,99,0,0,0,0,80,67,83,95,74,97,109,97,105,99,97,95,49,56,55,53,95,79,108,100,95,71,114,105,100,0,0,0,0,0,0,0,112,99,109,0,0,0,0,0,103,115,109,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,102,114,97,109,101,114,97,116,101,32,37,115,46,10,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,101,100,105,116,32,117,110,105,116,115,32,99,111,117,110,116,32,37,100,10,0,0,0,0,45,109,97,112,95,99,104,97,110,110,101,108,32,105,115,32,102,111,114,119,97,114,100,101,100,32,116,111,32,108,97,118,102,105,32,115,105,109,105,108,97,114,108,121,32,116,111,32,45,97,102,32,112,97,110,61,37,115,46,10,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,98,105,113,117,97,100,115,46,99,0,0,0,0,0,0,0,0,80,67,83,95,73,110,100,105,97,110,95,49,57,55,53,95,85,84,77,95,52,56,78,0,87,101,115,116,119,111,111,100,32,65,117,100,105,111,32,40,83,78,68,49,41,0,0,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,102,105,108,101,32,37,115,32,102,111,114,32,119,114,105,116,105,110,103,46,10,0,0,0,0,102,97,105,108,101,100,32,116,111,32,109,97,112,32,69,100,105,116,85,110,105,116,32,37,108,108,100,32,105,110,32,73,110,100,101,120,83,73,68,32,37,105,32,116,111,32,97,110,32,111,102,102,115,101,116,10,0,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,115,114,99,95,102,111,114,109,97,116,0,0,0,0,0,0,80,67,83,95,73,110,100,105,97,110,95,49,57,55,53,95,85,84,77,95,52,55,78,0,119,101,115,116,119,111,111,100,95,115,110,100,49,0,0,0,78,111,32,102,105,108,101,110,97,109,101,32,115,112,101,99,105,102,105,101,100,32,97,110,100,32,110,111,32,39,102,105,108,101,110,97,109,101,39,32,116,97,103,105,110,32,115,116,114,101,97,109,32,35,37,100,58,37,100,46,10,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,117,120,46,99,0,0,0,0,0,0,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,37,102,32,37,102,0,0,0,91,37,108,108,100,93,91,37,108,108,100,93,37,99,37,110,0,0,0,0,0,0,0,0,67,111,110,116,101,110,116,45,108,101,110,103,116,104,58,32,37,100,13,10,13,10,0,0,99,111,109,98,109,97,116,99,104,0,0,0,0,0,0,0,121,117,118,52,50,50,112,49,54,98,101,0,0,0,0,0,70,105,114,101,66,114,105,99,107,0,0,0,0,0,0,0,32,37,115,0,0,0,0,0,50,46,49,0,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,118,101,114,116,105,99,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,111,117,116,95,115,97,109,112,108,101,95,102,109,116,0,0,58,13,10,0,0,0,0,0,80,67,83,95,73,110,100,105,97,110,95,49,57,53,52,95,85,84,77,95,52,56,78,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,84,72,80,0,0,0,0,0,97,100,95,99,111,110,118,95,116,121,112,101,0,0,0,0,97,100,95,99,111,110,118,95,116,121,112,101,0,0,0,0,65,76,65,67,32,40,65,112,112,108,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,115,101,116,32,98,108,117,101,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,78,111,32,101,120,116,114,97,100,97,116,97,32,116,111,32,100,117,109,112,32,105,110,32,115,116,114,101,97,109,32,35,37,100,58,37,100,46,10,0,115,107,105,112,32,37,100,32,115,97,109,112,108,101,115,32,100,117,101,32,116,111,32,115,105,100,101,32,100,97,116,97,10,0,0,0,0,0,0,0,104,100,115,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,51,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,76,105,110,101,97,114,95,76,105,110,107,95,66,101,110,111,105,116,0,0,0,0,0,0,117,110,100,101,102,105,110,101,100,0,0,0,0,0,0,0,105,108,100,99,116,0,0,0,110,111,116,105,99,101,58,32,98,95,102,114,97,109,101,95,115,116,114,97,116,101,103,121,32,111,110,108,121,32,97,102,102,101,99,116,115,32,116,104,101,32,102,105,114,115,116,32,112,97,115,115,10,0,0,0,105,110,118,97,108,105,100,32,109,98,32,116,121,112,101,32,105,110,32,66,32,70,114,97,109,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,115,116,114,101,97,109,95,116,121,112,101,32,37,88,32,105,110,32,33,77,76,80,0,0,0,0,0,0,0,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,74,52,52,52,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,52,52,52,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,74,52,52,48,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,52,52,48,80,0,0,114,97,119,32,77,80,69,71,45,84,83,32,40,77,80,69,71,45,50,32,84,114,97,110,115,112,111,114,116,32,83,116,114,101,97,109,41,0,0,0,83,99,101,110,101,32,100,101,116,101,99,116,105,111,110,32,105,115,32,105,103,110,111,114,101,100,32,105,110,32,97,115,101,108,101,99,116,32,102,105,108,116,101,114,10,0,0,0,98,121,116,101,115,116,114,101,97,109,32,111,118,101,114,114,101,97,100,32,37,116,100,10,0,0,0,0,0,0,0,0,104,50,54,52,0,0,0,0,108,111,103,0,0,0,0,0,115,116,101,114,101,111,95,114,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,80,67,83,95,73,110,100,105,97,110,95,49,57,53,52,95,85,84,77,95,52,55,78,0,73,110,116,101,108,32,73,110,100,101,111,32,51,0,0,0,97,108,97,99,0,0,0,0,67,111,109,101,100,121,0,0,67,111,100,101,99,32,65,86,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,105,110,112,117,116,32,102,105,108,101,32,35,37,100,32,40,37,115,41,32,104,97,115,32,110,111,116,32,98,101,101,110,32,117,115,101,100,32,102,111,114,32,97,110,121,32,115,116,114,101,97,109,46,32,84,104,101,32,109,111,115,116,32,108,105,107,101,108,121,32,114,101,97,115,111,110,32,105,115,32,101,105,116,104,101,114,32,119,114,111,110,103,32,116,121,112,101,32,40,101,46,103,46,32,97,32,118,105,100,101,111,32,111,112,116,105,111,110,32,119,105,116,104,32,110,111,32,118,105,100,101,111,32,115,116,114,101,97,109,115,41,32,111,114,32,116,104,97,116,32,105,116,32,105,115,32,97,32,112,114,105,118,97,116,101,32,111,112,116,105,111,110,32,111,102,32,115,111,109,101,32,100,101,99,111,100,101,114,32,119,104,105,99,104,32,119,97,115,32,110,111,116,32,97,99,116,117,97,108,108,121,32,117,115,101,100,32,102,111,114,32,97,110,121,32,115,116,114,101,97,109,46,10,0,0,77,80,69,71,45,49,32,83,121,115,116,101,109,115,32,47,32,77,80,69,71,32,112,114,111,103,114,97,109,32,115,116,114,101,97,109,32,40,86,67,68,41,0,0,0,0,0,0,104,50,54,51,0,0,0,0,111,102,100,101,99,0,0,0,115,101,101,107,32,116,97,98,108,101,32,116,114,117,110,99,97,116,101,100,10,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,115,101,101,107,116,97,98,108,101,10,0,0,0,0,0,0,104,50,54,49,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,52,83,0,0,0,83,104,111,114,116,101,110,0,67,111,100,101,99,32,65,86,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,105,110,112,117,116,32,102,105,108,101,32,35,37,100,32,40,37,115,41,32,105,115,32,110,111,116,32,97,32,100,101,99,111,100,105,110,103,32,111,112,116,105,111,110,46,10,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,99,111,108,111,114,32,110,97,109,101,115,0,0,0,0,0,0,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,0,0,0,0,112,97,100,32,37,100,32,37,100,10,0,0,0,0,0,0,37,100,46,37,48,54,100,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,51,83,0,0,0,115,104,111,114,116,101,110,0,37,115,58,32,99,111,117,108,100,32,110,111,116,32,115,101,101,107,32,116,111,32,112,111,115,105,116,105,111,110,32,37,48,46,51,102,10,0,0,0,115,101,116,32,105,110,105,116,105,97,108,32,116,105,109,101,115,116,97,109,112,32,111,102,102,115,101,116,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,111,112,117,115,47,52,56,48,48,48,13,10,0,0,0,0,0,0,0,0,116,114,117,101,104,100,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,50,83,0,0,0,77,80,51,111,110,77,80,52,0,0,0,0,0,0,0,0,117,51,50,108,101,32,100,101,109,117,120,101,114,0,0,0,37,115,58,32,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,99,111,100,101,99,32,112,97,114,97,109,101,116,101,114,115,10,0,0,0,0,101,114,114,95,100,101,116,101,99,116,0,0,0,0,0,0,103,120,102,0,0,0,0,0,105,110,100,101,120,32,111,118,101,114,102,108,111,119,32,66,10,0,0,0,0,0,0,0,108,111,99,97,108,32,116,97,103,32,37,35,48,52,120,32,101,120,116,101,110,100,115,32,112,97,115,116,32,101,110,100,32,111,102,32,108,111,99,97,108,32,115,101,116,32,64,32,37,35,108,108,120,10,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,49,83,0,0,0,109,112,51,111,110,52,0,0,97,0,0,0,0,0,0,0,109,111,118,0,0,0,0,0,108,97,116,109,0,0,0,0,37,115,0,0,0,0,0,0,73,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,102,114,97,109,101,32,99,104,97,110,103,101,100,32,102,114,111,109,32,114,97,116,101,58,37,100,32,102,109,116,58,37,115,32,99,104,58,37,100,32,99,104,108,58,37,115,32,116,111,32,114,97,116,101,58,37,100,32,102,109,116,58,37,115,32,99,104,58,37,100,32,99,104,108,58,37,115,10,0,0,0,0,0,0,99,111,108,111,114,115,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,109,105,109,101,116,121,112,101,0,0,0,0,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,0,65,68,85,32,40,65,112,112,108,105,99,97,116,105,111,110,32,68,97,116,97,32,85,110,105,116,41,32,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,112,105,120,101,108,95,102,111,114,109,97,116,0,0,0,0,65,32,98,114,105,103,104,116,32,99,111,108,111,117,114,101,100,32,102,105,115,104,0,0,115,116,114,101,97,109,32,37,100,44,32,111,102,102,115,101,116,32,48,120,37,108,108,120,58,32,112,97,114,116,105,97,108,32,102,105,108,101,10,0,86,78,58,76,97,118,102,44,0,0,0,0,0,0,0,0,103,120,102,0,0,0,0,0,123,125,0,0,0,0,0,0,123,68,69,70,65,85,76,84,125,123,125,37,99,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,0,109,112,51,97,100,117,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,117,116,104,111,114,0,0,58,99,37,100,61,99,37,100,0,0,0,0,0,0,0,0,103,115,109,0,0,0,0,0,48,0,0,0,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,0,70,76,65,67,32,40,70,114,101,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,87,101,98,77,0,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,115,114,99,104,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,55,83,0,0,0,102,108,97,99,0,0,0,0,103,105,102,0,0,0,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,32,48,120,37,120,10,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,76,65,84,77,32,112,97,99,107,101,116,32,115,105,122,101,32,108,97,114,103,101,114,32,116,104,97,110,32,109,97,120,105,109,117,109,32,115,105,122,101,32,48,120,49,102,102,102,10,0,0,0,0,0,0,0,115,101,116,32,115,99,101,110,101,32,99,104,97,110,103,101,32,100,101,116,101,99,116,105,111,110,32,116,104,114,101,115,104,111,108,100,0,0,0,0,121,117,118,52,50,50,112,49,54,108,101,0,0,0,0,0,68,111,100,103,101,114,66,108,117,101,0,0,0,0,0,0,37,99,0,0,0,0,0,0,37,117,58,37,117,58,37,117,46,37,117,32,37,117,58,37,117,58,37,117,46,37,117,32,37,110,0,0,0,0,0,0,115,116,101,114,101,111,0,0,100,115,116,95,118,95,99,104,114,95,112,111,115,0,0,0,115,101,116,32,111,117,116,112,117,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,44,13,10,0,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,54,83,0,0,0,97,100,112,99,109,95,116,104,112,0,0,0,0,0,0,0,78,111,116,32,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,0,0,0,0,78,111,116,32,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,0,0,0,0,83,105,101,114,114,97,32,86,77,68,32,97,117,100,105,111,0,0,0,0,0,0,0,0,110,111,32,100,101,99,111,100,101,114,32,99,111,110,102,105,103,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,98,108,117,101,0,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,46,10,0,0,0,0,0,70,97,105,108,101,100,32,112,97,114,115,105,110,103,32,114,97,116,101,95,100,105,118,105,115,111,114,10,0,0,0,0,47,100,101,118,47,115,116,100,105,110,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,101,100,105,97,32,116,121,112,101,32,102,111,114,32,97,117,100,105,111,10,0,0,0,99,51,95,101,120,112,114,0,76,105,110,101,97,114,95,76,105,110,107,0,0,0,0,0,37,46,49,53,103,37,115,0,110,111,114,109,97,108,105,122,101,32,97,100,97,112,116,105,118,101,32,113,117,97,110,116,105,122,97,116,105,111,110,0,109,98,95,116,104,114,101,115,104,111,108,100,32,116,111,111,32,108,97,114,103,101,44,32,109,97,120,32,105,115,32,37,100,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,98,32,116,121,112,101,32,105,110,32,80,32,70,114,97,109,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,115,116,114,101,97,109,95,116,121,112,101,32,37,88,32,105,110,32,77,76,80,0,0,0,0,0,0,0,0,78,111,32,74,80,69,71,32,100,97,116,97,32,102,111,117,110,100,32,105,110,32,105,109,97,103,101,10,0,0,0,0,67,111,117,108,100,32,110,111,116,32,103,101,116,32,102,114,97,109,101,32,102,105,108,101,110,97,109,101,32,119,105,116,104,32,115,116,114,102,116,105,109,101,10,0,0,0,0,0,32,45,62,32,115,101,108,101,99,116,58,37,102,32,115,101,108,101,99,116,95,111,117,116,58,37,100,10,0,0,0,0,104,45,62,98,108,111,99,107,95,111,102,102,115,101,116,91,49,53,93,32,61,61,32,40,52,32,42,32,40,40,115,99,97,110,56,91,49,53,93,32,45,32,115,99,97,110,56,91,48,93,41,32,38,32,55,41,32,60,60,32,104,45,62,112,105,120,101,108,95,115,104,105,102,116,41,32,43,32,52,32,42,32,104,45,62,108,105,110,101,115,105,122,101,32,42,32,40,40,115,99,97,110,56,91,49,53,93,32,45,32,115,99,97,110,56,91,48,93,41,32,62,62,32,51,41,0,0,0,115,101,97,114,99,104,0,0,72,68,67,68,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,51,78,0,0,0,105,110,100,101,111,51,0,0,118,109,100,97,117,100,105,111,0,0,0,0,0,0,0,0,103,105,102,0,0,0,0,0,83,111,117,116,104,101,114,110,32,82,111,99,107,0,0,0,84,104,101,32,112,105,120,101,108,32,102,111,114,109,97,116,32,39,37,115,39,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,105,110,112,117,116,32,102,111,114,109,97,116,58,32,39,37,115,39,10,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,106,108,115,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,37,115,0,0,0,0,0,0,103,55,50,57,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,50,78,0,0,0,78,85,76,76,0,0,0,0,73,110,118,97,108,105,100,32,67,77,65,80,32,99,104,117,110,107,32,115,105,122,101,32,37,100,10,0,0,0,0,0,77,65,67,69,32,40,77,97,99,105,110,116,111,115,104,32,65,117,100,105,111,32,67,111,109,112,114,101,115,115,105,111,110,47,69,120,112,97,110,115,105,111,110,41,32,54,58,49,0,0,0,0,0,0,0,0,69,114,114,111,114,32,99,111,110,102,105,103,117,114,105,110,103,32,102,105,108,116,101,114,46,10,0,0,0,0,0,0,37,115,32,105,115,32,102,114,101,101,32,115,111,102,116,119,97,114,101,59,32,121,111,117,32,99,97,110,32,114,101,100,105,115,116,114,105,98,117,116,101,32,105,116,32,97,110,100,47,111,114,10,109,111,100,105,102,121,32,105,116,32,117,110,100,101,114,32,116,104,101,32,116,101,114,109,115,32,111,102,32,116,104,101,32,71,78,85,32,76,101,115,115,101,114,32,71,101,110,101,114,97,108,32,80,117,98,108,105,99,10,76,105,99,101,110,115,101,32,97,115,32,112,117,98,108,105,115,104,101,100,32,98,121,32,116,104,101,32,70,114,101,101,32,83,111,102,116,119,97,114,101,32,70,111,117,110,100,97,116,105,111,110,59,32,101,105,116,104,101,114,10,118,101,114,115,105,111,110,32,50,46,49,32,111,102,32,116,104,101,32,76,105,99,101,110,115,101,44,32,111,114,32,40,97,116,32,121,111,117,114,32,111,112,116,105,111,110,41,32,97,110,121,32,108,97,116,101,114,32,118,101,114,115,105,111,110,46,10,10,37,115,32,105,115,32,100,105,115,116,114,105,98,117,116,101,100,32,105,110,32,116,104,101,32,104,111,112,101,32,116,104,97,116,32,105,116,32,119,105,108,108,32,98,101,32,117,115,101,102,117,108,44,10,98,117,116,32,87,73,84,72,79,85,84,32,65,78,89,32,87,65,82,82,65,78,84,89,59,32,119,105,116,104,111,117,116,32,101,118,101,110,32,116,104,101,32,105,109,112,108,105,101,100,32,119,97,114,114,97,110,116,121,32,111,102,10,77,69,82,67,72,65,78,84,65,66,73,76,73,84,89,32,111,114,32,70,73,84,78,69,83,83,32,70,79,82,32,65,32,80,65,82,84,73,67,85,76,65,82,32,80,85,82,80,79,83,69,46,32,32,83,101,101,32,116,104,101,32,71,78,85,10,76,101,115,115,101,114,32,71,101,110,101,114,97,108,32,80,117,98,108,105,99,32,76,105,99,101,110,115,101,32,102,111,114,32,109,111,114,101,32,100,101,116,97,105,108,115,46,10,10,89,111,117,32,115,104,111,117,108,100,32,104,97,118,101,32,114,101,99,101,105,118,101,100,32,97,32,99,111,112,121,32,111,102,32,116,104,101,32,71,78,85,32,76,101,115,115,101,114,32,71,101,110,101,114,97,108,32,80,117,98,108,105,99,10,76,105,99,101,110,115,101,32,97,108,111,110,103,32,119,105,116,104,32,37,115,59,32,105,102,32,110,111,116,44,32,119,114,105,116,101,32,116,111,32,116,104,101,32,70,114,101,101,32,83,111,102,116,119,97,114,101,10,70,111,117,110,100,97,116,105,111,110,44,32,73,110,99,46,44,32,53,49,32,70,114,97,110,107,108,105,110,32,83,116,114,101,101,116,44,32,70,105,102,116,104,32,70,108,111,111,114,44,32,66,111,115,116,111,110,44,32,77,65,32,48,50,49,49,48,45,49,51,48,49,32,85,83,65,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,117,10,0,0,0,0,0,0,0,0,103,55,50,51,95,49,0,0,44,32,115,116,97,114,116,58,32,0,0,0,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1974920);
/* memory initializer */ allocate([101,95,53,49,78,0,0,0,116,98,0,0,0,0,0,0,109,97,99,101,54,0,0,0,37,115,32,39,37,115,39,32,119,97,115,32,115,112,101,99,105,102,105,101,100,32,116,104,114,111,117,103,104,32,116,104,101,32,37,115,32,111,112,116,105,111,110,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,44,32,119,104,105,99,104,32,105,115,32,102,101,100,32,102,114,111,109,32,97,32,99,111,109,112,108,101,120,32,102,105,108,116,101,114,103,114,97,112,104,46,10,37,115,32,97,110,100,32,45,102,105,108,116,101,114,95,99,111,109,112,108,101,120,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,116,111,103,101,116,104,101,114,32,102,111,114,32,116,104,101,32,115,97,109,101,32,115,116,114,101,97,109,46,10,0,0,0,0,0,0,103,55,50,50,0,0,0,0,105,110,105,116,105,97,108,95,111,102,102,115,101,116,0,0,97,61,102,109,116,112,58,37,100,32,118,98,114,61,37,115,13,10,0,0,0,0,0,0,103,101,110,114,101,0,0,0,79,117,116,112,117,116,32,105,115,32,110,111,116,32,115,101,101,107,97,98,108,101,10,0,102,114,109,0,0,0,0,0,121,117,118,44,114,103,98,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,48,78,0,0,0,116,116,0,0,0,0,0,0,35,69,88,84,45,88,45,84,65,82,71,69,84,68,85,82,65,84,73,79,78,58,37,100,10,0,0,0,0,0,0,0,77,65,67,69,32,40,77,97,99,105,110,116,111,115,104,32,65,117,100,105,111,32,67,111,109,112,114,101,115,115,105,111,110,47,69,120,112,97,110,115,105,111,110,41,32,51,58,49,0,0,0,0,0,0,0,0,117,50,52,98,101,32,100,101,109,117,120,101,114,0,0,0,35,115,111,102,116,119,97,114,101,58,32,37,115,10,0,0,45,102,105,108,116,101,114,95,115,99,114,105,112,116,0,0,115,101,116,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,32,102,108,97,103,115,32,40,100,101,112,114,101,99,97,116,101,100,59,32,117,115,101,32,101,114,114,95,100,101,116,101,99,116,44,32,115,97,118,101,32,118,105,97,32,97,118,99,111,110,118,41,0,99,111,111,107,105,101,115,0,105,110,100,101,120,32,111,118,101,114,102,108,111,119,32,65,32,37,100,32,43,32,37,108,108,117,32,62,61,32,37,100,10,0,0,0,0,0,0,0,108,111,99,97,108,32,116,97,103,32,37,35,48,52,120,32,119,105,116,104,32,48,32,115,105,122,101,10,0,0,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,37,115,32,102,111,114,32,119,114,105,116,105,110,103,10,0,0,115,101,116,32,80,65,84,44,32,80,77,84,32,97,110,100,32,83,68,84,32,118,101,114,115,105,111,110,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,57,78,0,0,0,112,114,111,103,114,101,115,115,105,118,101,0,0,0,0,0,109,97,99,101,51,0,0,0,102,114,97,109,101,99,114,99,0,0,0,0,0,0,0,0,45,118,102,47,45,97,102,47,45,102,105,108,116,101,114,0,86,101,114,32,49,10,66,114,32,37,46,54,102,10,73,112,103,32,49,10,80,112,105,32,37,100,10,66,112,105,111,112,32,37,100,10,80,105,120,32,48,10,67,102,32,37,100,10,67,103,32,37,100,10,83,108,32,37,100,10,110,108,49,54,32,37,100,10,86,105,32,49,10,102,49,32,49,10,0,0,82,84,80,32,109,117,120,101,114,32,102,108,97,103,115,0,37,100,47,37,100,0,0,0,116,111,111,32,109,97,110,121,32,105,110,100,101,120,32,101,110,116,114,105,101,115,32,37,117,32,40,37,120,41,10,0,85,110,97,98,108,101,32,116,111,32,102,105,110,100,32,100,101,102,97,117,108,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,102,111,114,32,73,110,112,117,116,32,83,116,114,101,97,109,32,35,37,100,46,37,100,10,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,115,97,109,112,108,101,32,102,111,114,109,97,116,115,0,0,0,0,0,115,116,101,114,101,111,95,109,111,100,101,0,0,0,0,0,71,73,70,32,100,101,109,117,120,101,114,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,56,78,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,105,101,108,100,32,111,114,100,101,114,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,50,0,0,0,98,105,116,95,114,97,116,101,0,0,0,0,0,0,0,0,83,116,114,101,97,109,99,111,112,121,32,114,101,113,117,101,115,116,101,100,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,44,32,119,104,105,99,104,32,105,115,32,102,101,100,32,102,114,111,109,32,97,32,99,111,109,112,108,101,120,32,102,105,108,116,101,114,103,114,97,112,104,46,32,70,105,108,116,101,114,105,110,103,32,97,110,100,32,115,116,114,101,97,109,99,111,112,121,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,116,111,103,101,116,104,101,114,46,10,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,103,55,50,50,46,99,0,0,0,0,0,0,77,111,118,105,101,47,118,105,100,101,111,32,115,99,114,101,101,110,32,99,97,112,116,117,114,101,0,0,0,0,0,0,44,32,37,56,100,44,32,48,120,37,48,56,120,0,0,0,105,109,97,103,101,50,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,55,78,0,0,0,102,105,101,108,100,95,111,114,100,101,114,0,0,0,0,0,86,105,100,101,111,32,99,111,100,101,99,32,39,37,115,39,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,119,109,97,118,50,0,0,0,79,110,108,121,32,118,105,100,101,111,32,97,110,100,32,97,117,100,105,111,32,102,105,108,116,101,114,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,32,99,117,114,114,101,110,116,108,121,46,10,0,0,65,115,112,101,99,116,82,97,116,105,111,89,0,0,0,0,69,110,99,111,100,101,114,0,48,120,37,108,108,120,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,54,78,0,0,0,83,107,105,112,32,112,114,111,99,101,115,115,105,110,103,32,97,108,112,104,97,0,0,0,115,101,116,32,73,47,79,32,111,112,101,114,97,116,105,111,110,32,109,97,120,105,109,117,109,32,98,108,111,99,107,32,115,105,122,101,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,49,0,0,0,84,73,77,69,66,65,83,69,61,37,100,47,37,100,10,0,83,121,110,116,97,120,32,101,114,114,111,114,32,105,110,32,109,97,116,114,105,120,32,34,37,115,34,32,97,116,32,99,111,101,102,102,32,37,100,10,0,0,0,0,0,0,0,0,83,84,65,82,84,61,37,108,108,100,0,0,0,0,0,0,102,102,109,45,62,112,97,99,107,101,116,95,101,110,100,32,62,61,32,102,102,109,45,62,112,97,99,107,101,116,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,100,10,0,0,0,0,115,114,99,119,0,0,0,0,80,67,83,95,71,97,114,111,117,97,95,85,84,77,95,122,111,110,101,95,51,51,78,0,115,107,105,112,95,97,108,112,104,97,0,0,0,0,0,0,85,110,107,110,111,119,110,32,116,97,103,32,37,99,37,99,37,99,37,99,10,0,0,0,119,109,97,118,49,0,0,0,67,97,110,39,116,32,105,110,105,116,105,97,108,105,122,101,32,68,86,32,102,111,114,109,97,116,33,10,77,97,107,101,32,115,117,114,101,32,116,104,97,116,32,121,111,117,32,115,117,112,112,108,121,32,101,120,97,99,116,108,121,32,116,119,111,32,115,116,114,101,97,109,115,58,10,32,32,32,32,32,118,105,100,101,111,58,32,50,53,102,112,115,32,111,114,32,50,57,46,57,55,102,112,115,44,32,97,117,100,105,111,58,32,50,99,104,47,52,56,107,72,122,47,80,67,77,10,32,32,32,32,32,40,53,48,77,98,112,115,32,97,108,108,111,119,115,32,97,110,32,111,112,116,105,111,110,97,108,32,115,101,99,111,110,100,32,97,117,100,105,111,32,115,116,114,101,97,109,41,10,0,0,0,0,43,112,97,115,115,50,0,0,67,97,110,39,116,32,100,101,116,101,114,109,105,110,101,32,112,114,111,102,105,108,101,32,111,102,32,68,86,32,105,110,112,117,116,32,115,116,114,101,97,109,46,10,0,0,0,0,90,101,114,111,32,70,80,83,32,114,101,112,111,114,116,101,100,44,32,100,101,102,97,117,108,116,105,110,103,32,116,111,32,49,48,10,0,0,0,0,115,99,116,104,114,101,115,104,0,0,0,0,0,0,0,0,121,117,118,52,50,48,112,49,54,98,101,0,0,0,0,0,68,105,109,71,114,97,121,0,60,99,104,97,110,110,101,108,95,108,97,121,111,117,116,62,0,0,0,0,0,0,0,0,109,111,110,111,0,0,0,0,115,111,117,114,99,101,32,104,111,114,105,122,111,110,116,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,105,110,95,115,97,109,112,108,101,95,102,109,116,0,0,0,13,10,0,0,0,0,0,0,80,67,83,95,70,97,104,117,100,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,65,68,80,67,77,32,83,104,111,99,107,119,97,118,101,32,70,108,97,115,104,0,0,0,114,101,102,99,111,117,110,116,101,100,95,102,114,97,109,101,115,0,0,0,0,0,0,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,76,105,110,101,32,37,100,58,32,102,105,108,101,110,97,109,101,32,114,101,113,117,105,114,101,100,10,0,0,0,0,0,100,118,97,117,100,105,111,0,101,112,67,111,110,102,105,103,32,37,100,0,0,0,0,0,103,0,0,0,0,0,0,0,32,86,111,114,98,105,115,32,105,100,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,102,114,97,109,105,110,103,32,102,108,97,103,32,110,111,116,32,115,101,116,41,46,32,10,0,0,0,0,0,0,67,68,88,76,32,100,101,109,117,120,101,114,0,0,0,0,66,105,116,115,32,111,118,101,114,99,111,110,115,117,109,112,116,105,111,110,58,32,37,105,32,62,32,37,105,10,0,0,43,112,97,115,115,49,0,0,105,110,118,97,108,105,100,32,112,97,99,107,101,116,58,32,78,85,76,76,32,100,97,116,97,44,32,115,105,122,101,32,33,61,32,48,10,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,50,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,76,105,110,101,97,114,95,70,111,111,116,95,73,110,100,105,97,110,0,0,0,0,0,0,85,110,107,110,111,119,110,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,116,97,103,32,37,100,47,48,88,37,48,88,10,0,0,0,0,109,117,120,105,110,103,32,99,111,100,101,99,32,99,117,114,114,101,110,116,108,121,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,80,67,77,32,68,45,67,105,110,101,109,97,32,97,117,100,105,111,32,115,105,103,110,101,100,32,50,52,45,98,105,116,0,0,0,0,0,0,0,0,110,97,113,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,112,97,99,107,101,116,32,116,97,98,108,101,10,0,0,0,0,0,102,114,97,109,101,114,97,116,101,32,110,111,116,32,115,101,116,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,98,32,116,121,112,101,32,105,110,32,73,32,70,114,97,109,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,37,100,32,115,117,98,115,116,114,101,97,109,115,32,40,109,111,114,101,32,116,104,97,110,32,116,104,101,32,109,97,120,105,109,117,109,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,100,101,99,111,100,101,114,41,0,0,69,79,73,32,109,105,115,115,105,110,103,44,32,101,109,117,108,97,116,105,110,103,10,0,32,115,97,109,112,108,101,115,95,110,58,37,100,32,99,111,110,115,117,109,101,100,95,115,97,109,112,108,101,115,95,110,58,37,100,0,0,0,0,0,116,111,111,32,109,97,110,121,32,98,108,111,99,107,115,58,32,37,117,10,0,0,0,0,99,111,110,116,101,120,116,95,99,111,117,110,116,32,62,32,48,0,0,0,0,0,0,0,56,108,101,118,101,108,0,0,104,100,99,100,0,0,0,0,80,67,83,95,70,97,104,117,100,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,112,114,101,95,100,101,99,111,100,101,114,0,0,0,0,0,72,46,50,54,52,32,47,32,65,86,67,32,47,32,77,80,69,71,45,52,32,65,86,67,32,47,32,77,80,69,71,45,52,32,112,97,114,116,32,49,48,0,0,0,0,0,0,0,86,111,114,98,105,115,0,0,68,114,101,97,109,0,0,0,37,115,10,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,114,99,95,111,118,101,114,114,105,100,101,10,0,0,0,0,0,0,101,88,116,101,110,100,101,100,32,66,73,78,97,114,121,32,116,101,120,116,32,40,88,66,73,78,41,32,100,101,109,117,120,101,114,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,108,97,114,103,101,115,116,32,102,114,97,109,101,32,115,105,122,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,102,105,108,101,32,115,105,122,101,10,0,0,0,0,0,0,102,108,118,0,0,0,0,0,117,110,107,110,111,119,110,32,98,108,111,99,107,32,40,99,104,97,114,97,99,116,101,114,32,61,32,37,99,44,32,100,101,99,105,109,97,108,32,61,32,37,100,44,32,104,101,120,32,61,32,37,120,41,33,33,33,10,0,0,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,100,111,95,110,111,116,104,105,110,103,0,0,0,0,0,0,118,111,114,98,105,115,0,0,37,100,44,37,100,44,37,100,0,0,0,0,0,0,0,0,118,101,114,115,105,111,110,0,83,116,97,116,105,115,116,105,99,115,58,32,37,100,32,115,101,101,107,115,44,32,37,100,32,119,114,105,116,101,111,117,116,115,10,0,0,0,0,0,78,47,65,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,111,112,101,110,32,116,104,101,32,39,37,115,39,32,112,114,111,116,111,99,111,108,32,102,111,114,32,114,101,97,100,105,110,103,10,0,0,0,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,115,101,116,32,105,110,112,117,116,32,116,101,120,116,32,115,117,98,116,105,116,108,101,115,32,99,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,32,109,111,100,101,0,0,0,0,0,0,0,0,68,67,65,32,40,68,84,83,32,67,111,104,101,114,101,110,116,32,65,99,111,117,115,116,105,99,115,41,0,0,0,0,97,118,105,115,116,45,62,102,114,97,109,101,115,95,104,100,114,95,115,116,114,109,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,105,110,116,101,114,32,109,97,116,114,105,120,46,10,0,0,0,0,114,101,115,101,116,32,116,105,109,101,115,116,97,109,112,115,32,97,116,32,116,104,101,32,98,101,103,105,110,32,111,102,32,101,97,99,104,32,115,101,103,109,101,110,116,0,0,0,111,102,102,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,102,105,110,100,32,116,105,109,101,115,116,97,109,112,32,37,108,108,100,32,105,110,32,105,110,100,101,120,32,37,108,108,100,32,46,46,32,37,108,108,100,10,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,0,115,117,98,95,99,104,97,114,101,110,99,95,109,111,100,101,0,0,0,0,0,0,0,0,100,116,115,0,0,0,0,0,117,50,52,108,101,32,100,101,109,117,120,101,114,0,0,0,68,105,97,108,111,103,117,101,58,32,37,108,100,44,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,37,115,13,10,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,105,110,116,114,97,32,109,97,116,114,105,120,46,10,0,0,0,0,91,83,99,114,105,112,116,32,73,110,102,111,93,0,0,0,102,95,101,114,114,95,100,101,116,101,99,116,0,0,0,0,69,114,114,111,114,32,115,121,110,99,112,111,105,110,116,95,99,111,117,110,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,0,0,112,97,114,116,105,116,105,111,110,32,37,105,58,32,98,97,100,32,84,104,105,115,80,97,114,116,105,116,105,111,110,32,61,32,37,108,108,88,10,0,116,97,98,108,101,115,95,118,101,114,115,105,111,110,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,0,115,101,116,32,105,110,112,117,116,32,116,101,120,116,32,115,117,98,116,105,116,108,101,115,32,99,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,0,0,0,0,0,65,84,83,67,32,65,47,53,50,65,32,40,65,67,45,51,41,0,0,0,0,0,0,0,112,107,116,110,117,109,58,37,100,44,32,112,107,116,99,116,58,37,100,32,32,112,116,115,58,32,37,108,108,100,10,0,85,110,107,110,111,119,110,32,112,105,120,101,108,32,102,111,114,109,97,116,32,114,101,113,117,101,115,116,101,100,58,32,37,115,46,10,0,0,0,0,10,0,0,0,0,0,0,0,65,80,69,32,84,97,103,32,105,115,32,97,32,104,101,97,100,101,114,10,0,0,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,78,111,32,102,114,97,109,101,115,32,105,110,32,116,104,101,32,102,105,108,101,33,10,0,37,100,0,0,0,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,37,100,32,105,110,118,97,108,105,100,10,0,102,108,118,0,0,0,0,0,115,97,109,112,108,101,95,102,109,116,115,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,97,116,116,97,99,104,109,101,110,116,10,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,102,114,97,109,101,32,102,114,111,109,32,102,105,108,101,10,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,52,78,0,0,0,115,117,98,95,99,104,97,114,101,110,99,0,0,0,0,0,97,99,51,0,0,0,0,0,102,115,45,62,111,110,95,101,118,101,110,116,0,0,0,0,73,110,118,97,108,105,100,32,97,115,112,101,99,116,32,114,97,116,105,111,58,32,37,115,10,0,0,0,0,0,0,0,68,117,114,105,110,103,32,112,101,114,102,111,114,109,97,110,99,101,0,0,0,0,0,0,115,114,99,45,62,97,117,100,105,111,0,0,0,0,0,0,102,108,105,99,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,118,111,108,117,109,101,100,101,116,101,99,116,46,99,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,51,78,0,0,0,112,107,116,95,116,105,109,101,98,97,115,101,0,0,0,0,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,0,118,111,108,117,109,101,95,105,58,37,100,47,50,53,53,32,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,114,97,116,101,32,118,97,108,117,101,58,32,37,115,10,0,0,0,0,100,0,0,0,0,0,0,0,65,115,112,101,99,116,82,97,116,105,111,88,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,108,108,95,99,104,97,110,110,101,108,95,99,111,117,110,116,115,0,0,0,0,0,0,67,104,97,110,110,101,108,32,34,37,46,56,115,34,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,32,105,110,32,116,104,101,32,99,104,111,115,101,110,32,108,97,121,111,117,116,10,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,101,113,117,101,110,99,121,32,37,102,46,32,70,114,101,113,117,101,110,99,121,32,109,117,115,116,32,98,101,32,108,101,115,115,32,116,104,97,110,32,104,97,108,102,32,116,104,101,32,115,97,109,112,108,101,45,114,97,116,101,32,37,100,46,10,0,0,0,0,0,102,108,97,99,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,0,115,97,109,112,108,101,32,102,111,114,109,97,116,32,97,117,100,105,111,32,100,101,99,111,100,101,114,115,32,115,104,111,117,108,100,32,112,114,101,102,101,114,0,0,0,0,0,0,97,97,99,0,0,0,0,0,105,32,60,32,99,116,120,45,62,110,98,95,105,110,112,117,116,115,0,0,0,0,0,0,66,111,116,104,32,45,102,105,108,116,101,114,32,97,110,100,32,45,102,105,108,116,101,114,95,115,99,114,105,112,116,32,115,101,116,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,46,10,0,0,100,101,99,97,121,115,0,0,102,108,97,99,0,0,0,0,115,116,101,114,101,111,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,108,105,115,116,32,111,102,32,99,104,97,110,110,101,108,32,109,97,112,112,101,100,58,32,39,37,115,39,46,10,0,0,0,0,82,101,115,99,97,108,101,100,32,118,97,108,117,101,32,102,111,114,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,32,105,115,32,116,111,111,32,98,105,103,46,10,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,0,114,101,113,117,101,115,116,95,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,0,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,0,0,0,0,109,97,105,110,32,119,58,37,100,32,104,58,37,100,32,102,109,116,58,37,115,32,111,118,101,114,108,97,121,32,119,58,37,100,32,104,58,37,100,32,102,109,116,58,37,115,32,101,111,102,95,97,99,116,105,111,110,58,37,115,10,0,0,0,70,105,108,116,101,114,103,114,97,112,104,32,115,99,114,105,112,116,0,0,0,0,0,0,102,105,108,109,115,116,114,105,112,0,0,0,0,0,0,0,66,111,111,115,116,32,111,114,32,99,117,116,32,117,112,112,101,114,32,102,114,101,113,117,101,110,99,105,101,115,46,0,121,49,0,0,0,0,0,0,121,117,118,52,50,48,112,49,54,108,101,0,0,0,0,0,68,101,101,112,83,107,121,66,108,117,101,0,0,0,0,0,60,99,111,108,111,114,62,0,69,118,97,108,0,0,0,0,108,111,119,32,102,114,101,113,117,101,110,99,121,32,50,0,115,114,99,95,104,95,99,104,114,95,112,111,115,0,0,0,115,101,116,32,105,110,112,117,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,44,32,13,10,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,48,78,0,0,0,115,101,116,32,116,101,109,112,111,32,115,99,97,108,101,32,102,97,99,116,111,114,0,0,97,100,112,99,109,95,115,119,102,0,0,0,0,0,0,0,75,97,114,97,111,107,101,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,77,111,100,101,0,0,0,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,77,111,100,101,0,0,0,0,109,112,51,0,0,0,0,0,76,111,119,32,68,101,108,97,121,32,83,66,82,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,116,32,103,114,101,101,110,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,0,0,0,0,32,86,111,114,98,105,115,32,105,100,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,105,108,108,101,103,97,108,32,98,108,111,99,107,115,105,122,101,41,46,32,10,0,77,105,120,101,100,32,102,105,101,108,100,47,102,114,97,109,101,32,100,105,114,101,99,116,32,109,111,100,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,70,105,108,116,101,114,103,114,97,112,104,0,0,0,0,0,115,49,0,0,0,0,0,0,99,50,95,101,120,112,114,0,76,105,110,101,97,114,95,70,111,111,116,95,67,108,97,114,107,101,0,0,0,0,0,0,115,111,102,116,119,97,114,101,0,0,0,0,0,0,0,0,112,99,109,95,115,50,52,100,97,117,100,0,0,0,0,0,77,97,120,32,108,101,118,101,108,58,32,37,102,10,0,0,116,114,117,110,99,97,116,101,100,0,0,0,0,0,0,0,102,105,108,109,115,116,114,105,112,0,0,0,0,0,0,0,97,117,116,111,109,97,116,105,99,32,116,104,114,101,97,100,32,110,117,109,98,101,114,32,100,101,116,101,99,116,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,44,32,112,97,116,99,104,32,119,101,108,99,111,109,101,10,0,0,0,0,0,0,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,111,110,116,101,120,116,32,115,99,114,97,116,99,104,32,98,117,102,102,101,114,115,46,10,0,0,0,0,0,0,0,115,107,105,112,32,119,105,116,104,32,112,114,101,118,105,110,116,114,97,10,0,0,0,0,77,76,80,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,117,112,32,116,111,32,50,32,115,117,98,115,116,114,101,97,109,115,46,10,0,0,37,48,56,88,32,0,0,0,109,97,114,107,101,114,32,112,97,114,115,101,114,32,117,115,101,100,32,37,100,32,98,121,116,101,115,32,40,37,100,32,98,105,116,115,41,10,0,0,32,105,110,116,101,114,108,97,99,101,95,116,121,112,101,58,37,99,32,112,105,99,116,95,116,121,112,101,58,37,99,32,115,99,101,110,101,58,37,102,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,104,45,62,109,98,95,121,32,60,32,104,45,62,109,98,95,104,101,105,103,104,116,0,0,52,108,101,118,101,108,0,0,83,116,97,110,100,97,114,100,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,0,110,0,0,0,0,0,0,0,107,97,0,0,0,0,0,0,104,50,54,52,0,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,112,111,115,0,0,0,0,0,69,117,114,111,100,97,110,99,101,0,0,0,0,0,0,0,69,114,114,111,114,46,32,89,85,86,52,77,80,69,71,32,115,116,114,101,97,109,32,104,101,97,100,101,114,32,119,114,105,116,101,32,102,97,105,108,101,100,46,10,0,0,0,0,37,115,32,39,37,115,39,32,119,97,115,32,100,101,102,105,110,101,100,32,102,111,114,32,37,115,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,32,98,117,116,32,99,111,100,101,99,32,99,111,112,121,32,119,97,115,32,115,101,108,101,99,116,101,100,46,10,70,105,108,116,101,114,105,110,103,32,97,110,100,32,115,116,114,101,97,109,99,111,112,121,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,116,111,103,101,116,104,101,114,46,10,0,0,102,105,108,101,0,0,0,0,115,101,116,32,105,110,112,117,116,32,103,97,105,110,0,0,112,97,100,95,108,101,110,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,0,86,111,105,99,101,32,79,118,101,114,0,0,0,0,0,0,109,112,50,0,0,0,0,0,102,114,97,109,101,95,108,105,115,116,45,62,101,110,100,32,33,61,32,48,76,0,0,0,77,97,120,32,99,104,97,110,110,101,108,32,109,97,112,112,105,110,103,32,102,111,114,32,111,117,116,112,117,116,32,37,100,46,37,100,32,114,101,97,99,104,101,100,10,0,0,0,37,115,58,32,37,115,10,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,32,111,118,101,114,108,97,112,58,32,111,117,116,112,117,116,32,108,97,121,111,117,116,32,119,105,108,108,32,98,101,32,100,101,116,101,114,109,105,110,101,100,32,98,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,100,105,115,116,105,110,99,116,32,105,110,112,117,116,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,0,0,0,0,0,102,102,109,101,116,97,100,97,116,97,0,0,0,0,0,0,80,67,83,95,69,103,121,112,116,95,49,57,48,55,95,69,120,116,95,80,117,114,112,108,101,0,0,0,0,0,0,0,118,111,0,0,0,0,0,0,68,80,67,77,32,83,111,108,0,0,0,0,0,0,0,0,105,110,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,114,101,115,101,116,95,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,0,0,118,97,100,0,0,0,0,0,100,101,108,97,121,91,37,100,93,58,32,37,102,32,105,115,32,111,117,116,32,111,102,32,97,108,108,111,119,101,100,32,114,97,110,103,101,58,32,40,48,44,32,57,48,48,48,48,93,10,0,0,0,0,0,0,124,0,0,0,0,0,0,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,80,67,83,95,69,103,121,112,116,95,49,57,48,55,95,80,117,114,112,108,101,95,66,101,108,116,0,0,0,0,0,0,69,109,101,114,103,101,110,99,121,0,0,0,0,0,0,0,115,111,108,95,100,112,99,109,0,0,0,0,0,0,0,0,117,49,54,98,101,32,100,101,109,117,120,101,114,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,58,32,37,115,46,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,39,124,39,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,99,104,97,110,110,101,108,115,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,0,0,115,105,122,101,32,105,110,32,98,121,116,101,115,32,102,111,114,32,101,97,99,104,32,99,104,117,110,107,0,0,0,0,102,102,109,101,116,97,100,97,116,97,0,0,0,0,0,0,110,111,32,105,110,100,101,120,32,97,116,32,116,104,101,32,101,110,100,10,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,100,47,37,100,41,32,102,111,117,110,100,32,102,111,114,32,115,116,114,101,97,109,32,35,37,100,44,32,116,105,109,101,32,98,97,115,101,32,102,111,114,99,101,100,32,116,111,32,49,47,52,56,48,48,48,10,0,0,78,117,108,108,32,118,105,100,101,111,32,115,111,117,114,99,101,44,32,114,101,116,117,114,110,32,117,110,112,114,111,99,101,115,115,101,100,32,118,105,100,101,111,32,102,114,97,109,101,115,46,0,0,0,0,0,100,111,110,39,116,32,111,102,102,115,101,116,32,100,116,115,47,112,116,115,0,0,0,0,80,67,83,95,69,103,121,112,116,95,49,57,48,55,95,82,101,100,95,66,101,108,116,0,101,109,0,0,0,0,0,0,68,80,67,77,32,88,97,110,0,0,0,0,0,0,0,0,68,97,116,97,32,115,116,114,101,97,109,32,101,110,99,111,100,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,121,101,116,32,40,111,110,108,121,32,115,116,114,101,97,109,99,111,112,121,41,10,0,0,0,0,0,0,0,102,102,109,0,0,0,0,0,115,0,0,0,0,0,0,0,79,109,105,116,32,116,104,101,32,98,97,115,101,32,100,97,116,97,32,111,102,102,115,101,116,32,105,110,32,116,102,104,100,32,97,116,111,109,115,0,85,110,107,110,111,119,110,32,99,111,118,101,114,32,116,121,112,101,58,32,48,120,37,120,46,10,0,0,0,0,0,0,100,101,99,111,100,101,95,97,117,100,105,111,32,37,100,46,37,100,0,0,0,0,0,0,85,115,105,110,103,32,37,46,49,54,108,108,120,32,102,111,114,32,97,116,116,97,99,104,109,101,110,116,32,37,100,10,0,0,0,0,0,0,0,0,68,95,87,69,66,86,84,84,47,77,69,84,65,68,65,84,65,0,0,0,0,0,0,0,115,104,111,119,32,115,116,97,110,100,97,114,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,0,0,0,51,50,48,120,50,52,48,0,102,102,109,0,0,0,0,0,80,67,83,95,68,111,117,97,108,97,95,85,84,77,95,122,111,110,101,95,51,50,78,0,67,111,109,109,101,110,116,97,114,121,0,0,0,0,0,0,120,97,110,95,100,112,99,109,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,37,115,32,116,121,112,101,32,39,37,115,39,10,0,0,0,68,117,114,105,110,103,32,114,101,99,111,114,100,105,110,103,0,0,0,0,0,0,0,0,115,58,37,100,120,37,100,32,114,58,37,100,47,37,100,32,114,117,108,101,58,37,100,32,115,116,105,116,99,104,58,37,100,32,115,99,114,111,108,108,58,37,100,32,102,117,108,108,58,37,100,32,115,101,101,100,58,37,117,10,0,0,0,0,101,112,97,102,0,0,0,0,115,101,110,100,32,111,110,101,32,102,114,97,109,101,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,0,0,0,80,67,83,95,67,111,114,114,101,103,111,95,65,108,101,103,114,101,95,85,84,77,95,50,52,83,0,0,0,0,0,0,99,111,0,0,0,0,0,0,68,80,67,77,32,73,110,116,101,114,112,108,97,121,0,0,99,111,109,112,108,101,120,0,85,110,107,110,111,119,110,32,37,115,32,39,37,115,39,10,0,0,0,0,0,0,0,0,80,97,121,108,111,97,100,32,101,120,116,101,110,115,105,111,110,32,37,120,32,37,100,10,0,0,0,0,0,0,0,0,97,98,117,102,102,101,114,115,105,110,107,0,0,0,0,0,119,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,80,67,83,95,67,111,114,114,101,103,111,95,65,108,101,103,114,101,95,85,84,77,95,50,51,83,0,0,0,0,0,0,68,105,97,108,111,103,117,101,0,0,0,0,0,0,0,0,105,110,116,101,114,112,108,97,121,95,100,112,99,109,0,0,108,120,0,0,0,0,0,0,77,97,116,99,104,101,100,32,37,115,32,39,37,115,39,32,102,111,114,32,99,111,100,101,99,32,39,37,115,39,46,10,0,0,0,0,0,0,0,0,114,111,116,97,116,101,32,99,111,117,110,116,101,114,45,99,108,111,99,107,119,105,115,101,32,119,105,116,104,32,118,101,114,116,105,99,97,108,32,102,108,105,112,0,0,0,0,0,115,101,116,32,103,114,105,100,32,115,105,122,101,0,0,0,115,101,116,32,116,104,101,32,102,114,97,109,101,115,32,98,97,116,99,104,32,115,105,122,101,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,80,67,83,95,67,97,114,116,104,97,103,101,95,83,117,100,95,84,117,110,105,115,105,101,0,0,0,0,0,0,0,0,100,105,0,0,0,0,0,0,68,80,67,77,32,105,100,32,82,111,81,0,0,0,0,0,100,101,99,111,100,101,114,0,109,97,105,110,0,0,0,0,102,105,114,115,116,95,102,105,101,108,100,0,0,0,0,0,93,10,0,0,0,0,0,0,107,101,101,112,32,116,104,101,32,115,97,109,101,32,105,110,112,117,116,32,102,105,101,108,100,0,0,0,0,0,0,0,101,97,0,0,0,0,0,0,100,101,102,105,110,101,32,97,110,32,101,120,99,108,117,115,105,111,110,32,98,97,110,100,32,119,104,105,99,104,32,101,120,99,108,117,100,101,115,32,116,104,101,32,108,105,110,101,115,32,98,101,116,119,101,101,110,32,121,48,32,97,110,100,32,121,49,32,102,114,111,109,32,116,104,101,32,102,105,101,108,100,32,109,97,116,99,104,105,110,103,32,100,101,99,105,115,105,111,110,0,0,0,0,118,97,97,112,105,95,118,108,100,0,0,0,0,0,0,0,68,101,101,112,80,105,110,107,0,0,0,0,0,0,0,0,60,100,117,114,97,116,105,111,110,62,0,0,0,0,0,0,80,72,73,0,0,0,0,0,76,70,69,50,0,0,0,0,115,119,115,58,32,105,110,105,116,70,105,108,116,101,114,32,102,97,105,108,101,100,10,0,115,111,117,114,99,101,32,118,101,114,116,105,99,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,0,0,111,117,116,95,115,97,109,112,108,101,95,114,97,116,101,0,10,0,0,0,0,0,0,0,80,67,83,95,67,97,114,116,104,97,103,101,95,78,111,114,100,95,84,117,110,105,115,105,101,0,0,0,0,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,52,45,98,105,116,0,0,0,72,101,97,114,105,110,103,32,73,109,112,97,105,114,101,100,0,0,0,0,0,0,0,0,100,104,101,97,100,112,104,111,110,101,95,109,111,100,101,0,100,104,101,97,100,112,104,111,110,101,95,109,111,100,101,0,114,111,113,95,100,112,99,109,0,0,0,0,0,0,0,0,65,65,67,32,100,97,116,97,32,114,101,115,105,108,105,101,110,99,101,32,40,102,108,97,103,115,32,37,120,41,0,0,103,114,101,101,110,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,114,97,116,101,10,0,0,0,0,0,48,0,0,0,0,0,0,0,101,110,99,111,100,101,114,0,101,97,95,99,100,97,116,97,0,0,0,0,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,49,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,76,105,110,101,97,114,95,70,111,111,116,95,77,111,100,105,102,105,101,100,95,65,109,101,114,105,99,97,110,0,0,0,32,47,32,0,0,0,0,0,101,114,114,111,114,91,63,93,32,118,97,114,105,97,98,108,101,115,32,119,105,108,108,32,98,101,32,115,101,116,32,100,117,114,105,110,103,32,101,110,99,111,100,105,110,103,0,0,119,0,0,0,0,0,0,0,99,98,112,121,32,37,100,32,105,110,118,97,108,105,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,109,117,108,116,105,32,116,104,114,101,97,100,101,100,32,101,110,99,111,100,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,40,117,118,32,115,116,114,105,100,101,32,109,105,115,109,97,116,99,104,41,10,0,0,0,0,0,0,0,115,107,105,112,112,101,100,32,77,66,32,105,110,32,73,32,102,114,97,109,101,32,97,116,32,37,100,32,37,100,10,0,66,108,111,99,107,32,115,105,122,101,32,112,111,119,50,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,109,97,120,105,109,117,109,32,40,37,100,41,46,10,0,109,106,112,101,103,58,32,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,105,110,103,32,116,121,112,101,32,40,37,120,41,10,0,0,0,0,110,58,37,102,32,112,116,115,58,37,102,32,116,58,37,102,32,107,101,121,58,37,100,0,100,101,99,111,100,101,95,115,108,105,99,101,95,104,101,97,100,101,114,32,101,114,114,111,114,10,0,0,0,0,0,0,50,108,101,118,101,108,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,80,67,83,95,67,97,114,116,104,97,103,101,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,0,0,0,0,0,105,110,95,119,0,0,0,0,104,105,0,0,0,0,0,0,67,114,101,97,116,105,118,101,32,89,85,86,32,40,67,89,85,86,41,0,0,0,0,0,82,101,97,108,65,117,100,105,111,32,50,46,48,32,40,50,56,46,56,75,41,0,0,0,110,0,0,0,0,0,0,0,80,111,112,45,70,111,108,107,0,0,0,0,0,0,0,0,89,85,86,52,77,80,69,71,32,115,116,114,101,97,109,32,99,111,110,116,97,105,110,115,32,109,105,120,101,100,32,105,110,116,101,114,108,97,99,101,100,32,97,110,100,32,110,111,110,45,105,110,116,101,114,108,97,99,101,100,32,102,114,97,109,101,115,46,10,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,99,111,112,121,0,0,0,0,100,120,97,0,0,0,0,0,108,97,118,102,105,46,112,115,110,114,46,109,115,101,46,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,55,0,0,0,0,0,86,105,115,117,97,108,108,121], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1985160);
/* memory initializer */ allocate([32,73,109,112,97,105,114,101,100,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,114,97,95,50,56,56,0,0,100,118,0,0,0,0,0,0,37,115,37,115,47,37,115,46,97,118,112,114,101,115,101,116,0,0,0,0,0,0,0,0,115,101,116,114,108,105,109,105,116,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,37,115,10,0,0,0,0,0,0,0,32,32,68,117,114,97,116,105,111,110,58,32,0,0,0,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,54,0,0,0,0,0,118,105,0,0,0,0,0,0,82,101,97,108,65,117,100,105,111,32,49,46,48,32,40,49,52,46,52,75,41,0,0,0,47,46,97,118,99,111,110,118,0,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,119,114,105,116,101,32,97,32,104,101,97,100,101,114,32,116,111,32,116,104,101,32,102,105,114,115,116,32,115,101,103,109,101,110,116,32,97,110,100,32,97,32,116,114,97,105,108,101,114,32,116,111,32,116,104,101,32,108,97,115,116,32,111,110,101,0,0,0,0,0,0,0,111,110,0,0,0,0,0,0,115,45,62,110,98,95,105,110,112,117,116,115,32,38,38,32,115,45,62,110,98,95,105,110,112,117,116,115,32,60,61,32,52,0,0,0,0,0,0,0,109,50,118,0,0,0,0,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,53,0,0,0,0,0,69,102,102,101,99,116,115,0,114,97,95,49,52,52,0,0,117,49,54,108,101,32,100,101,109,117,120,101,114,0,0,0,102,111,114,99,101,32,116,101,114,109,105,110,97,116,105,111,110,32,119,104,101,110,32,116,104,101,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,32,116,101,114,109,105,110,97,116,101,115,0,0,0,0,37,115,37,115,47,37,115,45,37,115,46,97,118,112,114,101,115,101,116,0,0,0,0,0,99,104,117,110,107,95,115,105,122,101,0,0,0,0,0,0,99,97,110,110,111,116,32,97,100,106,117,115,116,32,97,117,100,105,111,32,98,121,116,101,115,10,0,0,0,0,0,0,110,117,116,45,62,110,101,120,116,95,115,116,97,114,116,99,111,100,101,32,61,61,32,40,48,120,69,52,65,68,69,69,67,65,52,53,54,57,85,76,76,32,43,32,40,40,40,117,105,110,116,54,52,95,116,41,40,39,78,39,60,60,56,41,32,43,32,39,75,39,41,60,60,52,56,41,41,0,0,0,67,111,109,112,117,116,101,32,97,110,100,32,97,112,112,108,121,32,97,32,108,111,111,107,117,112,32,116,97,98,108,101,32,116,111,32,116,104,101,32,82,71,66,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,102,114,97,109,101,32,108,97,121,111,117,116,32,116,121,112,101,58,32,37,100,10,0,0,109,112,101,103,116,115,95,99,111,112,121,116,115,0,0,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,52,0,0,0,0,0,101,102,0,0,0,0,0,0,65,77,82,45,87,66,32,40,65,100,97,112,116,105,118,101,32,77,117,108,116,105,45,82,97,116,101,32,87,105,100,101,66,97,110,100,41,0,0,0,110,111,110,101,0,0,0,0,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,115,104,97,114,101,47,102,102,109,112,101,103,0,0,0,0,0,100,116,115,104,100,0,0,0,115,101,116,32,105,110,116,101,114,108,97,99,105,110,103,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,111,109,105,116,95,116,102,104,100,95,111,102,102,115,101,116,0,0,0,0,0,0,0,0,37,115,45,37,115,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,106,101,99,116,32,102,114,97,109,101,32,105,110,116,111,32,102,105,108,116,101,114,32,110,101,116,119,111,114,107,58,32,37,115,10,0,98,0,0,0,0,0,0,0,100,116,115,0,0,0,0,0,65,116,116,97,99,104,109,101,110,116,32,115,116,114,101,97,109,32,37,100,32,104,97,115,32,110,111,32,109,105,109,101,116,121,112,101,32,116,97,103,32,97,110,100,32,105,116,32,99,97,110,110,111,116,32,98,101,32,100,101,100,117,99,101,100,32,102,114,111,109,32,116,104,101,32,99,111,100,101,99,32,105,100,46,10,0,0,0,68,95,87,69,66,86,84,84,47,68,69,83,67,82,73,80,84,73,79,78,83,0,0,0,108,97,121,111,117,116,115,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,51,0,0,0,0,0,77,97,105,110,32,65,117,100,105,111,32,83,101,114,118,105,99,101,0,0,0,0,0,0,97,109,114,95,119,98,0,0,109,111,100,101,0,0,0,0,100,115,105,99,105,110,0,0,72,79,77,69,0,0,0,0,82,101,99,111,114,100,105,110,103,32,76,111,99,97,116,105,111,110,0,0,0,0,0,0,114,97,100,105,117,115,0,0,115,116,101,112,58,37,100,32,102,114,97,109,101,95,114,97,116,101,58,37,100,47,37,100,40,37,102,41,32,45,62,32,102,114,97,109,101,95,114,97,116,101,58,37,100,47,37,100,40,37,102,41,10,0,0,0,100,110,120,104,100,0,0,0,86,105,101,119,115,32,97,114,101,32,112,97,99,107,101,100,32,110,101,120,116,32,116,111,32,101,97,99,104,32,111,116,104,101,114,0,0,0,0,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,50,0,0,0,0,0,50,53,0,0,0,0,0,0,109,97,0,0,0,0,0,0,65,77,82,45,78,66,32,40,65,100,97,112,116,105,118,101,32,77,117,108,116,105,45,82,97,116,101,32,78,97,114,114,111,119,66,97,110,100,41,0,100,105,114,97,99,0,0,0,65,32,39,124,39,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,112,105,120,101,108,32,102,111,114,109,97,116,115,0,0,0,65,86,67,79,78,86,95,68,65,84,65,68,73,82,0,0,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,99,111,109,109,101,110,116,0,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,97,117,100,105,111,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,116,105,109,101,99,111,100,101,44,32,115,121,110,116,97,120,58,32,104,104,58,109,109,58,115,115,91,58,59,46,93,102,102,10,0,0,0,0,0,0,103,0,0,0,0,0,0,0,100,102,97,0,0,0,0,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,49,0,0,0,0,0,97,117,100,105,111,32,115,101,114,118,105,99,101,32,116,121,112,101,0,0,0,0,0,0,97,109,114,95,110,98,0,0,121,117,118,52,52,52,112,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,32,98,117,102,102,101,114,32,102,111,114,32,114,101,97,100,105,110,103,32,112,114,101,115,101,116,46,10,0,0,0,0,0,67,111,109,98,101,100,32,112,105,120,101,108,32,115,104,111,117,108,100,32,110,111,116,32,98,101,32,108,97,114,103,101,114,32,116,104,97,110,32,98,108,111,99,107,120,32,120,32,98,108,111,99,107,121,10,0,73,110,118,97,108,105,100,32,48,120,82,82,71,71,66,66,91,65,65,93,32,99,111,108,111,114,32,115,116,114,105,110,103,58,32,39,37,115,39,10,0,0,0,0,0,0,0,0,116,111,112,0,0,0,0,0,78,79,95,67,79,76,79,82,0,0,0,0,0,0,0,0,97,118,95,105,109,97,103,101,95,103,101,116,95,108,105,110,101,115,105,122,101,32,102,97,105,108,101,100,10,0,0,0,82,73,80,69,77,68,51,50,48,0,0,0,0,0,0,0,115,109,112,116,101,50,52,48,109,0,0,0,0,0,0,0,116,121,112,101,58,37,115,32,115,116,97,114,116,95,116,105,109,101,58,37,102,32,100,117,114,97,116,105,111,110,58,37,102,32,97,108,112,104,97,58,37,100,10,0,0,0,0,0,100,97,117,100,0,0,0,0,115,105,110,104,0,0,0,0,66,85,71,50,0,0,0,0,105,110,99,114,101,97,115,101,0,0,0,0,0,0,0,0,80,67,83,95,67,97,109,97,99,117,112,97,95,85,84,77,95,51,51,83,0,0,0,0,97,117,100,105,111,95,115,101,114,118,105,99,101,95,116,121,112,101,0,0,0,0,0,0,70,76,0,0,0,0,0,0,71,46,55,50,54,32,65,68,80,67,77,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,112,108,97,110,101,115,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,50,52,0,0,0,0,0,0,100,101,102,97,117,108,116,0,37,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,97,115,32,111,117,116,112,117,116,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,100,101,115,99,0,0,0,0,99,114,99,0,0,0,0,0,110,98,95,115,116,101,112,115,0,0,0,0,0,0,0,0,115,101,116,32,51,68,32,76,85,84,32,102,105,108,101,32,110,97,109,101,0,0,0,0,98,105,108,105,110,101,97,114,0,0,0,0,0,0,0,0,70,105,108,116,101,114,32,108,101,110,103,116,104,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,33,115,45,62,112,114,101,111,117,116,46,99,111,117,110,116,0,0,0,0,0,0,0,0,115,101,116,32,108,111,119,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,105,99,108,0,0,0,0,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,66,117,116,116,101,114,119,111,114,116,104,32,102,105,108,116,101,114,32,99,117,114,114,101,110,116,108,121,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,101,118,101,110,32,102,105,108,116,101,114,32,111,114,100,101,114,115,10,0,0,69,120,112,101,99,116,101,100,32,116,111,32,114,101,97,100,32,37,100,32,80,83,32,98,105,116,115,32,97,99,116,117,97,108,108,121,32,114,101,97,100,32,37,100,46,10,0,0,108,105,98,97,118,99,111,100,101,99,47,115,110,111,119,46,99,0,0,0,0,0,0,0,121,48,0,0,0,0,0,0,118,97,97,112,105,95,105,100,99,116,0,0,0,0,0,0,68,97,114,107,86,105,111,108,101,116,0,0,0,0,0,0,60,115,97,109,112,108,101,95,102,109,116,62,0,0,0,0,84,85,80,76,69,84,89,80,69,0,0,0,0,0,0,0,80,73,0,0,0,0,0,0,115,117,114,114,111,117,110,100,32,100,105,114,101,99,116,32,114,105,103,104,116,0,0,0,83,119,83,99,97,108,101,114,58,32,122,101,114,111,32,118,101,99,116,111,114,32,105,110,32,115,99,97,108,105,110,103,10,0,0,0,0,0,0,0,115,114,99,95,118,95,99,104,114,95,112,111,115,0,0,0,115,101,116,32,111,117,116,112,117,116,32,115,97,109,112,108,101,32,114,97,116,101,0,0,108,105,98,97,118,99,111,100,101,99,47,109,111,116,105,111,110,95,101,115,116,46,99,0,91,37,49,53,91,48,45,57,65,45,90,97,45,122,43,32,93,93,37,99,0,0,0,0,115,101,116,32,104,111,114,105,122,111,110,116,97,108,32,111,102,102,115,101,116,0,0,0,80,67,83,95,67,97,109,97,99,117,112,97,95,85,84,77,95,51,50,83,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,52,0,0,0,102,114,97,109,101,0,0,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,97,100,112,99,109,95,103,55,50,54,108,101,0,0,0,0,57,54,48,47,49,50,48,32,77,68,67,84,32,119,105,110,100,111,119,0,0,0,0,0,37,50,88,32,0,0,0,0,66,108,111,99,107,32,115,116,97,114,116,32,105,110,102,111,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,105,110,100,101,120,32,60,32,101,115,99,0,0,0,0,0,111,117,116,112,117,116,95,115,97,109,112,108,101,95,98,105,116,115,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,117,100,105,111,95,102,114,97,109,101,95,113,117,101,117,101,46,99,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,111,100,101,32,116,97,98,108,101,32,105,110,100,101,120,101,115,58,32,37,100,33,10,0,0,0,0,0,0,99,49,95,101,120,112,114,0,92,99,38,72,37,88,38,37,49,91,92,125,93,37,110,0,76,105,110,101,97,114,95,70,111,111,116,95,85,83,95,83,117,114,118,101,121,0,0,0,37,46,42,115,0,0,0,0,112,97,103,101,95,110,117,109,98,101,114,0,0,0,0,0,105,110,118,97,108,105,100,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,115,58,32,109,105,110,61,37,100,32,109,97,120,61,37,100,10,0,0,0,0,0,0,0,69,114,114,111,114,32,58,32,37,100,32,98,105,116,115,32,108,101,102,116,10,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,65,68,80,67,77,32,77,105,99,114,111,115,111,102,116,0,98,105,116,115,60,48,46,57,10,0,0,0,0,0,0,0,79,112,101,110,67,76,32,115,117,112,112,111,114,116,32,119,97,115,32,110,111,116,32,101,110,97,98,108,101,100,32,105,110,32,116,104,105,115,32,98,117,105,108,100,44,32,99,97,110,110,111,116,32,98,101,32,115,101,108,101,99,116,101,100,10,0,0,0,0,0,0,0,112,115,110,114,0,0,0,0,99,98,112,99,32,37,100,32,105,110,118,97,108,105,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,65,68,80,67,77,32,67,114,101,97,116,105,118,101,32,84,101,99,104,110,111,108,111,103,121,0,0,0,0,0,0,0,110,111,110,32,108,105,110,101,97,114,32,113,117,97,110,116,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,113,109,97,120,32,60,61,32,49,50,32,99,117,114,114,101,110,116,108,121,10,0,0,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,40,115,116,114,105,100,101,32,99,104,97,110,103,101,100,41,10,0,0,0,99,121,99,108,101,58,37,100,10,0,0,0,0,0,0,0,115,108,105,99,101,32,109,105,115,109,97,116,99,104,10,0,66,108,111,99,107,32,115,105,122,101,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,109,97,120,105,109,117,109,32,40,37,100,41,46,10,0,0,0,0,0,0,81,80,58,32,37,100,10,0,48,0,0,0,0,0,0,0,108,97,118,102,105,46,115,99,101,110,101,95,115,99,111,114,101,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,72,69,86,67,32,112,114,111,102,105,108,101,58,32,37,100,10,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,108,111,114,111,95,115,117,114,114,111,117,110,100,95,109,105,120,95,108,101,118,101,108,0,85,110,107,110,111,119,110,32,78,65,76,32,99,111,100,101,58,32,37,100,32,40,37,100,32,98,105,116,115,41,10,0,69,45,65,67,51,32,100,101,99,111,100,101,114,0,0,0,101,115,116,105,109,97,116,105,111,110,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,47,68,32,67,111,110,118,101,114,116,101,114,32,84,121,112,101,0,0,0,0,0,0,80,67,83,95,66,111,103,111,116,97,95,67,111,108,111,109,98,105,97,95,54,69,0,0,49,47,37,100,32,102,114,97,109,101,32,100,114,111,112,58,10,0,0,0,0,0,0,0,115,108,105,99,101,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,97,99,101,110,99,46,99,0,0,0,0,0,99,121,117,118,0,0,0,0,65,68,80,67,77,32,73,77,65,32,82,97,100,105,99,97,108,0,0,0,0,0,0,0,65,68,84,83,32,104,101,97,100,101,114,32,100,101,116,101,99,116,101,100,44,32,112,114,111,98,97,98,108,121,32,97,115,32,114,101,115,117,108,116,32,111,102,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,109,105,115,112,97,114,115,105,110,103,10,0,0,0,116,0,0,0,0,0,0,0,99,104,97,114,115,101,116,32,108,105,102,101,116,105,109,101,32,115,101,116,32,116,111,32,37,100,32,102,114,97,109,101,40,115,41,10,0,0,0,0,80,97,99,107,101,116,32,119,105,116,104,32,111,100,100,32,115,105,122,101,44,32,105,103,110,111,114,105,110,103,32,108,97,115,116,32,98,121,116,101,10,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,0,0,0,0,0,0,89,85,86,52,77,80,69,71,32,104,97,115,32,105,110,118,97,108,105,100,32,104,101,97,100,101,114,46,10,0,0,0,115,119,115,95,102,108,97,103,115,0,0,0,0,0,0,0,115,105,122,101,32,109,105,115,109,97,116,99,104,32,37,100,32,37,100,10,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,0,0,115,0,0,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,37,105,0,0,0,0,0,49,46,50,46,53,0,0,0,89,79,80,32,104,97,115,32,105,110,118,97,108,105,100,32,100,105,109,101,110,115,105,111,110,115,10,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,114,111,109,97,32,98,108,111,99,107,32,111,102,102,115,101,116,10,0,0,0,0,118,99,108,97,115,115,32,37,100,44,32,110,99,111,108,111,114,115,32,37,100,44,32,98,112,112,32,37,100,44,32,98,101,32,37,100,44,32,108,115,105,122,101,32,37,100,44,32,120,111,102,102,115,101,116,32,37,100,10,0,0,0,0,0,78,111,32,109,111,114,101,32,116,104,97,110,32,52,32,115,117,98,116,105,116,108,101,32,99,111,108,111,114,115,32,115,117,112,112,111,114,116,101,100,32,40,37,100,32,102,111,117,110,100,46,41,10,0,0,0,32,48,120,37,48,50,88,44,0,0,0,0,0,0,0,0,95,104,101,105,103,104,116,0,115,105,122,101,95,115,101,103,109,101,110,116,32,111,118,101,114,114,101,97,100,10,0,0,73,73,45,99,98,112,32,105,108,108,101,103,97,108,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,102,105,108,108,32,98,105,116,115,10,0,0,0,0,102,114,97,109,101,91,37,105,93,32,119,111,117,108,100,32,104,97,118,101,32,116,111,32,115,107,105,112,32,37,105,32,98,105,116,115,10,0,0,0,99,111,110,99,97,116,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,100,97,116,97,32,111,114,32,114,101,113,117,101,115,116,101,100,32,98,105,116,114,97,116,101,32,116,111,111,32,108,111,119,44,32,99,97,110,110,111,116,32,101,110,99,111,100,101,10,0,73,110,112,117,116,32,112,97,99,107,101,116,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,60,32,37,100,41,10,0,0,60,105,62,0,0,0,0,0,105,110,118,97,108,105,100,32,65,76,80,72,65,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,115,105,122,101,58,32,37,100,10,0,69,114,114,111,114,32,99,114,101,97,116,105,110,103,32,102,114,97,109,101,32,100,101,99,111,100,101,32,99,111,110,116,101,120,116,10,0,0,0,0,112,114,111,98,108,101,109,58,32,102,111,117,110,100,32,98,111,116,104,32,67,66,70,48,32,97,110,100,32,67,66,70,90,32,99,104,117,110,107,115,10,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,72,101,97,100,101,114,32,115,105,122,101,32,108,97,114,103,101,114,32,116,104,97,110,32,100,97,116,97,32,112,114,111,118,105,100,101,100,10,0,0,79,110,50,32,86,80,54,32,40,70,108,97,115,104,32,118,101,114,115,105,111,110,44,32,119,105,116,104,32,97,108,112,104,97,32,99,104,97,110,110,101,108,41,0,0,0,0,0,109,105,100,115,116,114,101,97,109,32,114,101,99,111,110,102,105,103,117,114,97,116,105,111,110,32,119,105,116,104,32,109,117,108,116,105,116,104,114,101,97,100,105,110,103,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,44,32,116,114,121,32,45,116,104,114,101,97,100,115,32,49,10,0,0,0,35,37,100,32,118,97,108,117,101,115,58,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,111,114,98,105,115,101,110,99,46,99,0,0,80,67,83,95,66,111,103,111,116,97,95,67,111,108,111,109,98,105,97,95,51,69,0,0,115,101,108,101,99,116,32,109,117,108,116,105,116,104,114,101,97,100,105,110,103,32,116,121,112,101,0,0,0,0,0,0,68,97,116,97,32,112,97,99,107,101,116,32,98,101,102,111,114,101,32,118,97,108,105,100,32,104,101,97,100,101,114,115,10,0,0,0,0,0,0,0,118,111,114,98,105,115,0,0,67,117,114,115,111,114,32,104,111,116,32,115,112,111,116,32,105,115,32,110,111,116,32,105,110,32,105,109,97,103,101,58,32,37,105,120,37,105,32,111,102,32,37,105,120,37,105,32,99,117,114,115,111,114,32,115,105,122,101,10,0,0,0,0,97,100,112,99,109,95,105,109,97,95,114,97,100,0,0,0,117,110,107,110,111,119,110,32,98,108,111,99,107,32,116,121,112,101,58,32,37,100,10,0,108,105,98,97,118,99,111,100,101,99,47,118,99,114,49,46,99,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,32,73,109,97,103,101,0,0,0,0,0,85,110,107,110,111,119,110,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,37,115,10,0,0,0,0,73,110,118,97,108,105,100,32,109,97,120,95,97,108,108,111,99,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,69,120,116,101,110,100,101,100,32,77,86,115,32,117,110,97,118,97,105,108,97,98,108,101,32,105,110,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,10,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,118,97,108,117,101,115,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,10,0,0,0,0,0,0,119,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,118,50,49,48,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,10,0,0,86,50,49,48,32,68,101,99,111,100,101,114,0,0,0,0,85,110,107,110,111,119,110,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,58,32,37,100,10,0,0,0,0,102,114,97,109,101,32,105,110,102,111,114,109,97,116,105,111,110,32,102,108,97,103,115,32,37,88,10,0,0,0,0,0,99,100,120,108,0,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,58,32,37,100,46,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,32,32,0,0,0,0,0,0,66,97,100,32,98,105,116,114,97,116,101,32,112,101,114,32,99,104,97,110,110,101,108,32,118,97,108,117,101,32,37,100,10,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,103,114,101,101,110,32,103,97,105,110,32,102,111,114,32,116,104,101,32,114,101,100,32,99,104,97,110,110,101,108,0,0,77,105,115,115,105,110,103,32,112,97,115,115,119,111,114,100,32,102,111,114,32,101,110,99,114,121,112,116,101,100,32,115,116,114,101,97,109,46,32,80,108,101,97,115,101,32,117,115,101,32,116,104,101,32,45,112,97,115,115,119,111,114,100,32,111,112,116,105,111,110,10,0,83,108,105,99,101,32,112,114,111,112,101,114,116,105,101,115,32,99,104,117,110,107,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,83,107,105,112,112,105,110,103,32,117,110,107,110,111,119,110,32,98,108,111,99,107,32,116,121,112,101,32,37,105,10,0,73,110,112,117,116,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,80,67,83,95,66,111,103,111,116,97,95,67,111,108,111,109,98,105,97,95,66,111,103,111,116,97,0,0,0,0,0,0,116,104,114,101,97,100,95,116,121,112,101,0,0,0,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,68,84,75,0,0,0,0,0,115,101,116,32,103,114,101,101,110,32,115,104,97,100,111,119,115,0,0,0,0,0,0,0,65,112,112,108,121,105,110,103,32,117,110,115,112,101,99,105,102,105,99,32,45,102,114,97,109,101,115,32,116,111,32,110,111,110,32,118,105,100,101,111,32,115,116,114,101,97,109,115,44,32,109,97,121,98,101,32,121,111,117,32,109,101,97,110,116,32,45,118,102,114,97,109,101,115,32,63,10,0,0,0,99,100,103,0,0,0,0,0,119,114,105,116,101,95,104,101,97,100,101,114,95,116,114,97,105,108,101,114,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,115,112,101,101,120,47,37,100,13,10,0,0,99,97,118,115,118,105,100,101,111,0,0,0,0,0,0,0,71,101,111,103,71,101,111,100,101,116,105,99,68,97,116,117,109,71,101,111,75,101,121,0,114,97,119,32,77,80,69,71,45,50,32,118,105,100,101,111,0,0,0,0,0,0,0,0,84,121,112,101,32,111,102,32,71,101,111,84,73,70,70,32,107,101,121,32,37,100,32,105,115,32,119,114,111,110,103,10,0,0,0,0,0,0,0,0,80,74,83,32,115,117,98,116,105,116,108,101,0,0,0,0,73,110,99,111,114,114,101,99,116,32,112,97,108,101,116,116,101,58,32,37,105,32,99,111,108,111,114,115,32,119,105,116,104,32,111,102,102,115,101,116,32,37,105,10,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,80,67,83,95,66,111,103,111,116,97,95,67,111,108,111,109,98,105,97,95,51,87,0,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,66,32,37,100,32,37,100,10,0,0,72,0,0,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,115,108,105,99,101,115,44,32,117,115,101,100,32,105,110,32,112,97,114,97,108,108,101,108,105,122,101,100,32,101,110,99,111,100,105,110,103,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,109,98,101,100,100,101,100,32,109,101,115,115,97,103,101,58,10,37,115,10,0,0,0,105,110,118,97,108,105,100,32,99,111,100,101,114,95,116,121,112,101,10,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,108,111,114,109,97,112,32,116,121,112,101,0,0,0,97,100,112,99,109,95,100,116,107,0,0,0,0,0,0,0,92,78,0,0,0,0,0,0,37,100,13,10,37,48,50,100,58,37,48,50,100,58,37,48,50,100,44,37,48,51,100,32,45,45,62,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,44,37,48,51,100,13,10,0,0,0,0,0,0,0,117,56,32,100,101,109,117,120,101,114,0,0,0,0,0,0,123,92,99,125,0,0,0,0,79,110,108,121,32,109,111,110,111,32,97,110,100,32,115,116,101,114,101,111,32,115,116,114,101,97,109,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,32,98,121,32,110,111,119,10,0,0,0,0,0,0,80,114,101,115,101,116,32,37,115,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,115,116,114,101,97,109,32,37,100,58,37,100,44,32,98,117,116,32,99,111,117,108,100,32,110,111,116,32,98,101,32,111,112,101,110,101,100,46,10,0,115,45,62,108,97,115,116,95,112,105,99,116,117,114,101,91,48,93,45,62,100,97,116,97,91,48,93,0,0,0,0,0,69,114,114,111,114,32,115,45,62,118,101,114,115,105,111,110,32,105,115,32,37,100,10,0,116,104,114,101,97,100,115,0,101,110,99,111,117,110,116,101,114,101,100,32,114,101,112,101,97,116,32,98,108,111,99,107,32,111,112,99,111,100,101,32,40,37,48,50,88,41,32,98,117,116,32,110,111,32,98,108,111,99,107,115,32,114,101,110,100,101,114,101,100,32,121,101,116,10,0,0,0,0,0,0,112,105,99,116,117,114,101,95,98,108,97,99,107,95,114,97,116,105,111,95,116,104,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,98,105,103,10,0,0,0,0,0,0,109,105,99,114,111,115,101,99,111,110,100,115,32,102,111,114,32,101,97,99,104,32,99,104,117,110,107,0,0,0,0,0,54,107,53,0,0,0,0,0,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,98,108,111,99,107,32,115,105,122,101,58,32,37,100,10,0,0,119,114,111,110,103,32,100,105,109,101,110,115,105,111,110,32,110,117,109,98,101,114,10,0,117,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,99,104,117,110,107,32,37,120,10,0,0,0,73,68,61,83,111,117,114,99,101,0,0,0,0,0,0,0,83,108,105,99,101,32,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,100,113,117,97,110,116,32,110,101,101,100,101,100,10,0,0,115,45,62,117,109,118,112,108,117,115,32,61,61,32,48,0,110,58,37,108,108,100,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,108,105,99,101,32,99,111,117,110,116,58,32,37,100,46,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,111,112,99,111,100,101,32,37,100,32,105,110,32,114,112,122,97,32,99,104,117,110,107,46,32,83,107,105,112,32,114,101,109,97,105,110,105,110,103,32,37,100,32,98,121,116,101,115,32,111,102,32,99,104,117,110,107,32,100,97,116,97,46,10,0,0,0,0,0,0,0,0,82,111,81,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,69,79,70,32,98,101,102,111,114,101,32,118,105,100,101,111,32,102,114,97,109,101,115,10,0,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,117,102,102,101,114,32,115,105,122,101,44,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,32,60,32,101,120,112,101,99,116,101,100,32,102,114,97,109,101,95,115,105,122,101,32,37,100,10,0,0,0,116,101,120,0,0,0,0,0,115,104,111,114,116,32,112,97,99,107,101,116,115,32,97,114,101,32,115,104,111,114,116,33,10,0,0,0,0,0,0,0,70,105,101,108,100,32,100,111,109,105,110,97,110,99,101,32,37,100,32,115,117,112,112,111,114,116,0,0,0,0,0,0,97,118,114,112,0,0,0,0,65,118,105,100,32,49,58,49,32,49,48,45,98,105,116,32,82,71,66,32,80,97,99,107,101,114,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,111,118,101,114,114,101,97,100,32,105,110,32,113,100,109,50,95,102,102,116,95,100,101,99,111,100,101,95,116,111,110,101,115,40,41,10,0,0,0,0,115,101,116,32,115,97,109,112,108,101,32,40,112,105,120,101,108,41,32,97,115,112,101,99,116,32,114,97,116,105,111,0,67,111,100,101,98,111,111,107,32,103,97,105,110,32,115,97,110,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,46,0,0,0,0,0,0,116,111,111,32,102,101,119,32,98,105,116,115,32,112,101,114,32,77,66,44,32,112,108,101,97,115,101,32,115,101,116,32,97,116,32,108,101,97,115,116,32,49,50,56,10,0,0,0,85,115,101,32,76,65,84,77,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,102,111,114,32,65,65,67,0,0,112,105,99,116,117,114,101,32,104,101,97,100,101,114,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,112,105,99,116,117,114,101,10,0,80,67,83,95,66,111,103,111,116,97,95,85,84,77,95,122,111,110,101,95,49,56,78,0,112,112,109,0,0,0,0,0,115,108,105,99,101,115,0,0,80,80,77,32,40,80,111,114,116,97,98,108,101,32,80,105,120,101,108,77,97,112,41,32,105,109,97,103,101,0,0,0,100,101,102,97,117,108,116,0,108,105,98,97,118,99,111,100,101,99,47,112,110,103,101,110,99,46,99,0,0,0,0,0,78,111,32,98,121,116,101,115,32,108,101,102,116,10,0,0,65,68,80,67,77,32,73,77,65,32,68,105,97,108,111,103,105,99,32,79,75,73,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,115,117,102,102,105,99,105,101,110,116,32,82,76,69,32,100,97,116,97,32,102,111,114,32,115,117,98,116,105,116,108,101,10,0,0,0,0,0,105,110,118,97,108,105,100,32,80,67,88,32,102,105,108,101,10,0,0,0,0,0,0,0,99,97,102,0,0,0,0,0,73,110,118,97,108,105,100,32,108,105,110,101,32,102,111,117,110,100,32,105,110,32,116,104,101,32,112,114,101,115,101,116,32,102,105,108,101,46,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,82,71,66,0,0,0,0,0,117,110,107,110,111,119,110,47,105,110,118,97,108,105,100,32,99,111,100,101,0,0,0,0,101,110,100,105,0,0,0,0,82,117,110,32,97,32,115,101,99,111,110,100,32,112,97,115,115,32,116,111,32,112,117,116,32,116,104,101,32,105,110,100,101,120,32,40,109,111,111,118,32,97,116,111,109,41,32,97,116,32,116,104,101,32,98,101,103,105,110,110,105,110,103,32,111,102,32,116,104,101,32,102,105,108,101,0,0,0,0,0,117,110,100,0,0,0,0,0,115,97,109,112,108,101,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,109,105,109,101,116,121,112,101,0,0,0,0,0,0,0,0,68,95,87,69,66,86,84,84,47,67,65,80,84,73,79,78,83,0,0,0,0,0,0,0,102,111,114,109,97,116,95,110,97,109,101,0,0,0,0,0,84,111,111,32,115,109,97,108,108,32,78,85,86,32,118,105,100,101,111,32,102,114,97,109,101,10,0,0,0,0,0,0,73,110,116,101,114,108,97,99,101,100,32,109,111,100,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,77,120,80,69,71,10,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,111,117,116,112,117,116,115,0,0,0,80,67,83,95,66,111,103,111,116,97,95,85,84,77,95,122,111,110,101,95,49,55,78,0,98,105,116,109,97,112,32,102,101,97,116,117,114,101,0,0,115,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,111,102,102,115,101,116,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,32,37,100,10,0,0,73,110,118,97,108,105,100,32,113,117,97,108,105,116,121,32,115,101,116,116,105,110,103,32,37,100,10,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,111,107,105,0,0,0,102,114,97,109,101,45,62,108,105,110,101,115,105,122,101,91,48,93,32,61,61,32,99,116,120,45,62,108,97,115,116,95,112,105,99,45,62,108,105,110,101,115,105,122,101,91,48,93,0,0,0,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,112,105,120,101,108,32,102,111,114,109,97,116,115,0,0,0,0,72,101,97,100,101,114,32,118,101,114,115,105,111,110,32,100,111,101,115,110,39,116,32,109,97,116,99,104,32,99,111,100,101,99,32,116,97,103,10,0,77,83,32,82,76,69,58,32,98,121,116,101,115,116,114,101,97,109,32,111,118,101,114,114,117,110,44,32,37,100,32,114,111,119,115,32,108,101,102,116,10,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,10,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,32,115,116,114,101,97,109,46,10,0,0,0,0,0,0,0,0,123,92,117,49,125,0,0,0,76,121,114,105,99,105,115,116,47,116,101,120,116,32,119,114,105,116,101,114,0,0,0,0,83,116,114,105,99,116,108,121,32,101,110,102,111,114,99,101,32,103,111,112,32,115,105,122,101,0,0,0,0,0,0,0,33,100,115,116,45,62,102,46,98,117,102,91,48,93,0,0,69,120,112,114,101,115,115,105,111,110,32,100,101,116,101,114,109,105,110,105,110,103,32,116,104,101,32,102,114,97,109,101,32,116,105,109,101,115,116,97,109,112,0,0,0,0,0,0,42,112,97,100,100,105,110,103,32,62,61,32,48,0,0,0,42,112,97,100,100,105,110,103,32,62,61,32,48,0,0,0,109,112,51,102,108,111,97,116,0,0,0,0,0,0,0,0,109,112,51,0,0,0,0,0,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,77,80,69,71,45,52,10,0,0,0,0,0,0,0,0,99,97,102,0,0,0,0,0,78,111,32,111,117,116,112,117,116,32,112,97,100,32,99,97,110,32,98,101,32,97,115,115,111,99,105,97,116,101,100,32,116,111,32,108,105,110,107,32,108,97,98,101,108,32,39,37,115,39,46,10,0,0,0,0,69,114,114,111,114,44,32,118,105,100,101,111,32,112,97,99,107,101,116,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,40,102,95,99,111,100,101,61,48,41,10,0,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,70,105,108,101,32,39,37,115,39,32,97,108,114,101,97,100,121,32,101,120,105,115,116,115,46,32,69,120,105,116,105,110,103,46,10,0,0,0,0,0,80,67,83,95,66,101,114,110,95,49,56,57,56,95,83,119,105,115,115,95,79,108,100,0,108,111,103,95,108,101,118,101,108,95,111,102,102,115,101,116,0,0,0,0,0,0,0,0,52,58,50,58,50,0,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,65,70,67,0,0,0,0,0,77,117,108,116,105,99,104,97,110,110,101,108,32,77,80,67,32,83,86,56,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,102,114,97,109,101,58,32,117,115,101,100,32,37,105,32,111,102,32,37,105,32,98,105,116,115,10,0,0,0,0,0,0,0,115,45,62,101,110,100,32,62,61,32,115,45,62,112,116,114,0,0,0,0,0,0,0,0,101,120,116,114,97,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,71,108,111,98,97,108,32,111,112,116,105,111,110,115,32,40,97,102,102,101,99,116,32,119,104,111,108,101,32,112,114,111,103,114,97,109,32,105,110,115,116,101,97,100,32,111,102,32,106,117,115,116,32,111,110,101,32,102,105,108,101,58,0,0,84,104,101,114,101,32,109,117,115,116,32,98,101,32,110,111,32,101,120,116,114,97,119,111,114,100,32,102,111,114,32,77,76,80,46,10,0,0,0,0,109,106,112,101,103,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,10,0,0,0,0,105,110,100,101,120,61,37,100,10,0,0,0,0,0,0,0,115,101,99,111,110,100,32,102,105,101,108,100,32,111,102,102,115,58,32,48,120,37,120,10,0,0,0,0,0,0,0,0,100,101,99,111,100,105,110,103,32,109,117,115,116,32,115,116,97,114,116,32,119,105,116,104,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,0,13,10,0,0,0,0,0,0,116,105,116,108,101,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,104,105,115,32,118,101,114,115,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,37,100,32,107,72,122,32,45,32,37,100,32,107,98,105,116,47,115,47,99,104,32,109,111,100,101,46,10,0,0,0,0,0,0,98,117,102,102,101,114,32,115,105,122,101,32,37,100,32,105,115,32,111,100,100,10,0,0,105,115,116,0,0,0,0,0,73,110,112,117,116,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,46,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,116,104,114,101,97,100,49], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1995400);
/* memory initializer */ allocate([32,100,101,99,111,100,101,100,32,115,105,122,101,32,100,105,102,102,101,114,115,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,0,0,0,0,115,101,116,32,101,120,112,114,101,115,115,105,111,110,32,100,101,116,101,114,109,105,110,105,110,103,32,116,104,101,32,111,117,116,112,117,116,32,116,105,109,101,98,97,115,101,0,0,79,117,116,112,117,116,32,109,111,114,101,32,98,121,116,101,115,32,116,104,97,110,32,108,101,110,103,116,104,32,40,37,100,32,111,102,32,37,100,41,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,77,86,10,0,0,0,0,0,99,57,51,0,0,0,0,0,83,97,109,112,108,101,32,105,110,116,101,114,108,101,97,118,101,100,32,105,109,97,103,101,115,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,74,67,0,0,0,0,0,0,115,101,116,32,103,97,105,110,0,0,0,0,0,0,0,0,97,102,116,101,114,32,116,105,101,114,49,10,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,98,97,110,100,58,32,37,100,44,32,112,108,97,110,101,58,32,37,100,10,0,0,0,0,0,0,0,80,67,83,95,66,101,108,103,101,95,76,97,109,98,101,114,116,95,53,48,0,0,0,0,99,104,114,111,109,97,95,115,97,109,112,108,101,95,108,111,99,97,116,105,111,110,0,0,32,43,0,0,0,0,0,0,109,111,116,105,111,110,32,111,102,102,115,101,116,32,97,98,111,118,101,32,108,105,109,105,116,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,87,114,111,110,103,32,73,110,116,101,108,32,72,50,54,51,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,0,97,100,112,99,109,95,97,102,99,0,0,0,0,0,0,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,37,100,32,37,100,32,111,117,116,115,105,100,101,32,114,101,102,101,114,101,110,99,101,10,0,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,37,100,32,37,100,32,111,117,116,115,105,100,101,32,114,101,102,101,114,101,110,99,101,10,0,0,99,0,0,0,0,0,0,0,83,107,105,112,67,101,108,108,32,112,114,111,99,101,100,117,114,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,33,10,0,0,0,0,0,0,0,0,78,111,116,32,111,118,101,114,119,114,105,116,105,110,103,32,45,32,101,120,105,116,105,110,103,10,0,0,0,0,0,0,102,114,97,109,101,32,116,111,111,32,115,109,97,108,108,33,10,0,0,0,0,0,0,0,100,101,99,111,100,101,95,98,121,116,101,114,117,110,32,101,110,100,101,100,32,98,101,102,111,114,101,32,112,108,97,110,101,32,115,105,122,101,10,0,70,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,0,112,114,101,100,105,99,116,105,111,110,32,116,121,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,97,100,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,84,79,80,32,70,105,101,108,100,10,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,102,114,97,109,101,44,32,68,80,66,32,102,117,108,108,46,10,0,0,0,0,0,0,118,112,115,95,114,101,115,101,114,118,101,100,95,102,102,102,102,95,49,54,98,105,116,115,32,105,115,32,110,111,116,32,48,120,102,102,102,102,10,0,77,97,110,100,101,108,98,114,111,116,32,99,97,99,104,101,32,105,115,32,116,111,111,32,115,109,97,108,108,33,10,0,59,32,0,0,0,0,0,0,99,111,108,95,105,110,116,101,114,108,101,97,118,101,100,95,114,108,0,0,0,0,0,0,108,111,110,103,95,116,101,114,109,95,112,105,99,95,105,100,120,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,108,111,103,50,95,109,97,120,95,102,114,97,109,101,95,110,117,109,95,109,105,110,117,115,52,32,111,117,116,32,111,102,32,114,97,110,103,101,32,40,48,45,49,50,41,58,32,37,100,10,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,112,97,114,115,105,110,103,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,66,32,115,117,98,95,109,98,95,116,121,112,101,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,32,97,116,32,37,100,32,37,100,10,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,100,101,99,114,101,97,115,101,0,0,0,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,50,51,78,0,0,0,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,99,111,108,111,114,95,114,97,110,103,101,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,49,100,101,99,46,99,0,0,0,0,77,105,115,115,105,110,103,32,71,83,77,32,109,97,103,105,99,33,10,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,67,82,89,79,32,65,80,67,0,0,0,0,0,0,105,109,97,103,101,32,105,115,32,111,117,116,115,105,100,101,32,116,104,101,32,115,99,114,101,101,110,32,100,105,109,101,110,115,105,111,110,115,46,10,0,0,0,0,0,0,0,0,98,114,115,116,109,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,97,99,107,101,116,32,115,105,122,101,32,37,100,32,105,115,32,117,110,107,110,111,119,110,46,10,0,0,0,0,0,68,101,99,111,100,105,110,103,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,99,104,97,110,110,101,108,0,0,115,101,108,101,99,116,32,112,101,114,109,105,115,115,105,111,110,115,32,109,111,100,101,0,66,105,116,114,97,116,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,117,115,101,32,54,46,51,107,10,0,0,0,0,0,0,0,0,70,105,108,101,32,39,37,115,39,32,97,108,114,101,97,100,121,32,101,120,105,115,116,115,46,32,79,118,101,114,119,114,105,116,101,32,63,32,91,121,47,78,93,32,0,0,0,0,114,101,112,101,97,116,32,111,118,101,114,108,97,121,32,111,102,32,116,104,101,32,108,97,115,116,32,111,118,101,114,108,97,121,32,102,114,97,109,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,117,110,107,32,115,105,122,101,32,37,100,32,116,121,112,101,32,37,48,50,88,10,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,44,32,110,101,101,100,32,37,105,44,32,104,97,118,101,32,37,105,10,0,0,70,114,97,112,115,58,32,101,114,114,111,114,32,105,110,32,100,97,116,97,32,115,116,114,101,97,109,10,0,0,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,95,112,116,114,32,61,32,37,100,32,62,32,112,105,120,101,108,95,108,105,109,105,116,32,61,32,37,100,10,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,105,102,114,97,109,101,0,0,102,105,108,101,0,0,0,0,37,100,32,99,104,97,110,110,101,108,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,109,97,120,32,37,100,41,10,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,10,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,105,110,112,117,116,115,0,0,0,0,115,97,109,112,108,101,47,102,114,97,109,101,32,110,117,109,98,101,114,32,109,105,115,109,97,116,99,104,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,0,0,0,0,0,0,0,114,101,115,101,114,118,101,100,32,98,108,111,99,107,115,105,122,101,32,99,111,100,101,58,32,48,10,0,0,0,0,0,90,101,114,111,32,115,108,105,99,101,115,32,102,111,117,110,100,46,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,82,67,32,109,105,115,109,97,116,99,104,32,37,88,33,0,0,0,0,0,0,0,0,84,105,108,101,32,115,117,112,112,111,114,116,0,0,0,0,67,108,97,105,109,101,100,32,98,105,116,114,97,116,101,32,97,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,109,105,115,109,97,116,99,104,46,10,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,46,10,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,105,110,116,101,114,32,102,114,97,109,101,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,115,101,116,32,119,104,101,116,104,101,114,32,111,114,32,110,111,116,32,99,104,114,111,109,97,32,105,115,32,105,110,99,108,117,100,101,100,32,100,117,114,105,110,103,32,116,104,101,32,109,97,116,99,104,32,99,111,109,112,97,114,105,115,111,110,115,0,0,0,0,0,0,112,101,114,95,102,114,97,109,101,95,109,101,116,97,100,97,116,97,0,0,0,0,0,0,118,97,97,112,105,95,109,111,99,111,0,0,0,0,0,0,37,100,32,115,108,105,99,101,115,32,102,111,114,32,37,100,120,37,100,0,0,0,0,0,98,111,97,0,0,0,0,0,68,97,114,107,84,117,114,113,117,111,105,115,101,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,68,86,67,80,82,79,32,72,68,32,101,110,99,111,100,105,110,103,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,60,112,105,120,95,102,109,116,62,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,32,48,120,37,48,54,120,0,69,0,0,0,0,0,0,0,52,45,98,105,116,32,112,105,120,101,108,32,115,116,114,105,110,103,32,105,110,32,37,100,45,98,105,116,32,114,101,103,105,111,110,33,10,0,0,0,83,68,82,0,0,0,0,0,83,119,83,99,97,108,101,114,58,32,114,101,100,117,99,105,110,103,32,47,32,97,108,105,103,110,105,110,103,32,102,105,108,116,101,114,115,105,122,101,32,37,100,32,45,62,32,37,100,10,0,0,0,0,0,0,115,99,97,108,101,114,32,112,97,114,97,109,32,49,0,0,105,110,95,115,97,109,112,108,101,95,114,97,116,101,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,98,105,116,109,97,112,32,98,117,102,102,101,114,115,46,10,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,83,97,109,112,108,101,32,102,111,114,109,97,116,32,119,97,115,32,110,111,116,32,115,101,116,32,111,114,32,119,97,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,100,97,116,97,32,115,116,97,114,116,32,111,102,102,115,101,116,10,0,0,0,0,0,0,68,80,67,77,32,83,111,108,0,0,0,0,0,0,0,0,84,101,120,116,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,50,50,78,0,0,0,99,105,100,32,37,100,10,0,105,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,115,105,122,101,10,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,50,46,54,45,98,105,116,0,99,111,108,111,114,115,112,97,99,101,0,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,0,0,0,0,83,99,104,114,111,101,100,105,110,103,101,114,32,37,100,46,37,100,46,37,100,0,0,0,68,105,109,101,110,115,105,111,110,115,32,109,117,115,116,32,98,101,32,97,32,105,110,116,101,103,101,114,32,109,117,108,116,105,112,108,121,32,111,102,32,116,104,101,32,99,104,114,111,109,97,32,115,117,98,115,97,109,112,108,105,110,103,10,0,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,97,112,99,0,0,0,84,83,87,49,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,100,99,97,101,110,99,46,99,0,0,0,0,0,115,101,116,32,114,101,100,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,0,0,0,0,0,0,32,86,111,114,98,105,115,32,105,100,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,110,111,32,118,111,114,98,105,115,32,115,105,103,110,97,116,117,114,101,41,46,32,10,0,0,0,0,0,0,0,68,111,119,110,109,105,120,105,110,103,32,37,100,32,99,104,97,110,110,101,108,115,0,0,77,105,120,101,100,32,102,114,97,109,101,47,102,105,101,108,100,32,100,105,114,101,99,116,32,109,111,100,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,69,114,114,111,114,44,32,98,111,116,104,32,45,121,32,97,110,100,32,45,110,32,115,117,112,112,108,105,101,100,46,32,69,120,105,116,105,110,103,46,10,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,10,0,0,0,0,68,101,99,105,109,97,116,105,111,110,32,117,110,115,117,112,112,111,114,116,101,100,33,10,0,0,0,0,0,0,0,0,115,117,98,112,97,99,107,101,116,91,37,105,93,32,115,105,122,101,32,37,105,32,106,115,32,37,105,32,37,105,32,98,108,111,99,107,95,97,108,105,103,110,32,37,105,10,0,0,33,112,105,99,116,117,114,101,45,62,101,120,116,101,110,100,101,100,95,100,97,116,97,32,124,124,32,112,105,99,116,117,114,101,45,62,101,120,116,101,110,100,101,100,95,100,97,116,97,32,61,61,32,112,105,99,116,117,114,101,45,62,100,97,116,97,0,0,0,0,0,0,98,109,118,0,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,48,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,76,105,110,101,97,114,95,70,111,111,116,0,0,0,0,0,112,97,103,101,95,110,97,109,101,0,0,0,0,0,0,0,113,112,60,61,48,46,48,10,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,100,111,32,110,111,116,32,100,114,97,119,32,101,100,103,101,115,0,0,0,0,0,0,0,10,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,58,32,37,100,32,120,32,37,100,32,40,37,100,41,10,0,0,0,0,0,0,98,32,102,114,97,109,101,115,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,119,105,116,104,32,108,111,119,32,100,101,108,97,121,10,0,97,108,108,111,99,95,102,114,97,109,101,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,40,104,119,97,99,99,101,108,32,112,114,105,118,97,116,101,32,100,97,116,97,32,97,108,108,111,99,97,116,105,111,110,41,10,0,0,109,98,32,105,110,99,114,32,100,97,109,97,103,101,100,10,0,0,0,0,0,0,0,0,83,97,109,112,108,105,110,103,32,114,97,116,101,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,109,97,120,105,109,117,109,32,40,37,100,41,46,10,0,0,0,70,111,117,110,100,32,69,79,73,32,98,101,102,111,114,101,32,97,110,121,32,83,79,70,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,77,97,105,110,32,83,116,105,108,108,32,80,105,99,116,117,114,101,32,112,114,111,102,105,108,101,32,98,105,116,115,116,114,101,97,109,10,0,0,0,37,102,0,0,0,0,0,0,115,116,114,105,99,108,121,32,97,112,112,108,121,32,100,101,102,97,117,108,116,32,100,105,115,112,108,97,121,32,119,105,110,100,111,119,32,115,105,122,101,0,0,0,0,0,0,0,77,80,69,71,45,49,47,50,32,118,105,100,101,111,32,88,118,77,67,32,40,88,45,86,105,100,101,111,32,77,111,116,105,111,110,32,67,111,109,112,101,110,115,97,116,105,111,110,41,0,0,0,0,0,0,0,110,101,120,116,95,97,118,99,32,45,32,98,117,102,95,105,110,100,101,120,32,43,32,99,111,110,115,117,109,101,100,32,61,61,32,110,97,108,115,105,122,101,0,0,0,0,0,0,70,114,97,109,101,32,99,111,100,105,110,103,32,116,121,112,101,58,32,37,100,10,0,0,73,110,118,97,108,105,100,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,99,105,110,101,112,97,107,101,110,99,46,99,0,112,114,101,100,109,0,0,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,100,114,97,119,105,110,103,32,116,105,108,101,10,0,0,0,0,0,0,97,100,95,99,111,110,118,95,116,121,112,101,0,0,0,0,119,101,105,103,104,116,101,100,32,112,114,101,100,105,99,116,105,111,110,32,110,111,116,32,121,101,116,32,115,117,112,112,111,114,116,101,100,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,111,114,109,97,116,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,100,105,115,97,98,108,101,32,100,101,99,111,100,105,110,103,32,111,102,32,116,104,101,32,88,67,104,32,101,120,116,101,110,115,105,111,110,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,50,49,78,0,0,0,65,117,100,105,111,32,100,97,116,97,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,99,111,108,111,114,95,116,114,99,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,32,37,100,10,0,72,117,102,102,89,85,86,0,115,121,109,98,111,108,115,95,115,105,122,101,32,60,61,32,50,32,124,124,32,33,115,121,109,98,111,108,115,0,0,0,71,46,55,50,50,32,65,68,80,67,77,0,0,0,0,0,105,67,69,68,114,97,119,32,116,101,120,116,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,10,0,0,0,0,0,0,113,117,97,110,116,95,105,110,100,101,120,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,101,110,97,98,108,101,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,84,101,99,104,110,111,45,73,110,100,117,115,116,114,105,97,108,0,0,0,0,0,0,0,49,58,49,40,0,0,0,0,52,52,52,80,49,54,0,0,110,32,61,61,32,115,105,110,107,95,108,105,110,107,115,95,99,111,117,110,116,0,0,0,83,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,37,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,32,97,110,121,32,115,116,114,101,97,109,115,46,10,0,0,0,0,0,0,0,70,114,97,109,101,32,100,97,116,97,32,100,111,101,115,110,39,116,32,109,97,116,99,104,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,33,10,0,0,0,0,0,0,0,0,83,111,117,110,100,32,85,110,105,116,32,105,100,32,33,61,32,48,120,50,56,46,10,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,77,68,67,84,10,0,0,0,0,0,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,78,111,32,101,120,116,114,97,100,97,116,97,32,112,114,111,118,105,100,101,100,10,0,0,68,105,97,108,111,103,117,101,58,32,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,85,110,107,110,111,119,110,32,101,115,99,97,112,101,32,99,111,100,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,73,68,32,109,111,100,101,0,0,0,0,0,0,0,0,84,104,101,32,102,105,108,101,32,105,115,32,99,111,114,114,117,112,116,101,100,44,32,112,105,116,99,104,95,108,97,103,32,61,32,48,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,32,108,101,110,103,116,104,32,37,100,32,105,110,32,99,104,97,110,110,101,108,32,100,97,116,97,33,10,0,0,0,0,0,0,0,98,105,116,0,0,0,0,0,83,111,117,114,99,101,70,105,108,101,110,97,109,101,0,0,108,101,102,116,95,114,105,103,104,116,0,0,0,0,0,0,100,97,116,101,0,0,0,0,70,117,110,107,0,0,0,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,109,105,109,101,116,121,112,101,58,32,37,115,46,10,0,97,114,116,105,115,116,0,0,71,111,116,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,112,105,99,116,117,114,101,32,105,110,32,115,116,114,101,97,109,32,37,100,44,32,105,103,110,111,114,105,110,103,46,10,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,50,48,78,0,0,0,99,105,114,99,117,108,97,114,32,102,105,108,116,101,114,32,99,104,97,105,110,32,100,101,116,101,99,116,101,100,10,0,99,111,108,111,114,95,112,114,105,109,97,114,105,101,115,0,77,80,69,71,45,52,32,65,79,84,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,68,84,83,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,117,100,105,111,32,104,101,97,100,101,114,32,105,110,118,97,108,105,100,10,0,0,0,97,100,112,99,109,95,103,55,50,50,0,0,0,0,0,0,52,50,48,106,112,101,103,0,73,110,118,97,108,105,100,32,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,58,32,37,100,10,0,0,0,0,0,0,85,110,99,111,109,109,111,110,32,118,101,114,115,105,111,110,32,37,100,0,0,0,0,0,102,102,109,112,101,103,95,111,112,116,46,99,0,0,0,0,34,37,115,34,10,0,0,0,102,114,111,109,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,57,78,0,0,0,116,105,99,107,115,95,112,101,114,95,102,114,97,109,101,0,65,68,80,67,77,32,73,77,65,32,70,117,110,99,111,109,32,73,83,83,0,0,0,0,114,101,109,111,118,101,32,97,108,108,32,102,114,97,103,109,101,110,116,115,32,119,104,101,110,32,102,105,110,105,115,104,101,100,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,119,114,105,116,101,32,104,101,97,100,101,114,47,116,114,97,105,108,101,114,32,116,111,32,101,97,99,104,32,115,101,103,109,101,110,116,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,105,76,66,67,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,109,111,100,101,61,37,100,13,10,0,0,0,0,0,0,0,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,56,78,0,0,0,114,99,95,109,105,110,95,118,98,118,95,117,115,101,0,0,97,100,112,99,109,95,105,109,97,95,105,115,115,0,0,0,97,108,97,119,32,100,101,109,117,120,101,114,0,0,0,0,112,114,111,103,114,97,109,0,99,104,117,110,107,95,100,117,114,97,116,105,111,110,0,0,78,111,116,32,97,108,108,32,115,116,114,101,97,109,32,104,101,97,100,101,114,115,32,102,111,117,110,100,46,10,0,0,79,110,101,70,105,101,108,100,32,102,114,97,109,101,32,108,97,121,111,117,116,32,105,115,110,39,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,98,105,110,0,0,0,0,0,82,101,101,109,105,116,32,80,65,84,47,80,77,84,32,98,101,102,111,114,101,32,119,114,105,116,105,110,103,32,116,104,101,32,110,101,120,116,32,112,97,99,107,101,116,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,55,78,0,0,0,114,99,95,109,97,120,95,118,98,118,95,117,115,101,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,97,120,105,115,32,67,68,82,79,77,32,88,65,0,0,0,0,99,104,97,112,116,101,114,0,102,97,115,116,115,116,97,114,116,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,111,118,101,114,32,97,114,116,46,10,0,0,0,0,0,0,0,69,114,114,111,114,32,114,101,105,110,105,116,105,97,108,105,122,105,110,103,32,102,105,108,116,101,114,115,33,10,0,0,65,116,116,97,99,104,109,101,110,116,32,115,116,114,101,97,109,32,37,100,32,104,97,115,32,110,111,32,102,105,108,101,110,97,109,101,32,116,97,103,46,10,0,0,0,0,0,0,37,115,95,37,100,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,54,78,0,0,0,114,101,113,117,101,115,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,97,100,112,99,109,95,101,97,95,109,97,120,105,115,95,120,97,0,0,0,0,0,0,0,112,105,120,95,102,109,116,115,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,37,115,32,105,110,100,101,120,32,37,100,32,119,104,105,108,101,32,112,114,111,99,101,115,115,105,110,103,32,109,101,116,97,100,97,116,97,32,109,97,112,115,46,10,0,0,0,0,67,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,98,105,110,107,0,0,0,0,98,102,105,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,53,78,0,0,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,88,65,83,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,101,116,97,100,97,116,97,32,116,121,112,101,32,37,99,46,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,100,97,116,97,32,115,105,122,101,58,32,37,100,32,62,61,32,37,100,46,10,0,0,67,97,110,110,111,116,32,102,105,110,100,32,97,32,109,97,116,99,104,105,110,103,32,115,116,114,101,97,109,32,102,111,114,32,117,110,108,97,98,101,108,101,100,32,105,110,112,117,116,32,112,97,100,32,37,100,32,111,110,32,102,105,108,116,101,114,32,37,115,10,0,0,98,101,116,104,115,111,102,116,118,105,100,0,0,0,0,0,103,97,105,110,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,52,78,0,0,0,115,101,116,32,100,101,115,105,114,101,100,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,0,0,0,0,97,100,112,99,109,95,101,97,95,120,97,115,0,0,0,0,73,110,118,97,108,105,100,32,109,101,116,97,100,97,116,97,32,115,112,101,99,105,102,105,101,114,32,37,115,46,10,0,97,118,115,0,0,0,0,0,100,101,102,97,117,108,116,0,97,118,114,0,0,0,0,0,100,105,115,97,98,108,101,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,51,78,0,0,0,114,101,113,117,101,115,116,95,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,69,65,67,83,0,0,73,110,118,97,108,105,100,32,99,104,97,112,116,101,114,32,105,110,100,101,120,32,37,100,32,105,110,32,109,101,116,97,100,97,116,97,32,115,112,101,99,105,102,105,101,114,46,10,0,0,0,0,0,0,0,0,114,101,112,101,97,116,108,97,115,116,0,0,0,0,0,0,37,100,32,37,100,32,37,100,0,0,0,0,0,0,0,0,109,99,104,114,111,109,97,0,98,103,114,53,53,53,108,101,0,0,0,0,0,0,0,0,68,97,114,107,83,108,97,116,101,71,114,97,121,0,0,0,60,118,105,100,101,111,95,114,97,116,101,62,0,0,0,0,85,110,107,110,111,119,110,32,102,117,110,99,116,105,111,110,32,105,110,32,39,37,115,39,10,0,0,0,0,0,0,0,115,117,114,114,111,117,110,100,32,100,105,114,101,99,116,32,108,101,102,116,0,0,0,0,115,119,115,58,32,102,105,108,116,101,114,83,105,122,101,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,44,32,116,114,121,32,108,101,115,115,32,101,120,116,114,101,109,101,32,115,99,97,108,105,110,103,32,111,114,32,105,110,99,114,101,97,115,101,32,77,65,88,95,70,73,76,84,69,82,95,83,73,90,69,32,97,110,100,32,114,101,99,111,109,112,105,108,101,10,0,0,0,0,112,97,114,97,109,49,0,0,115,101,116,32,105,110,112,117,116,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,69,110,100,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,50,51,0,0,0,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,51,0,0,0,71,79,80,32,116,105,109,101,99,111,100,101,32,102,114,97,109,101,32,115,116,97,114,116,32,110,117,109,98,101,114,44,32,105,110,32,110,111,110,45,100,114,111,112,45,102,114,97,109,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,77,111,100,101,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,77,111,100,101,0,0,97,100,112,99,109,95,105,109,97,95,101,97,95,101,97,99,115,0,0,0,0,0,0,0,83,66,82,43,0,0,0,0,114,101,100,0,0,0,0,0,32,69,114,114,111,114,32,103,101,110,101,114,97,116,105,110,103,32,118,108,99,32,116,97,98,108,101,115,46,32,10,0,33,118,45,62,102,105,101,108,100,95,109,111,100,101,0,0,78,111,32,39,61,39,32,99,104,97,114,97,99,116,101,114,32,105,110,32,109,101,116,97,100,97,116,97,32,115,116,114,105,110,103,32,37,115,46,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,97,112,112,108,121,105,110,103,32,112,97,114,97,109,101,116,101,114,32,99,104,97,110,103,101,115,46,10,0,0,0,0,0,0,99,48,95,101,120,112,114,0,76,105,110,101,97,114,95,77,101,116,101,114,0,0,0,0,109,111,100,101,108,0,0,0,69,114,114,111,114,32,101,118,97,108,117,97,116,105,110,103,32,114,99,95,101,113,32,34,37,115,34,10,0,0,0,0,112,99,109,95,115,50,52,98,101,0,0,0,0,0,0,0,101,109,117,95,101,100,103,101,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,100,99,32,118,108,99,10,0,108,111,119,32,100,101,108,97,121,32,102,111,114,99,105,110,103,32,105,115,32,111,110,108,121,32,97,118,97,105,108,97,98,108,101,32,102,111,114,32,109,112,101,103,50,10,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,40,37,100,32,37,112,41,10,0,0,0,0,32,97,116,32,37,100,10,0,101,110,100,32,109,105,115,109,97,116,99,104,32,108,101,102,116,61,37,100,32,37,48,88,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,47,117,110,107,110,111,119,110,32,115,97,109,112,108,105,110,103,32,114,97,116,101,10,0,0,104,117,102,102,109,97,110,32,116,97,98,108,101,32,100,101,99,111,100,101,32,101,114,114,111,114,10,0,0,0,0,0,77,97,105,110,32,49,48,32,112,114,111,102,105,108,101,32,98,105,116,115,116,114,101,97,109,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,115,116,114,105,99,116,45,100,105,115,112,108,97,121,119,105,110,0,0,0,0,0,0,0,83,80,83,32,100,101,99,111,100,105,110,103,32,102,97,105,108,117,114,101,44,32,116,114,121,105,110,103,32,97,103,97,105,110,32,119,105,116,104,32,116,104,101,32,99,111,109,112,108,101,116,101,32,78,65,76,10,0,0,0,0,0,0,0,83,101,97,114,99,104,32,109,101,116,104,111,100,32,102,111,114,32,115,101,108,101,99,116,105,110,103,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,0,0,0,0,83,101,116,32,116,104,101,32,100,101,99,111,100,105,110,103,32,108,97,121,101,114,0,0,78,111,116,32,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,0,0,0,0,100,105,115,97,98,108,101,95,120,99,104,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,50,50,0,0,0,0,0,0,0,116,105,109,101,99,111,100,101,95,102,114,97,109,101,95,115,116,97,114,116,0,0,0,0,104,117,102,102,121,117,118,0,65,68,80,67,77,32,73,77,65,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,83,69,65,68,0,0,84,105,109,101,108,105,110,101,32,40,39,101,110,97,98,108,101,39,32,111,112,116,105,111,110,41,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,102,105,108,116,101,114,32,39,37,115,39,10,0,0,0,0,0,0,68,97,114,107,119,97,118,101,0,0,0,0,0,0,0,0,52,50,50,80,49,54,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,50,49,0,0,0,0,0,0,0,109,97,120,95,112,114,101,100,105,99,116,105,111,110,95,111,114,100,101,114,0,0,0,0,97,100,112,99,109,95,105,109,97,95,101,97,95,115,101,97,100,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,105,110,100,101,120,32,37,100,32,105,110,32,99,104,97,112,116,101,114,32,109,97,112,112,105,110,103,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,108,111,103,108,101,118,101,108,32,34,37,115,34,46,32,80,111,115,115,105,98,108,101,32,108,101,118,101,108,115,32,97,114,101,32,110,117,109,98,101,114,115,32,111,114,58,10,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,84,104,105,115,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,97,32,115,105,110,103,108,101,32,87,97,118,80,97,99,107,32,115,116,114,101,97,109,46,10,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,32,37,48,51,88,10,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,116,111,0,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,50,48,0,0,0,0,0,0,0,109,105,110,95,112,114,101,100,105,99,116,105,111,110,95,111,114,100,101,114,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,50,0,0,0,0,0,0,0,0,54,48,48,120,50,52,48,0,114,101,109,111,118,101,95,97,116,95,101,120,105,116,0,0,110,97,114,0,0,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,105,110,100,101,120,32,37,100,32,119,104,105,108,101,32,112,114,111,99,101,115,115,105,110,103,32,109,101,116,97,100,97,116,97,32,109,97,112,115,10,0,0,0,0,0,32,110,111,116,101,58,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,115,101,101,110,32,40,37,99,37,99,37,99,37,99,41,10,0,0,0,105,110,100,105,118,105,100,117,97,108,95,104,101,97,100,101,114,95,116,114,97,105,108,101,114,0,0,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,71,55,50,54,45,37,100,47,37,100,13,10,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,87,69,66,86,84,84,0,0,32,32,100,111,121,116,115,99,104,58,32,37,115,10,0,0,109,112,103,44,109,112,101,103,44,109,49,118,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,57,0,0,0,0,0,0,0,99,111,109,112,114,101,115,115,105,111,110,95,108,101,118,101,108,0,0,0,0,0,0,0,97,100,112,99,109,95,101,97,95,114,50,0,0,0,0,0,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,112,114,101,108,111,97,100,0,83,111,110,121,32,87,97,118,101,54,52,0,0,0,0,0,109,105,99,114,111,115,101,99,111,110,100,115,32,98,121,32,119,104,105,99,104,32,97,117,100,105,111,32,112,97,99,107,101,116,115,32,115,104,111,117,108,100,32,98,101,32,105,110,116,101,114,108,101,97,118,101,100,32,101,97,114,108,105,101,114,0,0,0,0,0,0,0,78,111,32,109,97,105,110,32,115,116,97,114,116,99,111,100,101,32,102,111,117,110,100,46,10,0,0,0,0,0,0,0,83,101,103,109,101,110,116,101,100,70,114,97,109,101,32,108,97,121,111,117,116,32,105,115,110,39,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,114,101,115,101,110,100,95,104,101,97,100,101,114,115,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,56,0,0,0,0,0,0,0,97,100,106,117,115,116,32,115,101,110,115,105,116,105,118,105,116,121,32,111,102,32,98,95,102,114,97,109,101,95,115,116,114,97,116,101,103,121,32,49,0,0,0,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,51,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,105,109,97,103,101,50,0,0,37,100,58,37,100,58,37,100,46,37,100,37,99,37,110,0,67,114,101,97,116,101,32,97,32,108,105,118,101,32,115,109,111,111,116,104,32,115,116,114,101,97,109,105,110,103,32,102,101,101,100,32,40,102,111,114,32,112,117,115,104,105,110,103,32,116,111,32,97,32,112,117,98,108,105,115,104,105,110,103,32,112,111,105,110,116,41,0,68,73,83,67,78,85,77,66,69,82,0,0,0,0,0,0,113,117,105,99,107,116,105,109,101,95,118,101,114,115,105,111,110,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,0,73,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,102,114,97,109,101,32,99,104,97,110,103,101,100,32,102,114,111,109,32,115,105,122,101,58,37,100,120,37,100,32,102,109,116,58,37,115,32,116,111,32,115,105,122,101,58,37,100,120,37,100,32,102,109,116,58,37,115,10,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,99,111,100,101,100,32,108,101,110,103,116,104,32,105,115,32,109,111,114,101,32,116,104,97,110,32,116,119,111,32,98,121,116,101,115,10,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,55,0,0,0,0,0,0,0,98,95,115,101,110,115,105,116,105,118,105,116,121,0,0,0,97,100,112,99,109,95,101,97,95,114,51,0,0,0,0,0,67,111,100,101,99,32,65,86,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,111,117,116,112,117,116,32,102,105,108,101,32,35,37,100,32,40,37,115,41,32,104,97,115,32,110,111,116,32,98,101,101,110,32,117,115,101,100,32,102,111,114,32,97,110,121,32,115,116,114,101,97,109,46,32,84,104,101,32,109,111,115,116,32,108,105,107,101,108,121,32,114,101,97,115,111,110,32,105,115,32,101,105,116,104,101,114,32,119,114,111,110,103,32,116,121,112,101,32,40,101,46,103,46,32,97,32,118,105,100,101,111,32,111,112,116,105,111,110,32,119,105,116,104,32,110,111,32,118,105,100,101,111,32,115,116,114,101,97,109,115,41,32,111,114,32,116,104,97,116,32,105,116,32,105,115,32,97,32,112,114,105,118,97,116,101,32,111,112,116,105,111,110,32,111,102,32,115,111,109,101,32,101,110,99,111,100,101,114,32,119,104,105,99,104,32,119,97,115,32,110,111,116,32,97,99,116,117,97,108,108,121,32,117,115,101,100,32,102,111,114,32,97,110,121,32,115], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2005640);
/* memory initializer */ allocate([116,114,101,97,109,46,10,0,66,97,110,100,47,79,114,99,104,101,115,116,114,97,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,102,105,108,116,101,114,115,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,54,0,0,0,0,0,0,0,109,118,48,95,116,104,114,101,115,104,111,108,100,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,49,0,0,0,0,0,0,0,0,65,86,73,79,67,111,110,116,101,120,116,0,0,0,0,0,67,111,100,101,99,32,65,86,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,111,117,116,112,117,116,32,102,105,108,101,32,35,37,100,32,40,37,115,41,32,105,115,32,110,111,116,32,97,110,32,101,110,99,111,100,105,110,103,32,111,112,116,105,111,110,46,10,0,0,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,109,105,109,101,116,121,112,101,58,32,37,115,46,10,0,83,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,39,37,115,39,32,105,110,32,102,105,108,116,101,114,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,37,115,32,109,97,116,99,104,101,115,32,110,111,32,115,116,114,101,97,109,115,46,10,0,0,0,0,0,0,0,0,115,101,116,32,115,104,101,108,102,32,116,114,97,110,115,105,116,105,111,110,32,115,116,101,101,112,0,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,53,0,0,0,0,0,0,0,109,117,108,116,105,112,108,105,101,100,32,98,121,32,113,115,99,97,108,101,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,32,97,110,100,32,97,100,100,101,100,32,116,111,32,115,99,101,110,101,95,99,104,97,110,103,101,95,115,99,111,114,101,0,0,0,0,0,97,100,112,99,109,95,101,97,95,114,49,0,0,0,0,0,65,116,116,97,99,104,109,101,110,116,32,37,115,32,116,111,111,32,108,97,114,103,101,32,116,111,32,102,105,116,32,105,110,116,111,32,109,101,109,111,114,121,46,10,0,0,0,0,99,111,108,111,114,32,98,97,115,101,100,32,111,110,32,112,111,105,110,116,32,99,108,111,115,101,115,116,32,116,111,32,116,104,101,32,111,114,105,103,105,110,32,111,102,32,116,104,101,32,105,116,101,114,97,116,105,111,110,115,0,0,0,0,54,52,48,120,53,49,50,0,102,111,114,99,101,95,111,97,114,0,0,0,0,0,0,0,46,46,47,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,52,0,0,0,0,0,0,0,115,99,95,102,97,99,116,111,114,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,65,77,86,0,0,0,85,82,76,67,111,110,116,101,120,116,0,0,0,0,0,0,117,110,107,110,111,119,110,0,67,111,117,108,100,32,110,111,116,32,103,101,116,32,115,105,122,101,32,111,102,32,116,104,101,32,97,116,116,97,99,104,109,101,110,116,32,37,115,46,10,0,0,0,0,0,0,0,121,117,118,52,52,52,0,0,109,105,110,58,32,37,102,32,37,102,32,37,102,32,124,32,109,97,120,58,32,37,102,32,37,102,32,37,102,10,0,0,116,105,116,108,101,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,37,100,10,0,0,0,0,0,0,116,111,112,32,102,105,101,108,100,0,0,0,0,0,0,0,98,103,114,53,53,53,98,101,0,0,0,0,0,0,0,0,68,97,114,107,83,108,97,116,101,66,108,117,101,0,0,0,60,105,109,97,103,101,95,115,105,122,101,62,0,0,0,0,98,101,116,119,101,101,110,0,83,68,76,0,0,0,0,0,109,105,110,70,105,108,116,101,114,83,105,122,101,32,62,32,48,0,0,0,0,0,0,0,115,99,97,108,101,114,32,112,97,114,97,109,32,48,0,0,117,115,101,100,95,99,104,97,110,110,101,108,95,99,111,117,110,116,0,0,0,0,0,0,73,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,32,105,115,32,110,111,116,32,109,97,112,112,101,100,32,116,111,32,97,110,121,32,115,108,97,118,101,46,10,0,0,0,83,116,97,114,116,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,51,0,0,0,0,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,50,45,98,105,116,0,0,0,114,97,116,101,45,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,97,108,32,113,117,97,110,116,105,122,97,116,105,111,110,0,0,0,0,100,115,117,114,101,120,95,109,111,100,101,0,0,0,0,0,100,115,117,114,101,120,95,109,111,100,101,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,97,109,118,0,0,0,65,117,100,105,111,32,111,98,106,101,99,116,32,116,121,112,101,32,37,115,37,100,0,0,109,0,0,0,0,0,0,0,32,73,110,118,97,108,105,100,32,99,111,100,101,32,108,101,110,103,116,104,115,32,119,104,105,108,101,32,103,101,110,101,114,97,116,105,110,103,32,118,108,99,115,46,32,10,0,0,115,116,97,114,116,79,102,80,97,114,97,103,114,97,112,104,0,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,100,32,102,114,97,109,101,32,109,105,115,115,105,110,103,46,10,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,97,116,116,97,99,104,109,101,110,116,32,102,105,108,101,32,37,115,46,10,0,0,0,0,0,73,110,118,97,108,105,100,32,109,101,100,105,97,32,116,121,112,101,32,102,111,114,32,118,105,100,101,111,10,0,0,0,77,68,53,61,0,0,0,0,120,111,114,0,0,0,0,0,82,97,115,116,101,114,80,105,120,101,108,73,115,80,111,105,110,116,0,0,0,0,0,0,109,97,107,101,0,0,0,0,113,109,105,110,32,60,61,32,113,109,97,120,0,0,0,0,83,87,70,32,40,83,104,111,99,107,87,97,118,101,32,70,108,97,115,104,41,32,40,65,86,77,50,41,0,0,0,0,111,110,108,121,32,100,101,99,111,100,101,47,101,110,99,111,100,101,32,103,114,97,121,115,99,97,108,101,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,55,0,0,0,99,108,111,115,101,100,32,103,111,112,32,119,105,116,104,32,115,99,101,110,101,32,99,104,97,110,103,101,32,100,101,116,101,99,116,105,111,110,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,121,101,116,44,32,115,101,116,32,116,104,114,101,115,104,111,108,100,32,116,111,32,49,48,48,48,48,48,48,48,48,48,10,0,0,0,0,0,0,73,110,116,101,114,108,97,99,101,100,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,32,105,115,32,110,111,116,32,102,117,108,108,121,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,83,121,115,116,101,109,32,115,116,97,114,116,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,77,88,70,32,100,97,116,97,32,102,111,117,110,100,32,105,110,32,118,105,100,101,111,32,115,116,114,101,97,109,10,0,67,104,97,110,110,101,108,32,103,114,111,117,112,115,32,119,105,116,104,32,100,105,102,102,101,114,105,110,103,32,115,97,109,112,108,101,32,114,97,116,101,115,32,97,114,101,32,110,111,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,114,101,115,116,97,114,116,32,109,97,114,107,101,114,58,32,37,100,10,0,0,0,0,0,77,97,105,110,32,112,114,111,102,105,108,101,32,98,105,116,115,116,114,101,97,109,10,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,111,117,116,112,117,116,115,0,0,0,0,0,0,0,65,112,112,108,121,32,100,101,102,97,117,108,116,32,100,105,115,112,108,97,121,32,119,105,110,100,111,119,32,102,114,111,109,32,86,85,73,0,0,0,91,98,114,93,0,0,0,0,80,97,114,116,105,116,105,111,110,101,100,32,72,46,50,54,52,32,115,117,112,112,111,114,116,32,105,115,32,105,110,99,111,109,112,108,101,116,101,10,0,0,0,0,0,0,0,0,112,114,101,100,105,99,116,105,111,110,95,111,114,100,101,114,95,109,101,116,104,111,100,0,108,97,121,101,114,0,0,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,37,100,0,0,0,0,0,0,68,67,65,32,100,101,99,111,100,101,114,0,0,0,0,0,80,67,83,95,66,97,116,97,118,105,97,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,0,0,0,0,0,0,116,114,101,108,108,105,115,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,84,72,80,0,0,0,0,0,115,101,116,32,101,110,97,98,108,101,32,101,120,112,114,101,115,115,105,111,110,0,0,0,71,111,116,104,105,99,0,0,52,50,48,80,49,54,0,0,67,97,110,110,111,116,32,109,97,112,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,45,32,117,110,115,117,112,112,111,114,116,101,100,32,116,121,112,101,46,10,0,0,0,37,100,10,37,48,50,100,58,37,48,50,100,58,37,48,50,100,44,37,48,51,100,32,45,45,62,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,44,37,48,51,100,0,0,37,42,100,58,37,42,50,100,58,37,42,50,100,37,42,49,91,44,46,93,37,42,51,100,32,45,45,62,32,37,42,100,58,37,42,50,100,58,37,42,50,100,37,42,49,91,44,46,93,37,51,100,0,0,0,0,99,111,100,101,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,73,110,118,97,108,105,100,32,65,65,67,32,112,97,99,107,101,116,32,105,110,32,73,69,67,32,54,49,57,51,55,10,0,0,0,0,0,0,0,0,116,114,117,110,99,97,116,105,110,103,32,102,114,97,99,116,105,111,110,97,108,32,112,97,114,116,32,111,102,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,102,41,10,0,80,67,83,95,66,97,116,97,118,105,97,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,0,0,0,0,0,0,99,104,114,111,109,97,32,81,80,32,111,102,102,115,101,116,32,102,114,111,109,32,108,117,109,97,0,0,0,0,0,0,97,100,112,99,109,95,116,104,112,0,0,0,0,0,0,0,79,117,116,112,117,116,32,119,105,116,104,32,108,97,98,101,108,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,32,105,110,32,97,110,121,32,100,101,102,105,110,101,100,32,102,105,108,116,101,114,32,103,114,97,112,104,44,32,111,114,32,119,97,115,32,97,108,114,101,97,100,121,32,117,115,101,100,32,101,108,115,101,119,104,101,114,101,46,10,0,0,0,0,0,0,114,101,112,101,97,116,0,0,97,118,105,0,0,0,0,0,48,48,48,53,50,50,48,48,0,0,0,0,0,0,0,0,37,115,47,70,114,97,103,109,101,110,116,73,110,102,111,40,37,115,61,37,108,108,117,41,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,37,100,0,0,0,0,0,0,73,110,112,117,116,0,0,0,116,114,101,101,115,105,122,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,39,66,79,68,89,39,32,99,104,117,110,107,32,105,115,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,0,80,67,83,95,66,97,116,97,118,105,97,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,0,0,0,0,0,0,99,104,114,111,109,97,111,102,102,115,101,116,0,0,0,0,97,117,100,105,111,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,50,45,98,105,116,0,0,0,109,105,110,105,109,117,109,32,102,114,97,103,109,101,110,116,32,100,117,114,97,116,105,111,110,32,40,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,41,0,0,0,0,0,77,105,115,115,105,110,103,32,37,115,32,115,116,114,101,97,109,32,119,104,105,99,104,32,105,115,32,114,101,113,117,105,114,101,100,32,98,121,32,116,104,105,115,32,102,102,109,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,101,113,117,101,110,99,101,32,110,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,115,101,103,109,101,110,116,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,71,55,50,50,47,37,100,47,37,100,13,10,0,0,0,0,0,0,0,0,118,105,100,101,111,47,120,45,109,112,101,103,0,0,0,0,80,67,83,95,66,97,116,97,118,105,97,95,78,69,73,69,90,0,0,0,0,0,0,0,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,32,116,111,32,99,111,110,115,105,100,101,114,32,102,111,114,32,109,111,116,105,111,110,32,99,111,109,112,101,110,115,97,116,105,111,110,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,50,0,0,0,114,101,102,101,114,101,110,99,101,95,115,116,114,101,97,109,0,0,0,0,0,0,0,0,110,117,108,108,0,0,0,0,97,117,100,105,111,95,112,114,101,108,111,97,100,0,0,0,117,110,107,110,111,119,110,32,100,105,115,112,111,115,105,116,105,111,110,32,116,121,112,101,32,39,37,115,39,10,0,0,10,0,0,0,0,0,0,0,109,0,0,0,0,0,0,0,77,80,69,71,45,84,83,32,109,117,120,105,110,103,32,102,108,97,103,115,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,51,53,0,0,0,0,0,0,0,109,61,37,115,32,37,100,32,82,84,80,47,65,86,80,32,37,100,13,10,0,0,0,0,114,101,102,115,0,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,50,46,54,45,98,105,116,0,97,110,117,108,108,0,0,0,83,112,105,110,110,105,110,103,32,110,111,105,115,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,44,32,117,115,105,110,103,32,112,105,110,107,32,110,111,105,115,101,32,105,110,115,116,101,97,100,46,10,0,0,0,0,0,0,105,115,109,108,0,0,0,0,100,97,116,101,0,0,0,0,112,114,101,109,105,101,114,101,95,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,100,101,99,111,100,101,114,32,45,62,32,105,115,116,95,105,110,100,101,120,58,37,100,32,116,121,112,101,58,118,105,100,101,111,32,102,114,97,109,101,95,112,116,115,58,37,115,32,102,114,97,109,101,95,112,116,115,95,116,105,109,101,58,37,115,32,98,101,115,116,95,101,102,102,111,114,116,95,116,115,58,37,108,108,100,32,98,101,115,116,95,101,102,102,111,114,116,95,116,115,95,116,105,109,101,58,37,115,32,107,101,121,102,114,97,109,101,58,37,100,32,102,114,97,109,101,95,116,121,112,101,58,37,100,32,116,105,109,101,95,98,97,115,101,58,37,100,47,37,100,10,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,97,108,112,104,97,95,109,111,100,101,0,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,51,51,0,0,0,0,0,0,0,109,105,110,105,109,117,109,32,105,110,116,101,114,118,97,108,32,98,101,116,119,101,101,110,32,73,68,82,45,102,114,97,109,101,115,0,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,51,0,0,0,120,119,100,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,61,110,111,119,0,0,0,0,0,0,0,67,111,110,100,117,99,116,111,114,0,0,0,0,0,0,0,79,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,115,117,112,112,111,114,116,101,100,32,105,110,32,116,104,101,32,82,84,80,32,109,117,120,101,114,10,0,0,0,0,0,102,105,108,116,101,114,115,0,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,111,110,32,115,101,101,107,97,98,108,101,32,111,117,116,112,117,116,10,0,0,0,0,0,82,83,68,0,0,0,0,0,97,117,116,104,111,114,0,0,97,118,105,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,51,49,0,0,0,0,0,0,0,107,101,121,105,110,116,95,109,105,110,0,0,0,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,52,45,98,105,116,0,0,0,104,116,116,112,58,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,114,97,116,101,10,0,0,0,0,0,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,116,121,112,101,58,32,37,100,46,10,0,0,0,0,0,73,110,118,97,108,105,100,32,102,105,108,101,32,105,110,100,101,120,32,37,100,32,105,110,32,102,105,108,116,101,114,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,37,115,46,10,0,0,0,111,117,116,32,111,102,32,109,101,109,111,114,121,44,32,117,110,97,98,108,101,32,116,111,32,114,101,97,100,32,73,78,70,79,32,116,97,103,10,0,117,115,101,32,99,111,110,115,116,97,110,116,32,115,107,105,114,116,32,103,97,105,110,0,73,67,79,80,0,0,0,0,102,0,0,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,57,0,0,0,0,0,0,0,100,111,119,110,115,99,97,108,101,32,102,114,97,109,101,115,32,102,111,114,32,100,121,110,97,109,105,99,32,66,45,102,114,97,109,101,32,100,101,99,105,115,105,111,110,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,52,0,0,0,60,119,105,110,100,111,119,0,102,102,109,0,0,0,0,0,114,97,119,118,105,100,101,111,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,0,109,105,110,99,111,108,0,0,97,117,0,0,0,0,0,0,100,101,99,114,101,97,115,101,32,111,114,32,105,110,99,114,101,97,115,101,32,119,47,104,32,105,102,32,110,101,99,101,115,115,97,114,121,32,116,111,32,107,101,101,112,32,116,104,101,32,111,114,105,103,105,110,97,108,32,65,82,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,55,0,0,0,0,0,0,0,98,114,100,95,115,99,97,108,101,0,0,0,0,0,0,0,65,68,80,67,77,32,89,97,109,97,104,97,0,0,0,0,45,116,111,32,118,97,108,117,101,32,115,109,97,108,108,101,114,32,116,104,97,110,32,45,115,115,59,32,105,103,110,111,114,105,110,103,32,45,116,111,46,10,0,0,0,0,0,0,121,117,118,52,50,50,0,0,77,65,88,32,0,0,0,0,67,82,73,32,65,68,88,0,115,116,101,114,101,111,0,0,116,111,112,0,0,0,0,0,98,103,114,53,54,53,108,101,0,0,0,0,0,0,0,0,68,97,114,107,83,101,97,71,114,101,101,110,0,0,0,0,114,97,119,32,100,97,116,97,0,0,0,0,0,0,0,0,60,98,105,110,97,114,121,62,0,0,0,0,0,0,0,0,98,105,116,111,114,0,0,0,119,105,100,101,32,114,105,103,104,116,0,0,0,0,0,0,102,105,108,116,101,114,50,83,105,122,101,32,62,32,48,0,112,97,114,97,109,48,0,0,115,101,116,32,117,115,101,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,97,117,100,105,111,32,112,97,99,107,101,116,10,0,0,0,0,0,76,97,121,101,114,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,53,0,0,0,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,50,0,0,0,114,101,102,105,110,101,32,116,104,101,32,116,119,111,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,117,115,101,100,32,105,110,32,98,105,100,105,114,101,99,116,105,111,110,97,108,32,109,97,99,114,111,98,108,111,99,107,115,0,76,111,47,82,111,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,76,111,47,82,111,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,80,97,100,100,105,110,103,32,115,104,111,117,108,100,32,98,101,32,48,46,10,0,0,0,97,100,112,99,109,95,121,97,109,97,104,97,0,0,0,0,105,110,118,97,108,105,100,32,108,111,119,32,100,101,108,97,121,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,105,110,100,101,120,32,37,100,10,0,0,0,0,0,0,0,110,117,109,32,99,104,97,110,110,101,108,115,0,0,0,0,115,101,116,32,109,97,115,116,101,114,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,0,0,0,67,111,100,101,98,111,111,107,32,108,111,111,107,117,112,32,116,121,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,32,10,0,0,0,73,108,108,101,103,97,108,32,68,67,32,86,76,67,10,0,45,116,32,97,110,100,32,45,116,111,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,116,111,103,101,116,104,101,114,59,32,117,115,105,110,103,32,45,116,46,10,0,0,101,120,112,101,99,116,101,100,32,114,101,115,101,114,118,101,100,32,98,121,116,101,32,116,111,32,98,101,32,48,120,53,53,10,0,0,0,0,0,0,115,116,97,114,116,95,100,105,115,112,108,97,121,95,116,105,109,101,32,109,117,115,116,32,98,101,32,48,46,10,0,0,85,110,107,110,111,119,110,32,115,101,99,116,111,114,32,116,121,112,101,32,37,48,50,88,10,0,0,0,0,0,0,0,118,105,118,105,100,108,105,103,104,116,0,0,0,0,0,0,82,97,115,116,101,114,80,105,120,101,108,73,115,65,114,101,97,0,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,108,105,109,105,116,105,110,103,32,81,80,32,37,102,32,45,62,32,37,102,10,0,0,0,37,108,108,100,44,37,108,108,100,0,0,0,0,0,0,0,103,114,97,121,0,0,0,0,119,109,118,49,0,0,0,0,81,80,32,82,68,32,110,101,101,100,115,32,109,98,100,61,50,10,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,112,105,99,116,117,114,101,32,98,117,102,102,101,114,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,0,114,101,115,101,114,118,101,100,0,0,0,0,0,0,0,0,52,50,48,0,0,0,0,0,67,104,97,110,110,101,108,32,103,114,111,117,112,32,50,32,99,97,110,110,111,116,32,104,97,118,101,32,109,111,114,101,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,32,116,104,97,110,32,103,114,111,117,112,32,49,46,10,0,115,116,97,114,116,99,111,100,101,58,32,37,88,10,0,0,97,115,116,0,0,0,0,0,73,110,118,97,108,105,100,32,100,101,108,116,97,32,105,110,32,115,99,97,108,105,110,103,32,108,105,115,116,32,100,97,116,97,58,32,37,100,46,10,0,0,0,0,0,0,0,0,111,117,116,112,117,116,115,0,97,112,112,108,121,95,100,101,102,100,105,115,112,119,105,110,0,0,0,0,0,0,0,0,68,101,99,111,100,105,110,103,32,105,110,32,99,104,117,110,107,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,112,97,114,116,105,116,105,111,110,101,100,32,115,108,105,99,101,115,46,10,0,0,0,0,109,97,120,95,112,97,114,116,105,116,105,111,110,95,111,114,100,101,114,0,0,0,0,0,69,88,82,0,0,0,0,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,77,111,100,101,0,0,0,0,68,84,83,45,72,68,32,77,65,0,0,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,51,0,0,0,0,0,0,0,98,105,100,105,114,95,114,101,102,105,110,101,0,0,0,0,100,118,118,105,100,101,111,0,65,68,80,67,77,32,83,104,111,99,107,119,97,118,101,32,70,108,97,115,104,0,0,0,115,108,105,99,101,0,0,0,69,116,104,110,105,99,0,0,52,52,52,80,49,52,0,0,69,114,114,111,114,32,99,111,110,102,105,103,117,114,105,110,103,32,102,105,108,116,101,114,115,46,10,0,0,0,0,0,102,51,50,98,101,0,0,0,97,115,116,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,49,0,0,0,0,0,0,0,100,105,115,99,97,114,100,32,97,108,108,32,102,114,97,109,101,115,0,0,0,0,0,0,97,100,112,99,109,95,115,119,102,0,0,0,0,0,0,0,83,116,114,101,97,109,32,109,97,112,32,39,37,115,39,32,109,97,116,99,104,101,115,32,110,111,32,115,116,114,101,97,109,115,46,10,0,0,0,0,118,101,114,98,111,115,101,0,57,55,48,49,50,48,48,48,0,0,0,0,0,0,0,0,102,51,50,98,101,0,0,0,97,115,115,0,0,0,0,0,79,117,116,112,117,116,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,49,57,0,0,0,0,0,0,0,97,108,108,0,0,0,0,0,65,68,80,67,77,32,67,114,101,97,116,105,118,101,32,84,101,99,104,110,111,108,111,103,121,0,0,0,0,0,0,0,109,105,110,95,102,114,97,103,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,105,110,100,101,120,58,32,37,100,46,10,0,0,97,115,115,0,0,0,0,0,115,101,103,109,101,110,116,95,115,116,97,114,116,95,110,117,109,98,101,114,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,74,80,69,71,47,57,48,48,48,48,13,10,0,0,0,0,0,0,0,0,112,114,111,98,101,115,105,122,101,0,0,0,0,0,0,0,101,97,51,0,0,0,0,0,114,97,119,32,77,80,69,71,45,49,32,118,105,100,101,111,0,0,0,0,0,0,0,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,116,104,101,32,69,65,51,32,104,101,97,100,101,114,32,33,10,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,49,55,0,0,0,0,0,0,0,100,105,115,99,97,114,100,32,97,108,108,32,102,114,97,109,101,115,32,101,120,99,101,112,116,32,107,101,121,102,114,97,109,101,115,0,0,0,0,0,97,100,112,99,109,95,99,116,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,73,110,118,97,108,105,100,32,111,117,116,112,117,116,32,108,105,110,107,32,108,97,98,101,108,58,32,37,115,46,10,0,37,116,105,32,98,121,116,101,115,32,111,102,32,99,111,109,109,101,110,116,32,104,101,97,100,101,114,32,114,101,109,97,105,110,10,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,117,115,101,100,32,116,111,32,112,114,111,98,101,32,102,112,115,0,0,0,0,0,0,83,101,114,105,97,108,32,110,117,109,98,101,114,32,105,110,32,102,105,115,98,111,110,101,32,100,111,101,115,110,39,116,32,109,97,116,99,104,32,97,110,121,32,115,116,114,101,97,109,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,109,105,110,103,32,118,97,108,117,101,115,46,10,0,105,110,102,111,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,46,0,0,0,0,0,0,0,109,112,101,103,116,115,95,102,108,97,103,115,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,49,53,0,0,0,0,0,0,0,110,111,107,101,121,0,0,0,71,46,55,50,54,32,65,68,80,67,77,0,0,0,0,0,115,112,101,101,120,0,0,0,93,0,0,0,0,0,0,0,110,111,110,45,0,0,0,0,70,108,117,115,104,32,102,114,97,103,109,101,110,116,115,32,111,110,32,99,97,108,108,101,114,32,114,101,113,117,101,115,116,115,0,0,0,0,0,0,77,121,116,104,84,86,86,105,100,101,111,0,0,0,0,0,103,97,112,108,101,115,115,95,112,108,97,121,98,97,99,107,0,0,0,0,0,0,0,0,97,115,102,0,0,0,0,0,100,101,99,111,100,101,95,118,105,100,101,111,32,37,100,46,37,100,0,0,0,0,0,0,76,97,118,102,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,116,101,114,101,111,95,109,111,100,101,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,49,51,0,0,0,0,0,0,0,100,105,115,99,97,114,100,32,97,108,108,32,98,105,100,105,114,101,99,116,105,111,110,97,108,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,97,100,112,99,109,95,103,55,50,54,0,0,0,0,0,0,120,102,97,99,101,0,0,0,83,121,110,99,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,105,110,32,109,97,112,32,37,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,97,110,121,32,115,116,114,101,97,109,115,46,10,0,0,0,0,0,0,0,0,65,114,116,105,115,116,47,112,101,114,102,111,114,109,101,114,0,0,0,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,112,114,111,116,111,99,111,108,115,0,0,0,0,0,0,0,0,115,112,0,0,0,0,0,0,80,67,83,95,65,114,97,116,117,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,98,105,100,105,114,0,0,0,101,110,100,95,104,101,97,100,0,0,0,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,0,0,0,73,110,118,97,108,105,100,32,115,121,110,99,32,102,105,108,101,32,105,110,100,101,120,58,32,37,100,46,10,0,0,0,73,110,118,97,108,105,100,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,115,105,122,101,58,32,37,100,46,10,0,0,0,0,0,77,88,70,32,40,77,97,116,101,114,105,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,32,68,45,49,48,32,77,97,112,112,105,110,103,0,0,0,0,0,79,110,108,121,32,118,105,100,101,111,32,97,110,100,32,97,117,100,105,111,32,102,105,108,116,101,114,115,32,115,117,112,112,111,114,116,101,100,32,99,117,114,114,101,110,116,108,121,46,10,0,0,0,0,0,0,99,115,103,0,0,0,0,0,80,67,83,95,65,114,97,116,117,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,100,105,115,99,97,114,100,32,97,108,108,32,110,111,110,45,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,97,100,112,99,109,95,101,97,0,0,0,0,0,0,0,0,109,97,112,99,104,97,110,58,32,105,110,118,97,108,105,100,32,97,117,100,105,111,32,99,104,97,110,110,101,108,32,35,37,100,46,37,100,46,37,100,10,0,0,0,0,0,0,0,73,110,100,101,120,83,73,68,32,37,105,32,115,101,103,109,101,110,116,32,97,116,32,37,108,108,100,32,109,105,115,115,105,110,103,32,69,100,105,116,85,110,105,116,66,121,116,101,67,111,117,110,116,32,97,110,100,32,73,110,100,101,120,69,110,116,114,121,65,114,114,97,121,10,0,0,0,0,0,0,115,104,111,119,32,116,105,109,101,32,117,110,116,105,108,32,99,111,110,118,101,114,103,101,110,99,101,0,0,0,0,0,116,105,116,108,101,0,0,0,102,111,114,99,101,95,111,114,105,103,105,110,97,108,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,80,67,83,95,65,114,97,116,117,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,110,111,114,101,102,0,0,0,83,69,71,65,32,67,82,73,32,65,68,88,32,65,68,80,67,77,0,0,0,0,0,0,109,97,112,99,104,97,110,58,32,115,116,114,101,97,109,32,35,37,100,46,37,100,32,105,115,32,110,111,116,32,97,110,32,97,117,100,105,111,32,115,116,114,101,97,109,46,10,0,100,101,102,97,117,108,116,0,112,107,116,45,62,115,105,122,101,32,61,61,32,40,40,45,49,45,48,120,55,102,102,102,102,102,102,102,41,32,47,32,51,32,42,32,50,32,43,32,40,105,110,116,41,115,105,122,101,111,102,40,65,86,70,114,97,109,101,41,41,0,0,0,77,84,86,32,102,105,108,101,115,32,119,105,116,104,111,117,116,32,97,117,100,105,111,0,77,73,78,32,0,0,0,0,70,79,82,77,65,84,61,37,100,0,0,0,0,0,0,0,91,37,108,108,100,93,91,93,37,99,37,110,0,0,0,0,67,111,110,116,101,110,116,45,116,121,112,101,58,32,105,109,97,103,101,47,106,112,101,103,13,10,0,0,0,0,0,0,98,111,116,116,111,109,32,102,105,101,108,100,0,0,0,0,98,103,114,53,54,53,98,101,0,0,0,0,0,0,0,0,68,97,114,107,83,97,108,109,111,110,0,0,0,0,0,0,60,114,97,116,105,111,110,97,108,62,0,0,0,0,0,0,98,105,116,97,110,100,0,0,87,82,0,0,0,0,0,0,102,105,108,116,101,114,83,105,122,101,32,62,32,48,0,0,100,101,115,116,105,110,97,116,105,111,110,32,114,97,110,103,101,0,0,0,0,0,0,0,111,117,116,95,99,104,97,110,110,101,108,95,99,111,117,110,116,0,0,0,0,0,0,0,68,105,97,108,111,103,117,101,0,0,0,0,0,0,0,0,80,67,83,95,76,105,115,98,111,110,95,80,111,114,116,117,103,101,115,101,95,71,114,105,100,0,0,0,0,0,0,0,65,68,80,67,77,32,77,105,99,114,111,115,111,102,116,0,100,105,115,99,97,114,100,32,117,115,101,108,101,115,115,32,102,114,97,109,101,115,0,0,108,111,114,111,95,115,117,114,109,105,120,108,101,118,0,0,108,111,114,111,95,115,117,114,109,105,120,108,101,118,0,0,97,100,112,99,109,95,97,100,120,0,0,0,0,0,0,0,77,111,114,101,32,116,104,97,110,32,111,110,101,32,65,65,67,32,82,68,66,32,112,101,114,32,65,68,84,83,32,102,114,97,109,101,0,0,0,0,108,101,110,32,112,114,101,102,105,120,0,0,0,0,0,0,109,97,115,116,101,114,0,0,66,117,103,32,105,110,32,99,111,100,101,118,101,99,116,111,114,32,118,101,99,116,111,114,32,98,117,105,108,100,105,110,103,32,99,111,100,101,46,32,10,0,0,0,0,0,0,0,79,118,101,114,114,105,100,105,110,103,32,105,110,118,97,108,105,100,32,109,113,117,97,110,116,32,37,100,10,0,0,0,109,97,112,99,104,97,110,58,32,105,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,115,116,114,101,97,109,32,105,110,100,101,120,32,35,37,100,46,37,100,10,0,0,0,0,0,0,0,0,114,101,116,32,60,61,32,48,0,0,0,0,0,0,0,0,100,116,115,32,60,32,112,99,114,44,32,84,83,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,115,117,98,116,114,97,99,116,0,0,0,0,0,0,0,0,77,111,100,101,108,84,121,112,101,71,101,111,99,101,110,116,114,105,99,0,0,0,0,0,99,111,109,112,117,116,101,114,0,0,0,0,0,0,0,0,91,108,97,118,99,32,114,99,93,32,69,114,114,111,114,58,32,50,112,97,115,115,32,99,117,114,118,101,32,102,97,105,108,101,100,32,116,111,32,99,111,110,118,101,114,103,101,10,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,117,115,101,32,105,110,116,101,114,110,97,108,32,50,45,112,97,115,115,32,114,97,116,101,99,111,110,116,114,111,108,32,105,110,32,115,101,99,111,110,100,32,112,97,115,115,32,109,111,100,101,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,51,0,0,0,0,0,0,0,67,66,80,32,82,68,32,110,101,101,100,115,32,116,114,101,108,108,105,115,32,113,117,97,110,116,10,0,0,0,0,0,37,53,100,0,0,0,0,0,115,116,117,102,102,105,110,103,32,115,116,97,114,116,0,0,115,45,62,100,114,111,112,95,102,114,97,109,101,95,116,105,109,101,99,111,100,101,32,61,61,32,33,33,40,115,45,62,116,99,46,102,108,97,103,115,32,38,32,65,86,95,84,73,77,69,67,79,68,69,95,70,76,65,71,95,68,82,79,80,70,82,65,77,69,41,0,0,116,111,112,0,0,0,0,0,105,110,118,97,108,105,100,47,117,110,107,110,111,119,110,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,117,102,102,101,114,10,0,109,112,101,103,116,115,114,97,119,0,0,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,118,117,105,32,100,101,102,97,117,108,116,32,100,105,115,112,108,97,121,32,119,105,110,100,111,119,44,32,111,114,105,103,105,110,97,108,32,118,97,108,117,101,115,32,97,114,101,32,108,58,37,117,32,114,58,37,117,32,116,58,37,117,32,98,58,37,117,10,0,101,0,0,0,0,0,0,0,72,69,86,67,32,100,101,99,111,100,101,114,0,0,0,0,73,110,118,97,108,105,100,32,109,105,120,32,111,102,32,105,100,114,32,97,110,100,32,110,111,110,45,105,100,114,32,115,108,105,99,101,115,10,0,0,109,105,110,95,112,97,114,116,105,116,105,111,110,95,111,114,100,101,114,0,0,0,0,0,85,110,107,110,111,119,110,32,100,97,116,97,32,116,121,112,101,32,102,111,114,32,104,101,97,100,101,114,32,118,97,114,105,97,98,108,101,32,37,115,10,0,0,0,0,0,0,0,100,104,101,97,100,112,104,111,110,101,95,109,111,100,101,0,68,84,83,45,72,68,32,72,82,65,0,0,0,0,0,0,80,67,83,95,65,102,103,111,111,121,101,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,51,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,51,32,47,32,83,86,81,51,0,0,0,65,68,80,67,77,32,67,68,82,79,77,32,88,65,0,0,65,108,108,111,119,101,100,32,116,104,114,101,97,100,32,116,121,112,101,115,0,0,0,0,73,110,115,116,114,117,109,101,110,116,97,108,32,82,111,99,107,0,0,0,0,0,0,0,52,50,50,80,49,52,0,0,109,97,112,99,104,97,110,58,32,105,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,105,110,100,101,120,58,32,37,100,10,0,0,118,99,100,0,0,0,0,0,105,100,120,0,0,0,0,0,66,97,100,32,115,101,101,107,32,116,97,98,108,101,32,115,105,122,101,10,0,0,0,0,84,111,111,32,109,97,110,121,32,102,114,97,109,101,115,44,32,115,101,101,107,105,110,103,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,10,0,0,0,0,0,0,0,80,67,83,95,65,102,103,111,111,121,101,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,0,0,0,0,0,100,105,115,99,97,114,100,32,110,111,32,102,114,97,109,101,0,0,0,0,0,0,0,0,97,100,112,99,109,95,120,97,0,0,0,0,0,0,0,0,97,115,102,0,0,0,0,0,83,121,110,116,97,120,32,101,114,114,111,114,44,32,109,97,112,99,104,97,110,32,117,115,97,103,101,58,32,91,102,105,108,101,46,115,116,114,101,97,109,46,99,104,97,110,110,101,108,124,45,49,93,91,58,115,121,110,99,102,105,108,101,58,115,121,110,99,115,116,114,101,97,109,93,10,0,0,0,0,105,110,102,111,0,0,0,0,109,112,51,0,0,0,0,0,119,111,114,100,115,0,0,0,37,115,32,35,37,100,44,32,37,115,44,32,37,115,32,39,37,115,39,58,10,0,0,0,80,67,83,95,65,105,110,95,101,108,95,65,98,100,95,66,97,104,114,97,105,110,95,71,114,105,100,0,0,0,0,0,110,111,110,101,0,0,0,0,65,68,80,67,77,32,52,88,32,77,111,118,105,101,0,0,110,117,109,98,101,114,32,111,102,32,108,111,111,107,97,104,101,97,100,32,102,114,97,103,109,101,110,116,115,0,0,0,37,100,46,37,100,46,37,100,58,37,100,46,37,100,0,0,97,113,116,105,116,108,101,0,115,101,116,32,110,117,109,98,101,114,32,97,102,116,101,114,32,119,104,105,99,104,32,116,104,101,32,105,110,100,101,120,32,119,114,97,112,115,0,0,97,61,114,116,112,109,97,112,58,37,100,32,86,80,56,47,57,48,48,48,48,13,10,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,80,67,83,95,65,105,110,95,101,108,95,65,98,100,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,0,0,0,115,107,105,112,32,100,101,99,111,100,105,110,103,32,102,111,114,32,116,104,101,32,115,101,108,101,99,116,101,100,32,102,114,97,109,101,115,0,0,0,97,100,112,99,109,95,52,120,109,0,0,0,0,0,0,0,109,117,108,97,119,32,100,101,109,117,120,101,114,0,0,0,37,100,58,37,100,46,37,100,0,0,0,0,0,0,0,0,102,112,115,112,114,111,98,101,115,105,122,101,0,0,0,0,65,80,69,84,65,71,69,88,0,0,0,0,0,0,0,0,82,101,112,108,97,99,101,115,0,0,0,0,0,0,0,0,37,46,50,120,0,0,0,0,77,105,110,105,109,117,109,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2015880);
/* memory initializer */ allocate([80,69,83,32,112,97,99,107,101,116,32,112,97,121,108,111,97,100,32,105,110,32,98,121,116,101,115,0,0,0,0,0,80,67,83,95,65,105,110,95,101,108,95,65,98,100,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,0,0,115,107,105,112,95,102,114,97,109,101,0,0,0,0,0,0,65,68,80,67,77,32,77,105,99,114,111,115,111,102,116,0,37,115,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,115,101,116,32,116,104,101,32,39,99,114,101,97,116,105,111,110,95,116,105,109,101,39,32,109,101,116,97,100,97,116,97,32,116,97,103,32,105,110,115,116,101,97,100,46,10,0,0,0,0,0,0,0,0,112,116,115,32,104,97,115,32,110,111,32,118,97,108,117,101,10,0,0,0,0,0,0,0,102,114,97,103,95,99,117,115,116,111,109,0,0,0,0,0,104,100,95,118,105,100,101,111,0,0,0,0,0,0,0,0,115,117,98,50,118,105,100,101,111,58,32,114,101,99,116,97,110,103,108,101,32,111,118,101,114,102,108,111,119,105,110,103,10,0,0,0,0,0,0,0,101,110,99,111,100,105,110,103,95,116,111,111,108,0,0,0,97,112,101,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,80,67,83,95,65,105,110,95,101,108,95,65,98,100,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,0,0,115,107,105,112,32,73,68,67,84,47,100,101,113,117,97,110,116,105,122,97,116,105,111,110,32,102,111,114,32,116,104,101,32,115,101,108,101,99,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,97,100,112,99,109,95,109,115,0,0,0,0,0,0,0,0,120,98,109,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,61,37,70,84,37,84,37,122,0,0,0,76,101,97,100,32,97,114,116,105,115,116,47,108,101,97,100,32,112,101,114,102,111,114,109,101,114,47,115,111,108,111,105,115,116,0,0,0,0,0,0,97,112,99,0,0,0,0,0,112,114,111,116,111,99,111,108,115,0,0,0,0,0,0,0,35,32,116,105,109,101,99,111,100,101,32,102,111,114,109,97,116,32,118,50,10,0,0,0,123,37,108,108,100,125,0,0,97,110,109,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,56,0,0,0,123,37,100,125,123,37,42,100,125,37,54,108,102,0,0,0,115,107,105,112,95,105,100,99,116,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,76,111,107,105,32,83,68,76,32,77,74,80,69,71,0,0,0,0,0,0,0,0,102,114,97,109,101,115,58,100,0,0,0,0,0,0,0,0,37,100,44,32,37,49,48,108,108,100,44,32,37,49,48,108,108,100,44,32,37,56,100,44,32,37,56,100,44,32,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,97,108,117,101,32,116,121,112,101,32,37,100,32,105,110,32,116,97,103,32,37,115,46,10,0,0,0,115,117,98,50,118,105,100,101,111,58,32,117,115,105,110,103,32,37,100,120,37,100,32,99,97,110,118,97,115,10,0,0,97,109,114,0,0,0,0,0,115,101,116,32,98,97,110,100,45,119,105,100,116,104,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,55,0,0,0,97,118,100,105,115,99,97,114,100,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,115,109,106,112,101,103,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,112,114,111,103,114,101,115,115,32,85,82,76,32,34,37,115,34,58,32,37,115,10,0,0,0,119,101,98,109,0,0,0,0,99,111,110,118,101,114,103,101,110,99,101,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,99,114,101,97,116,101,32,115,99,97,108,101,32,99,111,110,116,101,120,116,32,102,111,114,32,116,104,101,32,99,111,110,118,101,114,115,105,111,110,32,102,109,116,58,37,115,32,115,58,37,100,120,37,100,32,45,62,32,102,109,116,58,37,115,32,115,58,37,100,120,37,100,10,0,70,105,108,101,32,105,115,32,98,114,111,107,101,110,44,32,107,101,121,102,114,97,109,101,115,32,110,111,116,32,99,111,114,114,101,99,116,108,121,32,109,97,114,107,101,100,33,10,0,0,0,0,0,0,0,0,111,117,116,112,117,116,32,104,111,114,105,122,111,110,116,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,54,0,0,0,115,107,105,112,32,108,111,111,112,32,102,105,108,116,101,114,105,110,103,32,112,114,111,99,101,115,115,32,102,111,114,32,116,104,101,32,115,101,108,101,99,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,87,101,115,116,119,111,111,100,0,0,0,0,0,0,85,110,107,110,111,119,110,32,102,111,114,109,97,116,32,118,101,114,115,105,111,110,32,37,105,10,0,0,0,0,0,0,112,105,112,101,58,0,0,0,121,117,118,52,50,48,0,0,99,51,102,0,0,0,0,0,68,79,77,65,73,78,95,0,65,68,84,83,32,104,101,97,100,101,114,32,100,101,116,101,99,116,101,100,32,45,32,65,68,84,83,32,119,105,108,108,32,110,111,116,32,98,101,32,105,110,99,111,114,114,101,99,116,108,121,32,109,117,120,101,100,32,105,110,116,111,32,76,65,84,77,10,0,0,0,0,105,109,97,103,101,50,0,0,98,111,116,116,111,109,0,0,114,103,98,53,53,53,108,101,0,0,0,0,0,0,0,0,68,97,114,107,82,101,100,0,60,115,116,114,105,110,103,62,0,0,0,0,0,0,0,0,35,84,32,37,115,0,0,0,105,102,110,111,116,0,0,0,119,105,100,101,32,108,101,102,116,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,100,115,116,95,114,97,110,103,101,0,0,0,0,0,0,0,68,75,73,70,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,99,111,117,110,116,0,0,0,0,0,0,0,0,86,52,32,83,116,121,108,101,115,0,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,53,0,0,0,97,100,112,99,109,95,109,115,0,0,0,0,0,0,0,0,115,107,105,112,95,108,111,111,112,95,102,105,108,116,101,114,0,0,0,0,0,0,0,0,76,111,47,82,111,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,76,111,47,82,111,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,97,100,112,99,109,95,105,109,97,95,119,115,0,0,0,0,65,115,115,117,109,105,110,103,32,97,110,32,105,110,99,111,114,114,101,99,116,108,121,32,101,110,99,111,100,101,100,32,55,46,49,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,105,110,115,116,101,97,100,32,111,102,32,97,32,115,112,101,99,45,99,111,109,112,108,105,97,110,116,32,55,46,49,40,119,105,100,101,41,32,108,97,121,111,117,116,44,32,117,115,101,32,45,115,116,114,105,99,116,32,37,100,32,116,111,32,100,101,99,111,100,101,32,97,99,99,111,114,100,105,110,103,32,116,111,32,116,104,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,105,110,115,116,101,97,100,46,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,119,105,100,116,104,47,104,101,105,103,104,116,10,0,0,0,0,0,0,0,109,97,120,32,110,117,109,32,115,117,98,102,114,97,109,101,115,0,0,0,0,0,0,0,118,105,110,116,97,103,101,0,32,77,111,114,101,32,99,111,100,101,108,101,110,103,116,104,115,32,116,104,97,110,32,99,111,100,101,115,32,105,110,32,99,111,100,101,98,111,111,107,46,32,10,0,0,0,0,0,66,105,116,115,32,111,118,101,114,99,111,110,115,117,109,112,116,105,111,110,58,32,37,105,32,62,32,37,105,32,97,116,32,37,105,120,37,105,10,0,45,0,0,0,0,0,0,0,70,97,105,108,101,100,32,112,97,114,115,105,110,103,32,115,116,101,114,101,111,32,102,108,97,103,10,0,0,0,0,0,97,118,99,116,120,45,62,99,111,100,101,99,45,62,101,110,99,111,100,101,50,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,115,111,102,116,108,105,103,104,116,0,0,0,0,0,0,0,77,111,100,101,108,84,121,112,101,71,101,111,103,114,97,112,104,105,99,0,0,0,0,0,100,111,99,117,109,101,110,116,95,110,97,109,101,0,0,0,91,108,97,118,99,32,114,99,93,32,69,114,114,111,114,58,32,98,105,116,114,97,116,101,32,116,111,111,32,108,111,119,32,102,111,114,32,116,104,105,115,32,118,105,100,101,111,32,119,105,116,104,32,116,104,101,115,101,32,112,97,114,97,109,101,116,101,114,115,46,10,0,112,99,109,95,115,49,54,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,105,110,103,101,110,105,101,110,116,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,112,97,115,115,50,0,0,0,109,115,109,112,101,103,52,0,109,112,101,103,50,32,115,116,121,108,101,32,113,117,97,110,116,105,122,97,116,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,68,67,84,32,99,111,101,102,102,115,32,111,102,32,77,66,32,97,116,32,37,100,120,37,100,58,10,0,0,0,0,0,84,101,120,116,117,114,101,32,83,104,97,112,101,32,76,97,121,101,114,32,115,116,97,114,116,0,0,0,0,0,0,0,115,45,62,109,98,95,115,107,105,112,95,114,117,110,32,61,61,32,48,0,0,0,0,0,97,108,116,0,0,0,0,0,114,101,115,116,97,114,116,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,109,97,114,107,101,114,61,37,120,32,97,118,97,105,108,95,115,105,122,101,95,105,110,95,98,117,102,61,37,116,100,10,0,0,0,0,0,0,0,0,76,111,119,101,114,32,116,104,101,32,100,101,99,111,100,105,110,103,32,114,101,115,111,108,117,116,105,111,110,32,98,121,32,97,32,112,111,119,101,114,32,111,102,32,116,119,111,0,112,105,112,101,100,32,105,109,97,103,101,50,32,115,101,113,117,101,110,99,101,0,0,0,85,110,107,110,111,119,110,32,83,65,82,32,105,110,100,101,120,58,32,37,117,46,10,0,49,0,0,0,0,0,0,0,77,97,105,110,32,83,116,105,108,108,32,80,105,99,116,117,114,101,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,78,65,76,32,37,100,32,105,110,32,103,108,111,98,97,108,32,104,101,97,100,101,114,47,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,112,97,115,115,101,115,32,116,111,32,117,115,101,32,102,111,114,32,67,104,111,108,101,115,107,121,32,102,97,99,116,111,114,105,122,97,116,105,111,110,32,100,117,114,105,110,103,32,76,80,67,32,97,110,97,108,121,115,105,115,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,68,84,83,32,57,54,47,50,52,0,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,52,0,0,0,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,98,105,116,114,97,116,101,32,112,101,110,97,108,116,121,32,99,111,109,112,101,110,115,97,116,105,111,110,32,40,49,46,48,32,61,32,50,53,54,41,0,0,0,0,0,0,115,118,113,51,0,0,0,0,65,68,80,67,77,32,73,77,65,32,68,117,99,107,32,68,75,52,0,0,0,0,0,0,116,104,114,101,97,100,95,116,121,112,101,0,0,0,0,0,73,110,115,116,114,117,109,101,110,116,97,108,32,80,111,112,0,0,0,0,0,0,0,0,52,50,48,80,49,52,0,0,85,110,107,110,111,119,110,32,116,97,114,103,101,116,58,32,37,115,10,0,0,0,0,0,105,109,97,103,101,50,112,105,112,101,32,100,101,109,117,120,101,114,0,0,0,0,0,0,108,106,112,103,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,115,116,114,101,97,109,115,10,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,115,101,116,32,116,105,109,101,32,98,97,115,101,10,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,51,0,0,0,109,101,112,99,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,105,102,102,46,99,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,100,107,52,0,0,0,70,111,114,32,118,105,110,116,97,103,101,32,99,111,109,112,97,116,105,98,105,108,105,116,121,32,102,112,115,32,109,117,115,116,32,98,101,32,51,48,10,0,0,0,0,0,0,0,121,117,118,52,49,49,112,0,119,97,114,110,105,110,103,0,105,110,99,111,109,112,108,101,116,101,32,104,101,97,100,101,114,10,0,0,0,0,0,0,87,79,82,68,0,0,0,0,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,32,105,115,32,110,111,116,32,118,97,108,105,100,10,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,50,0,0,0,109,97,120,105,109,117,109,32,109,97,99,114,111,98,108,111,99,107,32,76,97,103,114,97,110,103,101,32,102,97,99,116,111,114,32,40,86,66,82,41,0,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,68,117,99,107,32,68,75,51,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,111,111,107,97,104,101,97,100,95,99,111,117,110,116,0,121,117,118,52,50,50,112,0,115,101,103,109,101,110,116,95,119,114,97,112,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,116,104,101,111,114,97,47,57,48,48,48,48,13,10,97,61,102,109,116,112,58,37,100,32,100,101,108,105,118,101,114,121,45,109,101,116,104,111,100,61,105,110,108,105,110,101,59,32,119,105,100,116,104,61,37,100,59,32,104,101,105,103,104,116,61,37,100,59,32,115,97,109,112,108,105,110,103,61,37,115,59,32,99,111,110,102,105,103,117,114,97,116,105,111,110,61,37,115,13,10,0,0,0,0,0,0,0,0,84,67,79,78,0,0,0,0,73,110,118,97,108,105,100,32,66,77,80,10,0,0,0,0,105,110,118,97,108,105,100,32,114,101,115,111,108,117,116,105,111,110,58,32,37,117,120,37,117,10,0,0,0,0,0,0,116,0,0,0,0,0,0,0,114,97,119,32,77,76,80,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,49,0,0,0,109,98,108,109,97,120,0,0,117,108,0,0,0,0,0,0,35,69,88,84,45,88,45,86,69,82,83,73,79,78,58,51,10,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,100,107,51,0,0,0,117,108,0,0,0,0,0,0,100,118,53,48,0,0,0,0,109,97,120,105,109,117,109,32,109,117,120,105,110,103,32,111,114,32,100,101,109,117,120,105,110,103,32,100,101,108,97,121,32,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,0,0,0,0,0,0,0,0,117,115,101,114,45,97,103,101,110,116,0,0,0,0,0,0,67,111,108,111,114,32,99,111,110,118,101,114,115,105,111,110,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,102,111,114,32,37,115,10,0,0,0,0,0,0,0,0,68,101,112,101,110,100,115,0,37,115,58,32,85,110,105,118,101,114,115,97,108,32,76,97,98,101,108,58,32,0,0,0,37,115,47,105,110,100,101,120,46,102,52,109,46,116,109,112,0,0,0,0,0,0,0,0,112,101,115,95,112,97,121,108,111,97,100,95,115,105,122,101,0,0,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,48,0,0,0,109,105,110,105,109,117,109,32,109,97,99,114,111,98,108,111,99,107,32,76,97,103,114,97,110,103,101,32,102,97,99,116,111,114,32,40,86,66,82,41,0,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,87,65,86,0,0,0,100,118,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,97,108,108,111,99,32,109,97,112,32,111,102,102,115,101,116,115,10,0,0,87,114,105,116,101,32,115,101,112,97,114,97,116,101,32,109,111,111,102,47,109,100,97,116,32,97,116,111,109,115,32,102,111,114,32,101,97,99,104,32,116,114,97,99,107,0,0,0,109,101,100,105,97,95,116,121,112,101,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,105,114,115,116,32,97,110,100,32,108,97,115,116,32,115,97,109,112,108,101,32,118,97,108,117,101,115,10,0,0,0,115,117,98,50,118,105,100,101,111,58,32,110,111,110,45,98,105,116,109,97,112,32,115,117,98,116,105,116,108,101,10,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,71,114,97,112,104,105,99,32,67,111,110,116,114,111,108,32,69,120,116,101,110,115,105,111,110,32,98,108,111,99,107,39,115,32,115,105,122,101,32,108,101,115,115,32,116,104,97,110,32,52,46,10,0,0,0,0,85,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,65,86,67,111,100,101,99,73,68,32,37,115,46,10,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,52,57,0,0,0,71,73,70,32,109,117,120,101,114,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,97,32,115,105,110,103,108,101,32,118,105,100,101,111,32,71,73,70,32,115,116,114,101,97,109,46,10,0,0,0,0,0,109,98,108,109,105,110,0,0,97,100,112,99,109,95,105,109,97,95,119,97,118,0,0,0,119,101,98,112,0,0,0,0,103,55,50,57,32,100,101,109,117,120,101,114,0,0,0,0,52,56,48,48,48,0,0,0,115,116,45,62,99,111,100,101,99,45,62,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,62,32,48,0,0,0,0,77,101,100,105,97,32,40,101,46,103,46,32,108,97,98,101,108,32,115,105,100,101,32,111,102,32,67,68,41,0,0,0,44,32,83,61,37,100,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,98,105,116,32,115,116,114,101,97,109,32,102,105,108,116,101,114,115,0,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,52,56,0,0,0,105,110,99,114,101,97,115,101,32,116,104,101,32,113,117,97,110,116,105,122,101,114,32,102,111,114,32,109,97,99,114,111,98,108,111,99,107,115,32,99,108,111,115,101,32,116,111,32,98,111,114,100,101,114,115,0,70,97,105,108,101,100,32,116,111,32,117,112,100,97,116,101,32,104,101,97,100,101,114,32,119,105,116,104,32,99,111,114,114,101,99,116,32,102,105,108,101,115,105,122,101,46,10,0,65,68,80,67,77,32,73,77,65,32,81,117,105,99,107,84,105,109,101,0,0,0,0,0,118,111,108,117,109,101,100,101,116,101,99,116,0,0,0,0,52,52,56,48,48,48,0,0,85,110,115,117,112,112,111,114,116,101,100,32,71,85,73,68,32,118,97,108,117,101,32,105,110,32,116,97,103,32,37,115,46,10,0,0,0,0,0,0,110,101,103,97,116,105,118,101,32,99,116,115,44,32,112,114,101,118,105,111,117,115,32,116,105,109,101,115,116,97,109,112,115,32,109,105,103,104,116,32,98,101,32,119,114,111,110,103,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,109,97,103,105,99,32,99,104,117,110,107,32,105,110,32,102,105,108,101,10,0,0,0,0,0,121,97,100,105,102,0,0,0,111,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,102,76,97,67,0,0,0,0,112,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,97,99,107,105,110,103,32,109,101,116,104,111,100,0,0,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,56,0,0,0,98,111,114,100,101,114,95,109,97,115,107,0,0,0,0,0,98,108,111,99,107,115,105,122,101,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,113,116,0,0,0,0,49,48,48,56,48,48,48,48,0,0,0,0,0,0,0,0,91,67,72,65,80,84,69,82,93,0,0,0,0,0,0,0,84,73,77,69,66,65,83,69,61,37,100,47,37,100,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,116,32,112,101,114,105,111,100,32,109,111,100,101,0,99,97,110,110,111,116,32,102,105,110,100,32,70,70,77,32,115,121,110,99,119,111,114,100,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,0,0,0,111,117,116,95,104,95,99,104,114,95,112,111,115,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,55,0,0,0,102,114,97,109,101,32,115,107,105,112,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,0,0,0,70,114,97,109,101,32,115,105,122,101,32,105,115,32,116,111,111,32,98,105,103,58,32,37,100,10,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,32,112,108,97,110,97,114,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,50,48,52,56,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,102,111,114,109,97,116,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,102,108,97,103,115,0,0,84,111,111,32,108,97,114,103,101,32,111,114,32,105,110,118,97,108,105,100,32,51,68,32,76,85,84,32,115,105,122,101,10,0,0,0,0,0,0,0,67,97,110,110,111,116,32,102,105,110,100,32,68,86,32,104,101,97,100,101,114,46,10,0,102,105,108,101,105,110,102,111,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,97,103,105,99,32,102,111,114,32,68,70,65,10,0,0,97,117,116,111,109,97,116,105,99,32,40,115,97,109,101,32,118,97,108,117,101,32,97,115,32,39,111,114,100,101,114,39,41,0,0,0,0,0,0,0,80,97,99,107,101,116,32,115,105,122,101,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,115,51,48,50,109,46,32,40,37,100,32,62,32,54,53,53,51,53,41,10,0,0,114,103,98,53,53,53,98,101,0,0,0,0,0,0,0,0,68,97,114,107,79,114,99,104,105,100,0,0,0,0,0,0,60,102,108,111,97,116,62,0,105,102,0,0,0,0,0,0,87,76,0,0,0,0,0,0,115,105,122,101,70,97,99,116,111,114,32,62,32,48,0,0,115,111,117,114,99,101,32,114,97,110,103,101,0,0,0,0,105,110,95,99,104,97,110,110,101,108,95,99,111,117,110,116,0,0,0,0,0,0,0,0,65,108,105,103,110,109,101,110,116,0,0,0,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,54,0,0,0,65,68,80,67,77,32,73,77,65,32,87,101,115,116,119,111,111,100,0,0,0,0,0,0,115,107,105,112,99,109,112,0,108,111,114,111,95,99,109,105,120,108,101,118,0,0,0,0,108,111,114,111,95,99,109,105,120,108,101,118,0,0,0,0,32,9,13,10,0,0,0,0,112,99,109,95,115,56,95,112,108,97,110,97,114,0,0,0,105,110,118,97,108,105,100,32,100,101,102,97,117,108,116,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,40,37,100,41,10,0,0,0,0,0,101,120,116,114,97,100,97,116,97,32,119,114,111,110,103,32,111,114,32,109,105,115,115,105,110,103,10,0,0,0,0,0,108,111,103,50,32,102,114,97,109,101,32,115,105,122,101,0,115,116,114,111,110,103,95,99,111,110,116,114,97,115,116,0,32,37,117,46,32,67,111,100,101,98,111,111,107,32,104,97,115,32,116,111,111,32,109,97,110,121,32,101,110,116,114,105,101,115,32,40,37,117,41,46,10,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,112,97,114,115,101,32,102,114,97,109,101,114,97,116,101,58,32,37,115,46,10,0,65,100,118,97,110,99,101,100,0,0,0,0,0,0,0,0,57,48,48,48,48,48,48,0,115,99,114,101,101,110,0,0,77,111,100,101,108,84,121,112,101,80,114,111,106,101,99,116,101,100,0,0,0,0,0,0,100,97,116,101,0,0,0,0,67,65,70,32,102,105,108,101,115,32,104,97,118,101,32,101,120,97,99,116,108,121,32,111,110,101,32,115,116,114,101,97,109,10,0,0,0,0,0,0,91,108,97,118,99,32,114,99,93,32,85,115,105,110,103,32,97,108,108,32,111,102,32,114,101,113,117,101,115,116,101,100,32,98,105,116,114,97,116,101,32,105,115,32,110,111,116,32,110,101,99,101,115,115,97,114,121,32,102,111,114,32,116,104,105,115,32,118,105,100,101,111,32,119,105,116,104,32,116,104,101,115,101,32,112,97,114,97,109,101,116,101,114,115,46,10,0,0,0,0,0,0,0,0,117,115,101,32,105,110,116,101,114,110,97,108,32,50,45,112,97,115,115,32,114,97,116,101,99,111,110,116,114,111,108,32,105,110,32,102,105,114,115,116,32,32,112,97,115,115,32,109,111,100,101,0,0,0,0,0,77,105,115,115,105,110,103,32,112,97,99,107,101,116,32,116,97,98,108,101,46,32,73,116,32,105,115,32,114,101,113,117,105,114,101,100,32,119,104,101,110,32,98,108,111,99,107,32,115,105,122,101,32,111,114,32,102,114,97,109,101,32,115,105,122,101,32,97,114,101,32,118,97,114,105,97,98,108,101,46,10,0,0,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,0,114,101,102,45,62,115,105,122,101,32,62,61,32,111,102,102,115,101,116,32,43,32,115,45,62,109,98,95,115,116,114,105,100,101,32,42,32,40,40,102,45,62,104,101,105,103,104,116,43,49,53,41,47,49,54,41,0,0,0,0,0,0,0,0,84,101,120,116,117,114,101,32,84,105,108,101,32,115,116,97,114,116,0,0,0,0,0,0,109,112,101,103,49,118,105,100,101,111,32,101,110,99,111,100,101,114,0,0,0,0,0,0,112,102,0,0,0,0,0,0,65,115,115,105,103,110,109,101,110,116,32,111,102,32,109,97,116,114,105,120,32,99,104,97,110,110,101,108,32,37,100,32,116,111,32,105,110,118,97,108,105,100,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,37,100,0,0,0,0,77,74,80,69,71,32,112,97,99,107,101,116,32,48,120,37,120,32,116,111,111,32,98,105,103,32,40,37,100,47,37,100,41,44,32,99,111,114,114,117,112,116,32,100,97,116,97,63,10,0,0,0,0,0,0,0,108,111,119,114,101,115,0,0,114,117,110,32,111,118,101,114,102,108,111,119,32,97,116,32,37,100,120,37,100,32,105,58,37,100,10,0,0,0,0,0,68,101,99,111,100,105,110,103,32,86,85,73,10,0,0,0,115,101,116,32,97,110,32,101,120,112,114,101,115,115,105,111,110,32,116,111,32,117,115,101,32,102,111,114,32,115,101,108,101,99,116,105,110,103,32,102,114,97,109,101,115,0,0,0,99,111,100,101,99,32,37,100,0,0,0,0,0,0,0,0,77,97,105,110,32,49,48,0,65,86,67,58,32,67,111,110,115,117,109,101,100,32,111,110,108,121,32,37,100,32,98,121,116,101,115,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,0,0,0,0,0,108,112,99,95,112,97,115,115,101,115,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,0,0,0,0,68,84,83,45,69,83,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,53,0,0,0,102,114,97,109,101,32,115,107,105,112,32,101,120,112,111,110,101,110,116,0,0,0,0,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,49,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,49,32,47,32,83,86,81,49,0,0,0,83,77,80,84,69,32,51,48,50,77,0,0,0,0,0,0,65,86,70,105,108,116,101,114,0,0,0,0,0,0,0,0,77,101,100,105,116,97,116,105,118,101,0,0,0,0,0,0,52,52,52,80,49,50,0,0,54,48,48,48,48,48,48,0,101,88,116,101,110,100,101,100,32,66,73,78,97,114,121,32,116,101,120,116,32,40,88,66,73,78,41,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,109,111,114,101,32,116,104,97,110,32,49,48,48,48,48,48,48,32,102,114,97,109,101,115,10,0,0,0,0,0,0,0,114,101,97,99,104,101,100,32,116,101,114,109,105,110,97,116,105,110,103,32,99,104,97,114,97,99,116,101,114,32,98,117,116,32,110,111,116,32,97,108,108,32,102,114,97,109,101,115,32,114,101,97,100,46,10,0,118,111,108,117,109,101,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,52,0,0,0,115,107,105,112,95,101,120,112,0,0,0,0,0,0,0,0,115,51,48,50,109,0,0,0,55,50,48,120,52,56,48,0,101,114,114,111,114,0,0,0,115,58,37,100,120,37,100,32,82,68,70,84,32,119,105,110,100,111,119,32,115,105,122,101,58,37,100,10,0,0,0,0,116,114,97,99,107,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,118,105,111,98,117,102,46,99,0,0,0,116,105,116,108,101,0,0,0,104,116,116,112,115,32,112,114,111,116,111,99,111,108,32,110,111,116,32,102,111,117,110,100,44,32,114,101,99,111,109,112,105,108,101,32,119,105,116,104,32,111,112,101,110,115,115,108,32,111,114,32,103,110,117,116,108,115,32,101,110,97,98,108,101,100,46,10,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,51,0,0,0,102,114,97,109,101,32,115,107,105,112,32,102,97,99,116,111,114,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,48,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,110,117,109,98,101,114,32,111,102,32,102,114,97,103,109,101,110,116,115,32,107,101,112,116,32,111,117,116,115,105,100,101,32,111,102,32,116,104,101,32,109,97,110,105,102,101,115,116,32,98,101,102,111,114,101,32,114,101,109,111,118,105,110,103,32,102,114,111,109,32,100,105,115,107,0,0,0,0,0,0,55,50,48,120,53,55,54,0,115,101,116,32,115,101,103,109,101,110,116,32,115,112,108,105,116,32,102,114,97,109,101,32,110,117,109,98,101,114,115,0,84,104,101,111,114,97,32,99,111,110,102,105,103,117,97,116,105,111,110,32,105,110,102,111,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,118,105,100,101,99,46,99,0,0,0,0,111,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,109,108,112,0,0,0,0,0,76,111,111,112,101,110,100,32,118,97,108,117,101,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,97,110,100,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,50,0,0,0,115,107,105,112,95,102,97,99,116,111,114,0,0,0,0,0,80,67,77,32,109,117,45,108,97,119,0,0,0,0,0,0,112,99,109,95,108,120,102,0,115,105,108,101,110,99,101,100,101,116,101,99,116,0,0,0,80,67,77,32,109,117,45,108,97,119,0,0,0,0,0,0,44,0,0,0,0,0,0,0,97,99,51,0,0,0,0,0,37,42,91,94,44,93,44,37,100,58,37,100,58,37,100,37,42,99,37,100,44,37,100,58,37,100,58,37,100,37,42,99,37,100,0,0,0,0,0,0,109,97,120,95,100,101,108,97,121,0,0,0,0,0,0,0,97,115,102,95,115,116,114,101,97,109,0,0,0,0,0,0,85,115,101,115,0,0,0,0,98,114,111,107,101,110,32,101,110,99,114,121,112,116,101,100,32,109,120,102,32,102,105,108,101,10,0,0,0,0,0,0,109,117,120,114,97,116,101,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,49,0,0,0,102,114,97,109,101,32,115,107,105,112,32,116,104,114,101,115,104,111,108,100,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,124,50,48,124,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,102,111,114,32,66,108,117,45,114,97,121,32,109,101,100,105,97,0,0,0,0,105,116,105,109,101,58,48,120,37,108,108,120,44,32,112,99,116,58,37,100,44,32,105,99,116,58,37,100,10,0,0,0,100,118,100,0,0,0,0,0,45,45,62,62,32,37,108,108,100,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,116,97,103,32,102,105,101,108,100,115,32,40,37,100,41,10,0,0,0,0,0,0,0,115,101,112,97,114,97,116,101,95,109,111,111,102,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,102,105,108,101,32,118,101,114,115,105,111,110,32,45,32,37,100,46,37,48,50,100,10,0,0,0,0,0,114,101,112,108,97,121,103,97,105,110,0,0,0,0,0,0,115,101,97,115,111,110,95,110,117,109,98,101,114,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,103,101,116,32,97,32,98,108,97,110,107,32,99,97,110,118,97,115,46,10,0,0,0,0,0,0,84,104,101,32,77,97,116,114,111,115,107,97,32,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,121,101,116,32,115,117,112,112,111,114,116,32,109,117,120,105,110,103,32,37,115,10,0,0,0,0,0,0,84,84,65,49,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,32,102,114,97,109,101,10,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,48,0,0,0,115,107,105,112,95,116,104,114,101,115,104,111,108,100,0,0,112,99,109,95,98,108,117,114,97,121,0,0,0,0,0,0,121,117,118,49,48,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,102,114,97,109,101,115,121,110,99,46,99,0,49,0,0,0,0,0,0,0,76,101,97,102,108,101,116,32,112,97,103,101,0,0,0,0,115,114,99,45,62,118,105,100,101,111,0,0,0,0,0,0,112,111,119,101,114,32,60,61,32,48,120,56,48,48,48,32,42,32,48,120,56,48,48,48,0,0,0,0,0,0,0,0,98,115,102,115,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,52,57,0,0,0,100,101,99,111,100,101,32,97,116,32,49,61,32,49,47,50,44,32,50,61,49,47,52,44,32,51,61,49,47,56,32,114,101,115,111,108,117,116,105,111,110,115,0,0,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,110,58,37,102,32,116,58,37,102,32,112,116,115,58,37,102,32,112,114,101,99,105,115,105,111,110,58,37,115,32,0,0,115,99,97,110,95,111,102,102,115,101,116,0,0,0,0,0,117,115,101,32,111,100,109,108,32,105,110,100,101,120,0,0,110,111,105,115,101,0,0,0,37,108,108,117,0,0,0,0,100,101,102,97,117,108,116,0,100,101,105,110,116,101,114,108,97,99,101,32,105,110,112,117,116,32,102,114,111,109,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,69,120,112,101,99,116,101,100,32,111,117,116,32,99,104,97,110,110,101,108,32,110,97,109,101,44,32,103,111,116,32,34,37,46,56,115,34,10,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,112,111,108,101,115,0,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,52,56,0,0,0,108,111,119,114,101,115,0,0,112,99,109,95,102,54,52,108,101,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,49,56,51,53,48,48,56,0,100,101,102,97,117,108,116,0,112,101,114,105,111,100,0,0,48,46,51,0,0,0,0,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,46,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,58,32,39,37,115,39,46,10,0,0,0,0,111,117,116,112,117,116,32,118,101,114,116,105,99,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,0,0,80,67,83,95,65,100,105,110,100,97,110,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,0,0,0,0,0,108,101,118,101,108,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,48,0,0,0,0,0,0,0,102,111,114,109,97,116,0,0,99,51,95,102,108,97,103,115,0,0,0,0,0,0,0,0,76,85,84,95,51,68,95,83,73,90,69,32,0,0,0,0,112,97,110,0,0,0,0,0,99,108,105,112,118,97,108,0,116,114,101,98,108,101,0,0,115,101,116,32,116,104,101,32,102,105,101,108,100,32,116,111,32,109,97,116,99,104,32,102,114,111,109,0,0,0,0,0,114,103,98,53,54,53,108,101,0,0,0,0,0,0,0,0,68,97,114,107,111,114,97,110,103,101,0,0,0,0,0,0,60,100,111,117,98,108,101,62,0,0,0,0,0,0,0,0,103,99,100,0,0,0,0,0,100,111,119,110,109,105,120,32,114,105,103,104,116,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,115,114,99,95,114,97,110,103,101,0,0,0,0,0,0,0,115,101,116,32,105,110,112,117,116,32,99,104,97,110,110,101,108,32,99,111,117,110,116,0,85,110,100,101,114,108,105,110,101,0,0,0,0,0,0,0,80,67,83,95,65,100,105,110,100,97,110,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,119,115,0,0,0,0,100,116,115,95,104,100,95,109,97,0,0,0,0,0,0,0,84,101,109,112,111,32,118,97,108,117,101,32,37,102,32,101,120,99,101,101,100,115,32,91,48,46,53,44,32,50,46,48,93,32,114,97,110,103,101,10,0,0,0,0,0,0,0,0,76,116,47,82,116,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,76,116,47,82,116,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,65,67,51,32,100,101,99,111,100,101,114,0,0,0,0,0,112,99,109,95,102,54,52,98,101,0,0,0,0,0,0,0,115,116,101,114,101,111,32,119,105,116,104,32,83,67,69,10,0,0,0,0,0,0,0,0,117,110,107,32,98,105,116,32,50,10,0,0,0,0,0,0,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,0,0,0,0,0,0,0,110,101,103,97,116,105,118,101,0,0,0,0,0,0,0,0,32,37,117,46,32,67,111,100,101,98,111,111,107,39,115,32,100,105,109,101,110,115,105,111,110,32,105,115,32,105,110,118,97,108,105,100,32,40,37,100,41,46,10,0,0,0,0,0,67,111,109,112,108,101,120,0,58,37,115,0,0,0,0,0,50,53,49,54,48,48,48,0,98,50,0,0,0,0,0,0,114,101,102,108,101,99,116,0,86,101,114,116,105,99,97,108,85,110,105,116,115,71,101,111,75,101,121,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,91,108,97,118,99,32,114,99,93,32,101,115,116,105,109,97,116,101,100,32,116,97,114,103,101,116,32,97,118,101,114,97,103,101,32,113,112,58,32,37,46,51,102,10,0,0,0,0,77,105,110,32,108,101,118,101,108,58,32,37,102,10,0,0,112,97,115,115,49,0,0,0,109,115,109,112,101,103,52,118,50,0,0,0,0,0,0,0,119,105,100,116,104,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,50,10,0,0,0,0,10,0,0,0,0,0,0,0,84,101,120,116,117,114,101,32,83,78,82,32,76,97,121,101,114,32,115,116,97,114,116,0,68,114,111,112,32,102,114,97,109,101,32,116,105,109,101,32,99,111,100,101,32,111,110,108,121,32,97,108,108,111,119,101,100,32,119,105,116,104,32,49,48,48,49,47,51,48,48,48,48,32,102,112,115,10,0,0,76,111,115,115,108,101,115,115,32,99,104,101,99,107,32,102,97,105,108,101,100,32,45,32,101,120,112,101,99,116,101,100,32,37,48,50,120,44,32,99,97,108,99,117,108,97,116,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2026120);
/* memory initializer */ allocate([100,32,37,48,50,120,46,10,0,0,0,0,0,0,0,0,112,108,97,110,101,95,99,104,101,99,107,115,117,109,115,58,32,91,32,0,0,0,0,0,101,115,99,97,112,105,110,103,32,114,101,109,111,118,101,100,32,37,116,100,32,98,121,116,101,115,10,0,0,0,0,0,74,80,69,71,32,50,48,48,48,32,100,105,103,105,116,97,108,32,99,105,110,101,109,97,32,52,75,0,0,0,0,0,37,115,0,0,0,0,0,0,105,108,108,101,103,97,108,32,97,99,32,118,108,99,32,99,111,100,101,32,97,116,32,37,100,120,37,100,10,0,0,0,108,111,103,50,95,112,97,114,97,108,108,101,108,95,109,101,114,103,101,95,108,101,118,101,108,95,109,105,110,117,115,50,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,101,120,112,114,0,0,0,0,77,97,105,110,0,0,0,0,114,0,0,0,0,0,0,0,78,65,76,32,37,100,47,37,100,32,97,116,32,37,100,47,37,100,32,108,101,110,103,116,104,32,37,100,32,112,97,115,115,32,37,100,10,0,0,0,99,104,111,108,101,115,107,121,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,77,111,100,101,0,0,68,84,83,0,0,0,0,0,80,77,95,83,116,111,99,107,104,111,108,109,0,0,0,0,100,116,115,95,104,100,95,104,114,97,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,112,101,114,45,102,114,97,109,101,32,111,117,116,112,117,116,32,115,97,109,112,108,101,115,0,0,0,0,0,0,115,118,113,49,0,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,79,112,116,105,111,110,32,39,37,115,39,32,110,111,116,32,102,111,117,110,100,10,0,0,83,112,97,99,101,0,0,0,52,50,50,80,49,50,0,0,50,48,52,48,48,48,48,0,111,115,102,0,0,0,0,0,105,110,95,103,97,105,110,0,115,101,116,32,115,105,108,101,110,99,101,32,112,97,99,107,101,116,32,115,105,122,101,0,80,77,95,66,114,117,115,115,101,108,115,0,0,0,0,0,100,116,115,95,57,54,95,50,52,0,0,0,0,0,0,0,112,99,109,95,102,51,50,108,101,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,121,117,118,52,50,48,112,0,102,97,116,97,108,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,118,102,95,115,104,111,119,115,112,101,99,116,114,117,109,46,99,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,32,40,109,97,120,32,37,100,41,10,0,0,0,0,0,84,82,67,75,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,115,97,109,112,108,101,32,102,111,114,109,97,116,58,32,37,115,46,10,0,0,0,0,0,0,0,106,111,105,110,0,0,0,0,115,45,62,115,116,114,101,97,109,115,91,32,115,45,62,110,98,95,115,116,114,101,97,109,115,32,45,32,49,32,93,32,61,61,32,115,116,0,0,0,80,77,95,70,101,114,114,111,0,0,0,0,0,0,0,0,100,116,115,95,101,115,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,116,0,0,0,0,0,0,0,101,120,116,114,97,95,119,105,110,100,111,119,95,115,105,122,101,0,0,0,0,0,0,0,52,56,48,120,52,56,48,0,115,101,103,109,101,110,116,95,102,114,97,109,101,115,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,0,0,0,0,65,116,32,108,101,97,115,116,32,111,110,101,32,100,101,99,97,121,32,38,32,100,101,108,97,121,32,109,117,115,116,32,98,101,32,115,101,116,46,10,0,0,0,0,0,0,0,0,101,97,114,119,97,120,0,0,100,101,102,97,117,108,116,0,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,0,109,106,112,103,44,109,106,112,101,103,0,0,0,0,0,0,80,77,95,74,97,107,97,114,116,97,0,0,0,0,0,0,100,116,115,0,0,0,0,0,109,117,108,97,119,0,0,0,112,99,109,95,102,51,50,98,101,0,0,0,0,0,0,0,109,117,108,97,119,0,0,0,52,56,48,120,53,55,54,0,101,120,112,114,115,0,0,0,116,115,0,0,0,0,0,0,37,100,47,37,100,0,0,0,115,111,117,114,99,101,32,116,114,97,99,107,32,37,100,58,32,115,116,114,101,97,109,32,37,100,44,32,110,111,32,100,101,115,99,114,105,112,116,111,114,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,99,111,117,110,116,32,37,100,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,110,117,108,108,115,114,99,0,69,110,97,98,108,101,32,109,50,116,115,32,109,111,100,101,46,0,0,0,0,0,0,0,80,77,95,66,101,114,110,0,109,112,101,103,50,95,97,97,99,95,104,101,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,48,124,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,54,52,48,120,52,56,48,0,70,114,97,103,109,101,110,116,32,97,116,32,118,105,100,101,111,32,107,101,121,102,114,97,109,101,115,0,0,0,0,0,101,112,105,115,111,100,101,95,115,111,114,116,0,0,0,0,83,117,98,116,105,116,108,101,32,101,110,99,111,100,105,110,103,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,110,101,119,32,99,108,117,115,116,101,114,32,97,116,32,111,102,102,115,101,116,32,37,108,108,117,32,98,121,116,101,115,44,32,112,116,115,32,37,108,108,117,100,116,115,32,37,108,108,117,10,0,0,0,0,115,105,122,101,0,0,0,0,80,77,95,82,111,109,101,0,109,112,101,103,50,95,97,97,99,95,108,111,119,0,0,0,112,99,109,95,100,118,100,0,112,105,99,0,0,0,0,0,115,118,99,100,0,0,0,0,67,111,118,101,114,32,40,98,97,99,107,41,0,0,0,0,79,110,108,121,32,111,110,101,32,111,102,32,116,104,101,32,102,105,108,101,110,97,109,101,32,111,114,32,112,97,116,116,101,114,110,32,111,112,116,105,111,110,115,32,99,97,110,32,98,101,32,117,115,101,100,10,0,0,0,0,0,0,0,0,102,105,108,101,115,105,122,101,0,0,0,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,101,110,99,111,100,101,114,115,0,115,101,110,100,95,102,114,97,109,101,0,0,0,0,0,0,80,77,95,77,97,100,114,105,100,0,0,0,0,0,0,0,97,97,99,95,101,108,100,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,49,52,49,49,50,48,48,0,115,105,109,112,108,101,0,0,99,111,109,112,97,110,100,0,117,115,101,95,111,100,109,108,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,121,116,101,32,97,114,114,97,121,32,105,110,32,116,97,103,32,37,115,46,10,0,0,0,0,0,0,78,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,39,121,48,39,10,0,0,0,0,112,111,108,101,115,0,0,0,80,77,95,66,111,103,111,116,97,0,0,0,0,0,0,0,97,97,99,95,108,100,0,0,112,99,109,95,115,51,50,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,115,101,116,32,108,117,109,97,32,109,97,116,114,105,120,32,104,111,114,105,122,111,110,116,97,108,32,115,105,122,101,0,109,117,120,114,97,116,101,0,99,117,98,105,99,32,114,111,111,116,0,0,0,0,0,0,115,101,116,32,98,108,97,99,107,32,109,111,100,101,0,0,99,99,108,111,99,107,95,102,108,105,112,0,0,0,0,0,99,104,97,110,110,101,108,115,112,108,105,116,0,0,0,0,100,101,102,97,117,108,116,0,108,97,121,111,117,116,0,0,110,0,0,0,0,0,0,0,111,117,116,95,118,95,99,104,114,95,112,111,115,0,0,0,80,77,95,80,97,114,105,115,0,0,0,0,0,0,0,0,97,97,99,95,104,101,95,118,50,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,50,51,50,52,0,0,0,0,102,111,114,99,101,32,116,101,114,109,105,110,97,116,105,111,110,32,119,104,101,110,32,116,104,101,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,32,116,101,114,109,105,110,97,116,101,115,0,0,0,0,84,101,108,101,99,105,110,101,32,112,97,116,116,101,114,110,32,37,115,32,121,105,101,108,100,115,32,117,112,32,116,111,32,37,100,32,102,114,97,109,101,115,32,112,101,114,32,102,114,97,109,101,44,32,112,116,115,32,97,100,118,97,110,99,101,32,102,97,99,116,111,114,58,32,37,100,47,37,100,10,0,0,0,0,0,0,0,0,99,51,115,0,0,0,0,0,37,102,32,37,102,32,37,102,0,0,0,0,0,0,0,0,109,105,110,118,97,108,0,0,32,37,48,56,88,0,0,0,97,117,116,111,0,0,0,0,102,105,101,108,100,0,0,0,114,103,98,53,54,53,98,101,0,0,0,0,0,0,0,0,68,97,114,107,79,108,105,118,101,71,114,101,101,110,0,0,60,105,110,116,54,52,62,0,104,121,112,111,116,0,0,0,68,82,0,0,0,0,0,0,100,101,115,99,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,102,111,114,109,97,116,0,0,0,0,0,0,83,87,82,101,115,97,109,112,108,101,114,0,0,0,0,0,73,116,97,108,105,99,0,0,80,77,95,76,105,115,98,111,110,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,87,65,86,0,0,0,97,97,99,95,104,101,0,0,108,116,114,116,95,115,117,114,109,105,120,108,101,118,0,0,108,116,114,116,95,115,117,114,109,105,120,108,101,118,0,0,98,97,112,32,37,100,32,105,115,32,105,110,118,97,108,105,100,32,105,110,32,112,108,97,105,110,32,65,67,45,51,10,0,0,0,0,0,0,0,0,112,99,109,95,115,50,52,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,109,111,110,111,32,119,105,116,104,32,67,80,69,10,0,0,117,110,107,32,98,105,116,32,49,10,0,0,0,0,0,0,101,100,32,100,101,99,111,100,101,32,102,108,97,103,115,0,109,101,100,105,117,109,95,99,111,110,116,114,97,115,116,0,32,37,117,46,32,67,111,100,101,98,111,111,107,32,115,101,116,117,112,32,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,0,77,97,105,110,0,0,0,0,112,97,99,107,101,116,115,105,122,101,0,0,0,0,0,0,80,114,111,118,105,100,101,100,32,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,44,32,110,101,101,100,115,32,116,111,32,98,101,32,37,100,10,0,0,0,99,104,97,110,110,101,108,109,97,112,0,0,0,0,0,0,112,105,110,108,105,103,104,116,0,0,0,0,0,0,0,0,86,101,114,116,105,99,97,108,68,97,116,117,109,71,101,111,75,101,121,0,0,0,0,0,97,114,116,105,115,116,0,0,91,108,97,118,99,32,114,99,93,32,114,101,113,117,101,115,116,101,100,32,98,105,116,114,97,116,101,58,32,37,100,32,98,112,115,32,32,101,120,112,101,99,116,101,100,32,98,105,116,114,97,116,101,58,32,37,100,32,98,112,115,10,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,83,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,34,37,115,34,32,109,97,116,99,104,101,100,32,97,32,37,115,32,115,116,114,101,97,109,44,99,117,114,114,101,110,116,108,121,32,117,110,115,117,112,112,111,114,116,101,100,32,98,121,32,108,105,98,97,118,102,105,108,116,101,114,10,0,105,110,112,117,116,95,112,114,101,115,101,114,118,101,100,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,49,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,10,0,0,0,0,0,0,0,61,0,0,0,0,0,0,0,84,101,120,116,117,114,101,32,83,112,97,116,105,97,108,32,76,97,121,101,114,32,115,116,97,114,116,0,0,0,0,0,87,105,100,116,104,32,111,114,32,72,101,105,103,104,116,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,116,111,32,98,101,32,109,117,108,116,105,112,108,105,101,115,32,111,102,32,52,48,57,54,10,97,100,100,32,39,45,115,116,114,105,99,116,32,37,100,39,32,105,102,32,121,111,117,32,119,97,110,116,32,116,111,32,117,115,101,32,116,104,101,109,32,97,110,121,119,97,121,46,10,0,0,0,0,0,0,112,115,0,0,0,0,0,0,69,120,116,114,97,99,116,105,110,103,32,37,100,45,99,104,97,110,110,101,108,32,100,111,119,110,109,105,120,32,40,48,120,37,108,108,120,41,32,102,114,111,109,32,115,117,98,115,116,114,101,97,109,32,37,100,46,32,70,117,114,116,104,101,114,32,115,117,98,115,116,114,101,97,109,115,32,119,105,108,108,32,98,101,32,115,107,105,112,112,101,100,46,10,0,0,100,101,99,111,100,101,95,115,111,115,58,32,97,99,47,100,99,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,74,80,69,71,32,50,48,48,48,32,100,105,103,105,116,97,108,32,99,105,110,101,109,97,32,50,75,0,0,0,0,0,92,70,0,0,0,0,0,0,105,108,108,101,103,97,108,32,100,99,32,37,100,32,97,116,32,37,100,32,37,100,10,0,112,112,115,95,116,99,95,111,102,102,115,101,116,95,100,105,118,50,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,112,111,115,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,65,86,67,58,32,110,97,108,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,108,101,118,105,110,115,111,110,0,0,0,0,0,0,0,0,87,114,111,110,103,32,115,105,122,105,110,103,32,111,114,32,109,105,115,115,105,110,103,32,115,105,122,101,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,0,100,115,117,114,101,120,95,109,111,100,101,0,0,0,0,0,73,110,118,97,108,105,100,32,76,70,69,32,118,97,108,117,101,58,32,37,100,10,0,0,80,77,95,71,114,101,101,110,119,105,99,104,0,0,0,0,97,97,99,95,108,116,112,0,69,114,114,111,114,32,119,104,101,110,32,112,97,114,115,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,97,110,103,108,101,32,99,111,109,109,97,110,100,10,0,0,0,0,0,0,0,70,76,86,32,47,32,83,111,114,101,110,115,111,110,32,83,112,97,114,107,32,47,32,83,111,114,101,110,115,111,110,32,72,46,50,54,51,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,100,101,102,97,117,108,116,32,97,114,101,115,97,109,112,108,101,32,102,105,108,116,101,114,32,111,112,116,105,111,110,115,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,83,101,116,116,105,110,103,32,39,37,115,39,32,116,111,32,118,97,108,117,101,32,39,37,115,39,10,0,0,0,0,0,80,117,110,107,0,0,0,0,52,50,48,80,49,50,0,0,50,0,0,0,0,0,0,0,104,97,108,102,32,120,49,58,37,100,32,120,50,58,37,100,32,121,49,58,37,100,32,121,50,58,37,100,32,109,97,120,95,109,97,115,107,95,115,105,122,101,58,37,100,10,0,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,115,116,97,116,115,32,102,105,108,101,32,37,115,58,32,37,115,10,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,83,112,104,101,114,101,0,0,97,97,99,95,115,115,114,0,105,119,0,0,0,0,0,0,112,99,109,95,115,49,54,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,52,52,49,48,48,0,0,0,112,97,110,105,99,0,0,0,48,0,0,0,0,0,0,0,115,105,110,103,101,114,0,0,120,58,37,102,32,120,105,58,37,100,32,121,58,37,102,32,121,105,58,37,100,10,0,0,115,45,62,110,98,95,115,116,114,101,97,109,115,62,48,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,0,0,0,0,0,97,97,99,95,108,111,119,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,102,114,97,103,109,101,110,116,115,32,107,101,112,116,32,105,110,32,116,104,101,32,109,97,110,105,102,101,115,116,0,0,0,0,0,0,0,0,50,50,52,48,48,48,0,0,97,108,108,95,115,116,114,101,110,103,116,104,0,0,0,0,115,101,116,32,115,101,103,109,101,110,116,32,115,112,108,105,116,32,116,105,109,101,32,112,111,105,110,116,115,0,0,0,89,67,98,67,114,45,52,58,52,58,52,0,0,0,0,0,109,97,120,95,102,105,108,101,95,115,105,122,101,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,118,105,100,101,111,47,120,45,109,106,112,101,103,0,0,0,69,108,108,105,112,115,101,95,79,83,85,57,49,65,0,0,97,97,99,95,109,97,105,110,0,0,0,0,0,0,0,0,97,108,0,0,0,0,0,0,112,99,109,95,115,49,54,98,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,97,108,0,0,0,0,0,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,98,58,97,0,0,0,0,0,112,114,105,110,116,32,115,112,101,99,105,102,105,99,32,100,101,98,117,103,32,105,110,102,111,0,0,0,0,0,0,0,114,95,102,114,97,109,101,95,114,97,116,101,0,0,0,0,108,117,116,114,103,98,0,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,115,117,98,32,100,101,115,99,114,105,112,116,111,114,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,0,118,97,114,105,97,98,108,101,32,37,115,0,0,0,0,0,109,112,101,103,116,115,95,109,50,116,115,95,109,111,100,101,0,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,79,83,85,56,54,70,0,0,117,110,107,110,111,119,110,0,80,67,77,32,90,111,114,107,0,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,51,50,55,54,56,48,0,0,105,110,116,108,95,116,104,114,101,115,0,0,0,0,0,0,102,114,97,103,95,107,101,121,102,114,97,109,101,0,0,0,100,105,115,99,0,0,0,0,115,0,0,0,0,0,0,0,83,117,98,116,105,116,108,101,32,112,97,99,107,101,116,115,32,109,117,115,116,32,104,97,118,101,32,97,32,112,116,115,10,0,0,0,0,0,0,0,70,108,117,115,104,105,110,103,32,99,108,117,115,116,101,114,32,97,116,32,111,102,102,115,101,116,32,37,108,108,117,32,98,121,116,101,115,10,0,0,83,66,82,0,0,0,0,0,69,108,108,105,112,115,101,95,71,69,77,95,49,48,67,0,112,114,111,102,105,108,101,0,112,99,109,95,122,111,114,107,0,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,104,105,115,116,111,103,114,97,109,46,99,0,0,0,0,0,0,101,120,114,0,0,0,0,0,98,117,102,115,105,122,101,0,67,111,118,101,114,32,40,102,114,111,110,116,41,0,0,0,84,104,101,32,109,97,120,105,109,117,109,32,97,109,111,117,110,116,32,98,121,32,119,104,105,99,104,32,116,104,101,32,102,105,108,116,101,114,32,119,105,108,108,32,99,104,97,110,103,101,32,97,110,121,32,111,110,101,32,112,105,120,101,108,46,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,73,103,110,111,114,105,110,103,32,109,101,116,97,100,97,116,97,32,102,111,114,32,37,115,10,0,0,0,0,0,0,0,115,98,115,0,0,0,0,0,101,110,99,111,100,101,114,115,0,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,87,71,83,95,56,52,0,0,65,32,115,116,114,105,110,103,32,100,101,115,99,114,105,98,105,110,103,32,100,101,115,105,114,101,100,32,111,117,116,112,117,116,32,102,114,97,109,101,114,97,116,101,0,0,0,0,110,117,109,98,101,114,32,111,102,32,109,97,99,114,111,98,108,111,99,107,32,114,111,119,115,32,97,116,32,116,104,101,32,98,111,116,116,111,109,32,119,104,105,99,104,32,97,114,101,32,115,107,105,112,112,101,100,0,0,0,0,0,0,0,80,67,77,32,68,45,67,105,110,101,109,97,32,97,117,100,105,111,32,115,105,103,110,101,100,32,50,52,45,98,105,116,0,0,0,0,0,0,0,0,112,105,120,95,102,109,116,115,0,0,0,0,0,0,0,0,109,105,110,114,97,116,101,0,84,104,105,115,32,102,105,108,101,32,104,97,115,32,98,101,101,110,32,103,101,110,101,114,97,116,101,100,32,98,121,32,97,32,116,111,116,97,108,108,121,32,98,114,111,107,101,110,32,109,117,120,101,114,46,10,0,0,0,0,0,0,0,0,98,102,102,0,0,0,0,0,73,68,51,0,0,0,0,0,115,101,116,112,116,115,0,0,118,105,100,101,111,0,0,0,37,100,58,37,100,58,37,100,37,99,37,100,0,0,0,0,115,101,116,32,119,105,100,116,104,0,0,0,0,0,0,0,108,105,98,97,118,117,116,105,108,47,114,97,110,100,111,109,95,115,101,101,100,46,99,0,69,108,108,105,112,115,101,95,87,97,114,95,79,102,102,105,99,101,0,0,0,0,0,0,115,107,105,112,95,98,111,116,116,111,109,0,0,0,0,0,112,99,109,95,115,50,52,100,97,117,100,0,0,0,0,0,121,117,118,52,50,50,112,0,109,97,120,114,97,116,101,0,99,98,114,0,0,0,0,0,98,108,111,99,107,120,32,97,110,100,32,98,108,111,99,107,121,32,115,101,116,116,105,110,103,115,32,109,117,115,116,32,98,101,32,112,111,119,101,114,32,111,102,32,116,119,111,10,0,0,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,97,98,99,100,101,102,0,0,102,105,101,108,100,95,116,121,112,101,0,0,0,0,0,0,98,108,97,99,107,0,0,0,115,101,116,32,109,111,108,100,32,99,111,108,111,114,0,0,73,102,32,121,111,117,32,119,97,110,116,32,116,111,32,104,101,108,112,44,32,117,112,108,111,97,100,32,97,32,115,97,109,112,108,101,32,111,102,32,116,104,105,115,32,102,105,108,101,32,116,111,32,102,116,112,58,47,47,117,112,108,111,97,100,46,102,102,109,112,101,103,46,111,114,103,47,77,80,108,97,121,101,114,47,105,110,99,111,109,105,110,103,47,32,97,110,100,32,99,111,110,116,97,99,116,32,116,104,101,32,102,102,109,112,101,103,45,100,101,118,101,108,32,109,97,105,108,105,110,103,32,108,105,115,116,46,10,0,0,0,0,0,0,97,98,115,40,100,115,116,95,108,105,110,101,115,105,122,101,41,32,62,61,32,98,121,116,101,119,105,100,116,104,0,0,82,73,80,69,77,68,50,53,54,0,0,0,0,0,0,0,101,113,117,97,108,105,122,101,114,0,0,0,0,0,0,0,115,109,112,116,101,49,55,48,109,0,0,0,0,0,0,0,111,117,116,0,0,0,0,0,77,105,115,115,105,110,103,32,39,41,39,32,111,114,32,116,111,111,32,109,97,110,121,32,97,114,103,115,32,105,110,32,39,37,115,39,10,0,0,0,73,110,116,101,114,110,97,108,32,98,117,103,44,32,115,104,111,117,108,100,32,110,111,116,32,104,97,118,101,32,104,97,112,112,101,110,101,100,0,0,105,110,112,117,116,32,104,111,114,105,122,111,110,116,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,83,116,114,117,118,101,95,49,56,54,48,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,109,97,99,114,111,98,108,111,99,107,32,114,111,119,115,32,97,116,32,116,104,101,32,116,111,112,32,119,104,105,99,104,32,97,114,101,32,115,107,105,112,112,101,100,0,0,41,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,111,117,116,37,100,0,0,0,100,101,115,99,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,49,49,53,48,48,48,48,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,37,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,97,115,32,105,110,112,117,116,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,0,0,0,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,69,79,70,10,0,102,97,115,116,32,98,105,108,105,110,101,97,114,0,0,0,48,0,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,32,110,111,116,32,97,118,97,105,108,97,98,108,101,32,97,116,32,116,104,105,115,32,115,97,109,112,108,105,110,103,32,114,97,116,101,44,32,117,115,105,110,103,32,116,114,105,97,110,103,117,108,97,114,32,104,112,32,100,105,116,104,101,114,10,0,109,97,120,118,97,108,0,0,108,111,119,0,0,0,0,0,111,115,114,0,0,0,0,0,33,115,45,62,32,105,110,95,99,104,95,108,97,121,111,117,116,32,124,124,32,105,110,32,45,62,99,104,95,99,111,117,110,116,32,61,61,32,97,118,95,103,101,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,95,110,98,95,99,104,97,110,110,101,108,115,40,115,45,62,32,105,110,95,99,104,95,108,97,121,111,117,116,41,0,0,0,0,0,0,0,66,117,116,116,101,114,119,111,114,116,104,32,102,105,108,116,101,114,32,99,117,114,114,101,110,116,108,121,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,108,111,119,45,112,97,115,115,32,102,105,108,116,101,114,32,109,111,100,101,10,0,0,0,0,0,0,0,0,105,99,99,95,112,97,114,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,115,45,62,108,97,115,116,95,112,105,99,116,117,114,101,91,105,93,45,62,100,97,116,97,91,48,93,32,33,61,32,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,45,62,100,97,116,97,91,48,93,0,0,0,0,0,0,109,97,114,107,32,109,97,105,110,32,105,110,112,117,116,32,97,115,32,97,32,112,114,101,45,112,114,111,99,101,115,115,101,100,32,105,110,112,117,116,32,97,110,100,32,97,99,116,105,118,97,116,101,32,99,108,101,97,110,32,115,111,117,114,99,101,32,105,110,112,117,116,32,115,116,114,101,97,109,0,114,103,98,52,56,108,101,0,68,97,114,107,77,97,103,101,110,116,97,0,0,0,0,0,60,105,110,116,62,0,0,0,84,85,80,76,84,89,80,69,0,0,0,0,0,0,0,0,114,97,110,100,111,109,0,0,100,111,119,110,109,105,120,32,108,101,102,116,0,0,0,0,101,120,112,101,114,105,109,101,110,116,97,108,0,0,0,0,100,115,116,95,102,111,114,109,97,116,0,0,0,0,0,0,115,45,62,100,105,116,104,101,114,46,110,111,105,115,101,46,99,104,95,99,111,117,110,116,32,61,61,32,112,114,101,111,117,116,45,62,99,104,95,99,111,117,110,116,0,0,0,0,51,0,0,0,0,0,0,0,115,45,62,113,117,97,114,116,101,114,95,115,97,109,112,108,101,61,61,48,32,124,124,32,115,45,62,113,117,97,114,116,101,114,95,115,97,109,112,108,101,61,61,49,0,0,0,0,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,10,0,66,111,108,100,0,0,0,0,69,108,108,105,112,115,101,95,80,108,101,115,115,105,115,95,49,56,49,55,0,0,0,0,120,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,119,97,118,0,0,0,115,107,105,112,95,116,111,112,0,0,0,0,0,0,0,0,76,116,47,82,116,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,76,116,47,82,116,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,101,114,114,111,114,32,105,110,32,98,105,116,32,97,108,108,111,99,97,116,105,111,110,10,0,0,0,0,0,0,0,0,112,99,109,95,117,50,52,98,101,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,98,97,110,100,115,32,40,37,100,41,32,101,120,99,101,101,100,115,32,108,105,109,105,116,32,40,37,100,41,46,10,0,0,0,0,0,0,0,83,112,101,99,105,97,108,32,109,111,100,101,115,32,115,117,112,112,111,114,116,0,0,0,118,108,99,32,108,101,110,103,116,104,32,111,118,101,114,102,108,111,119,10,0,0,0,0,87,97,114,110,105,110,103,32,77,86,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,0,82,101,100,117,99,101,100,32,115,97,109,112,108,105,110,103,32,114,97,116,101,0,0,0,32,37,115,32,61,32,37,120,10,0,0,0,0,0,0,0,108,105,110,101,97,114,95,99,111,110,116,114,97,115,116,0,86,111,114,98,105,115,32,116,105,109,101,32,100,111,109,97,105,110,32,116,114,97,110,115,102,111,114,109,32,100,97,116,97,32,110,111,110,122,101,114,111,46,32,10,0,0,0,0,83,105,109,112,108,101,0,0,49,56,0,0,0,0,0,0,33,97,102,113,45,62,102,114,97,109,101,95,99,111,117,110,116,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,103,97,105,110,32,108,111,99,97,116,105,111,110,58,32,99,104,61,37,100,44,32,115,98,61,37,100,44,32,112,111,115,61,37,100,44,32,118,97,108,61,37,100,10,0,0,0,0,110,98,95,115,97,109,112,108,101,115,32,40,37,100,41,32,33,61,32,102,114,97,109,101,95,115,105,122,101,32,40,37,100,41,32,40,97,118,99,111,100,101,99,95,101,110,99,111,100,101,95,97,117,100,105,111,50,41,10,0,0,0,0,0,92,99,37,49,91,92,125,93,37,110,0,0,0,0,0,0,112,104,111,101,110,105,120,0,86,101,114,116,105,99,97,108,67,105,116,97,116,105,111,110,71,101,111,75,101,121,0,0,10,0,0,0,0,0,0,0,44,32,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,97,120,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,110,111,32,101,110,100,32,116,97,103,32,102,111,117,110,100,46,32,105,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,46,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,97,100,112,99,109,95,109,115,0,0,0,0,0,0,0,0,116,111,111,98,105,103,32,60,61,32,52,48,0,0,0,0,112,99,109,95,115,49,54,108,101,0,0,0,0,0,0,0,100,105,100,32,110,111,116,32,109,97,116,99,104,32,97,110,121,32,115,116,114,101,97,109,0,0,0,0,0,0,0,0,79,114,105,32,120,44,32,65,118,103,32,120,44,32,70,105,110,32,120,44,32,79,114,105,32,121,44,32,65,118,103,32,121,44,32,70,105,110,32,121,44,32,79,114,105,32,97,110,103,108,101,44,32,65,118,103,32,97,110,103,108,101,44,32,70,105,110,32,97,110,103,108,101,44,32,79,114,105,32,122,111,111,109,44,32,65,118,103,32,122,111,111,109,44,32,70,105,110,32,122,111,111,109,10,0,0,0,0,0,0,0,0,97,108,119,97,121,115,32,116,114,121,32,97,32,109,98,32,119,105,116,104,32,109,118,61,60,48,44,48,62,0,0,0,109,115,109,112,101,103,52,118,49,0,0,0,0,0,0,0,97,100,112,99,109,95,99,116,0,0,0,0,0,0,0,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,49,54,10,0,0,0,0,0,0,63,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,83,116,105,108,108,32,84,101,120,116,117,114,101,32,79,98,106,101,99,116,32,115,116,97,114,116,0,0,0,0,0,0,87,105,100,116,104,32,47,32,72,101,105,103,104,116,32,105,115,32,105,110,118,97,108,105,100,32,102,111,114,32,77,80,69,71,50,10,0,0,0,0,83,0,0,0,0,0,0,0,69,120,116,114,97,99,116,105,110,103,32,37,100,45,99,104,97,110,110,101,108,32,100,111,119,110,109,105,120,32,102,114,111,109,32,115,117,98,115,116,114,101,97,109,32,37,100,46,32,70,117,114,116,104,101,114,32,115,117,98,115,116,114,101,97,109,115,32,119,105,108,108,32,98,101,32,115,107,105,112,112,101,100,46,10,0,0,0,65,86,82,110,32,105,110,116,101,114,108,97,99,101,100,32,112,105,99,116,117,114,101,32,109,97,114,107,101,114,32,102,111,117,110,100,10,0,0,0,98,0,0,0,0,0,0,0,74,80,69,71,32,50,48,48,48,32,110,111,32,99,111,100,101,115,116,114,101,97,109,32,114,101,115,116,114,105,99,116,105,111,110,115,0,0,0,0,32,37,53,100,0,0,0,0,112,112,115,95,98,101,116,97,95,111,102,102,115,101,116,95,100,105,118,50,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,107,101,121,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,98,0,0,0,0,0,0,0,108,116,114,116,95,115,117,114,114,111,117,110,100,95,109,105,120,95,108,101,118,101,108,0,110,97,108,95,108,101,110,103,116,104,95,115,105,122,101,0,102,105,120,101,100,0,0,0,85,110,107,110,111,119,110,32,70,111,117,114,67,67,58,32,37,88,10,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,37,100,0,0,76,111,47,82,111,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,76,70,69,83,99,97,108,101,73,110,100,101,120,32,108,97,114,103,101,114,32,116,104,97,110,32,49,50,55,0,0,0,69,108,108,105,112,115,101,95,78,87,76,95,49,48,68,0,98,108,111,99,107,120,32,97,110,100,32,98,108,111,99,107,121,32,115,101,116,116,105,110,103,115,32,109,117,115,116,32,98,101,32,112,111,119,101,114,32,111,102,32,116,119,111,10,0,0,0,0,0,0,0,0,110,115,115,101,32,119,101,105,103,104,116,0,0,0,0,0,100,105,102,102,32,62,61,32,48,32,38,38,32,100,105,102,102,32,60,61,32,49,50,48,0,0,0,0,0,0,0,0,102,108,118,49,0,0,0,0,97,114,101,115,97,109,112,108,101,95,115,119,114,95,111,112,116,115,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,0,83,111,117,108,0,0,0,0,52,52,52,80,49,48,0,0,49,53,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,52,120,109,46,99,0,0,0,0,0,0,0,0,116,114,97,110,115,112,97,114,101,110,99,121,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,119,111,114,107,32,98,117,102,102,101,114,46,10,0,0,0,0,115,101,116,32,110,111,105,115,101,32,115,105,103,109,97,32,99,111,110,115,116,97,110,116,0,0,0,0,0,0,0,0,66,108,111,99,107,32,115,105,122,101,32,37,105,120,37,105,0,0,0,0,0,0,0,0,73,110,102,108,97,116,101,32,102,97,105,108,101,100,32,119,105,116,104,32,114,101,116,117,114,110,32,99,111,100,101,58,32,37,100,46,10,0,0,0,70,105,108,101,32,112,114,111,98,97,98,108,121,32,99,111,114,114,117,112,116,10,0,0,97,116,101,109,112,111,0,0,73,110,118,97,108,105,100,32,99,104,114,111,109,97,32,98,108,111,99,107,32,112,111,115,105,116,105,111,110,10,0,0,112,105,120,102,111,114,109,97,116,32,37,100,44,32,112,105,120,100,101,112,116,104,32,37,100,44,32,98,117,110,105,116,32,37,100,44,32,98,105,116,111,114,100,101,114,32,37,100,44,32,98,112,97,100,32,37,100,10,0,0,0,0,0,0,78,111,32,115,117,98,116,105,116,108,101,32,98,105,116,109,97,112,32,97,118,97,105,108,97,98,108,101,46,10,0,0,115,116,97,116,105,99,32,117,110,115,105,103,110,101,100,32,99,104,97,114,32,105,109,97,103,101,95,98,105,116,115,91,93,32,61,32,123,10,0,0,85,110,101,120,112,101,99,116,101,100,32,112,114,101,112,114,111,99,101,115,115,111,114,32,100,105,114,101,99,116,105,118,101,10,0,0,0,0,0,0,78,111,32,112,97,108,101,116,116,101,32,102,111,117,110,100,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,87,78,86,49,32,102,114,97,109,101,32,104,101,97,100,101,114,32,118,97,108,117,101,32,37,105,0,0,0,0,0,0,114,108,58,37,100,32,114,108,99,58,37,100,32,100,99,58,37,100,32,109,118,58,37,100,32,109,98,114,108,58,37,100,32,113,112,58,37,100,32,109,115,112,101,108,58,37,100,32,112,101,114,95,109,98,95,97,98,116,58,37,100,32,97,98,116,95,116,121,112,101,58,37,100,32,99,98,112,58,37,100,32,105,105,58,37,100,10,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,32,86,76,67,32,99,111,100,101,44,32,115,107,105,112,112,105,110,103,10,0,0,102,114,97,109,101,91,37,105,93,32,119,111,117,108,100,32,104,97,118,101,32,116,111,32,115,107,105,112,32,37,105,32,98,105,116,115,10,0,0,0,80,97,99,107,101,116,32,108,111,115,115,32,100,101,116,101,99,116,101,100,33,32,115,101,113,32,37,120,32,118,115,32,37,120,10,0,0,0,0,0,13,10,0,0,0,0,0,0,65,76,80,72,65,32,99,104,117,110,107,32,112,114,101,115,101,110,116,44,32,98,117,116,32,97,108,112,104,97,32,98,105,116,32,110,111,116,32,115,101,116,32,105,110,32,116,104,101,32,86,80,56,88,32,104,101,97,100,101,114,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,78,111,116,32,101,110,111,117,103,104,32,99,104,97,110,110,101,108,115,32,99,111,100,101,100,32,105,110,32,97,32,112,97,99,107,101,116,46,10,0,112,114,111,98,108,101,109,58,32,102,111,117,110,100,32,97,32,112,97,108,101,116,116,101,32,99,104,117,110,107,32,119,105,116,104,32,37,100,32,99,111,108,111,114,115,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,85,110,107,110,111,119,110,32,112,114,111,102,105,108,101,32,37,100,10,0,0,0,0,0,118,112,54,97,0,0,0,0,73,110,118,97,108,105,100,32,104,117,102,102,109,97,110,32,116,97,98,108,101,10,0,0,114,99,45,62,116,121,112,101,32,61,61,32,50,0,0,0,10,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,78,87,76,95,57,68,0,0,110,115,115,101,119,0,0,0,83,101,116,117,112,32,104,101,97,100,101,114,32,99,111,114,114,117,112,116,46,10,0,0,87,114,111,110,103,32,112,97,99,107,101,116,32,116,121,112,101,32,105,110,32,83,101,116,117,112,32,104,101,97,100,101,114,10,0,0,0,0,0,0,80,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,100,97,116,97,33,32,40,110,101,101,100,32,37,105,32,103,111,116,32,37,105,41,10,0,0,0,0,0,0,0,0,112,99,109,95,117,50,52,108,101,0,0,0,0,0,0,0,115,107,105,112,112,105,110,103,32,115,109,97,108,108,32,106,117,110,107,32,112,97,99,107,101,116,10,0,0,0,0,0,98,121,116,101,115,116,114,101,97,109,95,101,110,100,32,45,32,98,121,116,101,115,116,114,101,97,109,32,62,61,32,52,32,43,32,97,118,99,116,120,45,62,119,105,100,116,104,0,119,109,118,51,105,109,97,103,101,0,0,0,0,0,0,0,103,0,0,0,0,0,0,0,113,117,105,101,116,0,0,0,70,65,83,84,85,86,77,67,32,117,110,97,118,97,105,108,97,98,108,101,32,105,110,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2036360);
/* memory initializer */ allocate([73,110,118,97,108,105,100,32,67,111,100,101,10,0,0,0,80,97,108,101,116,116,101,32,100,97,116,97,32,114,117,110,115,32,98,101,121,111,110,100,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,0,73,103,110,111,114,101,32,108,101,110,103,116,104,0,0,0,118,52,49,48,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,44,32,99,111,110,116,105,110,117,105,110,103,32,97,110,121,119,97,121,46,10,0,0,0,0,0,105,119,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,118,50,49,48,120,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,73,78,71,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,118,50,49,48,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,10,0,0,85,110,107,110,111,119,110,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,100,10,0,0,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,102,111,114,32,102,114,97,109,101,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,73,110,99,111,110,115,105,115,116,101,110,116,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,46,10,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,100,51,100,32,102,111,114,109,97,116,32,40,37,48,56,120,41,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,105,10,0,0,0,0,0,65,102,116,101,114,32,97,118,102,111,114,109,97,116,95,102,105,110,100,95,115,116,114,101,97,109,95,105,110,102,111,40,41,32,112,111,115,58,32,37,108,108,100,32,98,121,116,101,115,32,114,101,97,100,58,37,108,108,100,32,115,101,101,107,115,58,37,100,32,102,114,97,109,101,115,58,37,100,10,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,111,114,109,97,116,10,0,114,103,0,0,0,0,0,0,73,110,118,97,108,105,100,32,113,117,97,110,116,105,115,101,114,115,32,37,100,32,47,32,37,100,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,71,111,116,32,37,105,32,116,111,107,101,110,115,32,102,111,114,32,37,105,32,98,108,111,99,107,115,10,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,32,40,37,100,41,10,0,0,0,0,0,0,0,69,110,99,111,100,101,32,115,116,114,105,112,32,102,97,105,108,101,100,10,0,0,0,0,69,108,108,105,112,115,101,95,75,114,97,115,115,111,119,115,107,121,95,49,57,52,48,0,105,110,116,114,97,95,100,99,95,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,103,115,0,0,0,0,0,0,119,105,110,100,111,119,95,115,105,122,101,0,0,0,0,0,51,53,50,120,50,52,48,0,115,101,103,109,101,110,116,95,116,105,109,101,115,0,0,0,89,67,98,67,114,45,52,58,50,58,50,0,0,0,0,0,102,114,97,109,101,95,115,105,122,101,0,0,0,0,0,0,71,101,111,103,67,105,116,97,116,105,111,110,71,101,111,75,101,121,0,0,0,0,0,0,37,115,37,51,105,0,0,0,114,97,119,32,77,74,80,69,71,32,118,105,100,101,111,0,97,115,116,114,101,97,109,115,121,110,99,0,0,0,0,0,85,110,107,110,111,119,110,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,71,101,111,84,73,70,70,32,107,101,121,32,37,100,10,0,0,112,106,115,0,0,0,0,0,0,0,0,0,0,0,0,0,84,82,85,69,86,73,83,73,79,78,45,88,70,73,76,69,46,0,0,0,0,0,0,0,66,105,116,32,100,101,112,116,104,32,37,105,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,100,97,116,97,32,116,121,112,101,58,32,37,100,10,0,0,0,0,0,0,69,108,108,105,112,115,101,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,49,57,54,55,0,0,0,0,0,0,101,114,114,111,114,32,105,110,32,66,45,102,114,97,109,101,32,112,105,99,116,117,114,101,32,105,100,10,0,0,0,0,100,99,0,0,0,0,0,0,87,0,0,0,0,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,80,67,77,32,65,45,108,97,119,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,46,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,105,110,118,97,108,105,100,32,40,99,111,109,112,114,101,115,115,105,111,110,41,32,116,121,112,101,10,0,0,0,0,0,112,99,109,95,115,50,52,98,101,0,0,0,0,0,0,0,91,98,114,93,0,0,0,0,79,110,108,121,32,83,85,66,84,73,84,76,69,95,65,83,83,32,116,121,112,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,123,92,102,115,125,0,0,0,80,67,77,32,65,45,108,97,119,0,0,0,0,0,0,0,51,53,50,120,50,56,56,0,108,105,98,97,118,99,111,100,101,99,47,115,110,111,119,101,110,99,46,99,0,0,0,0,73,110,118,97,108,105,100,32,114,101,102,10,0,0,0,0,77,74,80,69,71,32,99,111,100,101,99,32,110,111,116,32,102,111,117,110,100,10,0,0,119,97,114,110,105,110,103,58,32,98,108,111,99,107,32,99,111,117,110,116,101,114,32,106,117,115,116,32,119,101,110,116,32,110,101,103,97,116,105,118,101,32,40,116,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,41,10,0,0,0,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,98,108,97,99,107,95,109,105,110,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,102,100,101,98,117,103,0,0,56,107,53,0,0,0,0,0,73,110,99,114,101,97,115,105,110,103,32,98,108,111,99,107,32,115,105,122,101,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,119,114,111,110,103,32,99,104,97,110,110,101,108,32,110,117,109,98,101,114,10,0,0,0,105,110,99,111,114,114,101,99,116,32,112,97,108,101,116,116,101,32,99,104,97,110,103,101,32,98,108,111,99,107,32,115,105,122,101,32,37,100,10,0,62,0,0,0,0,0,0,0,101,110,99,111,100,105,110,103,32,97,115,32,50,52,32,98,105,116,115,45,112,101,114,45,115,97,109,112,108,101,10,0,67,104,97,110,103,105,110,103,32,100,105,109,101,110,115,105,111,110,115,32,116,111,32,37,100,120,37,100,10,0,0,0,73,110,99,111,114,114,101,99,116,32,77,66,32,116,121,112,101,32,99,111,100,101,10,0,115,45,62,97,108,116,95,105,110,116,101,114,95,118,108,99,32,61,61,32,48,0,0,0,100,101,102,97,117,108,116,0,82,101,97,108,86,105,100,101,111,32,50,46,48,0,0,0,119,97,114,110,105,110,103,58,32,98,108,111,99,107,32,99,111,117,110,116,101,114,32,106,117,115,116,32,119,101,110,116,32,110,101,103,97,116,105,118,101,32,40,116,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,41,10,0,0,0,0,0,87,97,114,110,105,110,103,58,32,100,105,109,101,110,115,105,111,110,115,32,110,111,116,32,112,111,119,101,114,32,111,102,32,116,119,111,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,68,105,115,112,111,115,105,116,105,111,110,0,0,0,0,0,92,78,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,114,97,119,100,101,99,46,99,0,0,0,0,0,112,84,101,120,0,0,0,0,116,111,111,32,115,104,111,114,116,32,112,97,99,107,101,116,115,32,97,114,101,32,116,111,111,32,115,104,111,114,116,33,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,73,110,118,97,108,105,100,32,101,100,105,116,32,114,97,116,101,32,40,37,100,47,37,100,41,32,102,111,117,110,100,32,111,110,32,115,116,114,101,97,109,32,35,37,100,44,32,100,101,102,97,117,108,116,105,110,103,32,116,111,32,50,53,47,49,10,0,0,0,0,0,0,97,118,114,112,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,79,80,84,73,77,73,90,69,68,0,0,0,0,0,0,0,104,97,115,32,101,114,114,111,114,115,44,32,97,110,100,32,67,32,108,105,115,116,32,105,115,32,110,111,116,32,101,109,112,116,121,0,0,0,0,0,115,97,114,0,0,0,0,0,87,114,111,110,103,32,100,97,116,97,32,105,110,32,114,101,115,101,114,118,101,100,32,102,114,97,109,101,32,97,114,101,97,46,0,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,10,0,0,0,0,0,0,118,101,110,100,111,114,32,73,68,32,115,104,111,117,108,100,32,98,101,32,52,32,98,121,116,101,115,10,0,0,0,0,105,110,118,97,108,105,100,32,100,97,116,97,32,115,105,122,101,10,0,0,0,0,0,0,83,101,116,32,116,104,101,32,102,105,114,115,116,32,112,105,100,46,0,0,0,0,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,112,105,99,116,117,114,101,32,104,101,97,100,101,114,10,0,0,69,108,108,105,112,115,101,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,49,57,50,52,0,0,0,0,0,0,109,97,99,114,111,98,108,111,99,107,32,116,104,114,101,115,104,111,108,100,0,0,0,0,112,112,109,0,0,0,0,0,98,112,112,32,124,124,32,33,112,114,101,100,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,113,117,101,117,101,46,104,0,0,0,0,0,0,0,105,110,102,108,97,116,101,73,110,105,116,32,114,101,116,117,114,110,101,100,32,101,114,114,111,114,32,37,100,10,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,68,101,99,111,100,101,100,32,37,100,32,112,105,120,101,108,115,44,32,119,104,101,110,32,108,105,110,101,32,115,104,111,117,108,100,32,98,101,32,37,100,32,112,105,120,101,108,115,10,0,0,0,0,0,0,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,80,67,88,32,100,97,116,97,32,105,115,32,99,111,114,114,117,112,116,101,100,10,0,0,109,112,50,0,0,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,71,82,65,89,83,67,65,76,69,95,65,76,80,72,65,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,84,105,109,101,115,116,97,109,112,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,112,97,115,115,101,100,0,0,0,0,0,0,77,97,107,101,32,116,104,101,32,105,110,105,116,105,97,108,32,109,111,111,118,32,97,116,111,109,32,101,109,112,116,121,32,40,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,81,117,105,99,107,84,105,109,101,41,0,0,0,116,114,97,99,107,0,0,0,44,32,100,114,111,112,112,105,110,103,32,105,116,0,0,0,69,114,114,111,114,32,115,116,114,105,112,112,105,110,103,32,97,32,87,97,118,80,97,99,107,32,112,97,99,107,101,116,46,10,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,101,114,114,111,114,32,100,117,114,105,110,103,32,108,122,111,32,100,101,99,111,109,112,114,101,115,115,105,111,110,10,0,83,79,70,32,100,97,116,97,32,100,101,99,111,100,101,32,101,114,114,111,114,10,0,0,69,108,108,105,112,115,101,95,73,110,100,111,110,101,115,105,97,110,95,78,97,116,105,111,110,97,108,95,83,112,104,101,114,111,105,100,0,0,0,0,100,105,109,101,110,115,105,111,110,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,111,117,116,112,117,116,115,0,109,98,95,116,104,114,101,115,104,111,108,100,0,0,0,0,73,110,118,97,108,105,100,32,113,117,97,108,105,116,121,32,115,101,116,116,105,110,103,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,32,43,37,100,44,37,100,10,0,0,105,109,97,103,101,50,32,100,101,109,117,120,101,114,0,0,112,99,109,95,115,50,52,108,101,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,69,110,99,111,100,101,114,32,118,101,114,115,105,111,110,32,37,100,46,37,100,10,0,0,100,112,120,0,0,0,0,0,77,83,32,82,76,69,32,119,97,114,110,105,110,103,58,32,110,111,32,101,110,100,45,111,102,45,112,105,99,116,117,114,101,32,99,111,100,101,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,99,111,109,112,97,116,105,98,108,101,32,112,105,120,101,108,32,102,111,114,109,97,116,32,39,37,115,39,32,102,111,114,32,99,111,100,101,99,32,39,37,115,39,44,32,97,117,116,111,45,115,101,108,101,99,116,105,110,103,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,0,123,92,98,49,125,0,0,0,79,116,104,101,114,32,102,105,108,101,32,105,99,111,110,0,115,116,114,105,99,116,95,103,111,112,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,97,32,112,105,99,116,117,114,101,46,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,120,112,114,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,115,116,97,116,115,0,0,100,97,116,97,115,116,114,101,97,109,0,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,0,0,0,117,110,116,101,115,116,101,100,10,0,0,0,0,0,0,0,77,80,69,71,45,49,32,118,105,100,101,111,0,0,0,0,69,108,108,105,112,115,101,95,72,101,108,109,101,114,116,95,49,57,48,54,0,0,0,0,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,109,112,101,103,118,105,100,101,111,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,100,101,99,111,100,101,114,115,0,109,97,120,98,97,110,100,115,32,37,100,32,116,111,111,32,104,105,103,104,10,0,0,0,115,117,98,98,97,110,100,32,105,110,100,101,120,32,105,110,118,97,108,105,100,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,111,111,32,109,97,110,121,32,99,111,100,101,115,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,83,116,114,101,97,109,32,112,97,114,97,109,101,116,101,114,115,32,110,111,116,32,115,101,101,110,59,32,115,107,105,112,112,105,110,103,32,102,114,97,109,101,46,10,0,0,0,0,97,118,99,116,120,45,62,99,111,100,101,99,45,62,112,114,105,118,95,100,97,116,97,95,115,105,122,101,32,61,61,32,115,105,122,101,111,102,40,77,112,101,103,69,110,99,67,111,110,116,101,120,116,41,0,0,109,111,100,101,108,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,32,39,37,115,39,10,0,0,0,0,0,0,0,100,113,116,58,32,105,110,118,97,108,105,100,32,112,114,101,99,105,115,105,111,110,10,0,115,101,99,111,110,100,95,102,105,101,108,100,95,111,102,102,115,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,82,101,115,111,108,117,116,105,111,110,32,99,104,97,110,103,105,110,103,0,0,0,0,0,92,78,0,0,0,0,0,0,87,77,47,80,105,99,116,117,114,101,0,0,0,0,0,0,100,101,102,97,117,108,116,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,105,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,108,111,99,111,46,99,0,0,0,0,0,0,0,68,101,102,108,97,116,101,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,102,111,114,99,101,32,67,70,82,32,102,111,114,32,105,110,112,117,116,32,102,114,111,109,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,108,101,110,32,37,100,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,76,97,103,97,114,105,116,104,32,102,114,97,109,101,32,116,121,112,101,58,32,37,35,120,10,0,0,0,101,120,112,114,0,0,0,0,68,97,116,97,32,111,118,101,114,114,117,110,10,0,0,0,74,80,69,71,32,112,97,114,97,109,115,58,32,73,76,86,61,37,105,32,80,116,61,37,105,32,66,80,80,61,37,105,44,32,115,99,97,110,32,61,32,37,105,10,0,0,0,0,84,114,97,110,115,102,111,114,109,115,32,109,105,115,109,97,116,99,104,44,32,77,67,84,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,108,105,98,97,118,99,111,100,101,99,47,106,112,101,103,50,48,48,48,46,99,0,0,0,86,84,0,0,0,0,0,0,97,102,116,101,114,32,100,119,116,32,45,62,32,116,105,101,114,49,10,0,0,0,0,0,115,101,116,32,102,114,101,113,117,101,110,99,121,0,0,0,67,111,108,111,114,32,112,108,97,110,101,115,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,100,32,121,101,116,10,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,71,82,83,95,49,57,56,48,0,0,0,0,0,0,0,0,109,101,95,116,104,114,101,115,104,111,108,100,0,0,0,0,32,76,79,78,71,0,0,0,109,111,116,105,111,110,32,111,102,102,115,101,116,32,60,32,48,32,40,37,100,41,10,0,83,65,67,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,112,99,109,95,117,51,50,98,101,0,0,0,0,0,0,0,97,115,104,111,119,105,110,102,111,0,0,0,0,0,0,0,69,109,112,116,121,32,109,97,99,114,111,98,108,111,99,107,32,105,110,32,97,110,32,73,78,84,82,65,32,112,105,99,116,117,114,101,33,10,0,0,114,101,102,95,109,98,32,117,110,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,115,101,116,32,99,111,109,109,97,110,100,115,0,0,0,0,73,110,118,97,108,105,100,32,86,81,95,78,85,76,76,32,99,111,100,101,58,32,37,100,10,0,0,0,0,0,0,0,80,114,105,110,116,32,104,101,108,112,32,47,32,105,110,102,111,114,109,97,116,105,111,110,32,47,32,99,97,112,97,98,105,108,105,116,105,101,115,58,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,115,113,117,97,114,101,32,114,111,111,116,0,0,0,0,0,89,85,89,50,32,111,117,116,112,117,116,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,10,0,0,0,0,0,119,114,105,116,101,111,102,102,115,101,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,66,79,84,84,79,77,32,70,105,101,108,100,10,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,114,101,102,32,119,105,116,104,32,80,79,67,32,37,100,10,0,98,108,97,99,107,0,0,0,118,112,115,95,114,101,115,101,114,118,101,100,95,116,104,114,101,101,95,50,98,105,116,115,32,105,115,32,110,111,116,32,116,104,114,101,101,10,0,0,115,101,116,32,105,110,110,101,114,32,99,111,108,111,114,105,110,103,32,109,111,100,101,0,109,111,108,100,95,99,111,108,111,114,0,0,0,0,0,0,112,108,97,110,101,32,37,100,32,45,32,99,111,114,114,101,99,116,32,0,0,0,0,0,99,104,101,99,107,101,114,98,111,97,114,100,95,108,114,0,97,98,115,95,100,105,102,102,95,112,105,99,95,110,117,109,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,105,108,108,101,103,97,108,32,98,105,116,32,100,101,112,116,104,32,118,97,108,117,101,32,40,37,100,44,32,37,100,41,10,0,0,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,102,111,114,32,97,110,32,105,110,116,114,97,32,80,67,77,32,98,108,111,99,107,46,10,0,0,0,0,0,0,0,0,108,101,102,116,32,98,108,111,99,107,32,117,110,97,118,97,105,108,97,98,108,101,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,105,110,116,114,97,32,109,111,100,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,105,110,95,104,95,99,104,114,95,112,111,115,0,0,0,0,69,108,108,105,112,115,101,95,69,118,101,114,101,115,116,95,49,56,51,48,95,77,111,100,105,102,105,101,100,0,0,0,82,101,118,101,114,116,105,110,103,32,112,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,115,32,99,104,97,110,103,101,32,100,117,101,32,116,111,32,104,101,97,100,101,114,32,100,101,99,111,100,105,110,103,32,102,97,105,108,117,114,101,10,0,0,0,0,0,97,117,116,111,100,101,116,101,99,116,32,97,32,115,117,105,116,97,98,108,101,32,110,117,109,98,101,114,32,111,102,32,116,104,114,101,97,100,115,32,116,111,32,117,115,101,0,0,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,46,102,46,112,105,99,116,95,116,121,112,101,32,61,61,32,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,95,112,116,114,45,62,102,46,112,105,99,116,95,116,121,112,101,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,112,105,99,116,117,114,101,32,100,111,101,115,110,39,116,32,104,97,118,101,32,101,105,116,104,101,114,32,103,108,111,98,97,108,32,111,114,32,108,111,99,97,108,32,112,97,108,101,116,116,101,46,10,0,0,0,71,73,70,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,54,53,53,51,53,120,54,53,53,51,53,10,0,0,0,0,0,71,46,55,50,57,68,32,64,32,54,46,52,107,98,105,116,47,115,0,0,0,0,0,0,70,114,97,109,101,32,105,110,118,97,108,105,100,108,121,32,115,112,108,105,116,44,32,109,105,115,115,105,110,103,32,112,97,114,115,101,114,63,10,0,66,105,116,114,97,116,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,121,101,116,44,32,117,115,101,32,54,46,51,107,10,0,0,0,0,109,111,100,101,0,0,0,0,82,101,113,117,101,115,116,101,100,32,116,114,101,108,108,105,115,32,118,97,108,117,101,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,46,32,85,115,105,110,103,32,37,100,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,66,105,116,115,32,112,101,114,32,71,55,50,50,32,99,111,100,101,119,111,114,100,0,0,118,99,100,0,0,0,0,0,102,111,114,99,101,32,112,97,99,107,101,100,32,82,71,66,32,105,110,32,105,110,112,117,116,32,97,110,100,32,111,117,116,112,117,116,32,40,100,101,112,114,101,99,97,116,101,100,41,0,0,0,0,0,0,0,71,50,77,50,32,97,110,100,32,71,50,77,51,32,97,114,101,32,110,111,116,32,121,101,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,70,105,101,108,100,32,115,105,122,101,32,37,105,32,105,115,32,116,111,111,32,115,109,97,108,108,32,40,114,101,113,117,105,114,101,100,32,37,105,41,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,108,101,110,103,116,104,32,37,100,32,40,115,104,111,117,108,100,32,98,101,32,37,100,41,10,0,70,76,86,32,47,32,83,111,114,101,110,115,111,110,32,83,112,97,114,107,32,47,32,83,111,114,101,110,115,111,110,32,72,46,50,54,51,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,99,51,95,115,116,114,101,110,103,116,104,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,117,110,107,95,115,105,122,101,32,61,32,37,117,32,62,32,102,114,97,109,101,95,115,105,122,101,32,61,32,37,117,10,0,0,0,0,0,0,73,110,112,117,116,32,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,44,32,105,110,112,117,116,32,109,117,115,116,32,98,101,32,109,97,120,32,52,48,57,54,120,52,48,57,54,32,33,10,0,0,0,0,0,0,97,115,101,116,114,97,116,101,0,0,0,0,0,0,0,0,49,46,50,46,53,0,0,0,105,110,118,97,108,105,100,32,105,110,32,40,37,100,41,32,111,114,32,111,117,116,32,40,37,100,41,10,0,0,0,0,101,110,99,111,100,105,110,103,32,97,115,32,50,52,32,98,105,116,115,45,112,101,114,45,115,97,109,112,108,101,10,0,104,0,0,0,0,0,0,0,115,107,105,112,105,110,103,32,118,111,114,98,105,115,32,99,111,109,109,101,110,116,10,0,99,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,119,114,97,112,32,98,117,102,102,101,114,32,111,102,32,115,105,122,101,32,37,100,0,0,0,0,0,0,110,98,95,105,110,112,117,116,115,0,0,0,0,0,0,0,115,97,109,112,108,101,47,102,114,97,109,101,32,110,117,109,98,101,114,32,105,110,118,97,108,105,100,59,32,117,116,102,56,32,102,115,99,107,101,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,70,73,67,32,72,101,97,100,101,114,46,10,0,0,0,0,37,100,10,0,0,0,0,0,83,108,105,99,101,32,112,111,105,110,116,101,114,32,99,104,97,105,110,32,98,114,111,107,101,110,10,0,0,0,0,0,86,101,114,115,105,111,110,32,37,100,0,0,0,0,0,0,70,114,97,109,101,32,35,37,100,44,32,37,115,10,0,0,68,105,109,101,110,115,105,111,110,115,32,115,104,111,117,108,100,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,116,119,111,46,10,0,0,0,0,0,0,0,0,105,110,116,101,114,32,102,114,97,109,101,32,119,105,116,104,111,117,116,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,105,110,116,114,97,32,102,114,97,109,101,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,112,112,115,114,99,0,0,0,69,45,65,67,45,51,32,69,110,99,111,100,101,114,0,0,114,103,98,52,56,98,101,0,110,111,32,115,108,105,99,101,32,100,97,116,97,10,0,0,68,97,114,107,75,104,97,107,105,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,70,111,117,110,100,32,110,111,32,68,86,32,112,114,111,102,105,108,101,32,102,111,114,32,37,105,120,37,105,32,37,115,32,118,105,100,101,111,46,32,86,97,108,105,100,32,68,86,32,112,114,111,102,105,108,101,115,32,97,114,101,58,10,0,60,102,108,97,103,115,62,0,32,48,120,37,48,54,120,64,64,37,48,50,120,32,40,48,120,37,120,44,48,120,37,120,41,0,0,0,0,0,0,0,112,97,108,101,116,116,101,58,0,0,0,0,0,0,0,0,112,114,105,110,116,0,0,0,73,110,118,97,108,105,100,32,111,98,106,101,99,116,32,108,111,99,97,116,105,111,110,33,32,37,100,45,37,100,32,37,100,45,37,100,32,37,48,50,120,10,0,0,0,0,0,0,68,76,0,0,0,0,0,0,98,105,99,117,98,105,99,32,115,112,108,105,110,101,0,0,115,111,117,114,99,101,32,102,111,114,109,97,116,0,0,0,115,45,62,105,110,46,112,108,97,110,97,114,0,0,0,0,82,76,69,32,111,118,101,114,114,101,97,100,10,0,0,0,115,101,116,32,116,104,101,32,98,111,120,32,116,104,105,99,107,110,101,115,115,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,58,32,37,100,10,0,0,0,0,0,0,68,80,88,32,109,97,114,107,101,114,32,110,111,116,32,102,111,117,110,100,10,0,0,0,66,117,102,102,101,114,32,97,117,100,105,111,32,102,114,97,109,101,115,44,32,97,110,100,32,109,97,107,101,32,116,104,101,109,32,97,99,99,101,115,115,105,98,108,101,32,116,111,32,116,104,101,32,102,105,108,116,101,114,99,104,97,105,110,46,0,0,0,0,0,0,0,115,111,108,95,100,112,99,109,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,66,97,99,107,67,111,108,111,117,114,0,0,0,0,0,0,69,108,108,105,112,115,101,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,55,53,95,68,101,102,105,110,105,116,105,111,110,0,0,0,0,118,105,100,101,111,32,112,97,114,97,109,101,116,101,114,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,68,78,120,72,68,46,32,86,97,108,105,100,32,68,78,120,72,68,32,112,114,111,102,105,108,101,115,58,10,0,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,101,100,32,37,100,44,32,99,117,114,32,102,105,101,108,100,32,37,100,10,0,0,0,0,65,68,80,67,77,32,73,77,65,32,76,111,107,105,32,83,68,76,32,77,74,80,69,71,0,0,0,0,0,0,0,0,116,104,114,101,97,100,115,0,108,116,114,116,95,99,109,105,120,108,101,118,0,0,0,0,108,116,114,116,95,99,109,105,120,108,101,118,0,0,0,0,68,101,108,97,121,32,102,114,97,109,101,32,111,118,101,114,102,108,111,119,10,0,0,0,100,101,108,116,97,32,98,105,116,32,97,108,108,111,99,97,116,105,111,110,32,115,116,114,97,116,101,103,121,32,114,101,115,101,114,118,101,100,10,0,66,105,116,100,101,112,116,104,32,103,114,101,97,116,101,114,32,116,104,97,110,32,56,10,0,0,0,0,0,0,0,0,112,99,109,95,117,51,50,108,101,0,0,0,0,0,0,0,100,101,99,111,100,101,95,98,97,110,100,95,116,121,112,101,115,58,32,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,0,67,79,80,89,0,0,0,0,112,116,114,32,111,118,101,114,102,108,111,119,32,105,110,32,114,101,97,100,95,104,117,102,102,109,97,110,95,116,97,98,108,101,115,10,0,0,0,0,112,101,97,107,95,99,98,32,60,61,32,48,0,0,0,0,101,100,32,115,97,109,112,108,101,32,98,105,116,32,100,101,112,116,104,0,0,0,0,0,108,105,103,104,116,101,114,0,37,100,32,98,105,116,115,32,108,101,102,116,32,105,110,32,112,97,99,107,101,116,32,37,88,10,0,0,0,0,0,0,102,108,111,111,114,48,32,100,101,99,58,32,98,111,111,107,110,117,109,98,101,114,32,116,111,111,32,104,105,103,104,33,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,109,111,100,101,32,37,100,10,0,0,0,0,0,0,0,0,103,111,116,32,97,32,98,117,102,102,101,114,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,119,104,101,110,32,37,100,32,119,101,114,101,32,101,120,112,101,99,116,101,100,10,0,0,0,0,0,0,0,111,100,100,32,115,112,114,105,116,101,115,32,115,117,112,112,111,114,116,0,0,0,0,0,111,114,32,115,101,116,32,97,32,102,114,97,109,101,114,97,116,101,32,119,105,116,104,32,34,45,114,32,120,120,120,34,46,10,0,0,0,0,0,0,101,114,114,111,114,32,100,117,114,105,110,103,32,122,108,105,98,32,100,101,99,111,109,112,114,101,115,115,105,111,110,10,0,0,0,0,0,0,0,0,65,115,112,101,99,116,58,32,37,105,58,37,105,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,89,85,86,32,98,121,116,101,32,111,114,100,101,114,33,10,0,0,0,0,102,114,97,109,101,32,115,117,98,112,97,99,107,101,116,32,115,105,122,101,32,116,111,116,97,108,32,62,32,97,118,99,116,120,45,62,98,108,111,99,107,95,97,108,105,103,110,33,10,0,0,0,0,0,0,0,109,111,114,101,32,115,97,109,112,108,101,115,32,116,104,97,110,32,102,114,97,109,101,32,115,105,122,101,32,40,97,118,99,111,100,101,99,95,101,110,99,111,100,101,95,97,117,100,105,111,50,41,10,0,0,0,111,118,101,114,108,97,121,0,86,101,114,116,105,99,97,108,67,83,84,121,112,101,71,101,111,75,101,121,0,0,0,0,73,110,118,97,108,105,100,32,71,101,111,84,73,70,70,32,107,101,121,32,37,100,10,0,102,105,108,116,101,114,95,115,105,122,101,32,37,32,50,32,61,61,32,49,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,97,116,99,104,101,100,32,111,110,108,121,32,97,108,114,101,97,100,121,32,117,115,101,100,32,115,116,114,101,97,109,115,0,0,0,0,0,0,0,109,118,48,0,0,0,0,0,105,108,108,101,103,97,108,32,77,86,32,99,111,100,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,77,80,69,71,45,50,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,49,54,51,56,51,120,49,54,51,56,51,10,0,0,32,0,0,0,0,0,0,0,77,101,115,104,32,79,98,106,101,99,116,32,80,108,97,110,101,32,115,116,97,114,116,0,79,110,108,121,32,72,105,103,104,40,49,41,32,97,110,100,32,52,58,50,58,50,40,48,41,32,112,114,111,102,105,108,101,115,32,115,117,112,112,111,114,116,32,52,58,50,58,50,32,99,111,108,111,114,32,115,97,109,112,108,105,110,103,10,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,83,117,98,115,116,114,101,97,109,32,109,105,110,32,99,104,97,110,110,101,108,32,99,97,110,110,111,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,109,97,120,32,99,104,97,110,110,101,108,46,10,0,0,0,0,0,0,115,45,62,112,105,99,116,117,114,101,95,112,116,114,32,61,61,32,115,45,62,112,105,99,116,117,114,101,0,0,0,0,74,80,69,71,32,50,48,48,48,32,99,111,100,101,115,116,114,101,97,109,32,114,101,115,116,114,105,99,116,105,111,110,32,49,0,0,0,0,0,0,92,67,0,0,0,0,0,0,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,104,101,105,103,104,116,115,46,10,0,0,112,114,101,118,95,115,101,108,101,99,116,101,100,95,110,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,112,101,103,118,105,100,101,111,95,120,118,109,99,0,0,105,115,32,97,118,99,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,115,119,97,112,112,101,100,32,98,117,102,102,101,114,46,10,0,0,0,0,0,68,105,116,104,101,114,32,116,121,112,101,0,0,0,0,0,105,32,62,61,32,115,105,122,101,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,77,105,115,115,105,110,103,32,99,104,97,110,110,101,108,32,108,105,115,116,10,0,0,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,108,111,97,100,105,110,103,32,112,97,108,101,116,116,101,10,0,0,0,108,111,114,111,95,115,117,114,109,105,120,108,101,118,0,0,115,116,99,32,48,120,37,48,50,120,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,111,102,102,115,101,116,32,37,100,32,100,117,114,105,110,103,32,67,57,51,32,100,101,99,111,100,105,110,103,10,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,32,108,101,110,103,116,104,10,0,0,74,111,105,110,116,32,115,116,101,114,101,111,32,99,111,100,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,69,108,108,105,112,115,101,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,54,55,95,68,101,102,105,110,105,116,105,111,110,0,0,0,0,101,120,112,101,99,116,101,100,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,10,0,0,0,0,0,0,101,114,114,111,114,0,0,0,110,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,40,37,100,32,60,32,37,100,41,44,32,116,114,121,105,110,103,32,116,111,32,100,101,99,111,100,101,32,97,110,121,119,97,121,10,0,0,0,0,0,73,110,116,101,108,32,72,46,50,54,51,0,0,0,0,0,100,101,102,97,117,108,116,32,115,99,97,108,101,32,102,105,108,116,101,114,32,111,112,116,105,111,110,115,0,0,0,0,110,98,95,99,111,100,101,115,32,43,32,49,32,60,61,32,40,115,105,122,101,111,102,40,108,111,99,97,108,98,117,102,41,32,47,32,115,105,122,101,111,102,40,40,108,111,99,97,108,98,117,102,41,91,48,93,41,41,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,105,100,102,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,85,110,107,110,111,119,110,32,98,108,111,99,107,32,116,121,112,101,32,37,100,10,0,0,70,114,97,109,101,32,108,97,114,103,101,114,32,116,104,97,110,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,78,111,32,111,112,116,105,111,110,32,110,97,109,101,32,110,101,97,114,32,39,37,115,39,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,66,97,115,115,0,0,0,0,0,0,0,24,65,80,82,71,65,80,82,71,48,48,48,49,0,0,0,0,0,0,0,0,108,111,119,114,101,115,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,32,119,105,116,104,32,114,97,119,118,105,100,101,111,10,0,0,0,52,50,50,80,49,48,0,0,97,115,101,116,110,115,97,109,112,108,101,115,0,0,0,0,80,108,101,97,115,101,32,112,114,101,102,105,120,32,116,97,114,103,101,116,32,119,105,116,104,32,34,112,97,108,45,34,44,32,34,110,116,115,99,45,34,32,111,114,32,34,102,105,108,109,45,34,44,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,105,122,101,60,61,48,120,55,102,102,102,102,102,102,102,32,38,38,32,112,32,45,32,112,107,116,45,62,100,97,116,97,32,62,61,32,115,105,122,101,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,117,110,105,116,32,101,120,116,101,110,115,105,111,110,0,0,74,83,32,109,111,110,111,32,83,111,117,110,100,32,85,110,105,116,32,105,100,32,33,61,32,51,46,10,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,108,111,99,107,32,97,108,105,103,110,46,0,0,0,0,0,0,0,0,99,111,100,101,100,32,99,111,101,102,102,32,112,97,116,116,101,114,110,32,100,97,109,97,103,101,100,10,0,0,0,0,79,110,108,121,32,83,85,66,84,73,84,76,69,95,65,83,83,32,116,121,112,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,65,83,83,32,112,97,99,107,101,116,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2046600);
/* memory initializer */ allocate([108,105,98,97,118,99,111,100,101,99,47,97,112,101,100,101,99,46,99,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,114,101,110,100,105,116,105,111,110,32,112,97,114,97,109,101,116,101,114,0,85,110,107,110,111,119,110,32,111,112,99,111,100,101,0,0,69,110,99,111,117,110,116,101,114,101,100,32,97,32,98,97,100,32,111,114,32,99,111,114,114,117,112,116,101,100,32,102,114,97,109,101,10,0,0,0,78,111,116,101,58,32,108,105,98,111,112,101,110,99,111,114,101,95,97,109,114,110,98,32,115,117,112,112,111,114,116,115,32,100,116,120,10,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,100,97,116,97,46,10,0,0,67,114,101,97,116,105,111,110,84,105,109,101,0,0,0,0,109,111,110,111,0,0,0,0,99,104,37,100,0,0,0,0,68,105,115,99,111,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,102,108,97,99,95,112,105,99,116,117,114,101,46,99,0,0,0,0,0,0,65,117,116,104,111,114,0,0,73,68,51,0,0,0,0,0,97,117,116,104,111,114,0,0,69,108,108,105,112,115,101,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,51,55,95,65,100,106,117,115,116,109,101,110,116,0,0,0,0,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,119,104,105,99,104,32,115,104,111,117,108,100,32,98,101,32,108,111,97,100,101,100,32,105,110,116,111,32,116,104,101,32,114,99,32,98,117,102,102,101,114,32,98,101,102,111,114,101,32,100,101,99,111,100,105,110,103,32,115,116,97,114,116,115,0,65,68,84,83,32,102,114,97,109,101,32,115,105,122,101,32,116,111,111,32,108,97,114,103,101,58,32,37,117,32,40,109,97,120,32,37,100,41,10,0,97,117,116,111,45,105,110,115,101,114,116,105,110,103,32,102,105,108,116,101,114,32,39,37,115,39,32,98,101,116,119,101,101,110,32,116,104,101,32,102,105,108,116,101,114,32,39,37,115,39,32,97,110,100,32,116,104,101,32,102,105,108,116,101,114,32,39,37,115,39,10,0,1,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,117,114,114,101,110,116,95,116,114,97,99,107,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,112,99,109,95,115,51,50,98,101,0,0,0,0,0,0,0,89,85,86,52,77,80,69,71,50,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,58,32,37,100,10,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,120,109,118,46,99,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,100,101,116,101,114,109,105,110,101,32,110,111,114,109,32,40,80,65,76,47,78,84,83,67,47,78,84,83,67,45,70,105,108,109,41,32,102,111,114,32,116,97,114,103,101,116,46,10,0,0,0,0,0,0,70,105,110,105,115,104,101,100,32,115,112,108,105,116,116,105,110,103,32,116,104,101,32,99,111,109,109,97,110,100,108,105,110,101,46,10,0,0,0,0,114,101,112,111,114,116,101,100,32,102,105,108,101,32,108,101,110,103,116,104,32,40,48,120,37,108,108,120,41,32,101,120,99,101,101,100,115,32,110,117,109,98,101,114,32,111,102,32,97,118,97,105,108,97,98,108,101,32,115,101,99,116,111,114,115,32,40,48,120,37,108,108,120,41,10,0,0,0,0,0,105,103,110,111,114,101,95,108,101,110,103,116,104,0,0,0,114,101,109,105,120,101,114,0,100,101,102,97,117,108,116,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,99,111,100,101,99,32,112,97,114,97,109,101,116,101,114,115,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,40,37,115,41,58,32,37,115,10,67,111,110,115,105,100,101,114,32,105,110,99,114,101,97,115,105,110,103,32,116,104,101,32,118,97,108,117,101,32,102,111,114,32,116,104,101,32,39,97,110,97,108,121,122,101,100,117,114,97,116,105,111,110,39,32,97,110,100,32,39,112,114,111,98,101,115,105,122,101,39,32,111,112,116,105,111,110,115,10,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,83,71,65,95,49,57,50,50,0,0,0,0,114,99,95,105,110,105,116,95,111,99,99,117,112,97,110,99,121,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,115,109,111,111,116,104,32,115,116,114,101,97,109,105,110,103,32,109,117,120,101,114,0,0,78,84,83,67,0,0,0,0,115,101,116,32,97,112,112,114,111,120,105,109,97,116,105,111,110,32,118,97,108,117,101,32,117,115,101,100,32,102,111,114,32,116,104,101,32,115,101,103,109,101,110,116,32,116,105,109,101,115,0,0,0,0,0,0,89,67,98,67,114,45,52,58,50,58,48,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,97,114,101,115,97,109,112,108,101,0,0,0,0,0,0,0,109,106,112,101,103,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,65,114,99,0,110,111,105,115,101,32,114,101,100,117,99,116,105,111,110,0,97,108,97,119,0,0,0,0,112,99,109,95,115,51,50,108,101,0,0,0,0,0,0,0,97,108,97,119,0,0,0,0,80,65,76,0,0,0,0,0,109,97,120,32,109,101,109,111,114,121,32,117,115,101,100,32,102,111,114,32,98,117,102,102,101,114,105,110,103,32,114,101,97,108,45,116,105,109,101,32,102,114,97,109,101,115,0,0,105,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,100,32,102,111,114,32,105,110,102,111,32,112,97,99,107,101,116,10,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,115,116,114,101,97,109,10,0,0,0,0,0,0,78,85,77,95,76,79,79,80,83,0,0,0,0,0,0,0,109,112,101,103,116,115,95,115,116,97,114,116,95,112,105,100,0,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,82,71,83,0,110,114,0,0,0,0,0,0,80,67,77,32,65,45,108,97,119,32,47,32,71,46,55,49,49,32,65,45,108,97,119,0,65,115,115,117,109,105,110,103,32,37,115,32,102,111,114,32,116,97,114,103,101,116,46,10,0,0,0,0,0,0,0,0,101,109,112,116,121,95,109,111,111,118,0,0,0,0,0,0,110,101,116,119,111,114,107,0,83,117,98,116,105,116,108,101,32,100,117,114,97,116,105,111,110,32,114,101,100,117,99,101,100,32,102,114,111,109,32,37,100,32,116,111,32,37,100,37,115,10,0,0,0,0,0,0,37,42,91,94,44,93,44,37,100,58,37,100,58,37,100,37,42,99,37,100,44,37,100,58,37,100,58,37,100,37,42,99,37,100,0,0,0,0,0,0,86,95,81,85,73,67,75,84,73,77,69,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,73,71,78,0,109,97,120,105,109,117,109,32,76,97,103,114,97,110,103,101,32,102,97,99,116,111,114,32,40,86,66,82,41,0,0,0,103,105,102,0,0,0,0,0,112,99,109,95,97,108,97,119,0,0,0,0,0,0,0,0,106,50,107,0,0,0,0,0,102,105,108,109,45,0,0,0,51,50,120,51,50,32,112,105,120,101,108,115,32,39,102,105,108,101,32,105,99,111,110,39,0,0,0,0,0,0,0,0,97,117,100,105,111,99,111,100,101,99,105,100,0,0,0,0,97,112,104,97,115,101,114,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,66,101,110,111,105,116,0,0,0,0,0,0,108,109,97,120,0,0,0,0,80,67,77,32,109,117,45,108,97,119,32,47,32,71,46,55,49,49,32,109,117,45,108,97,119,0,0,0,0,0,0,0,100,101,99,111,100,101,114,115,0,0,0,0,0,0,0,0,110,116,115,99,45,0,0,0,109,97,107,101,114,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,58,102,114,97,109,101,95,114,97,116,101,61,37,100,47,37,100,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,54,54,95,77,105,99,104,105,103,97,110,0,0,0,0,109,105,110,105,109,117,109,32,76,97,103,114,97,110,103,101,32,102,97,99,116,111,114,32,40,86,66,82,41,0,0,0,112,99,109,95,109,117,108,97,119,0,0,0,0,0,0,0,112,97,108,45,0,0,0,0,115,113,117,0,0,0,0,0,115,101,116,32,99,111,108,111,114,0,0,0,0,0,0,0,105,110,110,101,114,0,0,0,98,108,97,99,107,0,0,0,97,112,97,100,0,0,0,0,105,110,112,117,116,32,118,101,114,116,105,99,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,54,54,0,0,0,0,0,108,109,105,110,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,50,52,48,48,48,47,49,48,48,49,0,0,0,0,0,0,114,103,98,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,110,111,105,115,101,32,115,101,101,100,0,0,0,0,0,105,110,32,97,110,100,32,111,117,116,32,109,117,115,116,32,98,101,32,100,101,102,105,110,101,100,10,0,0,0,0,0,97,110,117,108,108,0,0,0,119,0,0,0,0,0,0,0,51,45,119,97,121,32,109,97,116,99,104,32,43,32,52,116,104,47,53,116,104,32,109,97,116,99,104,101,115,32,111,110,32,99,111,109,98,101,100,32,40,112,47,99,47,110,32,43,32,117,47,98,41,0,0,0,118,100,112,97,117,95,118,99,49,0,0,0,0,0,0,0,68,97,114,107,71,114,101,101,110,0,0,0,0,0,0,0,37,45,49,50,115,32,0,0,112,111,119,0,0,0,0,0,116,111,112,32,98,97,99,107,32,114,105,103,104,116,0,0,115,105,110,99,0,0,0,0,115,114,99,95,102,111,114,109,97,116,0,0,0,0,0,0,115,45,62,109,105,100,98,117,102,46,99,104,95,99,111,117,110,116,32,61,61,32,115,45,62,111,117,116,46,99,104,95,99,111,117,110,116,0,0,0,115,101,116,32,99,111,108,111,114,32,111,102,32,116,104,101,32,98,111,120,0,0,0,0,117,115,101,32,79,112,101,110,67,76,32,102,105,108,116,101,114,105,110,103,32,99,97,112,97,98,105,108,105,116,105,101,115,0,0,0,0,0,0,0,80,114,105,109,97,114,121,67,111,108,111,117,114,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,53,56,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,115,109,106,112,101,103,0,0,0,0,0,0,0,0,115,99,101,110,101,32,99,104,97,110,103,101,32,116,104,114,101,115,104,111,108,100,0,0,76,111,47,82,111,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,76,111,47,82,111,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,110,101,119,32,99,111,117,112,108,105,110,103,32,108,101,97,107,32,105,110,102,111,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,0,112,99,109,95,117,56,0,0,105,110,118,97,108,105,100,32,98,97,110,100,32,116,121,112,101,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,97,116,97,32,105,110,32,114,101,97,100,95,104,117,102,102,109,97,110,95,116,97,98,108,101,115,10,0,0,0,0,32,37,115,32,61,32,37,100,10,0,0,0,0,0,0,0,105,110,99,114,101,97,115,101,95,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,84,104,101,111,114,97,32,99,111,110,102,105,103,32,112,97,99,107,101,116,58,32,37,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,108,111,111,114,32,116,121,112,101,33,10,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,101,120,116,114,97,100,97,116,97,10,0,0,0,51,48,48,48,48,47,49,48,48,49,0,0,0,0,0,0,68,105,115,112,108,97,121,32,100,105,109,101,110,115,105,111,110,115,58,32,37,105,120,37,105,10,0,0,0,0,0,0,101,120,116,101,110,100,101,100,95,100,97,116,97,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,0,111,114,0,0,0,0,0,0,80,114,111,106,83,116,114,97,105,103,104,116,86,101,114,116,80,111,108,101,76,111,110,103,71,101,111,75,101,121,0,0,71,101,111,84,73,70,70,32,107,101,121,32,100,105,114,101,99,116,111,114,121,32,98,117,102,102,101,114,32,115,104,111,114,116,101,114,32,116,104,97,110,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,114,101,113,117,101,115,116,101,100,32,98,105,116,114,97,116,101,32,105,115,32,116,111,111,32,108,111,119,10,0,0,0,83,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,34,37,115,34,32,37,115,10,0,0,0,0,0,0,0,117,115,101,32,103,109,99,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,77,80,69,71,45,49,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,52,48,57,53,120,52,48,57,53,10,0,0,0,0,124,0,0,0,0,0,0,0,77,101,115,104,32,79,98,106,101,99,116,32,115,116,97,114,116,0,0,0,0,0,0,0,83,101,116,32,112,114,111,102,105,108,101,32,97,110,100,32,108,101,118,101,108,10,0,0,80,0,0,0,0,0,0,0,37,100,32,99,104,97,110,110,101,108,115,32,40,109,111,114,101,32,116,104,97,110,32,116,104,101,32,109,97,120,105,109,117,109,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,100,101,99,111,100,101,114,41,0,0,0,0,82,67,84,0,0,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,74,80,69,71,32,50,48,48,48,32,99,111,100,101,115,116,114,101,97,109,32,114,101,115,116,114,105,99,116,105,111,110,32,48,0,0,0,0,0,0,123,92,117,48,125,0,0,0,37,100,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,119,105,100,116,104,115,46,10,0,0,0,115,101,108,101,99,116,101,100,95,110,0,0,0,0,0,0,68,101,99,111,100,105,110,103,32,110,97,108,32,117,110,105,116,32,37,100,32,37,100,32,102,114,111,109,32,104,118,99,67,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,99,112,98,95,99,111,117,110,116,32,37,100,32,105,110,118,97,108,105,100,10,0,0,0,105,115,95,97,118,99,0,0,76,80,67,32,97,108,103,111,114,105,116,104,109,0,0,0,51,50,45,98,105,116,32,117,110,115,105,103,110,101,100,32,105,110,116,0,0,0,0,0,76,111,47,82,111,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,73,110,118,97,108,105,100,32,98,105,116,32,97,108,108,111,99,97,116,105,111,110,32,105,110,100,101,120,10,0,0,0,69,108,108,105,112,115,101,95,66,101,115,115,101,108,95,78,97,109,105,98,105,97,0,0,115,99,95,116,104,114,101,115,104,111,108,100,0,0,0,0,104,50,54,51,105,0,0,0,115,99,97,108,101,95,115,119,115,95,111,112,116,115,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,65,108,116,101,114,110,82,111,99,107,0,0,0,0,0,0,52,50,48,80,49,48,0,0,50,53,0,0,0,0,0,0,69,108,108,105,112,115,101,95,66,101,115,115,101,108,95,77,111,100,105,102,105,101,100,0,115,116,114,101,97,109,95,99,111,100,101,99,95,116,97,103,0,0,0,0,0,0,0,0,112,99,109,95,115,56,0,0,100,114,111,112,0,0,0,0,84,114,97,105,108,105,110,103,32,111,112,116,105,111,110,115,32,119,101,114,101,32,102,111,117,110,100,32,111,110,32,116,104,101,32,99,111,109,109,97,110,100,108,105,110,101,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,37,115,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,102,111,114,32,37,115,58,32,37,115,10,0,0,0,0,120,109,118,45,62,118,105,100,101,111,46,115,116,114,101,97,109,95,105,110,100,101,120,32,60,32,115,45,62,110,98,95,115,116,114,101,97,109,115,0,116,114,117,110,99,97,116,101,100,32,102,105,108,101,10,0,73,110,118,97,108,105,100,32,87,97,118,80,97,99,107,32,112,97,99,107,101,116,46,10,0,0,0,0,0,0,0,0,87,65,86,32,100,101,109,117,120,101,114,0,0,0,0,0,82,69,77,88,0,0,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,32,104,101,97,100,101,114,46,10,0,0,66,108,97,99,107,109,97,110,32,119,105,110,100,111,119,0,97,109,105,120,0,0,0,0,87,77,47,80,105,99,116,117,114,101,0,0,0,0,0,0,100,101,99,111,100,105,110,103,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,102,97,105,108,101,100,10,0,0,69,108,108,105,112,115,101,95,66,101,115,115,101,108,95,49,56,52,49,0,0,0,0,0,117,115,101,32,98,101,115,116,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,0,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,48,0,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,112,97,115,115,116,104,114,111,117,103,104,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,112,115,58,32,37,100,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,100,101,99,58,32,37,100,0,0,0,0,0,0,0,115,101,103,109,101,110,116,95,116,105,109,101,95,100,101,108,116,97,0,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,118,111,114,98,105,115,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,99,111,110,102,105,103,117,114,97,116,105,111,110,61,37,115,13,10,0,0,115,98,103,95,100,101,109,117,120,101,114,0,0,0,0,0,118,116,116,0,0,0,0,0,239,187,191,87,69,66,86,84,84,0,0,0,0,0,0,0,32,32,105,110,103,108,105,115,104,58,32,37,115,10,0,0,114,97,119,32,77,80,69,71,45,52,32,118,105,100,101,111,0,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,65,117,115,116,114,97,108,105,97,110,95,78,97,116,105,111,110,97,108,95,83,112,104,101,114,111,105,100,0,0,0,0,117,115,101,32,102,101,119,101,115,116,32,98,105,116,115,0,117,98,0,0,0,0,0,0,112,99,109,95,117,49,54,98,101,0,0,0,0,0,0,0,117,98,0,0,0,0,0,0,118,102,114,0,0,0,0,0,119,54,52,0,0,0,0,0,114,116,98,117,102,115,105,122,101,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,83,111,110,121,32,87,97,118,101,54,52,0,0,0,0,0,109,97,116,101,114,105,97,108,32,116,114,97,99,107,32,37,100,58,32,68,97,116,97,68,101,102,105,110,105,116,105,111,110,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,76,79,79,80,95,77,79,68,69,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,102,105,114,115,116,32,112,105,100,32,111,102,32,116,104,101,32,80,77,84,46,0,0,0,69,108,108,105,112,115,101,95,65,105,114,121,95,77,111,100,105,102,105,101,100,95,49,56,52,57,0,0,0,0,0,0,98,105,116,115,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,99,102,114,0,0,0,0,0,77,97,108,102,111,114,109,101,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,97,109,101,114,103,101,0,0,109,97,120,105,109,117,109,32,109,111,111,118,32,115,105,122,101,32,115,111,32,105,116,32,99,97,110,32,98,101,32,112,108,97,99,101,100,32,97,116,32,116,104,101,32,98,101,103,105,110,0,0,0,0,0,0,116,114,97,99,107,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,101,112,105,115,111,100,101,95,105,100,0,0,0,0,0,0,67,114,101,97,116,105,118,101,32,86,111,105,99,101,0,0,87,114,105,116,105,110,103,32,98,108,111,99,107,32,97,116,32,111,102,102,115,101,116,32,37,108,108,117,44,32,115,105,122,101,32,37,100,44,32,112,116,115,32,37,108,108,100,44,32,100,117,114,97,116,105,111,110,32,37,100,10,0,0,0,77,117,108,116,105,112,108,101,32,102,114,97,109,101,115,32,105,110,32,97,32,112,97,99,107,101,116,32,102,114,111,109,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,65,95,81,85,73,67,75,84,73,77,69,0,0,0,0,0,117,110,107,110,111,119,110,32,112,97,99,107,101,116,32,116,121,112,101,32,37,100,10,0,79,110,108,121,32,87,77,86,51,32,105,115,32,97,99,99,101,112,116,101,100,33,10,0,69,108,108,105,112,115,101,95,65,105,114,121,95,49,56,51,48,0,0,0,0,0,0,0,117,115,101,32,109,98,99,109,112,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,114,97,119,0,0,0,0,0,112,99,109,95,117,49,54,108,101,0,0,0,0,0,0,0,106,112,99,0,0,0,0,0,113,37,115,0,0,0,0,0,79,116,104,101,114,0,0,0,115,116,101,114,101,111,0,0,68,97,116,117,109,69,95,83,112,104,101,114,101,0,0,0,109,97,99,114,111,98,108,111,99,107,32,100,101,99,105,115,105,111,110,32,97,108,103,111,114,105,116,104,109,32,40,104,105,103,104,32,113,117,97,108,105,116,121,32,109,111,100,101,41,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,113,58,118,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,99,111,100,101,99,115,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,97,102,111,114,109,97,116,0,103,112,111,115,32,109,105,115,109,97,116,99,104,32,111,117,114,32,112,111,115,61,37,108,108,117,44,32,101,110,100,61,37,108,108,100,10,0,0,0,118,105,100,101,111,95,115,105,122,101,61,37,100,120,37,100,58,112,105,120,95,102,109,116,61,37,100,58,116,105,109,101,95,98,97,115,101,61,37,100,47,37,100,58,112,105,120,101,108,95,97,115,112,101,99,116,61,37,100,47,37,100,58,115,119,115,95,112,97,114,97,109,61,102,108,97,103,115,61,37,100,0,0,0,0,0,0,0,115,101,116,32,102,105,108,116,101,114,45,119,105,100,116,104,0,0,0,0,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,0,0,0,0,0,0,0,109,98,100,0,0,0,0,0,112,99,109,95,115,49,54,98,101,0,0,0,0,0,0,0,80,108,101,97,115,101,32,117,115,101,32,45,113,58,97,32,111,114,32,45,113,58,118,44,32,45,113,115,99,97,108,101,32,105,115,32,97,109,98,105,103,117,111,117,115,10,0,0,99,117,98,105,99,0,0,0,99,0,0,0,0,0,0,0,115,101,116,32,111,117,116,122,32,109,111,100,101,0,0,0,115,101,116,32,100,101,97,116,104,32,99,111,108,111,114,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,73,68,51,0,0,0,0,0,105,110,95,118,95,99,104,114,95,112,111,115,0,0,0,0,58,47,47,0,0,0,0,0,68,97,116,117,109,69,95,79,83,85,57,49,65,0,0,0,120,118,109,99,95,97,99,99,101,108,101,114,97,116,105,111,110,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,44,32,37,115,0,0,0,0,112,114,111,102,105,108,101,58,118,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,99,104,117,110,107,32,105,100,32,37,105,10,0,0,0,0,101,118,97,108,32,101,120,112,114,101,115,115,105,111,110,115,32,112,101,114,45,102,114,97,109,101,0,0,0,0,0,0,99,51,95,115,101,101,100,0,118,97,108,117,101,115,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,103,97,109,109,97,118,97,108,0,0,0,0,0,0,0,0,110,111,110,115,101,110,115,101,32,115,97,109,112,108,101,114,97,116,101,10,0,0,0,0,105,110,118,97,108,105,100,32,97,117,100,105,111,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,0,0,0,0,112,99,110,95,117,98,0,0,118,100,112,97,117,95,119,109,118,51,0,0,0,0,0,0,68,97,114,107,71,114,97,121,0,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,110,111,116,0,0,0,0,0,84,66,82,0,0,0,0,0,110,101,97,114,101,115,116,32,110,101,105,103,104,98,111,114,32,47,32,112,111,105,110,116,0,0,0,0,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,104,101,105,103,104,116,0,0,0,0,0,0,115,45,62,109,105,100,98,117,102,46,99,104,95,99,111,117,110,116,32,61,61,32,115,45,62,117,115,101,100,95,99,104,95,99,111,117,110,116,0,0,115,101,116,32,104,101,105,103,104,116,32,111,102,32,116,104,101,32,98,111,120,0,0,0,77,97,120,105,109,117,109,32,37,100,32,115,108,97,118,101,32,109,117,120,101,114,115,32,114,101,97,99,104,101,100,46,10,0,0,0,0,0,0,0,111,112,101,110,99,108,0,0,70,111,110,116,115,105,122,101,0,0,0,0,0,0,0,0,68,97,116,117,109,69,95,79,83,85,56,54,70,0,0,0,65,68,80,67,77,32,73,77,65,32,82,97,100,105,99,97,108,0,0,0,0,0,0,0,115,108,105,99,101,95,102,108,97,103,115,0,0,0,0,0,108,111,114,111,0,0,0,0,108,111,114,111,0,0,0,0,110,101,119,32,115,110,114,32,111,102,102,115,101,116,115,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,112,99,109,95,115,49,54,108,101,0,0,0,0,0,0,0,83,99,97,108,101,102,97,99,116,111,114,32,40,37,100,41,32,111,117,116,32,111,102,32,114,97,110,103,101,46,10,0,114,117,110,32,37,100,32,111,118,101,102,108,111,119,10,0,118,32,60,32,50,57,0,0,100,97,114,107,101,114,0,0,73,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,33,10,0,0,0,0,0,98,111,111,107,95,105,100,120,0,0,0,0,0,0,0,0,99,97,112,116,105,111,110,115,0,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,58,32,37,105,10,0,0,0,80,108,101,97,115,101,32,117,115,101,32,45,112,114,111,102,105,108,101,58,97,32,111,114,32,45,112,114,111,102,105,108,101,58,118,44,32,45,112,114,111,102,105,108,101,32,105,115,32,97,109,98,105,103,117,111,117,115,10,0,0,0,0,0,68,105,115,112,108,97,121,32,101,120,116,101,110,100,101,100,32,105,110,102,111,58,10,0,69,110,99,111,100,105,110,103,32,116,111,32,97,32,112,108,97,110,97,114,32,115,97,109,112,108,101,32,102,111,114,109,97,116,44,32,119,105,116,104,32,109,111,114,101,32,116,104,97,110,32,37,100,32,99,104,97,110,110,101,108,115,44,32,98,117,116,32,101,120,116,101,110,100,101,100,95,100,97,116,97,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,77,68,53,32,109,101,116,97,100,97,116,97,32,98,108,111,99,107,32,67,82,67,32,101,114,114,111,114,46,10,0,0,110,111,114,109,97,108,0,0,80,114,111,106,65,122,105,109,117,116,104,65,110,103,108,101,71,101,111,75,101,121,0,0,46,0,0,0,0,0,0,0,37,99,32,113,112,58,37,100,60,37,50,46,49,102,60,37,100,32,37,100,32,119,97,110,116,58,37,100,32,116,111,116,97,108,58,37,100,32,99,111,109,112,58,37,102,32,115,116,95,113,58,37,50,46,50,102,32,115,105,122,101,58,37,100,32,118,97,114,58,37,108,108,100,47,37,108,108,100,32,98,114,58,37,100,32,102,112,115,58,37,100,10,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,0,0,0,97,118,109,50,0,0,0,0,65,109,98,105,103,117,111,117,115,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,34,37,115,34,44,32,117,115,105,110,103,32,35,37,100,10,0,0,0,0,0,103,109,99,0,0,0,0,0,105,103,110,111,114,105,110,103,32,111,118,101,114,102,108,111,119,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,119,47,104,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,10,0,0,0,0,45,0,0,0,0,0,0,0,70,66,65,32,79,98,106,101,99,116,32,80,108,97,110,101,32,115,116,97,114,116,0,0,77,80,69,71,49,47,50,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,37,100,47,37,100,32,102,112,115,44,32,116,104,101,114,101,32,109,97,121,32,98,101,32,65,86,32,115,121,110,99,32,105,115,115,117,101,115,10,0,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,109,97,112,32,102,111,114,109,97,116,32,37,100,44,32,115,107,105,112,112,101,100,10,0,0,0,0,0,0,77,97,120,32,99,104,97,110,110,101,108,32,109,117,115,116,32,98,101,32,101,113,117,97,108,32,109,97,120,32,109,97,116,114,105,120,32,99,104,97,110,110,101,108,46,10,0,0,80,82,67,84,0,0,0,0,49,46,50,46,53,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,10,0,0,0,0,0,0,0,92,117,0,0,0,0,0,0,110,117,109,95,116,105,108,101,95,114,111,119,115,95,109,105,110,117,115,49,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,110,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,78,65,76,32,117,110,105,116,32,115,105,122,101,32,105,110,32,101,120,116,114,97,100,97,116,97,46,10,0,0,0,0,79,118,101,114,114,101,97,100,32,86,85,73,32,98,121,32,37,100,32,98,105,116,115,10,0,0,0,0,0,0,0,0,72,50,54,52,32,68,101,99,111,100,101,114,0,0,0,0,13,10,0,0,0,0,0,0,108,112,99,95,116,121,112,101,0,0,0,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,108,111,114,111,95,99,109,105,120,108,101,118,0,0,0,0,91,68,69,76,65,89,93,0,68,105,100,110,39,116,32,103,101,116,32,115,117,98,102,114,97,109,101,32,68,83,89,78,67,10,0,0,0,0,0,0,68,97,116,117,109,69,95,71,69,77,49,48,67,0,0,0,99,111,110,116,101,120,116,32,109,111,100,101,108,0,0,0,72,46,50,54,51,43,32,47,32,72,46,50,54,51,45,49,57,57,56,32,47,32,72,46,50,54,51,32,118,101,114,115,105,111,110,32,50,0,0,0,77,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,116,104,114,101,97,100,115,0,0,0,0,0,0,0,77,105,114,105,108,108,105,115,32,70,73,67,0,0,0,0,61,0,0,0,0,0,0,0,78,111,105,115,101,0,0,0,52,52,52,80,57,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,102,105,108,101,32,37,115,46,10,0,73,110,115,117,102,102,105,99,105,101,110,116,32,116,105,109,101,115,116,97,109,112,115,32,105,110,32,101,118,101,110,116,32,110,117,109,98,101,114,32,37,100,46,10,0,0,0,0,13,10,0,0,0,0,0,0,116,121,112,101,61,37,120,32,108,101,110,61,37,105,32,112,107,116,95,111,102,102,115,101,116,61,37,105,10,0,0,0,73,69,67,32,54,49,57,51,55,32,40,99,111,109,112,114,101,115,115,101,100,32,100,97,116,97,32,105,110,32,83,47,80,68,73,70,41,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,102,41,10,0,0,0,0,0,0,0,68,97,116,117,109,69,95,87,71,83,56,52,0,0,0,0,99,111,110,116,101,120,116,0,102,105,99,0,0,0,0,0,102,114,97,109,101,115,58,118,0,0,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,111,112,116,105,111,110,32,39,37,115,39,46,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,105,108,101,32,97,108,108,111,99,97,116,105,111,110,32,116,97,98,108,101,32,100,101,112,116,104,32,40,48,120,37,120,41,10,0,78,101,118,101,114,32,119,114,105,116,101,32,82,70,54,52,32,104,101,97,100,101,114,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,102,105,108,101,32,115,105,122,101,46,0,0,0,0,0,0,0,0,100,115,54,52,0,0,0,0,112,101,114,115,111,110,110,101,108,0,0,0,0,0,0,0,98,108,97,99,107,109,97,110,0,0,0,0,0,0,0,0,37,115,47,116,101,109,112,0,97,102,97,100,101,0,0,0,0,10,83,77,74,80,69,71,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,99,104,117,110,107,32,37,120,10,0,0,0,0,0,0,0,109,97,120,95,97,110,97,108,121,122,101,95,100,117,114,97,116,105,111,110,32,37,100,32,114,101,97,99,104,101,100,32,97,116,32,37,108,108,100,32,109,105,99,114,111,115,101,99,111,110,100,115,10,0,0,0,73,110,118,97,108,105,100,32,97,117,100,105,111,32,112,97,114,116,32,115,105,122,101,10,0,0,0,0,0,0,0,0,78,111,116,32,97,32,86,66,86,32,102,105,108,101,10,0,68,97,116,117,109,69,95,87,97,114,79,102,102,105,99,101,0,0,0,0,0,0,0,0,100,101,102,108,97,116,101,45,98,97,115,101,100,32,99,111,100,101,114,0,0,0,0,0,118,105,100,101,111,0,0,0,72,46,50,54,53,32,47,32,72,69,86,67,32,40,72,105,103,104,32,69,102,102,105,99,105,101,110,99,121,32,86,105,100,101,111,32,67,111,100,105,110,103,41,0,0,0,0,0,116,114,117,110,99,97,116,101,0,0,0,0,0,0,0,0,99,111,100,101,99,58,118,0,115,101,116,32,115,101,103,109,101,110,116,32,100,117,114,97,116,105,111,110,0,0,0,0,86,111,114,98,105,115,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,105,110,102,111,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,111,112,116,105,111,110,32,39,37,99,39,32,114,101,113,117,105,114,101,115,32,97,110,32,97,114,103,117,109,101,110,116,0,0,0,0,0,0,0,0,109,52,118,0,0,0,0,0,68,97,116,117,109,69,95,83,116,114,117,118,101,49,56,54,48,0,0,0,0,0,0,0,100,101,102,108,97,116,101,0,80,67,77,32,117,110,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,104,101,118,99,0,0,0,0,115,116,114,101,97,109,95,115,101,103,109,101,110,116,32,109,117,120,101,114,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,79,112,116,105,111,110,32,39,37,115,39,32,119,97,115,32,114,101,109,111,118,101,100,46,32,73,102,32,121,111,117,32,97,114,101,32,108,111,111,107,105,110,103,32,102,111,114,32,97,110,32,111,112,116,105,111,110,32,116,111,32,112,114,101,115,101,114,118,101,32,116,104,101,32,113,117,97,108,105,116,121,32,40,119,104,105,99,104,32,105,115,32,110,111,116,32,119,104,97,116,32,45,37,115,32,119,97,115,32,102,111,114,41,44,32,117,115,101,32,45,113,115,99,97,108,101,32,48,32,111,114,32,97,110,32,101,113,117,105,118,97,108,101,110,116,32,113,117,97,108,105,116,121,32,102,97,99,116,111,114,32,111,112,116,105,111,110,46,10,0,0,0,0,0,0,0,109,97,120,32,109,101,109,111,114,121,32,117,115,101,100,32,102,111,114,32,116,105,109,101,115,116,97,109,112,32,105,110,100,101,120,32,40,112,101,114,32,115,116,114,101,97,109,41,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,115,111,117,114,99,101,32,116,114,97,99,107,32,115,101,113,117,101,110,99,101,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,0,0,84,73,84,76,69,0,0,0,109,112,101,103,116,115,95,112,109,116,95,115,116,97,114,116,95,112,105,100,0,0,0,0,115,101,116,32,109,111,100,101,0,0,0,0,0,0,0,0,68,97,116,117,109,69,95,80,108,101,115,115,105,115,49,56,49,55,0,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,0,0,0,0,0,114,117,110,45,108,101,110,103,116,104,32,99,111,100,101,114,0,0,0,0,0,0,0,0,72,78,77,32,52,32,118,105,100,101,111,0,0,0,0,0,83,111,102,100,101,99,0,0,103,111,112,95,116,105,109,101,99,111,100,101,0,0,0,0,67,111,109,112,108,101,116,101,108,121,32,115,105,108,101,110,116,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,109,111,111,118,95,115,105,122,101,0,0,0,0,0,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,115,104,111,119,0,0,0,0,60,83,89,78,67,0,0,0,37,108,108,100,44,37,100,44,0,0,0,0,0,0,0,0,98,101,110,99,104,58,32,37,56,108,108,117,32,37,115,32,10,0,0,0,0,0,0,0,79,110,108,121,32,49,120,49,32,99,104,114,111,109,97,32,98,108,111,99,107,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,32,65,98,111,114,116,101,100,33,10,0,97,101,99,104,111,0,0,0,65,95,77,83,47,65,67,77,0,0,0,0,0,0,0,0,68,97,116,117,109,69,95,78,87,76,49,48,68,0,0,0,114,108,101,0,0,0,0,0,42,63,91,93,123,125,0,0,104,110,109,52,118,105,100,101,111,0,0,0,0,0,0,0,106,112,50,0,0,0,0,0,109,101,116,97,100,97,116,97,58,103,0,0,0,0,0,0,116,105,116,108,101,45,115,111,114,116,0,0,0,0,0,0,80,97,99,107,101,116,32,115,105,122,101,32,37,100,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,109,97,120,32,82,84,80,32,112,97,121,108,111,97,100,32,115,105,122,101,32,37,100,10,0,0,0,82,83,79,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,109,111,110,111,10,0,85,110,107,110,111,119,110,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,0,85,110,107,110,111,119,110,32,99,111,100,101,99,32,116,97,103,58,32,37,115,10,0,0,97,117,100,105,111,115,97,109,112,108,101,115,105,122,101,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,114,109,44,114,97,0,0,0,68,97,116,117,109,69,95,78,87,76,57,68,0,0,0,0,114,97,119,32,40,110,111,32,101,110,99,111,100,105,110,103,41,0,0,0,0,0,0,0,87,101,98,80,0,0,0,0,116,105,109,101,99,111,100,101,61,37,115,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,116,114,101,97,109,32,116,121,112,101,32,37,48,56,120,10,0,0,0,37,46,52,100,45,37,46,50,100,45,37,46,50,100,32,37,115,0,0,0,0,0,0,0,99,111,100,101,99,115,0,0,68,105,103,105,116,97,108,32,115,105,103,110,97,116,117,114,101,32,100,101,116,101,99,116,101,100,33,10,0,0,0,0,114,101,113,117,101,115,116,101,100,32,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,40,37,100,41,32,97,110,100,32,97,99,116,117,97,108,108,121,32,115,116,111,114,101,100,32,40,37,100,41,32,100,105,102,102,101,114,10,0,0,0,97,100,101,108,97,121,0,0,116,114,117,110,99,97,116,101,100,32,102,105,108,101,10,0,67,97,110,110,111,116,32,99,111,110,110,101,99,116,32,118,105,100,101,111,32,102,105,108,116,101,114,32,116,111,32,97,117,100,105,111,32,105,110,112,117,116,10,0,0,0,0,0,119,105,100,116,104,0,0,0,99,111,109,109,101,110,116,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,100,10,0,0,0,0,0,0,0,0,68,97,116,117,109,69,95,75,114,97,115,115,111,119,115,107,121,49,57,54,48,0,0,0,114,97,119,0,0,0,0,0,119,101,98,112,0,0,0,0,115,101,116,32,116,104,101,32,115,105,110,101,32,102,114,101,113,117,101,110,99,121,0,0,54,48,0,0,0,0,0,0,118,115,116,97,116,115,95,37,48,50,100,37,48,50,100,37,48,50,100,46,108,111,103,0,99,117,98,0,0,0,0,0,78,111,32,115,117,99,104,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,115,46,10,0,0,0,0,0,0,115,101,116,32,108,101,118,101,108,0,0,0,0,0,0,0,111,117,116,122,0,0,0,0,100,101,97,116,104,95,99,111,108,111,114,0,0,0,0,0,112,99,0,0,0,0,0,0,68,97,116,117,109,69,95,73,110,116,101,114,110,97,116,105,111,110,97,108,49,57,54,55,0,0,0,0,0,0,0,0,97,114,105,116,104,109,101,116,105,99,32,99,111,100,101,114,0,0,0,0,0,0,0,0,71,111,50,77,101,101,116,105,110,103,0,0,0,0,0,0,97,99,111,110,118,101,114,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2056840);
/* memory initializer */ allocate([0,0,0,0,0,0,0,0,102,105,108,116,101,114,58,118,0,0,0,0,0,0,0,0,102,114,97,109,101,0,0,0,99,50,102,0,0,0,0,0,111,117,116,0,0,0,0,0,97,100,120,0,0,0,0,0,99,108,105,112,0,0,0,0,51,45,119,97,121,32,109,97,116,99,104,32,40,112,47,99,47,110,41,0,0,0,0,0,118,100,112,97,117,95,109,112,101,103,50,0,0,0,0,0,115,101,116,32,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,68,97,114,107,71,111,108,100,101,110,82,111,100,0,0,0,32,32,37,115,37,45,49,55,115,32,0,0,0,0,0,0,100,97,116,97,0,0,0,0,115,113,114,116,0,0,0,0,116,111,112,32,98,97,99,107,32,99,101,110,116,101,114,0,76,97,110,99,122,111,115,0,100,115,116,104,0,0,0,0,33,115,45,62,114,101,115,97,109,112,108,101,0,0,0,0,115,101,116,32,119,105,100,116,104,32,111,102,32,116,104,101,32,98,111,120,0,0,0,0,66,97,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,115,101,116,32,109,111,116,105,111,110,32,115,101,97,114,99,104,32,100,101,116,97,105,108,101,100,32,108,111,103,32,102,105,108,101,32,110,97,109,101,0,0,0,0,0,0,0,0,70,111,110,116,110,97,109,101,0,0,0,0,0,0,0,0,68,97,116,117,109,69,95,73,110,116,101,114,110,97,116,105,111,110,97,108,49,57,50,52,0,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,114,97,100,0,0,0,118,97,114,105,97,98,108,101,32,108,101,110,103,116,104,32,99,111,100,101,114,32,47,32,72,117,102,102,109,97,110,32,99,111,100,101,114,0,0,0,76,116,47,82,116,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,76,116,47,82,116,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,110,101,119,32,98,105,116,32,97,108,108,111,99,97,116,105,111,110,32,105,110,102,111,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,80,97,99,107,101,116,32,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,103,50,109,0,0,0,0,0,73,102,32,121,111,117,32,104,101,97,114,100,32,97,110,32,97,117,100,105,98,108,101,32,97,114,116,105,102,97,99,116,44,32,116,104,101,114,101,32,109,97,121,32,98,101,32,97,32,98,117,103,32,105,110,32,116,104,101,32,100,101,99,111,100,101,114,46,32,67,108,105,112,112,101,100,32,110,111,105,115,101,32,103,97,105,110,32,40,37,100,32,45,62,32,37,100,41,0,0,0,0,0,0,48,32,99,111,101,102,102,10,0,0,0,0,0,0,0,0,80,86,70,49,10,0,0,0,110,117,109,95,115,102,98,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,99,114,111,115,115,95,112,114,111,99,101,115,115,0,0,0,67,111,114,114,117,112,116,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,0,70,108,111,111,114,32,48,32,98,97,114,107,32,109,97,112,32,115,105,122,101,32,105,115,32,48,46,10,0,0,0,0,82,101,97,100,32,37,105,32,98,105,116,115,32,105,110,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,37,115,58,37,99,0,0,0,80,114,111,103,114,101,115,115,105,118,101,32,83,101,103,109,101,110,116,101,100,32,70,114,97,109,101,32,109,111,100,101,58,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,121,101,116,41,10,0,0,105,110,118,97,108,105,100,32,115,116,114,101,97,109,105,100,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,112,97,99,107,101,116,32,111,102,32,115,105,122,101,32,37,108,108,100,10,0,109,105,115,115,109,97,116,99,104,105,110,103,32,115,101,99,116,111,114,95,99,111,117,110,116,10,0,0,0,0,0,0,110,101,103,97,116,105,111,110,0,0,0,0,0,0,0,0,80,114,111,106,83,99,97,108,101,65,116,67,101,110,116,101,114,71,101,111,75,101,121,0,71,101,111,84,73,70,70,95,75,101,121,95,82,101,118,105,115,105,111,110,0,0,0,0,67,97,110,110,111,116,32,40,114,101,41,97,108,108,111,99,97,116,101,32,112,97,99,107,101,116,32,98,117,102,102,101,114,10,0,0,0,0,0,0,113,32,62,32,48,46,48,0,112,99,109,95,115,49,54,98,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,34,37,115,34,10,0,0,117,115,101,32,102,105,120,101,100,32,113,115,99,97,108,101,0,0,0,0,0,0,0,0,100,99,32,111,118,101,114,102,108,111,119,43,32,67,32,113,115,99,97,108,101,58,32,37,100,47,47,10,0,0,0,0,72,46,50,54,51,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,50,48,52,56,120,49,49,53,50,10,0,0,0,0,0,43,0,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,115,105,122,101,32,45,32,109,117,108,116,105,112,108,101,32,102,114,97,109,101,115,32,105,110,32,98,117,102,102,101,114,63,10,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,115,105,122,101,32,45,32,109,117,108,116,105,112,108,101,32,102,114,97,109,101,115,32,105,110,32,98,117,102,102,101,114,63,10,0,0,0,0,0,0,70,66,65,32,79,98,106,101,99,116,32,115,116,97,114,116,0,0,0,0,0,0,0,0,77,80,69,71,49,47,50,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,37,100,47,37,100,32,102,112,115,10,0,0,0,0,0,113,112,58,37,100,32,102,99,58,37,50,100,37,50,100,37,50,100,37,50,100,32,37,115,32,37,115,32,37,115,32,37,115,32,37,115,32,100,99,58,37,100,32,112,115,116,114,117,99,116,58,37,100,32,102,100,99,116,58,37,100,32,99,109,118,58,37,100,32,113,116,121,112,101,58,37,100,32,105,118,108,99,58,37,100,32,114,102,102,58,37,100,32,37,115,10,0,0,0,0,0,0,0,0,77,97,120,32,109,97,116,114,105,120,32,99,104,97,110,110,101,108,32,99,97,110,110,111,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,37,100,46,10,0,0,85,110,107,110,111,119,110,32,102,108,97,103,32,115,101,116,32,40,37,100,41,46,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,78,111,32,99,111,109,109,97,110,100,32,115,112,101,99,105,102,105,101,100,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,0,0,0,0,123,92,117,49,125,0,0,0,83,69,80,66,50,32,109,97,114,107,101,114,32,109,105,115,115,105,110,103,10,0,0,0,110,117,109,95,116,105,108,101,95,99,111,108,117,109,110,115,95,109,105,110,117,115,49,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,110,97,108,95,117,110,105,116,95,116,121,112,101,58,32,37,100,44,32,110,117,104,95,108,97,121,101,114,95,105,100,58,32,37,100,116,101,109,112,111,114,97,108,95,105,100,58,32,37,100,10,0,0,0,0,0,67,108,105,112,112,105,110,103,32,105,108,108,101,103,97,108,32,110,117,109,95,114,101,111,114,100,101,114,95,102,114,97,109,101,115,32,37,100,10,0,67,65,86,76,67,32,52,58,52,58,52,0,0,0,0,0,76,80,67,32,99,111,101,102,102,105,99,105,101,110,116,32,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,99,111,109,112,114,101,115,115,105,111,110,32,97,116,116,114,105,98,117,116,101,10,0,0,76,116,47,82,116,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,83,116,114,101,97,109,32,119,105,116,104,32,104,105,103,104,32,102,114,101,113,117,101,110,99,105,101,115,32,86,81,32,99,111,100,105,110,103,10,0,68,97,116,117,109,69,95,73,110,100,111,110,101,115,105,97,110,78,97,116,105,111,110,97,108,83,112,104,101,114,111,105,100,0,0,0,0,0,0,0,118,108,99,0,0,0,0,0,104,50,54,51,112,0,0,0,116,104,114,101,97,100,115,0,83,105,103,109,97,116,101,108,32,77,111,116,105,111,110,32,86,105,100,101,111,0,0,0,80,114,111,99,101,115,115,105,110,103,32,99,111,109,109,97,110,100,32,116,105,109,101,58,37,102,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,10,0,0,0,71,111,115,112,101,108,0,0,52,50,50,80,57,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,39,37,115,39,32,102,111,114,32,111,112,116,105,111,110,32,39,37,115,39,44,32,114,101,113,117,105,114,101,100,32,115,121,110,116,97,120,32,105,115,32,39,105,110,100,101,120,58,118,97,108,117,101,39,10,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,68,97,116,117,109,69,95,72,101,108,109,101,114,116,49,57,48,54,0,0,0,0,0,0,99,111,100,101,114,0,0,0,115,109,118,0,0,0,0,0,98,58,118,0,0,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,111,112,116,105,111,110,32,39,37,115,39,32,40,37,115,41,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,48,46,10,0,0,102,105,108,101,110,97,109,101,32,101,120,99,101,101,100,115,32,98,117,102,102,101,114,32,115,105,122,101,59,32,114,101,109,97,105,110,105,110,103,32,100,105,114,101,99,116,111,114,121,32,101,110,116,114,105,101,115,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,110,101,118,101,114,0,0,0,82,70,54,52,0,0,0,0,80,82,83,78,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,72,97,109,109,105,110,103,32,119,105,110,100,111,119,0,0,68,84,83,32,100,105,115,99,111,110,116,105,110,117,105,116,121,32,105,110,32,115,116,114,101,97,109,32,37,100,58,32,112,97,99,107,101,116,32,37,100,32,119,105,116,104,32,68,84,83,32,37,108,108,100,44,32,112,97,99,107,101,116,32,37,100,32,119,105,116,104,32,68,84,83,32,37,108,108,100,10,0,0,0,0,0,0,0,68,97,116,117,109,69,95,71,82,83,49,57,56,48,0,0,103,108,111,98,97,108,95,113,117,97,108,105,116,121,0,0,66,82,101,110,100,101,114,32,80,73,88,32,105,109,97,103,101,0,0,0,0,0,0,0,37,48,50,120,0,0,0,0,80,108,101,97,115,101,32,117,115,101,32,45,98,58,97,32,111,114,32,45,98,58,118,44,32,45,98,32,105,115,32,97,109,98,105,103,117,111,117,115,10,0,0,0,0,0,0,0,115,101,103,109,101,110,116,95,116,105,109,101,0,0,0,0,97,101,118,97,108,115,114,99,0,0,0,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,65,77,82,45,87,66,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,111,99,116,101,116,45,97,108,105,103,110,61,49,13,10,0,0,0,0,0,105,109,109,101,100,105,97,116,101,32,115,101,113,117,101,110,99,101,115,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,0,114,101,100,117,99,101,32,98,117,102,102,101,114,105,110,103,0,0,0,0,0,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,79,112,101,110,77,71,32,97,117,100,105,111,10,0,0,0,114,97,119,32,72,69,86,67,32,118,105,100,101,111,0,0,68,97,116,117,109,69,95,69,118,101,114,101,115,116,49,56,51,48,77,111,100,105,102,105,101,100,0,0,0,0,0,0,101,97,51,0,0,0,0,0,105,110,116,101,114,32,113,117,97,110,116,32,98,105,97,115,0,0,0,0,0,0,0,0,117,56,0,0,0,0,0,0,98,114,101,110,100,101,114,95,112,105,120,0,0,0,0,0,85,110,107,110,111,119,110,32,86,80,56,32,104,101,97,100,101,114,32,116,121,112,101,32,48,120,37,48,50,88,10,0,117,56,0,0,0,0,0,0,102,114,97,109,101,115,58,97,0,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,105,110,100,101,120,109,101,109,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,104,101,97,100,101,114,32,116,121,112,101,32,37,88,10,0,102,105,115,98,111,110,101,0,79,112,117,115,84,97,103,115,0,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,1,68,105,114,101,99,116,32,83,104,111,119,32,83,97,109,112,108,101,115,32,101,109,98,101,100,100,101,100,32,105,110,32,79,103,103,0,0,0,0,109,97,116,101,114,105,97,108,32,116,114,97,99,107,32,37,100,58,32,110,111,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,115,111,117,114,99,101,32,116,114,97,99,107,32,102,111,117,110,100,10,0,67,79,77,77,69,78,84,0,83,101,116,32,115,101,114,118,105,99,101,95,105,100,32,102,105,101,108,100,46,0,0,0,68,97,116,117,109,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,55,53,68,101,102,105,110,105,116,105,111,110,0,0,0,0,0,0,0,112,98,105,97,115,0,0,0,88,45,102,97,99,101,32,105,109,97,103,101,0,0,0,0,73,77,75,72,0,0,0,0,87,114,105,116,101,32,116,104,101,32,88,105,110,103,32,104,101,97,100,101,114,32,99,111,110,116,97,105,110,105,110,103,32,102,105,108,101,32,100,117,114,97,116,105,111,110,46,0,113,58,97,0,0,0,0,0,111,103,103,44,111,103,118,0,65,100,100,32,82,84,80,32,104,105,110,116,32,116,114,97,99,107,115,0,0,0,0,0,65,117,100,105,111,32,112,97,99,107,101,116,32,105,110,32,102,105,108,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,32,115,116,114,101,97,109,33,10,0,0,0,0,0,115,121,110,111,112,115,105,115,0,0,0,0,0,0,0,0,68,105,97,108,111,103,117,101,58,32,37,100,44,0,0,0,37,108,108,100,0,0,0,0,77,117,108,116,105,112,108,101,32,107,101,121,102,114,97,109,101,115,32,119,105,116,104,32,115,97,109,101,32,80,84,83,10,0,0,0,0,0,0,0,86,95,77,83,47,86,70,87,47,70,79,85,82,67,67,0,68,97,116,117,109,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,54,55,68,101,102,105,110,105,116,105,111,110,0,0,0,0,0,0,0,105,110,116,114,97,32,113,117,97,110,116,32,98,105,97,115,0,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,120,102,97,99,101,0,0,0,106,50,99,0,0,0,0,0,99,111,100,101,99,58,97,0,84,83,79,84,0,0,0,0,114,101,109,111,118,101,32,97,108,108,32,102,114,97,103,109,101,110,116,115,32,119,104,101,110,32,102,105,110,105,115,104,101,100,0,0,0,0,0,0,97,117,100,105,111,115,97,109,112,108,101,114,97,116,101,0,65,108,108,111,99,97,116,101,32,115,116,114,101,97,109,115,32,97,99,99,111,114,100,105,110,103,32,116,111,32,116,104,101,32,111,110,77,101,116,97,68,97,116,97,32,97,114,114,97,121,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,68,97,116,117,109,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,51,55,65,100,106,117,115,116,109,101,110,116,0,0,0,0,0,0,0,105,98,105,97,115,0,0,0,67,80,105,65,32,118,105,100,101,111,32,102,111,114,109,97,116,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,78,101,120,116,32,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,122,101,114,111,10,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,77,88,70,0,0,0,0,0,37,42,51,115,37,42,91,32,93,37,51,115,37,42,91,32,93,37,50,100,37,42,91,32,93,37,56,115,37,42,91,32,93,37,52,100,0,0,0,0,65,83,70,32,69,120,116,101,110,100,101,100,32,67,111,110,116,101,110,116,32,69,110,99,114,121,112,116,105,111,110,0,109,120,102,95,100,49,48,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,102,111,114,109,97,116,115,0,0,98,117,102,102,101,114,0,0,115,108,111,112,101,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,83,71,65,49,57,50,50,0,0,0,0,0,0,0,108,105,109,105,116,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,114,97,110,103,101,32,40,49,48,50,51,32,102,111,114,32,68,105,118,88,32,112,108,97,121,101,114,41,0,0,0,0,0,0,0,99,112,105,97,0,0,0,0,37,108,108,117,0,0,0,0,113,117,97,100,114,97,116,105,99,0,0,0,0,0,0,0,73,110,100,101,120,83,73,68,32,37,105,32,115,101,103,109,101,110,116,32,97,116,32,37,108,108,100,32,73,110,100,101,120,69,110,116,114,121,65,114,114,97,121,32,116,111,111,32,115,109,97,108,108,10,0,0,108,101,118,101,108,0,0,0,73,110,118,97,108,105,100,32,97,117,100,105,111,95,100,97,116,97,95,115,105,122,101,32,40,37,100,41,32,111,114,32,102,114,97,109,101,115,95,99,111,117,110,116,32,40,37,100,41,10,0,0,0,0,0,0,115,101,116,32,119,104,105,116,101,32,109,111,100,101,0,0,119,104,105,116,101,0,0,0,120,115,99,97,108,101,61,37,102,32,121,115,99,97,108,101,61,37,102,32,100,109,97,120,61,37,102,10,0,0,0,0,97,117,100,105,111,32,99,111,109,112,114,101,115,115,105,111,110,32,40,102,111,114,109,97,116,32,37,105,41,0,0,0,116,118,0,0,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,65,114,99,0,0,0,109,101,95,114,97,110,103,101,0,0,0,0,0,0,0,0,65,118,105,100,32,65,86,73,32,67,111,100,101,99,0,0,85,110,107,110,111,119,110,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,58,32,37,115,10,0,0,0,0,0,101,118,97,108,32,101,120,112,114,101,115,115,105,111,110,115,32,111,110,99,101,32,100,117,114,105,110,103,32,105,110,105,116,105,97,108,105,122,97,116,105,111,110,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,102,108,97,103,115,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,32,111,114,32,115,101,103,109,101,110,116,95,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,32,97,110,100,32,73,32,99,97,110,110,111,116,32,99,97,108,99,117,108,97,116,101,32,116,104,101,109,32,102,114,111,109,32,111,116,104,101,114,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,105,110,0,0,0,0,0,0,99,111,108,111,114,0,0,0,118,97,108,91,37,100,93,91,37,100,93,32,61,32,37,100,10,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,13,10,0,0,0,0,0,0,109,106,112,103,0,0,0,0,112,99,110,0,0,0,0,0,118,100,112,97,117,95,109,112,101,103,49,0,0,0,0,0,68,97,114,107,67,121,97,110,0,0,0,0,0,0,0,0,32,32,32,32,32,37,45,49,53,115,32,0,0,0,0,0,116,114,117,110,99,0,0,0,69,120,112,101,114,105,109,101,110,116,97,108,32,102,101,97,116,117,114,101,0,0,0,0,84,66,67,0,0,0,0,0,71,97,117,115,115,105,97,110,0,0,0,0,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,119,105,100,116,104,0,0,0,0,0,0,0,111,117,116,45,62,99,104,95,99,111,117,110,116,32,61,61,32,105,110,45,62,99,104,95,99,111,117,110,116,0,0,0,115,101,116,32,118,101,114,116,105,99,97,108,32,112,111,115,105,116,105,111,110,32,111,102,32,116,104,101,32,116,111,112,32,98,111,120,32,101,100,103,101,0,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,78,97,109,101,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,82,71,83,0,0,0,100,116,103,95,97,99,116,105,118,101,95,102,111,114,109,97,116,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,81,117,105,99,107,84,105,109,101,0,0,0,0,0,108,116,114,116,0,0,0,0,108,116,114,116,0,0,0,0,101,120,112,111,110,101,110,116,32,111,117,116,45,111,102,45,114,97,110,103,101,10,0,0,97,118,114,110,0,0,0,0,73,102,32,121,111,117,32,104,101,97,114,100,32,97,110,32,97,117,100,105,98,108,101,32,97,114,116,105,102,97,99,116,44,32,116,104,101,114,101,32,109,97,121,32,98,101,32,97,32,98,117,103,32,105,110,32,116,104,101,32,100,101,99,111,100,101,114,46,32,67,108,105,112,112,101,100,32,105,110,116,101,110,115,105,116,121,32,115,116,101,114,101,111,32,112,111,115,105,116,105,111,110,32,40,37,100,32,45,62,32,37,100,41,0,0,0,0,0,0,0,101,114,114,111,114,32,100,99,32,114,117,110,32,33,61,32,48,10,0,0,0,0,0,0,99,111,108,111,114,95,110,101,103,97,116,105,118,101,0,0,77,105,115,115,105,110,103,32,101,120,116,114,97,100,97,116,97,33,10,0,0,0,0,0,70,108,111,111,114,32,48,32,114,97,116,101,32,105,115,32,48,46,10,0,0,0,0,0,69,120,116,114,97,32,100,97,116,97,58,32,37,105,32,98,105,116,115,32,108,101,102,116,44,32,118,97,108,117,101,58,32,37,88,10,0,0,0,0,102,105,108,116,101,114,58,97,0,0,0,0,0,0,0,0,65,100,118,97,110,99,101,100,32,80,114,111,102,105,108,101,32,108,101,118,101,108,32,37,105,58,10,102,114,109,114,116,113,95,112,111,115,116,112,114,111,99,61,37,105,44,32,98,105,116,114,116,113,95,112,111,115,116,112,114,111,99,61,37,105,10,76,111,111,112,70,105,108,116,101,114,61,37,105,44,32,67,104,114,111,109,97,70,111,114,109,97,116,61,37,105,44,32,80,117,108,108,100,111,119,110,61,37,105,44,32,73,110,116,101,114,108,97,99,101,58,32,37,105,10,84,70,67,84,82,102,108,97,103,61,37,105,44,32,70,73,78,84,69,82,80,102,108,97,103,61,37,105,10,0,0,0,0,0,0,85,115,101,114,32,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,60,32,37,108,108,100,41,10,0,0,0,109,117,108,116,105,112,108,121,0,0,0,0,0,0,0,0,80,114,111,106,83,99,97,108,101,65,116,78,97,116,79,114,105,103,105,110,71,101,111,75,101,121,0,0,0,0,0,0,71,101,111,84,73,70,70,95,86,101,114,115,105,111,110,0,116,115,44,109,50,116,44,109,50,116,115,44,109,116,115,0,112,105,99,116,95,116,121,112,101,32,61,61,32,114,99,101,45,62,110,101,119,95,112,105,99,116,95,116,121,112,101,0,78,111,32,37,115,32,115,116,114,101,97,109,32,119,105,116,104,32,105,110,100,101,120,32,39,37,100,39,32,102,111,117,110,100,10,0,0,0,0,0,113,115,99,97,108,101,0,0,100,99,32,111,118,101,114,102,108,111,119,43,32,76,32,113,115,99,97,108,101,58,32,37,100,47,47,10,0,0,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,97,115,112,101,99,116,32,114,97,116,105,111,32,37,105,47,37,105,44,32,108,105,109,105,116,32,105,115,32,50,53,53,47,50,53,53,32,114,101,100,117,99,105,110,103,10,0,0,0,0,88,0,0,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,102,103,115,32,115,116,97,114,116,0,0,0,0,0,0,0,83,105,109,117,108,97,116,101,32,101,114,114,111,114,115,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,32,116,111,32,116,101,115,116,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,46,0,0,0,0,0,105,110,105,116,105,97,108,32,115,107,105,112,32,111,118,101,114,102,108,111,119,10,0,0,77,76,80,32,109,117,115,116,32,104,97,118,101,32,48,120,51,49,101,97,32,115,121,110,99,32,119,111,114,100,46,10,0,0,0,0,0,0,0,0,82,71,66,0,0,0,0,0,80,78,71,32,102,105,108,116,101,114,32,102,108,97,103,32,115,101,116,46,10,0,0,0,85,110,107,110,111,119,110,32,112,97,108,101,116,116,101,0,78,111,32,116,97,114,103,101,116,32,115,112,101,99,105,102,105,101,100,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,0,0,0,0,0,92,85,0,0,0,0,0,0,77,80,69,71,45,84,83,32,40,77,80,69,71,45,50,32,84,114,97,110,115,112,111,114,116,32,83,116,114,101,97,109,41,0,0,0,0,0,0,0,83,69,80,66,49,32,109,97,114,107,101,114,32,109,105,115,115,105,110,103,10,0,0,0,112,112,115,95,99,114,95,113,112,95,111,102,102,115,101,116,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,115,97,109,112,108,101,115,95,110,0,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,115,108,105,99,101,32,115,101,103,109,101,110,116,46,10,0,0,0,0,0,0,116,105,109,101,95,115,99,97,108,101,47,110,117,109,95,117,110,105,116,115,95,105,110,95,116,105,99,107,32,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,40,37,100,47,37,100,41,10,0,0,0,0,72,105,103,104,32,52,58,52,58,52,32,73,110,116,114,97,0,0,0,0,0,0,0,0,108,112,99,95,99,111,101,102,102,95,112,114,101,99,105,115,105,111,110,0,0,0,0,0,70,111,117,110,100,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,99,111,109,112,114,101,115,115,105,111,110,32,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,0,108,116,114,116,95,115,117,114,109,105,120,108,101,118,0,0,69,82,82,79,82,58,32,98,108,111,99,107,32,99,111,100,101,32,108,111,111,107,45,117,112,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,73,71,78,0,0,0,115,117,98,45,112,101,108,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,113,117,97,108,105,116,121,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,56,0,0,0,115,108,105,99,101,0,0,0,65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,86,105,100,101,111,0,0,0,0,0,0,67,111,112,121,105,110,103,32,100,97,116,97,32,105,110,32,97,118,102,105,108,116,101,114,46,10,0,0,0,0,0,0,83,111,117,110,100,32,67,108,105,112,0,0,0,0,0,0,52,50,48,80,57,0,0,0,99,111,100,101,99,58,115,0,109,112,103,44,109,112,101,103,0,0,0,0,0,0,0,0,86,111,98,83,117,98,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,78,111,32,115,101,101,107,32,116,97,98,108,101,32,97,116,32,103,105,118,101,110,32,112,111,115,105,116,105,111,110,10,0,0,0,0,0,0,0,0,67,97,110,32,100,101,109,117,120,32,77,117,115,101,112,97,99,107,32,83,86,55,44,32,103,111,116,32,118,101,114,115,105,111,110,32,37,48,50,88,10,0,0,0,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,66,101,110,111,105,116,0,0,0,0,0,0,0,0,115,117,98,113,0,0,0,0,112,97,102,95,118,105,100,101,111,0,0,0,0,0,0,0,84,104,105,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,99,104,97,110,110,101,108,46,10,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,112,116,105,111,110,32,39,37,115,39,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,39,37,115,39,46,10,0,0,98,97,100,32,102,105,108,101,110,97,109,101,32,108,101,110,103,116,104,44,32,114,101,109,97,105,110,105,110,103,32,100,105,114,101,99,116,111,114,121,32,101,110,116,114,105,101,115,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,0,109,112,50,44,109,50,97,44,109,112,97,0,0,0,0,0,65,108,119,97,121,115,32,119,114,105,116,101,32,82,70,54,52,32,104,101,97,100,101,114,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,102,105,108,101,32,115,105,122,101,46,0,0,0,0,0,0,0,82,73,70,70,0,0,0,0,84,65,71,0,0,0,0,0,112,114,111,100,117,99,101,114,0,0,0,0,0,0,0,0,104,97,109,109,105,110,103,0,78,111,110,45,105,110,99,114,101,97,115,105,110,103,32,68,84,83,32,105,110,32,115,116,114,101,97,109,32,37,100,58,32,112,97,99,107,101,116,32,37,100,32,119,105,116,104,32,68,84,83,32,37,108,108,100,44,32,112,97,99,107,101,116,32,37,100,32,119,105,116,104,32,68,84,83,32,37,108,108,100,10,0,0,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,54,54,77,105,99,104,105,103,97,110,0,0,0,0,0,0,0,100,105,97,109,111,110,100,32,116,121,112,101,32,38,32,115,105,122,101,32,102,111,114,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,112,114,101,45,112,97,115,115,0,0,0,0,0,0,76,117,99,97,115,65,114,116,115,32,83,77,85,83,72,32,118,105,100,101,111,0,0,0,110,111,32,118,105,100,101,111,32,115,116,114,101,97,109,32,97,110,100,32,110,111,32,109,105,110,32,102,114,97,103,32,100,117,114,97,116,105,111,110,32,115,101,116,10,0,0,0,84,104,105,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,115,116,97,110,100,97,114,100,46,10,0,0,0,0,0,0,65,112,112,108,101,32,72,84,84,80,32,76,105,118,101,32,83,116,114,101,97,109,105,110,103,32,99,111,109,112,97,116,105,98,108,101,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,65,77,82,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,111,99,116,101,116,45,97,108,105,103,110,61,49,13,10,0,0,0,0,0,0,0,0,112,114,101,112,114,111,103,114,97,109,109,101,100,32,115,101,113,117,101,110,99,101,115,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,0,0,0,0,0,104,101,118,99,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,54,54,0,0,0,0,0,0,0,112,114,101,95,100,105,97,95,115,105,122,101,0,0,0,0,117,119,0,0,0,0,0,0,115,97,110,109,0,0,0,0,117,119,0,0,0,0,0,0,37,115,58,32,73,110,118,97,108,105,100,32,111,112,116,105,111,110,32,111,114,32,97,114,103,117,109,101,110,116,58,32,39,37,115,39,44,32,112,97,114,115,101,100,32,97,115,32,39,37,115,39,32,61,32,39,37,115,39,10,0,0,0,0,100,101,99,114,121,112,116,105,111,110,32,107,101,121,0,0,115,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,115,111,117,114,99,101,32,116,114,97,99,107,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,0,0,0,95,95,78,85,77,95,65,95,84,82,65,67,75,83,0,0,109,112,101,103,116,115,95,115,101,114,118,105,99,101,95,105,100,0,0,0,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,53,56,0,0,0,0,0,0,0,99,104,114,111,109,97,0,0,109,112,101,103,32,109,117,120,101,114,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,50,58,48,0,0,0,0,0,0,0,35,32,86,111,98,83,117,98,32,105,110,100,101,120,32,102,105,108,101,44,0,0,0,0,119,114,105,116,101,95,120,105,110,103,0,0,0,0,0,0,102,102,112,114,101,115,101,116,91,37,115,93,58,32,115,101,116,32,39,37,115,39,32,61,32,39,37,115,39,10,0,0,97,97,99,32,98,105,116,115,116,114,101,97,109,32,101,114,114,111,114,10,0,0,0,0,109,97,110,100,101,108,98,114,111,116,0,0,0,0,0,0,114,116,112,104,105,110,116,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,13,10,0,0,0,0,0,0,37,46,54,103,0,0,0,0,101,110,99,95,107,101,121,95,105,100,0,0,0,0,0,0,68,97,116,117,109,69,95,66,101,115,115,101,108,78,97,109,105,98,105,97,0,0,0,0,100,99,116,109,97,120,0,0,85,110,107,110,111,119,110,32,118,97,108,117,101,32,39,37,100,39,32,102,111,114,32,112,97,116,116,101,114,110,95,116,121,112,101,32,111,112,116,105,111,110,10,0,0,0,0,0,121,117,118,52,0,0,0,0,115,117,110,114,97,115,0,0,37,115,58,32,73,110,118,97,108,105,100,32,115,121,110,116,97,120,58,32,39,37,115,39,10,0,0,0,0,0,0,0,97,114,116,105,115,116,45,115,111,114,116,0,0,0,0,0,66,65,78,68,87,73,68,84,72,61,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,47,32,77,79,86,0,114,101,109,111,118,101,95,97,116,95,101,120,105,116,0,0,255,0,0,0,0,0,0,0,97,117,100,105,111,100,97,116,97,114,97,116,101,0,0,0,102,108,118,95,109,101,116,97,100,97,116,97,0,0,0,0,37,108,108,100,10,0,0,0,115,117,98,0,0,0,0,0,68,97,116,117,109,69,95,66,101,115,115,101,108,77,111,100,105,102,105,101,100,0,0,0,123,37,100,125,123,125,37,54,108,102,0,0,0,0,0,0,57,47,55,32,119,97,118,101,108,101,116,44,32,111,110,108,121,32,117,115,101,100,32,105,110,32,115,110,111,119,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,81,84,32,52,58,52,58,52,58,52,0,0,13,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,115,116,111,114,101,32,112,111,115,105,116,105,111,110,32,97,102,116,101,114,32,114,101,97,100,105,110,103,32,105,110,100,101,120,10,0,80,101,114,45,102,114,97,109,101,32,77,68,53,32,116,101,115,116,105,110,103,0,0,0,101,110,99,114,121,112,116,105,111,110,0,0,0,0,0,0,102,111,114,109,97,116,115,0,116,98,58,37,102,32,115,97,109,112,108,101,95,114,97,116,101,58,37,102,32,110,98,95,99,104,97,110,110,101,108,115,58,37,102,10,0,0,0,0,69,114,114,111,114,32,99,111,110,102,105,103,117,114,105,110,103,32,116,104,101,32,37,115,32,102,105,108,116,101,114,0,115,0,0,0,0,0,0,0,68,97,116,117,109,69,95,66,101,115,115,101,108,49,56,52,49,0,0,0,0,0,0,0,119,57,55,0,0,0,0,0,118,52,48,56,0,0,0,0,61,0,0,0,0,0,0,0,113,117,97,0,0,0,0,0,109,107,118,0,0,0,0,0,119,32,61,61,32,104,32,38,38,32,119,32,61,61,32,108,101,118,101,108,42,108,101,118,101,108,42,108,101,118,101,108,0,0,0,0,0,0,0,0,119,104,105,116,101,0,0,0,115,101,116,32,108,105,102,101,32,99,111,108,111,114,0,0,100,101,102,97,117,108,116,0,100,101,102,97,117,108,116,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,37,108,108,117,32,111,114,32,115,105,122,101,32,37,117,10,0,109,112,101,103,0,0,0,0,68,97,116,117,109,69,95,65,117,115,116,114,97,108,105,97,110,78,97,116,105,111,110,97,108,83,112,104,101,114,111,105,100,0,0,0,0,0,0,0,53,47,51,32,119,97,118,101,108,101,116,44,32,111,110,108,121,32,117,115,101,100,32,105,110,32,115,110,111,119,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,52,58,52,0,0,0,0,0,0,0,103,111,116,32,97,117,100,105,111,32,112,97,99,107,101,116,32,119,105,116,104,111,117,116,32,104,97,118,105,110,103,32,97,110,32,97,117,100,105,111,32,115,116,114,101,97,109,10,0,0,0,0,0,0,0,0,35,10,13,0,0,0,0,0,105,110,105,116,0,0,0,0,105,100,32,37,100,0,0,0,99,50,95,102,108,97,103,115,0,0,0,0,0,0,0,0,112,97,99,107,101,116,32,115,105,122,101,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,51,68,32,76,85,84,32,105,115,32,101,109,112,116,121,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,116,104,101,32,118,97,108,117,101,32,37,100,32,102,111,114,32,116,104,101,32,99,111,109,112,111,110,101,110,116,32,37,100,46,10,0,0,0,0,0,0,0,108,97,116,109,44,108,111,97,115,0,0,0,0,0,0,0,32,67,111,109,112,114,101,115,115,105,111,110,32,98,121,32,74,111,104,110,32,77,32,80,104,105,108,108,105,112,115,32,67,111,112,121,114,105,103,104,116,32,40,67,41,32,49,57,57,53,32,84,104,101,32,66,105,116,109,97,112,32,66,114,111,116,104,101,114,115,32,76,116,100,46,0,0,0,0,0,106,115,115,44,106,115,0,0,50,45,119,97,121,32,109,97,116,99,104,32,43,32,51,114,100,32,109,97,116,99,104,32,111,110,32,99,111,109,98,101,100,32,43,32,52,116,104,47,53,116,104,32,109,97,116,99,104,101,115,32,105,102,32,115,116,105,108,108,32,99,111,109,98,101,100,32,40,112,47,99,32,43,32,117,32,43,32,117,47,98,41,0,0,0,0,0,118,100,112,97,117,95,104,50,54,52,0,0,0,0,0,0,68,97,114,107,66,108,117,101,0,0,0,0,0,0,0,0,86,97,108,117,101,32,37,102,32,102,111,114,32,112,97,114,97,109,101,116,101,114,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,115,101,116,32,111,102,32,51,50,98,105,116,32,105,110,116,101,103,101,114,32,102,108,97,103,115,10,0,0,99,101,105,108,0,0,0,0,69,88,80,69,82,73,77,69,78,84,65,76,0,0,0,0,35,83,32,37,115,0,0,0,116,111,112,32,98,97,99,107,32,108,101,102,116,0,0,0,102,97,115,116,32,98,105,108,105,110,101,97,114,0,0,0,100,115,116,119,0,0,0,0,111,117,116,45,62,98,112,115,32,61,61,32,105,110,45,62,98,112,115,0,0,0,0,0,67,117,114,114,101,110,116,108,121,32,111,110,108,121,32,86,80,56,32,105,115,32,115,117,112,112,111,114,116,101,100,33,10,0,0,0,0,0,0,0,115,101,116,32,104,111,114,105,122,111,110,116,97,108,32,112,111,115,105,116,105,111,110,32,111,102,32,116,104,101,32,108,101,102,116,32,98,111,120,32,101,100,103,101,0,0,0,0,108,101,115,115,32,101,120,104,97,117,115,116,105,118,101,32,115,101,97,114,99,104,0,0,83,116,121,108,101,0,0,0,68,97,116,117,109,69,95,65,105,114,121,77,111,100,105,102,105,101,100,49,56,52,57,0,119,53,51,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,113,116,0,0,0,0,80,114,101,102,101,114,114,101,100,32,83,116,101,114,101,111,32,68,111,119,110,109,105,120,32,77,111,100,101,0,0,0,80,114,101,102,101,114,114,101,100,32,83,116,101,114,101,111,32,68,111,119,110,109,105,120,32,77,111,100,101,0,0,0,98,97,110,100,119,105,100,116,104,32,99,111,100,101,32,61,32,37,100,32,62,32,54,48,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,99,114,111,115,115,111,118,101,114,32,98,97,110,100,32,105,110,100,101,120,32,98,101,121,111,110,100,32,97,114,114,97,121,32,98,111,117,110,100,115,58,32,37,100,10,0,0,0,0,0,0,0,0,118,51,48,56,0,0,0,0,84,78,83,32,102,105,108,116,101,114,32,111,114,100,101,114,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,109,97,120,105,109,117,109,32,37,100,46,10,0,0,0,0,0,0,0,0,37,100,32,98,105,116,115,32,108,101,102,116,32,98,101,102,111,114,101,32,100,101,99,111,100,101,95,105,95,98,108,111,99,107,40,41,10,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,33,32,82,101,97,100,32,37,100,32,111,102,32,37,100,32,98,121,116,101,115,10,0,0,110,111,110,101,0,0,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,70,108,111,111,114,32,48,32,111,114,100,101,114,32,105,115,32,48,46,10,0,0,0,0,66,117,102,102,101,114,32,110,111,116,32,102,117,108,108,121,32,114,101,97,100,10,0,0,70,105,108,101,32,102,111,114,32,112,114,101,115,101,116,32,39,37,115,39,32,110,111,116,32,102,111,117,110,100,10,0,79,110,108,121,32,52,58,50,58,48,32,99,104,114,111,109], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2067080);
/* memory initializer */ allocate([97,32,102,111,114,109,97,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,70,97,105,108,101,100,32,112,97,114,115,105,110,103,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,0,33,97,118,112,107,116,45,62,100,97,116,97,32,124,124,32,97,118,112,107,116,45,62,100,97,116,97,32,33,61,32,97,118,99,116,120,45,62,105,110,116,101,114,110,97,108,45,62,98,121,116,101,95,98,117,102,102,101,114,0,0,0,0,0,111,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,108,105,103,104,116,101,110,0,80,114,111,106,67,101,110,116,101,114,78,111,114,116,104,105,110,103,71,101,111,75,101,121,0,0,0,0,0,0,0,0,77,111,100,101,108,84,105,101,112,111,105,110,116,84,97,103,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,116,97,103,32,37,88,10,0,73,110,112,117,116,32,105,115,32,108,111,110,103,101,114,32,116,104,97,110,32,50,45,112,97,115,115,32,108,111,103,32,102,105,108,101,10,0,0,0,108,105,102,101,0,0,0,0,100,37,49,91,97,118,93,37,100,37,99,0,0,0,0,0,73,110,103,101,110,105,101,110,116,32,112,97,99,107,101,116,58,32,115,105,122,101,61,37,100,44,32,119,105,100,116,104,61,37,100,44,32,104,101,105,103,104,116,61,37,100,44,32,117,110,107,49,61,37,100,32,117,110,107,50,61,37,100,10,0,0,0,0,0,0,0,0,117,115,101,32,108,111,111,112,32,102,105,108,116,101,114,0,100,99,32,111,118,101,114,102,108,111,119,45,32,98,108,111,99,107,58,32,37,100,32,113,115,99,97,108,101,58,32,37,100,47,47,10,0,0,0,0,109,97,120,32,98,32,102,114,97,109,101,115,32,109,117,115,116,32,98,101,32,48,32,111,114,32,112,111,115,105,116,105,118,101,32,102,111,114,32,109,112,101,103,118,105,100,101,111,32,98,97,115,101,100,32,101,110,99,111,100,101,114,115,10,0,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,72,101,97,100,101,114,32,109,105,115,115,105,110,103,10,0,72,101,97,100,101,114,32,109,105,115,115,105,110,103,10,0,101,120,116,101,110,115,105,111,110,32,115,116,97,114,116,0,101,114,114,111,114,95,114,97,116,101,0,0,0,0,0,0,102,105,114,115,116,32,109,98,95,105,110,99,114,32,100,97,109,97,103,101,100,10,0,0,114,101,115,116,97,114,116,32,104,101,97,100,101,114,32,115,121,110,99,32,105,110,99,111,114,114,101,99,116,32,40,103,111,116,32,48,120,37,48,52,120,41,10,0,0,0,0,0,115,101,113,117,101,110,116,105,97,108,32,68,67,84,0,0,78,117,108,108,102,114,97,109,101,32,105,110,115,101,114,116,105,111,110,32,102,108,97,103,32,115,101,116,46,10,0,0,85,110,107,110,111,119,110,32,112,105,120,95,102,109,116,44,32,112,114,111,102,105,108,101,58,32,37,100,44,32,99,111,108,111,117,114,95,115,112,97,99,101,58,32,37,100,44,32,99,111,109,112,111,110,101,110,116,115,58,32,37,100,44,32,112,114,101,99,105,115,105,111,110,58,32,37,100,44,32,99,100,120,91,49,93,58,32,37,100,44,32,99,100,121,91,49,93,58,32,37,100,44,32,99,100,120,91,50,93,58,32,37,100,44,32,99,100,121,91,50,93,58,32,37,100,10,0,0,77,105,115,115,105,110,103,32,102,108,97,103,32,116,101,114,109,105,110,97,116,111,114,32,111,114,32,101,120,116,114,97,110,101,111,117,115,32,100,97,116,97,32,102,111,117,110,100,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,102,108,97,103,115,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,0,0,0,0,123,92,98,48,125,0,0,0,100,105,109,101,110,115,105,111,110,115,32,48,10,0,0,0,105,109,97,103,101,50,112,105,112,101,0,0,0,0,0,0,112,112,115,95,99,98,95,113,112,95,111,102,102,115,101,116,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,84,104,101,32,115,108,105,99,101,95,113,112,32,37,100,32,105,115,32,111,117,116,115,105,100,101,32,116,104,101,32,118,97,108,105,100,32,114,97,110,103,101,32,91,37,100,44,32,53,49,93,46,10,0,0,0,99,111,110,115,117,109,101,100,95,115,97,109,112,108,101,115,95,110,0,0,0,0,0,0,84,114,117,110,99,97,116,101,100,32,86,85,73,10,0,0,72,105,103,104,32,52,58,52,58,52,32,80,114,101,100,105,99,116,105,118,101,0,0,0,70,76,65,67,32,101,110,99,111,100,101,114,0,0,0,0,99,111,109,112,114,101,115,115,105,111,110,0,0,0,0,0,76,116,47,82,116,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,67,111,114,101,32,97,117,120,105,108,105,97,114,121,32,100,97,116,97,32,114,101,115,101,114,118,101,100,32,99,111,110,116,101,110,116,0,0,0,0,68,97,116,117,109,69,95,65,105,114,121,49,56,51,48,0,110,111,105,115,101,32,112,114,101,115,101,114,118,105,110,103,32,115,117,109,32,111,102,32,115,113,117,97,114,101,100,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,0,119,109,118,50,0,0,0,0,65,108,108,111,119,101,100,32,116,104,114,101,97,100,32,116,121,112,101,115,0,0,0,0,80,105,110,110,97,99,108,101,32,84,65,82,71,65,32,67,105,110,101,87,97,118,101,32,89,85,86,49,54,0,0,0,83,97,109,112,108,101,115,32,100,114,111,112,112,101,100,32,100,117,101,32,116,111,32,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,117,114,101,46,10,0,0,0,0,0,0,71,97,109,101,0,0,0,0,52,50,48,80,65,76,68,86,0,0,0,0,0,0,0,0,80,108,101,97,115,101,32,117,115,101,32,45,112,114,101,115,101,116,32,60,115,112,101,101,100,62,32,45,113,112,32,48,10,0,0,0,0,0,0,0,112,105,112,101,100,32,105,109,97,103,101,50,32,115,101,113,117,101,110,99,101,0,0,0,109,112,111,0,0,0,0,0,108,98,99,0,0,0,0,0,68,97,116,117,109,95,78,111,114,100,95,100,101,95,71,117,101,114,114,101,0,0,0,0,110,115,115,101,0,0,0,0,48,0,0,0,0,0,0,0,116,97,114,103,97,95,121,50,49,54,0,0,0,0,0,0,70,114,97,109,101,32,114,97,116,101,32,109,97,121,32,110,111,116,32,101,120,99,101,101,100,32,50,53,53,102,112,115,10,0,0,0,0,0,0,0,108,105,98,120,50,54,52,45,108,111,115,115,108,101,115,115,0,0,0,0,0,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,65,86,79,112,116,105,111,110,32,39,37,115,39,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,39,37,115,39,46,10,0,0,117,110,107,110,111,119,110,32,103,117,105,100,32,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,44,32,101,120,112,101,99,116,101,100,32,100,105,114,95,101,110,116,114,121,95,103,117,105,100,59,32,114,101,109,97,105,110,105,110,103,32,100,105,114,101,99,116,111,114,121,32,101,110,116,114,105,101,115,32,105,103,110,111,114,101,100,10,0,0,0,0,105,110,118,97,108,105,100,32,99,104,117,110,107,32,115,105,122,101,58,32,37,117,10,0,97,108,119,97,121,115,0,0,87,65,86,69,0,0,0,0,80,82,79,68,0,0,0,0,72,97,110,110,32,119,105,110,100,111,119,0,0,0,0,0,83,116,114,101,97,109,32,35,37,100,58,32,110,111,116,32,101,110,111,117,103,104,32,102,114,97,109,101,115,32,116,111,32,101,115,116,105,109,97,116,101,32,114,97,116,101,59,32,99,111,110,115,105,100,101,114,32,105,110,99,114,101,97,115,105,110,103,32,112,114,111,98,101,115,105,122,101,10,0,0,68,97,116,117,109,95,65,110,99,105,101,110,110,101,95,84,114,105,97,110,103,117,108,97,116,105,111,110,95,70,114,97,110,99,97,105,115,101,0,0,115,117,109,32,111,102,32,115,113,117,97,114,101,100,32,118,101,114,116,105,99,97,108,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,77,83,32,52,58,52,58,52,58,52,0,0,85,110,115,117,112,112,111,114,116,101,100,32,97,117,100,105,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,99,111,100,101,99,58,100,0,104,108,115,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,80,67,77,65,47,37,100,47,37,100,13,10,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,111,112,116,105,111,110,58,32,39,37,99,39,0,0,0,0,109,111,118,32,109,117,120,101,114,0,0,0,0,0,0,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,73,67,79,32,97,108,114,101,97,100,121,32,99,111,110,116,97,105,110,115,32,37,100,32,105,109,97,103,101,115,10,0,117,110,107,110,111,119,110,32,99,104,117,110,107,32,102,111,117,110,100,58,32,37,100,44,32,111,102,102,115,101,116,58,32,37,100,10,0,0,0,0,114,97,119,32,72,46,50,54,52,32,118,105,100,101,111,0,112,114,101,118,95,102,111,114,99,101,100,95,116,0,0,0,68,97,116,117,109,95,87,71,83,56,52,0,0,0,0,0,118,115,115,101,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,97,121,117,118,0,0,0,0,35,69,88,84,77,51,85,10,0,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,100,105,115,97,98,108,101,32,100,97,116,97,0,0,0,0,99,114,121,112,116,111,107,101,121,0,0,0,0,0,0,0,78,111,32,108,111,110,103,101,114,32,114,101,99,101,105,118,105,110,103,32,112,108,97,121,108,105,115,116,32,37,100,10,0,0,0,0,0,0,0,0,104,101,118,99,32,100,101,109,117,120,101,114,0,0,0,0,85,84,70,45,56,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,109,97,116,101,114,105,97,108,32,116,114,97,99,107,32,115,101,113,117,101,110,99,101,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,95,95,78,85,77,95,73,95,84,82,65,67,75,83,0,0,37,115,47,115,116,114,101,97,109,37,100,46,97,98,115,116,0,0,0,0,0,0,0,0,83,101,116,32,111,114,105,103,105,110,97,108,95,110,101,116,119,111,114,107,95,105,100,32,102,105,101,108,100,46,0,0,99,101,108,108,97,117,116,111,0,0,0,0,0,0,0,0,68,97,116,117,109,95,87,71,83,55,50,95,84,114,97,110,115,105,116,95,66,114,111,97,100,99,97,115,116,95,69,112,104,101,109,101,114,105,115,0,104,50,54,52,32,100,101,109,117,120,101,114,0,0,0,0,112,105,100,32,37,120,32,105,115,32,110,111,116,32,80,69,83,10,0,0,0,0,0,0,115,117,109,32,111,102,32,97,98,115,111,108,117,116,101,32,118,101,114,116,105,99,97,108,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,109,117,120,32,114,97,116,101,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,65,118,105,100,32,77,101,114,105,100,105,101,110,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,0,0,37,115,10,0,0,0,0,0,104,50,54,49,32,100,101,109,117,120,101,114,0,0,0,0,69,110,97,98,108,101,32,73,68,51,118,49,32,119,114,105,116,105,110,103,46,32,73,68,51,118,49,32,116,97,103,115,32,97,114,101,32,119,114,105,116,116,101,110,32,105,110,32,85,84,70,45,56,32,119,104,105,99,104,32,109,97,121,32,110,111,116,32,98,101,32,115,117,112,112,111,114,116,101,100,32,98,121,32,109,111,115,116,32,115,111,102,116,119,97,114,101,46,0,0,0,0,0,0,100,110,0,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,77,79,86,32,109,117,120,101,114,32,102,108,97,103,115,0,108,111,99,97,116,105,111,110,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,101,100,105,97,32,112,97,99,107,101,116,32,108,101,110,103,116,104,10,0,0,0,0,110,117,108,108,115,105,110,107,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,32,45,45,62,32,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,0,0,0,78,79,80,84,83,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,108,97,98,101,108,10,0,0,0,0,70,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,99,111,100,101,99,32,112,114,105,118,97,116,101,32,100,97,116,97,10,0,0,0,0,68,97,116,117,109,95,87,71,83,55,50,0,0,0,0,0,118,115,97,100,0,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,0,67,111,117,108,100,32,102,105,110,100,32,110,111,32,102,105,108,101,32,119,105,116,104,32,112,97,116,104,32,39,37,115,39,32,97,110,100,32,105,110,100,101,120,32,105,110,32,116,104,101,32,114,97,110,103,101,32,37,100,45,37,100,10,0,97,118,117,105,0,0,0,0,105,109,51,50,0,0,0,0,79,110,108,121,32,56,48,48,48,32,98,47,115,32,97,110,100,32,54,52,48,48,32,98,47,115,32,98,105,116,114,97,116,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,32,80,114,111,118,105,100,101,100,58,32,37,100,32,98,47,115,10,0,0,0,0,102,111,114,99,101,32,100,97,116,97,32,99,111,100,101,99,32,40,39,99,111,112,121,39,32,116,111,32,99,111,112,121,32,115,116,114,101,97,109,41,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,83,79,80,0,0,0,0,73,86,61,0,0,0,0,0,44,32,70,61,48,120,37,48,88,0,0,0,0,0,0,0,109,105,110,105,109,117,109,32,102,114,97,103,109,101,110,116,32,100,117,114,97,116,105,111,110,32,40,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,41,0,0,0,0,0,105,109,97,103,101,50,112,105,112,101,0,0,0,0,0,0,118,105,100,101,111,99,111,100,101,99,105,100,0,0,0,0,102,108,118,100,101,99,0,0,68,97,116,117,109,95,67,111,110,97,107,114,121,95,49,57,48,53,0,0,0,0,0,0,48,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,117,112,100,97,116,101,32,104,101,97,100,101,114,32,119,105,116,104,32,99,111,114,114,101,99,116,32,100,117,114,97,116,105,111,110,46,10,0,48,49,50,118,0,0,0,0,100,99,111,100,101,99,0,0,84,111,111,32,100,101,101,112,108,121,32,110,101,115,116,101,100,32,79,68,77,76,32,105,110,100,101,120,101,115,10,0,69,120,116,32,68,82,77,32,112,114,111,116,101,99,116,101,100,32,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,44,32,100,101,99,111,100,105,110,103,32,119,105,108,108,32,108,105,107,101,108,121,32,102,97,105,108,33,10,0,0,83,116,114,101,97,109,32,100,105,115,99,111,118,101,114,101,100,32,97,102,116,101,114,32,104,101,97,100,32,97,108,114,101,97,100,121,32,112,97,114,115,101,100,10,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,101,101,107,32,97,116,32,112,114,101,97,109,98,108,101,10,0,0,0,0,0,100,101,102,97,117,108,116,0,115,116,97,114,116,105,0,0,115,104,111,119,32,98,117,105,108,100,32,99,111,110,102,105,103,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,117,110,97,98,108,101,32,116,111,32,114,101,119,114,105,116,101,32,70,76,65,67,32,104,101,97,100,101,114,46,10,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,86,111,114,98,105,115,67,111,109,109,101,110,116,32,109,101,116,97,100,97,116,97,10,0,0,0,111,110,108,121,32,65,86,95,80,73,88,95,70,77,84,95,82,71,66,65,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,111,99,116,97,118,101,0,0,109,97,103,105,99,32,110,117,109,98,101,114,32,110,111,116,32,102,111,117,110,100,10,0,68,97,116,117,109,95,68,101,117,116,115,99,104,101,95,72,97,117,112,116,100,114,101,105,101,99,107,115,110,101,116,122,0,0,0,0,0,0,0,0,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,97,108,44,32,115,108,111,119,0,0,0,116,114,117,110,99,97,116,101,32,101,120,105,115,116,105,110,103,32,102,105,108,101,115,32,111,110,32,119,114,105,116,101,0,0,0,0,0,0,0,0,65,118,105,100,32,49,58,49,32,49,48,45,98,105,116,32,82,71,66,32,80,97,99,107,101,114,0,0,0,0,0,0,115,101,116,32,111,112,116,105,111,110,115,32,102,114,111,109,32,105,110,100,105,99,97,116,101,100,32,112,114,101,115,101,116,32,102,105,108,101,0,0,91,83,84,82,69,65,77,93,0,0,0,0,0,0,0,0,105,110,118,101,114,116,101,100,32,112,97,114,97,98,111,108,97,0,0,0,0,0,0,0,91,67,72,65,80,84,69,82,93,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,116,101,120,94,113,67,111,109,112,0,0,0,0,0,0,0,115,101,116,32,110,111,114,109,97,108,105,122,101,100,32,105,116,101,114,97,116,105,111,110,32,99,111,117,110,116,32,109,111,100,101,0,0,0,0,0,114,101,115,121,110,99,105,110,103,10,0,0,0,0,0,0,108,105,102,101,95,99,111,108,111,114,0,0,0,0,0,0,115,116,105,116,99,104,32,98,111,117,110,100,97,114,105,101,115,0,0,0,0,0,0,0,50,52,45,98,105,116,32,80,97,114,105,115,32,80,67,77,32,102,111,114,109,97,116,0,115,101,116,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,48,120,37,48,52,120,10,0,0,106,112,101,103,0,0,0,0,68,97,116,117,109,95,82,101,115,101,97,117,95,78,97,116,105,111,110,97,108,95,66,101,108,103,101,95,49,57,55,50,0,0,0,0,0,0,0,0,114,100,0,0,0,0,0,0,102,97,105,108,101,100,32,114,101,97,100,105,110,103,32,100,120,97,95,101,120,116,114,97,10,0,0,0,0,0,0,0,97,118,114,112,0,0,0,0,67,97,110,39,116,32,112,114,111,99,101,115,115,32,68,86,32,102,114,97,109,101,32,35,37,100,46,32,73,110,115,117,102,102,105,99,105,101,110,116,32,118,105,100,101,111,32,100,97,116,97,32,111,114,32,115,101,118,101,114,101,32,115,121,110,99,32,112,114,111,98,108,101,109,46,10,0,0,0,0,102,112,114,101,0,0,0,0,115,112,101,99,105,102,121,32,119,104,101,110,32,116,111,32,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,99,50,115,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,39,46,37,115,39,32,102,105,108,101,32,116,121,112,101,10,0,0,0,100,118,44,100,105,102,0,0,69,114,114,111,114,32,119,104,101,110,32,112,97,114,115,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,116,104,101,32,99,111,109,112,111,110,101,110,116,32,37,100,32,97,110,100,32,99,111,108,111,114,32,37,100,46,10,0,0,0,0,0,0,99,104,117,110,107,32,115,105,122,101,32,116,111,111,32,98,105,103,10,0,0,0,0,0,77,52,65,32,0,0,0,0,115,107,105,112,112,105,110,103,32,37,100,32,98,121,116,101,115,32,111,102,32,101,110,100,45,111,102,45,102,114,97,109,101,32,109,97,114,107,101,114,32,99,104,117,110,107,10,0,112,99,95,110,95,117,98,0,121,117,118,97,52,50,48,112,0,0,0,0,0,0,0,0,51,48,50,0,0,0,0,0,67,121,97,110,0,0,0,0,86,97,108,117,101,32,37,102,32,102,111,114,32,112,97,114,97,109,101,116,101,114,32,39,37,115,39,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,37,103,32,45,32,37,103,93,10,0,0,0,0,0,102,108,111,111,114,0,0,0,85,110,107,110,111,119,110,32,101,114,114,111,114,32,111,99,99,117,114,114,101,100,0,0,84,66,76,0,0,0,0,0,98,105,108,105,110,101,97,114,0,0,0,0,0,0,0,0,115,111,117,114,99,101,32,104,101,105,103,104,116,0,0,0,111,117,116,45,62,112,108,97,110,97,114,32,61,61,32,105,110,45,62,112,108,97,110,97,114,0,0,0,0,0,0,0,105,110,118,101,114,116,0,0,108,101,115,115,0,0,0,0,70,111,114,109,97,116,0,0,68,97,116,117,109,95,77,105,108,105,116,97,114,95,71,101,111,103,114,97,112,104,105,115,99,104,101,95,73,110,115,116,105,116,117,116,0,0,0,0,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,110,101,101,100,101,100,32,102,111,114,32,116,104,101,32,98,108,111,99,107,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,68,105,97,108,111,103,105,99,32,79,75,73,0,0,100,109,105,120,95,109,111,100,101,0,0,0,0,0,0,0,100,109,105,120,95,109,111,100,101,0,0,0,0,0,0,0,87,97,114,110,105,110,103,58,32,110,101,119,32,114,101,109,97,116,114,105,120,105,110,103,32,115,116,114,97,116,101,103,121,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,95,109,97,115,116,101,114,58,32,37,100,10,0,0,0,102,105,108,101,0,0,0,0,79,112,101,110,69,88,82,32,105,109,97,103,101,0,0,0,101,114,114,111,114,32,105,110,32,115,112,101,99,116,114,97,108,32,100,97,116,97,44,32,69,83,67,32,111,118,101,114,102,108,111,119,10,0,0,0,101,110,100,32,109,105,115,109,97,116,99,104,10,0,0,0,112,114,101,115,101,116,95,110,97,109,101,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,118,97,108,105,100,32,102,114,97,109,101,114,97,116,101,10,0,0,0,0,0,0,70,108,111,111,114,32,118,97,108,117,101,32,105,115,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,98,108,111,99,107,115,105,122,101,58,32,37,117,32,40,37,117,41,10,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,111,118,101,114,114,117,110,10,0,110,111,110,45,115,116,97,110,100,97,114,100,32,99,100,120,108,32,102,105,108,101,10,0,115,101,116,32,116,104,101,32,115,117,98,116,105,116,108,101,32,111,112,116,105,111,110,115,32,116,111,32,116,104,101,32,105,110,100,105,99,97,116,101,100,32,112,114,101,115,101,116,0,0,0,0,0,0,0,0,82,101,115,101,114,118,101,100,32,76,69,86,69,76,32,37,105,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,105,110,105,109,117,109,32,114,101,113,117,105,114,101,100,32,112,97,99,107,101,116,32,115,105,122,101,32,37,108,108,100,32,40,109,97,120,32,97,108,108,111,119,101,100,32,105,115,32,37,100,41,10,0,0,104,97,114,100,108,105,103,104,116,0,0,0,0,0,0,0,80,114,111,106,67,101,110,116,101,114,69,97,115,116,105,110,103,71,101,111,75,101,121,0,77,111,100,101,108,84,114,97,110,115,102,111,114,109,97,116,105,111,110,84,97,103,0,0,115,116,117,102,102,105,110,103,32,37,100,32,98,121,116,101,115,10,0,0,0,0,0,0,77,52,86,32,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,85,110,97,98,108,101,32,116,111,32,108,111,111,112,58,32,37,115,10,0,0,0,0,0,108,111,111,112,0,0,0,0,73,32,102,114,97,109,101,32,116,111,111,32,108,111,110,103,44,32,105,103,110,111,114,105,110,103,32,101,120,116,32,104,101,97,100,101,114,10,0,0,115,107,105,112,112,105,110,103,32,67,65,70,32,99,104,117,110,107,58,32,37,48,56,88,32,40,37,99,37,99,37,99,37,99,41,44,32,115,105,122,101,32,37,108,108,100,10,0,98,32,102,114,97,109,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,62,0,0,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,73,68,51,32,116,97,103,10,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,73,68,51,32,116,97,103,10,0,0,0,0,0,115,108,105,99,101,32,115,116,97,114,116,0,0,0,0,0,113,117,97,110,116,105,122,101,114,95,110,111,105,115,101,95,115,104,97,112,105,110,103,0,84,111,111,32,109,97,110,121,32,102,114,97,99,116,105,111,110,97,108,32,98,105,116,115,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,116,111,111,32,109,97,110,121,32,102,114,97,109,101,115,32,105,110,32,98,108,111,99,107,10,0,0,0,0,0,0,0,108,111,115,115,108,101,115,115,0,0,0,0,0,0,0,0,77,117,108,116,105,116,104,114,101,97,100,32,101,110,99,111,100,101,114,32,102,108,97,103,32,115,101,116,46,10,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,115,101,112,97,114,97,116,105,111,110,32,37,100,47,37,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,108,97,103,115,32,99,104,97,114,32,39,37,99,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,0,92,98,0,0,0,0,0,0,117,110,111,114,100,101,114,101,100,32,115,108,105,99,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,121,97,100,105,102,0,0,0,83,80,83,32,37,117,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,46,10,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,10,0,0,0,0,0,0,66,79,84,84,79,77,70,73,82,83,84,0,0,0,0,0,108,105,116,116,108,101,32,101,110,100,105,97,110,32,98,121,116,101,32,111,114,100,101,114,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,97,115,112,101,99,116,32,114,97,116,105,111,10,0,0,0,72,105,103,104,32,52,58,52,58,52,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,108,97,99,101,110,99,46,99,0,0,0,0,102,108,111,97,116,0,0,0,108,116,114,116,95,99,109,105,120,108,101,118,0,0,0,0,79,118,101,114,114,101,97,100,32,97,117,120,105,108,105,97,114,121,32,100,97,116,97,32,98,121,32,37,100,32,98,105,116,115,10,0,0,0,0,0,68,97,116,117,109,95,90,97,110,100,101,114,105,106,0,0,98,105,116,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,55,0,0,0,116,104,114,101,97,100,95,116,121,112,101,0,0,0,0,0,101,120,114,0,0,0,0,0,72,111,117,115,101,0,0,0,52,50,48,77,80,69,71,50,0,0,0,0,0,0,0,0,115,112,114,101,0,0,0,0,120,98,105,110,0,0,0,0,102,114,97,109,101,32,37,108,108,100,58,32,97,117,100,105,111,32,115,105,122,101,32,105,110,32,104,101,97,100,101,114,32,40,37,117,41,32,62,32,115,105,122,101,32,111,102,32,112,97,99,107,101,116,32,108,101,102,116,32,40,37,117,41,10,0,0,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,97,117,100,105,111,32,98,108,111,99,107,10,0,66,112,115,32,37,100,32,97,110,100,32,115,105,103,110,32,37,100,0,0,0,0,0,0,68,97,116,117,109,95,89,111,102,102,0,0,0,0,0,0,115,117,109,32,111,102,32,115,113,117,97,114,101,100,32,113,117,97,110,116,105,122,97,116,105,111,110,32,101,114,114,111,114,115,32,40,97,118,111,105,100,44,32,108,111,119,32,113,117,97,108,105,116,121,41,0,69,115,99,97,112,101,32,49,51,48,0,0,0,0,0,0,115,101,116,32,116,104,101,32,118,105,100,101,111,32,111,112,116,105,111,110,115,32,116,111,32,116,104,101,32,105,110,100,105,99,97,116,101,100,32,112,114,101,115,101,116,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,111,112,116,105,111,110,32,39,37,115,39,32,40,37,115,41,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,39,37,115,39,46,10,0,0,0,0,0,0,0,37,89,45,37,109,45,37,100,32,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,87,114,105,116,101,32,82,70,54,52,32,104,101,97,100,101,114,32,105,102,32,102,105,108,101,32,103,114,111,119,115,32,108,97,114,103,101,32,101,110,111,117,103,104,46,0,0,0,110,111,116,101,0,0,0,0,104,97,110,110,0,0,0,0,33,115,45,62,119,114,105,116,101,95,102,108,97,103,0,0,105,109,97,103,101,50,0,0,104,116,116,112,115,58,0,0,119,51,102,100,105,102,0,0,68,97,116,117,109,95,89,97,99,97,114,101,0,0,0,0,115,117,109,32,111,102,32,97,98,115,111,108,117,116,101,32,68,67,84,32,116,114,97,110,115,102,111,114,109,101,100,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,0,101,115,99,97,112,101,49,51,48,0,0,0,0,0,0,0,76,73,83,84,0,0,0,0,87,77,65,80,0,0,0,0,118,112,114,101,0,0,0,0,77,51,85,56,32,102,111,114,109,97,116,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,80,67,77,85,47,37,100,47,37,100,13,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,51,103,50,97,0,0,0,0,115,116,114,101,97,109,95,105,110,100,101,120,32,62,61,32,48,0,0,0,0,0,0,0,104,50,54,52,0,0,0,0,76,111,111,112,115,116,97,114,116,32,118,97,108,117,101,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,97,110,100,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,0,68,97,116,117,109,95,83,116,111,99,107,104,111,108,109,95,49,57,51,56,0,0,0,0,115,117,109,32,111,102,32,97,98,115,111,108,117,116,101,32,72,97,100,97,109,97,114,100,32,116,114,97,110,115,102,111,114,109,101,100,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,0,0,0,0,117,49,54,108,101,0,0,0,100,101,112,116,104,32,37,100,0,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,89,85,86,32,52,58,49,58,49,32,49,50,45,98,105,116,0,0,0,117,49,54,108,101,0,0,0,97,115,115,44,115,115,97,0,115,101,116,32,116,104,101,32,97,117,100,105,111,32,111,112,116,105,111,110,115,32,116,111,32,116,104,101,32,105,110,100,105,99,97,116,101,100,32,112,114,101,115,101,116,0,0,0,37,115,0,0,0,0,0,0,115,112,101,99,105,102,121,32,104,111,119,32,109,97,110,121,32,109,105,99,114,111,115,101,99,111,110,100,115,32,97,114,101,32,97,110,97,108,121,122,101,100,32,116,111,32,112,114,111,98,101,32,116,104,101,32,105,110,112,117,116,0,0,0,79,103,103,32,109,117,120,101,114,0,0,0,0,0,0,0,51,103,50,98,0,0,0,0,97,115,102,44,119,109,118,44,119,109,97,0,0,0,0,0,69,114,114,111,114,32,115,116,114,101,97,109,95,105,100,95,112,108,117,115,49,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,83,65,77,80,76,69,95,87,73,68,84,72,0,0,0,0,109,112,101,103,116,115,95,111,114,105,103,105,110,97,108,95,110,101,116,119,111,114,107,95,105,100,0,0,0,0,0,0,68,97,116,117,109,95,78,111,114,100,95,83,97,104,97,114,97,95,49,57,53,57,0,0,115,101,114,118,105,99,101,95,112,114,111,118,105,100,101,114,0,0,0,0,0,0,0,0,115,97,116,100,0,0,0,0,98,117,102,102,101,114,32,115,105,122,101,32,37,100,44,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,121,52,49,112,0,0,0,0,73,110,118,97,108,105,100,32,108,97,110,103,105,100,120,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,0,83,69,69,75,84,79,58,32,37,108,108,100,10,0,0,0,119,114,105,116,101,95,105,100,51,118,49,0,0,0,0,0,97,112,114,101,0,0,0,0,13,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,97,103,32,115,105,122,101,32,37,117,46,10,0,0,0,109,111,118,102,108,97,103,115,0,0,0,0,0,0,0,0,51,103,112,52,0,0,0,0,105,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,0,109,111,100,101,108,0,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,32,101,108,101,109,101,110,116,0,0,37,46,42,115,10,37,46,42,115,10,37,46,42,115,0,0,97,118,95,105,110,116,101,114,108,101,97,118,101,100,95,119,114,105,116,101,95,102,114,97,109,101,40,41,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,101,110,99,111,100,105,110,103,32,116,121,112,101,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,99,111,100,101,99,10,0,0,0,68,97,116,117,109,95,66,101,114,110,95,49,57,51,56,0,115,117,109,32,111,102,32,115,113,117,97,114,101,100,32,101,114,114,111,114,115,0,0,0,92,42,63,91,93,123,125,0,65,112,112,108,101,32,73,110,116,101,114,109,101,100,105,97,116,101,32,67,111,100,101,99,0,0,0,0,0,0,0,0,105,109,50,52,0,0,0,0,33,102,115,45,62,102,114,97,109,101,95,114,101,97,100,121,0,0,0,0,0,0,0,0,118,105,100,101,111,32,98,105,116,115,116,114,101,97,109,95,102,105,108,116,101,114,115,0,97,108,98,117,109,45,115,111,114,116,0,0,0,0,0,0,85,82,73,61,0,0,0,0,109,105,110,95,102,114,97,103,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,51,103,112,54,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,118,99,111,100,101,99,46,99,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,66,114,111,107,101,110,32,70,76,86,32,102,105,108,101,44,32,119,104,105,99,104,32,115,97,121,115,32,110,111,32,115,116,114,101,97,109,115,32,112,114,101,115,101,110,116,44,32,116,104,105,115,32,109,105,103,104,116,32,102,97,105,108,10,0,0,0,0,0,0,0,0,68,97,116,117,109,95,86,111,105,114,111,108,95,85,110,105,102,105,101,95,49,57,54,48,0,0,0,0,0,0,0,0,115,115,101,0,0,0,0,0,97,105,99,0,0,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,78,97,78,32,102,111,114,32,118,111,108,117,109,101,44,32,115,101,116,116,105,110,103,32,116,111,32,48,10,0,0,0,0,0,118,98,115,102,0,0,0,0,118,112,114,112,0,0,0,0,79,68,77,76,32,105,110,100,101,120,32,105,110,118,97,108,105,100,10,0,0,0,0,0,115,101,116,32,110,111,105,115,101,32,116,111,108,101,114,97,110,99,101,0,0,0,0,0,65,83,70,95,76,105,99,101,110,115,101,95,85,82,76,0,116,114,97,99,107,95,112,101,97,107,32,61,32,37,46,54,102,10,0,0,0,0,0,0,101,118,97,108,32,118,111,108,117,109,101,32,101,120,112,114,101,115,115,105,111,110,32,112,101,114,45,102,114,97,109,101,0,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,105,0,0,0,0,0,0,0,118,105,103,110,101,116,116,101,0,0,0,0,0,0,0,0,98,117,105,108,100,99,111,110,102,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,111,0,0,0,0,0,0,0,68,97,116,117,109,95,86,111,105,114,111,108,95,49,56,55,53,0,0,0,0,0,0,0,115,117,109,32,111,102,32,97,98,115,111,108,117,116,101,32,100,105,102,102,101,114,101,110,99,101,115,44,32,102,97,115,116,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,77,83,32,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,86,57,32,83,99,114,101,101,110,0,0,0,0,0,0,0,0,97,117,100,105,111,32,98,105,116,115,116,114,101,97,109,95,102,105,108,116,101,114,115,0,105,110,112,117,116,37,100,0,112,97,114,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,100,101,99,105,109,97,108,115,32,116,111,32,115,104,111,119,0,0,110,111,114,109,97,108,105,122,101,100,95,105,116,101,114,97,116,105,111,110,95,99,111,117,110,116,0,0,0,0,0,0,115,101,116,32,109,111,108,100,32,115,112,101,101,100,32,102,111,114,32,100,101,97,100,32,99,101,108,108,115,0,0,0,115,116,105,116,99,104,0,0,118,102,108,105,112,0,0,0,115,101,116,32,116,105,109,101,32,111,118,101,114,32,119,104,105,99,104,32,105,110,99,114,101,97,115,101,32,111,102,32,118,111,108,117,109,101,32,105,115,32,100,101,116,101,114,109,105,110,101,100,0,0,0,0,97,115,112,101,99,116,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,32,109,97,112,112,101,100,58,32,39,37,100,39,46,10,0,0,0,0,0,0,0,0,102,117,108,108,0,0,0,0,68,97,116,117,109,95,84,114,117,99,105,97,108,95,67,111,97,115,116,95,49,57,52,56,0,0,0,0,0,0,0,0,115,97,100,0,0,0,0,0,109,115,115,50,0,0,0,0,68,105,114,101,99,116,32,112,97,100,100,105,110,103,32,105,109,112,111,115,115,105,98,108,101,32,97,108,108,111,99,97,116,105,110,103,32,110,101,119,32,102,114,97,109,101,10,0,100,101,112,114,101,99,97,116,101,100,0,0,0,0,0,0,101,118,97,108,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,109,51,100,0,0,0,0,0,100,101,102,97,117,108,116,0,100,101,102,97,117,108,116,0,50,45,119,97,121,32,109,97,116,99,104,32,43,32,51,114,100,32,109,97,116,99,104,32,40,115,97,109,101,32,111,114,100,101,114,41,32,111,110,32,99,111,109,98,101,100,32,40,112,47,99,32,43,32,117,41,0,0,0,0,0,0,0,0,66,111,111,115,116,32,111,114,32,99,117,116,32,108,111,119,101,114,32,102,114,101,113,117,101,110,99,105,101,115,46,0,121,117,118,106,52,52,48,112,0,0,0,0,0,0,0,0,67,114,105,109,115,111,110,0,114,111,111,116,0,0,0,0,85,78,75,78,79,87,78,0,116,111,112,32,102,114,111,110,116,32,114,105,103,104,116,0,108,117,109,97,32,98,105,99,117,98,105,99,32,47,32,99,104,114,111,109,97,32,98,105,108,105,110,101,97,114,0,0,115,114,99,104,0,0,0,0,99,111,109,112,101,110,115,97,116,105,110,103,32,97,117,100,105,111,32,116,105,109,101,115,116,97,109,112,32,100,114,105,102,116,58,37,102,32,99,111,109,112,101,110,115,97,116,105,111,110,58,37,100,32,105,110,58,37,100,10,0,0,0,0,115,97,114,0,0,0,0,0,101,120,104,97,117,115,116,105,118,101,32,115,101,97,114,99,104,0,0,0,0,0,0,0,86,52,43,32,83,116,121,108,101,115,0,0,0,0,0,0,68,97,116,117,109,95,84,114,105,110,105,100,97,100,95,49,57,48,51,0,0,0,0,0,112,114,101,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,97,100,112,99,109,95,105,109,97,95,111,107,105,0,0,0,79,114,105,103,105,110,97,108,32,66,105,116,32,83,116,114,101,97,109,0,0,0,0,0,73,110,118,97,108,105,100,32,116,101,109,112,111,32,118,97,108,117,101,32,39,37,115,39,10,0,0,0,0,0,0,0,79,114,105,103,105,110,97,108,32,66,105,116,32,83,116,114,101,97,109,0,0,0,0,0,110,101,119,32,99,111,117,112,108,105,110,103,32,99,111,111,114,100,105,110,97,116,101,115,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,73,110,118,97,108,105,100,32,118,68,107,49,91,37,100,93,58,32,37,100,10,0,0,0,67,97,110,111,112,117,115,32,76,111,115,115,108,101,115,115,32,67,111,100,101,99,0,0,83,83,82,0,0,0,0,0,112,114,101,115,116,114,101,97,109,32,60,61,32,98,117,102,32,43,32,108,101,110,103,116,104,0,0,0,0,0,0,0,115,101,108,101,99,116,32,97,32,99,111,108,111,114,32,99,117,114,118,101,115,32,112,114,101,115,101,116,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,79,108,100,32,40,60,97,108,112,104,97,51,41,32,84,104,101,111,114,97,32,98,105,116,115,116,114,101,97,109,44,32,102,108,105,112,112,101,100,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2077320);
/* memory initializer */ allocate([105,109,97,103,101,10,0,0,98,105,116,115,0,0,0,0,116,0,0,0,0,0,0,0,69,102,102,101,99,116,32,102,108,97,103,32,115,101,116,10,0,0,0,0,0,0,0,0,97,98,115,102,0,0,0,0,98,102,114,97,99,116,105,111,110,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,73,110,118,97,108,105,100,32,110,101,103,97,116,105,118,101,32,117,115,101,114,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,10,0,0,0,37,115,0,0,0,0,0,0,98,49,0,0,0,0,0,0,101,120,99,108,117,115,105,111,110,0,0,0,0,0,0,0,80,114,111,106,67,101,110,116,101,114,76,97,116,71,101,111,75,101,121,0,0,0,0,0,77,111,100,101,108,80,105,120,101,108,83,99,97,108,101,84,97,103,0,0,0,0,0,0,109,97,120,32,98,105,116,114,97,116,101,32,112,111,115,115,105,98,108,121,32,116,111,111,32,115,109,97,108,108,32,111,114,32,116,114,121,32,116,114,101,108,108,105,115,32,119,105,116,104,32,108,97,114,103,101,32,108,109,97,120,32,111,114,32,105,110,99,114,101,97,115,101,32,113,109,97,120,10,0,112,99,109,95,115,49,54,98,101,0,0,0,0,0,0,0,68,101,99,111,100,101,32,101,114,114,111,114,58,32,37,115,10,0,0,0,0,0,0,0,68,67,32,111,102,102,115,101,116,58,32,37,102,10,0,0,117,115,101,32,49,47,52,45,112,101,108,32,109,111,116,105,111,110,32,99,111,109,112,101,110,115,97,116,105,111,110,0,83,82,0,0,0,0,0,0,101,120,116,32,104,101,97,100,101,114,32,109,105,115,115,105,110,103,44,32,37,100,32,108,101,102,116,10,0,0,0,0,113,112,101,108,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,83,0,0,0,0,0,0,0,86,105,100,101,111,32,79,98,106,101,99,116,32,80,108,97,110,101,32,115,116,97,114,116,0,0,0,0,0,0,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,99,104,114,111,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,113,115,99,97,108,101,32,61,61,32,48,10,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,37,100,32,115,112,101,99,105,102,105,101,100,32,97,115,32,111,117,116,112,117,116,32,102,114,111,109,32,109,97,116,114,105,120,46,10,0,0,0,0,37,115,32,37,115,32,112,58,37,100,32,62,62,58,37,100,32,105,108,118,58,37,100,32,98,105,116,115,58,37,100,32,115,107,105,112,58,37,100,32,37,115,32,99,111,109,112,58,37,100,10,0,0,0,0,0,110,58,37,108,108,100,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,112,111,115,58,37,108,108,100,32,102,109,116,58,37,115,32,99,104,97,110,110,101,108,115,58,37,100,32,99,104,108,97,121,111,117,116,58,37,115,32,114,97,116,101,58,37,100,32,110,98,95,115,97,109,112,108,101,115,58,37,100,32,99,104,101,99,107,115,117,109,58,37,48,56,88,32,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,100,105,109,101,110,115,105,111,110,32,37,100,120,37,100,46,10,0,0,123,92,98,49,125,0,0,0,43,124,0,0,0,0,0,0,114,101,99,116,97,110,103,117,108,97,114,32,115,108,105,99,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,80,80,83,32,105,100,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,0,73,110,100,101,112,101,110,100,101,110,116,32,115,108,105,99,101,32,115,101,103,109,101,110,116,32,109,105,115,115,105,110,103,46,10,0,0,0,0,0,84,79,80,70,73,82,83,84,0,0,0,0,0,0,0,0,67,117,114,114,101,110,116,32,112,114,111,102,105,108,101,32,100,111,101,115,110,39,116,32,112,114,111,118,105,100,101,32,109,111,114,101,32,82,66,83,80,32,100,97,116,97,32,105,110,32,80,80,83,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,72,105,103,104,32,52,58,50,58,50,32,73,110,116,114,97,0,0,0,0,0,0,0,0,115,97,109,112,108,101,114,97,116,101,32,62,32,48,0,0,112,105,120,101,108,65,115,112,101,99,116,82,97,116,105,111,0,0,0,0,0,0,0,0,67,104,97,110,103,105,110,103,32,102,114,97,109,101,32,112,114,111,112,101,114,116,105,101,115,32,111,110,32,116,104,101,32,102,108,121,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,76,111,47,82,111,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,73,110,118,97,108,105,100,32,100,111,119,110,109,105,120,32,99,111,101,102,102,105,99,105,101,110,116,32,99,111,100,101,32,37,117,10,0,0,0,0,68,97,116,117,109,95,84,111,107,121,111,0,0,0,0,0,112,114,101,99,109,112,0,0,110,98,95,111,117,116,95,115,97,109,112,108,101,115,0,0,119,109,118,49,0,0,0,0,65,86,70,105,108,116,101,114,71,114,97,112,104,0,0,0,99,108,108,99,0,0,0,0,78,111,32,115,117,99,104,32,111,112,116,105,111,110,58,32,37,115,46,10,0,0,0,0,65,99,105,100,0,0,0,0,52,50,48,74,80,69,71,0,98,105,116,115,116,114,101,97,109,95,102,105,108,116,101,114,115,0,0,0,0,0,0,0,111,99,108,0,0,0,0,0,111,117,116,95,103,97,105,110,32,109,97,121,32,99,97,117,115,101,32,99,108,105,112,112,105,110,103,10,0,0,0,0,112,97,99,107,101,116,95,115,105,122,101,0,0,0,0,0,68,97,116,117,109,95,84,77,55,53,0,0,0,0,0,0,112,114,101,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,77,83,32,69,120,112,114,101,115,115,105,111,110,32,69,110,99,111,100,101,114,32,83,99,114,101,101,110,0,0,0,0,117,110,107,110,111,119,110,32,105,110,112,117,116,32,108,105,110,107,10,0,0,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,115,0,0,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,37,115,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,39,37,115,39,46,10,0,0,0,0,0,116,105,116,108,101,0,0,0,97,117,116,111,0,0,0,0,85,115,105,110,103,32,34,37,115,34,32,102,111,114,32,105,110,112,117,116,32,37,100,10,0,0,0,0,0,0,0,0,78,79,84,69,0,0,0,0,117,110,115,104,97,114,112,0,115,101,116,32,119,105,110,100,111,119,32,102,117,110,99,116,105,111,110,0,0,0,0,0,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,80,114,111,98,101,32,98,117,102,102,101,114,32,115,105,122,101,32,108,105,109,105,116,32,111,102,32,37,100,32,98,121,116,101,115,32,114,101,97,99,104,101,100,10,0,0,0,0,68,97,116,117,109,95,84,77,54,53,0,0,0,0,0,0,112,114,101,109,101,0,0,0,109,116,115,50,0,0,0,0,115,101,116,32,116,104,101,32,102,97,100,101,32,100,105,114,101,99,116,105,111,110,0,0,65,65,67,76,0,0,0,0,98,115,102,0,0,0,0,0,109,51,117,56,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,76,49,54,47,37,100,47,37,100,13,10,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,114,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,100,101,108,97,121,115,32,37,100,32,100,105,102,102,101,114,115,32,102,114,111,109,32,110,117,109,98,101,114,32,111,102,32,100,101,99,97,121,115,32,37,100,46,10,0,0,115,101,116,32,108,105,115,116,32,111,102,32,100,101,108,97,121,115,32,102,111,114,32,101,97,99,104,32,99,104,97,110,110,101,108,0,0,0,0,0,97,117,116,111,0,0,0,0,118,105,100,101,111,47,120,45,104,50,54,51,0,0,0,0,68,97,116,117,109,95,84,105,109,98,97,108,97,105,95,49,57,52,56,0,0,0,0,0,97,109,111,117,110,116,32,111,102,32,109,111,116,105,111,110,32,112,114,101,100,105,99,116,111,114,115,32,102,114,111,109,32,116,104,101,32,112,114,101,118,105,111,117,115,32,102,114,97,109,101,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,84,101,99,104,83,109,105,116,104,32,83,99,114,101,101,110,32,67,111,100,101,99,32,50,0,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,111,118,101,114,114,105,100,101,32,116,104,101,32,111,112,116,105,111,110,115,32,102,114,111,109,32,102,102,115,101,114,118,101,114,0,0,0,0,0,0,70,105,108,116,101,114,32,97,117,100,105,111,32,115,105,103,110,97,108,32,97,99,99,111,114,100,105,110,103,32,116,111,32,97,32,115,112,101,99,105,102,105,101,100,32,101,120,112,114,101,115,115,105,111,110,46,0,0,0,0,0,0,0,0,97,110,97,108,121,122,101,100,117,114,97,116,105,111,110,0,87,97,114,110,105,110,103,44,32,101,120,116,101,110,115,105,111,110,32,105,115,32,110,111,116,32,46,109,52,97,32,110,111,114,32,46,109,52,118,32,81,117,105,99,107,116,105,109,101,47,73,112,111,100,32,109,105,103,104,116,32,110,111,116,32,112,108,97,121,32,116,104,101,32,102,105,108,101,10,0,102,114,97,109,101,32,115,105,122,101,32,62,32,50,109,97,120,95,100,105,115,116,97,110,99,101,32,97,110,100,32,110,111,32,99,104,101,99,107,115,117,109,10,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,109,97,116,101,114,105,97,108,32,116,114,97,99,107,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,0,83,65,77,80,76,69,95,82,65,84,69,0,0,0,0,0,80,114,111,118,105,100,101,32,97,110,32,105,100,101,110,116,105,116,121,32,72,97,108,100,32,67,76,85,84,46,0,0,83,101,116,32,116,114,97,110,115,112,111,114,116,95,115,116,114,101,97,109,95,105,100,32,102,105,101,108,100,46,0,0,68,97,116,117,109,95,84,97,110,97,110,97,114,105,118,101,95,49,57,50,53,0,0,0,115,101,114,118,105,99,101,95,110,97,109,101,0,0,0,0,108,97,115,116,95,112,114,101,100,0,0,0,0,0,0,0,86,66,86,32,98,117,102,102,101,114,32,115,105,122,101,32,110,111,116,32,115,101,116,44,32,109,117,120,105,110,103,32,109,97,121,32,102,97,105,108,10,0,0,0,0,0,0,0,116,115,99,99,50,0,0,0,37,100,0,0,0,0,0,0,83,101,108,101,99,116,32,73,68,51,118,50,32,118,101,114,115,105,111,110,32,116,111,32,119,114,105,116,101,46,32,67,117,114,114,101,110,116,108,121,32,51,32,97,110,100,32,52,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,0,111,118,101,114,114,105,100,101,95,102,102,115,101,114,118,101,114,0,0,0,0,0,0,0,115,101,116,32,102,114,97,109,101,32,115,105,122,101,0,0,102,52,118,32,109,117,120,101,114,0,0,0,0,0,0,0,109,52,118,0,0,0,0,0,109,97,107,101,0,0,0,0,87,114,105,116,105,110,103,32,98,108,111,99,107,32,97,116,32,111,102,102,115,101,116,32,37,108,108,117,44,32,115,105,122,101,32,37,100,44,32,112,116,115,32,37,108,108,100,44,32,100,116,115,32,37,108,108,100,44,32,100,117,114,97,116,105,111,110,32,37,100,44,32,102,108,97,103,115,32,37,100,10,0,0,0,0,0,0,0,116,114,97,110,115,112,111,115,101,0,0,0,0,0,0,0,109,117,120,101,114,32,60,45,32,116,121,112,101,58,37,115,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,32,115,105,122,101,58,37,100,10,0,77,117,108,116,105,112,108,101,32,99,111,109,98,105,110,101,100,32,101,110,99,111,100,105,110,103,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,0,0,0,0,0,68,97,116,117,109,95,83,117,100,97,110,0,0,0,0,0,100,105,97,109,111,110,100,32,116,121,112,101,32,38,32,115,105,122,101,32,102,111,114,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,0,0,0,0,37,42,63,91,93,123,125,0,77,83,32,65,84,67,32,83,99,114,101,101,110,0,0,0,105,109,56,0,0,0,0,0,115,101,116,32,116,104,101,32,105,110,105,116,105,97,108,32,100,101,109,117,120,45,100,101,99,111,100,101,32,100,101,108,97,121,0,0,0,0,0,0,84,83,79,65,0,0,0,0,77,69,84,72,79,68,61,0,51,50,48,120,53,49,56,0,110,117,109,98,101,114,32,111,102,32,102,114,97,103,109,101,110,116,115,32,107,101,112,116,32,111,117,116,115,105,100,101,32,111,102,32,116,104,101,32,109,97,110,105,102,101,115,116,32,98,101,102,111,114,101,32,114,101,109,111,118,105,110,103,32,102,114,111,109,32,100,105,115,107,0,0,0,0,0,0,109,52,97,0,0,0,0,0,118,105,100,101,111,100,97,116,97,114,97,116,101,0,0,0,70,111,117,110,100,32,105,110,118,97,108,105,100,32,105,110,100,101,120,32,101,110,116,114,105,101,115,44,32,99,108,101,97,114,105,110,103,32,116,104,101,32,105,110,100,101,120,46,10,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,105,110,116,101,114,108,97,99,105,110,103,32,109,111,100,101,0,0,0,0,68,97,116,117,109,95,83,101,114,105,110,100,117,110,103,0,100,105,97,95,115,105,122,101,0,0,0,0,0,0,0,0,109,115,97,49,0,0,0,0,109,117,120,112,114,101,108,111,97,100,0,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,102,105,108,116,101,114,0,0,0,0,0,0,74,85,78,75,0,0,0,0,115,116,114,110,0,0,0,0,65,83,70,95,75,101,121,95,73,68,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,104,101,105,103,104,116,32,102,111,114,32,100,118,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,102,114,97,109,101,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,39,120,48,39,10,0,0,0,0,37,115,32,102,105,108,116,101,114,32,110,111,116,32,112,114,101,115,101,110,116,44,32,99,97,110,110,111,116,32,108,105,109,105,116,32,114,101,99,111,114,100,105,110,103,32,116,105,109,101,46,10,0,0,0,0,115,104,111,119,32,118,101,114,115,105,111,110,0,0,0,0,81,45,70,97,99,116,111,114,0,0,0,0,0,0,0,0,68,97,116,117,109,95,83,101,103,111,114,97,0,0,0,0,105,110,116,101,114,108,97,99,101,100,32,68,67,84,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,77,83,32,83,99,114,101,101,110,32,49,0,0,0,0,0,108,117,109,97,95,109,115,105,122,101,95,120,0,0,0,0,115,101,99,111,110,100,115,0,108,111,103,97,114,105,116,104,109,105,99,0,0,0,0,0,116,105,108,101,0,0,0,0,100,101,99,105,109,97,108,115,0,0,0,0,0,0,0,0,115,101,116,32,105,116,101,114,97,116,105,111,110,32,99,111,117,110,116,32,109,111,100,101,0,0,0,0,0,0,0,0,85,115,105,110,103,32,77,83,32,115,116,121,108,101,32,97,117,100,105,111,32,99,111,100,101,99,32,116,97,103,44,32,116,104,101,32,102,105,108,101,32,109,97,121,32,98,101,32,117,110,112,108,97,121,97,98,108,101,33,10,0,0,0,0,115,101,116,32,116,114,97,110,115,112,111,115,101,32,100,105,114,101,99,116,105,111,110,0,109,111,108,100,0,0,0,0,102,117,108,108,0,0,0,0,115,101,116,32,100,105,116,104,101,114,105,110,103,0,0,0,110,98,95,102,114,97,109,101,115,32,109,117,115,116,32,98,101,32,108,101,115,115,32,116,104,97,110,32,111,114,32,101,113,117,97,108,32,116,111,32,37,100,120,37,100,61,37,100,10,0,0,0,0,0,0,0,98,97,116,99,104,32,115,105,122,101,58,32,37,100,32,102,114,97,109,101,115,10,0,0,115,101,116,32,111,117,116,112,117,116,32,99,111,108,111,114,32,114,97,110,103,101,0,0,68,97,116,117,109,95,83,99,104,119,97,114,122,101,99,107,0,0,0,0,0,0,0,0,105,108,100,99,116,99,109,112,0,0,0,0,0,0,0,0,110,58,37,102,32,116,105,109,101,58,37,102,32,97,110,103,108,101,58,37,102,47,80,73,10,0,0,0,0,0,0,0,109,115,115,49,0,0,0,0,118,115,117,98,0,0,0,0,115,101,116,32,116,104,101,32,109,97,120,105,109,117,109,32,100,101,109,117,120,45,100,101,99,111,100,101,32,100,101,108,97,121,0,0,0,0,0,0,80,97,115,115,32,116,104,114,111,117,103,104,32,116,104,101,32,109,97,105,110,32,105,110,112,117,116,46,0,0,0,0,80,114,111,118,105,100,101,100,32,112,97,116,116,101,114,110,32,105,110,99,108,117,100,101,115,32,110,111,110,45,110,117,109,101,114,105,99,32,99,104,97,114,97,99,116,101,114,115,46,10,0,0,0,0,0,0,99,50,95,115,116,114,101,110,103,116,104,0,0,0,0,0,99,117,98,101,0,0,0,0,115,101,116,32,65,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,110,58,37,108,108,100,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,112,111,115,58,37,108,108,100,32,102,109,116,58,37,115,32,115,97,114,58,37,100,47,37,100,32,115,58,37,100,120,37,100,32,105,58,37,99,32,105,115,107,101,121,58,37,100,32,116,121,112,101,58,37,99,32,99,104,101,99,107,115,117,109,58,37,48,56,88,32,112,108,97,110,101,95,99,104,101,99,107,115,117,109,58,91,37,48,56,88,0,0,0,0,85,115,105,110,103,32,77,83,32,115,116,121,108,101,32,118,105,100,101,111,32,99,111,100,101,99,32,116,97,103,44,32,116,104,101,32,102,105,108,101,32,109,97,121,32,98,101,32,117,110,112,108,97,121,97,98,108,101,33,10,0,0,0,0,108,111,103,97,114,105,116,104,109,105,99,0,0,0,0,0,115,101,108,101,99,116,32,105,110,116,101,114,108,97,99,101,32,109,111,100,101,0,0,0,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,101,118,101,110,10,0,0,0,0,112,99,95,117,0,0,0,0,121,117,118,52,52,48,112,0,67,111,114,110,115,105,108,107,0,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,102,97,100,101,46,99,0,0,0,116,97,121,108,111,114,0,0,83,116,114,101,97,109,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,0,84,70,82,0,0,0,0,0,98,105,99,117,98,105,99,0,115,111,117,114,99,101,32,119,105,100,116,104,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,111,109,112,101,110,115,97,116,101,32,102,111,114,32,116,105,109,101,115,116,97,109,112,32,100,101,108,116,97,32,111,102,32,37,102,10,0,105,119,0,0,0,0,0,0,101,120,104,97,117,115,116,105,118,101,0,0,0,0,0,0,84,105,109,101,114,0,0,0,68,97,116,117,109,95,83,97,112,112,101,114,95,72,105,108,108,95,49,57,52,51,0,0,109,97,99,114,111,98,108,111,99,107,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,70,117,110,99,111,109,32,73,83,83,0,0,0,0,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,110,101,119,32,99,111,117,112,108,105,110,103,32,115,116,114,97,116,101,103,121,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,118,68,107,48,91,37,100,93,58,32,37,100,10,0,0,0,90,101,114,111,67,111,100,101,99,32,76,111,115,115,108,101,115,115,32,86,105,100,101,111,0,0,0,0,0,0,0,0,80,117,108,115,101,32,100,97,116,97,32,99,111,114,114,117,112,116,32,111,114,32,105,110,118,97,108,105,100,46,10,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,72,117,102,102,109,97,110,32,116,97,98,108,101,115,46,10,0,0,116,104,117,109,98,110,97,105,108,0,0,0,0,0,0,0,112,114,101,115,101,116,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,104,101,111,114,97,32,98,105,116,115,116,114,101,97,109,32,118,101,114,115,105,111,110,32,37,88,10,0,0,0,0,102,108,111,111,114,95,115,101,116,117,112,45,62,100,97,116,97,46,116,49,46,99,108,97,115,115,95,109,97,115,116,101,114,98,111,111,107,91,106,93,0,0,0,0,0,0,0,0,112,111,115,0,0,0,0,0,69,102,102,101,99,116,32,112,97,114,97,109,115,32,50,58,32,0,0,0,0,0,0,0,109,117,120,100,101,108,97,121,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,78,79,82,77,45,54,32,86,76,67,10,0,0,0,0,0,115,101,116,32,116,104,101,32,97,108,112,104,97,32,103,97,105,110,32,102,111,114,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,105,99,111,110,118,32,99,111,110,116,101,120,116,32,119,105,116,104,32,105,110,112,117,116,32,99,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,32,34,37,115,34,10,0,0,0,0,0,0,0,0,100,111,100,103,101,0,0,0,80,114,111,106,67,101,110,116,101,114,76,111,110,103,71,101,111,75,101,121,0,0,0,0,85,110,107,110,111,119,110,32,70,105,108,108,79,114,100,101,114,32,118,97,108,117,101,32,37,100,44,32,116,114,121,105,110,103,32,100,101,102,97,117,108,116,32,111,110,101,10,0,114,99,32,98,117,102,102,101,114,32,117,110,100,101,114,102,108,111,119,10,0,0,0,0,119,105,100,101,0,0,0,0,83,116,114,101,97,109,32,102,105,110,105,115,104,101,100,44,32,108,111,111,112,105,110,103,46,10,0,0,0,0,0,0,113,112,101,108,0,0,0,0,83,0,0,0,0,0,0,0,115,107,105,112,58,37,100,32,114,108,58,37,100,32,114,108,99,58,37,100,32,100,99,58,37,100,32,109,118,58,37,100,32,109,98,114,108,58,37,100,32,113,112,58,37,100,32,32,32,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,39,37,115,39,10,0,0,0,0,0,0,79,66,77,67,32,105,115,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,115,105,109,112,108,101,32,109,98,32,100,101,99,105,115,105,111,110,10,0,71,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,80,69,71,32,97,117,100,105,111,32,102,114,97,109,101,46,10,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,80,69,71,32,97,117,100,105,111,32,102,114,97,109,101,46,10,0,86,105,115,117,97,108,32,79,98,106,101,99,116,32,83,116,97,114,116,0,0,0,0,0,99,104,114,111,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,49,50,100,101,99,46,99,0,0,78,117,109,98,101,114,32,111,102,32,112,114,105,109,105,116,105,118,101,32,109,97,116,114,105,99,101,115,32,99,97,110,110,111,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,37,100,46,10,0,0,0,0,0,0,0,0,66,85,71,33,32,85,110,107,110,111,119,110,32,99,111,100,101,99,32,105,110,32,99,111,109,112,114,101,115,115,105,111,110,32,115,119,105,116,99,104,46,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,111,109,112,111,110,101,110,116,115,58,32,37,100,10,0,0,0,0,0,0,0,92,66,0,0,0,0,0,0,85,110,107,110,111,119,110,32,102,108,97,103,32,39,37,115,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,122,101,114,111,32,102,114,97,109,101,114,97,116,101,10,0,68,101,99,111,100,105,110,103,32,80,80,83,10,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,109,101,114,103,105,110,103,32,77,86,80,32,99,97,110,100,105,100,97,116,101,115,58,32,37,100,46,10,0,0,80,82,79,71,82,69,83,83,73,86,69,0,0,0,0,0,56,120,56,68,67,84,0,0,72,105,103,104,32,52,58,50,58,50,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,85,110,107,110,111,119,110,32,108,105,110,101,32,111,114,100,101,114,10,0,0,0,0,0,67,104,97,110,103,105,110,103,32,102,114,97,109,101,32,112,114,111,112,101,114,116,105,101,115,32,111,110,32,116,104,101,32,102,108,121,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,97,108,108,32,102,105,108,116,101,114,115,46,10,0,0,108,111,114,111,0,0,0,0,73,110,118,97,108,105,100,32,109,111,100,101,32,37,100,32,102,111,114,32,101,109,98,101,100,100,101,100,32,100,111,119,110,109,105,120,32,99,111,101,102,102,105,99,105,101,110,116,115,10,0,0,0,0,0,0,68,97,116,117,109,95,83,111,117,116,104,95,65,109,101,114,105,99,97,110,95,68,97,116,117,109,95,49,57,54,57,0,109,98,99,109,112,0,0,0,97,0,0,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,51,0,0,0,0,0,0,0,79,117,116,112,117,116,32,112,97,100,32,34,37,115,34,32,119,105,116,104,32,116,121,112,101,32,37,115,32,111,102,32,116,104,101,32,102,105,108,116,101,114,32,105,110,115,116,97,110,99,101,32,34,37,115,34,32,111,102,32,37,115,32,110,111,116,32,99,111,110,110,101,99,116,101,100,32,116,111,32,97,110,121,32,100,101,115,116,105,110,97,116,105,111,110,10,0,0,0,0,0,0,0,0,122,101,114,111,99,111,100,101,99,0,0,0,0,0,0,0,73,110,115,116,114,117,109,101,110,116,97,108,0,0,0,0,89,83,67,83,83,61,0,0,116,104,105,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,32,97,110,100,32,100,111,101,115,32,110,111,116,104,105,110,103,0,0,0,0,0,0,102,117,108,108,32,120,49,58,37,100,32,120,50,58,37,100,32,121,49,58,37,100,32,121,50,58,37,100,32,109,97,120,95,109,97,115,107,95,115,105,122,101,58,37,100,10,0,0,60,112,97,114,97,109,32,110,97,109,101,61,34,37,115,34,32,118,97,108,117,101,61,34,37,100,34,32,118,97,108,117,101,116,121,112,101,61,34,100,97,116,97,34,47,62,10,0,119,0,0,0,0,0,0,0,68,97,116,117,109,95,82,84,51,56,0,0,0,0,0,0,115,117,98,45,112,101,108,32,77,69,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,0,0,0,115,101,116,32,116,104,101,32,112,97,100,32,97,114,101,97,32,119,105,100,116,104,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,88,66,77,32,40,88,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,105,115,121,110,99,0,0,0,77,105,115,115,105,110,103,32,97,114,103,117,109,101,110,116,32,102,111,114,32,111,112,116,105,111,110,32,39,37,115,39,46,10,0,0,0,0,0,0,105,109,97,103,101,47,106,112,101,103,0,0,0,0,0,0,85,115,101,32,82,70,54,52,32,104,101,97,100,101,114,32,114,97,116,104,101,114,32,116,104,97,110,32,82,73,70,70,32,102,111,114,32,108,97,114,103,101,32,102,105,108,101,115,46,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,60,112,97,114,97,109,32,110,97,109,101,61,34,37,115,34,32,118,97,108,117,101,61,34,37,115,34,32,118,97,108,117,101,116,121,112,101,61,34,100,97,116,97,34,47,62,10,0,119,105,110,95,102,117,110,99,0,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,65,108,108,32,105,110,102,111,32,102,111,117,110,100,10,0,84,101,101,32,109,117,120,101,114,0,0,0,0,0,0,0,116,101,108,101,99,105,110,101,0,0,0,0,0,0,0,0,68,97,116,117,109,95,65,109,101,114,115,102,111,111,114,116,0,0,0,0,0,0,0,0,115,117,98,99,109,112,0,0,120,98,109,0,0,0,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,97,117,100,105,111,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,110,111,105,115,101,32,115,101,101,100,0,0,0,0,0,102,102,99,111,110,99,97,116,32,102,111,114,109,97,116,0,97,61,114,116,112,109,97,112,58,37,100,32,77,80,69,71,52,45,71,69,78,69,82,73,67,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,112,114,111,102,105,108,101,45,108,101,118,101,108,45,105,100,61,49,59,109,111,100,101,61,65,65,67,45,104,98,114,59,115,105,122,101,108,101,110,103,116,104,61,49,51,59,105,110,100,101,120,108,101,110,103,116,104,61,51,59,105,110,100,101,120,100,101,108,116,97,108,101,110,103,116,104,61,51,37,115,13,10,0,0,0,115,112,101,101,100,32,102,97,99,116,111,114,32,111,116,104,101,114,32,116,104,97,110,32,49,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,60,47,115,109,105,108,62,10,0,0,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,115,101,113,117,101,110,99,101,32,110,117,109,98,101,114,0,0,0,0,0,0,0,0,77,97,112,112,105,110,103,32,119,105,116,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,105,110,112,117,116,32,97,110,100,47,111,114,32,112,108,97,110,101,32,110,117,109,98,101,114,46,10,0,0,0,115,119,97,112,117,118,0,0,114,97,119,32,72,46,50,54,51,0,0,0,0,0,0,0,68,97,116,117,109,95,76,111,109,97,95,81,117,105,110,116,97,110,97,0,0,0,0,0,99,109,112,95,102,117,110,99,0,0,0,0,0,0,0,0,117,49,54,98,101,0,0,0,67,111,109,109,111,100,111,114,101,32,67,68,88,76,32,118,105,100,101,111,0,0,0,0,117,49,54,98,101,0,0,0,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,65,100,106,117,115,116,32,99,111,108,111,114,115,32,117,115,105,110,103,32,97,32,72,97,108,100,32,67,76,85,84,46,0,0,0,0,0,0,0,0,97,108,108,111,119,32,115,101,101,107,105,110,103,32,116,111,32,110,111,110,45,107,101,121,102,114,97,109,101,115,32,111,110,32,100,101,109,117,120,101,114,32,108,101,118,101,108,32,119,104,101,110,32,115,117,112,112,111,114,116,101,100,0,0,60,47,98,111,100,121,62,10,0,0,0,0,0,0,0,0,104,101,97,100,101,114,95,105,100,120,32,105,110,118,97,108,105,100,10,0,0,0,0,0,110,111,32,109,97,116,101,114,105,97,108,32,112,97,99,107,97,103,101,32,102,111,117,110,100,10,0,0,0,0,0,0,67,111,109,112,117,116,101,32,97,110,100,32,97,112,112,108,121,32,97,32,108,111,111,107,117,112,32,116,97,98,108,101,32,116,111,32,116,104,101,32,89,85,86,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,0,78,85,77,95,67,72,65,78,78,69,76,83,0,0,0,0,109,112,101,103,116,115,95,116,114,97,110,115,112,111,114,116,95,115,116,114,101,97,109,95,105,100,0,0,0,0,0,0,115,104,111,119,105,110,102,111,0,0,0,0,0,0,0,0,68,97,116,117,109,95,81,111,114,110,111,113,0,0,0,0,80,114,101,100,101,102,105,110,101,100,32,83,76,67,111,110,102,105,103,68,101,115,99,114,105,112,116,111,114,0,0,0,102,117,108,108,45,112,101,108,32,77,69,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,0,0,37,115,32,105,110,32,77,80,69,71,45,49,32,115,121,115,116,101,109,32,115,116,114,101,97,109,115,32,105,115,32,110,111,116,32,119,105,100,101,108,121,32,115,117,112,112,111,114,116,101,100,44,32,99,111,110,115,105,100,101,114,32,117,115,105,110,103,32,116,104,101,32,118,111,98,32,111,114,32,116,104,101,32,100,118,100,32,109,117,120,101,114,32,116,111,32,102,111,114,99,101,32,97,32,77,80,69,71,45,50,32,112,114,111,103,114,97,109,32,115,116,114,101,97,109,46,10,0,99,100,120,108,0,0,0,0,108,97,110,103,105,100,120,58,0,0,0,0,0,0,0,0,115,101,108,101,99,116,32,108,117,109,97,32,109,111,100,101,0,0,0,0,0,0,0,0,105,100,51,118,50,95,118,101,114,115,105,111,110,0,0,0,116,118,115,116,100,0,0,0,77,117,108,116,105,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,58,32,84,70,70,58,37,100,32,66,70,70,58,37,100,32,80,114,111,103,114,101,115,115,105,118,101,58,37,100,32,85,110,100,101,116,101,114,109,105,110,101,100,58,37,100,10,0,0,0,0,60,47,115,119,105,116,99,104,62,10,0,0,0,0,0,0,101,110,99,111,100,101,114,0,72,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,100,121,110,97,109,105,99,32,98,117,102,102,101,114,10,0,0,99,104,97,110,103,105,110,103,32,116,111,32,37,108,108,100,46,32,84,104,105,115,32,109,97,121,32,114,101,115,117,108,116,32,105,110,32,105,110,99,111,114,114,101,99,116,32,116,105,109,101,115,116,97,109,112,115,32,105,110,32,116,104,101,32,111,117,116,112,117,116,32,102,105,108,101,46,10,0,0,85,110,107,110,111,119,110,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,116,114,97,99,107,32,116,121,112,101,32,37,108,108,117,10,0,68,97,116,117,109,95,81,97,116,97,114,95,49,57,52,56,0,0,0,0,0,0,0,0,99,109,112,0,0,0,0,0,80,97,116,116,101,114,110,32,116,121,112,101,32,39,103,108,111,98,95,115,101,113,117,101,110,99,101,39,32,105,115,32,100,101,112,114,101,99,97,116,101,100,58,32,117,115,101,32,112,97,116,116,101,114,110,95,116,121,112,101,32,39,103,108,111,98,39,32,105,110,115,116,101,97,100,10,0,0,0,0,88,87,68,32,40,88,32,87,105,110,100,111,119,32,68,117,109,112,41,32,105,109,97,103,101,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,105,109,49,0,0,0,0,0,99,104,97,110,110,101,108,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,0,35,0,0,0,0,0,0,0,101,120,116,114,97,95,119,105,110,100,111,119,95,115,105,122,101,0,0,0,0,0,0,0,115,101,116,32,102,114,97,109,101,32,115,116,101,112,0,0,60,47,37,115,62,10,0,0,115,101,116,102,105,101,108,100,0,0,0,0,0,0,0,0,104,101,105,103,104,116,0,0,73,110,118,97,108,105,100,32,107,101,121,102,114,97,109,101,115,32,111,98,106,101,99,116,44,32,115,107,105,112,112,105,110,103,46,10,0,0,0,0,70,114,97,109,101,32,112,97,99,107,32,111,117,116,112,117,116,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,68,97,116,117,109,95,81,97,116,97,114,0,0,0,0,0,98,97,99,107,119,97,114,100,32,112,114,101,100,105,99,116,101,100,32,77,86,115,32,111,102,32,66,45,102,114,97,109,101,115,0,0,0,0,0,0,102,112,115,61,37,100,47,37,100,10,0,0,0,0,0,0,120,119,100,0,0,0,0,0,70,111,114,99,101,32,108,105,98,97,118,102,105,108,116,101,114,32,110,111,116,32,116,111,32,117,115,101,32,97,110,121,32,111,102,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,115,32,102,111,114,32,116,104,101,32,105,110,112,117,116,32,116,111,32,116,104,101,32,110,101,120,116,32,102,105,108,116,101,114,46,0,0,0,0,0,0,0,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,83,117,98,116,105,116,108,101,32,45,32,37,115,45,120,120,59,48,50,0,0,0,0,0,110,111,110,45,105,110,116,101,114,108,101,97,118,101,100,32,65,86,73,10,0,0,0,0,111,117,116,112,117,116,32,102,105,101,108,100,32,111,114,100,101,114,0,0,0,0,0,0,65,83,70,95,80,114,111,116,101,99,116,105,111,110,95,84,121,112,101,0,0,0,0,0,115,101,112,97,114,97,116,101,102,105,101,108,100,115,0,0,80,97,99,107,101,116,83,105,122,101,0,0,0,0,0,0,101,118,97,108,32,118,111,108,117,109,101,32,101,120,112,114,101,115,115,105,111,110,32,111,110,99,101,0,0,0,0,0,97,116,114,105,109,0,0,0,37,48,50,117,58,37,48,50,117,58,37,48,50,117,37,99,37,48,50,117,0,0,0,0,113,0,0,0,0,0,0,0,115,105,122,101,111,102,40,116,109,112,41,32,62,61,32,97,118,95,115,104,97,95,115,105,122,101,0,0,0,0,0,0,118,101,114,115,105,111,110,0,68,97,116,117,109,95,80,117,108,107,111,118,111,95,49,57,52,50,0,0,0,0,0,0,98,98,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,52,58,52,32,49,48,45,98,105,116,0,0,0,0,0,0,0,98,103,114,50,52,0,0,0,118,99,0,0,0,0,0,0,108,111,103,0,0,0,0,0,99,108,101,97,110,95,115,114,99,0,0,0,0,0,0,0,98,105,107,101,115,104,101,100,0,0,0,0,0,0,0,0,115,101,116,32,102,105,101,108,100,32,116,121,112,101,32,40,116,111,112,32,111,114,32,98,111,116,116,111,109,41,0,0,100,101,102,97,117,108,116,0,105,116,101,114,97,116,105,111,110,95,99,111,117,110,116,0,73,110,118,97,108,105,100,32,111,112,116,105,111,110,32,116,121,112,101,46,10,0,0,0,66,105,116,115,80,101,114,83,97,109,112,108,101,0,0,0,115,116,105,116,99,104,32,98,111,117,110,100,97,114,105,101,115,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,32,62,61,32,48,0,0,0,115,116,97,114,116,32,102,105,108,108,105,110,103,32,116,104,101,32,119,104,111,108,101,32,118,105,100,101,111,0,0,0,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,32,85,112,100,97,116,101,32,121,111,117,114,32,70,70,109,112,101,103,32,118,101,114,115,105,111,110,32,116,111,32,116,104,101,32,110,101,119,101,115,116,32,111,110,101,32,102,114,111,109,32,71,105,116,46,32,73,102,32,116,104,101,32,112,114,111,98,108,101,109,32,115,116,105,108,108,32,111,99,99,117,114,115,44,32,105,116,32,109,101,97,110,115,32,116,104,97,116,32,121,111,117,114,32,102,105,108,101,32,104,97,115,32,97,32,102,101,97,116,117,114,101,32,119,104,105,99,104,32,104,97,115,32,110,111,116,32,98,101,101,110,32,105,109,112,108,101,109,101,110,116,101,100,46,10,0,70,97,105,108,101,100,32,116,111,32,114,101,97,108,108,111,99,97,116,101,32,102,114,97,109,101,10,0,0,0,0,0,108,105,98,97,118,117,116,105,108,47,105,109,103,117,116,105,108,115,46,99,0,0,0,0,82,73,80,69,77,68,49,54,48,0,0,0,0,0,0,0,100,105,116,104,101,114,0,0,98,116,52,55,48,98,103,0,69,114,114,111,114,32,111,99,99,117,114,114,101,100,32,105,110,32,109,109,97,112,40,41,58,32,37,115,10,0,0,0,105,110,0,0,0,0,0,0,77,105,115,115,105,110,103,32,39,41,39,32,105,110,32,39,37,115,39,10,0,0,0,0,66,85,71,0,0,0,0,0,111,117,116,95,114,97,110,103,101,0,0,0,0,0,0,0,68,97,116,117,109,95,71,101,111,99,101,110,116,114,105,99,95,68,97,116,117,109,95,111,102,95,65,117,115,116,114,97,108,105,97,95,49,57,57,52,0,0,0,0,0,0,0,0,102,111,114,119,97,114,100,32,112,114,101,100,105,99,116,101,100,32,77,86,115,32,111,102,32,66,45,102,114,97,109,101,115,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,114,111,116,104,0,0,0,0,118,52,49,48,0,0,0,0,39,92,0,0,0,0,0,0,104,115,117,98,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,117,110,115,99,97,108,101,100,46,99,0,0,0,69,120,116,114,97,99,116,32,97,110,32,97,108,112,104,97,32,99,104,97,110,110,101,108,32,97,115,32,97,32,103,114,97,121,115,99,97,108,101,32,105,109,97,103,101,32,99,111,109,112,111,110,101,110,116,46], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2087560);
/* memory initializer */ allocate([0,0,0,0,0,0,0,0,100,101,115,99,0,0,0,0,115,101,116,32,99,97,110,118,97,115,32,115,105,122,101,32,40,87,120,72,32,111,114,32,97,98,98,114,101,118,105,97,116,105,111,110,41,0,0,0,100,101,115,99,0,0,0,0,112,97,115,115,0,0,0,0,100,101,112,114,101,99,97,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,117,115,101,100,44,32,109,97,107,101,32,115,117,114,101,32,121,111,117,32,100,105,100,32,115,101,116,32,114,97,110,103,101,32,99,111,114,114,101,99,116,108,121,10,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,110,111,105,115,101,32,115,101,101,100,0,0,0,0,0,83,108,105,99,101,115,32,115,116,97,114,116,32,105,110,32,116,104,101,32,109,105,100,100,108,101,33,10,0,0,0,0,115,101,116,32,99,111,100,101,98,111,111,107,32,108,101,110,103,116,104,0,0,0,0,0,51,100,108,0,0,0,0,0,102,97,115,116,95,98,105,108,105,110,101,97,114,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,10,0,0,0,0,0,0,48,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,83,97,109,112,108,105,110,103,82,97,116,101,0,0,0,0,115,101,116,32,104,105,103,104,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,108,105,110,101,97,114,0,0,111,115,102,0,0,0,0,0,33,115,45,62,111,117,116,95,99,104,95,108,97,121,111,117,116,32,124,124,32,111,117,116,45,62,99,104,95,99,111,117,110,116,32,61,61,32,97,118,95,103,101,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,95,110,98,95,99,104,97,110,110,101,108,115,40,115,45,62,111,117,116,95,99,104,95,108,97,121,111,117,116,41,0,0,0,0,0,0,0,66,105,113,117,97,100,32,102,105,108,116,101,114,32,109,117,115,116,32,104,97,118,101,32,111,114,100,101,114,32,111,102,32,50,10,0,0,0,0,0,105,105,100,95,112,97,114,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,50,45,119,97,121,32,109,97,116,99,104,32,43,32,51,114,100,32,109,97,116,99,104,32,111,110,32,99,111,109,98,101,100,32,40,112,47,99,32,43,32,117,41,0,0,0,0,0,103,114,97,121,49,54,108,101,0,0,0,0,0,0,0,0,67,111,114,110,102,108,111,119,101,114,66,108,117,101,0,0,48,0,0,0,0,0,0,0,77,65,88,86,65,76,0,0,119,104,105,108,101,0,0,0,83,84,82,69,65,77,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,0,116,111,112,32,102,114,111,110,116,32,99,101,110,116,101,114,0,0,0,0,0,0,0,0,97,114,101,97,32,97,118,101,114,97,103,105,110,103,0,0,115,114,99,119,0,0,0,0,97,100,100,105,110,103,32,37,100,32,97,117,100,105,111,32,115,97,109,112,108,101,115,32,111,102,32,115,105,108,101,110,99,101,10,0,0,0,0,0,105,110,95,119,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,109,111,100,101,0,0,0,80,108,97,121,82,101,115,89,0,0,0,0,0,0,0,0,68,97,116,117,109,95,80,111,105,110,116,101,95,78,111,105,114,101,0,0,0,0,0,0,102,111,114,119,97,114,100,32,112,114,101,100,105,99,116,101,100,32,77,86,115,32,111,102,32,80,45,102,114,97,109,101,115,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,105,115,115,0,0,0,68,114,97,119,32,97,32,99,111,108,111,114,101,100,32,103,114,105,100,32,111,110,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,0,0,0,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,117,112,108,105,110,103,32,114,97,110,103,101,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,95,98,97,110,100,115,95,48,58,32,37,100,10,0,0,0,0,0,0,0,0,68,120,116,111,114,121,0,0,80,117,108,115,101,32,116,111,111,108,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,101,105,103,104,116,32,115,104,111,114,116,32,115,101,113,117,101,110,99,101,46,10,0,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,109,111,100,101,32,86,76,67,10,0,0,0,0,0,115,105,122,101,32,109,105,115,109,97,116,99,104,32,37,100,32,37,100,32,37,100,10,0,67,97,110,110,111,116,32,117,115,101,32,110,101,120,116,32,112,105,99,116,117,114,101,32,105,110,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,10,0,0,0,65,100,100,105,116,105,111,110,97,108,32,115,117,98,115,116,114,101,97,109,115,0,0,0,99,117,114,118,101,115,32,37,100,32,40,105,110,116,105,100,61,37,100,41,32,91,37,100,32,112,111,105,110,116,115,93,58,32,91,37,115,93,10,0,107,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,104,117,102,102,109,97,110,32,116,114,101,101,32,111,118,101,114,102,108,111,119,10,0,0,114,101,115,95,115,101,116,117,112,45,62,98,111,111,107,115,91,106,93,91,107,93,0,0,110,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,101,102,102,101,99,116,32,112,97,114,97,109,101,116,101,114,115,10,0,0,0,0,0,99,97,110,118,97,115,95,115,105,122,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,97,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,116,111,110,101,115,58,32,37,100,32,40,109,97,120,46,32,52,56,41,44,32,102,114,97,109,101,58,32,37,100,33,10,0,0,0,0,0,0,0,85,84,70,45,56,0,0,0,92,37,49,91,98,105,115,117,93,37,49,91,48,49,92,125,93,37,110,0,0,0,0,0,100,105,118,105,100,101,0,0,80,114,111,106,70,97,108,115,101,79,114,105,103,105,110,78,111,114,116,104,105,110,103,71,101,111,75,101,121,0,0,0,68,101,102,97,117,108,116,44,0,0,0,0,0,0,0,0,67,111,108,111,114,32,109,111,100,101,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,105,110,118,97,108,105,100,32,109,105,110,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,101,108,101,109,101,110,116,32,99,104,97,110,110,101,108,32,99,111,117,110,116,10,0,0,73,110,99,111,114,114,101,99,116,32,115,108,105,99,101,32,115,105,122,101,10,0,0,0,40,99,41,67,82,73,0,0,113,98,108,117,114,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,87,65,86,0,0,0,98,105,116,115,32,102,111,114,32,97,108,112,104,97,32,112,108,97,110,101,0,0,0,0,67,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,99,111,100,101,99,10,0,0,0,119,0,0,0,0,0,0,0,117,115,101,32,102,111,117,114,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,112,101,114,32,109,97,99,114,111,98,108,111,99,107,32,40,77,80,69,71,45,52,41,0,82,84,67,83,84,65,82,84,0,0,0,0,0,0,0,0,113,115,99,97,108,101,58,37,100,32,114,108,99,58,37,100,32,114,108,58,37,100,32,100,99,58,37,100,32,109,98,114,108,58,37,100,32,115,108,105,99,101,58,37,100,32,32,32,10,0,0,0,0,0,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,65,70,67,0,0,0,0,0,52,77,86,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,0,103,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,86,105,100,101,111,32,83,101,115,115,105,111,110,32,69,114,114,111,114,0,0,0,0,0,115,101,116,32,116,104,101,32,108,101,110,103,116,104,32,111,102,32,116,104,101,32,99,121,99,108,101,32,116,111,32,117,115,101,32,102,111,114,32,100,101,106,117,100,100,101,114,105,110,103,0,0,0,0,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,108,117,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,0,0,109,98,95,121,32,60,32,115,45,62,109,98,95,104,101,105,103,104,116,0,0,0,0,0,77,97,116,114,105,99,101,115,32,109,97,121,32,99,104,97,110,103,101,32,111,110,108,121,32,111,110,99,101,32,112,101,114,32,97,99,99,101,115,115,32,117,110,105,116,46,10,0,100,101,99,111,100,101,95,115,111,115,58,32,105,110,100,101,120,40,37,100,41,32,111,117,116,32,111,102,32,99,111,109,112,111,110,101,110,116,115,10,0,0,0,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,102,111,114,32,90,76,73,66,58,32,40,37,100,41,46,10,0,0,0,0,0,0,83,117,112,112,111,114,116,32,102,111,114,32,105,109,97,103,101,32,111,102,102,115,101,116,115,0,0,0,0,0,0,0,65,84,83,67,32,65,47,53,50,65,32,40,65,67,45,51,41,0,0,0,0,0,0,0,123,92,105,48,125,0,0,0,124,43,93,0,0,0,0,0,66,97,100,32,85,70,69,80,32,116,121,112,101,32,40,37,100,41,10,0,0,0,0,0,80,97,114,115,101,100,32,83,80,83,58,32,105,100,32,37,100,59,32,99,111,100,101,100,32,119,120,104,58,32,37,100,120,37,100,59,32,99,114,111,112,112,101,100,32,119,120,104,58,32,37,100,120,37,100,59,32,112,105,120,95,102,109,116,58,32,37,115,46,10,0,0,73,110,118,97,108,105,100,32,99,111,108,108,111,99,97,116,101,100,95,114,101,102,95,105,100,120,58,32,37,100,46,10,0,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,101,95,116,121,112,101,0,0,65,84,83,67,32,65,47,53,50,65,32,40,65,67,45,51,41,0,0,0,0,0,0,0,82,69,68,85,0,0,0,0,108,111,114,111,95,99,101,110,116,101,114,95,109,105,120,95,108,101,118,101,108,0,0,0,72,105,103,104,32,49,48,32,73,110,116,114,97,0,0,0,32,108,112,99,32,112,114,101,99,105,115,105,111,110,58,32,37,100,10,0,0,0,0,0,65,84,83,67,32,65,47,53,50,66,32,40,65,67,45,51,44,32,69,45,65,67,45,51,41,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,108,97,99,100,101,99,46,99,0,0,0,0,85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,37,100,10,0,0,0,0,108,105,110,101,32,111,114,100,101,114,32,58,32,37,100,10,0,0,0,0,0,0,0,0,115,119,115,95,112,97,114,97,109,0,0,0,0,0,0,0,76,116,47,82,116,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,65,117,120,105,108,105,97,114,121,32,68,101,99,111,100,101,32,84,105,109,101,32,83,116,97,109,112,32,70,108,97,103,0,0,0,0,0,0,0,0,86,76,67,32,116,97,98,108,101,115,32,105,110,105,116,105,97,108,105,122,101,100,46,10,0,0,0,0,0,0,0,0,68,97,116,117,109,95,80,97,108,101,115,116,105,110,101,95,49,57,50,51,0,0,0,0,112,102,0,0,0,0,0,0,99,108,101,97,110,95,115,114,99,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,115,109,112,101,103,52,118,51,0,0,0,0,0,0,0,73,110,112,117,116,32,112,97,100,32,34,37,115,34,32,119,105,116,104,32,116,121,112,101,32,37,115,32,111,102,32,116,104,101,32,102,105,108,116,101,114,32,105,110,115,116,97,110,99,101,32,34,37,115,34,32,111,102,32,37,115,32,110,111,116,32,99,111,110,110,101,99,116,101,100,32,116,111,32,97,110,121,32,115,111,117,114,99,101,10,0,0,0,0,0,0,100,120,116,111,114,121,0,0,65,65,67,32,76,65,84,77,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,32,76,65,84,77,32,115,121,110,116,97,120,41,0,0,0,0,77,117,108,116,105,99,111,108,111,114,32,99,104,97,114,115,101,116,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,44,32,101,120,116,101,110,100,101,100,32,119,105,116,104,32,53,116,104,32,99,111,108,111,114,32,40,99,111,108,114,97,109,41,0,0,0,99,111,109,112,97,116,58,32,99,97,108,108,101,100,32,119,105,116,104,32,97,114,103,115,61,91,37,115,93,10,0,0,67,108,97,115,115,105,99,97,108,0,0,0,0,0,0,0,56,83,86,88,32,101,120,112,111,110,101,110,116,105,97,108,0,0,0,0,0,0,0,0,37,100,58,37,100,0,0,0,102,105,120,32,115,117,98,116,105,116,108,101,115,32,100,117,114,97,116,105,111,110,0,0,97,118,99,116,120,45,62,119,105,100,116,104,32,37,32,49,54,32,61,61,32,48,32,38,38,32,97,118,99,116,120,45,62,104,101,105,103,104,116,32,37,32,49,54,32,61,61,32,48,0,0,0,0,0,0,0,80,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,58,32,37,100,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,115,104,111,117,108,100,32,98,101,32,48,45,57,44,32,110,111,116,32,37,105,10,0,0,0,0,0,0,0,0,86,101,114,115,105,111,110,32,37,105,46,37,105,0,0,0,115,105,103,109,97,0,0,0,67,111,117,108,100,32,110,111,116,32,114,101,115,101,116,32,105,110,102,108,97,116,101,58,32,37,100,46,10,0,0,0,102,114,97,109,101,32,105,115,32,116,111,111,32,111,100,100,32,37,100,10,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,121,52,49,112,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,100,105,118,105,115,105,98,108,101,32,98,121,32,56,46,10,0,0,0,0,0,0,76,117,109,97,32,100,101,99,111,100,105,110,103,32,102,97,105,108,101,100,10,0,0,0,108,97,118,99,120,119,100,101,110,99,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,79,110,108,121,32,115,105,110,103,108,101,32,114,101,99,116,115,32,115,117,112,112,111,114,116,101,100,32,40,37,100,32,105,110,32,115,117,98,116,105,116,108,101,46,41,10,0,0,105,110,118,97,108,105,100,32,116,105,109,101,32,99,111,100,101,10,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,83,105,122,101,32,118,97,108,117,101,32,37,100,120,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,111,110,108,121,32,97,99,99,101,112,116,115,32,97,32,115,105,122,101,32,111,102,32,37,100,120,37,100,10,0,0,0,35,100,101,102,105,110,101,32,105,109,97,103,101,95,104,101,105,103,104,116,32,37,117,10,0,0,0,0,0,0,0,0,35,100,101,102,105,110,101,32,37,50,53,53,115,32,37,117,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,115,101,108,101,99,116,101,100,10,0,0,0,0,0,0,0,70,114,97,109,101,32,100,97,116,97,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,105,110,112,117,116,32,98,117,102,102,101,114,10,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,0,115,45,62,110,111,95,114,111,117,110,100,105,110,103,61,61,49,0,0,0,0,0,0,0,83,117,112,101,114,102,114,97,109,101,32,101,110,99,111,100,101,115,32,62,52,56,48,32,115,97,109,112,108,101,115,32,40,37,100,41,44,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,0,0,0,65,117,100,105,111,84,97,103,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,108,111,115,115,32,100,101,116,101,99,116,101,100,33,32,115,101,113,32,37,120,32,118,115,32,37,120,10,0,0,0,0,0,66,105,116,115,116,114,101,97,109,32,115,112,108,105,99,105,110,103,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,50,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,50,0,0,0,92,78,0,0,0,0,0,0,109,105,115,115,105,110,103,32,87,69,66,80,32,116,97,103,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,66,108,111,99,107,32,37,100,32,104,97,115,32,105,110,118,97,108,105,100,32,115,105,122,101,32,40,115,105,122,101,32,37,100,32,118,115,46,32,37,100,32,98,121,116,101,115,32,108,101,102,116,41,10,0,0,112,114,111,98,108,101,109,58,32,102,111,117,110,100,32,98,111,116,104,32,67,80,76,48,32,97,110,100,32,67,80,76,90,32,99,104,117,110,107,115,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,98,108,111,99,107,32,98,117,102,102,101,114,115,10,0,0,0,0,0,0,0,79,110,50,32,86,80,56,0,79,110,50,32,86,80,54,32,40,70,108,97,115,104,32,118,101,114,115,105,111,110,41,0,73,110,118,97,108,105,100,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,79,110,50,32,86,80,51,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,32,40,37,102,59,37,102,41,0,0,0,0,0,0,0,0,68,97,116,117,109,95,80,97,100,97,110,103,95,49,56,56,52,0,0,0,0,0,0,0,100,101,98,117,103,95,109,118,0,0,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,99,111,109,109,101,110,116,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,0,83,101,116,117,112,32,104,101,97,100,101,114,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,86,66,76,69,32,76,111,115,115,108,101,115,115,32,67,111,100,101,99,0,0,0,0,0,83,105,101,114,114,97,32,86,77,68,32,97,117,100,105,111,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,105,120,95,115,117,98,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,37,115,46,10,0,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,109,101,116,97,100,97,116,97,32,101,110,116,114,121,59,32,107,101,121,58,37,115,44,32,116,121,112,101,58,37,100,44,32,108,101,110,103,116,104,58,48,120,37,120,10,0,0,0,0,0,0,0,114,102,54,52,0,0,0,0,76,79,79,80,70,73,76,84,69,82,32,115,104,97,108,108,32,110,111,116,32,98,101,32,101,110,97,98,108,101,100,32,105,110,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,10,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,86,66,76,69,32,86,101,114,115,105,111,110,58,32,37,100,10,0,0,0,80,97,108,101,116,116,101,32,99,104,97,110,103,101,32,114,117,110,115,32,98,101,121,111,110,100,32,101,110,116,114,121,32,50,53,54,10,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,118,52,49,48,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,46,10,0,0,0,0,0,0,0,0,99,111,100,105,110,103,95,104,105,115,116,111,114,121,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,81,84,32,52,58,52,58,52,58,52,0,0,115,101,116,32,116,104,101,32,119,105,100,116,104,32,99,114,111,112,32,97,114,101,97,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,81,84,32,52,58,52,58,52,58,52,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,118,51,48,56,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,46,10,0,0,0,0,0,0,0,0,40,80,114,111,98,97,98,108,121,41,32,112,97,100,100,101,100,32,100,97,116,97,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,78,65,77,69,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,69,114,114,111,114,32,101,110,99,111,100,105,110,103,32,112,108,97,110,101,32,37,100,46,10,0,0,0,0,0,0,0,87,77,65,80,0,0,0,0,73,110,99,111,114,114,101,99,116,32,115,108,105,99,101,32,115,105,122,101,10,0,0,0,99,111,108,111,114,32,115,97,116,117,114,97,116,105,111,110,32,109,117,108,116,105,112,108,105,101,114,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,117,116,105,108,115,46,99,0,0,0,0,0,0,119,97,114,110,105,110,103,58,32,117,110,107,110,111,119,110,32,101,115,99,97,112,101,32,48,120,37,48,50,88,10,0,100,101,112,116,104,32,111,102,32,37,105,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,105,110,116,101,114,114,117,112,116,101,100,10,0,0,0,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,77,68,67,84,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,114,101,100,32,103,97,105,110,32,102,111,114,32,116,104,101,32,114,101,100,32,99,104,97,110,110,101,108,0,0,0,0,70,114,97,109,101,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,73,110,102,108,97,116,101,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,67,104,97,110,110,101,108,32,99,111,117,110,116,32,37,100,0,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,110,111,32,115,112,97,99,101,32,102,111,114,32,116,109,50,95,114,101,97,100,95,115,116,114,101,97,109,10,0,0,0,73,110,118,97,108,105,100,32,105,110,100,101,120,32,118,97,108,117,101,46,10,0,0,0,78,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,10,0,0,0,0,0,0,68,97,116,117,109,95,79,83,95,83,78,95,49,57,56,48,0,0,0,0,0,0,0,0,118,105,115,117,97,108,105,122,101,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,40,77,86,115,41,0,0,118,98,108,101,0,0,0,0,115,101,116,32,114,101,100,32,115,104,97,100,111,119,115,0,102,111,114,99,101,32,115,117,98,116,105,116,108,101,32,116,97,103,47,102,111,117,114,99,99,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,102,102,99,111,110,99,97,116,0,0,0,0,0,0,0,0,65,65,67,32,119,105,116,104,32,110,111,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,32,105,115,32,99,117,114,114,101,110,116,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,113,0,0,0,0,0,0,65,65,67,76,0,0,0,0,115,101,113,0,0,0,0,0,71,101,111,103,114,97,112,104,105,99,84,121,112,101,71,101,111,75,101,121,0,0,0,0,37,115,37,53,105,0,0,0,104,50,54,51,0,0,0,0,73,70,68,32,111,102,102,115,101,116,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,105,109,97,103,101,32,115,105,122,101,10,0,0,86,80,108,97,121,101,114,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,80,105,120,101,108,32,102,111,114,109,97,116,32,39,37,115,39,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,70,105,108,101,32,119,105,116,104,111,117,116,32,99,111,108,111,114,109,97,112,32,104,97,115,32,99,111,108,111,114,109,97,112,32,105,110,102,111,114,109,97,116,105,111,110,32,115,101,116,46,10,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,58,32,37,100,10,0,0,68,97,116,117,109,95,79,83,71,66,95,49,57,55,48,95,83,78,0,0,0,0,0,0,37,99,32,104,112,101,108,58,37,100,44,32,116,112,101,108,58,37,100,32,97,113,112,58,37,100,32,113,112,58,37,100,44,32,115,108,105,99,101,95,110,117,109,58,37,48,50,88,10,0,0,0,0,0,0,0,118,105,115,109,118,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,89,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,84,73,70,70,47,73,70,70,47,69,88,80,69,82,73,77,69,78,84,65,76,32,40,99,111,109,112,114,101,115,115,105,111,110,41,32,116,121,112,101,0,0,0,0,0,0,0,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,32,118,105,100,101,111,0,0,65,86,80,97,99,107,101,116,32,105,115,32,110,111,116,32,99,108,101,97,110,32,40,99,111,110,116,97,105,110,115,32,116,105,109,105,110,103,32,105,110,102,111,114,109,97,116,105,111,110,41,46,32,89,111,117,32,110,101,101,100,32,116,111,32,117,112,103,114,97,100,101,32,121,111,117,114,32,108,105,98,97,118,102,111,114,109,97,116,32,111,114,32,115,97,110,105,116,105,122,101,32,121,111,117,114,32,112,97,99,107,101,116,46,10,0,0,0,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,65,77,86,32,86,105,100,101,111,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,83,111,110,105,99,32,108,111,115,115,108,101,115,115,0,0,115,116,97,103,0,0,0,0,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,45,62,100,97,116,97,91,48,93,0,0,0,0,0,101,114,114,111,114,32,97,116,32,101,110,100,32,111,102,32,102,114,97,109,101,10,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,112,101,114,32,106,112,101,103,46,10,0,0,0,0,0,83,77,67,32,100,101,99,111,100,101,114,32,106,117,115,116,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,114,111,119,32,112,116,114,32,61,32,37,100,44,32,104,101,105,103,104,116,32,61,32,37,100,41,10,0,0,0,0,0,0,0,0,83,109,97,99,107,101,114,32,97,117,100,105,111,0,0,0,115,101,116,32,109,105,110,105,109,117,109,32,100,101,116,101,99,116,101,100,32,98,108,97,99,107,32,100,117,114,97,116,105,111,110,32,105,110,32,115,101,99,111,110,100,115,0,0,49,54,107,0,0,0,0,0,115,101,101,107,50,97,110,121,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,115,104,111,114,116,101,110,32,102,117,110,99,116,105,111,110,32,37,100,10,0,0,0,0,98,97,100,32,109,97,103,105,99,32,110,117,109,98,101,114,10,0,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,112,97,108,101,116,116,101,32,98,108,111,99,107,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,0,92,78,0,0,0,0,0,0,69,110,99,111,100,105,110,103,32,37,100,32,99,104,97,110,110,101,108,40,115,41,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,46,32,79,110,108,121,32,50,44,32,52,44,32,54,32,97,110,100,32,56,32,99,104,97,110,110,101,108,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,102,114,97,109,101,32,104,97,115,32,105,110,118,97,108,105,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,68,113,117,97,110,116,32,102,111,114,32,66,45,102,114,97,109,101,10,0,0,0,0,0,78,101,119,32,102,114,97,109,101,32,98,117,116,32,115,116,105,108,108,32,37,100,32,77,66,32,108,101,102,116,46,10,0,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,45,32,110,101,101,100,32,97,116,32,108,101,97,115,116,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,10,0,0,0,0,0,0,0,0,68,105,115,112,108,97,121,72,101,105,103,104,116,0,0,0,115,45,62,117,110,114,101,115,116,114,105,99,116,101,100,95,109,118,32,61,61,32,48,0,110,117,116,47,109,117,108,116,105,109,101,100,105,97,32,99,111,110,116,97,105,110,101,114,0,0,0,0,0,0,0,0,115,101,116,32,109,105,110,105,109,117,109,32,108,117,109,105,110,97,110,99,101,32,118,97,108,117,101,32,102,111,114,32,98,111,117,110,100,105,110,103,32,98,111,120,0,0,0,0,114,118,50,48,0,0,0,0,77,79,86,32,99,104,117,110,107,32,115,105,122,101,32,33,61,32,101,110,99,111,100,101,100,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,68,105,109,101,110,115,105,111,110,115,32,109,117,115,116,32,98,101,32,100,105,118,105,115,105,98,108,101,32,98,121,32,49,54,10,0,0,0,0,0,67,104,117,110,107,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,65,117,100,105,111,32,109,117,115,116,32,98,101,32,50,50,48,53,48,32,72,122,10,0,105,110,118,97,108,105,100,32,118,105,100,101,111,95,98,97,115,101,10,0,0,0,0,0,60,98,114,62,0,0,0,0,69,114,114,111,114,32,42,115,116,114,101,97,109,95,105,100,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,97,118,99,116,120,45,62,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,61,61,32,50,0,0,0,0,0,0,0,105,84,101,120,0,0,0,0,87,114,111,110,103,32,112,97,99,107,101,116,32,116,97,105,108,115,32,97,114,101,32,119,114,111,110,103,33,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,98,108,111,99,107,32,97,108,105,103,110,10,0,0,0,0,0,0,0,0,65,74,65,32,75,111,110,97,32,49,48,45,98,105,116,32,82,71,66,32,67,111,100,101,99,0,0,0,0,0,0,0,105,110,100,101,120,32,101,110,116,114,121,32,37,105,32,43,32,84,101,109,112,111,114,97,108,79,102,102,115,101,116,32,37,105,32,61,32,37,105,44,32,119,104,105,99,104,32,105,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,65,74,65,32,75,111,110,97,32,49,48,45,98,105,116,32,82,71,66,32,67,111,100,101,99,0,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,80,114,111,98,108,101,109,58,32,112,105,120,101,108,95,112,116,114,32,61,32,37,100,44,32,112,105,120,101,108,95,108,105,109,105,116,32,61,32,37,100,10,0,0,0,0,0,0,66,111,103,117,115,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,40,37,105,44,37,105,41,44,32,98,108,111,99,107,32,115,105,122,101,32,37,105,120,37,105,32,97,116,32,37,105,44,37,105,10,0,80,97,108,101,116,116,101,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,117,10,0,68,69,70,65,85,76,84,95,86,79,76,0,0,0,0,0,84,104,105,115,32,102,105,108,101,32,116,114,105,103,103,101,114,115,32,115,111,109,101,32,109,105,115,115,105,110,103,32,99,111,100,101,46,32,80,108,101,97,115,101,32,99,111,110,116,97,99,116,32,116,104,101,32,100,101,118,101,108,111,112,101,114,115,46,10,80,111,115,105,116,105,111,110,58,32,37,115,10,0,0,0,0,0,0,66,105,116,114,97,116,101,32,105,115,32,49,47,56,32,97,110,100,32,102,105,114,115,116,32,49,54,32,98,105,116,115,32,97,114,101,32,111,110,46,0,0,0,0,0,0,0,0,111,102,102,115,101,116,32,33,61,32,48,120,50,99,0,0,83,101,116,32,116,104,101,32,112,105,120,101,108,32,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,46,0,0,0,0,0,0,97,108,112,104,97,32,98,105,116,115,32,115,104,111,117,108,100,32,98,101,32,48,44,32,56,32,111,114,32,49,54,10,0,0,0,0,0,0,0,0,115,108,105,99,101,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,0,0,77,80,69,71,84,83,32,109,117,120,101,114,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,68,97,116,117,109,95,79,83,71,66,95,49,57,51,54,0,80,71,77,89,85,86,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,32,89,85,86,41,32,105,109,97,103,101,0,0,0,0,0,116,105,109,101,115,116,97,109,112,95,108,101,110,32,62,32,54,52,0,0,0,0,0,0,116,104,114,101,97,100,105,110,103,32,111,112,101,114,97,116,105,111,110,115,0,0,0,0,80,71,77,89,85,86,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,32,89,85,86,41,32,105,109,97,103,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,10,0,113,117,101,117,101,45,62,97,118,97,105,108,97,98,108,101,0,0,0,0,0,0,0,0,49,46,50,46,53,0,0,0,98,109,118,95,118,105,100,101,111,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,76,69,32,100,97,116,97,32,108,101,110,103,116,104,32,37,117,32,105,115,32,37,117,32,98,121,116,101,115,32,115,104,111,114,116,101,114,32,116,104,97,110,32,101,120,112,101,99,116,101,100,10,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,102,109,116,10,0,0,0,0,0,37,100,58,37,100,58,37,100,58,37,100,0,0,0,0,0,105,110,118,97,108,105,100,32,105,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,10,0,0,0,0,0,0,0,77,80,51,32,109,117,120,101,114,0,0,0,0,0,0,0,102,111,114,99,101,32,115,117,98,116,105,116,108,101,32,99,111,100,101,99,32,40,39,99,111,112,121,39,32,116,111,32,99,111,112,121,32,115,116,114,101,97,109,41,0,0,0,0,112,99,109,95,102,51,50,98,101,0,0,0,0,0,0,0,98,108,111,99,107,95,115,105,122,101,32,104,97,115,32,99,104,97,110,103,101,100,32,37,100,32,33,61,32,37,100,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,71,82,65,89,83,67,65,76,69,0,0,0,0,0,0,0,65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,65,117,100,105,111,0,0,0,0,0,0,115,116,97,114,116,105,0,0,97,112,112,108,105,99,97,116,105,111,110,47,102,52,118,0,68,105,115,112,108,97,121,87,105,100,116,104,0,0,0,0,103,101,110,114,101,0,0,0,67,97,110,39,116,32,119,114,105,116,101,32,112,97,99,107,101,116,32,119,105,116,104,32,117,110,107,110,111,119,110,32,116,105,109,101,115,116,97,109,112,10,0,0,0,0,0,0,101,110,99,111,100,101,114,0,97,98,111,114,116,105,110,103,46,10,0,0,0,0,0,0,82,101,97,100,32,97,117,100,105,111,32,102,114,111,109,32,97,32,109,111,118,105,101,32,115,111,117,114,99,101,46,0,84,114,105,101,100,32,116,111,32,99,111,112,121,32,65,86,67,111,100,101,99,67,111,110,116,101,120,116,32,37,112,32,105,110,116,111,32,97,108,114,101,97,100,121,45,105,110,105,116,105,97,108,105,122,101,100,32,37,112,10,0,0,0,0,110,111,116,32,97,32,110,117,118,32,118,105,100,101,111,32,102,114,97,109,101,10,0,0,78,101,108,108,121,109,111,115,101,114,32,119,111,114,107,115,32,111,110,108,121,32,119,105,116,104,32,56,48,48,48,44,32,49,54,48,48,48,44,32,49,49,48,50,53,44,32,50,50,48,53,48,32,97,110,100,32,52,52,49,48,48,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,76,101,102,116,111,118,101,114,32,98,121,116,101,115,58,32,37,100,46,10,0,0,0,0,104,117,102,102,109,97,110,32,116,97,98,108,101,32,100,101,99,111,100,101,32,101,114,114,111,114,10,0,0,0,0,0,68,97,116,117,109,95,78,83,87,67,95,57,90,95,50,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,116,105,111,110,32,86,105,100,101,111,32,67,111,109,112,114,101,115,115,111,114,32,50,0,0,0,0,0,0,116,104,114,101,97,100,95,111,112,115,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,80,97,115,115,32,111,110,32,116,104,101,32,97,117,100,105,111,32,105,110,112,117,116,32,116,111,32,78,32,97,117,100,105,111,32,111,117,116,112,117,116,115,46,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,32,37,88,10,0,0,78,111,32,115,117,99,104,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,115,46,10,0,0,0,0,0,0,85,116,32,86,105,100,101,111,0,0,0,0,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,103,114,97,110,100,99,104,105,108,100,114,101,110,10,0,0,0,0,0,0,0,70,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,32,116,111,111,32,115,109,97,108,108,0,0,0,0,0,0,0,0,98,121,116,101,115,116,114,101,97,109,32,111,118,101,114,114,117,110,10,0,0,0,0,0,114,115,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,115,99,111,100,101,99,0,0,123,92,105,49,125,0,0,0,84,68,69,78,0,0,0,0,82,68,32,111,112,116,105,109,97,108,32,77,66,32,108,101,118,101,108,32,114,101,115,105,100,117,97,108,32,115,107,105,112,112,105,110,103,0,0,0,35,69,88,84,73,78,70,58,0,0,0,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,102,114,97,103,109,101,110,116,115,32,107,101,112,116,32,105,110,32,116,104,101,32,109,97,110,105,102,101,115,116,0,0,0,0,0,0,0,0,33,112,105,99,45,62,102,46,98,117,102,91,48,93,0,0,77,97,120,72,101,105,103,104,116,0,0,0,0,0,0,0,83,101,116,32,80,84,83,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,97,117,100,105,111,32,102,114,97,109,101,46,0,0,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,119,105,100,116,104,0,0,0,102,105,108,101,112,111,115,105,116,105,111,110,115,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,109,112,101,103,52,0,0,0,115,99,97,108,101,0,0,0,98,101,102,111,114,101,32,118,111,112,95,99,111,100,105,110], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2097800);
/* memory initializer */ allocate([103,95,116,121,112,101,32,105,110,32,118,105,100,101,111,32,112,97,99,107,101,100,32,104,101,97,100,101,114,0,0,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,68,97,116,117,109,95,78,111,117,118,101,108,108,101,95,84,114,105,97,110,103,117,108,97,116,105,111,110,95,70,114,97,110,99,97,105,115,101,0,0,112,105,99,116,117,114,101,32,98,117,102,102,101,114,32,97,108,108,111,99,97,116,105,111,110,115,0,0,0,0,0,0,77,80,69,71,45,50,32,118,105,100,101,111,0,0,0,0,117,116,118,105,100,101,111,0,84,111,111,32,115,109,97,108,108,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,40,37,105,41,33,10,0,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,110,111,116,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,46,32,101,120,116,114,97,32,98,121,116,101,115,32,97,116,32,116,104,101,32,101,110,100,32,119,105,108,108,32,98,101,32,115,107,105,112,112,101,100,46,10,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,65,83,83,32,101,118,101,110,116,46,10,0,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,100,101,32,115,105,122,101,32,37,100,47,37,100,10,0,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,100,105,115,97,98,108,101,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,84,114,117,101,72,68,0,0,109,108,112,112,97,114,115,101,58,32,80,97,114,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,46,10,0,108,105,98,97,118,99,111,100,101,99,47,109,106,112,101,103,101,110,99,46,99,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,78,111,110,45,105,110,116,101,114,108,101,97,118,101,100,32,65,86,73,32,119,105,116,104,111,117,116,32,105,110,100,101,120,44,32,115,119,105,116,99,104,105,110,103,32,116,111,32,105,110,116,101,114,108,101,97,118,101,100,10,0,0,0,0,102,105,101,108,100,32,115,105,122,101,58,32,48,120,37,120,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,119,105,100,116,104,47,104,101,105,103,104,116,33,10,0,0,65,86,80,97,99,107,101,116,32,105,115,32,110,111,116,32,99,108,101,97,110,32,40,99,111,110,116,97,105,110,115,32,116,105,109,105,110,103,32,105,110,102,111,114,109,97,116,105,111,110,32,97,110,100,32,97,32,116,114,97,105,108,105,110,103,32,108,105,110,101,32,98,114,101,97,107,41,46,32,89,111,117,32,110,101,101,100,32,116,111,32,117,112,103,114,97,100,101,32,121,111,117,114,32,108,105,98,97,118,102,111,114,109,97,116,32,111,114,32,115,97,110,105,116,105,122,101,32,121,111,117,114,32,112,97,99,107,101,116,46,10,0,0,0,83,101,99,114,101,116,32,100,97,116,97,58,10,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,116,97,103,32,37,48,56,88,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,99,32,99,111,100,101,32,97,116,10,0,0,0,0,0,77,97,120,87,105,100,116,104,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,105,110,112,117,116,32,102,114,97,109,101,115,32,97,110,100,32,115,101,110,100,32,116,104,101,109,32,119,104,101,110,32,116,104,101,121,32,97,114,101,32,114,101,113,117,101,115,116,101,100,46,0,0,0,0,0,0,77,65,67,69,32,40,77,97,99,105,110,116,111,115,104,32,65,117,100,105,111,32,67,111,109,112,114,101,115,115,105,111,110,47,69,120,112,97,110,115,105,111,110,41,32,54,58,49,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,76,105,109,105,116,101,100,32,114,97,110,103,101,32,89,85,86,32,105,115,32,110,111,110,45,115,116,97,110,100,97,114,100,44,32,115,101,116,32,115,116,114,105,99,116,95,115,116,100,95,99,111,109,112,108,105,97,110,99,101,32,116,111,32,97,116,32,108,101,97,115,116,32,117,110,111,102,102,105,99,105,97,108,32,116,111,32,117,115,101,32,105,116,46,10,0,68,101,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,111,110,99,101,0,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,90,76,73,66,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,111,102,102,115,101,116,115,10,0,0,85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,37,105,10,0,0,102,114,97,109,101,32,102,105,110,105,115,104,101,100,32,119,105,116,104,32,37,100,32,100,105,102,102,10,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,32,116,121,112,101,32,37,105,10,0,0,0,0,0,0,83,101,116,32,116,105,109,101,98,97,115,101,32,102,111,114,32,116,104,101,32,97,117,100,105,111,32,111,117,116,112,117,116,32,108,105,110,107,46,0,116,114,105,109,0,0,0,0,10,0,0,0,0,0,0,0,74,80,69,71,45,76,83,32,112,97,114,97,109,115,58,32,37,105,120,37,105,32,78,69,65,82,61,37,105,32,77,86,61,37,105,32,84,40,37,105,44,37,105,44,37,105,41,32,82,69,83,69,84,61,37,105,44,32,76,73,77,73,84,61,37,105,44,32,113,98,112,112,61,37,105,44,32,82,65,78,71,69,61,37,105,10,0,0,83,79,67,32,109,97,114,107,101,114,32,110,111,116,32,112,114,101,115,101,110,116,10,0,114,101,115,32,43,32,49,32,60,32,40,48,120,55,102,102,102,102,102,102,102,41,0,0,86,77,0,0,0,0,0,0,100,119,116,10,0,0,0,0,72,122,0,0,0,0,0,0,80,97,115,115,119,111,114,100,45,112,114,111,116,101,99,116,101,100,32,99,108,105,112,33,10,0,0,0,0,0,0,0,68,97,116,117,109,95,68,97,116,117,109,95,55,51,0,0,98,117,102,102,101,114,115,0,32,85,77,86,0,0,0,0,100,101,99,111,100,101,32,102,105,110,105,115,104,101,100,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,108,101,102,116,32,111,118,101,114,10,0,0,0,0,0,0,0,0,73,110,116,101,108,32,72,50,54,51,32,102,114,101,101,32,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,32,73,109,97,103,101,32,118,50,0,0,45,104,101,108,112,0,0,0,65,108,108,111,99,97,116,101,100,32,116,105,108,101,32,115,105,122,101,32,37,100,32,109,105,115,109,97,116,99,104,101,115,32,112,97,114,97,109,101,116,101,114,115,32,37,100,10,0,0,0,0,0,0,0,0,69,109,112,116,121,32,109,97,99,114,111,98,108,111,99,107,32,105,110,32,97,110,32,73,78,84,82,65,32,112,105,99,116,117,114,101,33,10,0,0,83,116,97,99,107,32,111,118,101,114,102,108,111,119,32,40,99,111,114,114,117,112,116,101,100,32,98,105,110,97,114,121,32,116,114,101,101,41,33,10,0,0,0,0,0,0,0,0,99,111,109,109,97,110,100,115,0,0,0,0,0,0,0,0,121,117,118,106,0,0,0,0,115,110,0,0,0,0,0,0,73,65,67,32,40,73,110,100,101,111,32,65,117,100,105,111,32,67,111,100,101,114,41,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,32,32,105,100,32,67,73,78,32,118,105,100,101,111,58,32,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,111,102,32,37,100,10,0,0,104,97,108,102,32,111,102,32,115,105,110,101,32,119,97,118,101,0,0,0,0,0,0,0,72,117,102,102,121,117,118,32,70,70,109,112,101,103,32,118,97,114,105,97,110,116,0,0,72,117,102,102,121,117,118,32,70,70,109,112,101,103,32,118,97,114,105,97,110,116,0,0,105,110,118,97,108,105,100,32,99,104,117,110,107,32,105,100,58,32,37,100,10,0,0,0,97,99,116,105,118,101,95,112,97,114,97,109,101,116,101,114,95,115,101,116,95,105,100,32,37,100,32,105,110,118,97,108,105,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,114,101,102,101,114,101,110,99,101,32,105,110,100,101,120,46,10,0,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,115,101,116,32,111,117,116,101,114,32,99,111,108,111,114,105,110,103,32,109,111,100,101,0,87,86,67,49,0,0,0,0,115,116,105,116,99,104,0,0,86,101,114,105,102,121,105,110,103,32,99,104,101,99,107,115,117,109,32,102,111,114,32,102,114,97,109,101,32,119,105,116,104,32,80,79,67,32,37,100,58,32,0,0,0,0,0,0,115,116,97,114,116,95,102,117,108,108,0,0,0,0,0,0,82,101,97,108,108,111,99,97,116,105,110,103,32,102,114,97,109,101,32,100,117,101,32,116,111,32,100,105,102,102,101,114,105,110,103,32,115,116,114,105,100,101,10,0,0,0,0,0,101,118,97,108,32,101,120,112,114,101,115,115,105,111,110,115,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,0,99,104,101,99,107,101,114,98,111,97,114,100,95,114,108,0,114,101,102,101,114,101,110,99,101,32,99,111,117,110,116,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,68,105,102,102,101,114,101,110,116,32,99,104,114,111,109,97,32,97,110,100,32,108,117,109,97,32,98,105,116,32,100,101,112,116,104,0,0,0,0,0,109,98,95,116,121,112,101,32,37,100,32,105,110,32,37,99,32,115,108,105,99,101,32,116,111,111,32,108,97,114,103,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,111,118,101,114,102,108,111,119,32,105,110,32,100,101,99,111,100,101,95,99,97,98,97,99,95,109,98,95,109,118,100,10,0,0,0,0,0,0,0,0,83,101,108,101,99,116,32,118,105,100,101,111,32,102,114,97,109,101,115,32,116,111,32,112,97,115,115,32,105,110,32,111,117,116,112,117,116,46,0,0,116,111,112,32,98,108,111,99,107,32,117,110,97,118,97,105,108,97,98,108,101,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,105,110,116,114,97,32,109,111,100,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,116,111,32,116,114,121,32,116,111,32,103,117,101,115,115,32,116,104,101,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,68,97,116,117,109,95,78,71,79,95,49,57,52,56,0,0,114,97,110,103,101,0,0,0,68,105,115,99,97,114,100,105,110,103,32,101,120,99,101,115,115,105,118,101,32,98,105,116,115,116,114,101,97,109,32,105,110,32,112,97,99,107,101,100,32,120,118,105,100,10,0,0,118,105,115,117,97,108,105,122,101,32,98,108,111,99,107,32,116,121,112,101,115,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,111,116,119,0,0,0,0,71,83,77,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,0,0,0,118,99,49,105,109,97,103,101,0,0,0,0,0,0,0,0,99,111,100,101,61,37,48,50,120,32,39,37,99,39,10,0,78,111,32,97,118,97,105,108,97,98,108,101,32,99,111,108,111,114,44,32,99,97,110,32,110,111,116,32,117,115,101,32,116,114,97,110,115,112,97,114,101,110,99,121,10,0,0,0,71,46,55,50,57,32,64,32,56,107,98,105,116,47,115,0,71,46,55,50,54,32,65,68,80,67,77,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,100,97,114,0,0,0,0,0,79,110,108,121,32,109,111,110,111,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,82,101,113,117,101,115,116,101,100,32,102,114,97,109,101,32,115,105,122,101,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,46,32,85,115,105,110,103,32,37,100,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,0,0,0,98,105,116,115,95,112,101,114,95,99,111,100,101,119,111,114,100,0,0,0,0,0,0,0,71,101,116,116,105,110,103,32,104,101,108,112,58,10,32,32,32,32,45,104,32,32,32,32,32,32,45,45,32,112,114,105,110,116,32,98,97,115,105,99,32,111,112,116,105,111,110,115,10,32,32,32,32,45,104,32,108,111,110,103,32,45,45,32,112,114,105,110,116,32,109,111,114,101,32,111,112,116,105,111,110,115,10,32,32,32,32,45,104,32,102,117,108,108,32,45,45,32,112,114,105,110,116,32,97,108,108,32,111,112,116,105,111,110,115,32,40,105,110,99,108,117,100,105,110,103,32,97,108,108,32,102,111,114,109,97,116,32,97,110,100,32,99,111,100,101,99,32,115,112,101,99,105,102,105,99,32,111,112,116,105,111,110,115,44,32,118,101,114,121,32,108,111,110,103,41,10,32,32,32,32,83,101,101,32,109,97,110,32,37,115,32,102,111,114,32,100,101,116,97,105,108,101,100,32,100,101,115,99,114,105,112,116,105,111,110,32,111,102,32,116,104,101,32,111,112,116,105,111,110,115,46,10,10,0,0,0,0,0,0,83,101,116,32,112,101,114,109,105,115,115,105,111,110,115,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,118,105,100,101,111,32,102,114,97,109,101,46,0,0,0,0,0,87,114,111,110,103,32,109,97,103,105,99,32,37,48,56,88,10,0,0,0,0,0,0,0,69,110,100,32,98,111,116,104,32,115,116,114,101,97,109,115,46,0,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,109,97,114,107,101,114,10,0,0,0,0,0,0,0,84,104,105,115,32,102,105,108,101,32,105,115,32,101,110,99,111,100,101,100,32,119,105,116,104,32,70,114,97,112,115,32,118,101,114,115,105,111,110,32,37,100,46,32,84,104,105,115,32,99,111,100,101,99,32,99,97,110,32,111,110,108,121,32,100,101,99,111,100,101,32,118,101,114,115,105,111,110,115,32,60,61,32,53,46,10,0,0,102,108,118,0,0,0,0,0,99,50,95,115,101,101,100,0,50,52,66,112,112,32,70,76,67,32,85,110,115,117,112,112,111,114,116,101,100,32,100,117,101,32,116,111,32,108,97,99,107,32,111,102,32,116,101,115,116,32,102,105,108,101,115,46,10,0,0,0,0,0,0,0,101,114,114,111,114,32,119,104,105,108,101,32,99,111,109,112,114,101,115,115,105,110,103,32,98,108,111,99,107,32,37,100,120,37,100,10,0,0,0,0,73,110,115,101,114,116,105,110,103,32,107,101,121,32,102,114,97,109,101,32,97,116,32,102,114,97,109,101,32,37,100,10,0,0,0,0,0,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,118,50,0,0,0,100,97,116,0,0,0,0,0,69,114,114,111,114,32,117,112,100,97,116,105,110,103,32,77,68,53,32,99,104,101,99,107,115,117,109,10,0,0,0,0,115,101,116,32,66,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,115,107,105,112,105,110,103,32,102,108,97,99,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,49,10,0,0,0,74,117,110,107,32,102,114,97,109,101,32,116,105,108,108,32,111,102,102,115,101,116,32,37,105,10,0,0,0,0,0,0,98,114,111,107,101,110,32,115,116,114,101,97,109,44,32,105,110,118,97,108,105,100,32,112,97,100,100,105,110,103,10,0,70,114,97,109,101,32,100,97,116,97,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,84,101,109,112,111,114,97,108,108,121,32,105,110,116,101,114,108,101,97,118,101,32,97,117,100,105,111,32,105,110,112,117,116,115,46,0,0,0,0,0,73,110,118,97,108,105,100,32,105,110,116,101,114,118,97,108,115,32,100,101,102,105,110,105,116,105,111,110,115,46,10,0,72,50,54,52,0,0,0,0,10,0,0,0,0,0,0,0,115,101,116,32,108,101,118,101,108,115,32,109,111,100,101,0,118,101,114,58,37,100,32,107,101,121,102,114,97,109,101,58,37,100,32,99,111,100,101,114,58,37,100,32,101,99,58,37,100,32,115,108,105,99,101,115,58,37,100,32,98,112,115,58,37,100,10,0,0,0,0,0,87,114,111,110,103,32,109,97,103,105,99,32,110,117,109,98,101,114,32,37,100,10,0,0,102,114,97,109,101,32,101,114,97,115,117,114,101,10,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,115,107,105,112,32,118,97,108,117,101,10,0,0,0,0,0,0,69,115,99,97,112,101,32,115,105,122,101,115,58,32,37,105,44,32,37,105,44,32,37,105,10,0,0,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,105,110,116,114,97,32,102,114,97,109,101,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,109,98,32,109,111,100,101,32,37,105,10,0,68,105,109,101,110,115,105,111,110,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,112,99,95,110,0,0,0,0,48,0,0,0,0,0,0,0,103,114,97,121,49,54,98,101,0,0,0,0,0,0,0,0,70,114,97,109,101,32,104,101,97,100,101,114,32,37,88,0,67,111,114,97,108,0,0,0,99,111,109,112,114,58,37,50,100,44,32,100,115,105,122,101,58,37,100,10,0,0,0,0,98,105,116,115,116,114,101,97,109,32,119,114,105,116,116,101,110,32,98,101,121,111,110,100,32,98,117,102,102,101,114,32,115,105,122,101,10,0,0,0,32,10,9,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,101,108,101,99,116,101,100,32,112,97,108,101,116,116,101,58,0,0,0,0,0,0,0,65,116,116,101,109,112,116,32,116,111,32,114,101,99,111,110,115,116,114,117,99,116,32,116,111,111,32,108,97,114,103,101,32,83,80,85,32,112,97,99,107,101,116,115,32,97,98,111,114,116,101,100,46,10,0,0,115,116,0,0,0,0,0,0,65,67,32,69,79,66,32,109,97,114,107,101,114,32,105,115,32,97,98,115,101,110,116,32,112,111,115,61,37,100,10,0,80,114,111,116,111,99,111,108,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,85,110,107,110,111,119,110,32,111,98,106,101,99,116,32,99,111,100,105,110,103,32,37,100,10,0,0,0,0,0,0,0,84,70,67,0,0,0,0,0,70,114,97,109,101,32,115,105,122,101,58,32,37,100,120,37,100,59,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,115,44,32,102,114,97,109,101,114,97,116,101,58,32,37,100,47,37,100,10,0,0,101,114,114,111,114,32,100,105,102,102,117,115,105,111,110,32,100,105,116,104,101,114,0,0,100,105,115,99,97,114,100,105,110,103,32,37,100,32,97,117,100,105,111,32,115,97,109,112,108,101,115,10,0,0,0,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,32,97,117,100,105,111,0,0,0,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,105,104,0,0,0,0,0,0,68,80,67,77,32,105,100,32,82,111,81,0,0,0,0,0,97,98,117,102,102,101,114,0,115,101,116,32,115,101,97,114,99,104,32,115,116,114,97,116,101,103,121,0,0,0,0,0,80,108,97,121,82,101,115,88,0,0,0,0,0,0,0,0,68,97,116,117,109,95,78,101,119,95,90,101,97,108,97,110,100,95,71,101,111,100,101,116,105,99,95,68,97,116,117,109,95,49,57,52,57,0,0,0,112,105,120,101,108,32,102,111,114,109,97,116,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,68,78,120,72,68,10,0,0,0,0,0,0,0,0,101,114,114,111,114,32,105,110,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,0,118,105,115,95,109,98,95,116,121,112,101,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,83,69,65,68,0,0,111,102,102,0,0,0,0,0,111,102,102,0,0,0,0,0,69,114,114,111,114,32,105,110,32,100,105,114,97,99,95,100,101,99,111,100,101,95,100,97,116,97,95,117,110,105,116,10,0,0,0,0,0,0,0,0,69,110,104,97,110,99,101,100,32,99,111,117,112,108,105,110,103,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,104,114,111,109,97,32,102,111,114,109,97,116,32,37,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,116,111,111,32,109,97,110,121,32,81,77,70,32,115,117,98,98,97,110,100,115,58,32,37,100,10,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,32,73,109,97,103,101,0,0,0,0,0,73,110,118,97,108,105,100,32,80,114,101,100,105,99,116,111,114,32,82,101,115,101,116,32,71,114,111,117,112,46,10,0,73,103,110,111,114,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,116,121,112,101,32,37,100,10,0,112,97,99,107,101,116,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,111,114,101,32,116,104,97,110,32,37,100,32,99,104,97,110,110,101,108,115,0,0,0,37,102,47,37,102,32,0,0,69,120,116,114,97,32,98,105,116,115,32,67,82,67,32,101,114,114,111,114,10,0,0,0,105,110,118,97,108,105,100,32,113,105,32,37,100,32,62,32,54,51,10,0,0,0,0,0,114,101,115,95,115,101,116,117,112,45,62,99,108,97,115,115,98,111,111,107,0,0,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,10,0,0,0,118,115,117,98,0,0,0,0,67,114,101,97,116,105,118,101,32,89,85,86,32,40,67,89,85,86,41,0,0,0,0,0,32,37,100,46,37,46,50,100,0,0,0,0,0,0,0,0,103,117,101,115,115,95,108,97,121,111,117,116,95,109,97,120,0,0,0,0,0,0,0,0,101,114,114,111,114,32,100,117,114,105,110,103,32,108,122,111,32,100,101,99,111,109,112,114,101,115,115,105,111,110,10,0,85,110,115,117,112,112,111,114,116,101,100,32,115,117,98,115,97,109,112,108,101,33,10,0,115,101,116,32,116,104,101,32,98,108,117,101,32,103,97,105,110,32,102,111,114,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,0,77,101,109,111,114,121,32,100,101,97,108,108,111,99,97,116,101,100,46,10,0,0,0,0,67,111,100,101,99,32,39,37,115,39,32,105,115,32,98,105,116,109,97,112,45,98,97,115,101,100,44,32,115,117,98,116,105,116,108,101,115,32,99,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,0,100,105,102,102,101,114,101,110,99,101,0,0,0,0,0,0,80,114,111,106,70,97,108,115,101,79,114,105,103,105,110,69,97,115,116,105,110,103,71,101,111,75,101,121,0,0,0,0,84,105,108,101,100,32,105,109,97,103,101,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,10,0,0,0,0,0,0,0,8,4,4,8,4,4,8,2,4,0,0,0,0,0,0,0,88,118,105,100,32,114,97,116,101,99,111,110,116,114,111,108,32,114,101,113,117,105,114,101,115,32,108,105,98,97,118,99,111,100,101,99,32,99,111,109,112,105,108,101,100,32,119,105,116,104,32,88,118,105,100,32,115,117,112,112,111,114,116,46,10,0,0,0,0,0,0,0,70,70,84,32,115,105,122,101,32,37,100,32,110,111,116,32,112,111,119,101,114,32,111,102,32,50,46,10,0,0,0,0,97,108,112,104,97,95,98,105,116,115,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,32,112,108,97,110,97,114,0,70,111,117,114,67,67,0,0,102,102,97,98,117,102,102,101,114,115,105,110,107,0,0,0,70,97,105,108,101,100,32,116,111,32,102,105,110,100,32,97,110,121,32,99,111,100,101,99,10,0,0,0,0,0,0,0,109,118,52,0,0,0,0,0,101,114,114,111,114,44,32,115,108,105,99,101,32,99,111,100,101,32,119,97,115,32,37,88,10,0,0,0,0,0,0,0,82,84,67,84,73,77,69,0,87,97,114,110,105,110,103,32,118,98,118,95,100,101,108,97,121,32,119,105,108,108,32,98,101,32,115,101,116,32,116,111,32,48,120,70,70,70,70,32,40,61,86,66,82,41,32,97,115,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,118,98,118,32,98,117,102,102,101,114,32,105,115,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,116,104,101,32,103,105,118,101,110,32,98,105,116,114,97,116,101,33,10,0,68,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,71,114,111,117,112,32,111,102,32,86,79,80,32,115,116,97,114,116,0,0,0,0,0,0,108,117,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,73,82,32,102,105,108,116,101,114,32,104,97,115,32,115,116,97,116,101,32,100,97,116,97,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,99,111,109,112,111,110,101,110,116,58,32,37,100,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,102,111,114,32,90,76,73,66,58,32,40,37,100,41,46,10,0,0,101,120,116,114,97,32,99,98,108,107,32,115,116,121,108,101,115,32,37,88,10,0,0,0,92,105,0,0,0,0,0,0,67,111,109,109,97,110,100,32,119,97,115,32,112,97,114,115,101,100,32,97,115,58,32,102,108,97,103,115,58,91,37,115,93,32,116,97,114,103,101,116,58,37,115,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,10,0,0,73,110,100,101,112,101,110,100,101,110,116,32,83,101,103,109,101,110,116,32,68,101,99,111,100,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,109,97,120,32,116,114,97,110,115,102,111,114,109,32,98,108,111,99,107,32,115,105,122,101,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,90,101,114,111,32,114,101,102,115,32,102,111,114,32,97,32,102,114,97,109,101,32,119,105,116,104,32,80,32,111,114,32,66,32,115,108,105,99,101,115,46,10,0,0,0,0,0,0,80,73,67,84,95,84,89,80,69,95,66,73,0,0,0,0,77,80,69,71,45,50,32,118,105,100,101,111,0,0,0,0,79,110,108,121,32,109,111,110,111,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,67,79,78,83,84,82,0,0,72,105,103,104,32,49,48,0,83,107,105,112,112,105,110,103,32,73,78,70,79,32,99,104,117,110,107,46,10,0,0,0,100,105,116,104,101,114,95,116,121,112,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,32,98,108,111,99,107,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,0,115,45,62,109,97,120,95,98,108,111,99,107,115,105,122,101,0,0,0,0,0,0,0,0,101,110,99,111,100,101,100,95,98,117,102,95,115,105,122,101,32,48,0,0,0,0,0,0,80,114,111,116,101,99,116,32,115,108,105,99,101,115,32,119,105,116,104,32,67,82,67,115,0,0,0,0,0,0,0,0,69,110,99,111,100,105,110,103,32,37,100,32,97,110,100,32,98,112,112,32,37,100,0,0,108,105,110,101,79,114,100,101,114,0,0,0,0,0,0,0,98,117,102,102,101,114,32,116,111,111,32,98,105,103,32,102,111,114,32,100,101,99,111,100,101,114,10,0,0,0,0,0,102,114,97,109,101,95,114,97,116,101,0,0,0,0,0,0,108,116,114,116,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,115,116,97,114,116,32,99,111,100,101,32,48,120,37,48,50,120,10,0,0,0,117,110,101,120,112,101,99,116,101,100,32,116,121,112,101,32,37,120,32,97,116,32,37,100,120,37,100,10,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,112,105,120,101,108,95,102,109,116,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,117,110,107,32,116,121,112,101,32,37,100,10,0,0,110,83,89,78,67,65,85,88,32,109,105,115,109,97,116,99,104,32,37,35,120,10,0,0,115,117,98,112,97,99,107,101,116,32,37,105,32,74,111,105,110,116,45,115,116,101,114,101,111,32,86,76,67,32,117,115,101,100,46,10,0,0,0,0,68,97,116,117,109,95,78,97,112,97,114,105,109,97,95,49,57,55,50,0,0,0,0,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,32,97,117,100,105,111,0,0,118,105,115,117,97,108,105,122,101,32,113,117,97,110,116,105,122,97,116,105,111,110,32,112,97,114,97,109,101,116,101,114,32,40,81,80,41,44,32,108,111,119,101,114,32,81,80,32,97,114,101,32,116,105,110,116,101,100,32,103,114,101,101,110,101,114,0,0,0,0,0,0,98,97,100,32,109,97,103,105,99,32,110,117,109,98,101,114,10,0,0,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,33,118,108,99,45,62,116,97,98,108,101,95,115,105,122,101,0,0,0,0,0,0,0,0,97,117,116,111,45,105,110,115,101,114,116,101,100,32,102,105,102,111,32,37,100,0,0,0,119,109,118,51,105,109,97,103,101,0,0,0,0,0,0,0,101,88,116,101,110,100,101,100,32,66,73,78,97,114,121,32,116,101,120,116,0,0,0,0,66,105,110,107,32,65,117,100,105,111,32,40,68,67,84,41,0,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,98,108,111,99,107,32,105,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,73,110,112,117,116,32,114,101,115,111,108,117,116,105,111,110,32,108,97,114,103,101,114,32,116,104,97,110,32,97,99,116,117,97,108,32,102,114,97,109,101,46,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,104,105,115,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,46,32,85,115,101,32,39,124,39,32,116,111,32,115,101,112,97,114,97,116,101,32,116,104,101,32,108,105,115,116,32,105,116,101,109,115,46,10,0,84,114,97,110,99,101,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,49,58,49,0,0,0,0,0,89,85,86,52,77,80,69,71,32,115,116,114,101,97,109,32,99,111,110,116,97,105,110,115,32,97,110,32,117,110,107,110,111,119,110,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,0,0,0,0,115,101,116,32,97,117,100,105,111,32,102,105,108,116,101,114,115,0,0,0,0,0,0,0,117,110,107,110,111,119,110,0,112,45,112,107,116,45,62,100,97,116,97,32,61,61,32,112,107,116,45,62,115,105,122,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,97,114,116,32,98,105,116,33,10,0,0,0,0,0,70,114,97,109,101,32,100,101,99,111,100,105,110,103,32,101,114,114,111,114,33,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,0,0,0,114,111,116,97,116,101,0,0,65,83,85,83,32,86,50,0,65,83,85,83,32,86,50,0,65,83,83,32,40,65,100,118,97,110,99,101,100,32,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,65,83,83,32,40,65,100,118,97,110,99,101,100,32,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,115,45,62,115,97,109,112,108,101,115,32,62,61,32,48,0,85,110,115,117,112,112,111,114,116,101,100,32,115,99,114,101,101,110,32,109,111,100,101,0,80,97,100,100,105,110,103,32,98,121,116,101,115,0,0,0,70,114,97,109,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,98,121,116,101,115,41,46,32,84,114,117,110,99,97,116,101,100,32,102,105,108,101,63,10,0,0,0,0,100,116,120,32,109,111,100,101,0,0,0,0,0,0,0,0,67,82,67,32,101,114,114,111,114,46,10,0,0,0,0,0,67,111,100,101,99,80,114,105,118,97,116,101,68,97,116,97,0,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,100,97,116,101,0,0,0,0,116,114,97,99,107,0,0,0,116,105,116,108,101,0,0,0,68,97,110,99,101,0,0,0,108,101,110,32,60,32,115,105,122,101,111,102,40,109,105,109,101,116,121,112,101,41,0,0,97,108,98,117,109,0,0,0,97,105,102,44,97,105,102,102,44,97,102,99,44,97,105,102,99,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,68,97,116,117,109,95,78,97,104,114,119,97,110,95,49,57,54,55,0,0,0,0,0,0,118,105,115,95,113,112,0,0,97,97,99,44,97,100,116,115,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,114,97,119,32,69,45,65,67,45,51,0,0,0,0,0,0,115,116,100,32,84,65,71,32,116,114,117,110,99,97,116,101,100,10,0,0,0,0,0,0,67,104,114,111,110,111,109,97,115,116,101,114,32,68,70,65,0,0,0,0,0,0,0,0,70,82,65,77,69,0,0,0,85,110,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,40,37,100,32,98,121,116,101,115,41,0,97,102,0,0,0,0,0,0,82,101,97,100,105,110,103,32,111,112,116,105,111,110,32,39,37,115,39,32,46,46,46,0,87,77,47,80,105,99,116,117,114,101,0,0,0,0,0,0,87,114,105,116,101,32,66,69,88,84,32,99,104,117,110,107,46,0,0,0,0,0,0,0,117,109,105,100,0,0,0,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,116,114,97,99,107,73,68,0,115,97,116,117,114,97,116,105,111,110,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,99,111,100,101,99,32,105,110,32,97,118,95,102,105,110,100,95,115,116,114,101,97,109,95,105,110,102,111,10,0,0,0,0,91,0,0,0,0,0,0,0,114,101,109,111,118,101,108,111,103,111,0,0,0,0,0,0,68,97,116,117,109,95,78,111,114,116,104,95,65,109,101,114,105,99,97,110,95,68,97,116,117,109,95,49,57,56,51,0,98,117,103,115,0,0,0,0,100,102,97,0,0,0,0,0,100,101,102,97,117,108,116,0,108,97,121,111,117,116,0,0,87,86,67,49,0,0,0,0,101,120,116,101,110,100,101,100,32,102,111,114,109,97,116,0,97,61,114,116,112,109,97,112,58,37,100,32,77,80,52,65,45,76,65,84,77,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,112,114,111,102,105,108,101,45,108,101,118,101,108,45,105,100,61,37,100,59,99,112,114,101,115,101,110,116,61,48,59,99,111,110,102,105,103,61,37,115,13,10,0,0,0,0,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,84,0,0,0,0,0,0,115,121,115,116,101,109,66,105,116,114,97,116,101,0,0,0,67,78,65,77,69,32,116,111,32,105,110,99,108,117,100,101,32,105,110,32,82,84,67,80,32,83,82,32,112,97,99,107,101,116,115,0,0,0,0,0,118,105,100,101,111,47,120,45,104,50,54,49,0,0,0,0,68,97,116,117,109,95,78,65,68,95,77,105,99,104,105,103,97,110,0,0,0,0,0,0,109,101,109,111,114,121,32,109,97,110,97,103,101,109,101,110,116,32,99,111,110,116,114,111,108,32,111,112,101,114,97,116,105,111,110,115,32,40,72,46,50,54,52,41,0,0,0,0,117,50,52,108,101,0,0,0,66,105,116,109,97,112,32,66,114,111,116,104,101,114,115,32,74,86,32,118,105,100,101,111,0,0,0,0,0,0,0,0,117,50,52,108,101,0,0,0,115,101,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,0,0,0,114,101,100,117,99,101,32,116,104,101,32,108,97,116,101,110,99,121,32,105,110,116,114,111,100,117,99,101,100,32,98,121,32,111,112,116,105,111,110,97,108,32,98,117,102,102,101,114,105,110,103,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,60,37,115,32,115,121,115,116,101,109,66,105,116,114,97,116,101,61,34,37,100,34,62,10,0,0,0,0,0,0,0,0,110,117,116,45,62,102,114,97,109,101,95,99,111,100,101,91,39,78,39,93,46,102,108,97,103,115,32,61,61,32,70,76,65,71,95,73,78,86,65,76,73,68,0,0,0,0,0,0,76,97,115,116,32,102,114,97,109,101,32,109,117,115,116,32,104,97,118,101,32,98,101,101,110,32,100,97,109,97,103,101,100,32,37,108,108,100,32,62,32,37,108,108,100,32,43,32,37,100,10,0,0,0,0,0,120,32,62,61,32,110,98,95,112,116,115,101,115,32,45,32,73,110,100,101,120,69,110,116,114,121,67,111,117,110,116,32,37,105,32,60,32,73,110,100,101,120,68,117,114,97,116,105,111,110,32,37,108,108,100,63,10,0,0,0,0,0,0,0,65,85,68,73,79,95,70,79,82,77,65,84,0,0,0,0,109,50,116,115,0,0,0,0,68,97,116,117,109,95,78,111,114,116,104,95,65,109,101,114,105,99,97,110,95,68,97,116,117,109,95,49,57,50,55,0,70,111,117,110,100,32,116,97,103,32,37,120,32,101,120,112,101,99,116,101,100,32,37,120,10,0,0,0,0,0,0,0,109,109,99,111,0,0,0,0,70,105,114,115,116,32,83,67,82,58,32,37,108,108,100,32,70,105,114,115,116,32,68,84,83,58,32,37,108,108,100,10,0,0,0,0,0,0,0,0,106,118,0,0,0,0,0,0,100,101,108,97,121,58,0,0,73,68,51,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,70,52,86,32,65,100,111,98,101,32,70,108,97,115,104,32,86,105,100,101,111,0,0,0,97,117,100,105,111,0,0,0,100,97,116,101,0,0,0,0,117,110,100,0,0,0,0,0,116,105,116,108,101,0,0,0,78,111,110,45,109,111,110,111,116,111,110,111,117,115,32,68,84,83,32,105,110,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,59,32,112,114,101,118,105,111,117,115,58,32,37,108,108,100,44,32,99,117,114,114,101,110,116,58,32,37,108,108,100,59,32,0,0,0,0,0,0,68,97,116,117,109,95,77,95,112,111,114,97,108,111,107,111,0,0,0,0,0,0,0,0,101,114,114,111,114,32,114,101,99,111,103,110,105,116,105,111,110,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,102,105,108,101,32,58,32,37,115,10,0,0,0,0,0,0,0,65,112,112,108,101,32,80,114,111,82,101,115,32,40,105,67,111,100,101,99,32,80,114,111,41,0,0,0,0,0,0,0,114,97,115,0,0,0,0,0,112,115,110,114,0,0,0,0,115,101,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,84,68,82,67,0,0,0,0,35,69,88,84,45,88,45,69,78,68,76,73,83,84,0,0,119,105,110,100,111,119,95,115,105,122,101,0,0,0,0,0,118,105,100,101,111,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,116,105,109,101,115,0,0,0,112,105,120,100,101,115,99,116,101,115,116,0,0,0,0,0,68,97,116,117,109,95,77,111,110,116,101,95,77,97,114,105,111,0,0,0,0,0,0,0,101,114,0,0,0,0,0,0,112,114,111,114,101,115,0,0,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,0,115,116,114,110,0,0,0,0,80,111,116,69,110,99,111,100,101,114,0,0,0,0,0,0,68,82,77,32,112,114,111,116,101,99,116,101,100,32,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,44,32,100,101,99,111,100,105,110,103,32,119,105,108,108,32,108,105,107,101,108,121,32,102,97,105,108,33,10,0,0,0,0,0,0,60,115,119,105,116,99,104,62,10,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,119,104,101,110,32,116,111,32,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,32,37,100,0,0,0,0,0,116,114,105,109,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,78,111,32,99,104,97,110,110,101,108,115,32,97,114,101,32,117,115,101,100,32,102,114,111,109,32,105,110,112,117,116,32,115,116,114,101,97,109,32,37,100,46,10,0,0,0,0,0,104,0,0,0,0,0,0,0,68,97,116,117,109,95,77,104,97,115,116,0,0,0,0,0,112,116,115], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2108040);
/* memory initializer */ allocate([76,97,103,97,114,105,116,104,32,108,111,115,115,108,101,115,115,0,0,0,0,0,0,0,104,101,108,112,0,0,0,0,118,111,108,117,109,101,0,0,104,115,105,110,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,58,37,100,32,99,104,108,97,121,111,117,116,58,37,115,32,100,117,114,97,116,105,111,110,58,37,108,108,100,10,0,0,0,0,0,0,0,115,97,114,0,0,0,0,0,111,117,116,101,114,0,0,0,60,98,111,100,121,62,10,0,115,101,101,100,0,0,0,0,115,99,114,111,108,108,32,112,97,116,116,101,114,110,32,100,111,119,110,119,97,114,100,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,121,97,100,105,102,46,99,0,0,102,114,97,109,101,0,0,0,101,102,102,101,99,116,58,37,115,32,116,121,112,101,58,37,115,32,109,115,105,122,101,95,120,58,37,100,32,109,115,105,122,101,95,121,58,37,100,32,97,109,111,117,110,116,58,37,48,46,50,102,10,0,0,0,68,97,116,117,109,95,77,105,110,110,97,0,0,0,0,0,115,101,116,32,105,110,112,117,116,32,99,111,108,111,114,32,114,97,110,103,101,0,0,0,115,116,97,114,116,99,111,100,101,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,114,32,101,118,97,108,117,97,116,105,110,103,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,111,112,116,105,111,110,32,37,115,58,32,105,110,118,97,108,105,100,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,111,114,32,110,111,110,45,112,111,115,105,116,105,118,101,32,111,114,32,105,110,100,101,102,105,110,105,116,101,32,118,97,108,117,101,32,37,102,10,0,0,0,108,97,103,97,114,105,116,104,0,0,0,0,0,0,0,0,115,97,114,0,0,0,0,0,99,104,97,110,103,101,32,97,117,100,105,111,32,118,111,108,117,109,101,32,40,50,53,54,61,110,111,114,109,97,108,41,0,0,0,0,0,0,0,0,101,110,100,97,108,108,0,0,99,49,102,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,103,117,101,115,115,32,116,104,101,32,102,111,114,109,97,116,32,102,114,111,109,32,116,104,101,32,101,120,116,101,110,115,105,111,110,10,0,0,98,0,0,0,0,0,0,0,60,47,104,101,97,100,62,10,0,0,0,0,0,0,0,0,108,101,118,101,108,115,95,109,111,100,101,0,0,0,0,0,50,45,119,97,121,32,109,97,116,99,104,32,40,112,47,99,41,0,0,0,0,0,0,0,98,103,114,97,0,0,0,0,67,104,111,99,111,108,97,116,101,0,0,0,0,0,0,0,69,114,114,111,114,32,115,101,116,116,105,110,103,32,111,112,116,105,111,110,32,37,115,32,116,111,32,118,97,108,117,101,32,37,115,46,10,0,0,0,100,101,102,97,117,108,116,0,105,115,105,110,102,0,0,0,80,82,79,84,79,67,79,76,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,116,111,112,32,102,114,111,110,116,32,108,101,102,116,0,0,101,114,114,111,114,95,100,105,102,102,117,115,105,111,110,0,67,111,110,116,101,120,116,32,104,97,115,32,110,111,116,32,98,101,101,110,32,105,110,105,116,105,97,108,105,122,101,100,10,0,0,0,0,0,0,0,105,110,95,104,0,0,0,0,115,101,97,114,99,104,0,0,67,111,108,108,105,115,105,111,110,115,0,0,0,0,0,0,68,97,116,117,109,95,77,97,115,115,97,119,97,0,0,0,115,107,105,112,0,0,0,0,97,100,112,99,109,95,105,109,97,95,101,97,95,115,101,97,100,0,0,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,99,111,117,112,108,105,110,103,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,111,110,111,32,111,114,32,100,117,97,108,45,109,111,110,111,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,97,99,115,98,114,46,99,0,0,0,0,0,77,111,98,111,116,105,120,32,77,120,80,69,71,32,118,105,100,101,111,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,115,99,97,108,101,102,97,99,116,111,114,32,98,97,110,100,115,32,105,110,32,103,114,111,117,112,32,40,37,100,41,32,101,120,99,101,101,100,115,32,108,105,109,105,116,32,40,37,100,41,46,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,100,10,0,0,48,47,48,46,50,50,32,48,46,52,57,47,48,46,52,52,32,49,47,48,46,56,0,0,67,82,67,32,101,114,114,111,114,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,97,115,101,32,109,97,116,114,105,120,32,105,110,100,101,120,10,0,0,0,0,0,0,112,97,114,116,105,116,105,111,110,32,111,117,116,32,111,102,32,98,111,117,110,100,115,58,32,116,121,112,101,44,32,98,101,103,105,110,44,32,101,110,100,44,32,115,105,122,101,44,32,98,108,111,99,107,115,105,122,101,58,32,37,117,44,32,37,117,44,32,37,117,44,32,37,117,44,32,37,117,10,0,104,115,117,98,0,0,0,0,69,102,102,101,99,116,58,32,37,100,59,32,112,97,114,97,109,115,58,32,0,0,0,0,118,111,108,0,0,0,0,0,97,98,0,0,0,0,0,0,67,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,32,105,115,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,115,117,98,116,105,116,108,101,115,32,99,111,100,101,99,115,10,0,0,0,0,0,100,97,114,107,101,110,0,0,80,114,111,106,70,97,108,115,101,79,114,105,103,105,110,76,97,116,71,101,111,75,101,121,0,0,0,0,0,0,0,0,84,97,103,32,114,101,102,101,114,101,110,99,105,110,103,32,112,111,115,105,116,105,111,110,32,111,117,116,115,105,100,101,32,116,104,101,32,105,109,97,103,101,10,0,0,0,0,0,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,32,45,45,62,32,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,37,42,91,32,93,88,49,58,37,117,32,88,50,58,37,117,32,89,49,58,37,117,32,89,50,58,37,117,0,0,0,0,0,0,0,118,101,114,58,37,88,32,118,101,114,48,58,37,88,10,0,115,116,97,116,105,115,116,105,99,115,32,97,114,101,32,100,97,109,97,103,101,100,32,97,116,32,108,105,110,101,32,37,100,44,32,112,97,114,115,101,114,32,111,117,116,61,37,100,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,70,70,84,32,111,114,100,101,114,32,40,37,100,41,44,32,99,111,110,116,97,99,116,32,116,104,101,32,100,101,118,101,108,111,112,101,114,115,33,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,112,99,109,95,115,56,95,112,108,97,110,97,114,0,0,0,60,109,101,116,97,32,110,97,109,101,61,34,99,114,101,97,116,111,114,34,32,99,111,110,116,101,110,116,61,34,37,115,34,32,47,62,10,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,44,32,103,117,101,115,115,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,105,115,32,39,37,115,39,10,0,0,97,108,108,111,119,32,100,101,99,111,100,101,114,115,32,116,111,32,112,114,111,100,117,99,101,32,117,110,97,108,105,103,110,101,100,32,111,117,116,112,117,116,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,108,105,99,101,32,104,101,105,103,104,116,32,37,100,10,0,0,0,0,0,0,0,0,84,66,0,0,0,0,0,0,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,37,100,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,98,105,116,114,97,116,101,32,37,100,10,0,0,100,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,32,110,117,109,98,101,114,46,10,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,32,110,117,109,98,101,114,46,10,0,85,115,101,114,32,68,97,116,97,0,0,0,0,0,0,0,117,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,67,66,80,0,0,0,0,0,0,0,0,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,100,10,0,0,0,0,0,0,0,0,83,117,109,32,111,102,32,99,111,101,102,102,95,98,105,116,115,32,97,110,100,32,99,111,101,102,102,95,115,104,105,102,116,32,102,111,114,32,37,99,73,82,32,102,105,108,116,101,114,32,109,117,115,116,32,98,101,32,49,54,32,111,114,32,108,101,115,115,46,10,0,0,100,101,99,111,100,101,95,115,111,115,58,32,105,110,118,97,108,105,100,32,108,101,110,32,40,37,100,41,10,0,0,0,78,111,114,109,97,108,32,99,111,109,112,114,101,115,115,105,111,110,46,10,0,0,0,0,99,98,108,107,32,115,105,122,101,32,62,32,54,52,0,0,123,92,105,49,125,0,0,0,77,105,115,115,105,110,103,32,115,101,112,97,114,97,116,111,114,32,111,114,32,101,120,116,114,97,110,101,111,117,115,32,100,97,116,97,32,102,111,117,110,100,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,105,110,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,82,101,102,101,114,101,110,99,101,32,80,105,99,116,117,114,101,32,83,101,108,101,99,116,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,109,97,120,95,116,114,97,110,115,102,111,114,109,95,104,105,101,114,97,114,99,104,121,95,100,101,112,116,104,95,105,110,116,114,97,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,84,111,111,32,109,97,110,121,32,114,101,102,115,58,32,37,100,47,37,100,46,10,0,0,80,73,67,84,95,84,89,80,69,95,83,80,0,0,0,0,105,110,100,101,120,32,60,32,100,101,102,95,108,101,110,0,76,80,65,82,0,0,0,0,72,105,103,104,0,0,0,0,32,112,97,114,116,105,116,105,111,110,32,111,114,100,101,114,58,32,37,100,44,32,37,100,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,108,105,99,101,99,114,99,0,0,0,0,0,0,0,0,100,105,115,112,108,97,121,87,105,110,100,111,119,0,0,0,112,105,120,101,108,95,97,115,112,101,99,116,0,0,0,0,80,114,101,102,101,114,114,101,100,32,83,116,101,114,101,111,32,68,111,119,110,109,105,120,32,77,111,100,101,0,0,0,67,111,110,102,108,105,99,116,105,110,103,32,97,108,108,95,99,104,97,110,110,101,108,95,99,111,117,110,116,115,32,97,110,100,32,108,105,115,116,32,105,110,32,111,112,116,105,111,110,115,10,0,0,0,0,0,99,104,101,99,107,32,102,97,105,108,101,100,58,32,37,105,62,37,105,0,0,0,0,0,115,113,118,104,32,86,76,67,32,105,110,105,116,10,0,0,68,97,116,117,109,95,77,101,114,99,104,105,99,104,0,0,100,99,116,95,99,111,101,102,102,0,0,0,0,0,0,0,109,115,109,112,101,103,52,118,50,0,0,0,0,0,0,0,97,102,105,102,111,0,0,0,109,120,112,101,103,0,0,0,97,101,118,97,108,115,114,99,0,0,0,0,0,0,0,0,70,117,115,105,111,110,0,0,115,101,114,118,105,99,101,95,110,97,109,101,0,0,0,0,109,111,110,111,0,0,0,0,102,111,114,99,101,32,97,117,100,105,111,32,116,97,103,47,102,111,117,114,99,99,0,0,112,97,100,0,0,0,0,0,60,104,101,97,100,62,10,0,68,97,116,117,109,95,77,97,110,111,99,97,0,0,0,0,109,111,116,105,111,110,32,118,101,99,116,111,114,0,0,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,116,105,111,110,32,86,105,100,101,111,32,67,111,109,112,114,101,115,115,111,114,32,50,0,0,0,0,0,0,97,116,97,103,0,0,0,0,83,112,108,105,116,116,105,110,103,32,116,104,101,32,99,111,109,109,97,110,100,108,105,110,101,46,10,0,0,0,0,0,69,120,112,101,99,116,101,100,32,105,110,116,32,102,111,114,32,37,115,32,98,117,116,32,102,111,117,110,100,32,37,115,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,37,48,56,120,45,37,48,52,120,45,37,48,52,120,45,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,0,97,117,100,105,111,47,120,45,119,97,118,112,97,99,107,0,119,114,105,116,101,95,98,101,120,116,0,0,0,0,0,0,48,120,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,0,0,0,0,0,0,77,85,83,67,0,0,0,0,84,111,111,32,109,97,110,121,32,115,97,109,112,108,101,115,32,105,110,32,98,108,111,99,107,58,32,37,117,10,0,0,60,115,109,105,108,32,120,109,108,110,115,61,34,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,49,47,83,77,73,76,50,48,47,76,97,110,103,117,97,103,101,34,62,10,0,0,108,105,110,101,97,114,0,0,49,0,0,0,0,0,0,0,93,0,0,0,0,0,0,0,68,97,116,117,109,95,77,97,108,111,110,103,111,95,49,57,56,55,0,0,0,0,0,0,109,118,0,0,0,0,0,0,109,118,99,50,0,0,0,0,102,111,114,99,101,32,97,117,100,105,111,32,99,111,100,101,99,32,40,39,99,111,112,121,39,32,116,111,32,99,111,112,121,32,115,116,114,101,97,109,41,0,0,0,0,0,0,0,72,50,54,52,0,0,0,0,115,101,116,32,122,111,111,109,32,102,97,99,116,111,114,0,68,86,66,32,115,99,114,97,109,98,108,101,100,32,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,32,40,115,116,58,37,100,41,44,32,100,101,99,111,100,105,110,103,32,119,105,108,108,32,108,105,107,101,108,121,32,102,97,105,108,10,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,48,120,37,48,56,88,10,0,0,115,105,122,101,0,0,0,0,83,116,101,114,101,111,32,87,83,45,83,78,68,49,0,0,101,120,116,0,0,0,0,0,108,97,116,109,0,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,76,0,0,0,0,0,0,116,101,120,116,47,118,116,116,0,0,0,0,0,0,0,0,60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,110,99,111,100,105,110,103,61,34,117,116,102,45,56,34,63,62,10,0,99,110,97,109,101,0,0,0,118,116,116,0,0,0,0,0,83,117,98,116,105,116,108,101,32,116,105,109,101,33,10,0,114,97,119,32,72,46,50,54,49,0,0,0,0,0,0,0,68,97,116,117,109,95,69,117,114,111,112,101,97,110,95,82,101,102,101,114,101,110,99,101,95,83,121,115,116,101,109,95,49,57,56,57,0,0,0,0,112,101,114,45,98,108,111,99,107,32,113,117,97,110,116,105,122,97,116,105,111,110,32,112,97,114,97,109,101,116,101,114,32,40,81,80,41,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,116,105,111,110,32,86,105,100,101,111,32,67,111,109,112,114,101,115,115,111,114,32,49,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,97,99,111,100,101,99,0,0,97,117,100,105,111,47,120,45,119,97,118,0,0,0,0,0,110,111,98,117,102,102,101,114,0,0,0,0,0,0,0,0,102,102,109,112,101,103,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,83,107,105,112,69,110,100,0,85,110,107,110,111,119,110,32,105,110,116,101,103,101,114,32,37,115,10,0,0,0,0,0,119,54,52,0,0,0,0,0,110,111,32,115,116,114,101,97,109,115,63,10,0,0,0,0,37,100,0,0,0,0,0,0,112,99,114,32,101,118,101,114,121,32,37,100,32,112,107,116,115,44,32,115,100,116,32,101,118,101,114,121,32,37,100,44,32,112,97,116,47,112,109,116,32,101,118,101,114,121,32,37,100,32,112,107,116,115,10,0,68,97,116,117,109,95,77,97,107,97,115,115,97,114,0,0,77,97,120,105,109,117,109,32,77,80,52,32,100,101,115,99,114,105,112,116,111,114,32,108,101,118,101,108,32,101,120,99,101,101,100,101,100,10,0,0,113,112,0,0,0,0,0,0,98,117,102,102,101,114,32,117,110,100,101,114,102,108,111,119,32,115,116,61,37,100,32,98,117,102,105,61,37,100,32,115,105,122,101,61,37,100,10,0,109,118,99,49,0,0,0,0,73,68,88,32,115,116,114,101,97,109,91,37,100,93,32,110,97,109,101,61,37,115,10,0,65,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,115,32,119,101,114,101,32,114,101,113,117,101,115,116,101,100,44,32,98,117,116,32,116,104,101,32,73,68,51,118,50,32,104,101,97,100,101,114,32,105,115,32,100,105,115,97,98,108,101,100,46,10,0,0,0,0,100,105,115,97,98,108,101,32,97,117,100,105,111,0,0,0,118,113,102,44,118,113,108,44,118,113,101,0,0,0,0,0,116,120,116,0,0,0,0,0,102,52,118,0,0,0,0,0,84,82,65,67,75,78,85,77,66,69,82,0,0,0,0,0,116,114,97,99,107,32,37,100,58,32,109,117,120,105,110,103,32,109,112,51,32,97,116,32,37,100,104,122,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,97,117,100,105,111,47,120,45,118,111,99,0,0,0,0,0,97,108,98,117,109,0,0,0,118,111,99,0,0,0,0,0,116,105,116,108,101,0,0,0,85,110,107,110,111,119,110,32,69,66,77,76,32,100,111,99,116,121,112,101,32,39,37,115,39,10,0,0,0,0,0,0,99,111,112,121,0,0,0,0,118,105,118,0,0,0,0,0,114,99,118,0,0,0,0,0,90,101,114,111,32,70,80,83,32,115,112,101,99,105,102,105,101,100,44,32,100,101,102,97,117,108,116,105,110,103,32,116,111,32,49,32,70,80,83,10,0,0,0,0,0,0,0,0,68,97,116,117,109,95,77,97,104,101,95,49,57,55,49,0,109,97,99,114,111,98,108,111,99,107,32,40,77,66,41,32,116,121,112,101,0,0,0,0,115,101,116,32,102,114,97,109,101,32,116,105,109,101,115,116,97,109,112,32,102,114,111,109,32,102,105,108,101,39,115,32,111,110,101,0,0,0,0,0,65,74,65,32,75,111,110,97,32,49,48,45,98,105,116,32,82,71,66,32,67,111,100,101,99,0,0,0,0,0,0,0,115,117,110,0,0,0,0,0,97,110,0,0,0,0,0,0,100,97,116,101,0,0,0,0,35,69,88,84,45,88,45,77,69,68,73,65,45,83,69,81,85,69,78,67,69,58,0,0,72,68,83,32,109,117,120,101,114,0,0,0,0,0,0,0,116,114,97,99,107,32,37,100,58,32,99,111,100,101,99,32,98,108,111,99,107,32,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,32,102,111,114,32,97,100,112,99,109,10,0,0,0,0,0,0,0,111,110,77,101,116,97,68,97,116,97,0,0,0,0,0,0,83,107,105,112,105,110,103,32,100,117,112,108,105,99,97,116,101,32,105,110,100,101,120,10,0,0,0,0,0,0,0,0,68,97,116,117,109,95,72,101,114,97,116,95,78,111,114,116,104,0,0,0,0,0,0,0,109,98,95,116,121,112,101,0,114,49,48,107,0,0,0,0,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,73,83,70,84,0,0,0,0,112,97,99,107,101,116,95,102,114,97,103,95,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,32,40,37,100,45,37,100,41,10,0,0,0,0,116,114,97,99,107,32,37,100,58,32,99,111,100,101,99,32,102,114,97,109,101,32,115,105,122,101,32,105,115,32,110,111,116,32,115,101,116,10,0,0,101,118,97,108,0,0,0,0,32,77,0,0,0,0,0,0,118,111,108,117,109,101,0,0,10,0,0,0,0,0,0,0,111,118,101,114,108,97,121,0,115,101,116,32,102,105,108,116,101,114,45,119,105,100,116,104,32,116,121,112,101,0,0,0,68,97,116,117,109,95,72,105,116,111,95,88,86,73,73,73,95,49,57,54,51,0,0,0,114,97,116,101,32,99,111,110,116,114,111,108,0,0,0,0,77,117,108,116,105,99,111,108,111,114,32,99,104,97,114,115,101,116,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,44,32,101,120,116,101,110,100,101,100,32,119,105,116,104,32,53,116,104,32,99,111,108,111,114,32,40,99,111,108,114,97,109,41,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,0,0,0,0,101,120,112,111,110,101,110,116,105,97,108,32,115,105,110,101,32,119,97,118,101,0,0,0,63,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,110,117,108,108,0,0,0,0,100,0,0,0,0,0,0,0,115,101,116,32,109,111,114,112,104,32,97,109,112,108,105,116,117,100,101,0,0,0,0,0,87,65,82,78,73,78,71,32,99,111,100,101,99,32,116,105,109,101,98,97,115,101,32,105,115,32,118,101,114,121,32,104,105,103,104,46,32,73,102,32,100,117,114,97,116,105,111,110,32,105,115,32,116,111,111,32,108,111,110,103,44,10,102,105,108,101,32,109,97,121,32,110,111,116,32,98,101,32,112,108,97,121,97,98,108,101,32,98,121,32,113,117,105,99,107,116,105,109,101,46,32,83,112,101,99,105,102,121,32,97,32,115,104,111,114,116,101,114,32,116,105,109,101,98,97,115,101,10,111,114,32,99,104,111,111,115,101,32,100,105,102,102,101,114,101,110,116,32,99,111,110,116,97,105,110,101,114,46,10,0,115,101,116,32,116,104,101,32,115,101,101,100,32,102,111,114,32,102,105,108,108,105,110,103,32,116,104,101,32,105,110,105,116,105,97,108,32,103,114,105,100,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,115,99,114,111,108,108,0,0,102,114,97,109,101,0,0,0,115,105,122,101,0,0,0,0,101,118,97,108,32,101,120,112,114,101,115,115,105,111,110,115,32,111,110,99,101,32,100,117,114,105,110,103,32,105,110,105,116,105,97,108,105,122,97,116,105,111,110,0,0,0,0,0,73,110,118,97,108,105,100,32,101,118,101,110,32,115,105,122,101,32,102,111,114,32,37,115,32,109,97,116,114,105,120,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,84,114,117,110,99,97,116,105,110,103,32,112,97,99,107,101,116,32,111,102,32,115,105,122,101,32,37,100,32,116,111,32,37,108,108,100,10,0,0,0,68,97,116,117,109,95,76,117,122,111,110,95,49,57,49,49,0,0,0,0,0,0,0,0,105,110,95,114,97,110,103,101,0,0,0,0,0,0,0,0,114,99,0,0,0,0,0,0,69,114,114,111,114,32,111,99,99,117,114,114,101,100,32,112,97,114,115,105,110,103,32,97,110,103,108,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,97,54,52,95,109,117,108,116,105,53,0,0,0,0,0,0,97,0,0,0,0,0,0,0,37,100,44,32,37,49,48,108,108,100,0,0,0,0,0,0,97,99,0,0,0,0,0,0,109,97,114,107,101,114,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,10,0,0,82,101,112,101,97,116,32,116,104,101,32,112,114,101,118,105,111,117,115,32,102,114,97,109,101,46,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,102,108,97,103,115,0,0,37,115,58,32,37,115,10,0,97,110,115,44,97,114,116,44,97,115,99,44,100,105,122,44,105,99,101,44,110,102,111,44,116,120,116,44,118,116,0,0,115,101,116,32,71,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,68,45,49,48,47,73,77,88,32,109,117,115,116,32,117,115,101,32,55,50,48,120,54,48,56,32,111,114,32,55,50,48,120,53,49,50,32,118,105,100,101,111,32,114,101,115,111,108,117,116,105,111,110,10,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,111,118,101,114,108,97,121,0,112,99,0,0,0,0,0,0,97,98,103,114,0,0,0,0,67,104,97,114,116,114,101,117,115,101,0,0,0,0,0,0,99,0,0,0,0,0,0,0,105,115,110,97,110,0,0,0,78,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,32,105,110,32,70,70,109,112,101,103,44,32,112,97,116,99,104,101,115,32,119,101,108,99,111,109,101,0,0,84,70,76,0,0,0,0,0,97,45,62,99,104,95,99,111,117,110,116,0,0,0,0,0,118,115,117,98,0,0,0,0,70,97,105,108,101,100,32,116,111,32,102,105,108,116,101,114,32,98,105,116,115,116,114,101,97,109,32,119,105,116,104,32,102,105,108,116,101,114,32,37,115,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,105,110,32,102,105,108,101,32,39,37,115,39,32,119,105,116,104,32,99,111,100,101,99,32,37,115,10,0,0,0,0,0,115,101,116,32,99,111,110,116,114,97,115,116,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,98,108,111,99,107,115,0,0,0,0,0,0,0,83,99,114,105,112,116,84,121,112,101,0,0,0,0,0,0,68,97,116,117,109,95,76,111,109,101,0,0,0,0,0,0,112,105,99,116,117,114,101,32,105,110,102,111,0,0,0,0,65,68,80,67,77,32,73,77,65,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,69,65,67,83,0,0,111,110,0,0,0,0,0,0,111,110,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,112,101,99,116,114,97,108,32,101,120,116,101,110,115,105,111,110,32,99,111,112,121,32,115,116,97,114,116,32,98,105,110,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,48,0,0,0,0,0,0,0,67,111,110,115,116,97,110,116,32,113,117,97,110,116,105,122,101,114,0,0,0,0,0,0,77,117,108,116,105,99,111,108,111,114,32,99,104,97,114,115,101,116,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,0,0,0,0,0,76,84,80,32,105,110,32,69,82,32,65,65,67,32,76,68,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,46,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,48,46,53,48,47,48,46,52,56,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,32,99,111,100,101,100,32,105,110,32,97,32,112,97,99,107,101,116,46,10,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,98,97,115,101,32,109,97,116,114,105,120,101,115,10,0,0,0,0,0,0,0,0,109,97,112,112,105,110,103,95,115,101,116,117,112,45,62,115,117,98,109,97,112,95,114,101,115,105,100,117,101,91,106,93,0,0,0,0,0,0,0,0,100,97,114,0,0,0,0,0,10,0,0,0,0,0,0,0,83,121,110,116,97,120,32,101,114,114,111,114,32,110,101,97,114,32,111,102,102,115,101,116,32,37,108,108,100,46,10,0,115,101,116,32,97,117,100,105,111,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,40,105,110,32,72,122,41,0,73,110,116,101,110,115,105,116,121,32,99,111,109,112,101,110,115,97,116,105,111,110,32,115,101,116,32,102,111,114,32,66,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,103,114,101,101,110,32,103,97,105,110,32,102,111,114,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,119,105,116,104,32,37,100,32,99,104,97,110,110,101,108,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,115,112,101,99,105,102,105,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,100,58,32,105,103,110,111,114,105,110,103,32,115,112,101,99,105,102,105,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,10,0,37,100,32,109,101,116,97,100,97,116,97,32,98,108,111,99,107,32,67,82,67,32,101,114,114,111,114,46,10,0,0,0,98,117,114,110,0,0,0,0,80,114,111,106,70,97,108,115,101,79,114,105,103,105,110,76,111,110,103,71,101,111,75,101,121,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,118,97,108,117,101,32,111,102,32,114,111,119,115,32,112,101,114,32,115,116,114,105,112,10,0,0,0,0,0,0,34,32,62,0,0,0,0,0,82,86,49,47,50,32,118,101,114,115,105,111,110,0,0,0,32,105,110,58,37,42,100,32,111,117,116,58,37,42,100,32,116,121,112,101,58,37,100,32,113,58,37,102,32,105,116,101,120,58,37,100,32,112,116,101,120,58,37,100,32,109,118,58,37,100,32,109,105,115,99,58,37,100,32,102,99,111,100,101,58,37,100,32,98,99,111,100,101,58,37,100,32,109,99,45,118,97,114,58,37,108,108,100,32,118,97,114,58,37,108,108,100,32,105,99,111,117,110,116,58,37,100,32,115,107,105,112,99,111,117,110,116,58,37,100,32,104,98,105,116,115,58,37,100,0,0,0,0,0,0,0,100,97,116,97,32,98,108,111,99,107,32,115,105,122,101,32,116,111,111,32,108,97,114,103,101,32,40,37,117,41,10,0,97,117,116,111,0,0,0,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,100,114,111,112,112,101,100,32,97,103,97,105,110,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,116,97,103,32,102,111,114,32,99,111,100,101,99,32,37,115,32,105,110,32,115,116,114,101,97,109,32,35,37,100,44,32,99,111,100,101,99,32,110,111,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,32,105,110,32,99,111,110,116,97,105,110,101,114,10,0,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,115,116,114,101,97,109,32,37,100,44,32,97,110,100,32,99,111,117,108,100,32,110,111,116,32,98,101,32,103,117,101,115,115,101,100,32,102,114,111,109,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,40,37,100,41,10,0,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,115,104,111,99,107,119,97,118,101,45,102,108,97,115,104,0,0,0,117,110,97,108,105,103,110,101,100,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,113,115,99,97,108,101,10,0,84,0,0,0,0,0,0,0,86,66,86,32,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,98,105,116,114,97,116,101,10,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,67,111,100,101,99,32,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,32,111,114,32,116,111,111,32,115,104,111,114,116,46,10,0,0,67,111,100,101,99,32,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,32,111,114,32,116,111,111,32,115,104,111,114,116,46,10,0,0,86,105,115,117,97,108,32,79,98,106,101,99,116,32,83,101,113,32,69,110,100,0,0,0,99,98,112,95,114,100,0,0,77,105,115,115,105,110,103,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,0,0,0,0,37,99,73,82,32,102,105,108,116,101,114,32,99,111,101,102,102,95,98,105,116,115,32,109,117,115,116,32,98,101,32,98,101,116,119,101,101,110,32,49,32,97,110,100,32,49,54,46,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,116,97,103,32,108,101,110,103,116,104,58,32,37,100,10,0,100,101,99,111,100,101,95,115,111,115,58,32,110,98,95,99,111,109,112,111,110,101,110,116,115,32,40,37,100,41,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,72,105,103,104,32,99,111,109,112,114,101,115,115,105,111,110,46,10,0,0,0,0,0,0,99,98,108,107,32,115,105,122,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,92,73,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,40,114,101,41,97,108,108,111,99,97,116,101,32,99,111,109,109,97,110,100,32,97,114,114,97,121,10,0,0,0,83,121,110,116,97,120,45,98,97,115,101,100,32,65,114,105,116,104,109,101,116,105,99,32,67,111,100,105,110,103,32,40,83,65,67,41,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,66,97,100,32,98,108,111,99,107,115,32,98,105,116,115,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,109,97,120,95,116,114,97,110,115,102,111,114,109,95,104,105,101,114,97,114,99,104,121,95,100,101,112,116,104,95,105,110,116,101,114,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,73,110,118,97,108,105,100,32,108,111,110,103,32,116,101,114,109,32,82,80,83,46,10,0,80,73,67,84,95,84,89,80,69,95,83,73,0,0,0,0,115,104,111,114,116,32,116,101,114,109,32,108,105,115,116,58,10,0,0,0,0,0,0,0,119,101,105,103,104,116,101,100,0,0,0,0,0,0,0,0,69,120,116,101,110,100,101,100,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,115,101,32,86,76,67,115,10,0,115,117,98,0,0,0,0,0,108,111,103,32,115,101,97,114,99,104,0,0,0,0,0,0,32,32,66,105,116,115,58,32,37,100,10,0,0,0,0,0,102,102,118,49,32,101,110,99,111,100,101,114,0,0,0,0,98,111,120,50,105,0,0,0,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,100,109,105,120,95,109,111,100,101,0,0,0,0,0,0,0,68,67,65,45,88,88,67,72,58,32,100,109,105,120,32,116,111,32,76,70,69,49,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,99,104,97,110,110,101,108,95,99,111,117,110,116,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,0,77,68,67,84,32,105,110,105,116,105,97,108,105,122,101,100,44,32,111,114,100,101,114,32,61,32,37,100,46,10,0,0,115,117,98,0,0,0,0,0,68,97,116,117,109,95,76,105,98,101,114,105,97,95,49,57,54,52,0,0,0,0,0,0,112,105,99,116,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,49,0,0,0,0,0,0,0,102,105,102,111,0,0,0,0,97,54,52,95,109,117,108,116,105,0,0,0,0,0,0,0,112,112,0,0,0,0,0,0,74,97,122,122,43,70,117,110,107,0,0,0,0,0,0,0,87,77,47,77,101,100,105,97,83,116,97,116,105,111,110,78,97,109,101,0,0,0,0,0,109,111,110,111,49,54,0,0,97,114,0,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,115,117,98,114,105,112,0,0,0,0,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,32,45,45,62,32,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,37,42,91,32,93,88,49,58,37,117,32,88,50,58,37,117,32,89,49,58,37,117,32,89,50,58,37,117,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,98,105,116,114,97,116,101,32,105,115,32,116,111,111,32,104,105,103,104,10,0,0,0,0,115,112,100,105,102,0,0,0,99,111,109,109,101,110,116,0,105,110,118,97,108,105,100,32,99,111,109,109,101,110,116,32,115,105,122,101,32,40,37,117,41,10,0,0,0,0,0,0,87,114,111,110,103,32,109,97,103,105,99,10,0,0,0,0,68,97,116,117,109,95,76,101,105,103,111,110,0,0,0,0,112,114,105,110,116,32,115,112,101,99,105,102,105,99,32,100,101,98,117,103,32,105,110,102,111,0,0,0,0,0,0,0,65,83,67,73,73,47,65,78,83,73,32,97,114,116,0,0,113,117,97,108,105,116,121,0,69,114,114,111,114,32,115,101,116,116,105,110,103,32,111,112,116,105,111,110,32,37,115,46,10,0,0,0,0,0,0,0,37,117,0,0,0,0,0,0,87,65,86,32,109,117,120,101,114,0,0,0,0,0,0,0,48,120,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,89,111,117,32,114,101,113,117,101,115,116,101,100,32,97,32,99,111,112,121,32,111,102,32,116,104,101,32,111,114,105,103,105,110,97,108,32,116,105,109,101,99,111,100,101,32,116,114,97,99,107,32,115,111,32,116,105,109,101,99,111,100,101,32,109,101,116,97,100,97,116,97,32,97,114,101,32,110,111,119,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,0,37,115,47,77,97,110,105,102,101,115,116,0,0,0,0,0,108,105,110,0,0,0,0,0,109,111,114,101,32,116,104,97,110,32,62,50,32,115,116,114,101,97,109,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,109,106,112,103,0,0,0,0,116,104,114,101,97,100,115,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,117,112,100,97,116,101,44,32,111,102,102,115,101,116,61,37,100,32,108,101,110,103,116,104,61,37,100,32,101,120,116,101,110,100,115,32,98,101,121,111,110,100,32,112,97,108,101,116,116,101,32,115,105,122,101,10,0,0,0,0,0,0,0,0,58,93,0,0,0,0,0,0,118,98,44,115,111,110,0,0,68,97,116,117,109,95,76,97,107,101,0,0,0,0,0,0,100,101,98,117,103,0,0,0,32,100,105,115,112,97,116,99,104,105,110,103,32,37,115,32,102,114,97,109,101,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,97,110,100,32,112,116,115,32,37,108,108,100,10,0,0,0,0,0,0,0,97,110,115,105,0,0,0,0,115,101,116,32,97,117,100,105,111,32,113,117,97,108,105,116,121,32,40,99,111,100,101,99,45,115,112,101,99,105,102,105,99,41,0,0,0,0,0,0,118,105,100,101,111,0,0,0,122,111,111,109,0,0,0,0,99,115,118,32,102,111,114,109,97,116,0,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,77,80,52,86,45,69,83,47,57,48,48,48,48,13,10,97,61,102,109,116,112,58,37,100,32,112,114,111,102,105,108,101,45,108,101,118,101,108,45,105,100,61,49,37,115,13,10,0,0,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,70,0,0,0,0,0,0,80,83,80,32,109,111,100,101,32,110,101,101,100,32,111,110,101,32,118,105,100,101,111,32,97,110,100,32,111,110,101,32,97,117,100,105,111,32,115,116,114,101,97,109,10,0,0,0,83,116,114,101,97,109,32,105,100,101,110,116,105,102,105,101,114,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,105,110,116,101,114,108,101,97,118,101,114,32,37,88,10,0,104,50,54,49,0,0,0,0,110,111,105,115,101,0,0,0,68,97,116,117,109,95,80,114,111,118,105,115,105,111,110,97,108,95,83,95,65,109,101,114,105,99,97,110,95,68,97,116,117,109,95,49,57,53,54,0,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,117,50,52,98,101,0,0,0,80,105,99,116,111,114,47,80,67,32,80,97,105,110,116,0,117,50,52,98,101,0,0,0,115,116,114,101,97,109,105,110,103,32,115,101,103,109,101,110,116,32,109,117,120,101,114,0,97,113,0,0,0,0,0,0,114,97,119,32,118,105,100,101,111,32,105,115,32,117,115,105,110,103,32,117,110,104,97,110,100,108,101,100,32,37,100,98,112,112,10,0,0,0,0,0,101,110,97,98,108,101,32,82,84,80,32,77,80,52,65,45,76,65,84,77,32,112,97,121,108,111,97,100,0,0,0,0,116,104,101,111,114,97,32,107,102,103,115,104,105,102,116,32,37,100,44,32,118,114,101,118,32,37,100,10,0,0,0,0,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,111,110,32,115,101,101,107,97,98,108,101,32,111,117,116,112,117,116,10,0,0,0,0,0,83,107,105,112,83,116,97,114,116,0,0,0,0,0,0,0,72,101,105,103,104,116,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,73,110,100,101,120,83,73,68,32,37,105,32,115,101,103,109,101,110,116,32,37,105,32,104,97,115,32,122,101,114,111,32,73,110,100,101,120,68,117,114,97,116,105,111,110,32,97,110,100,32,116,104,101,114,101,39], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2118280);
/* memory initializer */ allocate([115,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,115,101,103,109,101,110,116,10,0,0,0,0,0,0,0,0,80,65,67,75,73,78,71,0,109,117,120,114,97,116,101,32,37,100,44,32,0,0,0,0,68,97,116,117,109,95,76,97,95,67,97,110,111,97,0,0,84,97,103,32,37,120,32,108,101,110,103,116,104,32,118,105,111,108,97,116,105,111,110,32,110,101,119,32,108,101,110,103,116,104,32,37,100,32,98,121,116,101,115,32,114,101,109,97,105,110,105,110,103,32,37,100,10,0,0,0,0,0,0,0,97,115,112,101,99,116,0,0,116,101,120,116,0,0,0,0,112,97,121,108,111,97,100,95,115,105,122,101,32,45,32,115,116,117,102,102,105,110,103,95,115,105,122,101,32,60,61,32,97,118,95,102,105,102,111,95,115,105,122,101,40,115,116,114,101,97,109,45,62,102,105,102,111,41,0,0,0,0,0,0,112,105,99,116,111,114,0,0,109,111,100,101,0,0,0,0,116,105,116,108,101,0,0,0,78,111,32,97,117,100,105,111,32,115,116,114,101,97,109,32,112,114,101,115,101,110,116,46,10,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,102,114,97,109,101,115,32,116,111,32,114,101,99,111,114,100,0,0,0,0,0,0,0,0,77,105,120,32,102,101,97,116,117,114,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,58,32,45,109,32,105,115,32,105,103,110,111,114,101,100,32,97,110,100,32,109,105,120,32,99,104,97,110,110,101,108,115,32,119,105,108,108,32,98,101,32,115,105,108,101,110,116,46,10,0,0,0,0,84,104,101,32,102,97,115,116,115,116,97,114,116,32,102,108,97,103,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,102,114,97,103,109,101,110,116,97,116,105,111,110,32,97,110,100,32,99,117,115,116,111,109,32,73,79,44,32,100,105,115,97,98,108,105,110,103,32,102,97,115,116,115,116,97,114,116,10,0,0,0,0,0,0,0,97,114,116,105,115,116,0,0,99,111,109,109,101,110,116,0,115,109,105,44,115,97,109,105,0,0,0,0,0,0,0,0,116,114,97,99,107,110,117,109,62,61,48,32,38,38,32,116,114,97,99,107,110,117,109,60,110,117,109,95,116,114,97,99,107,115,0,0,0,0,0,0,84,111,111,32,115,104,111,114,116,32,74,80,69,71,32,104,101,97,100,101,114,46,32,65,98,111,114,116,101,100,33,10,0,0,0,0,0,0,0,0,69,66,77,76,32,104,101,97,100,101,114,32,117,115,105,110,103,32,117,110,115,117,112,112,111,114,116,101,100,32,102,101,97,116,117,114,101,115,10,40,69,66,77,76,32,118,101,114,115,105,111,110,32,37,108,108,117,44,32,100,111,99,116,121,112,101,32,37,115,44,32,100,111,99,32,118,101,114,115,105,111,110,32,37,108,108,117,41,10,0,0,0,0,0,0,0,78,65,76,32,115,105,122,101,32,37,100,32,62,32,37,100,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,37,115,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,119,105,116,104,32,99,111,100,101,99,32,37,115,0,0,68,97,116,117,109,95,75,117,119,97,105,116,95,79,105,108,95,67,111,109,112,97,110,121,0,0,0,0,0,0,0,0,109,101,100,105,97,110,0,0,116,115,95,102,114,111,109,95,102,105,108,101,0,0,0,0,71,111,111,103,108,101,32,86,80,57,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,117,100,105,111,46,99,0,0,0,0,0,112,105,120,0,0,0,0,0,97,102,114,97,109,101,115,0,84,68,82,76,0,0,0,0,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,115,105,100,101,32,100,97,116,97,10,0,0,0,35,69,88,84,45,88,45,84,65,82,71,69,84,68,85,82,65,84,73,79,78,58,0,0,79,117,116,112,117,116,32,102,105,108,101,32,105,115,32,116,111,111,32,98,105,103,32,40,37,108,108,100,32,98,121,116,101,115,32,62,61,32,54,52,107,66,41,10,0,0,0,0,70,76,86,0,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,65,68,80,67,77,32,105,110,32,82,83,79,0,0,0,0,67,111,100,101,99,32,116,97,103,58,32,37,115,0,0,0,109,101,114,103,101,112,108,97,110,101,115,0,0,0,0,0,70,76,86,0,0,0,0,0,37,46,102,0,0,0,0,0,116,105,116,108,101,0,0,0,115,116,114,101,97,109,32,116,121,112,101,59,32,97,117,100,105,111,32,99,111,109,112,114,101,115,115,105,111,110,95,116,121,112,101,61,37,105,0,0,97,112,112,108,105,99,97,116,105,111,110,47,118,110,100,46,114,110,45,114,101,97,108,109,101,100,105,97,0,0,0,0,68,97,116,117,109,95,75,101,114,116,97,117,0,0,0,0,112,108,97,110,101,0,0,0,118,112,57,0,0,0,0,0,115,101,108,101,99,116,32,97,32,100,101,118,105,99,101,32,102,111,114,32,72,87,32,97,99,99,101,108,101,114,97,116,105,111,110,100,101,118,105,99,101,110,97,109,101,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,78,97,109,101,32,118,97,108,117,101,32,112,114,111,112,101,114,116,121,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,63,0,0,0,0,0,0,0,83,111,109,101,116,104,105,110,103,32,119,101,110,116,32,119,114,111,110,103,32,100,117,114,105,110,103,32,104,101,97,100,101,114,32,112,97,114,115,105,110,103,44,32,73,32,119,105,108,108,32,105,103,110,111,114,101,32,105,116,32,97,110,100,32,116,114,121,32,116,111,32,99,111,110,116,105,110,117,101,32,97,110,121,119,97,121,46,10,0,0,0,0,0,0,0,112,97,99,107,101,116,95,114,101,112,108,105,99,95,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,108,105,98,97,118,102,111,114,109,97,116,47,114,105,102,102,101,110,99,46,99,0,0,0,116,111,111,32,98,105,103,32,73,78,70,79,32,115,117,98,99,104,117,110,107,10,0,0,115,101,108,101,99,116,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,0,0,0,0,80,117,114,101,32,99,104,97,110,110,101,108,32,109,97,112,112,105,110,103,32,100,101,116,101,99,116,101,100,58,0,0,45,118,111,108,32,105,115,32,102,111,114,119,97,114,100,101,100,32,116,111,32,108,97,118,102,105,32,115,105,109,105,108,97,114,108,121,32,116,111,32,45,97,102,32,118,111,108,117,109,101,61,37,115,46,10,0,37,100,46,37,115,32,61,62,32,37,115,32,0,0,0,0,37,100,58,32,120,61,37,102,32,121,61,37,102,10,0,0,119,105,100,116,104,95,116,121,112,101,0,0,0,0,0,0,73,67,77,84,0,0,0,0,68,97,116,117,109,95,75,97,110,100,97,119,97,108,97,0,114,115,100,0,0,0,0,0,108,101,102,116,0,0,0,0,79,110,50,32,86,80,56,0,114,116,0,0,0,0,0,0,102,114,101,113,117,101,110,99,121,0,0,0,0,0,0,0,104,119,97,99,99,101,108,95,100,101,118,105,99,101,0,0,101,115,105,110,0,0,0,0,121,117,118,44,99,105,102,44,113,99,105,102,44,114,103,98,0,0,0,0,0,0,0,0,115,101,116,32,97,117,100,105,111,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,116,111,112,105,99,0,0,0,115,101,116,32,118,105,100,101,111,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,109,111,114,112,104,97,109,112,0,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,114,101,45,111,112,101,110,32,37,115,32,111,117,116,112,117,116,32,102,105,108,101,32,102,111,114,32,116,104,101,32,115,101,99,111,110,100,32,112,97,115,115,32,40,102,97,115,116,115,116,97,114,116,41,10,0,0,0,0,0,0,0,114,97,110,100,111,109,95,115,101,101,100,0,0,0,0,0,115,101,101,100,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,105,116,0,0,0,0,115,104,97,114,112,101,110,0,68,97,116,117,109,95,75,97,108,105,97,110,112,117,114,0,115,101,116,32,111,117,116,112,117,116,32,89,67,98,67,114,32,116,121,112,101,0,0,0,112,114,101,100,105,99,116,105,111,110,32,109,101,116,104,111,100,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,118,112,56,0,0,0,0,0,111,104,0,0,0,0,0,0,104,119,97,99,99,101,108,32,110,97,109,101,0,0,0,0,114,101,112,101,97,116,0,0,99,49,95,102,108,97,103,115,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,103,0,0,0,0,0,0,0,97,117,100,105,111,47,120,45,97,99,51,0,0,0,0,0,112,97,114,97,100,101,0,0,115,101,116,32,116,104,101,32,109,97,116,99,104,105,110,103,32,109,111,100,101,32,111,114,32,115,116,114,97,116,101,103,121,32,116,111,32,117,115,101,0,0,0,0,0,0,0,0,114,103,98,97,0,0,0,0,67,97,100,101,116,66,108,117,101,0,0,0,0,0,0,0,98,108,97,99,107,0,0,0,50,53,0,0,0,0,0,0,108,100,0,0,0,0,0,0,80,65,84,67,72,87,69,76,67,79,77,69,0,0,0,0,116,111,112,32,99,101,110,116,101,114,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,99,104,114,32,115,114,99,87,61,37,100,32,115,114,99,72,61,37,100,32,100,115,116,87,61,37,100,32,100,115,116,72,61,37,100,32,120,73,110,99,61,37,100,32,121,73,110,99,61,37,100,10,0,0,0,0,98,105,116,101,120,97,99,116,0,0,0,0,0,0,0,0,97,45,62,98,112,115,0,0,104,115,117,98,0,0,0,0,99,111,117,108,100,32,110,111,116,32,115,101,101,107,32,116,111,32,102,114,97,109,101,32,37,100,10,0,0,0,0,0,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,0,83,99,114,105,112,116,32,73,110,102,111,0,0,0,0,0,68,97,116,117,109,95,74,97,109,97,105,99,97,95,49,57,54,57,0,0,0,0,0,0,112,114,101,100,0,0,0,0,97,100,112,99,109,95,105,109,97,95,101,97,95,101,97,99,115,0,0,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,77,111,100,101,0,0,0,0,0,70,80,83,58,32,37,100,47,37,100,32,45,62,32,37,100,47,37,100,10,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,77,111,100,101,0,0,0,0,0,105,110,118,97,108,105,100,32,115,112,101,99,116,114,97,108,32,101,120,116,101,110,115,105,111,110,32,114,97,110,103,101,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,0,68,97,116,97,32,99,104,117,110,107,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,97,115,116,0,0,0,0,80,115,121,103,110,111,115,105,115,32,89,79,80,32,86,105,100,101,111,0,0,0,0,0,80,114,101,100,105,99,116,105,111,110,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,65,67,45,76,67,46,10,0,0,0,48,0,0,0,0,0,0,0,109,105,110,95,115,97,109,112,108,101,115,95,112,101,114,95,115,117,98,102,114,97,109,101,32,111,102,32,37,100,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,37,100,32,37,100,32,37,100,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,48,47,48,46,49,49,32,48,46,52,50,47,48,46,53,49,32,49,47,48,46,57,53,0,67,117,115,116,111,109,32,115,97,109,112,108,101,32,114,97,116,101,32,109,105,115,115,105,110,103,46,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,112,51,46,99,0,0,0,0,0,0,0,0,109,97,112,112,105,110,103,95,115,101,116,117,112,45,62,115,117,98,109,97,112,95,102,108,111,111,114,91,106,93,0,0,115,97,114,0,0,0,0,0,32,37,100,46,37,46,51,100,0,0,0,0,0,0,0,0,117,115,101,32,72,87,32,97,99,99,101,108,101,114,97,116,101,100,32,100,101,99,111,100,105,110,103,0,0,0,0,0,77,66,32,70,111,114,119,97,114,100,32,84,121,112,101,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,97,103,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,121,110,99,119,111,114,100,10,0,0,0,0,0,0,0,66,105,116,114,97,116,101,32,37,100,32,105,115,32,101,120,116,114,101,109,101,108,121,32,108,111,119,44,32,109,97,121,98,101,32,121,111,117,32,109,101,97,110,32,37,100,107,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,115,32,37,100,32,37,100,32,37,100,10,0,0,0,0,80,114,111,106,70,97,108,115,101,78,111,114,116,104,105,110,103,71,101,111,75,101,121,0,97,118,101,114,97,103,101,0,85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,37,105,10,0,0,13,10,0,0,0,0,0,0,110,111,116,32,101,110,111,117,103,104,32,101,120,116,114,97,100,97,116,97,10,0,0,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,37,88,10,0,0,0,0,0,0,78,111,32,97,117,100,105,111,32,112,97,99,107,101,116,115,46,10,0,0,0,0,0,0,112,105,99,116,117,114,101,95,110,117,109,98,101,114,32,60,32,114,99,99,45,62,110,117,109,95,101,110,116,114,105,101,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,113,117,97,110,116,105,115,101,114,32,109,97,116,114,105,120,0,0,0,0,0,0,0,0,101,110,100,95,102,114,97,109,101,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,13,10,0,0,0,0,0,0,115,101,101,107,95,112,111,105,110,116,58,37,108,108,105,32,102,111,114,109,97,116,95,110,97,109,101,58,37,115,32,102,105,108,101,95,110,97,109,101,58,37,115,32,115,116,114,101,97,109,95,105,110,100,101,120,58,37,100,10,0,0,0,0,83,101,116,32,118,105,100,101,111,32,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,40,105,110,32,98,105,116,115,47,115,41,46,32,73,110,32,49,45,112,97,115,115,32,109,111,100,101,44,32,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,115,112,101,99,105,102,105,101,115,32,104,111,119,32,102,97,114,32,114,97,116,101,99,111,110,116,114,111,108,32,105,115,32,119,105,108,108,105,110,103,32,116,111,32,100,101,118,105,97,116,101,32,102,114,111,109,32,116,104,101,32,116,97,114,103,101,116,32,97,118,101,114,97,103,101,32,98,105,116,114,97,116,101,32,118,97,108,117,101,46,32,84,104,105,115,32,105,115,32,110,111,116,32,114,101,108,97,116,101,100,32,116,111,32,109,105,110,105,109,117,109,47,109,97,120,105,109,117,109,32,98,105,116,114,97,116,101,46,32,76,111,119,101,114,105,110,103,32,116,111,108,101,114,97,110,99,101,32,116,111,111,32,109,117,99,104,32,104,97,115,32,97,110,32,97,100,118,101,114,115,101,32,101,102,102,101,99,116,32,111,110,32,113,117,97,108,105,116,121,46,0,0,0,0,0,105,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,116,121,112,101,10,0,0,0,83,84,65,82,84,84,0,0,105,109,112,111,115,115,105,98,108,101,32,98,105,116,114,97,116,101,32,99,111,110,115,116,114,97,105,110,116,115,44,32,116,104,105,115,32,119,105,108,108,32,102,97,105,108,10,0,105,0,0,0,0,0,0,0,115,119,105,116,99,104,32,112,111,105,110,116,32,105,110,32,56,107,104,122,0,0,0,0,115,119,105,116,99,104,32,112,111,105,110,116,32,105,110,32,56,107,104,122,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,86,105,115,117,97,108,32,79,98,106,101,99,116,32,83,101,113,32,83,116,97,114,116,0,85,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,113,112,32,115,101,108,101,99,116,105,111,110,0,0,0,0,0,0,0,115,108,105,99,101,32,98,101,108,111,119,32,105,109,97,103,101,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,37,99,73,82,32,102,105,108,116,101,114,32,111,114,100,101,114,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,109,97,120,105,109,117,109,32,37,100,46,10,0,0,0,0,0,0,0,115,45,62,112,105,99,116,117,114,101,95,112,116,114,45,62,100,97,116,97,91,48,93,0,72,105,103,104,32,115,112,101,101,100,32,99,111,109,112,114,101,115,115,105,111,110,46,10,0,0,0,0,0,0,0,0,114,101,100,117,99,116,105,111,110,95,102,97,99,116,111,114,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,116,104,105,115,32,98,105,116,115,116,114,101,97,109,44,32,109,97,120,32,105,115,32,37,100,10,0,0,0,0,0,0,0,123,92,114,125,0,0,0,0,78,111,32,105,110,116,101,114,118,97,108,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,105,110,116,101,114,118,97,108,32,35,37,100,10,0,72,50,54,51,32,83,65,67,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,67,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,105,110,116,101,114,110,97,108,32,115,116,114,117,99,116,117,114,101,115,33,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,67,84,66,32,115,105,122,101,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,50,94,37,100,10,0,0,0,0,78,111,32,114,101,102,32,108,105,115,116,115,32,105,110,32,116,104,101,32,83,80,83,46,10,0,0,0,0,0,0,0,80,73,67,84,95,84,89,80,69,95,83,0,0,0,0,0,37,100,32,102,110,58,37,100,32,112,111,99,58,37,100,32,37,112,10,0,0,0,0,0,67,65,86,76,67,0,0,0,77,97,105,110,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,102,117,108,108,32,115,101,97,114,99,104,0,0,0,0,0,32,32,67,104,97,110,110,101,108,115,58,32,37,100,10,0,45,49,0,0,0,0,0,0,100,97,116,97,87,105,110,100,111,119,0,0,0,0,0,0,115,97,114,0,0,0,0,0,79,114,105,103,105,110,97,108,32,66,105,116,32,83,116,114,101,97,109,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,68,84,83,45,88,88,67,72,32,101,120,116,101,110,115,105,111,110,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,115,97,109,112,108,101,115,95,112,101,114,95,99,104,97,110,110,101,108,32,61,32,37,100,0,0,0,0,0,0,0,0,68,97,116,117,109,95,74,97,109,97,105,99,97,95,49,56,55,53,0,0,0,0,0,0,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,0,0,0,109,115,109,112,101,103,52,118,49,0,0,0,0,0,0,0,65,108,108,32,99,111,117,110,116,115,32,119,105,116,104,111,117,116,32,97,108,108,32,108,97,121,111,117,116,115,10,0,121,111,112,0,0,0,0,0,112,97,110,0,0,0,0,0,86,111,99,97,108,0,0,0,115,101,114,118,105,99,101,95,112,114,111,118,105,100,101,114,0,0,0,0,0,0,0,0,52,52,52,0,0,0,0,0,104,119,97,99,99,101,108,0,102,54,52,108,101,0,0,0,114,111,116,97,116,101,0,0,68,97,116,117,109,95,73,110,100,105,97,110,95,49,57,55,53,0,0,0,0,0,0,0,117,115,101,32,115,116,114,111,110,103,32,100,101,98,108,111,99,107,32,102,105,108,116,101,114,32,102,111,114,32,100,97,109,97,103,101,100,32,77,66,115,0,0,0,0,0,0,0,75,101,103,97,32,71,97,109,101,32,86,105,100,101,111,0,98,105,116,114,97,116,101,0,82,111,117,116,105,110,103,32,111,112,116,105,111,110,32,37,115,32,116,111,32,98,111,116,104,32,99,111,100,101,99,32,97,110,100,32,109,117,120,101,114,32,108,97,121,101,114,10,0,0,0,0,0,0,0,0,37,108,108,105,0,0,0,0,99,111,100,105,110,103,95,104,105,115,116,111,114,121,0,0,116,105,109,101,95,114,101,102,101,114,101,110,99,101,0,0,76,65,66,76,0,0,0,0,102,54,52,108,101,0,0,0,108,111,103,97,114,105,116,104,109,105,99,0,0,0,0,0,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,86,49,46,48,10,40,99,41,32,49,57,57,50,45,57,54,32,65,109,97,122,105,110,103,32,83,116,117,100,105,111,10,26,0,108,117,116,51,100,0,0,0,112,97,114,115,101,114,32,110,111,116,32,102,111,117,110,100,32,102,111,114,32,99,111,100,101,99,32,37,115,44,32,112,97,99,107,101,116,115,32,111,114,32,116,105,109,101,115,32,109,97,121,32,98,101,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,78,111,32,111,112,116,105,111,110,32,102,111,117,110,100,32,110,101,97,114,32,34,37,115,34,10,0,0,0,0,0,0,68,97,116,117,109,95,73,110,100,105,97,110,95,49,57,53,52,0,0,0,0,0,0,0,100,101,98,108,111,99,107,0,107,103,118,49,0,0,0,0,118,105,100,101,111,32,98,105,116,114,97,116,101,32,40,112,108,101,97,115,101,32,117,115,101,32,45,98,58,118,41,0,102,114,97,103,95,99,117,115,116,111,109,0,0,0,0,0,115,101,116,32,98,108,117,101,32,102,97,100,101,0,0,0,99,115,118,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,72,50,54,51,45,50,48,48,48,47,57,48,48,48,48,13,10,97,61,102,114,97,109,101,115,105,122,101,58,37,100,32,37,100,45,37,100,13,10,0,0,0,0,0,119,97,118,101,102,111,114,109,32,100,101,102,105,110,105,116,105,111,110,115,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,0,0,0,0,0,0,0,0,97,118,95,114,101,115,99,97,108,101,95,114,110,100,40,116,114,97,99,107,45,62,99,108,117,115,116,101,114,91,48,93,46,100,116,115,44,32,49,48,48,48,44,32,116,114,97,99,107,45,62,116,105,109,101,115,99,97,108,101,44,32,65,86,95,82,79,85,78,68,95,68,79,87,78,41,32,60,61,32,48,0,0,0,0,0,0,0,115,115,114,99,0,0,0,0,100,105,114,101,99,116,0,0,109,105,115,109,97,116,99,104,105,110,103,32,105,110,116,101,114,108,101,97,118,101,114,32,112,97,114,97,109,101,116,101,114,115,0,0,0,0,0,0,97,117,100,105,111,47,120,45,111,109,97,0,0,0,0,0,116,99,111,44,114,99,111,0,68,97,116,117,109,95,73,110,100,111,110,101,115,105,97,110,95,68,97,116,117,109,95,49,57,55,52,0,0,0,0,0,105,116,101,114,97,116,105,118,101,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,40,77,86,41,32,115,101,97,114,99,104,32,40,115,108,111,119,41,0,0,0,0,0,0,111,109,97,44,111,109,103,44,97,97,51,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,73,70,70,32,66,121,116,101,82,117,110,49,0,0,0,0,85,110,107,110,111,119,110,32,79,103,103,86,80,56,32,118,101,114,115,105,111,110,32,37,100,46,37,100,10,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,99,111,118,101,114,32,97,114,116,32,98,108,111,99,107,46,10,0,0,0,0,0,0,0,108,97,116,109,0,0,0,0,73,110,118,97,108,105,100,32,116,105,109,101,32,98,97,115,101,32,105,110,32,116,104,101,111,114,97,32,115,116,114,101,97,109,44,32,97,115,115,117,109,105,110,103,32,50,53,32,70,80,83,10,0,0,0,0,69,65,51,0,0,0,0,0,105,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,46,32,83,112,101,101,120,32,109,117,115,116,32,98,101,32,109,111,110,111,32,111,114,32,115,116,101,114,101,111,46,10,0,0,0,85,110,107,110,111,119,110,32,115,107,101,108,101,116,111,110,32,118,101,114,115,105,111,110,32,37,100,46,37,100,10,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,101,100,10,0,0,0,0,76,97,115,116,32,112,97,99,107,101,116,32,119,97,115,32,116,114,117,110,99,97,116,101,100,32,116,111,32,37,100,32,100,117,101,32,116,111,32,101,110,100,32,116,114,105,109,109,105,110,103,46,10,0,0,0,72,101,105,103,104,116,0,0,87,105,100,116,104,0,0,0,1,116,101,120,116,0,0,0,116,114,97,99,107,32,37,100,58,32,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,101,115,115,101,110,99,101,32,99,111,110,116,97,105,110,101,114,32,117,108,44,32,99,111,100,101,99,32,110,111,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,32,105,110,32,99,111,110,116,97,105,110,101,114,10,0,0,0,0,0,0,73,110,100,101,120,83,73,68,32,37,105,32,115,116,97,114,116,115,32,97,116,32,69,100,105,116,85,110,105,116,32,37,108,108,100,32,45,32,115,101,101,107,105,110,103,32,109,97,121,32,110,111,116,32,119,111,114,107,32,97,115,32,101,120,112,101,99,116,101,100,10,0,73,78,84,69,82,76,65,67,73,78,71,0,0,0,0,0,109,117,120,114,97,116,101,32,86,66,82,44,32,0,0,0,68,97,116,117,109,95,72,117,110,103,97,114,105,97,110,95,68,97,116,117,109,95,49,57,55,50,0,0,0,0,0,0,103,117,101,115,115,95,109,118,115,0,0,0,0,0,0,0,97,118,95,102,105,102,111,95,115,105,122,101,40,115,116,114,101,97,109,45,62,102,105,102,111,41,32,61,61,32,116,114,97,105,108,101,114,95,115,105,122,101,0,0,0,0,0,0,105,102,102,95,98,121,116,101,114,117,110,49,0,0,0,0,97,108,116,58,0,0,0,0,79,110,108,121,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,97,110,100,32,112,105,99,116,117,114,101,115,32,97,114,101,32,97,108,108,111,119,101,100,32,105,110,32,77,80,51,46,10,0,0,0,0,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,111,103,103,0,66,114,111,107,101,110,32,102,105,108,101,44,32,37,115,107,101,121,102,114,97,109,101,32,110,111,116,32,99,111,114,114,101,99,116,108,121,32,109,97,114,107,101,100,46,10,0,0,105,115,109,118,44,105,115,109,97,0,0,0,0,0,0,0,86,105,100,101,111,32,112,97,99,107,101,116,32,105,110,32,102,105,108,101,32,119,105,116,104,111,117,116,32,118,105,100,101,111,32,115,116,114,101,97,109,33,10,0,0,0,0,0,108,121,114,105,99,115,0,0,115,105,122,101,32,62,61,32,50,0,0,0,0,0,0,0,118,105,100,101,111,47,120,45,110,117,116,0,0,0,0,0,101,110,103,0,0,0,0,0,116,121,112,101,61,32,37,99,10,0,0,0,0,0,0,0,68,97,116,117,109,95,72,117,95,84,122,117,95,83,104,97,110,0,0,0,0,0,0,0,115,101,116,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,32,115,116,114,97,116,101,103,121,0,0,102,111,114,99,101,32,102,114,97,109,101,32,115,105,122,101,32,105,110,32,98,121,116,101,115,0,0,0,0,0,0,0,73,70,70,32,73,76,66,77,0,0,0,0,0,0,0,0,112,99,120,0,0,0,0,0,102,111,114,99,101,32,107,101,121,32,102,114,97,109,101,115,32,97,116,32,115,112,101,99,105,102,105,101,100,32,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,0,48,88,0,0,0,0,0,0,78,111,32,118,105,100,101,111,32,115,116,114,101,97,109,32,105,110,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,32,97,110,100,32,110,111,32,109,105,110,32,102,114,97,103,32,100,117,114,97,116,105,111,110,32,115,101,116,10,0,0,0,0,0,0,0,67,111,100,101,99,32,116,121,112,101,32,39,37,115,39,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,0,0,0,102,97,108,115,101,0,0,0,37,108,108,117,45,37,108,108,117,32,37,108,108,100,45,37,108,108,100,10,0,0,0,0,67,104,97,110,110,101,108,115,32,105,115,32,48,10,0,0,115,116,114,101,97,109,32,116,121,112,101,59,32,99,111,109,112,114,101,115,115,105,111,110,95,116,121,112,101,61,37,105,0,0,0,0,0,0,0,0,68,97,116,117,109,95,71,117,121,97,110,101,95,70,114,97,110,99,97,105,115,101,0,0,101,99,0,0,0,0,0,0,105,102,102,95,105,108,98,109,0,0,0,0,0,0,0,0,110,105,115,116,44,115,112,104,0,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,102,111,114,99,101,95,107,101,121,95,102,114,97,109,101,115,0,0,0,0,0,0,0,0,70,111,117,110,100,32,69,79,73,32,98,101,102,111,114,101,32,83,79,73,44,32,115,107,105,112,112,105,110,103,10,0,73,110,118,97,108,105,100,32,111,114,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,116,121,112,101,32,39,37,115,39,32,102,111,117,110,100,32,105,110,32,116,104,101,32,105,110,112,117,116,10,0,0,0,0,111,118,101,114,114,105,100,105,110,103,32,115,97,109,112,108,101,95,115,105,122,101,10,0,117,110,101,120,112,101,99,116,101,100,32,112,97,99,107,101,116,95,114,101,112,108,105,99,95,115,105,122,101,32,111,102,32,37,100,10,0,0,0,0,70,65,84,65,76,32,101,114,114,111,114,44,32,102,105,108,101,32,100,117,114,97,116,105,111,110,32,116,111,111,32,108,111,110,103,32,102,111,114,32,116,105,109,101,98,97,115,101,44,32,116,104,105,115,32,102,105,108,101,32,119,105,108,108,32,110,111,116,32,98,101,10,112,108,97,121,97,98,108,101,32,119,105,116,104,32,113,117,105,99,107,116,105,109,101,46,32,67,104,111,111,115,101,32,97,32,100,105,102,102,101,114,101,110,116,32,116,105,109,101,98,97,115,101,32,111,114,32,97,32,100,105,102,102,101,114,101,110,116,10,99,111,110,116,97,105,110,101,114,32,102,111,114,109,97,116,10,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,109,120,102,0,115,101,108,101,99,116,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,0,0,0,0,111,37,100,32,61,32,37,115,10,0,0,0,0,0,0,0,37,102,0,0,0,0,0,0,109,97,112,112,105,110,103,115,58,32,0,0,0,0,0,0,84,114,97,110,115,102,101,114,32,102,117,110,99,116,105,111,110,32,105,110,112,117,116,32,118,97,108,117,101,115,32,109,117,115,116,32,98,101,32,105,110,99,114,101,97,115,105,110,103,46,10,0,0,0,0,0,102,0,0,0,0,0,0,0,68,97,116,117,109,95,71,97,114,111,117,97,0,0,0,0,115,108,105,99,101,95,99,111,117,110,116,0,0,0,0,0,66,105,110,107,32,118,105,100,101,111,0,0,0,0,0,0,115,116,114,101,97,109,73,110,100,101,120,58,118,97,108,117,101,0,0,0,0,0,0,0,113,117,97,114,116,101,114,32,111,102,32,115,105,110,101,32,119,97,118,101,0,0,0,0,115,101,101,107,105,110,103,32,100,101,116,101,99,116,101,100,32,111,110,32,115,116,114,101,97,109,32,35,37,100,32,119,105,116,104,32,116,105,109,101,32,98,97,115,101,32,40,37,100,47,37,100,41,32,97,110,100,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,100,47,37,100,41,44,32,97,117,100,105,111,32,112,116,115,32,119,111,110,39,116,32,98,101,32,97,99,99,117,114,97,116,101,46,10,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,117,110,104,97,110,100,108,101,100,32,118,101,114,115,105,111,110,32,40,37,100,44,37,100,41,10,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,115,104,111,119,32,104,101,108,112,0,0,0,0,0,0,0,115,101,116,32,109,111,114,112,104,32,121,32,102,114,101,113,117,101,110,99,121,0,0,0,114,97,116,105,111,0,0,0,115,101,116,32,116,104,101,32,115,101,101,100,32,102,111,114,32,102,105,108,108,105,110,103,32,116,104,101,32,105,110,105,116,105,97,108,32,103,114,105,100,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,86,105,100,101,111,32,111,102,32,108,101,115,115,32,116,104,97,110,32,51,32,99,111,108,117,109,110,115,32,111,114,32,108,105,110,101,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,115,112,101,99,105,102,121,32,119,104,101,110,32,116,111,32,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,98,108,117,114,0,0,0,0,118,105,100,101,111,32,99,111,109,112,114,101,115,115,105,111,110,32,37,105,0,0,0,0,108,117,116,0,0,0,0,0,68,97,116,117,109,95,71,97,110,100,97,106,105,107,97,95,49,57,55,48,0,0,0,0,111,117,116,95,99,111,108,111,114,95,109,97,116,114,105,120,0,0,0,0,0,0,0,0,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,65,65,78,32,73,68,67,84,0,117,115,101,32,98,105,108,105,110,101,97,114,32,105,110,116,101,114,112,111,108,97,116,105,111,110,0,0,0,0,0,0,98,105,110,107,118,105,100,101,111,0,0,0,0,0,0,0,111,117,116,95,104,0,0,0,115,101,116,32,116,104,101,32,118,97,108,117,101,32,111,102,32,97,110,32,111,117,116,102,105,108,101,32,115,116,114,101,97,109,105,100,0,0,0,0,65,99,116,105,111,110,32,116,111,32,116,97,107,101,32,119,104,101,110,32,101,110,99,111,117,110,116,101,114,105,110,103,32,69,79,70,32,102,114,111,109,32,115,101,99,111,110,100,97,114,121,32,105,110,112,117,116,32,0,0,0,0,0,0,99,49,115,0,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,72,101,97,100,101,114,32,99,108,97,105,109,115,32,37,100,98,112,112,32,40,33,61,32,49,54,41,46,32,73,103,110,111,114,105,110,103,10,0,0,48,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,118,97,108,105,100,32,115,116,97,114,116,46,10,0,0,0,0,115,101,116,32,82,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,104,108,100,114,95,116,121,112,101,32,102,111,114,32,37,115,32,47,32,48,120,37,48,52,88,44,32,119,114,105,116,105,110,103,32,100,117,109,109,121,32,118,97,108,117,101,115,10,0,0,0,0,0,0,0,0,115,117,98,0,0,0,0,0,115,101,116,32,100,105,115,112,108,97,121,32,109,111,100,101,0,0,0,0,0,0,0,0,116,120,116,44,109,112,108,50,0,0,0,0,0,0,0,0,109,117,108,116,105,112,97,114,116,47,120,45,109,105,120,101,100,45,114,101,112,108,97,99,101,59,98,111,117,110,100,97,114,121,61,102,102,115,101,114,118,101,114,0,0,0,0,0,109,112,101,103,118,105,100,101,111,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,109,111,100,101,0,0,0,0,97,114,103,98,0,0,0,0,66,117,114,108,121,87,111,111,100,0,0,0,0,0,0,0,115,101,116,32,99,111,108,111,114,0,0,0,0,0,0,0,108,116,0,0,0,0,0,0,79,112,116,105,111,110,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,0,84,67,0,0,0,0,0,0,108,117,109,32,115,114,99,87,61,37,100,32,115,114,99,72,61,37,100,32,100,115,116,87,61,37,100,32,100,115,116,72,61,37,100,32,120,73,110,99,61,37,100,32,121,73,110,99,61,37,100,10,0,0,0,0,102,117,108,108,32,99,104,114,111,109,97,32,105,110,112,117,116,0,0,0,0,0,0,0,115,45,62,111,117,116,46,99,104,95,99,111,117,110,116,0,100,97,114,0,0,0,0,0,115,101,116,32,109,111,116,105,111,110,32,115,101,97,114,99,104,32,98,108,111,99,107,115,105,122,101,0,0,0,0,0,68,101,102,97,117,108,116,0,68,97,116,117,109,95,70,97,104,117,100,0,0,0,0,0,102,97,97,110,105,0,0,0,65,68,80,67,77,32,73,77,65,32,68,117,99,107,32,68,75,52,0,0,0,0,0,0,100,115,117,114,95,109,111,100,101,0,0,0,0,0,0,0,84,104,101,32,105,110,112,117,116,32,110,101,101,100,115,32,97,32,99,111,110,115,116,97,110,116,32,102,114,97,109,101,32,114,97,116,101,59,32,99,117,114,114,101,110,116,32,114,97,116,101,32,111,102,32,37,100,47,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,100,115,117,114,95,109,111,100,101,0,0,0,0,0,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,116,104,101,32,97,117,100,105,111,32,98,108,111,99,107,10,0,73,110,118,97,108,105,100,32,98,115,95,115,116,111,112,95,102,114,101,113,58,32,37,100,10,0,0,0,0,0,0,0,84,119,111,32,108,111,111,112,32,115,101,97,114,99,104,105,110,103,32,109,101,116,104,111,100,0,0,0,0,0,0,0,68,101,108,117,120,101,32,80,97,105,110,116,32,65,110,105,109,97,116,105,111,110,0,0,65,65,67,32,76,68,32,105,115,32,111,110,108,121,32,100,101,102,105,110,101,100,32,102,111,114,32,79,78,76,89,95,76,79,78,71,95,83,69,81,85,69,78,67,69,32,98,117,116,32,119,105,110,100,111,119,32,115,101,113,117,101,110,99,101,32,37,100,32,102,111,117,110,100,46,10,0,0,0,0,109,118,32,111,117,116,32,111,102,32,112,105,99,10,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,117,98,102,114,97,109,101,115,32,37,105,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,84,111,111,32,115,109,97,108,108,32,69,88,84,82,65,66,73,84,83,10,0,0,0,0,48,46,51,48,49,47,48,46,49,57,54,32,48,46,53,57,50,47,48,46,54,32,48,46,54,56,54,47,48,46,55,51,55,0,0,0,0,0,0,0,102,105,108,116,101,114,95,108,105,109,105,116,32,60,32,49,50,56,85,0,0,0,0,0,37,117,46,32,109,97,112,112,105,110,103,32,115,101,116,117,112,32,100,97,116,97,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,83,49,58,0,0,0,0,0,97,0,0,0,0,0,0,0,115,116,114,101,97,109,105,100,0,0,0,0,0,0,0,0,66,32,70,105,101,108,100,115,10,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,114,101,100,32,103,97,105,110,32,102,111,114,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,0,0,100,105,109,101,110,115,105,111,110,115,32,110,111,116,32,115,101,116,10,0,0,0,0,0,80,114,111,106,70,97,108,115,101,69,97,115,116,105,110,103,71,101,111,75,101,121,0,0,97,110,100,0,0,0,0,0,74,80,69,71,32,99,111,109,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,118,105,100,101,111,47,120,45,109,112,101,103,116,115,0,0,60,117,62,0,0,0,0,0,60,47,37,115,62,0,0,0,101,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,115,10,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,114,97,116,101,99,111,110,116,114,111,108,46,99,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,44,32,101,120,112,101,99,116,105,110,103,32,81,68,67,65,10,0,0,0,0,0,0,113,117,97,110,116,95,109,97,116,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,112,97,115,115,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,0,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,0,0,84,105,109,101,67,111,100,101,72,97,110,100,108,101,114,0,111,117,116,37,100,0,0,0,98,116,0,0,0,0,0,0,83,84,65,82,84,80,84,83,0,0,0,0,0,0,0,0,98,105,116,114,97,116,101,32,97,98,111,118,101,32,109,97,120,32,98,105,116,114,97,116,101,10,0,0,0,0,0,0,65,0,0,0,0,0,0,0,98,105,116,115,95,108,101,102,116,61,37,100,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2128520);
/* memory initializer */ allocate([98,105,116,115,95,108,101,102,116,61,37,100,10,0,0,0,83,105,109,117,108,97,116,101,32,101,114,114,111,114,115,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,32,116,111,32,116,101,115,116,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,46,0,0,0,0,0,70,71,83,32,98,112,32,115,116,97,114,116,0,0,0,0,113,112,95,114,100,0,0,0,115,108,105,99,101,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,0,70,105,108,116,101,114,115,32,109,97,121,32,99,104,97,110,103,101,32,111,110,108,121,32,111,110,99,101,32,112,101,114,32,97,99,99,101,115,115,32,117,110,105,116,46,10,0,0,67,97,110,32,110,111,116,32,112,114,111,99,101,115,115,32,83,79,83,32,98,101,102,111,114,101,32,83,79,70,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,102,111,114,109,97,116,32,102,111,114,32,77,83,90,72,32,40,37,100,41,46,10,0,0,110,114,101,115,108,101,118,101,108,115,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,37,72,58,37,77,0,0,0,73,110,118,97,108,105,100,32,101,110,100,32,116,105,109,101,32,39,37,115,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,58,32,99,97,110,110,111,116,32,98,101,32,108,101,115,115,101,114,32,116,104,97,110,32,115,116,97,114,116,32,116,105,109,101,32,39,37,115,39,10,0,0,0,109,112,101,103,116,115,0,0,66,97,100,32,72,50,54,51,32,105,100,10,0,0,0,0,67,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,99,111,108,111,114,32,112,108,97,110,101,115,33,10,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,73,110,118,97,108,105,100,32,99,111,100,101,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,46,10,0,0,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,80,79,67,32,99,104,97,110,103,101,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,58,32,37,100,32,45,62,32,37,100,10,0,0,0,80,73,67,84,95,84,89,80,69,95,66,0,0,0,0,0,108,111,110,103,32,116,101,114,109,32,108,105,115,116,58,10,0,0,0,0,0,0,0,0,67,65,66,65,67,0,0,0,67,111,110,115,116,114,97,105,110,101,100,32,66,97,115,101,108,105,110,101,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,56,45,108,101,118,101,108,0,32,32,83,97,109,112,108,101,114,97,116,101,58,32,37,100,10,0,0,0,0,0,0,0,99,111,100,101,114,0,0,0,77,105,115,115,105,110,103,32,98,108,117,101,32,99,104,97,110,110,101,108,10,0,0,0,115,97,114,95,100,101,110,0,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,112,105,99,116,117,114,101,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,10,0,0,0,0,0,0,0,0,68,84,83,32,101,120,116,101,110,115,105,111,110,115,32,100,101,116,101,99,116,105,111,110,32,109,105,115,109,97,116,99,104,32,40,37,100,44,32,37,100,41,10,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,115,97,109,112,108,101,95,114,97,116,101,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,0,0,0,115,117,98,112,97,99,107,101,116,115,32,62,32,37,100,0,68,97,116,117,109,95,69,117,114,111,112,101,97,110,95,68,97,116,117,109,95,49,57,56,55,0,0,0,0,0,0,0,120,118,105,100,109,109,120,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,65,108,108,32,108,97,121,111,117,116,115,32,115,101,116,32,111,110,32,110,111,110,45,101,109,112,116,121,32,108,105,115,116,10,0,0,0,0,0,0,97,110,109,0,0,0,0,0,111,99,118,0,0,0,0,0,84,114,105,112,45,72,111,112,0,0,0,0,0,0,0,0,87,77,47,77,101,100,105,97,83,116,97,116,105,111,110,67,97,108,108,83,105,103,110,0,67,97,110,110,111,116,32,104,97,110,100,108,101,32,52,58,52,58,52,58,52,32,89,85,86,52,77,80,69,71,32,115,116,114,101,97,109,46,10,0,102,111,114,99,101,32,116,104,101,32,115,101,108,101,99,116,101,100,32,102,114,97,109,101,114,97,116,101,44,32,100,105,115,97,98,108,101,32,116,104,101,32,98,101,115,116,32,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,114,97,116,101,32,115,101,108,101,99,116,105,111,110,0,0,0,0,118,105,100,101,111,47,109,112,101,103,0,0,0,0,0,0,72,105,110,116,72,97,110,100,108,101,114,0,0,0,0,0,118,111,98,115,117,98,0,0,78,111,32,115,116,114,101,97,109,32,97,100,100,101,100,32,98,101,102,111,114,101,32,112,97,114,115,105,110,103,32,115,101,101,107,32,116,97,98,108,101,10,0,0,0,0,0,0,78,111,116,32,97,32,77,117,115,101,112,97,99,107,32,102,105,108,101,10,0,0,0,0,68,97,116,117,109,95,69,117,114,111,112,101,97,110,95,68,97,116,117,109,95,49,57,53,48,0,0,0,0,0,0,0,105,112,112,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,32,49,48,45,98,105,116,0,105,108,0,0,0,0,0,0,102,111,114,99,101,95,102,112,115,0,0,0,0,0,0,0,102,100,101,98,117,103,0,0,37,102,0,0,0,0,0,0,97,117,100,105,111,47,120,45,109,112,101,103,0,0,0,0,117,109,105,100,0,0,0,0,37,108,108,117,0,0,0,0,109,112,50,44,109,112,51,44,109,50,97,44,109,112,97,0,103,101,110,114,101,0,0,0,104,105,110,116,0,0,0,0,108,111,103,0,0,0,0,0,66,101,102,111,114,101,32,97,118,102,111,114,109,97,116,95,102,105,110,100,95,115,116,114,101,97,109,95,105,110,102,111,40,41,32,112,111,115,58,32,37,108,108,100,32,98,121,116,101,115,32,114,101,97,100,58,37,108,108,100,32,115,101,101,107,115,58,37,100,10,0,0,61,0,0,0,0,0,0,0,68,97,116,117,109,95,69,103,121,112,116,95,49,57,48,55,0,0,0,0,0,0,0,0,115,105,109,112,108,101,97,108,112,104,97,0,0,0,0,0,114,50,49,48,0,0,0,0,115,104,111,119,32,81,80,32,104,105,115,116,111,103,114,97,109,0,0,0,0,0,0,0,109,111,118,102,108,97,103,115,0,0,0,0,0,0,0,0,98,102,0,0,0,0,0,0,102,108,97,116,32,102,111,114,109,97,116,0,0,0,0,0,114,102,99,50,49,57,48,0,112,105,110,107,0,0,0,0,83,117,98,116,105,116,108,101,72,97,110,100,108,101,114,0,83,112,101,99,105,102,121,32,82,84,80,32,112,97,121,108,111,97,100,32,116,121,112,101,0,0,0,0,0,0,0,0,115,117,98,95,112,97,99,107,101,116,95,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,97,117,100,105,111,47,103,55,50,51,0,0,0,0,0,0,68,97,116,117,109,95,68,111,117,97,108,97,0,0,0,0,115,105,109,112,108,101,110,101,111,110,0,0,0,0,0,0,117,51,50,108,101,0,0,0,67,68,32,71,114,97,112,104,105,99,115,32,118,105,100,101,111,0,0,0,0,0,0,0,117,51,50,108,101,0,0,0,113,112,104,105,115,116,0,0,100,111,110,39,116,32,109,101,114,103,101,32,115,105,100,101,32,100,97,116,97,0,0,0,37,115,58,32,37,115,10,0,105,100,101,116,0,0,0,0,116,104,101,111,114,97,0,0,115,98,116,108,0,0,0,0,87,105,100,116,104,0,0,0,83,97,109,112,108,101,82,97,116,101,0,0,0,0,0,0,77,88,70,32,68,45,49,48,32,111,110,108,121,32,115,117,112,112,111,114,116,32,49,54,32,111,114,32,50,52,32,98,105,116,115,32,108,101,32,97,117,100,105,111,10,0,0,0,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,73,110,100,101,120,84,97,98,108,101,83,101,103,109,101,110,116,32,112,111,105,110,116,101,114,32,97,114,114,97,121,10,0,0,0,0,0,81,95,84,69,77,80,79,82,65,76,0,0,0,0,0,0,102,114,97,109,101,32,115,105,122,101,32,110,111,116,32,115,101,116,10,0,0,0,0,0,68,97,116,117,109,95,68,101,105,114,95,101,122,95,90,111,114,0,0,0,0,0,0,0,115,105,109,112,108,101,97,114,109,118,54,0,0,0,0,0,97,118,97,105,108,95,115,112,97,99,101,32,62,61,32,115,45,62,112,97,99,107,101,116,95,115,105,122,101,32,124,124,32,105,103,110,111,114,101,95,99,111,110,115,116,114,97,105,110,116,115,0,0,0,0,0,99,100,103,114,97,112,104,105,99,115,0,0,0,0,0,0,73,110,118,97,108,105,100,32,97,117,100,105,111,32,115,116,114,101,97,109,46,32,69,120,97,99,116,108,121,32,111,110,101,32,77,80,51,32,97,117,100,105,111,32,115,116,114,101,97,109,32,105,115,32,114,101,113,117,105,114,101,100,46,10,0,0,0,0,0,0,0,0,102,111,114,99,101,32,118,105,100,101,111,32,116,97,103,47,102,111,117,114,99,99,0,0,77,97,108,102,111,114,109,101,100,32,65,65,67,32,98,105,116,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,58,32,117,115,101,32,97,117,100,105,111,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,39,97,97,99,95,97,100,116,115,116,111,97,115,99,39,32,116,111,32,102,105,120,32,105,116,32,40,39,45,98,115,102,58,97,32,97,97,99,95,97,100,116,115,116,111,97,115,99,39,32,111,112,116,105,111,110,32,119,105,116,104,32,102,102,109,112,101,103,41,10,0,0,0,0,0,73,83,77,86,47,73,83,77,65,32,40,83,109,111,111,116,104,32,83,116,114,101,97,109,105,110,103,41,0,0,0,0,67,108,111,115,101,100,67,97,112,116,105,111,110,72,97,110,100,108,101,114,0,0,0,0,103,114,111,117,112,105,110,103,0,0,0,0,0,0,0,0,98,121,116,101,115,32,60,61,32,56,0,0,0,0,0,0,117,110,100,0,0,0,0,0,115,95,115,105,122,101,61,32,37,56,46,48,102,107,66,32,116,105,109,101,61,32,37,48,46,51,102,32,98,114,61,32,37,55,46,49,102,107,98,105,116,115,47,115,32,97,118,103,95,98,114,61,32,37,55,46,49,102,107,98,105,116,115,47,115,32,0,0,0,0,0,0,68,97,116,117,109,95,67,111,116,101,95,100,95,73,118,111,105,114,101,0,0,0,0,0,115,105,109,112,108,101,97,114,109,118,53,116,101,0,0,0,102,114,97,109,101,95,115,105,122,101,0,0,0,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,118,50,0,0,0,112,116,120,0,0,0,0,0,118,116,97,103,0,0,0,0,84,83,83,69,0,0,0,0,48,120,0,0,0,0,0,0,109,111,118,44,109,112,52,44,109,52,97,44,51,103,112,44,51,103,50,44,109,106,50,0,37,115,47,115,116,114,101,97,109,37,100,95,116,101,109,112,0,0,0,0,0,0,0,0,99,108,99,112,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,118,110,100,46,115,109,97,102,0,0,0,0,68,97,116,97,32,99,111,100,101,99,32,39,37,115,39,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,117,110,107,110,111,119,110,32,99,104,117,110,107,32,116,121,112,101,32,48,120,37,120,10,0,0,0,0,0,0,0,0,77,111,114,101,32,116,104,97,110,32,111,110,101,32,115,116,114,101,97,109,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,115,116,114,101,97,109,32,116,121,112,101,59,32,114,101,118,105,115,105,111,110,50,61,37,105,0,0,0,0,0,0,0,116,101,120,116,47,120,45,109,105,99,114,111,100,118,100,0,68,97,116,117,109,95,67,111,114,114,101,103,111,95,65,108,101,103,114,101,0,0,0,0,115,105,109,112,108,101,97,114,109,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,102,108,97,115,104,115,118,50,0,0,0,0,0,0,0,0,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,0,115,116,114,102,0,0,0,0,111,118,101,114,114,105,100,105,110,103,32,105,110,118,97,108,105,100,32,100,115,104,111,119,95,98,108,111,99,107,95,97,108,105,103,110,32,111,102,32,37,100,10,0,0,0,0,0,102,114,97,109,101,109,100,53,0,0,0,0,0,0,0,0,116,111,111,32,108,111,110,103,32,112,97,121,108,111,97,100,10,0,0,0,0,0,0,0,83,111,117,110,100,72,97,110,100,108,101,114,0,0,0,0,115,101,108,101,99,116,32,56,45,98,105,116,32,102,105,120,101,100,45,112,111,105,110,116,0,0,0,0,0,0,0,0,104,117,101,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,105,110,112,117,116,32,99,104,97,110,110,101,108,32,102,111,114,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,39,37,115,39,46,10,0,0,45,118,111,108,32,104,97,115,32,98,101,101,110,32,100,101,112,114,101,99,97,116,101,100,46,32,85,115,101,32,116,104,101,32,118,111,108,117,109,101,32,97,117,100,105,111,32,102,105,108,116,101,114,32,105,110,115,116,101,97,100,46,10,0,73,110,118,97,108,105,100,32,97,110,100,47,111,114,32,109,105,115,115,105,110,103,32,105,110,112,117,116,47,111,117,116,112,117,116,32,118,97,108,117,101,46,10,0,0,0,0,0,115,101,116,32,99,101,110,116,114,97,108,32,102,114,101,113,117,101,110,99,121,0,0,0,68,97,116,117,109,95,67,104,117,97,0,0,0,0,0,0,115,104,52,0,0,0,0,0,70,111,114,119,97,114,100,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,105,110,116,114,97,95,100,99,95,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,113,115,105,110,0,0,0,0,118,105,100,101,111,47,120,45,109,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,52,52,49,48,48,0,0,0,114,0,0,0,0,0,0,0,109,111,114,112,104,121,102,0,115,111,117,110,0,0,0,0,115,101,116,32,102,105,108,108,32,114,97,116,105,111,32,102,111,114,32,102,105,108,108,105,110,103,32,105,110,105,116,105,97,108,32,103,114,105,100,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,0,0,114,97,110,100,111,109,95,115,101,101,100,0,0,0,0,0,104,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,101,118,97,108,0,0,0,0,110,111,110,101,0,0,0,0,69,66,77,76,32,98,108,111,99,107,32,100,97,116,97,32,101,114,114,111,114,10,0,0,109,52,118,32,100,101,109,117,120,101,114,0,0,0,0,0,68,97,116,117,109,95,67,97,114,116,104,97,103,101,0,0,97,117,116,111,0,0,0,0,97,114,109,0,0,0,0,0,98,105,108,105,110,101,97,114,0,0,0,0,0,0,0,0,102,114,119,117,0,0,0,0,111,119,0,0,0,0,0,0,103,111,116,32,112,97,99,107,101,116,32,119,105,116,104,32,105,108,108,101,103,97,108,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,117,10,0,0,0,0,0,0,0,0,100,99,0,0,0,0,0,0,101,111,102,95,97,99,116,105,111,110,0,0,0,0,0,0,37,100,32,115,116,114,101,97,109,115,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,95,116,121,112,101,10,0,0,0,0,0,0,84,111,111,32,108,97,114,103,101,32,72,97,108,100,32,67,76,85,84,32,40,109,97,120,105,109,117,109,32,108,101,118,101,108,32,105,115,32,37,100,44,32,111,114,32,37,100,120,37,100,32,67,76,85,84,41,10,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,97,117,100,105,111,47,77,80,52,65,45,76,65,84,77,0,86,105,100,101,111,72,97,110,100,108,101,114,0,0,0,0,100,105,115,112,108,97,121,95,109,111,100,101,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,97,117,100,105,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,116,101,120,116,47,120,45,106,97,99,111,115,117,98,0,0,97,115,115,117,109,101,32,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,0,110,118,50,49,0,0,0,0,66,114,111,119,110,0,0,0,99,111,108,111,114,0,0,0,108,116,101,0,0,0,0,0,79,80,84,73,79,78,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,0,92,10,0,0,0,0,0,0,115,105,100,101,32,114,105,103,104,116,0,0,0,0,0,0,37,100,120,37,100,32,45,62,32,37,100,120,37,100,10,0,102,117,108,108,95,99,104,114,111,109,97,95,105,110,112,0,115,45,62,117,115,101,100,95,99,104,95,99,111,117,110,116,0,0,0,0,0,0,0,0,70,111,114,109,97,116,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,101,120,97,99,116,108,121,32,111,110,101,32,118,105,100,101,111,32,115,116,114,101,97,109,10,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,46,10,0,0,0,0,0,92,125,0,0,0,0,0,0,98,108,111,99,107,115,105,122,101,0,0,0,0,0,0,0,68,97,116,117,109,95,67,97,112,101,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,114,97,116,101,10,0,0,0,0,0,115,105,109,112,108,101,109,109,120,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,100,107,52,0,0,0,68,105,97,108,111,103,117,101,32,76,101,118,101,108,32,40,100,66,41,0,0,0,0,0,100,101,102,97,117,108,116,0,68,105,97,108,111,103,117,101,32,76,101,118,101,108,32,40,100,66,41,0,0,0,0,0,117,110,97,98,108,101,32,116,111,32,100,101,116,101,114,109,105,110,101,32,99,104,97,110,110,101,108,32,109,111,100,101,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,102,111,114,32,83,66,82,58,32,37,100,10,0,0,0,0,116,119,111,108,111,111,112,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,97,100,99,111,119,32,86,105,100,101,111,0,0,0,0,82,101,115,101,114,118,101,100,32,98,105,116,32,115,101,116,46,10,0,0,0,0,0,0,115,116,97,114,116,32,60,61,32,115,114,99,32,38,38,32,115,114,99,32,60,61,32,101,110,100,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,103,114,111,119,32,112,97,99,107,101,116,10,0,0,49,52,45,98,105,116,32,98,108,111,99,107,32,115,105,122,101,115,0,0,0,0,0,0,77,111,114,101,32,116,104,97,110,32,37,100,32,99,104,97,110,110,101,108,115,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,108,111,97,116,32,105,110,102,111,114,109,97,116,105,111,110,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,48,47,49,32,49,47,48,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,97,112,112,105,110,103,95,115,101,116,117,112,45,62,97,110,103,108,101,91,106,93,0,83,50,58,0,0,0,0,0,111,104,0,0,0,0,0,0,116,111,112,61,49,47,98,111,116,116,111,109,61,48,47,97,117,116,111,61,45,49,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,83,75,73,80,77,66,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,0,37,100,0,0,0,0,0,0,97,114,0,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,119,105,116,104,32,37,100,32,99,104,97,110,110,101,108,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,110,117,109,98,101,114,32,111,102,32,115,112,101,99,105,102,105,101,100,32,99,104,97,110,110,101,108,115,32,37,100,10,0,0,0,0,80,114,111,106,78,97,116,79,114,105,103,105,110,76,97,116,71,101,111,75,101,121,0,0,83,97,109,112,108,101,115,32,112,101,114,32,112,105,120,101,108,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,115,118,113,51,32,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,60,105,62,0,0,0,0,0,115,102,44,105,114,99,97,109,0,0,0,0,0,0,0,0,123,92,37,99,37,100,125,0,115,45,62,98,108,111,99,107,115,105,122,101,32,43,32,115,45,62,110,119,114,97,112,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,112,98,32,102,114,97,109,101,0,0,0,0,0,0,0,0,119,58,37,100,32,104,58,37,100,32,100,97,114,58,37,100,47,37,100,32,115,97,114,58,37,100,47,37,100,32,45,62,32,100,97,114,58,37,100,47,37,100,32,115,97,114,58,37,100,47,37,100,10,0,0,0,112,105,99,116,117,114,101,95,110,117,109,98,101,114,32,62,61,32,48,0,0,0,0,0,115,102,44,105,114,99,97,109,0,0,0,0,0,0,0,0,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,100,101,115,105,114,101,100,32,98,105,116,115,32,112,101,114,32,109,97,99,114,111,98,108,111,99,107,0,0,0,0,0,67,97,110,32,110,111,116,32,114,101,97,100,32,97,117,100,105,111,32,112,97,99,107,101,116,32,98,101,102,111,114,101,97,117,100,105,111,32,99,111,100,101,99,32,105,115,32,107,110,111,119,110,10,0,0,0,115,116,97,114,116,95,102,114,97,109,101,0,0,0,0,0,112,99,109,95,115,56,0,0,118,105,100,101,0,0,0,0,43,0,0,0,0,0,0,0,99,103,105,0,0,0,0,0,97,98,0,0,0,0,0,0,83,65,77,80,76,69,95,82,65,84,69,0,0,0,0,0,98,105,116,114,97,116,101,32,98,101,108,111,119,32,109,105,110,32,98,105,116,114,97,116,101,10,0,0,0,0,0,0,80,0,0,0,0,0,0,0,111,118,101,114,114,101,97,100,44,32,115,107,105,112,32,37,100,32,101,110,100,100,105,115,116,115,58,32,37,100,32,37,100,10,0,0,0,0,0,0,111,118,101,114,114,101,97,100,44,32,115,107,105,112,32,37,100,32,101,110,100,100,105,115,116,115,58,32,37,100,32,37,100,10,0,0,0,0,0,0,101,114,114,111,114,95,114,97,116,101,0,0,0,0,0,0,82,101,115,101,114,118,101,100,0,0,0,0,0,0,0,0,83,116,114,105,99,116,108,121,32,101,110,102,111,114,99,101,32,103,111,112,32,115,105,122,101,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,95,112,114,101,100,95,102,114,97,109,101,95,100,99,116,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,108,112,100,101,99,46,99,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,105,110,103,32,97,110,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,99,111,109,98,105,110,97,116,105,111,110,10,0,0,0,0,0,0,0,0,78,111,32,99,111,109,112,114,101,115,115,105,111,110,46,10,0,0,0,0,0,0,0,0,77,67,84,32,37,100,32,119,105,116,104,32,116,111,111,32,102,101,119,32,99,111,109,112,111,110,101,110,116,115,32,40,37,100,41,10,0,0,0,0,92,84,0,0,0,0,0,0,73,110,118,97,108,105,100,32,101,110,100,32,116,105,109,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,39,37,115,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,10,0,0,0,0,66,97,100,32,109,97,114,107,101,114,10,0,0,0,0,0,83,99,97,108,97,98,105,108,105,116,121,58,32,117,110,115,117,112,112,111,114,116,101,100,32,115,117,98,100,105,118,105,115,105,111,110,33,32,76,117,109,97,32,98,97,110,100,115,58,32,37,100,44,32,99,104,114,111,109,97,32,98,97,110,100,115,58,32,37,100,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,68,105,115,112,108,97,121,105,110,103,32,116,104,101,32,119,104,111,108,101,32,118,105,100,101,111,32,115,117,114,102,97,99,101,46,10,0,0,0,0,73,110,116,101,114,32,115,108,105,99,101,115,32,105,110,32,97,110,32,73,82,65,80,32,102,114,97,109,101,46,10,0,98,109,112,44,100,112,120,44,106,108,115,44,106,112,101,103,44,106,112,103,44,108,106,112,103,44,112,97,109,44,112,98,109,44,112,99,120,44,112,103,109,44,112,103,109,121,117,118,44,112,110,103,44,112,112,109,44,115,103,105,44,116,103,97,44,116,105,102,44,116,105,102,102,44,106,112,50,44,106,50,99,44,106,50,107,44,120,119,100,44,115,117,110,44,114,97,115,44,114,115,44,105,109,49,44,105,109,56,44,105,109,50,52,44,115,117,110,114,97,115,44,119,101,98,112,44,120,98,109,44,120,102,97,99,101,0,80,73,67,84,95,84,89,80,69,95,80,0,0,0,0,0,77,77,67,79,32,111,112,99,111,100,101,32,91,37,100,44,32,37,100,93,32,97,116,32,37,100,32,109,105,115,109,97,116,99,104,101,115,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,10,0,0,0,112,112,115,58,37,117,32,115,112,115,58,37,117,32,37,115,32,115,108,105,99,101,95,103,114,111,117,112,115,58,37,100,32,114,101,102,58,37,100,47,37,100,32,37,115,32,113,112,58,37,100,47,37,100,47,37,100,47,37,100,32,37,115,32,37,115,32,37,115,32,37,115,10,0,0,0,0,0,0,0,66,97,115,101,108,105,110,101,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,49,46,50,46,53,0,0,0,52,45,108,101,118,101,108,0,32,32,77,97,120,32,70,114,97,109,101,115,105,122,101,58,32,37,100,10,0,0,0,0,33,115,102,45,62,114,99,95,115,116,97,116,50,91,105,93,0,0,0,0,0,0,0,0,103,108,111,98,97,108,58,32,118,101,114,58,37,100,46,37,100,44,32,99,111,100,101,114,58,37,100,44,32,99,111,108,111,114,115,112,97,99,101,58,32,37,100,32,98,112,114,58,37,100,32,99,104,114,111,109,97,58,37,100,40,37,100,58,37,100,41,44,32,97,108,112,104,97,58,37,100,32,115,108,105,99,101,115,58,37,100,120,37,100,32,113,116,97,98,115,58,37,100,32,101,99,58,37,100,32,105,110,116,114,97,58,37,100,10,0,0,0,0,0,77,105,115,115,105,110,103,32,103,114,101,101,110,32,99,104,97,110,110,101,108,10,0,0,115,97,114,95,110,117,109,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,0,0,0,0,77,86,32,112,114,101,99,105,115,105,111,110,32,102,105,110,101,114,32,116,104,97,110,32,101,105,103,104,116,104,45,112,101,108,10,0,0,0,0,0,68,84,83,32,99,111,114,101,32,100,101,116,101,99,116,105,111,110,32,109,105,115,109,97,116,99,104,46,10,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,115,97,109,112,108,101,95,102,109,116,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,0,0,0,0,84,111,111,32,109,97,110,121,32,115,117,98,112,97,99,107,101,116,115,32,37,100,32,102,111,114,32,99,104,97,110,110,101,108,115,32,37,100,10,0,68,97,116,117,109,95,67,97,109,112,111,95,73,110,99,104,97,117,115,112,101,0,0,0,115,105,109,112,108,101,0,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,81,117,101,114,121,32,102,111,114,109,97,116,32,102,97,105,108,101,100,32,102,111,114,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,0,109,97,100,0,0,0,0,0,65,109,98,105,101,110,116,0,102,114,101,105,48,114,95,115,114,99,0,0,0,0,0,0,116,114,97,99,107,0,0,0,83,101,108,101,99,116,32,73,68,51,118,50,32,118,101,114,115,105,111,110,32,116,111,32,119,114,105,116,101,46,32,67,117,114,114,101,110,116,108,121,32,51,32,97,110,100,32,52,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,0,52,52,52,97,108,112,104,97,0,0,0,0,0,0,0,0,116,111,112,0,0,0,0,0,105,109,97,103,101,50,112,105,112,101,0,0,0,0,0,0,104,105,115,116,111,103,114,97,109,0,0,0,0,0,0,0,106,112,115,0,0,0,0,0,97,117,100,105,111,47,105,76,66,67,0,0,0,0,0,0,68,97,116,117,109,95,67,97,109,97,99,117,112,97,0,0,115,101,108,101,99,116,32,73,68,67,84,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,0,0,0,0,0,0,68,80,88,32,40,68,105,103,105,116,97,108,32,80,105,99,116,117,114,101,32,69,120,99,104,97,110,103,101,41,32,105,109,97,103,101,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,114,97,109,101,32,114,97,116,101,32,109,117,115,116,32,98,101,32,105,110,116,101,103,101,114,10,0,0,0,0,0,99,104,114,111,109,97,95,105,110,116,114,97,95,109,97,116,114,105,120,0,0,0,0,0,100,101,98,117,103,0,0,0,32,32,117,110,107,110,111,119,110,32,82,111,81,32,99,104,117,110,107,32,40,37,48,52,88,41,10,0,0,0,0,0,87,77,47,87,77,82,86,66,105,116,114,97,116,101,0,0,105,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,10,0,0,0,0,0,0,116,105,109,101,95,114,101,102,101,114,101,110,99,101,0,0,111,114,105,103,105,110,97,116,111,114,95,114,101,102,101,114,101,110,99,101,0,0,0,0,71,69,78,82,0,0,0,0,109,104,108,114,0,0,0,0,99,117,98,105,99,32,114,111,111,116,0,0,0,0,0,0,104,102,108,105,112,0,0,0,114,102,112,115,58,32,37,102,32,37,102,10,0,0,0,0,47,0,0,0,0,0,0,0,68,97,116,117,109,95,66,117,107,105,116,95,82,105,109,112,97,104,0,0,0,0,0,0,105,100,99,116,0,0,0,0,100,112,120,0,0,0,0,0,109,105,110,32,115,101,99,115,32,116,111,32,115,116,114,105,112,32,72,68,32,102,111,114,32,97,102,116,101,114,32,97,110,32,111,118,101,114,102,108,111,119,32,40,45,49,58,32,116,105,108,108,32,116,104,101,32,101,110,100,44,32,100,101,102,97,117,108,116,32,54,48,41,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,105,110,116,101,114,32,109,97,116,114,105,120,32,99,111,101,102,102,115,0,0,0,0,0,105,115,109,95,108,111,111,107,97,104,101,97,100,0,0,0,115,101,116,32,103,114,101,101,110,32,102,97,100,101,0,0,102,108,97,116,0,0,0,0,98,101,108,108,0,0,0,0,68,97,116,97,72,97,110,100,108,101,114,0,0,0,0,0,84,67,79,77,0,0,0,0,112,97,121,108,111,97,100,95,116,121,112,101,0,0,0,0,98,97,100,32,83,73,80,82,32,102,105,108,101,32,102,108,97,118,111,114,32,37,100,10,0,0,0,0,0,0,0,0,105,109,97,103,101,47,118,110,100,46,109,105,99,114,111,115,111,102,116,46,105,99,111,110,0,0,0,0,0,0,0,0,99,111,100,101,99,32,37,100,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,104,117,110,107,32,115,105,122,101,58,32,37,117,44,32,111,102,102,115,101,116,58,32,37,117,10,0,0,0,0,0,114,97,119,32,71,46,55,50,51,46,49,0,0,0,0,0,112,114,101,118,95,102,111,114,99,101,100,95,110,0,0,0,68,97,116,117,109,95,66,111,103,111,116,97,0,0,0,0,99,111,109,112,114,101,115,115,101,115,32,100,97,114,107,32,97,114,101,97,115,32,115,116,114,111,110,103,101,114,32,116,104,97,110,32,109,101,100,105,117,109,32,111,110,101,115,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,109,51,117,56,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,105,110,116,101,114,95,109,97,116,114,105,120,0,0,0,0,103,114,97,100,102,117,110,0,107,101,101,112,115,105,100,101,0,0,0,0,0,0,0,0,77,105,115,109,97,116,99,104,105,110,103,32,82,73,68,10,0,0,0,0,0,0,0,0,118,111,114,98,105,115,0,0,78,111,119,32,114,101,99,101,105,118,105,110,103,32,112,108,97,121,108,105,115,116,32,37,100,10,0,0,0,0,0,0,100,104,108,114,0,0,0,0,83,97,109,112,108,101,82,97,116,101,0,0,0,0,0,0,104,101,118,99,44,104,50,54,53,44,50,54,53,0,0,0,67,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,39,37,115,39,32,97,115,32,109,101,116,97,100,97,116,97,10,0,0,0,0,0,0,0,77,88,70,32,68,45,49,48,32,111,110,108,121,32,115,117,112,112,111,114,116,32,111,110,101,32,97,117,100,105,111,32,116,114,97,99,107,10,0,0,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,105,110,100,101,120,32,116,97,98,108,101,115,10,0,0,0,0,0,0,0,0,81,95,83,80,65,84,73,65,76,0,0,0,0,0,0,0,37,115,47,105,110,100,101,120,46,102,52,109,0,0,0,0,97,100,116,115,0,0,0,0,68,97,116,117,109,95,66,101,114,110,95,49,56,57,56,0,115,116,114,101,97,109,61,37,100,32,115,116,114,101,97,109,95,116,121,112,101,61,37,120,32,112,105,100,61,37,120,32,112,114,111,103,95,114,101,103,95,100,101,115,99,61,37,46,52,115,10,0,0,0,0,0,100,97,114,107,95,109,97,115,107,0,0,0,0,0,0,0,104,50,54,108,44,104,50,54,52,44,50,54,52,44,97,118,99,0,0,0,0,0,0,0,97,118,95,102,105,102,111,95,115,105,122,101,40,115,116,114,101,97,109,45,62,102,105,102,111,41,32,62,32,48,0,0,104,50,54,51,32,100,101,109,117,120,101,114,0,0,0,0,118,50,49,48,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,116,105,109,101,115,116,97,109,112,32,108,105,110,101,32,39,37,115,39,44,32,97,98,111,114,116,32,112,97,114,115,105,110,103,10,0,0,0,0,0,73,110,118,97,108,105,100,32,73,68,51,118,50,32,118,101,114,115,105,111,110,32,114,101,113,117,101,115,116,101,100,58,32,37,100,46,32,79,110,108,121,32,51,44,32,52,32,111,114,32,48,32,40,100,105,115,97,98,108,101,100,41,32,97,114,101,32,97,108,108,111,119,101,100,46,10,0,0,0,0,109,97,116,114,105,120,0,0,102,114,97,109,101,115,116,101,112,0,0,0,0,0,0,0,69,88,84,58,47,80,68,82,47,100,101,102,97,117,108,116,47,69,83,46,0,0,0,0,105,115,109,118,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,115,121,110,99,32,108,111,115,116,10,0,0,0,0,0,0,103,115,109,32,100,101,109,117,120,101,114,0,0,0,0,0,98,121,116,101,115,32,62,61,32,110,101,101,100,101,100,95,98,121,116,101,115,0,0,0,108,122,119,32,109,105,110,105,109,117,109,32,99,111,100,101,32,115,105,122,101,32,109,117,115,116,32,98,101,32,62,61,32,49,10,0,0,0,0,0,77,97,120,32,69,66,77,76,32,101,108,101,109,101,110,116,32,100,101,112,116,104,32,40,37,100,41,32,114,101,97,99,104,101,100,44,32,99,97,110,110,111,116,32,112,97,114,115,101,32,102,117,114,116,104,101,114,46,10,0,0,0,0,0,102,95,115,105,122,101,61,32,37,54,100,32,0,0,0,0,68,97,116,117,109,95,66,101,114,109,117,100,97,95,49,57,53,55,0,0,0,0,0,0,105,110,116,101,114,32,109,97,115,107,105,110,103,0,0,0,105,109,97,103,101,47,103,105,102,0,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,56,48,56,56,102,108,101,120,32,84,77,86,0,0,0,0,115,103,105,0,0,0,0,0,78,111,32,98,105,116,114,97,116,101,32,115,112,101,99,105,102,105,101,100,46,32,65,115,115,117,109,105,110,103,32,56,48,48,48,32,98,47,115,10,0,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,105,110,116,114,97,32,109,97,116,114,105,120,32,99,111,101,102,102,115,0,0,0,0,0,116,99,111,44,114,99,111,44,103,55,50,51,95,49,0,0,103,55,50,50,44,55,50,50,0,0,0,0,0,0,0,0,116,114,97,99,107,0,0,0,35,116,98,32,37,100,58,32,37,100,47,37,100,10,0,0,65,69,83,45,49,50,56,0,37,100,44,32,37,49,48,108,108,100,44,32,37,49,48,108,108,100,44,32,37,56,100,44,32,37,56,100,44,32,48,120,37,48,56,120,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,116,114,101,97,109,32,116,121,112,101,32,105,110,32,115,116,114,101,97,109,32,37,100,10,0,0,0,115,115,101,103,109,101,110,116,0,0,0,0,0,0,0,0,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,97,117,100,105,111,32,105,110,32,102,108,118,32,105,115,32,118,97,108,105,100,32,98,117,116,32,109,111,115,116,32,108,105,107,101,108,121,32,117,110,112,108,97,121,97,98,108,101,32,40,104,97,114,100,119,97,114,101,32,100,101,112,101,110,100,101,110,116,41,59,32,117,115,101,32,115,49,54,108,101,10,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,115,116,114,101,97,109,32,116,121,112,101,59,32,114,101,118,105,115,105,111,110,61,37,105,44,32,114,101,118,105,115,105,111,110,50,61,37,105,0,0,68,97,116,117,109,95,82,101,115,101,97,117,95,78,97,116,105,111,110,97,108,95,66,101,108,103,101,95,49,57,53,48,0,0,0,0,0,0,0,0,112,95,109,97,115,107,0,0,116,109,118,0,0,0,0,0,50,53,0,0,0,0,0,0,118,105,100,101,111,47,120,45,102,108,118,0,0,0,0,0,105,110,116,114,97,95,109,97,116,114,105,120,0,0,0,0,112,97,99,107,101,116,95,111,98,106,95,115,105,122,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,115,107,105,112,112,105,110,103,32,102,108,118,32,112,97,99,107,101,116,58,32,116,121,112,101,32,37,100,44,32,115,105,122,101,32,37,100,44,32,102,108,97,103,115,32,37,100,10,0,0,0,0,0,0,0,0,70,105,108,101,32,119,105,116,104,32,110,111,32,115,112,101,99,105,102,105,101,100,32,119,105,100,116,104,47,104,101,105,103,104,116,46,32,84,114,121,105,110,103,32,54,52,48,120,52,56,48,46,10,0,0,0,115,101,108,101,99,116,32,109,97,116,104,101,109,97,116,105,99,97,108,32,112,114,101,99,105,115,105,111,110,0,0,0,32,43,32,0,0,0,0,0,97,117,100,105,111,47,120,45,102,108,97,99,0,0,0,0,82,101,113,117,101,115,116,101,100,32,99,104,97,110,110,101,108,32,37,115,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,105,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,46,10,0,0,0,0,0,0,0,97,114,101,115,97,109,112,108,101,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,46,10,0,0,0,0,0,0,0,0,37,108,102,47,37,108,102,0,102,114,97,109,101,112,97,99,107,0,0,0,0,0,0,0,102,114,101,113,117,101,110,99,121,0,0,0,0,0,0,0,102,108,109,0,0,0,0,0,68,97,116,117,109,95,66,101,105,106,105,110,103,95,49,57,53,52,0,0,0,0,0,0,102,108,109,0,0,0,0,0,115,112,97,116,105,97,108,32,99,111,109,112,108,101,120,105,116,121,32,109,97,115,107,105,110,103,0,0,0,0,0,0,116,114,117,110,99,97,116,101,0,0,0,0,0,0,0,0,118,50,49,48,120,0,0,0,115,101,116,32,118,105,100,101,111,32,102,105,108,116,101,114,115,0,0,0,0,0,0,0,102,102,109,101,116,97,0,0,108,105,110,101,97,114,32,115,108,111,112,101,0,0,0,0,91,83,84,82,69,65,77,93,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,50,53,0,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,115,101,116,32,109,111,114,112,104,32,120,32,102,114,101,113,117,101,110,99,121,0,0,0,76,117,99,105,100,97,32,71,114,97,110,100,101,0,0,0,105,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,10,0,0,0,0,0,0,0,0,114,97,110,100,111,109,95,102], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2138760);
/* memory initializer */ allocate([105,108,108,95,114,97,116,105,111,0,0,0,0,0,0,0,114,97,116,105,111,0,0,0,112,97,102,44,102,97,112,0,111,110,108,121,32,100,101,105,110,116,101,114,108,97,99,101,32,102,114,97,109,101,115,32,109,97,114,107,101,100,32,97,115,32,105,110,116,101,114,108,97,99,101,100,0,0,0,0,115,104,111,119,32,108,105,99,101,110,115,101,0,0,0,0,98,97,99,107,119,97,114,100,0,0,0,0,0,0,0,0,99,104,114,111,109,97,0,0,99,111,117,110,116,101,114,99,108,111,99,107,119,105,115,101,0,0,0,0,0,0,0,0,118,105,100,101,111,32,104,101,97,100,101,114,32,102,111,108,108,111,119,101,100,32,98,121,32,97,117,100,105,111,32,112,97,99,107,101,116,0,0,0,99,100,97,116,97,0,0,0,68,97,116,117,109,95,66,101,100,117,97,114,97,109,0,0,115,101,116,32,105,110,112,117,116,32,89,67,98,67,114,32,116,121,112,101,0,0,0,0,115,99,112,108,120,95,109,97,115,107,0,0,0,0,0,0,99,0,0,0,0,0,0,0,102,97,105,108,101,100,32,114,101,97,100,105,110,103,32,99,104,117,110,107,32,116,121,112,101,10,0,0,0,0,0,0,65,117,114,97,118,105,115,105,111,110,32,65,117,114,97,32,50,0,0,0,0,0,0,0,67,97,110,39,116,32,112,114,111,99,101,115,115,32,68,86,32,102,114,97,109,101,32,35,37,100,46,32,73,110,115,117,102,102,105,99,105,101,110,116,32,97,117,100,105,111,32,100,97,116,97,32,111,114,32,115,101,118,101,114,101,32,115,121,110,99,32,112,114,111,98,108,101,109,46,10,0,0,0,0,111,117,116,95,119,0,0,0,118,102,0,0,0,0,0,0,115,101,116,32,116,104,101,32,121,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,99,49,95,115,116,114,101,110,103,116,104,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,108,117,116,51,100,46,99,0,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,115,101,116,32,86,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,99,104,117,110,107,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,10,0,0,0,100,101,102,97,117,108,116,0,116,101,120,116,0,0,0,0,115,101,116,32,119,97,118,101,102,111,114,109,32,109,105,114,114,111,114,105,110,103,0,0,100,110,120,104,100,32,100,101,109,117,120,101,114,0,0,0,100,105,114,97,99,32,100,101,109,117,120,101,114,0,0,0,84,111,111,32,108,97,114,103,101,32,99,104,117,110,107,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,116,102,102,0,0,0,0,0,110,118,49,50,0,0,0,0,66,108,117,101,86,105,111,108,101,116,0,0,0,0,0,0,65,86,79,112,116,105,111,110,32,116,121,112,101,32,37,100,32,111,102,32,111,112,116,105,111,110,32,37,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,10,0,0,0,0,0,0,100,0,0,0,0,0,0,0,51,48,50,44,100,97,117,100,0,0,0,0,0,0,0,0,103,116,0,0,0,0,0,0,77,117,120,101,114,32,110,111,116,32,102,111,117,110,100,0,67,82,67,61,48,120,37,48,56,120,10,0,0,0,0,0,83,82,0,0,0,0,0,0,117,115,105,110,103,32,37,115,10,0,0,0,0,0,0,0,102,117,108,108,32,99,104,114,111,109,97,32,105,110,116,101,114,112,111,108,97,116,105,111,110,0,0,0,0,0,0,0,82,101,109,97,116,114,105,120,32,105,115,32,110,101,101,100,101,100,32,98,101,116,119,101,101,110,32,37,115,32,97,110,100,32,37,115,32,98,117,116,32,116,104,101,114,101,32,105,115,32,110,111,116,32,101,110,111,117,103,104,32,105,110,102,111,114,109,97,116,105,111,110,32,116,111,32,100,111,32,105,116,10,0,0,0,0,0,0,120,58,37,100,32,121,58,37,100,32,119,58,37,100,32,104,58,37,100,32,99,111,108,111,114,58,48,120,37,48,50,88,37,48,50,88,37,48,50,88,37,48,50,88,10,0,0,0,92,111,114,103,40,37,100,44,37,100,41,37,49,91,92,125,93,37,110,0,0,0,0,0,109,105,114,114,111,114,101,100,32,101,100,103,101,32,97,116,32,98,108,97,110,107,32,108,111,99,97,116,105,111,110,115,0,0,0,0,0,0,0,0,68,97,116,117,109,95,66,97,114,98,97,100,111,115,0,0,116,101,109,112,111,114,97,108,32,99,111,109,112,108,101,120,105,116,121,32,109,97,115,107,105,110,103,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,68,117,99,107,32,68,75,51,0,0,0,0,0,0,100,105,97,108,110,111,114,109,0,0,0,0,0,0,0,0,115,101,116,32,119,104,101,116,104,101,114,32,111,114,32,110,111,116,32,99,104,114,111,109,97,32,105,115,32,99,111,110,115,105,100,101,114,101,100,32,105,110,32,116,104,101,32,109,101,116,114,105,99,32,99,97,108,99,117,108,97,116,105,111,110,115,0,0,0,0,0,0,100,105,97,108,110,111,114,109,0,0,0,0,0,0,0,0,102,114,97,109,101,32,67,82,67,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,84,111,111,32,109,97,110,121,32,112,97,116,99,104,101,115,58,32,37,100,10,0,0,0,65,78,77,82,32,109,101,116,104,111,100,0,0,0,0,0,97,117,114,97,50,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,111,112,101,110,32,39,37,115,39,10,0,0,0,0,0,0,0,0,109,115,95,112,114,101,115,101,110,116,32,61,32,51,32,105,115,32,114,101,115,101,114,118,101,100,46,10,0,0,0,0,98,121,116,101,115,116,114,101,97,109,32,111,118,101,114,114,101,97,100,10,0,0,0,0,76,97,114,103,101,32,98,108,111,99,107,32,97,108,105,103,110,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,100,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,104,117,110,107,32,115,105,122,101,10,0,80,97,99,107,101,100,32,115,97,109,112,108,101,115,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,48,46,50,56,54,47,48,46,50,49,57,32,48,46,54,51,57,47,48,46,54,52,51,0,73,110,118,97,108,105,100,32,102,117,108,108,121,32,99,111,100,101,100,32,115,117,112,101,114,98,108,111,99,107,32,114,117,110,32,108,101,110,103,116,104,10,0,0,0,0,0,0,109,97,112,112,105,110,103,95,115,101,116,117,112,45,62,109,97,103,110,105,116,117,100,101,91,106,93,0,0,0,0,0,78,111,110,45,122,101,114,111,32,114,111,116,97,116,105,111,110,32,99,111,101,102,102,105,99,105,101,110,116,115,0,0,111,119,0,0,0,0,0,0,102,105,108,101,0,0,0,0,67,79,78,68,79,86,69,82,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,99,100,120,108,44,120,108,0,115,101,116,32,116,104,101,32,97,108,112,104,97,32,103,97,105,110,32,102,111,114,32,116,104,101,32,98,108,117,101,32,99,104,97,110,110,101,108,0,83,112,101,99,105,102,105,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,87,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,52,10,0,99,97,118,115,118,105,100,101,111,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,80,114,111,106,78,97,116,79,114,105,103,105,110,76,111,110,103,71,101,111,75,101,121,0,97,100,100,105,116,105,111,110,0,0,0,0,0,0,0,0,83,97,109,112,108,101,115,32,112,101,114,32,112,105,120,101,108,32,114,101,113,117,105,114,101,115,32,97,32,115,105,110,103,108,101,32,118,97,108,117,101,44,32,109,97,110,121,32,112,114,111,118,105,100,101,100,10,0,0,0,0,0,0,0,119,97,116,101,114,109,97,114,107,32,107,101,121,32,37,35,120,10,0,0,0,0,0,0,60,98,62,0,0,0,0,0,98,105,115,117,0,0,0,0,72,117,102,102,109,97,110,32,99,111,100,101,115,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,110,109,101,97,110,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,109,97,114,107,101,114,32,109,105,115,115,105,110,103,10,0,100,97,114,95,100,101,110,0,32,105,110,58,37,100,32,0,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,44,32,37,105,32,60,32,37,105,10,0,0,0,0,0,0,98,105,116,115,95,112,101,114,95,109,98,0,0,0,0,0,97,117,100,105,111,47,120,45,99,97,102,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,116,114,105,109,46,99,0,0,0,0,0,0,37,115,58,32,99,111,117,108,100,32,110,111,116,32,115,101,101,107,32,116,111,32,112,111,115,105,116,105,111,110,32,37,108,108,100,10,0,0,0,0,115,101,116,32,98,105,116,114,97,116,101,32,40,105,110,32,98,105,116,115,47,115,41,0,80,82,69,86,95,79,85,84,84,0,0,0,0,0,0,0,100,101,115,99,32,99,104,117,110,107,32,110,111,116,32,112,114,101,115,101,110,116,10,0,87,97,114,110,105,110,103,32,109,105,110,95,114,97,116,101,32,62,32,48,32,98,117,116,32,109,105,110,95,114,97,116,101,32,33,61,32,109,97,120,95,114,97,116,101,32,105,115,110,39,116,32,114,101,99,111,109,109,101,110,100,101,100,33,10,0,0,0,0,0,0,0,37,50,100,0,0,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,116,121,112,101,10,0,0,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,116,121,112,101,10,0,0,0,0,0,113,117,97,110,116,105,122,101,114,95,110,111,105,115,101,95,115,104,97,112,105,110,103,0,86,105,100,101,111,32,79,98,106,101,99,116,32,76,97,121,101,114,32,83,116,97,114,116,0,0,0,0,0,0,0,0,115,116,114,105,99,116,95,103,111,112,0,0,0,0,0,0,112,105,99,116,117,114,101,95,115,116,114,117,99,116,117,114,101,32,37,100,32,105,110,118,97,108,105,100,44,32,105,103,110,111,114,105,110,103,10,0,102,105,108,116,101,114,32,60,32,50,0,0,0,0,0,0,105,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,115,105,122,101,32,37,117,10,0,0,0,0,0,0,0,0,100,101,99,111,100,101,95,115,111,102,48,58,32,101,114,114,111,114,44,32,108,101,110,40,37,100,41,32,109,105,115,109,97,116,99,104,10,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,101,110,97,98,108,101,100,46,10,0,0,0,73,110,118,97,108,105,100,32,99,111,109,112,110,111,32,37,100,46,32,84,104,101,114,101,32,97,114,101,32,37,100,32,99,111,109,112,111,110,101,110,116,115,32,105,110,32,116,104,101,32,105,109,97,103,101,46,10,0,0,0,0,0,0,0,37,100,32,37,98,32,37,89,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,97,114,116,32,116,105,109,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,39,37,115,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,10,0,0,66,97,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,79,110,108,121,32,89,86,85,57,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,32,105,115,32,115,117,112,112,111,114,116,101,100,33,10,0,72,97,108,102,112,101,108,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,0,0,73,110,118,97,108,105,100,32,118,105,115,105,98,108,101,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,58,32,37,100,120,37,100,46,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,115,108,105,99,101,32,116,121,112,101,58,32,37,100,46,10,0,0,0,0,0,0,0,0,80,73,67,84,95,84,89,80,69,95,73,0,0,0,0,0,105,110,118,97,108,105,100,32,98,121,116,101,32,111,114,100,101,114,58,32,37,88,10,0,37,100,32,37,100,32,37,112,10,0,0,0,0,0,0,0,114,101,102,101,114,101,110,99,101,32,111,118,101,114,102,108,111,119,32,40,112,112,115,41,10,0,0,0,0,0,0,0,115,116,101,114,101,111,95,109,111,100,101,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,99,117,114,115,111,114,32,98,117,102,102,101,114,10,0,0,100,101,99,111,100,101,95,104,121,98,114,105,100,32,102,97,105,108,101,100,10,0,0,0,50,45,108,101,118,101,108,0,32,32,77,97,120,32,66,108,111,99,107,115,105,122,101,58,32,37,100,10,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,37,100,32,111,102,32,115,108,105,99,101,115,32,114,101,113,117,101,115,116,101,100,44,32,112,108,101,97,115,101,32,115,112,101,99,105,102,121,32,97,32,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,119,105,116,104,32,45,115,108,105,99,101,115,32,40,101,120,58,52,44,54,44,57,44,49,50,44,49,54,44,32,46,46,46,41,10,0,0,0,0,0,0,0,0,67,82,67,32,109,105,115,109,97,116,99,104,32,37,88,33,10,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,100,32,99,104,97,110,110,101,108,10,0,0,0,0,111,102,102,0,0,0,0,0,116,105,109,101,95,98,97,115,101,95,100,101,110,0,0,0,82,101,112,111,114,116,101,100,32,97,117,100,105,111,32,115,105,122,101,32,37,100,32,105,115,32,98,105,103,103,101,114,32,116,104,97,110,32,112,97,99,107,101,116,32,115,105,122,101,32,40,37,100,41,10,0,85,110,115,117,112,112,111,114,116,101,100,32,108,97,114,103,101,32,98,108,111,99,107,32,115,105,122,101,10,0,0,0,65,115,115,101,116,32,104,101,97,100,101,114,32,115,105,122,101,32,109,105,115,109,97,116,99,104,46,10,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,102,105,102,111,10,0,0,0,0,0,0,0,0,115,117,98,98,97,110,100,115,32,61,32,48,0,0,0,0,68,97,116,117,109,95,66,97,116,97,118,105,97,0,0,0,116,99,112,108,120,95,109,97,115,107,0,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,0,0,0,84,104,101,32,102,111,108,108,111,119,105,110,103,32,102,105,108,116,101,114,115,32,99,111,117,108,100,32,110,111,116,32,99,104,111,111,115,101,32,116,104,101,105,114,32,102,111,114,109,97,116,115,58,32,37,115,10,67,111,110,115,105,100,101,114,32,105,110,115,101,114,116,105,110,103,32,116,104,101,32,40,97,41,102,111,114,109,97,116,32,102,105,108,116,101,114,32,110,101,97,114,32,116,104,101,105,114,32,105,110,112,117,116,32,111,114,32,111,117,116,112,117,116,46,10,0,0,0,65,117,114,97,118,105,115,105,111,110,32,65,85,82,65,0,97,117,100,105,111,47,98,105,116,0,0,0,0,0,0,0,102,112,115,0,0,0,0,0,69,117,114,111,45,84,101,99,104,110,111,0,0,0,0,0,102,114,101,105,48,114,0,0,87,77,47,84,114,97,99,107,78,117,109,98,101,114,0,0,105,100,51,118,50,95,118,101,114,115,105,111,110,0,0,0,52,50,50,0,0,0,0,0,118,115,116,97,116,115,95,102,105,108,101,0,0,0,0,0,66,105,110,97,114,121,32,116,101,120,116,32,100,101,109,117,120,101,114,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,105,110,100,101,120,32,101,110,116,114,121,32,102,111,114,32,102,114,97,109,101,32,37,108,108,100,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,97,117,100,105,111,47,118,105,100,101,111,32,111,102,102,115,101,116,115,32,111,114,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,117,110,117,115,101,100,32,112,97,108,101,116,116,101,10,0,0,0,0,0,0,84,104,105,115,32,97,118,115,32,112,114,101,116,101,110,100,32,116,111,32,98,101,32,37,100,120,37,100,32,119,104,101,110,32,116,104,101,32,97,118,115,32,102,111,114,109,97,116,32,105,115,32,115,117,112,112,111,115,101,100,32,116,111,32,98,101,32,51,49,56,120,49,57,56,32,111,110,108,121,46,10,0,0,0,0,0,0,0,99,104,97,110,32,37,100,0,68,97,116,117,109,95,65,114,99,95,49,57,54,48,0,0,99,111,109,112,114,101,115,115,101,115,32,98,114,105,103,104,116,32,97,114,101,97,115,32,115,116,114,111,110,103,101,114,32,116,104,97,110,32,109,101,100,105,117,109,32,111,110,101,115,0,0,0,0,0,0,0,97,117,114,97,0,0,0,0,100,117,109,112,32,118,105,100,101,111,32,99,111,100,105,110,103,32,115,116,97,116,105,115,116,105,99,115,32,116,111,32,102,105,108,101,0,0,0,0,104,105,100,101,95,98,97,110,110,101,114,0,0,0,0,0,87,77,47,87,77,82,86,69,120,112,105,114,97,116,105,111,110,68,97,116,101,0,0,0,111,114,105,103,105,110,97,116,105,111,110,95,116,105,109,101,0,0,0,0,0,0,0,0,110,111,32,39,100,97,116,97,39,32,116,97,103,32,102,111,117,110,100,10,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,102,111,114,109,97,116,0,0,99,98,114,116,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,101,120,116,114,97,100,97,116,97,32,111,102,32,115,105,122,101,32,37,100,10,0,0,0,0,78,111,32,85,82,76,32,80,114,111,116,111,99,111,108,115,32,97,114,101,32,114,101,103,105,115,116,101,114,101,100,46,32,77,105,115,115,105,110,103,32,99,97,108,108,32,116,111,32,97,118,95,114,101,103,105,115,116,101,114,95,97,108,108,40,41,63,10,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,119,105,116,104,32,110,97,109,101,32,39,37,115,39,44,32,117,110,107,110,111,119,110,32,102,105,108,116,101,114,32,111,114,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,104,97,112,112,101,110,101,100,10,0,0,0,68,97,116,117,109,95,65,114,99,95,49,57,53,48,0,0,108,117,109,105,95,109,97,115,107,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,81,73,32,118,105,100,101,111,0,0,0,0,0,0,0,100,116,115,104,100,95,102,97,108,108,98,97,99,107,95,116,105,109,101,0,0,0,0,0,118,105,100,101,111,47,120,45,109,115,118,105,100,101,111,0,118,115,116,97,116,115,0,0,37,100,0,0,0,0,0,0,103,102,0,0,0,0,0,0,108,105,115,116,95,116,121,112,101,0,0,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,72,50,54,52,47,57,48,48,48,48,13,10,97,61,102,109,116,112,58,37,100,32,112,97,99,107,101,116,105,122,97,116,105,111,110,45,109,111,100,101,61,37,100,37,115,13,10,0,0,0,0,0,109,105,120,0,0,0,0,0,83,101,110,100,32,82,84,67,80,32,66,89,69,32,112,97,99,107,101,116,115,32,119,104,101,110,32,102,105,110,105,115,104,105,110,103,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,111,100,101,99,100,97,116,97,95,108,101,110,103,116,104,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,101,110,99,111,100,101,100,95,98,121,0,0,0,0,0,0,97,117,100,105,111,47,98,97,115,105,99,0,0,0,0,0,103,55,50,51,95,49,0,0,116,111,116,97,108,32,115,97,109,112,108,101,115,58,32,37,108,108,100,10,0,0,0,0,68,97,116,117,109,95,65,114,97,116,117,0,0,0,0,0,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,65,65,78,32,68,67,84,0,0,117,51,50,98,101,0,0,0,117,110,107,110,111,119,110,32,99,104,117,110,107,32,37,120,10,0,0,0,0,0,0,0,116,113,105,0,0,0,0,0,117,51,50,98,101,0,0,0,99,97,108,99,117,108,97,116,101,32,80,83,78,82,32,111,102,32,99,111,109,112,114,101,115,115,101,100,32,102,114,97,109,101,115,0,0,0,0,0,116,101,120,116,47,120,45,115,115,97,0,0,0,0,0,0,91,69,118,101,110,116,115,93,0,0,0,0,0,0,0,0,102,105,101,108,100,111,114,100,101,114,0,0,0,0,0,0,116,114,121,32,116,111,32,105,110,116,101,114,108,101,97,118,101,32,111,117,116,112,117,116,116,101,100,32,112,97,99,107,101,116,115,32,98,121,32,100,116,115,0,0,0,0,0,0,69,75,66,32,0,0,0,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,79,112,117,115,32,104,101,97,100,101,114,115,10,0,0,0,0,0,117,114,108,32,0,0,0,0,118,105,100,101,111,47,120,45,109,115,45,97,115,102,0,0,117,54,52,0,0,0,0,0,83,107,105,112,69,110,100,0,37,51,49,115,32,37,42,115,32,37,51,49,115,0,0,0,111,110,108,121,32,52,56,107,104,122,32,105,115,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,102,111,117,110,100,32,105,110,99,111,110,115,105,115,116,101,110,116,32,66,111,100,121,83,73,68,10,0,0,0,0,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,108,97,116,109,0,0,0,0,68,97,116,117,109,95,76,105,115,98,111,110,0,0,0,0,99,97,110,110,111,116,32,115,101,116,32,115,116,114,101,97,109,32,105,110,102,111,44,32,99,111,100,101,99,32,105,115,32,111,112,101,110,10,0,0,102,97,97,110,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,71,81,32,118,105,100,101,111,0,0,0,0,0,0,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,58,37,48,51,100,44,32,102,105,108,101,112,111,115,58,32,37,108,108,120,0,0,0,0,0,0,97,115,102,95,114,101,97,100,95,112,116,115,32,102,97,105,108,101,100,10,0,0,0,0,71,111,116,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,112,105,99,116,117,114,101,32,105,110,32,115,116,114,101,97,109,32,37,100,44,32,105,103,110,111,114,105,110,103,46,10,0,0,0,0,0,0,112,115,110,114,0,0,0,0,97,113,116,0,0,0,0,0,84,97,103,32,115,105,122,101,32,105,115,32,119,97,121,32,116,111,111,32,98,105,103,10,0,0,0,0,0,0,0,0,97,112,101,44,97,112,108,44,109,97,99,0,0,0,0,0,67,82,89,79,95,65,80,67,0,0,0,0,0,0,0,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,109,97,120,95,112,97,103,101,115,32,33,61,32,50,53,54,0,0,0,0,0,0,0,0,97,117,100,105,111,47,97,109,114,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,97,116,114,111,115,107,97,101,110,99,46,99,0,0,0,0,0,0,0,87,111,114,107,105,110,103,32,97,114,111,117,110,100,32,98,114,111,107,101,110,32,105,110,100,101,120,46,10,0,0,0,70,97,105,108,101,100,32,116,111,32,102,105,110,100,32,99,111,100,101,99,10,0,0,0,80,83,78,82,61,32,37,54,46,50,102,32,0,0,0,0,68,97,116,117,109,95,65,103,97,100,101,122,0,0,0,0,97,108,116,105,118,101,99,0,116,103,113,0,0,0,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,116,105,102,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,104,105,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,116,104,101,32,121,97,100,105,102,32,102,105,108,116,101,114,32,105,110,115,116,101,97,100,0,108,105,98,97,118,102,105,108,116,101,114,47,100,117,97,108,105,110,112,117,116,46,99,0,84,82,67,75,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,97,102,116,101,114,32,119,104,105,99,104,32,116,104,101,32,105,110,100,101,120,32,119,114,97,112,115,0,0,35,69,88,84,45,88,45,75,69,89,58,0,0,0,0,0,78,111,32,98,105,116,32,114,97,116,101,32,115,101,116,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,115,114,99,0,0,0,0,0,110,95,115,97,109,112,108,101,115,58,32,37,108,108,100,10,0,0,0,0,0,0,0,0,97,116,32,109,111,115,116,32,111,110,101,32,97,117,100,105,111,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,32,105,110,32,102,108,118,10,0,0,0,102,105,108,101,115,105,122,101,0,0,0,0,0,0,0,0,115,116,114,101,97,109,32,116,121,112,101,59,32,114,101,118,105,115,105,111,110,61,37,105,0,0,0,0,0,0,0,0,68,97,116,117,109,95,65,102,103,111,111,121,101,0,0,0,109,109,120,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,71,86,32,118,105,100,101,111,0,0,0,0,0,0,0,115,101,116,32,102,114,97,109,101,114,97,116,101,32,40,102,114,97,109,101,115,32,112,101,114,32,115,101,99,111,110,100,41,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,78,97,78,32,102,111,114,32,118,111,108,117,109,101,10,0,0,0,100,101,105,110,116,101,114,108,97,99,101,0,0,0,0,0,115,97,109,112,108,101,32,115,105,122,101,32,40,37,100,41,32,33,61,32,98,108,111,99,107,32,97,108,105,103,110,32,40,37,100,41,10,0,0,0,110,0,0,0,0,0,0,0,112,97,99,107,101,116,95,114,101,112,108,105,99,95,115,105,122,101,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,116,114,97,99,107,95,103,97,105,110,32,61,32,37,43,46,50,102,32,100,66,10,0,0,116,105,109,101,99,111,100,101,58,32,116,98,99,61,37,100,47,37,100,32,105,110,118,97,108,105,100,44,32,102,97,108,108,98,97,99,107,32,111,110,32,37,100,47,37,100,10,0,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,0,37,115,37,46,51,103,32,105,37,100,0,0,0,0,0,0,100,101,102,97,117,108,116,0,103,114,97,112,104,32,37,100,32,37,115,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,97,116,116,97,99,107,115,32,37,100,32,100,105,102,102,101,114,115,32,102,114,111,109,32,110,117,109,98,101,114,32,111,102,32,100,101,99,97,121,115,32,37,100,46,10,0,112,97,110,32,102,105,108,116,101,114,32,110,101,101,100,115,32,97,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,97,110,100,32,97,32,115,101,116,32,111,102,32,99,104,97,110,110,101,108,115,32,100,101,102,105,110,105,116,105,111,110,115,32,97,115,32,112,97,114,97,109,101,116,101,114,10,0,0,0,0,0,0,0,98,50,0,0,0,0,0,0,68,97,116,117,109,95,65,105,110,95,101,108,95,65,98,100,95,49,57,55,48,0,0,0,97,99,99,117,114,97,116,101,32,105,110,116,101,103,101,114,0,0,0,0,0,0,0,0,116,103,118,0,0,0,0,0,99,104,97,110,110,101,108,115,32,62,32,48,0,0,0,0,112,114,101,102,105,120,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,46,10,0,0,0,0,0,116,114,105,0,0,0,0,0,100,101,102,97,117,108,116,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,109,111,114,112,104,120,102,0,37,100,0,0,0,0,0,0,66,51,47,83,50,51,0,0,115,101,116,32,102,105,108,108,32,114,97,116,105,111,32,102,111,114,32,102,105,108,108,105,110,103,32,105,110,105,116,105,97,108,32,103,114,105,100,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,101,100,0,0,0,0,0,0,97,116,116,97,99,107,115,0,102,111,114,119,97,114,100,0,108,117,109,97,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,46,10,0,0,0,0,0,76,0,0,0,0,0,0,0,99,108,111,99,107,119,105,115,101,0,0,0,0,0,0,0,37,115,37,48,50,100,58,37,48,50,100,58,37,48,50,100,37,99,37,48,50,100,0,0,84,104,105,115,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,39,124,39,32,116,111,32,115,101,112,97,114,97,116,101,32,116,104,101,32,109,97,112,112,105,110,103,115,46,10,0,0,0,68,97,116,117,109,95,65,117,115,116,114,97,108,105,97,110,95,71,101,111,100,101,116,105,99,95,68,97,116,117,109,95,49,57,56,52,0,0,0,0,105,110,95,99,111,108,111,114,95,109,97,116,114,105,120,0,105,110,116,0,0,0,0,0,128,0,0,0,0,0,0,0,98,108,97,99,107,0,0,0,77,111,116,105,111,110,32,80,105,120,101,108,115,32,118,105,100,101,111,0,0,0,0,0,128,0,0,0,0,0,0,0,105,110,95,104,0,0,0,0,115,101,108,101,99,116,32,116,119,111,32,112,97,115,115,32,108,111,103,32,102,105,108,101,32,110,97,109,101,32,112,114,101,102,105,120,0,0,0,0,115,101,116,32,116,104,101,32,120,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,110,111,105,115,101,32,115,101,101,100,0,0,0,0,0,110,97,109,101,32,32,32,100,101,112,116,104,0,0,0,0,118,0,0,0,0,0,0,0,97,115,0,0,0,0,0,0,32,37,100,37,99,0,0,0,128,0,0,0,0,0,0,0,119,97,118,101,102,111,114,109,95,109,105,114,114,111,114,0,68,117,112,108,105,99,97,116,105,110,103,32,102,114,97,109,101,46,10,0,0,0,0,0,47,100,101,118,47,117,114,97,110,100,111,109,0,0,0,0,97,115,115,117,109,101,32,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,0,98,97,115,115,0,0,0,0,114,103,98,52,95,98,121,116,101,0,0,0,0,0,0,0,66,108,117,101,0,0,0,0,37,115,32,65,86,79,112,116,105,111,110,115,58,10,0,0,68,117,114,97,116,105,111,110,32,111,102,32,116,104,101,32,101,102,102,101,99,116,32,105,110,32,115,101,99,111,110,100,115,46,0,0,0,0,0,0,103,116,101,0,0,0,0,0,77,85,88,69,82,95,78,79,84,95,70,79,85,78,68,0,115,105,100,101,32,108,101,102,116,0,0,0,0,0,0,0,67,0,0,0,0,0,0,0,102,117,108,108,95,99,104,114,111,109,97,95,105,110,116,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,97,110,100,32,108,97,121,111,117,116,32,97,114,101,32,117,110,115,101,116,10,0,0,0,0,0,0,0,83,105,122,101,32,118,97,108,117,101,115,32,108,101,115,115,32,116,104,97,110,32,48,32,97,114,101,32,110,111,116,32,97,99,99,101,112,116,97,98,108,101,46,10,0,0,0,0,92,112,111,115,40,37,100,44,37,100,41,37,49,91,92,125,93,37,110,0,0,0,0,0,68,97,116,117,109,95,65,117,115,116,114,97,108,105,97,110,95,71,101,111,100,101,116,105,99,95,68,97,116,117,109,95,49,57,54,54,0,0,0,0,109,105,114,114,111,114,0,0,102,97,115,116,32,105,110,116,101,103,101,114,0,0,0,0,97,100,112,99,109,95,105,109,97,95,100,107,51,0,0,0,67,111,112,121,114,105,103,104,116,32,66,105,116,0,0,0,67,111,112,121,114,105,103,104,116,32,66,105,116,0,0,0,99,104,114,111,109,97,0,0,105,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,116,101,109,112,111,0,0,0,84,111,111,32,109,97,110,121,32,110,111,105,115,101,32,102,108,111,111,114,32,115,99,97,108,101,32,102,97,99,116,111,114,115,58,32,37,100,10,0,97,110,109,114,0,0,0,0,109,111,116,105,111,110,112,105,120,101,108,115,0,0,0,0,115,107,105,112,95,100,97,116,97,95,115,116,114,101,97,109,95,101,108,101,109,101,110,116,58,32,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,0,0,119,111,114,100,115,116,114,101,97,109,32,111,118,101,114,114,101,97,100,10,0,0,0,0,85,110,107,110,111,119,110,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,117,98,102,114,97,109,101,115,32,37,105,10,0,105,110,118,97,108,105,100,32,115,121,109,98,111,108,32,37,100,32,43,32,114,101,112,101,97,116,32,37,100,32,62,32,97,108,112,104,97,98,101,116,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,72,121,98,114,105,100,32,99,111,110,102,105,103,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,48,46,51,48,53,47,48,46,50,56,54,32,48,46,54,57,52,47,48,46,55,49,51,0,73,110,118,97,108,105,100,32,112,97,114,116,105,97,108,108,121,32,99,111,100,101,100,32,115,117,112,101,114,98,108,111,99,107,32,114,117,110,32,108,101,110,103,116,104,10,0,0,79,116,104,101,114,32,109,97,112,112,105,110,103,115,32,116,104,97,110,32,116,121,112,101,32,48,32,97,114,101,32,110,111,116,32,99,111,109,112,108,105,97,110,116,32,119,105,116,104,32,116,104,101,32,86,111,114,98,105,115,32,73,32,115,112,101,99,105,102,105,99,97,116,105,111,110,46,32,10,0,78,101,101,100,32,116,119,111,32,115,112,114,105,116,101,115,44,32,111,110,108,121,32,103,111,116,32,111,110,101,10,0,112,97,115,115,108,111,103,102,105,108,101,0,0,0,0,0,105,110,95,104,0,0,0,0,65,67,80,82,69,68,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,0,98,97,0,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,110,111,116,32,115,112,101,99,105,102,105,101,100,10,0,0,0,78,111,116,32,97,32,84,77,50,32,104,101,97,100,101,114,58,32,48,120,37,48,56,88,10,0,0,0,0,0,0,0,69,114,114,111,114,32,105,110,32,101,120,112,114,101,115,115,105,111,110,32,34,37,115,34,10,0,0,0,0,0,0,0,80,114,111,106,83,116,100,80,97,114,97,108,108,101,108,50,71,101,111,75,101,121,0,0,115,101,116,32,98,108,101,110,100,32,109,111,100,101,32,102,111,114,32,97,108,108,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,0,0,0,84,104,105,115,32,102,111,114,109,97,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,98,112,112,61,37,100,44,32,37,100,32,99,111,109,112,111,110,101,110,116,115,41,10,0,0,0,99,111,117,108,100,32,110,111,116,32,117,110,99,111,109,112,114,101,115,115,32,119,97,116,101,114,109,97,114,107,32,108,111,103,111,10,0,0,0,0,62,0,0,0,0,0,0,0,123,92,102,110,37,115,125,0,73,110,99,111,109,112,97,116,105,98,108,101,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,39,37,115,39,32,102,111,114,32,99,111,100,101,99,32,39,37,115,39,44,32,97,117,116,111,45,115,101,108,101,99,116,105,110,103,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,83,107,105,112,112,105,110,103,32,104,105,103,104,32,98,121,116,101,115,32,116,114,101,101,10,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,97,117,100,105,111,32,116,121,112,101,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,114,118,49,48,46,99,0,0,0,0,0,0,0,115,101,116,32,100,105,115,112,108,97,121,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,114,99,95,101,113,32,34,37,115,34,10,0,0,0,0,0,0,0,115,116,114,101,97,109,32,105,115,32,81,68,77,67,32,118,101,114,115,105,111,110,32,49,44,32,119,104,105,99,104,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,76,97,118,99,0,0,0,0,115,116,97,114,116,95,115,97,109,112,108,101,32,60,32,101,110,100,95,115,97,109,112,108,101,32,124,124,32,40,115,116,97,114,116,95,115,97,109,112,108,101,32,61,61,32,101,110,100,95,115,97,109,112,108,101,32,38,38,32,33,102,114,97,109,101,45,62,110,98,95,115,97,109,112,108,101,115,41,0,32,69,88,0,0,0,0,0,37,115,58,32,115,101,101,107,32,118,97,108,117,101,32,111,118,101,114,102,108,111,119,32,119,105,116,104,32,115,116,97,114,116,95,116,105,109,101,58,37,108,108,100,32,115,101,101,107,95,112,111,105,110,116,58,37,108,108,100,10,0,0,0,98,0,0,0,0,0,0,0,67,104,97,110,110,101,108,58,32,37,100,10,0,0,0,0,80,82,69,86,95,79,85,84,80,84,83,0,0,0,0,0,69,105,116,104,101,114,32,98,111,116,104,32,98,117,102,102,101,114,32,115,105,122,101,32,97,110,100,32,109,97,120,32,114,97,116,101,32,111,114,32,110,101,105,116,104,101,114,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,0,37,49,100,0,0,0,0,0,98,105,103,95,118,97,108,117,101,115,32,116,111,111,32,98,105,103,10,0,0,0,0,0,98,105,103,95,118,97,108,117,101,115,32,116,111,111,32,98,105,103,10,0,0,0,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,99,104,114,111,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,86,105,100,101,111,32,79,98,106,101,99,116,32,83,116,97,114,116,0,0,0,0,0,0,82,68,32,111,112,116,105,109,97,108,32,77,66,32,108,101,118,101,108,32,114,101,115,105,100,117,97,108,32,115,107,105,112,112,105,110,103,0,0,0,105,110,116,101,114,108,97,99,101,100,32,102,114,97,109,101,32,105,110,32,112,114,111,103,114,101,115,115,105,118,101,32,115,101,113,117,101,110,99,101,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,111,117,108,100,32,110,111,116,32,103,101,116,32,97,32,112,105,120,101,108,32,102,111,114,109,97,116,32,100,101,115,99,114,105,112,116,111,114,46,10,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,85,110,115,117,112,112,111,114,116,101,100,32,105,109,97,103,101,32,102,111,114,109,97,116,32,37,100,46,10,0,0,0,83,117,112,112,111,114,116,32,102,111,114,32,37,100,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,0,0,0,92,68,0,0,0,0,0,0,45,0,0,0,0,0,0,0,114,101,102,95,116,105,108,101,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,72,101,97,100,101,114,32,108,111,111,107,115,32,108,105,107,101,32,82,84,80,32,105,110,115,116,101,97,100,32,111,102,32,72,46,50,54,51,10,0,83,121,110,99,32,98,105,116,32,105,115,32,115,101,116,33,10,0,0,0,0,0,0,0,56,45,98,105,116,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,0,0,82,101,100,117,99,105,110,103,32,108,101,102,116,32,111,117,116,112,117,116,32,119,105,110,100,111,119,32,116,111,32,37,100,32,99,104,114,111,109,97,32,115,97,109,112,108,101,115,32,116,111,32,112,114,101,115,101,114,118,101,32,97,108,105,103,110,109,101,110,116,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,108,105,99,101,32,115,101,103,109,101,110,116,32,97,100,100,114,101,115,115,58,32,37,117,46,10,0,0,0,0,0,66,73,0,0,0,0,0,0,114,101,109,111,118,101,32,115,104,111,114,116,32,37,100,32,99,111,117,110,116,32,37,100,10,0,0,0,0,0,0,0,70,77,79,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,114,97,110,100,111,109,32,115,101,101,100,58,32,48,120,37,48,56,120,10,0,0,0,0,67,117,114,115,111,114,32,102,111,114,109,97,116,32,37,100,0,0,0,0,0,0,0,0,90,108,105,98,32,114,101,115,121,110,99,32,111,99,99,117,114,114,101,100,10,0,0,0,101,115,116,105,109,97,116,101,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2149000);
/* memory initializer */ allocate([112,114,101,100,32,111,114,100,101,114,32,37,100,10,0,0,50,80,97,115,115,32,102,105,108,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,115,108,105,99,101,32,99,111,117,110,116,32,105,110,118,97,108,105,100,10,0,0,0,0,82,71,66,32,99,104,97,110,110,101,108,115,32,110,111,116,32,111,102,32,116,104,101,32,115,97,109,101,32,100,101,112,116,104,10,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,100,101,112,114,101,99,97,116,101,100,44,32,100,111,32,110,111,116,32,117,115,101,0,0,66,108,111,99,107,32,115,101,112,97,114,97,116,105,111,110,32,103,114,101,97,116,101,114,32,116,104,97,110,32,115,105,122,101,10,0,0,0,0,0,68,84,83,45,88,66,82,58,32,101,110,100,32,111,102,32,99,104,97,110,110,101,108,32,115,101,116,44,32,115,107,105,112,112,105,110,103,32,102,117,114,116,104,101,114,32,116,104,97,110,32,101,120,112,101,99,116,101,100,32,40,37,100,32,98,105,116,115,41,10,0,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,115,0,115,117,98,98,97,110,100,115,32,62,32,53,48,0,0,0,68,97,116,117,109,95,65,100,105,110,100,97,110,0,0,0,102,97,115,116,105,110,116,0,110,98,95,111,117,116,95,115,97,109,112,108,101,115,58,37,100,32,112,97,100,58,37,100,10,0,0,0,0,0,0,0,109,112,101,103,52,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,67,77,86,32,118,105,100,101,111,0,0,0,0,0,0,0,110,111,32,109,97,120,105,109,117,109,46,32,100,101,99,111,100,101,32,97,108,108,32,115,97,109,112,108,101,115,32,102,111,114,32,101,97,99,104,32,112,97,99,107,101,116,32,97,116,32,111,110,99,101,0,0,83,111,117,110,100,116,114,97,99,107,0,0,0,0,0,0,110,111,102,111,114,109,97,116,0,0,0,0,0,0,0,0,87,77,47,84,111,111,108,0,69,110,97,98,108,101,32,73,68,51,32,116,97,103,115,32,119,114,105,116,105,110,103,46,0,0,0,0,0,0,0,0,52,49,49,0,0,0,0,0,115,101,108,101,99,116,32,116,104,101,32,112,97,115,115,32,110,117,109,98,101,114,32,40,49,32,116,111,32,51,41,0,111,115,114,0,0,0,0,0,32,72,68,0,0,0,0,0,105,110,95,103,97,105,110,32,109,97,121,32,99,97,117,115,101,32,99,108,105,112,112,105,110,103,10,0,0,0,0,0,121,117,118,52,50,48,112,0,66,111,116,104,32,119,104,111,108,101,32,97,110,100,32,112,97,100,32,108,101,110,103,116,104,32,97,114,101,32,115,101,116,44,32,116,104,105,115,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,71,67,83,69,95,83,112,104,101,114,101,0,0,0,0,0,97,117,116,111,115,101,108,101,99,116,32,97,32,103,111,111,100,32,111,110,101,32,40,100,101,102,97,117,108,116,41,0,99,109,118,0,0,0,0,0,105,110,112,117,116,37,100,0,112,97,115,115,0,0,0,0,67,111,109,109,97,110,100,32,108,105,110,101,58,10,0,0,87,77,47,87,77,82,86,69,110,100,84,105,109,101,0,0,111,114,105,103,105,110,97,116,105,111,110,95,100,97,116,101,0,0,0,0,0,0,0,0,116,111,111,32,115,104,111,114,116,32,76,73,83,84,32,116,97,103,10,0,0,0,0,0,78,111,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,102,111,114,32,105,110,112,117,116,32,37,100,10,0,70,73,76,69,0,0,0,0,32,72,68,52,50,50,0,0,115,113,117,97,114,101,32,114,111,111,116,0,0,0,0,0,84,104,105,115,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,39,124,39,32,116,111,32,115,101,112,97,114,97,116,101,32,37,115,46,10,0,0,0,0,0,114,101,97,100,95,116,105,109,101,115,116,97,109,112,40,41,32,102,97,105,108,101,100,32,105,110,32,116,104,101,32,109,105,100,100,108,101,10,0,0,85,110,107,110,111,119,110,32,111,112,116,105,111,110,32,39,37,115,39,10,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,0,97,117,116,111,0,0,0,0,66,114,117,116,101,32,70,111,114,99,101,32,38,32,73,103,110,111,114,97,110,99,101,0,109,117,120,32,99,111,109,112,108,101,116,101,32,68,84,83,32,102,114,97,109,101,115,32,105,110,32,72,68,32,109,111,100,101,32,97,116,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,73,69,67,57,53,56,32,114,97,116,101,32,40,105,110,32,72,122,44,32,100,101,102,97,117,108,116,32,48,61,100,105,115,97,98,108,101,100,41,0,0,0,0,0,116,121,112,101,0,0,0,0,104,104,58,109,109,58,115,115,91,58,59,46,93,102,102,0,37,115,47,81,117,97,108,105,116,121,76,101,118,101,108,115,40,37,100,41,0,0,0,0,115,101,116,32,114,101,100,32,102,97,100,101,0,0,0,0,115,101,116,32,116,104,101,32,115,101,103,109,101,110,116,32,108,105,115,116,32,116,121,112,101,0,0,0,0,0,0,0,104,50,54,52,95,109,111,100,101,48,0,0,0,0,0,0,102,105,101,108,100,109,97,116,99,104,0,0,0,0,0,0,115,112,105,110,58,0,0,0,77,105,115,115,105,110,103,32,100,101,108,97,121,115,32,97,110,100,47,111,114,32,100,101,99,97,121,115,46,10,0,0,88,68,67,65,77,0,0,0,115,101,110,100,95,98,121,101,0,0,0,0,0,0,0,0,100,101,108,97,121,115,0,0,111,117,116,115,105,100,101,32,118,105,100,101,111,98,117,102,115,105,122,101,10,0,0,0,73,84,67,72,0,0,0,0,84,104,105,115,32,102,105,108,116,101,114,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,97,102,111,114,109,97,116,32,105,110,115,116,101,97,100,10,0,97,117,100,105,111,47,71,55,50,50,0,0,0,0,0,0,37,100,58,37,100,37,99,0,71,67,83,69,95,79,83,85,57,49,65,0,0,0,0,0,68,67,84,32,97,108,103,111,114,105,116,104,109,0,0,0,115,98,0,0,0,0,0,0,98,102,105,0,0,0,0,0,115,98,0,0,0,0,0,0,115,101,116,32,105,110,105,116,105,97,108,32,84,105,109,101,67,111,100,101,32,118,97,108,117,101,46,0,0,0,0,0,97,101,118,97,108,0,0,0,115,111,114,116,100,116,115,0,69,75,0,0,0,0,0,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,83,112,101,101,120,32,104,101,97,100,101,114,115,10,0,0,0,0,67,104,97,110,110,101,108,76,97,121,111,117,116,0,0,0,83,107,105,112,83,116,97,114,116,0,0,0,0,0,0,0,115,97,109,112,108,101,95,115,105,103,95,98,105,116,115,0,101,114,114,111,114,32,77,88,70,32,68,45,49,48,32,111,110,108,121,32,115,117,112,112,111,114,116,32,51,48,47,52,48,47,53,48,32,109,98,105,116,47,115,10,0,0,0,0,98,114,111,107,101,110,32,111,114,32,101,109,112,116,121,32,105,110,100,101,120,10,0,0,79,82,73,69,78,84,65,84,73,79,78,0,0,0,0,0,104,97,108,100,99,108,117,116,115,114,99,0,0,0,0,0,101,110,99,111,100,101,114,0,102,105,101,108,100,0,0,0,68,117,112,108,105,99,97,116,101,32,115,116,114,101,97,109,32,105,100,32,37,100,10,0,71,67,83,69,95,79,83,85,56,54,70,0,0,0,0,0,65,108,108,32,112,114,111,103,114,97,109,115,32,104,97,118,101,32,112,109,116,44,32,104,101,97,100,101,114,115,32,102,111,117,110,100,10,0,0,0,100,99,116,0,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,108,97,114,103,101,44,32,105,103,110,111,114,105,110,103,32,98,117,102,102,101,114,32,108,105,109,105,116,115,32,116,111,32,109,117,120,32,105,116,10,0,0,0,0,0,68,105,114,97,99,0,0,0,84,105,109,101,115,116,97,109,112,32,100,101,99,108,97,114,101,100,32,98,101,102,111,114,101,32,97,110,121,32,115,116,114,101,97,109,10,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,100,117,114,97,116,105,111,110,10,0,0,115,105,122,101,0,0,0,0,109,52,118,44,109,52,97,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,110,117,109,32,60,32,40,49,85,76,76,60,60,53,54,41,45,49,0,0,0,0,0,0,128,0,0,0,0,0,0,0,70,105,108,101,32,109,111,118,101,115,32,98,101,121,111,110,100,32,109,97,120,46,32,97,108,108,111,119,101,100,32,100,101,112,116,104,32,40,37,100,41,10,0,0,0,0,0,0,102,114,97,109,101,61,32,37,53,100,32,113,61,32,37,50,46,49,102,32,0,0,0,0,255,255,255,0,0,0,0,0,71,67,83,69,95,71,69,77,49,48,67,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,105,116,105,97,108,32,99,111,109,112,108,101,120,105,116,121,32,102,111,114,32,49,45,112,97,115,115,32,101,110,99,111,100,105,110,103,0,0,100,105,114,97,99,0,0,0,115,101,116,32,114,97,110,103,101,32,102,111,114,32,108,111,111,107,105,110,103,32,97,116,32,116,104,101,32,102,105,114,115,116,32,115,101,113,117,101,110,99,101,32,110,117,109,98,101,114,0,0,0,0,0,0,116,105,102,102,0,0,0,0,115,97,109,101,95,113,117,97,110,116,0,0,0,0,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,104,108,115,95,119,114,97,112,0,0,0,0,0,0,0,0,35,69,88,84,45,88,45,83,84,82,69,65,77,45,73,78,70,58,0,0,0,0,0,0,115,105,122,101,0,0,0,0,37,115,37,115,37,115,0,0,102,108,118,0,0,0,0,0,100,101,102,97,117,108,116,0,86,105,100,101,111,32,99,111,100,101,99,32,39,37,115,39,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,0,0,104,101,105,103,104,116,0,0,80,105,99,116,117,114,101,32,115,105,122,101,32,37,117,120,37,117,32,105,115,32,105,110,118,97,108,105,100,10,0,0,104,101,97,100,101,114,32,101,108,101,109,101,110,116,32,48,120,37,48,50,120,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,0,0,109,111,100,101,0,0,0,0,71,67,83,69,95,87,71,83,56,52,0,0,0,0,0,0,114,99,95,105,110,105,116,95,99,112,108,120,0,0,0,0,69,115,99,97,112,101,32,49,50,52,0,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,77,68,53,0,0,0,0,0,82,101,109,111,118,101,100,0,102,105,108,116,101,114,0,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,105,100,120,32,43,32,49,32,60,61,32,97,115,102,95,115,116,45,62,112,107,116,46,115,105,122,101,32,47,32,97,115,102,95,115,116,45,62,100,115,95,99,104,117,110,107,95,115,105,122,101,0,0,0,0,0,49,46,48,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,39,97,110,103,108,101,39,10,0,111,99,108,0,0,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,99,104,97,110,110,101,108,115,32,109,97,112,115,32,105,110,32,116,104,101,32,102,111,114,109,97,116,32,39,105,110,112,117,116,95,115,116,114,101,97,109,46,105,110,112,117,116,95,99,104,97,110,110,101,108,45,111,117,116,112,117,116,95,99,104,97,110,110,101,108,46,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,45,97,115,121,110,99,32,105,115,32,102,111,114,119,97,114,100,101,100,32,116,111,32,108,97,118,102,105,32,115,105,109,105,108,97,114,108,121,32,116,111,32,45,97,102,32,97,114,101,115,97,109,112,108,101,61,37,115,46,10,0,0,0,0,37,108,102,0,0,0,0,0,71,66,82,0,0,0,0,0,98,49,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,99,108,111,115,101,32,111,110,32,101,120,101,99,10,0,0,0,0,71,67,83,69,95,87,97,114,79,102,102,105,99,101,0,0,81,80,32,111,102,102,115,101,116,32,98,101,116,119,101,101,110,32,80,45,32,97,110,100,32,73,45,102,114,97,109,101,115,0,0,0,0,0,0,0,101,115,99,97,112,101,49,50,52,0,0,0,0,0,0,0,67,97,110,110,111,116,32,114,101,97,100,32,102,105,108,101,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,112,104,97,115,101,114,46,99,0,0,0,0,0,0,0,0,115,45,62,110,98,95,105,110,112,117,116,115,32,62,32,49,0,0,0,0,0,0,0,0,79,112,101,110,67,76,32,115,117,112,112,111,114,116,32,119,97,115,32,110,111,116,32,101,110,97,98,108,101,100,32,105,110,32,116,104,105,115,32,98,117,105,108,100,44,32,99,97,110,110,111,116,32,98,101,32,115,101,108,101,99,116,101,100,10,0,0,0,0,0,0,0,115,97,109,101,113,0,0,0,99,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,114,101,113,117,101,115,116,101,100,32,102,114,97,109,101,0,0,0,114,97,116,101,0,0,0,0,115,101,116,32,116,104,101,32,98,97,105,108,111,117,116,32,118,97,108,117,101,0,0,0,100,105,114,0,0,0,0,0,115,101,116,32,114,117,108,101,0,0,0,0,0,0,0,0,114,97,110,100,111,109,95,102,105,108,108,95,114,97,116,105,111,0,0,0,0,0,0,0,100,101,105,110,116,101,114,108,97,99,101,32,97,108,108,32,102,114,97,109,101,115,0,0,115,101,116,32,102,111,114,119,97,114,100,47,98,97,99,107,119,97,114,100,32,109,111,100,101,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,84,105,108,101,32,115,105,122,101,32,37,117,120,37,117,32,105,115,32,105,110,115,97,110,101,46,10,0,0,0,0,0,119,58,37,100,32,104,58,37,100,32,100,105,114,58,37,100,32,45,62,32,119,58,37,100,32,104,58,37,100,32,114,111,116,97,116,105,111,110,58,37,115,32,118,102,108,105,112,58,37,100,10,0,0,0,0,0,37,115,10,0,0,0,0,0,65,108,108,111,99,97,116,105,111,110,32,102,97,105,108,117,114,101,44,32,116,114,121,32,116,111,32,108,111,119,101,114,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,10,0,0,73,110,118,97,108,105,100,32,99,104,97,114,115,32,39,37,115,39,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,102,97,100,101,0,0,0,0,71,67,83,69,95,83,116,114,117,118,101,49,56,54,48,0,115,0,0,0,0,0,0,0,105,95,113,111,102,102,115,101,116,0,0,0,0,0,0,0,115,101,116,32,98,97,99,107,103,114,111,117,110,100,32,102,105,108,108,32,99,111,108,111,114,0,0,0,0,0,0,0,82,76,50,32,118,105,100,101,111,0,0,0,0,0,0,0,105,110,95,119,0,0,0,0,102,111,114,99,101,32,118,105,100,101,111,32,99,111,100,101,99,32,40,39,99,111,112,121,39,32,116,111,32,99,111,112,121,32,115,116,114,101,97,109,41,0,0,0,0,0,0,0,110,58,37,102,32,116,58,37,102,32,112,111,115,58,37,102,32,120,58,37,102,32,120,105,58,37,100,32,121,58,37,102,32,121,105,58,37,100,10,0,78,111,32,112,97,116,116,101,114,110,32,112,114,111,118,105,100,101,100,46,10,0,0,0,99,49,95,115,101,101,100,0,100,101,102,97,117,108,116,0,69,114,114,111,114,32,110,117,109,98,101,114,32,37,100,32,111,99,99,117,114,114,101,100,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,116,32,85,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,115,119,97,112,32,97,108,112,104,97,32,102,105,101,108,100,115,0,0,0,0,0,0,0,72,58,37,48,46,49,102,42,80,73,32,104,58,37,48,46,49,102,32,115,58,37,48,46,49,102,32,98,58,37,48,46,102,32,116,58,37,48,46,49,102,32,110,58,37,100,10,0,99,111,108,117,109,110,0,0,109,111,100,101,0,0,0,0,68,114,111,112,112,105,110,103,32,37,100,32,102,114,97,109,101,40,115,41,46,10,0,0,102,108,97,103,115,0,0,0,100,101,102,97,117,108,116,0,98,102,102,0,0,0,0,0,114,103,98,52,0,0,0,0,66,108,97,110,99,104,101,100,65,108,109,111,110,100,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,101,113,0,0,0,0,0,0,73,110,118,97,108,105,100,32,100,97,116,97,32,102,111,117,110,100,32,119,104,101,110,32,112,114,111,99,101,115,115,105,110,103,32,105,110,112,117,116,0,0,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,112,108,97,110,101,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,46,10,0,0,0,0,0,0,0,0,83,76,0,0,0,0,0,0,97,99,99,117,114,97,116,101,32,114,111,117,110,100,105,110,103,0,0,0,0,0,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,115,119,114,101,115,97,109,112,108,101,46,99,0,0,0,0,0,0,100,101,102,97,117,108,116,0,92,109,111,118,101,40,37,100,44,37,100,44,37,100,44,37,100,44,37,100,44,37,100,41,37,49,91,92,125,93,37,110,0,0,0,0,0,0,0,0,71,67,83,69,95,80,108,101,115,115,105,115,49,56,49,55,0,0,0,0,0,0,0,0,101,120,116,114,117,100,101,100,32,101,100,103,101,32,118,97,108,117,101,32,97,116,32,98,108,97,110,107,32,108,111,99,97,116,105,111,110,115,0,0,81,80,32,102,97,99,116,111,114,32,98,101,116,119,101,101,110,32,80,45,32,97,110,100,32,73,45,102,114,97,109,101,115,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,67,82,89,79,32,65,80,67,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,109,97,114,107,32,109,97,105,110,32,105,110,112,117,116,32,97,115,32,97,32,112,114,101,45,112,114,111,99,101,115,115,101,100,32,105,110,112,117,116,32,97,110,100,32,97,99,116,105,118,97,116,101,32,99,108,101,97,110,32,115,111,117,114,99,101,32,105,110,112,117,116,32,115,116,114,101,97,109,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,10,0,0,0,0,0,83,116,97,114,116,32,102,114,101,113,117,101,110,99,121,32,98,111,114,100,101,114,32,116,111,111,32,104,105,103,104,58,32,37,100,10,0,0,0,0,70,65,65,67,45,105,110,115,112,105,114,101,100,32,109,101,116,104,111,100,0,0,0,0,114,108,50,0,0,0,0,0,99,111,100,101,32,62,61,32,48,32,38,38,32,99,111,100,101,32,60,61,32,54,32,38,38,32,108,111,103,50,119,32,62,61,32,48,0,0,0,0,98,108,111,99,107,95,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,10,0,108,105,98,97,118,99,111,100,101,99,47,119,109,97,108,111,115,115,108,101,115,115,100,101,99,46,99,0,0,0,0,0,109,97,120,32,115,121,109,98,111,108,32,37,100,32,62,32,97,108,112,104,97,98,101,116,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,78,111,32,98,108,111,99,107,32,119,105,116,104,32,101,110,116,114,111,112,121,32,105,110,102,111,10,0,0,0,0,0,48,46,52,47,48,46,53,0,77,111,114,101,32,98,108,111,99,107,115,32,101,110,100,101,100,32,116,104,97,110,32,99,111,100,101,100,33,10,0,0,109,111,100,101,95,115,101,116,117,112,45,62,109,97,112,112,105,110,103,0,0,0,0,0,71,111,116,32,110,111,32,115,112,114,105,116,101,115,10,0,118,99,111,100,101,99,0,0,105,110,95,119,0,0,0,0,70,73,69,76,68,84,88,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,115,101,116,32,116,104,101,32,98,108,117,101,32,103,97,105,110,32,102,111,114,32,116,104,101,32,98,108,117,101,32,99,104,97,110,110,101,108,0,0,83,112,101,99,105,102,105,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,79,108,100,32,84,77,50,32,104,101,97,100,101,114,0,0,80,114,111,106,83,116,100,80,97,114,97,108,108,101,108,49,71,101,111,75,101,121,0,0,97,108,108,95,109,111,100,101,0,0,0,0,0,0,0,0,84,104,105,115,32,102,111,114,109,97,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,98,112,112,61,37,100,44,32,98,112,112,99,111,117,110,116,61,37,100,41,10,0,0,0,0,0,117,49,58,32,37,120,32,117,50,58,32,37,120,32,117,51,58,32,37,120,32,99,111,109,112,114,101,115,115,101,100,32,100,97,116,97,32,115,105,122,101,58,32,37,100,32,111,102,102,115,101,116,58,32,37,100,10,0,0,0,0,0,0,0,32,99,111,108,111,114,61,34,35,37,48,54,120,34,0,0,32,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,108,111,119,32,98,121,116,101,115,32,116,114,101,101,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,115,117,98,99,111,100,101,99,32,51,55,32,99,111,109,112,114,101,115,115,105,111,110,32,37,100,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,115,45,62,112,105,99,116,95,116,121,112,101,32,33,61,32,65,86,95,80,73,67,84,85,82,69,95,84,89,80,69,95,66,32,124,124,32,33,115,45,62,108,111,119,95,100,101,108,97,121,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,114,97,116,105,111,32,110,117,109,101,114,97,116,111,114,32,34,37,115,34,10,0,0,0,116,101,120,94,113,67,111,109,112,0,0,0,0,0,0,0,118,101,110,100,111,114,32,73,68,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,77,32,109,117,45,108,97,119,32,47,32,71,46,55,49,49,32,109,117,45,108,97,119,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,102,105,110,100,32,115,116,114,101,97,109,32,105,110,102,111,10,0,0,0,0,0,65,86,67,111,100,101,99,67,111,110,116,101,120,116,0,0,80,82,69,86,95,73,78,84,0,0,0,0,0,0,0,0,65,117,116,111,109,97,116,105,99,97,108,108,121,32,99,104,111,111,115,105,110,103,32,86,66,86,32,98,117,102,102,101,114,32,115,105,122,101,32,111,102,32,37,100,32,107,98,121,116,101,10,0,0,0,0,0,83,105,122,101,32,97,110,100,32,119,105,100,116,104,47,104,101,105,103,104,116,32,101,120,112,114,101,115,115,105,111,110,115,32,99,97,110,110,111,116,32,98,101,32,115,101,116,32,97,116,32,116,104,101,32,115,97,109,101,32,116,105,109,101,46,10,0,0,0,0,0,0,78,101,119,32,102,114,97,109,101,44,32,116,121,112,101,58,32,37,99,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,97,117,100,105,111,100,101,99,95,116,101,109,112,108,97,116,101,46,99,0,0,0,0,0,0,115,119,115,95,102,108,97,103,115,32,110,111,116,32,116,101,114,109,105,110,97,116,101,100,32,119,105,116,104,32,39,59,39,46,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,97,117,100,105,111,100,101,99,95,116,101,109,112,108,97,116,101,46,99,0,0,0,0,0,0,99,104,114,111,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,115,116,97,114,116,99,111,100,101,58,32,37,51,88,32,0,115,107,105,112,95,114,100,0,105,103,110,111,114,105,110,103,32,71,79,80,95,83,84,65,82,84,95,67,79,68,69,32,97,102,116,101,114,32,37,88,10,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,117,102,102,95,108,115,98,115,46,10,0,0,0,0,0,108,111,119,114,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,119,101,105,114,100,32,115,117,98,115,97,109,112,108,105,110,103,10,0,0,0,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,52,58,50,58,48,46,10,0,0,0,0,0,0,0,80,115,111,116,32,37,100,32,116,111,111,32,98,105,103,10,0,0,0,0,0,0,0,0,92,78,0,0,0,0,0,0,32,12,9,10,13,44,59,0,77,86,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,73,32,99,98,112,121,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,58,32,37,100,10,0,83,121,110,99,32,102,114,97,109,101,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,115,104,111,114,116,32,116,101,114,109,32,82,80,83,58,32,37,100,46,10,0,0,0,80,80,83,32,99,104,97,110,103,101,100,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,46,10,0,0,0,0,83,80,0,0,0,0,0,0,105,108,108,101,103,97,108,32,109,101,109,111,114,121,32,109,97,110,97,103,101,109,101,110,116,32,99,111,110,116,114,111,108,32,111,112,101,114,97,116,105,111,110,32,37,100,10,0,85,110,105,109,112,108,101,109,101,110,116,101,100,32,108,117,109,97,32,98,105,116,32,100,101,112,116,104,61,37,100,10,0,0,0,0,0,0,0,0,111,111,111,0,0,0,0,0,82,87,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,100,97,116,97,32,115,105,122,101,32,37,100,47,37,100,10,0,73,110,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,32,111,114,100,101,114,32,109,101,116,104,111,100,58,32,37,115,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,112,114,101,100,105,99,116,111,114,32,111,114,100,101,114,58,32,37,105,32,62,32,37,105,10,0,0,0,0,0,0,0,50,80,97,115,115,32,102,105,108,101,32,105,110,118,97,108,105,100,32,97,116,32,37,100,32,37,100,32,37,100,32,37,100,32,91,37,115,93,10,0,73,110,118,97,108,105,100,32,118,101,114,115,105,111,110,32,105,110,32,103,108,111,98,97,108,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,83,117,98,115,97,109,112,108,105,110,103,32,37,100,120,37,100,0,0,0,0,0,0,0,80,111,111,108,32,114,97,99,101,32,100,101,99,116,101,99,116,101,100,44,32,115,112,105,110,105,110,103,32,116,111,32,97,118,111,105,100,32,111,118,101,114,97,108,108,111,99,97,116,105,111,110,32,97,110,100,32,101,118,101,110,116,117,97,108,32,79,79,77,10,0,0,111,110,0,0,0,0,0,0,116,105,109,101,95,98,97,115,101,95,110,117,109,0,0,0,66,108,111,99,107,32,115,101,112,97,114,97,116,105,111,110,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,68,84,83,45,88,66,82,58,32,68,105,100,110,39,116,32,103,101,116,32,115,117,98,102,114,97,109,101,32,68,83,89,78,67,10,0,0,0,0,0,112,105,120,95,102,109,116,115,0,0,0,0,0,0,0,0,106,115,95,118,108,99,95,98,105,116,115,32,61,32,37,100,44,32,111,110,108,121,32,62,61,32,37,100,32,97,110,100,32,60,61,32,54,32,97,108,108,111,119,101,100,33,10,0,71,67,83,69,95,78,87,76,49,48,68,0,0,0,0,0,105,95,113,102,97,99,116,111,114,0,0,0,0,0,0,0,74,80,69,71,45,76,83,0,97,110,103,108,101,0,0,0,44,32,0,0,0,0,0,0,77,105,109,105,99,0,0,0,97,108,108,0,0,0,0,0,80,114,97,110,107,115,0,0,102,111,114,109,97,116,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,119,114,105,116,101,95,105,100,51,118,50,0,0,0,0,0,52,50,48,0,0,0,0,0,111,118,101,114,114,105,100,101,0,0,0,0,0,0,0,0,84,104,101,32,98,105,116,109,97,112,32,102,105,108,101,32,110,97,109,101,32,105,115,32,109,97,110,100,97,116,111,114,121,10,0,0,0,0,0,0,80,83,78,82,32,97,118,101,114,97,103,101,58,37,48,46,50,102,32,109,105,110,58,37,48,46,50,102,32,109,97,120,58,37,48,46,50,102,10,0,100,101,102,97,117,108,116,0,117,110,115,117,112,112,111,114,116,101,100,32,98,97,121,101,114,32,99,111,110,118,101,114,115,105,111,110,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,71,67,83,69,95,78,87,76,57,68,0,0,0,0,0,0,99,117,114,114,101,110,116,108,121,32,117,115,101,108,101,115,115,0,0,0,0,0,0,0,119,105,100,116,104,0,0,0,109,105,109,105,99,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,97,116,101,32,99,111,110,116,114,111,108,32,111,118,101,114,114,105,100,101,32,102,111,114,32,115,112,101,99,105,102,105,99,32,105,110,116,101,114,118,97,108,115,0,0,0,0,70,70,82,69,80,79,82,84,0,0,0,0,0,0,0,0,78,111,32,97,99,99,101,108,101,114,97,116,101,100,32,99,111,108,111,114,115,112,97,99,101,32,99,111,110,118,101,114,115,105,111,110,32,102,111,117,110,100,32,102,114,111,109,32,37,115,32,116,111,32,37,115,46,10,0,0,0,0,0,0,87,77,47,87,77,82,86,69,110,99,111,100,101,84,105,109,101,0,0,0,0,0,0,0,87,101,98,86,84,84,32,109,101,116,97,100,97,116,97,32,107,105,110,100,0,0,0,0,111,114,105,103,105,110,97,116,111,114,95,114,101,102,101,114,101,110,99,101,0,0,0,0,101,120,116,114,97,99,116,112,108,97,110,101,115,0,0,0,116,111,111,32,109,97,110,121,32,102,114,97,109,101,115,32,112,101,114,32,106,112,101,103,10,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,115,113,114,116,0,0,0,0,120,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,116,109,112,95,112,111,115,32,62,32,112,111,115,95,109,97,120,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,115,101,113,117,101,110,99,101,32,39,37,115,39,32,97,115,115,111,99,105,97,116,101,100,32,116,111,32,115,116,114,101,97,109,32,37,100,32,111,102,32,115,108,97,118,101,32,111,117,116,112,117,116,32,39,37,115,39,10,0,0,0,0,0,0,71,67,83,69,95,75,114,97,115,115,111,119,115,107,121,49,57,52,48,0,0,0,0,0,114,99,95,98,117,102,95,97,103,103,114,101,115,115,105,118,105,116,121,0,0,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,86,105,100,101,111,32,73,110,116,101,114,97,99,116,105,118,101,32,53,0,100,116,115,104,100,95,114,97,116,101,0,0,0,0,0,0,114,99,95,111,118,101,114,114,105,100,101,0,0,0,0,0,78,111,32,98,105,116,32,114,97,116,101,32,115,101,116,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,79,110,101,32,111,102,32,116,104,101,32,105,110,112,117,116,32,112,97,114,97,109,101,116,101,114,115,32,116,111,32,115,119,115,95,115,99,97,108,101,40,41,32,105,115,32,78,85,76,76,44,32,112,108,101,97,115,101,32,99,104,101,99,107,32,116,104,101,32,99,97,108,108,105,110,103,32,99,111,100,101,10,0,0,0,0,0,0,114,102,0,0,0,0,0,0,97,108,108,95,115,101,101,100,0,0,0,0,0,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,95,116,121,112,101,0,0,0,0,0,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,37,103,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,85,115,101,32,109,111,100,101,32,48,32,102,111,114,32,72,50,54,52,32,105,110,32,82,84,80,0,0,0,0,0,0,79,110,108,121,32,112,108,97,110,97,114,32,102,111,114,109,97,116,115,32,119,105,116,104,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,99,111,109,112,111,110,101,110,116,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,99,117,114,32,115,108,105,99,101,32,37,100,44,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,114,97,119,32,71,46,55,50,50,0,0,0,0,0,0,0,83,87,83,99,97,108,101,114,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,71,67,83,69,95,73,110,116,101,114,110,97,116,105,111,110,97,108,49,57,54,55,0,0,115,101,116,32,114,97,116,101,99,111,110,116,114,111,108,32,98,117,102,102,101,114,32,115,105,122,101,32,40,105,110,32,98,105,116,115,41,0,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,0,0,105,110,100,101,111,53,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,100,105,115,99,97,114,100,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,104,97,108,100,99,108,117,116,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,100,105,115,99,97,114,100,32,99,111,114,114,117,112,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,107,101,121,10,0,0,0,0,101,108,98,103,0,0,0,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,70,76,65,67,32,104,101,97,100,101,114,115,10,0,0,0,0,0,67,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,100,97,116,97,32,37,115,32,47,32,37,115,10,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,102,114,97,109,101,32,114,97,116,101,32,37,100,47,37,100,10,0,0,0,0,0,99,97,110,110,111,116,32,100,101,109,117,120,32,79,80,65,116,111,109,32,119,105,116,104,111,117,116,32,97,110,32,105,110,100,101,120,10,0,0,0,108,117,116,121,117,118,0,0,87,73,68,84,72,0,0,0,67,111,100,101,99,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,100,111,101,115,32,110,111,116,32,117,115,101,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,32,98,117,116,32,99,111,110,116,97,105,110,101,114,32,102,111,114,109,97,116,32,114,101,113,117,105,114,101,115,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,10,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,100,32,37,100,44,32,109,117,115,116,32,98,101,32,108,101,115,115,32,116,104,97,110,32,56,49,57,49,10,0,0,0,71,67,83,69,95,73,110,116,101,114,110,97,116,105,111,110,97,108,49,57,50,52,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,112,101,103,116,115,46,99,0,0,0,0,98,117,102,115,105,122,101,0,97,118,97,105,108,95,100,97,116,97,62,48,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,86,105,100,101,111,32,73,110,116,101,114,97,99,116,105,118,101,32,52,0,116,105,109,101,115,116,97,109,112,58,0,0,0,0,0,0,108,117,109,97,95,109,111,100,101,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,112,51,101,110,99,46,99,0,0,0,0,118,100,116,0,0,0,0,0,83,105,110,103,108,101,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,58,32,84,70,70,58,37,100,32,66,70,70,58,37,100,32,80,114,111,103,114,101,115,115,105,118,101,58,37,100,32,85,110,100,101,116,101,114,109,105,110,101,100,58,37,100,10,0,0,0,105,80,111,100,32,72,46,50,54,52,32,77,80,52,32,40,77,80,69,71,45,52,32,80,97,114,116,32,49,52,41,0,97,114,116,105,115,116,0,0,104,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,101,97,100,32,101,114,114,111,114,10,0,0,0,0,0,101,100,103,101,100,101,116,101,99,116,0,0,0,0,0,0,102,111,112,101,110,0,0,0,71,67,83,69,95,73,110,100,111,110,101,115,105,97,110,78,97,116,105,111,110,97,108,83,112,104,101,114,111,105,100,0,83,101,116,32,109,105,110,105,109,117,109,32,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,40,105,110,32,98,105,116,115,47,115,41,46,32,77,111,115,116,32,117,115,101,102,117,108,32,105,110,32,115,101,116,116,105,110,103,32,117,112,32,97,32,67,66,82,32,101,110,99,111,100,101,46,32,73,116,32,105,115,32,111,102,32,108,105,116,116,108,101,32,117,115,101,32,111,116,104,101,114,119,105,115,101,46,0,0,0,0,0,0,0,105,110,100,101,111,52,0,0,115,116,97,114,116,95,110,117,109,98,101,114,95,114,97,110,103,101,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2159240);
/* memory initializer */ allocate([98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,0,0,0,116,103,97,0,0,0,0,0,100,105,115,97,98,108,101,32,118,105,100,101,111,0,0,0,100,101,102,97,117,108,116,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,80,85,66,0,0,0,0,116,104,114,101,115,104,111,108,100,58,37,46,50,102,32,114,97,100,105,117,115,58,37,100,10,0,0,0,0,0,0,0,115,101,116,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,112,108,97,121,108,105,115,116,32,101,110,116,114,105,101,115,0,0,35,69,88,84,77,51,85,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,100,105,114,101,99,116,111,114,121,32,37,115,10,0,0,115,116,101,112,0,0,0,0,97,116,32,109,111,115,116,32,111,110,101,32,118,105,100,101,111,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,32,105,110,32,102,108,118,10,0,0,0,119,105,100,116,104,0,0,0,102,111,114,109,97,116,0,0,51,71,80,80,32,84,83,32,50,54,46,52,48,51,45,105,110,115,112,105,114,101,100,32,109,111,100,101,108,0,0,0,101,110,100,32,111,102,32,104,101,97,100,101,114,32,98,108,111,99,107,32,114,101,97,99,104,101,100,10,0,0,0,0,105,105,100,95,109,111,100,101,32,37,100,32,105,115,32,114,101,115,101,114,118,101,100,46,10,0,0,0,0,0,0,0,71,67,83,69,95,72,101,108,109,101,114,116,49,57,48,54,0,0,0,0,0,0,0,0,109,105,110,114,97,116,101,0,37,100,32,102,114,97,109,101,115,32,105,110,44,32,37,100,32,102,114,97,109,101,115,32,111,117,116,59,32,37,100,32,102,114,97,109,101,115,32,100,114,111,112,112,101,100,44,32,37,100,32,102,114,97,109,101,115,32,100,117,112,108,105,99,97,116,101,100,46,10,0,0,83,117,110,32,82,97,115,116,101,114,102,105,108,101,32,105,109,97,103,101,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,44,32,115,117,99,104,32,97,115,32,54,52,48,120,52,56,48,32,111,114,32,104,100,55,50,48,46,0,0,0,0,0,0,0,110,111,102,111,114,109,97,116,0,0,0,0,0,0,0,0,118,110,0,0,0,0,0,0,83,117,98,116,105,116,108,101,32,115,116,114,101,97,109,115,32,111,116,104,101,114,32,116,104,97,110,32,68,105,118,88,32,88,83,85,66,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,65,86,73,32,109,117,120,101,114,46,10,0,0,0,0,0,0,68,117,112,108,105,99,97,116,101,32,118,97,108,117,101,32,102,111,117,110,100,32,105,110,32,102,108,111,111,114,32,49,32,88,32,99,111,111,114,100,105,110,97,116,101,115,10,0,70,105,108,101,32,105,115,32,116,114,117,110,99,97,116,101,100,32,97,100,106,117,115,116,105,110,103,32,100,117,114,97,116,105,111,110,10,0,0,0,111,114,100,101,114,0,0,0,111,102,102,115,101,116,32,43,32,97,115,102,95,115,116,45,62,100,115,95,99,104,117,110,107,95,115,105,122,101,32,60,61,32,97,115,102,95,115,116,45,62,112,107,116,46,115,105,122,101,0,0,0,0,0,0,115,101,116,32,118,111,108,117,109,101,32,97,100,106,117,115,116,109,101,110,116,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,68,101,103,101,110,101,114,97,116,101,32,99,111,101,102,102,105,99,105,101,110,116,115,32,119,104,105,108,101,32,114,101,110,111,114,109,97,108,105,122,105,110,103,10,0,0,0,0,109,97,112,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,58,102,105,114,115,116,95,112,116,115,61,48,0,0,0,0,32,124,0,0,0,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,0,0,0,98,48,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,71,67,83,69,95,71,82,83,49,57,56,48,0,0,0,0,83,101,116,32,109,97,120,105,109,117,109,32,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,40,105,110,32,98,105,116,115,47,115,41,46,32,82,101,113,117,105,114,101,115,32,98,117,102,115,105,122,101,32,116,111,32,98,101,32,115,101,116,46,0,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,111,117,116,32,111,102,32,98,111,117,110,100,115,58,32,77,86,32,61,32,40,37,100,44,32,37,100,41,44,32,98,111,117,110,100,97,114,105,101,115,32,61,32,40,48,44,32,48,44,32,37,100,44,32,37,100,41,10,0,0,0,0,0,0,0,0,115,117,110,114,97,115,116,0,48,0,0,0,0,0,0,0,114,103,98,50,52,0,0,0,105,110,102,111,32,33,61,32,48,76,0,0,0,0,0,0,100,101,112,114,101,99,97,116,101,100,32,117,115,101,32,45,103,32,49,0,0,0,0,0,79,118,101,114,102,108,111,119,46,32,66,114,111,107,101,110,32,115,97,109,112,108,101,63,10,0,0,0,0,0,0,0,115,101,116,32,102,97,100,101,32,99,117,114,118,101,32,116,121,112,101,0,0,0,0,0,109,97,105,110,0,0,0,0,111,117,116,95,103,97,105,110,32,37,102,32,99,97,110,32,99,97,117,115,101,32,115,97,116,117,114,97,116,105,111,110,32,111,102,32,111,117,116,112,117,116,10,0,0,0,0,0,114,97,110,100,111,109,0,0,110,98,95,115,97,109,112,108,101,115,0,0,0,0,0,0,116,121,112,101,0,0,0,0,115,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,10,0,0,0,0,98,97,105,108,111,117,116,0,114,117,108,101,0,0,0,0,108,105,98,97,118,117,116,105,108,47,109,97,116,104,101,109,97,116,105,99,115,46,99,0,115,101,116,32,114,117,108,101,0,0,0,0,0,0,0,0,32,32,32,32,76,97,115,116,32,109,101,115,115,97,103,101,32,114,101,112,101,97,116,101,100,32,37,100,32,116,105,109,101,115,10,0,0,0,0,0,97,108,108,0,0,0,0,0,97,98,115,40,115,114,99,95,108,105,110,101,115,105,122,101,41,32,62,61,32,98,121,116,101,119,105,100,116,104,0,0,82,73,80,69,77,68,49,50,56,0,0,0,0,0,0,0,109,111,100,101,0,0,0,0,102,99,99,0,0,0,0,0,87,73,68,84,72,0,0,0,117,115,101,32,79,112,101,110,67,76,32,102,105,108,116,101,114,105,110,103,32,99,97,112,97,98,105,108,105,116,105,101,115,0,0,0,0,0,0,0,119,58,37,100,32,104,58,37,100,32,45,62,32,119,58,37,100,32,104,58,37,100,32,40,112,97,115,115,116,104,114,111,117,103,104,32,109,111,100,101,41,10,0,0,0,0,0,0,116,121,112,101,58,37,115,32,115,116,97,114,116,95,102,114,97,109,101,58,37,100,32,110,98,95,102,114,97,109,101,115,58,37,100,32,97,108,112,104,97,58,37,100,10,0,0,0,85,110,100,101,102,105,110,101,100,32,99,111,110,115,116,97,110,116,32,111,114,32,109,105,115,115,105,110,103,32,39,40,39,32,105,110,32,39,37,115,39,10,0,0,0,0,0,0,66,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,111,117,116,112,117,116,32,102,105,108,101,115,58,32,0,0,0,0,71,67,83,69,95,69,118,101,114,101,115,116,49,56,51,48,77,111,100,105,102,105,101,100,0,0,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,109,97,120,114,97,116,101,0,32,40,0,0,0,0,0,0,102,105,108,108,99,111,108,111,114,0,0,0,0,0,0,0,80,67,32,80,97,105,110,116,98,114,117,115,104,32,80,67,88,32,105,109,97,103,101,0,32,10,9,0,0,0,0,0,73,110,112,117,116,115,32,109,117,115,116,32,98,101,32,111,102,32,115,97,109,101,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,48,0,0,0,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,111,117,116,112,117,116,46,99,0,0,0,0,0,97,108,112,104,97,101,120,116,114,97,99,116,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,105,110,116,114,97,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,104,101,32,114,103,98,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,32,97,110,100,32,105,115,32,111,118,101,114,114,105,100,105,110,103,32,116,104,101,32,102,111,114,109,97,116,32,111,112,116,105,111,110,44,32,117,115,101,32,102,111,114,109,97,116,32,105,110,115,116,101,97,100,10,0,0,0,99,48,102,0,0,0,0,0,98,97,100,32,100,115,116,32,105,109,97,103,101,32,112,111,105,110,116,101,114,115,10,0,99,111,100,101,98,111,111,107,95,108,101,110,103,116,104,0,115,99,97,108,101,114,32,102,108,97,103,115,0,0,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,114,101,115,97,109,112,108,101,46,99,0,0,0,0,0,0,0,0,84,104,101,32,72,97,108,100,32,67,76,85,84,32,119,105,100,116,104,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,108,101,118,101,108,10,0,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,100,105,116,104,101,114,46,99,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,97,117,100,105,111,99,111,110,118,101,114,116,46,99,0,0,0,0,117,0,0,0,0,0,0,0,97,108,112,104,97,95,115,119,97,112,0,0,0,0,0,0,104,105,103,104,0,0,0,0,66,114,105,103,104,116,110,101,115,115,32,118,97,108,117,101,32,110,111,116,32,105,110,32,114,97,110,103,101,32,91,37,100,44,37,100,93,58,32,99,108,105,112,112,105,110,103,32,118,97,108,117,101,32,116,111,32,37,48,46,49,102,10,0,114,111,119,0,0,0,0,0,111,99,108,0,0,0,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,114,101,109,97,116,114,105,120,46,99,0,0,0,0,0,0,0,0,66,105,113,117,97,100,32,102,105,108,116,101,114,32,99,117,114,114,101,110,116,108,121,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,104,105,103,104,45,112,97,115,115,32,97,110,100,32,108,111,119,45,112,97,115,115,32,102,105,108,116,101,114,32,109,111,100,101,115,10,0,0,0,0,0,0,68,105,115,99,97,114,100,105,110,103,32,105,110,105,116,105,97,108,32,102,114,97,109,101,40,115,41,32,119,105,116,104,32,110,111,32,116,105,109,101,115,116,97,109,112,46,10,0,112,115,32,101,120,116,101,110,115,105,111,110,32,111,118,101,114,102,108,111,119,32,37,100,10,0,0,0,0,0,0,0,78,111,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,10,0,0,0,0,97,117,116,111,32,100,101,116,101,99,116,32,112,97,114,105,116,121,0,0,0,0,0,0,114,103,98,56,0,0,0,0,66,108,97,99,107,0,0,0,115,116,0,0,0,0,0,0,68,69,80,84,72,0,0,0,109,105,110,0,0,0,0,0,73,78,86,65,76,73,68,68,65,84,65,0,0,0,0,0,100,101,102,97,117,108,116,0,98,97,99,107,32,99,101,110,116,101,114,0,0,0,0,0,77,69,95,77,65,80,32,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,83,65,66,32,100,105,97,109,111,110,100,10,0,0,0,0,0,0,0,100,105,116,104,101,114,101,100,32,0,0,0,0,0,0,0,97,99,99,117,114,97,116,101,95,114,110,100,0,0,0,0,33,115,45,62,105,110,95,99,104,95,108,97,121,111,117,116,0,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,77,69,95,77,65,80,32,115,105,122,101,32,109,97,121,32,98,101,32,97,32,108,105,116,116,108,101,32,115,109,97,108,108,32,102,111,114,32,116,104,101,32,115,101,108,101,99,116,101,100,32,100,105,97,109,111,110,100,32,115,105,122,101,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,107,98,100,119,105,110,46,99,0,0,0,0,0,92,109,111,118,101,40,37,100,44,37,100,44,37,100,44,37,100,41,37,49,91,92,125,93,37,110,0,0,0,0,0,0,71,67,83,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,55,53,68,101,102,105,110,105,116,105,111,110,0,99,108,97,109,112,0,0,0,108,105,98,97,118,99,111,100,101,99,47,105,110,116,114,97,120,56,46,99,0,0,0,0,83,101,116,32,114,97,116,101,32,99,111,110,116,114,111,108,32,101,113,117,97,116,105,111,110,46,32,87,104,101,110,32,99,111,109,112,117,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,44,32,98,101,115,105,100,101,115,32,116,104,101,32,115,116,97,110,100,97,114,100,32,102,117,110,99,116,105,111,110,115,32,100,101,102,105,110,101,100,32,105,110,32,116,104,101,32,115,101,99,116,105,111,110,32,39,69,120,112,114,101,115,115,105,111,110,32,69,118,97,108,117,97,116,105,111,110,39,44,32,116,104,101,32,102,111,108,108,111,119,105,110,103,32,102,117,110,99,116,105,111,110,115,32,97,114,101,32,97,118,97,105,108,97,98,108,101,58,32,98,105,116,115,50,113,112,40,98,105,116,115,41,44,32,113,112,50,98,105,116,115,40,113,112,41,46,32,65,108,115,111,32,116,104,101,32,102,111,108,108,111,119,105,110,103,32,99,111,110,115,116,97,110,116,115,32,97,114,101,32,97,118,97,105,108,97,98,108,101,58,32,105,84,101,120,32,112,84,101,120,32,116,101,120,32,109,118,32,102,67,111,100,101,32,105,67,111,117,110,116,32,109,99,86,97,114,32,118,97,114,32,105,115,73,32,105,115,80,32,105,115,66,32,97,118,103,81,80,32,113,67,111,109,112,32,97,118,103,73,73,84,101,120,32,97,118,103,80,73,84,101,120,32,97,118,103,80,80,84,101,120,32,97,118,103,66,80,84,101,120,32,97,118,103,84,101,120,46,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,97,112,99,0,0,0,83,109,97,108,108,32,82,111,111,109,0,0,0,0,0,0,100,114,97,119,103,114,105,100,0,0,0,0,0,0,0,0,83,109,97,108,108,32,82,111,111,109,0,0,0,0,0,0,112,112,115,114,99,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,32,116,121,112,101,32,58,32,115,107,105,112,112,105,110,103,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,83,116,111,112,32,102,114,101,113,117,101,110,99,121,32,98,111,114,100,101,114,32,116,111,111,32,104,105,103,104,58,32,37,100,10,0,0,0,0,0,102,97,97,99,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,102,118,49,46,99,0,0,0,0,0,0,0,112,99,120,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,99,111,100,101,10,0,108,101,110,103,116,104,115,32,37,100,32,37,100,32,37,100,32,37,100,10,0,0,0,0,67,97,110,110,111,116,32,117,115,101,32,112,114,101,118,105,111,117,115,32,112,105,99,116,117,114,101,32,105,110,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,10,0,0,0,0,0,0,0,82,101,115,101,114,118,101,100,32,102,114,97,109,101,32,116,121,112,101,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,101,110,32,60,61,32,112,117,116,95,98,105,116,115,95,108,101,102,116,40,38,115,45,62,112,98,41,0,0,0,0,115,45,62,115,97,109,112,108,101,115,95,112,101,114,95,102,114,97,109,101,32,60,61,32,40,49,32,60,60,32,49,52,41,0,0,0,0,0,0,0,99,111,108,111,114,32,99,97,99,104,101,32,105,110,100,101,120,32,111,117,116,45,111,102,45,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,78,111,32,98,108,111,99,107,32,119,105,116,104,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,115,97,109,112,108,101,115,10,0,0,0,0,73,109,97,103,101,32,115,105,122,101,32,110,111,116,32,109,117,108,116,105,112,108,101,32,111,102,32,98,108,111,99,107,32,115,105,122,101,10,0,0,48,46,49,52,57,47,48,46,48,54,54,32,48,46,56,51,49,47,48,46,57,48,53,32,48,46,57,48,53,47,48,46,57,56,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,111,107,101,110,32,37,100,10,0,0,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,102,114,97,109,105,110,103,32,102,108,97,103,41,46,32,10,0,0,0,109,105,115,115,105,110,103,32,99,98,112,99,121,95,118,108,99,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,112,101,114,32,114,97,119,32,115,97,109,112,108,101,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,80,97,110,45,115,99,97,110,0,0,0,0,0,0,0,0,84,114,121,105,110,103,32,116,111,32,114,101,109,111,118,101,32,37,100,32,115,97,109,112,108,101,115,44,32,98,117,116,32,116,104,101,32,113,117,101,117,101,32,105,115,32,101,109,112,116,121,10,0,0,0,0,71,72,65,32,80,104,97,115,101,32,115,104,105,102,116,105,110,103,0,0,0,0,0,0,98,98,0,0,0,0,0,0,83,112,101,99,105,102,105,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,37,115,32,105,115,32,105,110,118,97,108,105,100,32,111,114,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,123,92,0,0,0,0,0,0,80,114,111,106,76,105,110,101,97,114,85,110,105,116,83,105,122,101,71,101,111,75,101,121,0,0,0,0,0,0,0,0,68,105,97,108,111,103,117,101,58,32,37,108,100,44,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,98,108,101,110,100,32,109,111,100,101,0,0,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,101,110,99,111,100,105,110,103,32,97,115,32,50,52,32,98,105,116,115,45,112,101,114,45,115,97,109,112,108,101,10,0,119,97,116,101,114,109,97,114,107,32,115,105,122,101,58,32,37,100,120,37,100,10,0,0,32,115,105,122,101,61,34,37,100,34,0,0,0,0,0,0,34,0,0,0,0,0,0,0,115,121,110,116,97,120,32,101,108,101,109,101,110,116,32,117,110,115,117,112,112,111,114,116,101,100,58,32,37,100,10,0,115,105,122,101,32,116,111,111,32,108,97,114,103,101,10,0,84,111,111,32,115,109,97,108,108,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,105,110,118,97,108,105,100,32,109,111,116,105,111,110,32,98,97,115,101,32,118,97,108,117,101,32,37,100,10,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,65,68,88,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,110,117,109,58,100,101,110,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,112,108,101,97,115,101,32,117,115,101,32,110,117,109,47,100,101,110,32,111,114,32,110,97,109,101,100,32,111,112,116,105,111,110,115,32,105,110,115,116,101,97,100,10,0,0,0,0,0,0,113,112,50,98,105,116,115,0,97,100,112,99,109,95,105,109,97,95,119,97,118,0,0,0,110,111,116,32,101,110,111,117,103,104,32,101,120,116,114,97,100,97,116,97,32,40,37,105,41,10,0,0,0,0,0,0,118,101,110,100,111,114,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,100,101,102,97,117,108,116,0,112,99,109,95,109,117,108,97,119,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,118,102,111,114,109,97,116,95,111,112,101,110,95,105,110,112,117,116,32,39,37,115,39,10,0,0,0,0,0,114,120,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,49,54,10,0,0,0,0,69,114,114,111,114,32,103,101,110,101,114,97,116,105,110,103,32,104,117,102,102,109,97,110,32,116,97,98,108,101,10,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,80,82,69,86,95,73,78,80,84,83,0,0,0,0,0,0,97,100,112,99,109,95,97,102,99,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,66,45,102,114,97,109,101,115,32,114,101,113,117,101,115,116,101,100,44,32,109,97,120,105,109,117,109,32,105,115,32,37,100,46,10,0,0,0,0,115,45,62,112,105,99,116,95,116,121,112,101,32,61,61,32,65,86,95,80,73,67,84,85,82,69,95,84,89,80,69,95,73,32,124,124,32,40,115,45,62,108,97,115,116,95,112,105,99,116,117,114,101,95,112,116,114,32,38,38,32,115,45,62,108,97,115,116,95,112,105,99,116,117,114,101,95,112,116,114,45,62,102,46,98,117,102,91,48,93,41,0,0,0,0,0,115,45,62,102,114,97,109,101,32,33,61,32,48,76,0,0,115,119,115,95,102,108,97,103,115,61,0,0,0,0,0,0,115,45,62,102,114,97,109,101,32,33,61,32,48,76,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,108,117,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,0,0,102,114,97,109,101,32,115,107,105,112,32,37,100,10,0,0,70,108,97,103,115,32,99,111,109,109,111,110,32,102,111,114,32,97,108,108,32,109,112,101,103,118,105,100,101,111,45,98,97,115,101,100,32,101,110,99,111,100,101,114,115,46,0,0,99,121,99,108,101,0,0,0,105,103,110,111,114,105,110,103,32,112,105,99,32,99,111,100,32,101,120,116,32,97,102,116,101,114,32,37,88,10,0,0,70,73,82,32,97,110,100,32,73,73,82,32,102,105,108,116,101,114,115,32,109,117,115,116,32,117,115,101,32,116,104,101,32,115,97,109,101,32,112,114,101,99,105,115,105,111,110,46,10,0,0,0,0,0,0,0,85,110,104,97,110,100,108,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,48,120,37,120,10,0,0,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,50,58,49,58,49,46,10,0,0,0,0,0,0,0,101,114,114,111,114,32,100,117,114,105,110,103,32,112,114,111,99,101,115,115,105,110,103,32,109,97,114,107,101,114,32,115,101,103,109,101,110,116,32,37,46,52,120,10,0,0,0,0,97,99,51,0,0,0,0,0,92,110,0,0,0,0,0,0,65,108,108,111,99,97,116,101,100,32,116,105,108,101,32,115,105,122,101,32,37,100,32,109,105,115,109,97,116,99,104,101,115,32,112,97,114,97,109,101,116,101,114,115,32,37,100,32,105,110,32,105,118,105,95,112,114,111,99,101,115,115,95,101,109,112,116,121,95,116,105,108,101,40,41,10,0,0,0,0,67,111,117,108,100,32,110,111,116,32,40,114,101,41,97,108,108,111,99,97,116,101,32,105,110,116,101,114,118,97,108,115,32,97,114,114,97,121,10,0,73,32,99,98,112,99,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,33,10,0,0,0,0,79,110,101,32,111,102,32,116,104,101,32,121,47,117,47,118,32,111,102,102,115,101,116,115,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,80,67,77,32,98,105,116,32,100,101,112,116,104,32,40,37,100,41,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,110,111,114,109,97,108,32,98,105,116,32,100,101,112,116,104,32,40,37,100,41,10,0,0,0,0,0,0,0,80,80,83,32,105,100,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,0,97,99,51,95,102,105,120,101,100,0,0,0,0,0,0,0,83,73,0,0,0,0,0,0,99,116,95,116,121,112,101,58,37,88,32,112,105,99,95,115,116,114,117,99,116,58,37,100,10,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,108,111,110,103,32,114,101,102,32,105,110,32,109,101,109,111,114,121,32,109,97,110,97,103,101,109,101,110,116,32,99,111,110,116,114,111,108,32,111,112,101,114,97,116,105,111,110,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,108,117,109,97,32,98,105,116,32,100,101,112,116,104,61,37,100,10,0,0,0,0,0,0,108,116,114,116,95,99,101,110,116,101,114,95,109,105,120,95,108,101,118,101,108,0,0,0,110,111,32,112,105,99,116,117,114,101,32,37,115,10,0,0,82,79,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,111,116,115,112,111,116,32,112,111,115,105,116,105,111,110,32,37,100,44,37,100,10,0,98,117,102,102,101,114,32,110,111,116,32,102,117,108,108,121,32,99,111,110,115,117,109,101,100,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,44,32,37,100,10,0,0,0,0,0,0,101,97,99,51,0,0,0,0,105,110,118,97,108,105,100,32,114,105,99,101,32,111,114,100,101,114,58,32,37,105,32,98,108,111,99,107,115,105,122,101,32,37,105,10,0,0,0,0,50,80,97,115,115,32,102,105,108,101,32,105,110,118,97,108,105,100,32,97,116,32,37,100,32,37,100,32,91,37,115,93,10,0,0,0,0,0,0,0,102,114,97,109,101,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,95,99,111,117,110,116,32,62,61,32,48,0,0,0,0,0,0,85,110,107,110,111,119,110,32,112,105,120,101,108,32,116,121,112,101,10,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,77,111,100,101,0,0,0,0,0,112,105,120,95,102,109,116,0,66,108,111,99,107,32,112,114,101,100,105,99,116,105,111,110,32,105,110,100,101,120,32,116,111,111,32,104,105,103,104,10,0,0,0,0,0,0,0,0,69,82,82,79,82,58,32,68,84,83,45,88,66,82,58,32,98,108,111,99,107,32,99,111,100,101,32,108,111,111,107,45,117,112,32,102,97,105,108,101,100,10,0,0,0,0,0,0,67,97,110,110,111,116,32,98,117,102,102,101,114,32,109,111,114,101,32,102,114,97,109,101,115,46,32,67,111,110,115,117,109,101,32,115,111,109,101,32,97,118,97,105,108,97,98,108,101,32,102,114,97,109,101,115,32,98,101,102,111,114,101,32,97,100,100,105,110,103,32,110,101,119,32,111,110,101,115,46,10,0,0,0,0,0,0,0,116,111,116,97,108,95,115,117,98,98,97,110,100,115,32,62,32,53,51,0,0,0,0,0,71,67,83,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,54,55,68,101,102,105,110,105,116,105,111,110,0,114,99,95,101,113,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,109,97,105,110,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,106,112,101,103,108,115,0,0,37,115,37,115,0,0,0,0,66,101,97,109,32,83,111,102,116,119,97,114,101,32,86,66,0,0,0,0,0,0,0,0,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,100,101,99,111,100,101,100,32,112,101,114,32,99,97,108,108,0,0,0,0,0,0,97,97,99,95,108,97,116,109,0,0,0,0,0,0,0,0,97,54,52,109,117,108,116,105,53,0,0,0,0,0,0,0,82,117,110,32,111,118,101,114,114,117,110,10,0,0,0,0,68,101,97,116,104,32,77,101,116,97,108,0,0,0,0,0,56,115,118,120,95,101,120,112,0,0,0,0,0,0,0,0,84,104,105,115,32,102,105,108,116,101,114,32,100,111,101,115,32,110,111,116,32,116,97,107,101,32,97,110,121,32,111,112,116,105,111,110,115,44,32,98,117,116,32,111,112,116,105,111,110,115,32,119,101,114,101,32,112,114,111,118,105,100,101,100,58,32,37,115,46,10,0,0,87,77,47,80,117,98,108,105,115,104,101,114,0,0,0,0,69,114,114,111,114,58,32,85,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,32,100,101,112,116,104,58,32,37,117,46,10,0,0,0,0,65,73,70,70,32,109,117,120,101,114,0,0,0,0,0,0,48,120,37,48,52,88,0,0,52,52,52,112,57,0,0,0,100,114,97,119,98,111,120,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,87,105,100,116,104,32,49,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,69,114,114,111,114,32,99,111,109,112,114,101,115,115,105,110,103,32,100,97,116,97,10,0,70,108,97,103,115,61,37,88,32,118,101,114,61,37,105,46,37,105,32,99,111,109,112,61,37,105,32,102,109,116,61,37,105,32,98,108,107,61,37,105,120,37,105,10,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,99,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,80,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,121,52,49,112,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,100,105,118,105,115,105,98,108,101,32,98,121,32,56,46,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,102,114,97,109,101,32,116,121,112,101,32,37,100,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,10,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,88,83,85,66,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,99,111,100,101,100,32,102,114,97,109,101,32,115,105,122,101,32,37,100,32,116,111,111,32,115,109,97,108,108,10,0,0,119,105,100,116,104,32,105,115,32,110,111,116,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,10,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,108,105,99,101,32,101,110,100,32,98,101,102,111,114,101,32,115,116,97,114,116,10,0,83,105,122,101,32,118,97,108,117,101,32,37,100,120,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,111,110,108,121,32,97,99,99,101,112,116,115,32,97,32,115,105,122,101,32,111,102,32,37,100,120,37,100,10,0,0,0,66,117,102,102,101,114,32,105,115,32,108,111,110,103,101,114,32,116,104,97,110,32,101,120,112,101,99,116,101,100,44,32,116,114,117,110,99,97,116,105,110,103,32,97,116,32,98,121,116,101,32,37,100,10,0,0,35,100,101,102,105,110,101,32,105,109,97,103,101,95,119,105,100,116,104,32,37,117,10,0,35,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,97,103,32,115,105,122,101,32,37,100,10,0,0,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,80,97,99,107,101,116,32,115,105,122,101,32,37,100,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,119,109,118,50,101,110,99,46,99,0,0,0,0,87,77,65,80,114,111,45,105,110,45,87,77,65,86,111,105,99,101,0,0,0,0,0,0,71,65,81,32,103,97,105,110,32,103,114,111,117,112,32,99,111,100,101,32,111,117,116,45,111,102,45,114,97,110,103,101,10,0,0,0,0,0,0,0,73,110,112,117,116,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,60,32,37,100,41,10,0,0,0,0,0,0,0,98,117,102,32,115,105,122,101,32,37,100,32,105,110,118,97,108,105,100,10,0,0,0,0,119,109,97,118,50,0,0,0,119,109,97,118,50,0,0,0,111,118,101,114,102,108,111,119,32,105,110,32,115,112,101,99,116,114,97,108,32,82,76,69,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,37,115,0,0,0,0,0,0,109,105,115,115,105,110,103,32,82,73,70,70,32,116,97,103,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,58,32,37,100,10,0,0,70,111,117,110,100,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,116,121,112,101,58,32,37,99,37,99,37,99,37,99,32,40,37,48,56,88,41,10,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,114,101,102,101,114,101,110,99,101,32,37,100,32,110,111,116,32,97,118,97,105,108,97,98,108,101,10,0,0,0,118,112,56,0,0,0,0,0,118,112,54,102,0,0,0,0,85,110,107,110,111,119,110,32,119,97,118,101,108,101,116,32,116,121,112,101,32,37,100,10,0,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,118,112,51,0,0,0,0,0,111,117,116,112,117,116,32,98,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,35,37,100,32,112,111,105,110,116,115,58,0,0,0,0,0,71,67,83,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,51,55,65,100,106,117,115,116,109,101,110,116,0,114,99,95,111,118,101,114,114,105,100,101,95,99,111,117,110,116,0,0,0,0,0,0,0,73,100,32,104,101,97,100,101,114,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,73,110,118,97,108,105,100,32,109,111,100,101,32,105,110,32,112,97,99,107,101,116,10,0,80,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,100,97,116,97,33,10,0,118,98,0,0,0,0,0,0,118,109,100,97,117,100,105,111,0,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,32,37,100,32,60,32,37,100,10,0,0,0,0,0,0,0,102,111,114,109,97,116,0,0,114,101,112,111,114,116,0,0,119,109,118,51,0,0,0,0,87,77,47,77,101,100,105,97,79,114,105,103,105,110,97,108,66,114,111,97,100,99,97,115,116,68,97,116,101,84,105,109,101,0,0,0,0,0,0,0,73,108,108,101,103,97,108,32,105,110,116,114,97,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,10,0,0,109,101,116,97,100,97,116,97,0,0,0,0,0,0,0,0,79,108,100,32,105,110,116,101,114,108,97,99,101,100,32,109,111,100,101,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,111,114,105,103,105,110,97,116,111,114,0,0,0,0,0,0,70,114,97,109,101,32,115,105,122,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,118,52,49,48,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,46,10,0,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,118,52,48,56,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,101,120,116,114,97,100,97,116,97,46,10,0,0,118,52,48,56,0,0,0,0,111,117,116,95,119,0,0,0,118,51,48,56,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,46,10,0,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,80,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,79,77,84,0,0,0,0,66,114,111,107,101,110,32,118,50,49,48,32,119,105,116,104,32,116,111,111,32,115,109,97,108,108,32,112,97,100,100,105,110,103,32,40,54,52,32,98,121,116,101,41,32,100,101,116,101,99,116,101,100,10,0,0,100,101,102,97,117,108,116,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,32,50,46,10,0,0,0,0,37,100,32,102,114,97,109,101,115,32,108,101,102,116,32,105,110,32,116,104,101,32,113,117,101,117,101,32,111,110,32,99,108,111,115,105,110,103,10,0,73,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,32,102,111,114,32,97,32,112,108,97,110,101,10,0,0,13,10,86,101,114,115,105,111,110,58,86,105,118,111,47,0,115,101,116,32,100,105,115,112,108,97,121,32,115,99,97,108,101,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,113,117,97,110,116,105,122,97,116,105,111,110,32,117,110,105,116,115,58,32,37,100,33,10,0,0,0,0,0,0,100,101,115,99,45,62,102,108,97,103,115,32,38,32,40,49,32,60,60,32,52,41,0,0,119,97,114,110,105,110,103,58,32,109,111,100,105,102,105,101,114,32,109,117,115,116,32,98,101,32,48,32,111,114,32,49,44,32,103,111,116,32,37,105,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2169480);
/* memory initializer */ allocate([116,101,120,116,117,114,101,32,100,97,116,97,32,118,101,114,115,105,111,110,32,37,105,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,10,0,77,105,115,115,105,110,103,32,111,114,32,105,110,99,111,109,112,108,101,116,101,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,102,114,97,109,101,115,32,112,101,114,32,112,97,99,107,101,116,32,40,37,100,41,10,0,0,0,0,0,0,0,0,101,110,99,111,100,105,110,103,32,97,115,32,50,52,32,98,105,116,115,45,112,101,114,45,115,97,109,112,108,101,10,0,105,110,100,101,120,32,60,32,115,116,45,62,110,98,95,105,110,100,101,120,95,101,110,116,114,105,101,115,0,0,0,0,67,82,67,32,101,114,114,111,114,10,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,116,121,112,101,32,37,100,10,0,0,0,0,0,0,0,0,114,114,0,0,0,0,0,0,73,110,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,84,111,111,32,115,109,97,108,108,32,105,110,112,117,116,32,98,117,102,102,101,114,32,40,37,100,32,98,121,116,101,115,41,44,32,110,101,101,100,32,97,116,32,108,101,97,115,116,32,51,50,32,98,121,116,101,115,10,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,0,68,117,112,108,105,99,97,116,101,32,98,115,102,115,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,97,115,115,111,99,105,97,116,101,100,32,116,111,32,115,116,114,101,97,109,32,37,100,32,111,102,32,115,108,97,118,101,32,111,117,116,112,117,116,32,39,37,115,39,44,32,102,105,108,116,101,114,115,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,0,0,32,104,101,108,112,33,32,116,114,117,101,109,111,116,105,111,110,49,32,100,101,99,111,100,101,114,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,73,110,112,117,116,32,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,44,32,116,114,117,110,99,97,116,101,100,32,115,97,109,112,108,101,63,10,0,0,0,0,0,0,84,104,105,115,32,99,111,108,111,114,115,32,102,111,114,109,97,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,83,71,65,49,57,50,50,0,114,99,95,113,109,111,100,95,102,114,101,113,0,0,0,0,65,77,86,32,86,105,100,101,111,0,0,0,0,0,0,0,111,117,116,112,117,116,32,105,110,32,98,105,103,45,101,110,100,105,97,110,32,102,111,114,109,97,116,32,40,102,111,114,32,117,115,101,32,97,115,32,115,49,54,98,101,41,0,0,114,115,0,0,0,0,0,0,115,101,116,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,105,115,109,118,0,0,0,0,115,101,116,32,98,108,117,101,32,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,115,101,116,32,112,114,101,102,105,120,32,116,111,32,112,114,101,112,101,110,100,32,116,111,32,101,97,99,104,32,108,105,115,116,32,101,110,116,114,121,32,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,116,116,108,0,0,0,0,0,119,97,118,101,0,0,0,0,104,50,54,52,95,109,111,100,101,48,0,0,0,0,0,0,69,118,101,110,116,115,0,0,65,116,32,109,111,115,116,32,50,32,115,116,114,101,97,109,115,32,97,114,101,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,109,117,120,105,110,103,32,105,110,32,82,77,10,0,0,0,0,0,73,109,112,111,115,115,105,98,108,121,32,115,105,122,101,100,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,0,73,83,77,80,0,0,0,0,71,84,67,105,116,97,116,105,111,110,71,101,111,75,101,121,0,0,0,0,0,0,0,0,37,115,37,46,49,53,103,0,91,83,99,114,105,112,116,32,73,110,102,111,93,13,10,83,99,114,105,112,116,84,121,112,101,58,32,118,52,46,48,48,43,13,10,13,10,91,86,52,43,32,83,116,121,108,101,115,93,13,10,70,111,114,109,97,116,58,32,78,97,109,101,44,32,70,111,110,116,110,97,109,101,44,32,70,111,110,116,115,105,122,101,44,32,80,114,105,109,97,114,121,67,111,108,111,117,114,44,32,83,101,99,111,110,100,97,114,121,67,111,108,111,117,114,44,32,79,117,116,108,105,110,101,67,111,108,111,117,114,44,32,66,97,99,107,67,111,108,111,117,114,44,32,66,111,108,100,44,32,73,116,97,108,105,99,44,32,85,110,100,101,114,108,105,110,101,44,32,66,111,114,100,101,114,83,116,121,108,101,44,32,79,117,116,108,105,110,101,44,32,83,104,97,100,111,119,44,32,65,108,105,103,110,109,101,110,116,44,32,77,97,114,103,105,110,76,44,32,77,97,114,103,105,110,82,44,32,77,97,114,103,105,110,86,44,32,65,108,112,104,97,76,101,118,101,108,44,32,69,110,99,111,100,105,110,103,13,10,83,116,121,108,101,58,32,68,101,102,97,117,108,116,44,37,115,44,37,100,44,38,72,37,120,44,38,72,37,120,44,38,72,37,120,44,38,72,37,120,44,37,100,44,37,100,44,37,100,44,49,44,49,44,48,44,37,100,44,49,48,44,49,48,44,49,48,44,48,44,48,13,10,13,10,91,69,118,101,110,116,115,93,13,10,70,111,114,109,97,116,58,32,76,97,121,101,114,44,32,83,116,97,114,116,44,32,69,110,100,44,32,83,116,121,108,101,44,32,84,101,120,116,13,10,0,0,0,0,0,0,0,0,103,55,50,50,0,0,0,0,73,110,118,97,108,105,100,32,84,73,70,70,32,104,101,97,100,101,114,10,0,0,0,0,118,112,108,97,121,101,114,0,105,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,97,108,97,99,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,116,111,32,114,101,97,100,32,104,101,97,100,101,114,10,0,67,82,67,32,101,114,114,111,114,10,0,0,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,65,114,99,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,101,120,112,101,114,105,109,101,110,116,97,108,32,113,117,97,110,116,105,122,101,114,32,109,111,100,117,108,97,116,105,111,110,0,0,0,0,0,0,0,82,68,58,32,37,102,10,0,69,114,114,111,114,32,105,110,32,115,118,113,49,95,100,101,99,111,100,101,95,98,108,111,99,107,32,37,105,32,40,107,101,121,102,114,97,109,101,41,10,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,104,105,115,32,105,115,32,110,111,116,32,115,117,110,114,97,115,32,101,110,99,111,100,101,100,32,100,97,116,97,10,0,0,0,0,0,0,0,0,115,56,0,0,0,0,0,0,97,109,118,0,0,0,0,0,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,44,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,37,99,0,0,0,0,0,0,0,115,117,98,114,105,112,0,0,115,117,98,114,105,112,0,0,97,109,118,0,0,0,0,0,115,111,110,105,99,108,115,0,115,56,0,0,0,0,0,0,112,105,120,95,102,109,116,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,108,97,99,0,0,0,0,107,101,121,102,114,97,109,101,58,37,100,32,113,108,111,103,58,37,100,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,115,110,111,119,95,100,119,116,46,99,0,0,0,73,110,118,97,108,105,100,32,104,101,105,103,104,116,10,0,119,97,114,110,105,110,103,58,32,77,79,86,32,99,104,117,110,107,32,115,105,122,101,32,33,61,32,101,110,99,111,100,101,100,32,99,104,117,110,107,32,115,105,122,101,32,40,37,100,32,33,61,32,37,100,41,59,32,117,115,105,110,103,32,77,79,86,32,99,104,117,110,107,32,115,105,122,101,10,0,115,109,97,99,107,97,117,100,0,0,0,0,0,0,0,0,69,114,114,111,114,32,112,114,111,99,101,115,115,105,110,103,32,112,97,99,107,101,116,58,32,112,97,99,107,101,116,32,115,105,122,101,32,40,37,100,41,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,100,0,0,0,0,0,0,0,100,105,115,99,97,114,100,99,111,114,114,117,112,116,0,0,67,66,67,45,77,65,67,0,97,105,99,0,0,0,0,0,101,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,98,105,116,115,116,114,101,97,109,32,98,117,102,102,101,114,10,0,0,0,0,0,0,111,112,99,111,100,101,32,37,100,0,0,0,0,0,0,0,83,71,73,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,54,53,53,51,53,120,54,53,53,51,53,10,0,0,0,0,0,98,117,102,95,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,41,10,0,0,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,99,104,117,110,107,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,0,97,100,112,99,109,95,97,100,120,0,0,0,0,0,0,0,60,80,0,0,0,0,0,0,102,114,97,109,101,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,68,113,117,97,110,116,32,102,111,114,32,80,45,102,114,97,109,101,10,0,0,0,0,0,78,111,32,101,120,116,114,97,100,97,116,97,32,112,114,101,115,101,110,116,10,0,0,0,73,110,118,97,108,105,100,32,100,101,99,111,100,101,114,32,115,116,97,116,101,58,32,66,45,102,114,97,109,101,32,119,105,116,104,111,117,116,32,114,101,102,101,114,101,110,99,101,32,100,97,116,97,46,10,0,97,100,112,99,109,95,97,100,120,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,114,118,50,48,101,110,99,46,99,0,0,0,0,114,118,49,48,32,101,110,99,111,100,101,114,0,0,0,0,98,105,110,0,0,0,0,0,109,105,110,95,118,97,108,0,82,101,97,108,86,105,100,101,111,32,49,46,48,0,0,0,70,105,114,115,116,32,99,104,117,110,107,32,98,121,116,101,32,105,115,32,48,120,37,48,50,120,32,105,110,115,116,101,97,100,32,111,102,32,48,120,101,49,10,0,0,0,0,0,87,97,114,110,105,110,103,44,32,103,101,110,101,114,97,116,101,100,32,97,32,102,114,97,109,101,32,116,111,111,32,98,105,103,32,102,111,114,32,81,117,97,107,101,32,40,37,100,32,62,32,54,53,53,51,53,41,44,32,110,111,119,32,115,119,105,116,99,104,105,110,103,32,116,111,32,97,32,98,105,103,103,101,114,32,113,115,99,97,108,101,32,118,97,108,117,101,46,10,0,0,0,0,0,67,104,117,110,107,32,100,111,101,115,32,110,111,116,32,102,105,116,32,105,110,32,105,110,112,117,116,32,98,117,102,102,101,114,10,0,0,0,0,0,65,117,100,105,111,32,109,117,115,116,32,98,101,32,109,111,110,111,32,111,114,32,115,116,101,114,101,111,10,0,0,0,105,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,10,0,60,98,114,47,62,0,0,0,67,104,97,110,110,101,108,76,97,121,111,117,116,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,97,109,112,108,101,95,110,95,98,121,116,101,115,0,0,116,104,101,114,101,32,109,117,115,116,32,98,101,32,101,120,97,99,116,108,121,32,111,110,101,32,118,105,100,101,111,32,115,116,114,101,97,109,32,97,110,100,32,105,116,32,109,117,115,116,32,98,101,32,116,104,101,32,102,105,114,115,116,32,111,110,101,10,0,0,0,0,69,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,113,116,0,0,0,0,87,114,111,110,103,32,112,97,99,107,101,116,39,115,32,98,114,101,97,116,104,32,115,109,101,108,108,115,32,111,102,32,119,114,111,110,103,32,100,97,116,97,33,10,0,0,0,0,69,114,114,111,114,33,32,73,110,112,117,116,32,98,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,32,91,37,100,60,37,100,93,10,0,0,0,0,0,0,0,70,114,97,109,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,98,121,116,101,115,41,46,32,84,114,117,110,99,97,116,101,100,32,102,105,108,101,63,10,0,0,0,0,114,49,48,107,0,0,0,0,114,49,48,107,0,0,0,0,103,111,116,32,37,105,32,105,110,100,101,120,32,116,97,98,108,101,115,32,45,32,111,110,108,121,32,116,104,101,32,102,105,114,115,116,32,111,110,101,32,40,73,110,100,101,120,83,73,68,32,37,105,41,32,119,105,108,108,32,98,101,32,117,115,101,100,10,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,115,112,97,99,101,46,10,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,115,112,97,99,101,58,32,37,100,32,98,105,116,115,47,115,97,109,112,108,101,63,10,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,69,114,114,111,114,32,99,111,108,111,114,32,99,111,117,110,116,32,45,32,37,105,40,48,120,37,88,41,10,0,0,0,80,73,88,69,76,95,65,83,80,69,67,84,0,0,0,0,83,117,112,101,114,98,108,111,99,107,32,102,111,108,108,111,119,115,10,0,0,0,0,0,66,105,116,114,97,116,101,32,99,97,110,110,111,116,32,98,101,32,100,101,116,101,114,109,105,110,101,100,46,0,0,0,73,109,97,103,101,32,102,111,114,109,97,116,32,110,111,116,32,82,71,66,49,53,0,0,84,97,103,32,37,115,47,48,120,37,48,56,120,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,111,117,116,112,117,116,32,99,111,100,101,99,32,105,100,32,39,37,100,39,32,40,37,115,41,10,0,0,0,0,0,0,115,101,116,115,97,114,0,0,116,104,101,114,101,32,115,104,111,117,108,100,32,98,101,32,97,110,32,105,110,116,101,103,101,114,32,112,111,119,101,114,32,111,102,32,116,119,111,32,77,66,115,32,112,101,114,32,115,108,105,99,101,10,0,0,112,114,111,114,101,115,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,10,0,0,70,70,109,112,101,103,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,82,71,83,0,0,0,0,0,112,103,109,121,117,118,0,0,112,111,115,32,62,61,32,49,56,56,0,0,0,0,0,0,114,99,95,113,109,111,100,95,97,109,112,0,0,0,0,0,112,103,109,121,117,118,0,0,49,46,50,46,53,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,105,115,115,105,110,103,32,112,110,103,32,115,105,103,110,97,116,117,114,101,10,0,0,79,110,50,32,86,80,54,32,40,70,108,97,115,104,32,118,101,114,115,105,111,110,44,32,119,105,116,104,32,97,108,112,104,97,32,99,104,97,110,110,101,108,41,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,0,0,0,85,110,107,110,111,119,110,32,115,117,98,116,105,116,108,101,32,115,101,103,109,101,110,116,32,116,121,112,101,32,48,120,37,120,44,32,108,101,110,103,116,104,32,37,100,10,0,0,105,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,32,100,111,32,110,111,116,32,102,105,116,32,105,110,32,49,54,32,98,105,116,115,10,0,73,68,88,32,115,116,114,101,97,109,91,37,100,93,32,105,100,61,37,115,10,0,0,0,116,104,105,115,32,105,115,32,110,111,116,32,80,67,88,32,101,110,99,111,100,101,100,32,100,97,116,97,10,0,0,0,98,101,115,116,95,98,105,116,114,97,116,101,95,105,100,120,32,62,61,32,48,0,0,0,115,101,116,32,97,115,112,101,99,116,32,114,97,116,105,111,32,40,52,58,51,44,32,49,54,58,57,32,111,114,32,49,46,51,51,51,51,44,32,49,46,55,55,55,55,41,0,0,80,67,77,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,80,67,77,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,66,76,65,67,75,65,78,68,87,72,73,84,69,0,0,0,112,97,102,95,97,117,100,105,111,0,0,0,0,0,0,0,97,116,114,105,109,0,0,0,105,112,111,100,0,0,0,0,116,105,116,108,101,0,0,0,101,110,100,32,100,117,114,97,116,105,111,110,32,61,32,37,108,108,117,10,0,0,0,0,73,110,118,97,108,105,100,32,101,108,101,109,101,110,116,10,0,0,0,0,0,0,0,0,97,109,111,118,105,101,0,0,119,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,111,112,116,105,111,110,115,46,99,0,0,0,0,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,115,109,97,108,108,10,0,0,78,101,108,108,121,109,111,115,101,114,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,49,32,99,104,97,110,110,101,108,10,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,113,117,97,110,116,105,122,97,116,105,111,110,32,116,97,98,108,101,32,100,101,99,111,100,101,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,73,71,78,0,0,0,0,0,109,118,99,50,0,0,0,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,105,101,115,32,111,102,32,52,10,0,0,0,0,0,0,0,32,77,83,32,86,105,100,101,111,45,49,32,119,97,114,110,105,110,103,58,32,115,116,114,101,97,109,95,112,116,114,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,0,0,0,0,104,111,119,32,116,111,32,107,101,101,112,32,113,117,97,110,116,105,122,101,114,32,98,101,116,119,101,101,110,32,113,109,105,110,32,97,110,100,32,113,109,97,120,32,40,48,32,61,32,99,108,105,112,44,32,49,32,61,32,117,115,101,32,100,105,102,102,101,114,101,110,116,105,97,98,108,101,32,102,117,110,99,116,105,111,110,41,0,117,115,101,32,115,116,114,102,116,105,109,101,32,102,111,114,32,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,70,114,97,109,101,32,115,104,111,117,108,100,32,104,97,118,101,32,97,116,32,108,101,97,115,116,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,32,105,110,115,116,101,97,100,10,0,0,0,0,70,114,97,109,101,32,115,104,111,117,108,100,32,104,97,118,101,32,97,116,32,108,101,97,115,116,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,32,105,110,115,116,101,97,100,10,0,0,0,0,97,115,112,108,105,116,0,0,118,112,54,97,0,0,0,0,105,109,112,108,105,99,105,116,95,114,101,99,116,32,38,38,32,117,115,101,100,95,114,101,99,116,115,32,62,32,48,10,0,0,0,0,0,0,0,0,115,101,116,32,102,105,114,115,116,32,110,117,109,98,101,114,32,105,110,32,116,104,101,32,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,70,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,32,116,111,111,32,108,97,114,103,101,0,0,0,0,0,0,0,0,83,107,105,112,32,98,101,121,111,110,100,32,112,105,99,116,117,114,101,32,98,111,117,110,100,115,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,98,109,112,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,115,109,112,101,103,52,101,110,99,46,99,0,97,115,112,101,99,116,0,0,47,92,95,0,0,0,0,0,100,101,115,104,97,107,101,0,100,105,115,99,0,0,0,0,97,100,112,99,109,95,52,120,109,0,0,0,0,0,0,0,115,107,105,112,95,114,100,0,104,108,115,95,108,105,115,116,95,115,105,122,101,0,0,0,108,111,99,97,116,105,111,110,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,118,105,100,101,111,46,99,0,0,37,115,47,115,116,114,101,97,109,37,100,46,97,98,115,116,46,116,109,112,0,0,0,0,110,111,116,32,119,114,105,116,105,110,103,32,39,99,104,97,110,39,32,116,97,103,32,100,117,101,32,116,111,32,108,97,99,107,32,111,102,32,99,104,97,110,110,101,108,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,97,115,101,116,112,116,115,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,37,99,37,48,50,100,0,0,0,0,109,112,50,102,108,111,97,116,0,0,0,0,0,0,0,0,65,117,100,105,111,32,99,111,100,101,99,32,39,37,115,39,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,0,0,0,109,112,50,0,0,0,0,0,115,116,101,114,101,111,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,52,118,105,100,101,111,101,110,99,46,99,0,0,0,0,0,0,101,110,100,32,111,102,32,104,101,97,100,101,114,32,98,108,111,99,107,32,114,101,97,99,104,101,100,32,40,119,105,116,104,105,110,32,97,117,100,105,111,32,115,117,98,104,101,97,100,101,114,41,10,0,0,0,98,101,102,111,114,101,32,116,105,109,101,95,105,110,99,114,101,109,101,110,116,32,105,110,32,118,105,100,101,111,32,112,97,99,107,101,100,32,104,101,97,100,101,114,0,0,0,0,111,118,101,114,102,108,111,119,32,116,104,97,116,32,119,111,117,108,100,32,110,101,101,100,32,99,108,105,112,105,110,103,32,105,110,32,102,102,95,97,99,101,108,112,95,105,110,116,101,114,112,111,108,97,116,101,40,41,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,49,50,101,110,99,46,99,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,66,101,110,111,105,116,0,0,113,115,113,117,105,115,104,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,82,101,110,100,101,114,119,97,114,101,32,84,88,68,32,40,84,101,88,116,117,114,101,32,68,105,99,116,105,111,110,97,114,121,41,32,105,109,97,103,101,0,0,0,0,0,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,109,97,120,98,97,110,100,32,37,100,32,116,111,111,32,108,97,114,103,101,10,0,0,0,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,32,40,37,105,32,98,121,116,101,115,41,10,0,0,0,0,79,110,108,121,32,83,85,66,84,73,84,76,69,95,65,83,83,32,116,121,112,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,92,78,0,0,0,0,0,0,116,111,111,32,102,101,119,32,99,111,100,101,115,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,105,122,101,0,0,0,0,116,114,117,101,104,100,0,0,102,102,95,99,111,109,98,105,110,101,95,102,114,97,109,101,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,115,116,114,104,0,0,0,0,117,110,107,110,111,119,110,32,115,116,114,101,97,109,32,116,121,112,101,32,37,88,10,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,10,0,0,0,0,0,110,111,116,32,109,106,112,101,103,45,98,32,40,98,97,100,32,102,111,117,114,99,99,41,10,0,0,0,0,0,0,0,100,101,106,117,100,100,101,114,0,0,0,0,0,0,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,10,0,0,0,0,0,0,123,37,42,100,125,123,37,42,91,48,49,50,51,52,53,54,55,56,57,93,125,37,99,0,112,107,116,46,115,105,122,101,32,33,61,32,100,115,95,112,97,99,107,101,116,95,115,105,122,101,32,42,32,100,115,95,115,112,97,110,32,40,37,100,32,37,100,32,37,100,41,10,0,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,111,114,32,105,110,99,111,109,112,108,101,116,101,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,0,0,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,97,102,105,102,111,0,0,0,109,97,99,101,54,0,0,0,108,105,98,97,118,99,111,100,101,99,47,108,122,119,101,110,99,46,99,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,108,105,98,97,118,99,111,100,101,99,47,108,112,99,46,99,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,70,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,0,122,108,105,98,0,0,0,0,116,98,0,0,0,0,0,0,99,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,0,66,108,111,99,107,32,115,105,122,101,32,61,32,37,105,10,0,0,0,0,0,0,0,0,70,114,97,109,101,32,114,101,102,101,114,101,110,99,101,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,10,0,118,105,100,101,111,32,115,105,122,101,32,37,100,32,105,110,118,97,108,105,100,10,0,0,97,115,101,116,116,98,0,0,79,110,108,121,32,103,114,97,121,115,99,97,108,101,32,97,110,100,32,82,71,66,50,52,47,66,71,82,50,52,32,105,109,97,103,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,105,110,118,97,108,105,100,32,105,100,32,37,100,10,0,0,117,99,104,0,0,0,0,0,115,116,101,114,101,111,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,74,112,101,103,50,48,48,48,32,99,111,100,101,115,116,114,101,97,109,32,97,116,111,109,46,10,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,78,117,109,98,101,114,32,111,102,32,97,116,116,97,99,107,115,47,100,101,99,97,121,115,32,98,105,103,103,101,114,32,116,104,97,110,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,46,10,0,0,0,0,0,0,0,58,109,105,110,95,104,97,114,100,95,99,111,109,112,61,37,102,0,0,0,0,0,0,0,86,66,0,0,0,0,0,0,101,110,100,10,0,0,0,0,97,50,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,112,105,99,116,117,114,101,32,104,101,97,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,54,54,77,105,99,104,105,103,97,110,0,117,115,101,32,77,80,69,71,32,113,117,97,110,116,105,122,101,114,115,32,105,110,115,116,101,97,100,32,111,102,32,72,46,50,54,51,0,0,0,0,100,101,99,111,100,101,32,112,114,111,98,108,101,109,32,111,110,32,102,114,97,109,101,32,37,100,44,32,64,32,98,108,111,99,107,32,40,37,100,44,32,37,100,41,10,0,0,0,66,97,100,32,72,50,54,51,32,105,100,10,0,0,0,0,116,120,100,0,0,0,0,0,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,99,111,108,111,114,32,112,108,97,110,101,115,33,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,110,117,109,95,77,66,115,32,109,105,115,109,97,116,99,104,32,37,100,32,37,100,32,37,100,32,37,100,10,0,0,0,82,101,97,100,32,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,37,100,10,0,0,0,0,0,0,0,115,45,62,102,114,97,109,101,95,108,105,115,116,45,62,110,98,95,102,114,97,109,101,115,32,62,32,48,0,0,0,0,105,110,112,117,116,32,98,117,102,102,101,114,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,41,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,105,109,103,99,111,110,118,101,114,116,46,99,0,115,101,116,32,102,114,97,109,101,32,115,105,122,101,32,40,87,120,72,32,111,114,32,97,98,98,114,101,118,105,97,116,105,111,110,41,0,0,0,0,97,115,101,110,100,99,109,100,0,0,0,0,0,0,0,0,105,97,99,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,72,117,102,102,109,97,110,32,100,101,99,111,100,101,32,101,114,114,111,114,46,10,0,0,102,102,118,104,117,102,102,0,99,117,114,118,101,0,0,0,102,102,118,104,117,102,102,0,78,111,116,104,105,110,103,32,116,111,32,101,99,104,111,32,45,32,109,105,115,115,105,110,103,32,100,101,108,97,121,32,115,97,109,112,108,101,115,46,10,0,0,0,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,83,107,105,112,112,101,100,32,83,85,70,70,73,88,32,83,69,73,32,37,100,10,0,0,90,101,114,111,32,114,101,102,115,32,105,110,32,116,104,101,32,102,114,97,109,101,32,82,80,83,46,10,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,39,37,100,39,32,112,114,111,118,105,100,101,100,10,0,0,0,0,0,0,0,68,101,99,111,100,105,110,103,32,86,80,83,10,0,0,0,51,50,48,120,50,52,48,0,115,101,116,32,116,104,101,32,116,101,114,109,105,110,97,108,32,112,116,115,32,118,97,108,117,101,0,0,0,0,0,0,68,101,99,111,100,101,100,32,102,114,97,109,101,32,119,105,116,104,32,80,79,67,32,37,100,46,10,0,0,0,0,0,114,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,52,112,114,101,100,46,99,0,0,0,114,117,108,101,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,119,104,105,99,104,32,102,114,97,109,101,115,32,116,111,32,100,101,105,110,116,101,114,108,97,99,101,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,52,100,115,112,46,99,0,0,0,0,117,110,107,110,111,119,110,32,83,69,73,32,116,121,112,101,32,37,100,10,0,0,0,0,104,47,50,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,52,95,114,101,102,115,46,99,0,0,111,112,101,110,99,108,0,0,100,105,114,32,118,97,108,117,101,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,51,32,97,114,101,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,116,104,101,32,112,97,115,115,116,104,114,111,117,103,104,32,111,112,116,105,111,110,32,105,110,115,116,101,97,100,10,0,0,0,115,101,112,97,114,97,116,101,32,99,111,108,111,114,32,112,108,97,110,101,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,99,101,110,116,101,114,95,109,105,120,95,108,101,118,101,108,0,0,0,0,0,0,0,0,99,97,98,97,99,32,100,101,99,111,100,101,32,111,102,32,113,115,99,97,108,101,32,100,105,102,102,32,102,97,105,108,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,115,101,108,101,99,116,0,0,111,117,116,32,111,102,32,114,97,110,103,101,32,105,110,116,114,97,32,99,104,114,111,109,97,32,112,114,101,100,32,109,111,100,101,32,97,116,32,37,100,32,37,100,10,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,54,54,0,116,104,105,115,32,99,111,100,101,99,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,114,117,110,99,97,116,101,100,32,98,105,116,115,116,114,101,97,109,115,10,0,0,0,0,0,0,0,104,50,54,49,32,101,110,99,111,100,101,114,0,0,0,0,115,105,122,101,0,0,0,0,109,112,101,103,95,113,117,97,110,116,0,0,0,0,0,0,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,103,115,109,95,109,115,0,0,115,101,116,32,111,117,116,112,117,116,32,104,101,105,103,104,116,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,86,46,70,108,97,115,104,32,80,84,88,32,105,109,97,103,101,0,0,0,0,0,0,0,99,97,110,110,111,116,32,100,101,99,111,100,101,32,102,114,97,109,101,32,119,105,116,104,111,117,116,32,107,101,121,102,114,97,109,101,10,0,0,0,111,117,116,112,117,116,0,0,37,100,120,37,100,32,105,109,97,103,101,32,97,116,32,112,111,115,32,40,37,100,59,37,100,41,32,91,97,114,101,97,58,37,100,120,37,100,93,10,0,0,0,0,0,0,0,0,87,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,111,102,32,105,110,112,117,116,32,118,105,100,101,111,115,32,109,117,115,116,32,98,101,32,115,97,109,101,46,10,0,80,97,99,107,101,116,32,116,121,112,101,58,32,37,115,10,0,0,0,0,0,0,0,0,103,55,50,54,108,101,0,0,79,110,108,121,32,56,48,48,48,72,122,32,115,97,109,112,108,101,32,114,97,116,101,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,73,110,112,117,116,32,97,114,101,97,32,37,100,58,37,100,58,37,100,58,37,100,32,110,111,116,32,119,105,116,104,105,110,32,116,104,101,32,112,97,100,100,101,100,32,97,114,101,97,32,48,58,48,58,37,100,58,37,100,32,111,114,32,122,101,114,111,45,115,105,122,101,100,10,0,0,0,0,0,0,79,110,108,121,32,109,111,110,111,32,116,114,97,99,107,115,32,97,114,101,32,97,108,108,111,119,101,100,46,10,0,0,103,55,50,50,32,100,101,99,111,100,101,114,0,0,0,0,115,0,0,0,0,0,0,0,70,114,97,109,101,32,115,104,111,117,108,100,32,104,97,118,101,32,97,116,32,108,101,97,115,116,32,49,50,32,98,121,116,101,115,44,32,103,111,116,32,37,100,32,105,110,115,116,101,97,100,10,0,0,0,0,112,101,114,109,115,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,111,118,101,114,108,97,121,46,99,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,102,108,118,32,101,110,99,111,100,101,114,0,0,0,0,0,37,99,32,101,115,99,95,116,121,112,101,58,37,100,44,32,113,112,58,37,100,32,110,117,109,58,37,100,10,0,0,0,85,110,107,110,111,119,110,32,70,76,67,32,102,111,114,109,97,116,44,32,109,121,32,115,99,105,101,110,99,101,32,99,97,110,110,111,116,32,101,120,112,108,97,105,110,32,104,111,119,32,116,104,105,115,32,104,97,112,112,101,110,101,100,46,10,0,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,99,48,95,102,108,97,103,115,0,0,0,0,0,0,0,0,102,108,97,115,104,115,118,50,0,0,0,0,0,0,0,0,80,97,100,100,105,110,103,32,97,116,32,116,104,101,32,98,111,116,116,111,109,32,40,37,100,112,120,41,32,111,102,32,116,104,101,32,72,97,108,100,32,67,76,85,84,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,66,97,100,32,102,114,97,109,101,32,99,111,117,110,116,10,0,0,0,0,0,0,0,0,115,101,116,32,89,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,127,70,76,65,67,0,0,0,97,99,51,0,0,0,0,0,102,105,110,100,95,110,101,119,95,104,101,97,100,101,114,115,32,99,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,70,76,65,67,32,104,101,97,100,101,114,10,0,99,115,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,115,105,122,101,32,99,111,100,101,32,40,37,100,41,10,0,0,114,101,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,10,0,0,84,104,105,115,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,105,115,32,108,105,109,105,116,101,100,32,116,111,32,37,100,32,99,104,97,110,110,101,108,115,46,10,0,97,105,110,116,101,114,108,101,97,118,101,0,0,0,0,0,83,97,116,117,114,97,116,105,111,110,32,118,97,108,117,101,32,110,111,116,32,105,110,32,114,97,110,103,101,32,91,37,100,44,37,100,93,58,32,99,108,105,112,112,105,110,103,32,118,97,108,117,101,32,116,111,32,37,48,46,49,102,10,0,37,108,108,117,32,37,108,108,117,32,0,0,0,0,0,0,97,97,115,99,0,0,0,0,67,97,110,110,111,116,32,100,101,99,111,100,101,32,110,111,110,45,107,101,121,102,114,97,109,101,32,119,105,116,104,111,117,116,32,118,97,108,105,100,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,0,115,101,116,32,119,97,118,101,102,111,114,109,32,109,111,100,101,0,0,0,0,0,0,0,84,111,111,32,115,104,111,114,116,32,104,101,97,100,101,114,32,116,111,32,112,97,114,115,101,10,0,0,0,0,0,0,98,105,116,114,97,116,101,32,99,97,110,110,111,116,32,98,101,32,100,101,116,101,114,109,105,110,101,100,46,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,102,114,97,109,101,32,100,97,116,97,10,0,0,0,0,0,0,0,0,83,101,116,32,102,105,114,115,116,32,112,116,115,32,116,111,32,40,105,110,58,37,108,108,100,32,111,117,116,58,37,108,108,100,41,10,0,0,0,0,83,107,105,112,112,105,110,103,32,102,114,97,109,101,10,0,116,114,117,110,99,97,116,101,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,73,110,112,117,116,32,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,116,114,117,110,99,97,116,101,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,98,103,114,52,95,98,121,116,101,0,0,0,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,66,105,115,113,117,101,0,0,85,110,99,111,109,112,114,101,115,115,32,102,97,105,108,101,100,33,10,0,0,0,0,0,97,99,32,98,105,116,115,116,114,101,97,109,32,111,118,101,114,102,108,111,119,10,0,0,48,120,37,108,108,120,0,0,66,105,116,109,97,112,32,115,117,98,116,105,116,108,101,32,114,101,113,117,105,114,101,100,10,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,115,101,99,111,110,100,115,32,111,102,32,116,104,101,32,98,101,103,105,110,110,105,110,103,32,111,102,32,116,104,101,32,101,102,102,101,99,116,46,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,109,109,97,110,100,32,111,102,102,115,101,116,10,0,109,97,120,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,100,118,32,102,114,97,109,101,32,112,114,111,102,105,108,101,10,0,0,0,0,0,0,0,0,70,105,108,116,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,0,115,101,116,32,97,108,112,104,97,32,112,108,97,110,101,0,70,105,101,108,100,32,100,97,116,97,32,115,105,122,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,66,67,0,0,0,0,0,0,37,115,32,115,99,97,108,101,114,44,32,102,114,111,109,32,37,115,32,116,111,32,37,115,37,115,32,0,0,0,0,0,112,114,105,110,116,32,105,110,102,111,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,100,115,105,99,105,110,97,117,100,105,111,0,0,0,0,0,49,0,0,0,0,0,0,0,80,97,99,107,101,116,32,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2179720);
/* memory initializer */ allocate([111,111,32,115,109,97,108,108,32,102,111,114,32,68,80,88,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,0,114,111,113,95,100,112,99,109,0,0,0,0,0,0,0,0,114,97,116,101,0,0,0,0,92,114,37,49,50,55,91,94,92,125,93,37,49,91,92,125,93,37,110,0,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,53,56,0,112,105,99,116,117,114,101,32,99,111,117,108,100,32,110,111,116,32,102,105,116,32,114,97,116,101,99,111,110,116,114,111,108,32,99,111,110,115,116,114,97,105,110,116,115,44,32,105,110,99,114,101,97,115,101,32,113,109,97,120,10,0,0,0,111,114,105,103,105,110,97,108,32,105,109,97,103,101,32,97,116,32,98,108,97,110,107,32,108,111,99,97,116,105,111,110,115,0,0,0,0,0,0,0,102,114,97,109,101,32,115,105,122,101,32,99,104,97,110,103,101,100,58,32,37,100,120,37,100,32,45,62,32,37,100,120,37,100,10,0,0,0,0,0,66,117,102,102,101,114,32,118,105,100,101,111,32,102,114,97,109,101,115,44,32,97,110,100,32,109,97,107,101,32,116,104,101,109,32,97,99,99,101,115,115,105,98,108,101,32,116,111,32,116,104,101,32,102,105,108,116,101,114,99,104,97,105,110,46,0,0,0,0,0,0,0,98,108,111,99,107,95,97,108,105,103,110,0,0,0,0,0,121,117,118,52,50,50,112,0,65,68,80,67,77,32,73,77,65,32,65,77,86,0,0,0,115,109,97,108,108,0,0,0,115,109,97,108,108,0,0,0,115,101,116,32,116,104,101,32,115,105,122,101,32,111,102,32,116,104,101,32,121,45,97,120,105,115,32,98,108,111,99,107,115,32,117,115,101,100,32,100,117,114,105,110,103,32,109,101,116,114,105,99,32,99,97,108,99,117,108,97,116,105,111,110,115,0,0,0,0,0,0,0,68,97,116,97,32,117,110,105,116,32,119,105,116,104,32,115,105,122,101,32,37,100,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,105,110,112,117,116,32,98,117,102,102,101,114,44,32,100,105,115,99,97,114,100,105,110,103,10,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,10,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,105,99,116,117,114,101,32,99,111,100,105,110,103,32,109,111,100,101,32,37,100,10,0,0,0,0,0,83,66,82,32,114,101,115,101,116,32,102,97,105,108,101,100,46,32,83,119,105,116,99,104,105,110,103,32,83,66,82,32,116,111,32,112,117,114,101,32,117,112,115,97,109,112,108,105,110,103,32,109,111,100,101,46,10,0,0,0,0,0,0,0,112,116,120,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,37,115,32,99,104,117,110,107,10,0,0,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,108,101,110,103,116,104,58,37,100,10,0,0,0,0,0,0,0,84,111,111,32,115,109,97,108,108,32,105,110,112,117,116,32,98,117,102,102,101,114,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,111,108,111,114,32,99,97,99,104,101,32,110,111,116,32,102,111,117,110,100,10,0,0,78,111,32,98,108,111,99,107,32,119,105,116,104,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,119,101,105,103,104,116,115,10,0,0,0,0,86,81,65,32,86,101,114,115,105,111,110,32,37,105,0,0,48,46,53,47,48,46,52,0,73,110,118,97,108,105,100,32,122,101,114,111,32,114,117,110,32,111,102,32,37,100,32,119,105,116,104,32,37,100,32,99,111,101,102,102,115,32,108,101,102,116,10,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,109,111,100,101,115,41,46,32,10,0,0,78,111,116,32,97,32,118,97,108,105,100,32,68,67,65,32,102,114,97,109,101,10,0,0,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,111,102,32,37,100,10,0,0,99,121,117,118,0,0,0,0,101,110,100,32,109,98,32,121,32,37,100,32,37,100,32,105,110,118,97,108,105,100,10,0,85,110,107,110,111,119,110,32,104,101,108,112,32,111,112,116,105,111,110,32,39,37,115,39,46,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,111,111,32,98,105,103,32,111,114,32,110,111,110,32,112,111,115,105,116,105,118,101,32,115,105,122,101,32,102,111,114,32,119,105,100,116,104,32,39,37,100,39,32,111,114,32,104,101,105,103,104,116,32,39,37,100,39,10,0,0,0,0,0,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,115,109,97,108,108,10,0,0,108,105,98,97,118,99,111,100,101,99,47,118,99,49,46,99,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,33,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,85,116,32,86,105,100,101,111,32,70,79,85,82,67,67,32,112,114,111,118,105,100,101,100,32,40,37,48,56,88,41,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,103,114,101,101,110,32,103,97,105,110,32,102,111,114,32,116,104,101,32,98,108,117,101,32,99,104,97,110,110,101,108,0,68,101,97,108,108,111,99,97,116,105,110,103,32,109,101,109,111,114,121,46,10,0,0,0,83,112,101,99,105,102,105,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,37,115,32,105,115,32,105,110,118,97,108,105,100,32,111,114,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,80,114,111,106,76,105,110,101,97,114,85,110,105,116,115,71,101,111,75,101,121,0,0,0,99,51,95,109,111,100,101,0,49,46,50,46,53,0,0,0,83,69,81,72,0,0,0,0,32,102,97,99,101,61,34,37,115,34,0,0,0,0,0,0,102,97,99,101,61,0,0,0,83,107,105,112,112,105,110,103,32,84,89,80,69,32,116,114,101,101,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,69,120,112,101,99,116,101,100,32,116,111,32,114,101,97,100,32,37,100,32,83,66,82,32,98,121,116,101,115,32,97,99,116,117,97,108,108,121,32,114,101,97,100,32,37,100,46,10,0,0,0,0,0,0,0,0,77,86,32,105,115,32,105,110,118,97,108,105,100,32,10,0,110,117,109,58,37,53,100,32,120,58,37,50,100,32,121,58,37,50,100,32,116,121,112,101,58,37,100,32,113,115,99,97,108,101,58,37,50,100,32,114,110,100,58,37,100,10,0,0,118,115,117,98,0,0,0,0,98,105,116,115,50,113,112,0,102,114,109,97,81,68,77,0,104,113,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,77,97,120,105,109,117,109,32,100,117,114,97,116,105,111,110,32,111,102,32,116,104,101,32,111,117,116,112,117,116,32,105,110,32,115,101,99,111,110,100,115,0,0,0,0,0,0,0,116,109,99,100,0,0,0,0,102,102,98,117,102,102,101,114,115,105,110,107,0,0,0,0,76,111,111,112,32,119,105,116,104,32,115,101,118,101,114,97,108,32,115,116,114,101,97,109,115,32,105,115,32,99,117,114,114,101,110,116,108,121,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,46,99,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,80,79,83,0,0,0,0,0,107,101,121,102,114,97,109,101,32,105,110,116,101,114,118,97,108,32,116,111,111,32,108,97,114,103,101,33,44,32,114,101,100,117,99,105,110,103,32,105,116,32,102,114,111,109,32,37,100,32,116,111,32,37,100,10,0,0,0,0,0,0,0,0,97,108,108,111,99,97,116,101,32,100,117,109,109,121,32,108,97,115,116,32,112,105,99,116,117,114,101,32,102,111,114,32,102,105,101,108,100,32,98,97,115,101,100,32,102,105,114,115,116,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,117,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,109,112,118,95,102,108,97,103,115,0,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,115,101,113,32,101,120,116,32,97,102,116,101,114,32,37,88,10,0,0,0,0,0,0,84,111,116,97,108,32,102,105,108,116,101,114,32,111,114,100,101,114,115,32,116,111,111,32,104,105,103,104,46,10,0,0,115,45,62,110,98,95,99,111,109,112,111,110,101,110,116,115,32,61,61,32,52,0,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,52,58,49,58,49,46,10,0,0,0,0,0,0,0,97,97,99,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,109,97,114,107,101,114,32,48,120,37,46,52,88,32,97,116,32,112,111,115,32,48,120,37,88,10,0,0,123,92,104,125,0,0,0,0,84,111,111,32,108,97,114,103,101,32,116,114,97,110,115,102,111,114,109,10,0,0,0,0,77,105,115,115,105,110,103,32,116,101,114,109,105,110,97,116,111,114,32,111,114,32,101,120,116,114,97,110,101,111,117,115,32,100,97,116,97,32,102,111,117,110,100,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,105,110,116,101,114,118,97,108,32,35,37,100,10,0,98,32,99,98,112,121,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,65,108,105,103,110,109,101,110,116,32,98,105,116,115,32,97,114,101,32,110,111,116,32,122,101,114,111,33,10,0,0,0,98,97,110,100,45,62,115,99,97,110,32,110,111,116,32,115,101,116,10,0,0,0,0,0,73,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,115,58,32,37,100,32,120,32,37,100,33,10,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,102,111,114,32,108,111,103,50,95,109,105,110,95,116,98,95,115,105,122,101,0,0,0,0,0,0,69,114,114,111,114,32,99,111,110,115,116,114,117,99,116,105,110,103,32,116,104,101,32,102,114,97,109,101,32,82,80,83,46,10,0,0,0,0,0,0,83,0,0,0,0,0,0,0,117,115,101,114,32,100,97,116,97,58,34,37,115,34,10,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,32,40,37,100,43,37,100,41,32,101,120,99,101,101,100,115,32,109,97,120,32,40,37,100,59,32,112,114,111,98,97,98,108,121,32,99,111,114,114,117,112,116,32,105,110,112,117,116,41,44,32,100,105,115,99,97,114,100,105,110,103,32,111,110,101,10,0,0,0,0,69,114,114,111,114,32,103,101,116,116,105,110,103,32,111,117,116,112,117,116,32,112,97,99,107,101,116,10,0,0,0,0,112,112,115,95,105,100,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,112,105,99,115,32,60,61,32,49,54,0,0,0,0,0,0,73,110,118,97,108,105,100,32,73,78,70,79,32,104,101,97,100,101,114,32,111,102,102,115,101,116,58,32,48,120,37,48,56,88,32,105,115,32,116,111,111,32,108,97,114,103,101,46,10,0,0,0,0,0,0,0,99,108,106,114,32,101,110,99,111,100,101,114,0,0,0,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,70,76,67,47,70,76,88,32,100,101,112,116,104,32,111,102,32,37,100,32,66,112,112,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,105,109,97,103,101,32,100,97,116,97,10,0,0,0,0,0,115,107,105,112,112,105,110,103,32,122,101,114,111,32,104,101,105,103,104,116,32,115,116,114,105,112,32,37,105,32,111,102,32,37,105,10,0,0,0,0,101,115,0,0,0,0,0,0,105,108,108,101,103,97,108,32,114,101,115,105,100,117,97,108,32,99,111,100,105,110,103,32,109,101,116,104,111,100,32,37,100,10,0,0,0,0,0,0,99,105,110,101,112,97,107,95,100,101,99,111,100,101,32,102,97,105,108,101,100,10,0,0,115,45,62,118,101,114,115,105,111,110,32,62,61,32,50,0,115,108,105,99,101,32,99,111,117,110,116,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,80,105,120,101,108,32,102,111,114,109,97,116,32,48,120,37,48,120,0,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,104,101,97,100,101,114,10,0,0,0,0,0,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,100,101,99,111,100,101,114,10,0,0,0,100,115,117,114,95,109,111,100,101,0,0,0,0,0,0,0,104,101,105,103,104,116,0,0,110,111,32,102,114,97,109,101,32,100,101,99,111,100,101,100,10,0,0,0,0,0,0,0,98,108,111,99,107,32,111,118,101,114,108,97,112,32,37,100,32,37,100,32,37,100,32,37,100,10,0,0,0,0,0,0,77,97,110,100,97,116,111,114,121,32,99,117,115,116,111,109,32,108,111,119,32,100,101,108,97,121,32,109,97,116,114,105,120,32,109,105,115,115,105,110,103,32,102,111,114,32,100,101,112,116,104,32,37,100,10,0,78,111,116,32,97,32,66,82,101,110,100,101,114,32,80,73,88,32,102,105,108,101,10,0,68,84,83,45,88,66,82,58,32,83,89,78,67,32,69,82,82,79,82,10,0,0,0,0,100,105,102,102,101,114,101,110,116,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,99,104,97,110,110,101,108,33,10,0,0,0,0,0,0,0,37,100,32,98,117,102,102,101,114,115,32,113,117,101,117,101,100,32,105,110,32,37,115,44,32,115,111,109,101,116,104,105,110,103,32,109,97,121,32,98,101,32,119,114,111,110,103,46,10,0,0,0,0,0,0,0,71,67,83,69,95,66,101,115,115,101,108,78,97,109,105,98,105,97,0,0,0,0,0,0,98,109,118,95,97,117,100,105,111,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,104,97,115,95,98,95,102,114,97,109,101,115,0,0,0,0,98,117,102,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,41,10,0,0,0,0,0,0,0,0,83,117,110,112,108,117,115,32,74,80,69,71,32,40,83,80,53,88,41,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,105,116,115,116,114,101,97,109,46,99,0,0,113,117,101,114,121,95,102,111,114,109,97,116,115,58,32,37,100,32,113,117,101,114,105,101,100,44,32,37,100,32,109,101,114,103,101,100,44,32,37,100,32,97,108,114,101,97,100,121,32,100,111,110,101,44,32,37,100,32,100,101,108,97,121,101,100,10,0,0,0,0,0,0,66,101,116,104,101,115,100,97,32,86,73,68,32,118,105,100,101,111,0,0,0,0,0,0,120,98,105,110,0,0,0,0,98,105,110,107,97,117,100,105,111,95,100,99,116,0,0,0,109,97,120,95,115,97,109,112,108,101,115,0,0,0,0,0,82,117,110,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,98,97,99,107,103,114,111,117,110,100,0,0,0,0,0,0,80,97,108,101,116,116,101,32,105,115,32,116,111,111,32,108,97,114,103,101,46,10,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,112,97,108,101,116,116,101,10,0,0,83,107,97,0,0,0,0,0,79,110,108,121,32,55,50,48,120,52,56,54,32,97,110,100,32,55,50,48,120,53,55,54,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,97,112,112,108,121,105,110,103,32,111,112,116,105,111,110,115,32,116,111,32,116,104,101,32,102,105,108,116,101,114,46,10,0,0,100,105,115,99,0,0,0,0,65,80,82,71,65,80,82,71,48,48,48,49,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,52,50,50,112,57,0,0,0,100,101,99,105,109,97,116,101,0,0,0,0,0,0,0,0,115,101,116,32,102,114,97,109,101,32,114,97,116,101,32,40,72,122,32,118,97,108,117,101,44,32,102,114,97,99,116,105,111,110,32,111,114,32,97,98,98,114,101,118,105,97,116,105,111,110,41,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,118,112,97,99,107,101,116,46,99,0,0,0,69,79,70,32,111,110,32,115,105,110,107,32,108,105,110,107,32,37,115,58,37,115,46,10,0,0,0,0,0,0,0,0,103,111,116,32,97,32,98,117,102,102,101,114,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,119,104,101,110,32,37,100,32,119,101,114,101,32,101,120,112,101,99,116,101,100,10,0,0,0,0,0,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,10,0,0,0,0,70,114,97,109,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,98,121,116,101,115,41,46,32,84,114,117,110,99,97,116,101,100,32,102,105,108,101,63,10,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,116,111,32,100,101,99,111,100,101,33,10,0,0,0,0,0,97,115,118,50,0,0,0,0,97,115,118,50,0,0,0,0,97,115,115,0,0,0,0,0,97,115,115,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,114,103,115,32,111,118,101,114,102,108,111,119,32,40,37,105,41,10,0,0,0,0,0,85,110,107,110,111,119,110,32,114,101,99,111,114,100,32,116,121,112,101,0,0,0,0,0,73,110,118,97,108,105,100,32,109,111,100,101,32,37,100,10,0,0,0,0,0,0,0,0,67,111,114,114,117,112,116,32,98,105,116,115,116,114,101,97,109,10,0,0,0,0,0,0,82,101,97,100,105,110,103,32,102,114,97,109,101,32,100,97,116,97,32,102,97,105,108,101,100,46,32,83,107,105,112,112,105,110,103,32,82,65,32,117,110,105,116,46,10,0,0,0,102,112,115,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,114,102,99,50,49,57,48,0,97,97,99,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,88,45,67,114,101,97,116,105,111,110,84,105,109,101,0,0,80,65,82,84,95,78,85,77,66,69,82,0,0,0,0,0,99,111,109,109,101,110,116,0,97,54,52,109,117,108,116,105,0,0,0,0,0,0,0,0,67,111,117,110,116,114,121,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,56,115,118,120,95,102,105,98,0,0,0,0,0,0,0,0,87,77,47,65,108,98,117,109,84,105,116,108,101,0,0,0,56,98,112,115,0,0,0,0,97,117,100,105,111,47,97,105,102,102,0,0,0,0,0,0,73,68,51,0,0,0,0,0,71,67,83,69,95,66,101,115,115,101,108,77,111,100,105,102,105,101,100,0,0,0,0,0,67,104,97,110,110,101,108,115,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,0,0,0,0,99,111,110,115,105,100,101,114,32,116,104,105,110,103,115,32,116,104,97,116,32,97,32,115,97,110,101,32,101,110,99,111,100,101,114,32,115,104,111,117,108,100,32,110,111,116,32,100,111,32,97,115,32,97,110,32,101,114,114,111,114,0,0,0,97,117,100,105,111,47,97,97,99,0,0,0,0,0,0,0,97,100,112,44,100,116,107,0,83,97,109,112,108,101,32,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,77,101,100,105,97,32,116,121,112,101,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,116,104,101,32,39,37,115,39,32,102,105,108,116,101,114,32,111,117,116,112,117,116,32,112,97,100,32,37,100,32,40,37,115,41,32,97,110,100,32,116,104,101,32,39,37,115,39,32,102,105,108,116,101,114,32,105,110,112,117,116,32,112,97,100,32,37,100,32,40,37,115,41,10,0,0,0,101,97,99,51,0,0,0,0,97,54,52,44,32,65,54,52,0,0,0,0,0,0,0,0,99,104,117,110,107,32,108,97,114,103,101,114,32,116,104,97,110,32,97,114,114,97,121,32,37,100,62,37,100,10,0,0,98,101,116,104,115,111,102,116,118,105,100,0,0,0,0,0,121,52,109,0,0,0,0,0,89,79,80,32,104,97,115,32,105,110,118,97,108,105,100,32,104,101,97,100,101,114,10,0,85,110,101,120,112,101,99,116,101,100,32,99,111,100,101,99,32,40,116,97,103,32,48,120,48,52,37,120,59,32,105,100,32,37,100,41,0,0,0,0,114,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,87,77,47,69,110,99,111,100,105,110,103,84,105,109,101,0,87,101,98,86,84,84,32,100,101,115,99,114,105,112,116,105,111,110,115,32,107,105,110,100,0,0,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,52,120,109,0,0,0,0,0,70,111,117,110,100,32,83,77,86,32,100,97,116,97,10,0,99,111,110,100,117,99,116,111,114,0,0,0,0,0,0,0,48,49,50,118,0,0,0,0,70,80,83,0,0,0,0,0,122,109,98,118,0,0,0,0,115,99,97,108,101,0,0,0,122,109,98,118,0,0,0,0,105,110,100,101,120,32,61,61,32,48,32,124,124,32,105,101,91,45,49,93,46,116,105,109,101,115,116,97,109,112,32,60,32,116,105,109,101,115,116,97,109,112,0,0,0,0,0,0,122,101,114,111,99,111,100,101,99,0,0,0,0,0,0,0,115,112,101,99,58,37,115,32,98,115,102,115,58,37,115,32,109,97,116,99,104,101,115,32,115,116,114,101,97,109,32,37,100,32,111,102,32,115,108,97,118,101,32,111,117,116,112,117,116,32,39,37,115,39,10,0,101,110,97,98,108,101,32,117,110,115,97,102,101,32,109,111,100,101,0,0,0,0,0,0,121,117,118,52,0,0,0,0,71,67,83,69,95,66,101,115,115,101,108,49,56,52,49,0,97,103,103,114,101,115,115,105,118,101,0,0,0,0,0,0,121,117,118,52,0,0,0,0,73,110,116,101,114,112,108,97,121,32,67,57,51,0,0,0,98,101,0,0,0,0,0,0,121,111,112,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,118,105,100,101,111,32,102,114,97,109,101,115,32,116,111,32,114,101,99,111,114,100,0,0,0,0,0,0,0,0,109,107,100,105,114,32,102,97,105,108,101,100,10,0,0,0,121,52,49,112,0,0,0,0,121,52,49,112,0,0,0,0,98,99,0,0,0,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,95,101,110,116,114,121,95,112,114,101,102,105,120,0,0,0,0,0,0,0,120,97,110,95,119,99,52,0,115,114,116,112,0,0,0,0,100,99,116,100,110,111,105,122,0,0,0,0,0,0,0,0,78,79,87,0,0,0,0,0,120,119,100,0,0,0,0,0,68,111,110,39,116,32,115,101,110,100,32,82,84,67,80,32,115,101,110,100,101,114,32,114,101,112,111,114,116,115,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,37,100,32,98,121,116,101,115,10,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,0,120,119,100,0,0,0,0,0,120,115,117,98,0,0,0,0,97,117,100,105,111,47,120,45,101,97,99,51,0,0,0,0,109,106,112,101,103,32,100,101,109,117,120,101,114,0,0,0,120,115,117,98,0,0,0,0,71,67,83,69,95,65,117,115,116,114,97,108,105,97,110,78,97,116,105,111,110,97,108,83,112,104,101,114,111,105,100,0,120,108,0,0,0,0,0,0,99,111,110,115,105,100,101,114,32,97,108,108,32,115,112,101,99,32,110,111,110,32,99,111,109,112,108,105,97,110,99,105,101,115,32,97,115,32,101,114,114,111,114,115,0,0,0,0,115,119,0,0,0,0,0,0,99,57,51,0,0,0,0,0,120,102,97,99,101,0,0,0,115,119,0,0,0,0,0,0,120,102,97,99,101,0,0,0,118,102,114,97,109,101,115,0,120,98,109,0,0,0,0,0,105,103,110,111,114,101,32,100,116,115,0,0,0,0,0,0,73,86,0,0,0,0,0,0,120,98,109,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,105,100,32,105,110,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,115,116,112,115,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,120,97,110,95,119,99,51,0,67,111,100,101,99,83,112,101,99,105,102,105,99,83,105,100,101,37,108,108,100,0,0,0,119,115,95,115,110,100,49,0,37,42,115,32,37,42,115,32,37,108,108,100,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,119,110,118,49,0,0,0,0,110,111,32,101,115,115,101,110,99,101,10,0,0,0,0,0,72,69,73,71,72,84,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,112,101,99,116,32,114,97,116,105,111,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,109,117,120,101,114,32,40,37,100,47,37,100,41,32,97,110,100,32,101,110,99,111,100,101,114,32,108,97,121,101,114,32,40,37,100,47,37,100,41,10,0,0,115,101,114,118,105,99,101,95,112,114,111,118,105,100,101,114,0,0,0,0,0,0,0,0,71,67,83,69,95,65,105,114,121,77,111,100,105,102,105,101,100,49,56,52,57,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,111,109,112,108,105,97,110,116,0,0,0,0,0,0,0,73,55,58,37,88,47,10,0,108,105,98,97,118,102,111,114,109,97,116,47,109,112,101,103,101,110,99,46,99,0,0,0,83,71,73,32,82,76,69,32,56,45,98,105,116,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,105,110,32,87,77,86,50,32,97,98,116,10,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,97,116,105,111,32,111,102,32,101,114,114,111,114,115,32,40,48,46,48,58,32,110,111,32,101,114,114,111,114,115,44,32,49,46,48,58,32,49,48,48,37,32,101,114,114,111,114,115,41,32,97,98,111,118,101,32,119,104,105,99,104,32,102,102,109,112,101,103,32,114,101,116,117,114,110,115,32,97,110,32,101,114,114,111,114,32,105,110,115,116,101,97,100,32,111,102,32,115,117,99,99,101,115,115,46,0,0,0,0,0,0,119,109,97,118,111,105,99,101,0,0,0,0,0,0,0,0,115,116,115,115,0,0,0,0,111,118,101,114,114,101,97,100,32,101,110,100,32,111,102,32,97,116,111,109,32,39,37,46,52,115,39,32,98,121,32,37,108,108,100,32,98,121,116,101,115,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,115,112,97,99,101,32,114,101,115,101,114,118,101,100,32,102,111,114,32,99,117,101,115,58,32,37,100,32,40,110,101,101,100,101,100,58,32,37,108,108,100,41,46,10,0,0,0,0,0,0,0,119,109,97,112,114,111,0,0,73,110,118,97,108,105,100,32,108,101,110,103,116,104,32,48,120,37,108,108,120,32,62,32,48,120,37,108,108,120,32,102,111,114,32,115,121,110,116,97,120,32,101,108,101,109,101,110,116,32,37,105,10,0,0,0,13,10,0,0,0,0,0,0,37,115,32,101,110,99,111,100,105,110,103,32,102,97,105,108,101,100,10,0,0,0,0,0,71,67,83,69,95,65,105,114,121,49,56,51,48,0,0,0,99,111,110,115,105,100,101,114,32,116,104,105,110,103,115,32,116,104,97,116,32,118,105,111,108,97,116,101,32,116,104,101,32,115,112,101,99,44,32,97,114,101,32,102,97,115,116,32,116,111,32,99,104,101,99,107,32,97,110,100,32,104,97,118,101,32,110,111,116,32,98,101,101,110,32,115,101,101,110,32,105,110,32,116,104,101,32,119,105,108,100,32,97,115,32,101,114,114,111,114,115,0,0,0,115,116,114,102,116,105,109,101,0,0,0,0,0,0,0,0,115,103,105,114,108,101,0,0,115,116,97,114,116,95,110,117,109,98,101,114,0,0,0,0,114,97,119,0,0,0,0,0,119,109,97,108,111,115,115,108,101,115,115,0,0,0,0,0,109,97,120,105,109,117,109,32,101,114,114,111,114,32,114,97,116,101,0,0,0,0,0,0,84,80,79,83,0,0,0,0,115,101,116,32,115,101,103,109,101,110,116,32,108,101,110,103,116,104,32,105,110,32,115,101,99,111,110,100,115,0,0,0,119,109,97,118,49,0,0,0,105,118,0,0,0,0,0,0,37,115,47,115,116,114,101,97,109,37,100,83,101,103,49,45,70,114,97,103,37,100,0,0,117,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,116,105,109,101,99,111,100,101,44,32,115,121,110,116,97,120,58,32,104,104,58,109,109,58,115,115,91,58,59,46,93,102,102,10,0,0,0,0,0,0,85,77,70,32,112,97,99,107,101,116,32,109,105,115,115,105,110,103,10,0,0,0,0,0,119,109,97,118,49,0,0,0,70,76,86,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,44,32,99,104,111,111,115,101,32,102,114,111,109,32,40,52,52,49,48,48,44,32,50,50,48,53,48,44,32,49,49,48,50,53,41,10,0,98,121,116,101,95,111,102,102,115,101,116,95,98,105,116,115,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,97,117,100,105,111,115,97,109,112,108,101,115,105,122,101,0,114,101,118,105,115,105,111,110,50,32,40,101,108,101,109,101,110,116,32,48,120,65,48,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,119,101,98,118,116,116,0,0,71,67,83,95,78,68,71,95,80,97,114,105,115,0,0,0,99,97,114,101,102,117,108,0,83,71,73,32,105,109,97,103,101,0,0,0,0,0,0,0,115,101,116,32,115,105,109,117,108,97,116,101,100,32,108,105,110,101,32,115,112,101,101,100,32,40,98,121,116,101,115,32,112,101,114,32,115,101,99,111,110,100,41,0,0,0,0,0,109,97,120,95,101,114,114,111,114,95,114,97,116,101,0,0,119,101,98,112,0,0,0,0,99,114,97,122,121,32,115,116,97,114,116,32,116,105,109,101,44,32,105,97,109,32,115,99,97,114,101,100,44,32,103,105,118,105,110,103,32,117,112,10,0,0,0,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,109,115,32,102,97,114,116,10,0,0,0,0,0,119,97,118,112,97,99,107,0,116,0,0,0,0,0,0,0,105,99,108,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,111,102,32,116,104,101,32,111,117,116,112,117,116,32,115,116,114,101,97,109,46,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,97,115,121,110,99,61,37,100,0,0,0,0,0,0,0,0,119,97,118,112,97,99,107,0,97,49,0,0,0,0,0,0,112,114,105,110,116,32,116,105,109,101,115,116,97,109,112,32,100,101,98,117,103,103,105,110,103,32,105,110,102,111,0,0,71,67,83,95,65,84,70,95,80,97,114,105,115,0,0,0,97,98,111,114,116,32,100,101,99,111,100,105,110,103,32,111,110,32,109,105,110,111,114,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,0,115,103,105,0,0,0,0,0,100,101,102,97,117,108,116,0,118,113,97,118,105,100,101,111,0,0,0,0,0,0,0,0,105,110,112,117,116,115,58,37,100,32,102,109,116,58,37,115,32,115,114,97,116,101,58,37,100,32,99,108,58,37,115,10,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,118,97,108,117,101,32,39,37,115,39,32,102,111,114,32,111,112,116,105,111,110,32,39,37,115,39,58,32,37,115,10,0,0,0,100,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,115,97,109,101,0,0,0,0,118,112,57,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,101,110,100,95,112,116,115,0,82,97,110,32,111,117,116,32,111,102,32,102,114,101,101,32,102,114,97,109,101,115,33,10,0,0,0,0,0,0,0,0,50,53,0,0,0,0,0,0,115,0,0,0,0,0,0,0,100,101,105,110,116,0,0,0,118,112,54,0,0,0,0,0,115,101,116,32,99,105,114,99,108,101,32,99,101,110,116,101,114,32,112,111,115,105,116,105,111,110,32,111,110,32,121,45,97,120,105,115,0,0,0,0,99,97,0,0,0,0,0,0,100,101,102,97,117,108,116,0,84,66,58,32,37,100,47,37,100,32,45,62,32,37,100,47,37,100,10,0,0,0,0,0,113,104,100,0,0,0,0,0,100,101,98,117,103,95,116,115,0,0,0,0,0,0,0,0,71,67,83,95,66,97,116,97,118,105,97,95,74,97,107,97,114,116,97,0,0,0,0,0,115,101,116,32,105,110,116,101,114,108,97,99,105,110,103,0,101,120,112,108,111,100,101,0,115,101,116,32,111,117,116,112,117,116,32,119,105,100,116,104,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,84,72,80,32,118,105,100,101,111,0,0,0,0,0,114,101,102,101,114,101,110,99,101,0,0,0,0,0,0,0,119,58,37,100,32,104,58,37,100,32,45,62,32,119,58,37,100,32,104,58,37,100,32,120,58,37,100,32,121,58,37,100,32,99,111,108,111,114,58,48,120,37,48,50,88,37,48,50,88,37,48,50,88,37,48,50,88,10,0,0,0,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,105,110,112,117,116,32,102,105,108,101,115,58,32,0,0,0,0,0,92,120,37,48,50,120,0,0,65,108,112,104,97,32,114,101,99,111,110,102,105,103,117,114,97,116,105,111,110,10,0,0,48,0,0,0,0,0,0,0,118,112,53,0,0,0,0,0,99,48,115,0,0,0,0,0,80,97,100,100,105,110,103,32,111,110,32,116,104,101,32,114,105,103,104,116,32,40,37,100,112,120,41,32,111,102,32,116,104,101,32,72,97,108,100,32,67,76,85,84,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,121,0,0,0,0,0,0,0,115,119,97,112,32,99,104,114,111,109,97,32,102,105,101,108,100,115,0,0,0,0,0,0,100,101,102,97,117,108,116,0,119,97,118,101,102,111,114,109,95,109,111,100,101,0,0,0,100,101,102,97,117,108,116,0,116,104,101,111,114,97,0,0,115,112,101,99,105,102,121,32,116,104,101,32,97,115,115,117,109,101,100,32,102,105,101,108,100,32,111,114,100,101,114,0,98,103,114,52,0,0,0,0,66,101,105,103,101,0,0,0,48,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,0,0,0,0,0,0,115,116,97,114,116,95,116,105,109,101,0,0,0,0,0,0,109,111,100,0,0,0,0,0,70,73,76,84,69,82,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,102,114,111,110,116,32,114,105,103,104,116,45,111,102,45,99,101,110,116,101,114,0,0,0,101,104,104,32,102,108,97,103,115,32,105,110,118,97,108,105,100,63,33,0,0,0,0,0,112,114,105,110,116,95,105,110,102,111,0,0,0,0,0,0,82,101,115,97,109,112,108,105,110,103,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,105,110,116,101,114,110,97,108,32,115,49,54,47,115,51,50,47,102,108,116,47,100,98,108,10,0,0,0,0,0,0,0,0,104,118,103,97,0,0,0,0,115,101,116,32,103,114,105,100,32,108,105,110,101,32,116,104,105,99,107,110,101,115,115,0,118,111,114,98,105,115,0,0,101,120,116,114,97,99,116,32,97,110,32,97,116,116,97,99,104,109,101,110,116,32,105,110,116,111,32,97,32,102,105,108,101,0,0,0,0,0,0,0,92,114,37,49,91,92,125,93,37,110,0,0,0,0,0,0,71,67,83,95,86,111,105,114,111,108,95,85,110,105,102,105,101,95,80,97,114,105,115,0,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,100,101,116,101,99,116,32,105,109,112,114,111,112,101,114,32,98,105,116,115,116,114,101,97,109,32,108,101,110,103,116,104,0,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,97,109,118,0,0,0,76,97,114,103,101,32,82,111,111,109,0,0,0,0,0,0,76,97,114,103,101,32,82,111,111,109,0,0,0,0,0,0,98,108,111,99,107,121,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,78,111,110,32,109,111,110,111,116,111,110,101,32,116,105,109,101,32,98,111,114,100,101,114,115,10,0,0,0,0,0,0,97,97,99,95,99,111,100,101,114,0,0,0,0,0,0,0,116,104,112,0,0,0,0,0,100,101,99,111,100,101,95,112,99,101,58,32,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,105,103,110,111,114,105,110,103,32,115,110,100,95,32,99,104,117,110,107,32,108,101,110,103,116,104,58,37,100,10,0,0,85,110,107,110,111,119,110,32,102,105,108,101,58,32,98,112,112,32,37,100,44,32,112,105,120,100,101,112,116,104,32,37,100,44,32,118,99,108,97,115,115,32,37,100,0,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,115,117,98,102,114,97,109,101,95,108,101,110,32,37,105,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,0,0,0,0,0,0,92,125,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,108,111,114,32,99,97,99,104,101,32,98,105,116,115,58,32,37,100,10,0,0,0,78,111,32,98,108,111,99,107,32,119,105,116,104,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,116,101,114,109,115,10,0,0,0,0,0,0,86,81,65,32,86,101,114,115,105,111,110,32,37,100,0,0,48,46,50,51,49,47,48,46,48,57,52,32,48,46,55,48,57,47,48,46,56,55,52,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,111,101,102,102,105,99,101,110,116,115,32,97,116,32,108,101,118,101,108,32,37,100,10,0,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,109,97,112,112,105,110,103,115,41,46,32,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,102,105,114,115,116,32,102,105,101,108,100,32,115,108,105,99,101,32,99,111,117,110,116,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,92,37,99,0,0,0,0,0,119,58,37,100,32,104,58,37,100,32,115,97,114,58,37,100,47,37,100,32,45,62,32,119,58,37,100,32,104,58,37,100,32,115,97,114,58,37,100,47,37,100,10,0,0,0,0,0,118,45,62,115,46,109,98,95,104,101,105,103,104,116,32,61,61,32,118,45,62,115,46,104,101,105,103,104,116,32,43,32,49,53,32,62,62,32,52,32,124,124,32,118,45,62,115,46,109,98,95,104,101,105,103,104,116,32,61,61,32,40,40,40,118,45,62,115,46,104,101,105,103,104,116,32,43,32,49,53,32,62,62,32,52,41,43,40,50,41,45,49,41,38,126,40,40,50,41,45,49,41,41,0,69,110,99,111,100,105,110,103,32,112,97,114,97,109,101,116,101,114,115,32,37,48,56,88,10,0,0,0,0,0,0,0,98,103,0,0,0,0,0,0,37,100,0,0,0,0,0,0,100,101,102,97,117,108,116,0,80,114,111,106,67,111,111,114,100,84,114,97,110,115,71,101,111,75,101,121,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,98,108,101,110,100,32,109,111,100,101,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,105,110,103,32,102,97,105,108,101,100,32,40,37,108,117,32,111,102,32,37,108,117,41,32,119,105,116,104,32,101,114,114,111,114,32,37,100,10,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,115,108,105,99,101,32,116,121,112,101,32,37,100,32,10,0,60,102,111,110,116,0,0,0,123,92,99,38,72,37,88,38,125,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,70,85,76,76,32,116,114,101,101,10,0,0,0,0,0,37,100,32,104,101,97,100,101,114,32,98,121,116,101,115,32,117,110,112,97,114,115,101,100,10,0,0,0,0,0,0,0,115,117,98,99,111,100,101,99,32,52,55,32,99,111,109,112,114,101,115,115,105,111,110,32,37,100,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,109,101,115,115,101,100,32,117,112,32,111,114,100,101,114,44,32,112,111,115,115,105,98,108,101,32,102,114,111,109,32,115,101,101,107,105,110,103,63,32,115,107,105,112,112,105,110,103,32,99,117,114,114,101,110,116,32,98,32,102,114,97,109,101,10,0,0,0,0,0,0,0,104,115,117,98], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2189960);
/* memory initializer */ allocate([97,118,103,84,101,120,0,0,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,32,111,114,32,116,114,117,110,99,97,116,101,100,10,0,108,116,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,48,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,100,37,99,37,100,0,0,0,102,111,114,109,97,116,0,0,78,66,95,83,65,77,80,76,69,83,0,0,0,0,0,0,111,110,108,121,32,89,85,86,52,50,48,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,119,97,114,110,105,110,103,58,32,102,105,114,115,116,32,102,114,97,109,101,32,105,115,32,110,111,32,107,101,121,102,114,97,109,101,10,0,0,0,0,118,111,114,98,105,115,0,0,105,110,118,97,108,105,100,32,110,101,119,32,98,97,99,107,115,116,101,112,32,37,100,10,0,0,0,0,0,0,0,0,32,119,105,116,104,32,97,114,103,115,32,39,37,115,39,0,105,110,118,97,108,105,100,32,110,101,119,32,98,97,99,107,115,116,101,112,32,37,100,10,0,0,0,0,0,0,0,0,117,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,67,66,80,0,0,0,0,0,0,0,0,69,110,97,98,108,101,32,97,108,116,101,114,110,97,116,101,32,115,99,97,110,116,97,98,108,101,46,0,0,0,0,0,105,103,110,111,114,105,110,103,32,112,105,99,32,97,102,116,101,114,32,37,88,10,0,0,99,117,114,118,101,115,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,115,105,122,101,46,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,106,112,101,103,100,101,99,46,99,0,0,0,37,46,42,115,0,0,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,82,71,66,32,50,52,46,10,0,0,73,110,118,97,108,105,100,32,116,112,101,110,100,10,0,0,126,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,121,109,32,101,110,99,111,117,110,116,101,114,101,100,58,32,37,100,46,10,0,0,0,32,12,9,10,13,0,0,0,98,32,109,98,95,116,121,112,101,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,67,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,105,110,116,101,114,110,97,108,32,115,116,114,117,99,116,117,114,101,115,33,10,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,99,111,114,114,101,99,116,105,111,110,115,58,32,37,100,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,118,101,114,115,105,111,110,33,10,0,0,0,0,0,69,114,114,111,114,58,32,82,71,66,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,109,101,100,105,97,110,32,112,114,101,100,105,99,116,111,114,10,0,0,0,0,0,0,0,115,112,115,95,109,97,120,95,110,117,109,95,114,101,111,114,100,101,114,95,112,105,99,115,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,84,104,101,32,99,117,95,113,112,95,100,101,108,116,97,32,37,100,32,105,115,32,111,117,116,115,105,100,101,32,116,104,101,32,118,97,108,105,100,32,114,97,110,103,101,32,91,37,100,44,32,37,100,93,46,10,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,120,50,54,52,32,45,32,99,111,114,101,32,48,48,48,48,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,115,104,111,114,116,32,116,101,114,109,32,98,117,102,102,101,114,32,115,116,97,116,101,32,100,101,116,101,99,116,101,100,10,0,0,0,0,0,0,0,86,85,73,0,0,0,0,0,73,110,99,114,101,97,115,105,110,103,32,114,101,111,114,100,101,114,32,98,117,102,102,101,114,32,116,111,32,37,100,10,0,0,0,0,0,0,0,0,32,40,110,111,45,111,112,41,0,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,99,104,117,110,107,32,116,121,112,101,32,37,48,50,88,10,0,0,0,0,0,0,0,50,52,66,112,112,32,70,76,67,47,70,76,88,0,0,0,101,114,114,111,114,32,105,110,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,111,102,32,98,108,111,99,107,32,37,100,120,37,100,10,0,0,113,108,101,118,101,108,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,109,97,121,98,101,32,98,117,103,103,121,32,115,116,114,101,97,109,10,0,0,0,0,73,110,118,97,108,105,100,32,99,111,110,116,101,120,116,32,109,111,100,101,108,32,37,100,44,32,118,97,108,105,100,32,118,97,108,117,101,115,32,97,114,101,32,48,32,97,110,100,32,49,10,0,0,0,0,0,114,101,97,100,95,113,117,97,110,116,95,116,97,98,108,101,32,101,114,114,111,114,10,0,85,110,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,37,46,50,53,54,115,10,0,0,0,0,0,68,105,97,108,111,103,117,101,32,76,101,118,101,108,32,40,100,66,41,0,0,0,0,0,102,119,113,118,103,97,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,76,111,119,32,68,101,108,97,121,58,32,72,97,115,32,67,117,115,116,111,109,32,81,117,97,110,116,105,122,97,116,105,111,110,32,77,97,116,114,105,120,33,10,0,0,0,0,0,68,84,83,45,88,66,82,58,32,100,101,99,111,100,105,110,103,32,88,66,82,32,101,120,116,101,110,115,105,111,110,10,0,0,0,0,0,0,0,0,67,111,111,107,32,118,101,114,115,105,111,110,32,37,100,0,100,101,102,97,117,108,116,0,100,117,109,112,95,97,116,116,97,99,104,109,101,110,116,0,71,67,83,95,86,111,105,114,111,108,95,49,56,55,53,95,80,97,114,105,115,0,0,0,98,117,102,102,101,114,0,0,118,109,110,99,0,0,0,0,115,112,53,120,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,86,67,51,47,68,78,120,72,68,0,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,99,111,110,118,101,114,116,32,98,101,116,119,101,101,110,32,116,104,101,32,102,111,114,109,97,116,115,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,102,105,108,116,101,114,32,39,37,115,39,32,97,110,100,32,116,104,101,32,102,105,108,116,101,114,32,39,37,115,39,10,0,0,0,0,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,77,68,67,84,10,0,0,0,0,0,0,0,0,65,80,69,32,100,101,99,111,100,101,114,0,0,0,0,0,114,105,103,104,116,0,0,0,65,108,116,101,114,110,97,116,105,118,101,0,0,0,0,0,69,114,114,111,114,32,97,112,112,108,121,105,110,103,32,103,101,110,101,114,105,99,32,102,105,108,116,101,114,32,111,112,116,105,111,110,115,46,10,0,87,77,47,80,97,114,116,79,102,83,101,116,0,0,0,0,52,50,48,112,57,0,0,0,103,108,111,98,97,108,0,0,118,109,100,118,105,100,101,111,0,0,0,0,0,0,0,0,118,105,109,97,0,0,0,0,118,99,114,49,0,0,0,0,119,113,118,103,97,0,0,0,97,100,100,32,97,110,32,97,116,116,97,99,104,109,101,110,116,32,116,111,32,116,104,101,32,111,117,116,112,117,116,32,102,105,108,101,0,0,0,0,71,67,83,95,84,97,110,97,110,97,114,105,118,101,95,80,97,114,105,115,0,0,0,0,100,101,116,101,99,116,32,98,105,116,115,116,114,101,97,109,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,100,101,118,105,97,116,105,111,110,115,0,0,0,0,0,0,0,100,110,120,104,100,0,0,0,37,48,52,100,37,48,50,100,37,48,50,100,45,37,48,50,100,37,48,50,100,37,48,50,100,0,0,0,0,0,0,0,108,111,103,108,101,118,101,108,0,0,0,0,0,0,0,0,69,120,112,101,99,116,101,100,32,105,110,116,54,52,32,102,111,114,32,37,115,32,98,117,116,32,102,111,117,110,100,32,37,115,10,0,0,0,0,0,77,105,99,114,111,115,111,102,116,32,88,77,86,0,0,0,118,99,49,0,0,0,0,0,102,97,108,115,101,0,0,0,77,97,120,105,115,32,88,65,0,0,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,115,0,0,0,0,114,97,119,32,87,97,118,80,97,99,107,0,0,0,0,0,98,101,120,116,0,0,0,0,85,110,107,110,111,119,110,32,83,77,86,32,118,101,114,115,105,111,110,32,102,111,117,110,100,10,0,0,0,0,0,0,67,68,67,84,0,0,0,0,87,97,118,80,97,99,107,0,86,105,118,111,47,37,100,46,0,0,0,0,0,0,0,0,105,110,116,101,110,115,105,116,121,32,98,97,115,101,100,32,99,111,108,111,114,105,110,103,0,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,84,101,108,101,118,105,115,105,111,110,32,40,87,84,86,41,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,10,0,0,0,0,0,0,0,0,104,113,118,103,97,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,39,37,115,39,32,105,110,32,98,115,102,115,32,111,112,116,105,111,110,32,39,37,115,39,32,102,111,114,32,115,108,97,118,101,32,111,117,116,112,117,116,32,39,37,115,39,10,0,0,0,0,0,0,0,0,117,110,115,97,102,101,0,0,97,116,116,97,99,104,0,0,71,67,83,95,66,101,108,103,101,95,49,57,53,48,95,66,114,117,115,115,101,108,115,0,98,105,116,115,116,114,101,97,109,0,0,0,0,0,0,0,70,101,101,98,108,101,32,70,105,108,101,115,47,83,99,117,109,109,86,77,32,68,88,65,0,0,0,0,0,0,0,0,73,69,67,32,54,49,57,51,55,32,101,110,99,97,112,115,117,108,97,116,105,111,110,32,102,108,97,103,115,0,0,0,37,115,0,0,0,0,0,0,60,99,32,110,61,34,37,100,34,32,100,61,34,37,108,108,117,34,32,47,62,10,0,0,87,105,110,100,111,119,115,32,84,101,108,101,118,105,115,105,111,110,32,40,87,84,86,41,0,0,0,0,0,0,0,0,115,101,116,32,103,114,101,101,110,32,99,111,110,116,114,97,115,116,0,0,0,0,0,0,87,101,115,116,119,111,111,100,32,83,116,117,100,105,111,115,32,86,81,65,0,0,0,0,115,101,116,32,116,104,101,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,112,108,97,121,108,105,115,116,32,101,110,116,114,105,101,115,0,0,0,0,0,0,87,101,115,116,119,111,111,100,32,83,116,117,100,105,111,115,32,97,117,100,105,111,0,0,114,116,112,0,0,0,0,0,45,62,0,0,0,0,0,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,0,115,107,105,112,95,114,116,99,112,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,114,101,109,97,105,110,105,110,103,32,108,101,110,10,0,0,0,0,0,73,83,70,84,0,0,0,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,0,67,111,110,118,101,114,116,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,97,32,118,105,100,101,111,32,111,117,116,112,117,116,46,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,73,73,32,109,111,118,105,101,0,0,0,0,0,0,0,0,114,97,119,32,69,45,65,67,45,51,0,0,0,0,0,0,118,99,49,32,100,101,109,117,120,101,114,0,0,0,0,0,110,104,100,0,0,0,0,0,112,114,105,110,116,32,112,114,111,103,114,101,115,115,32,114,101,112,111,114,116,32,100,117,114,105,110,103,32,101,110,99,111,100,105,110,103,0,0,0,71,67,83,95,80,97,100,97,110,103,95,74,97,107,97,114,116,97,0,0,0,0,0,0,118,101,114,105,102,121,32,101,109,98,101,100,100,101,100,32,67,82,67,115,0,0,0,0,72,101,97,100,101,114,58,32,37,48,88,10,0,0,0,0,100,120,97,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,118,98,108,101,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,37,115,32,115,116,97,114,116,101,100,32,111,110,32,37,48,52,100,45,37,48,50,100,45,37,48,50,100,32,97,116,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,10,82,101,112,111,114,116,32,119,114,105,116,116,101,110,32,116,111,32,34,37,115,34,10,0,0,118,98,0,0,0,0,0,0,87,65,86,32,47,32,87,65,86,69,32,40,87,97,118,101,102,111,114,109,32,65,117,100,105,111,41,0,0,0,0,0,105,103,110,100,116,115,0,0,118,52,49,48,0,0,0,0,82,73,68,58,32,37,46,56,120,10,0,0,0,0,0,0,118,52,49,48,0,0,0,0,84,104,101,32,112,97,103,101,115,105,122,101,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,10,0,0,0,0,0,0,97,121,117,118,0,0,0,0,76,97,118,102,0,0,0,0,97,121,117,118,0,0,0,0,69,120,116,114,97,100,97,116,97,0,0,0,0,0,0,0,115,97,109,112,108,101,95,99,111,117,110,116,0,0,0,0,118,51,48,56,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,109,112,101,103,50,32,102,114,97,109,101,10,0,0,0,0,0,0,87,65,86,32,47,32,87,65,86,69,32,40,87,97,118,101,102,111,114,109,32,65,117,100,105,111,41,0,0,0,0,0,118,51,48,56,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,104,101,97,100,101,114,32,109,101,116,97,100,97,116,97,10,0,0,118,50,49,48,120,0,0,0,70,80,83,0,0,0,0,0,100,105,109,101,110,115,105,111,110,115,32,110,111,116,32,115,101,116,10,0,0,0,0,0,52,107,115,99,111,112,101,0,118,50,49,48,0,0,0,0,83,101,114,118,105,99,101,48,49,0,0,0,0,0,0,0,99,114,111,112,0,0,0,0,115,116,97,116,115,0,0,0,71,67,83,95,78,84,70,95,80,97,114,105,115,0,0,0,99,114,99,99,104,101,99,107,0,0,0,0,0,0,0,0,67,111,110,116,105,110,117,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,32,102,111,114,32,112,105,100,32,37,100,32,101,120,112,101,99,116,101,100,32,37,100,32,103,111,116,32,37,100,10,0,0,97,118,95,102,105,102,111,95,115,105,122,101,40,115,116,114,101,97,109,45,62,102,105,102,111,41,32,61,61,32,48,0,71,73,70,32,40,71,114,97,112,104,105,99,115,32,73,110,116,101,114,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,118,50,49,48,0,0,0,0,77,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,115,117,98,116,105,116,108,101,115,32,115,116,114,101,97,109,115,32,114,101,97,99,104,101,100,10,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,44,32,110,111,116,32,119,114,105,116,105,110,103,32,88,105,110,103,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,114,101,112,111,114,116,32,34,37,115,34,58,32,37,115,10,0,78,105,112,112,111,110,32,84,101,108,101,103,114,97,112,104,32,97,110,100,32,84,101,108,101,112,104,111,110,101,32,67,111,114,112,111,114,97,116,105,111,110,32,40,78,84,84,41,32,84,119,105,110,86,81,0,117,116,118,105,100,101,111,0,86,80,108,97,121,101,114,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,0,51,71,80,50,32,40,51,71,80,80,50,32,102,105,108,101,32,102,111,114,109,97,116,41,0,0,0,0,0,0,0,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,67,114,101,97,116,105,118,101,32,86,111,105,99,101,0,0,117,116,118,105,100,101,111,0,99,111,112,121,0,0,0,0,66,114,111,107,101,110,32,102,105,108,101,44,32,116,114,97,107,47,109,100,97,116,32,110,111,116,32,97,116,32,116,111,112,45,108,101,118,101,108,10,0,0,0,0,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,83,77,65,70,32,99,104,117,110,107,32,37,48,56,120,10,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,100,101,99,32,116,97,103,10,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,119,114,105,116,101,32,99,97,99,104,101,100,32,97,117,100,105,111,32,112,97,99,107,101,116,32,114,101,116,58,37,100,10,0,0,0,0,0,85,110,107,110,111,119,110,32,101,110,116,114,121,32,48,120,37,88,10,0,0,0,0,0,86,105,118,111,0,0,0,0,64,37,117,32,64,37,117,32,37,99,0,0,0,0,0,0,52,107,102,108,97,116,0,0,86,67,45,49,32,116,101,115,116,32,98,105,116,115,116,114,101,97,109,0,0,0,0,0,102,108,117,115,104,32,37,115,32,37,100,46,37,100,0,0,86,67,45,49,32,116,101,115,116,32,98,105,116,115,116,114,101,97,109,0,0,0,0,0,114,101,97,100,32,99,111,109,112,108,101,120,32,102,105,108,116,101,114,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,102,114,111,109,32,97,32,102,105,108,101,0,0,0,0,0,0,0,0,71,67,83,95,77,111,110,116,101,95,77,97,114,105,111,95,82,111,109,101,0,0,0,0,115,101,116,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,32,102,108,97,103,115,0,0,0,0,0,0,0,115,101,116,32,102,105,114,115,116,32,110,117,109,98,101,114,32,105,110,32,116,104,101,32,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,103,105,102,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,121,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,112,101,114,102,111,114,109,101,114,0,0,0,0,0,0,0,104,108,115,95,116,105,109,101,0,0,0,0,0,0,0,0,107,101,121,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,114,101,110,97,109,101,32,102,105,108,101,32,37,115,32,116,111,32,37,115,10,0,37,100,58,37,100,58,37,100,37,99,37,100,0,0,0,0,97,61,99,111,110,116,114,111,108,58,115,116,114,101,97,109,105,100,61,37,100,13,10,0,85,77,70,32,112,97,99,107,101,116,32,116,111,111,32,115,104,111,114,116,10,0,0,0,70,76,86,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,109,111,110,111,32,83,112,101,101,120,32,97,117,100,105,111,10,0,0,0,0,0,97,117,100,105,111,115,97,109,112,108,101,114,97,116,101,0,101,120,105,116,101,100,32,97,117,100,105,111,32,115,117,98,104,101,97,100,101,114,10,0,52,107,0,0,0,0,0,0,102,105,108,116,101,114,95,99,111,109,112,108,101,120,95,115,99,114,105,112,116,0,0,0,71,67,83,95,77,71,73,95,70,101,114,114,111,0,0,0,101,114,114,95,100,101,116,101,99,116,0,0,0,0,0,0,84,73,70,70,32,105,109,97,103,101,0,0,0,0,0,0,108,105,110,101,115,112,101,101,100,0,0,0,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,32,98,117,105,108,100,105,110,103,32,114,101,112,111,114,116,32,102,105,108,101,32,110,97,109,101,10,0,0,0,0,0,0,0,0,115,99,97,108,101,47,114,97,116,101,32,105,115,32,37,117,47,37,117,32,119,104,105,99,104,32,105,115,32,105,110,118,97,108,105,100,46,32,40,84,104,105,115,32,102,105,108,101,32,104,97,115,32,98,101,101,110,32,103,101,110,101,114,97,116,101,100,32,98,121,32,98,114,111,107,101,110,32,115,111,102,116,119,97,114,101,46,41,10,0,0,0,0,0,0,0,112,97,99,107,101,116,32,102,114,97,103,109,101,110,116,32,112,111,115,105,116,105,111,110,32,105,110,118,97,108,105,100,32,37,117,44,37,117,32,110,111,116,32,105,110,32,37,117,10,0,0,0,0,0,0,0,115,116,97,114,116,116,0,0,111,99,104,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,100,101,102,97,117,108,116,0,103,114,97,112,104,32,37,100,32,105,110,112,117,116,32,102,114,111,109,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,0,0,0,97,48,0,0,0,0,0,0,50,107,115,99,111,112,101,0,108,97,118,102,105,0,0,0,71,67,83,95,77,97,107,97,115,115,97,114,95,74,97,107,97,114,116,97,0,0,0,0,81,80,32,111,102,102,115,101,116,32,98,101,116,119,101,101,110,32,80,45,32,97,110,100,32,66,45,102,114,97,109,101,115,0,0,0,0,0,0,0,116,105,102,102,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,100,105,109,101,110,115,105,111,110,115,32,37,100,32,37,100,10,0,115,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,37,112,45,37,116,46,108,111,103,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,117,108,116,105,109,111,116,105,111,110,0,0,0,0,0,0,115,101,116,32,102,97,100,101,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,48,46,53,0,0,0,0,0,116,120,100,0,0,0,0,0,118,97,108,0,0,0,0,0,115,105,122,101,0,0,0,0,115,101,116,32,116,104,101,32,116,101,114,109,105,110,97,108,32,115,99,97,108,101,32,118,97,108,117,101,0,0,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,116,119,105,110,118,113,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,97,117,116,111,32,100,101,116,101,99,116,32,112,97,114,105,116,121,0,0,0,0,0,0,70,114,97,109,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,98,121,116,101,115,41,46,32,84,114,117,110,99,97,116,101,100,32,102,105,108,101,63,10,0,0,0,0,121,48,0,0,0,0,0,0,116,116,97,0,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,101,102,102,101,99,116,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,112,114,101,115,101,114,118,101,32,108,97,110,100,115,99,97,112,101,32,103,101,111,109,101,116,114,121,0,0,0,0,0,70,80,83,58,32,37,100,47,37,100,32,45,62,32,37,100,47,37,100,10,0,0,0,0,50,107,102,108,97,116,0,0,103,114,97,112,104,95,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,0,0,71,67,83,95,76,105,115,98,111,110,95,76,105,115,98,111,110,0,0,0,0,0,0,0,105,110,116,101,114,108,0,0,98,95,113,111,102,102,115,101,116,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,84,105,101,114,116,101,120,32,76,105,109,105,116,101,100,32,83,69,81,32,118,105,100,101,111,0,0,0,0,0,0,0,116,116,97,0,0,0,0,0,109,97,105,110,0,0,0,0,78,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,114,101,32,110,111,116,32,97,99,99,101,112,116,97,98,108,101,46,10,0,0,0,0,117,110,99,111,100,101,100,32,102,114,97,109,101,99,114,99,32,116,101,115,116,105,110,103,0,0,0,0,0,0,0,0,67,111,110,118,101,114,116,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,97,32,115,112,101,99,116,114,117,109,32,118,105,100,101,111,32,111,117,116,112,117,116,46,0,85,110,107,110,111,119,110,32,107,101,121,32,39,37,115,39,32,105,110,32,70,70,82,69,80,79,82,84,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,101,110,100,101,114,119,97,114,101,32,84,101,88,116,117,114,101,32,68,105,99,116,105,111,110,97,114,121,0,0,0,116,115,99,99,50,0,0,0,99,48,95,115,116,114,101,110,103,116,104,0,0,0,0,0,105,110,112,117,116,0,0,0,99,108,117,116,0,0,0,0,84,101,108,101,45,116,121,112,101,119,114,105,116,101,114,0,99,97,109,116,97,115,105,97,0,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,99,104,114,111,109,97,95,115,119,97,112,0,0,0,0,0,116,114,117,101,115,112,101,101,99,104,0,0,0,0,0,0,84,84,65,32,40,84,114,117,101,32,65,117,100,105,111,41,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,115,101,116,32,119,97,118,101,102,111,114,109,32,115,116,101,112,32,118,97,108,117,101,0,56,48,56,56,102,108,101,120,32,84,77,86,0,0,0,0,84,105,101,114,116,101,120,32,76,105,109,105,116,101,100,32,83,69,81,0,0,0,0,0,114,105,103,104,116,0,0,0,114,111,117,110,100,32,116,111,32,110,101,97,114,101,115,116,0,0,0,0,0,0,0,0,84,72,80,0,0,0,0,0,116,114,117,101,109,111,116,105,111,110,50,0,0,0,0,0,111,114,100,101,114,0,0,0,98,103,114,56,0,0,0,0,99,111,108,111,114,99,104,97,110,110,101,108,109,105,120,101,114,0,0,0,0,0,0,0,65,122,117,114,101,0,0,0,37,108,108,105,100,58,37,48,50,100,58,37,48,50,100,46,37,48,54,100,0,0,0,0,102,97,100,101,32,97,108,112,104,97,32,105,102,32,105,116,32,105,115,32,97,118,97,105,108,97,98,108,101,32,111,110,32,116,104,101,32,105,110,112,117,116,0,0,0,0,0,0,103,97,117,115,115,0,0,0,71,101,110,101,114,105,99,32,101,114,114,111,114,32,105,110,32,97,110,32,101,120,116,101,114,110,97,108,32,108,105,98,114,97,114,121,0,0,0,0,115,101,116,32,98,108,117,101,32,112,108,97,110,101,0,0,70,82,67,0,0,0,0,0,99,45,62,99,104,114,68,115,116,72,32,60,61,32,100,115,116,72,0,0,0,0,0,0,110,97,116,117,114,97,108,32,98,105,99,117,98,105,99,32,115,112,108,105,110,101,0,0,82,101,113,117,101,115,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,37,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,116,101,114,110,97,108,108,121,44,32,83,49,54,47,83,51,50,47,70,76,84,47,68,66,76,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,50,107,0,0,0,0,0,0,116,114,117,101,109,111,116,105,111,110,49,0,0,0,0,0,116,104,105,99,107,110,101,115,115,0,0,0,0,0,0,0,116,109,118,0,0,0,0,0,92,97,110,37,49,117,37,49,91,92,125,93,37,110,0,0,71,67,83,95,66,111,103,111,116,97,95,66,111,103,111,116,97,0,0,0,0,0,0,0,99,114,101,97,116,101,32,97,32,99,111,109,112,108,101,120,32,102,105,108,116,101,114,103,114,97,112,104,0,0,0,0,109,97,120,32,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,32,105,110,118,97,108,105,100,58,32,37,117,10,0,0,0,0,0,0,102,105,108,108,32,122,101,114,111,101,115,32,97,116,32,98,108,97,110,107,32,108,111,99,97,116,105,111,110,115,0,0,77,117,108,116,105,112,108,101,32,109,117,120,101,114,32,116,101,101,0,0,0,0,0,0,97,108,108,111,119,32,110,111,110,45,115,116,97,110,100,97,114,100,105,122,101,100,32,101,120,112,101,114,105,109,101,110,116,97,108,32,116,104,105,110,103,115,0,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,88,65,83,0,0,0,0,0,0,0,108,97,114,103,101,0,0,0,108,97,114,103,101,0,0,0,115,101,116,32,116,104,101,32,115,105,122,101,32,111,102,32,116,104,101,32,120,45,97,120,105,115,32,98,108,111,99,107,115,32,117,115,101,100,32,100,117,114,105,110,103,32,109,101,116,114,105,99,32,99,97,108,99,117,108,97,116,105,111,110,115,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,32,105,100,10,0,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,98,115,95,112,111,105,110,116,101,114,32,112,111,105,110,116,115,32,116,111,32,97,32,109,105,100,100,108,101,32,110,111,105,115,101,32,98,111,114,100,101,114,32,111,117,116,115,105,100,101,32,116,104,101,32,116,105,109,101,32,98,111,114,100,101,114,115,32,116,97,98,108,101,58,32,37,100,10,0,0,0,0,0,0,0,70,111,114,99,101,32,77,105,100,47,83,105,100,101,32,102,111,114,32,116,104,101,32,119,104,111,108,101,32,102,114,97,109,101,32,105,102,32,112,111,115,115,105,98,108,101,0,0,116,105,101,114,116,101,120,115,101,113,118,105,100,101,111,0,83,97,109,112,108,101,32,114,97,116,101,32,105,110,100,101,120,32,105,110,32,112,114,111,103,114,97,109,32,99,111,110,102,105,103,32,101,108,101,109,101,110,116,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,32,105,110,100,101,120,32,99,111,110,102,105,103,117,114,101,100,32,98,121,32,116,104,101,32,99,111,110,116,97,105,110,101,114,46,10,0,0,105,110,118,97,108,105,100,32,118,105,115,117,97,108,32,99,108,97,115,115,10,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,99,104,97,110,110,101,108,32,108,101,110,32,62,32,115,97,109,112,108,101,115,95,112,101,114,95,102,114,97,109,101,10,0,0,85,110,107,110,111,119,110,32,98,105,116,45,100,101,112,116,104,58,32,37,100,10,0,0,68,105,115,97,98,108,105,110,103,32,117,115,101,95,118,97,114,105,97,98,108,101,95,98,108,111,99,107,95,108,101,110,44,32,105,102,32,116,104,105,115,32,102,97,105,108,115,32,99,111,110,116,97,99,116,32,116,104,101,32,102,102,109,112,101,103,32,100,101,118,101,108,111,112,101,114,115,32,97,110,100,32,115,101,110,100,32,117,115,32,116,104,101,32,102,105,108,101,10,0,0,0,0,0,125,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,112,114,101,100,105,99,116,111,114,32,109,111,100,101,58,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,99,117,115,116,111,109,32,115,97,109,112,108,101,32,114,97,116,101,46,10,0,0,0,0,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,111,102,32,37,100,10,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,32,98,117,102,102,101,114,32,37,100,10,0,0,0,0,0,48,46,50,53,47,48,46,49,56,56,32,48,46,51,56,47,48,46,53,48,49,32,48,46,55,52,53,47,48,46,56,49,53,32,49,47,48,46,56,49,53,0,0,0,0,0,0,0,67,111,101,102,102,105,99,105,101,110,116,32,105,110,100,101,120,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,114,101,115,105,100,117,101,115,41,46,32,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,83,108,105,99,101,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,0,0,102,105,108,101,0,0,0,0,84,111,111,32,98,105,103,32,118,97,108,117,101,32,111,114,32,105,110,118,97,108,105,100,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,111,117,116,95,119,47,111,119,32,111,114,32,111,117,116,95,104,47,111,104,46,32,77,97,121,98,101,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,111,117,116,95,119,58,39,37,115,39,32,111,114,32,102,111,114,32,111,117,116,95,104,58,39,37,115,39,32,105,115,32,115,101,108,102,45,114,101,102,101,114,101,110,99,105,110,103,46,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,69,68,32,84,97,108,107,115,32,99,97,112,116,105,111,110,115,0,0,0,0,0,0,70,114,97,109,101,32,105,110,102,111,32,110,111,116,32,52,32,98,121,116,101,115,0,0,115,101,116,32,116,104,101,32,114,101,100,32,103,97,105,110,32,102,111,114,32,116,104,101,32,98,108,117,101,32,99,104,97,110,110,101,108,0,0,0,84,104,101,32,109,97,120,105,109,117,109,32,118,97,108,117,101,32,102,111,114,32,108,111,119,114,101,115,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,100,101,99,111,100,101,114,32,105,115,32,37,100,10,0,0,0,0,73,110,99,111,114,114,101,99,116,32,100,101,108,116,97,32,116,97,98,108,101,58,32,37,105,32,100,101,108,116,97,115,32,120,32,37,105,32,98,105,116,115,10,0,0,0,0,0,115,101,116,32,98,108,117,101,32,104,105,103,104,108,105,103,104,116,115,0,0,0,0,0,116,105,102,102,0,0,0,0,114,97,119,32,84,65,75,0,80,114,111,106,101,99,116,105,111,110,71,101,111,75,101,121,0,0,0,0,0,0,0,0,99,50,95,109,111,100,101,0,85,110,99,111,109,112,114,101,115,115,101,100,32,102,97,120,32,109,111,100,101,0,0,0,115,108,105,99,101,32,97,102,116,101,114,32,98,105,116,115,116,114,101,97,109,32,101,110,100,10,0,0,0,0,0,0,65,114,105,97,108,0,0,0,99,111,108,111,114,61,0,0,83,107,105,112,32,102,105,110,97,108,32,98,105,116,115,116,114,101,97,109,32,119,114,105,116,101,111,117,116,46,0,0,83,107,105,112,112,105,110,103,32,77,67,76,82,32,116,114,101,101,10,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,58,32,37,100,10,0,0,0,0,0,0,100,101,99,111,100,101,100,32,115,105,122,101,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,70,32,37,100,47,37,100,47,37,100,10,0,0,0,0,0,97,118,103,66,80,84,101,120,0,0,0,0,0,0,0,0,100,97,114,0,0,0,0,0,83,117,98,112,97,99,107,101,116,58,32,116,121,112,101,61,37,100,32,115,105,122,101,61,37,100,32,115,116,97,114,116,95,111,102,102,115,61,37,120,10,0,0,0,0,0,0,0,112,114,111,102,105,108,101,0,72,101,97,100,101,114,32,116,114,117,110,99,97,116,101,100,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,105,109,101,115,116,97,109,112,32,105,110,32,115,101,99,111,110,100,115,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,100,114,111,112,112,101,100,32,97,103,97,105,110,0,0,0,0,112,99,109,95,108,120,102,0,78,111,32,102,105,108,101,110,97,109,101,32,112,114,111,118,105,100,101,100,33,10,0,0,83,87,70,32,40,83,104,111,99,107,87,97,118,101,32,70,108,97,115,104,41,0,0,0,104,101,105,103,104,116,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,97,115,107,32,112,108,97,110,101,10,0,0,0,0,0,78,66,95,67,79,78,83,85,77,69,68,95,83,65,77,80,76,69,83,0,0,0,0,0,99,111,108,111,114,115,112,97,99,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,106,112,101,103,10,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,100,117,109,109,121,32,108,97,115,116,32,112,105,99,116,117,114,101,32,102,111,114,32,66,32,102,114,97,109,101,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,111,108,100,32,98,97,99,107,115,116,101,112,32,37,100,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,102,105,108,116,101,114,32,39,37,115,39,0,0,105,110,118,97,108,105,100,32,111,108,100,32,98,97,99,107,115,116,101,112,32,37,100,10,0,0,0,0,0,0,0,0,99,98,112,95,114,100,0,0,97,108,116,101,114,110,97,116,101,95,115,99,97,110,0,0,109,112,101,103,95,100,101,99,111,100,101,95,112,111,115,116,105,110,105,116,40,41,32,102,97,105,108,117,114,101,10,0,98,108,111,99,107,32,100,97,116,97,32,108,101,110,103,116,104,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,115,45,62,110,98,95,99,111,109,112,111,110,101,110,116,115,32,61,61,32,51,0,0,0,65,114,105,97,108,0,0,0,83,87,70,32,40,83,104,111,99,107,87,97,118,101,32,70,108,97,115,104,41,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,100,105,109,101,110,115,105,111,110,115,10,0,77,105,115,115,105,110,103,32,83,79,84,10,0,0,0,0,92,126,0,0,0,0,0,0,83,99,97,110,32,112,97,116,116,101,114,110,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,0,0,32,32,32,32,91,37,115,93,32,116,97,114,103,101,116,58,37,115,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,32,105,110,100,101,120,58,37,100,10,0,0,99,98,112,99,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,69,110,100,32,109,97,114,107,101,114,32,109,105,115,115,105,110,103,33,10,0,0,0,0,109,105,115,109,97,116,99,104,105,110,103,32,116,114,97,110,115,102,111,114,109,95,115,105,122,101,33,10,0,0,0,0,79,83,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,33,10,0,0,0,86,101,114,32,62,32,50,32,105,115,32,117,110,100,101,114,32,100,101,118,101,108,111,112,109,101,110,116,44,32,102,105,108,101,115,32,101,110,99,111,100,101,100,32,119,105,116,104,32,105,116,32,109,97,121,32,110,111,116,32,98,101,32,100,101,99,111,100,97,98,108,101,32,119,105,116,104,32,102,117,116,117,114,101,32,118,101,114,115,105,111,110,115,33,33,33,10,85,115,101,32,118,115,116,114,105,99,116,61,45,50,32,47,32,45,115,116,114,105,99,116,32,45,50,32,116,111,32,117,115,101,32,105,116,32,97,110,121,119,97,121,46,10,0,115,112,115,95,109,97,120,95,100,101,99,95,112,105,99,95,98,117,102,102,101,114,105,110,103,95,109,105,110,117,115,49,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,80,114,101,118,105,111,117,115,32,115,108,105,99,101,32,115,101,103,109,101,110,116,32,109,105,115,115,105,110,103,10,0,80,0,0,0,0,0,0,0,120,50,54,52,32,45,32,99,111,114,101,32,37,100,0,0,105,108,108,101,103,97,108,32,115,104,111,114,116,32,116,101,114,109,32,114,101,102,101,114,101,110,99,101,32,97,115,115,105,103,110,109,101,110,116,32,102,111,114,32,115,101,99,111,110,100,32,102,105,101,108,100,32,105,110,32,99,111,109,112,108,101,109,101,110,116,97,114,121,32,102,105,101,108,100,32,112,97,105,114,32,40,102,105,114,115,116,32,102,105,101,108,100,32,105,115,32,108,111,110,103,32,116,101,114,109,41,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,80,79,67,32,37,100,60,37,100,10,0,0,0,0,0,0,37,115,32,45,62,32,37,115,37,115,10,0,0,0,0,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,100,97,116,97,32,115,105,122,101,32,37,100,10,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,10,0,0,0,110,111,32,100,97,116,97,32,97,118,97,105,108,97,98,108,101,32,102,111,114,32,122,108,105,98,32,112,114,105,109,105,110,103,10,0,0,0,0,0,32,108,112,99,32,116,121,112,101,58,32,67,104,111,108,101,115,107,121,32,102,97,99,116,111,114,105,122,97,116,105,111,110,44,32,37,100,32,112,97,115,115,37,115,10,0,0,0,83,117,98,86,105,101,119,101,114,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,101,102,102,32,112,114,101,99,105,115,105,111,110,10,0,0,0,0,0,0,0,0,83,116,111,114,105,110,103,32,97,108,112,104,97,32,112,108,97,110,101,44,32,116,104,105,115,32,119,105,108,108,32,114,101,113,117,105,114,101,32,97,32,114,101,99,101,110,116,32,70,70,86,49,32,100,101,99,111,100,101,114,32,116,111,32,112,108,97,121,98,97,99,107,33,10,0,0,0,0,0,0,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,65,0,0,0,0,0,0,0,100,105,97,108,110,111,114,109,0,0,0,0,0,0,0,0,104,100,49,48,56,48,0,0,119,105,100,116,104,0,0,0,73,110,118,97,108,105,100,32,108,111,119,100,101,108,97,121,46,98,121,116,101,115,46,100,101,110,10,0,0,0,0,0,68,84,83,45,69,120,83,83,58,32,117,110,107,110,111,119,110,32,109,97,114,107,101,114,32,61,32,48,120,37,48,56,120,10,0,0,0,0,0,0,77,85,76,84,73,95,67,72,65,78,78,69,76,10,0,0,97,99,99,101,112,116,32,97,108,108,32,99,104,97,110,110,101,108,32,99,111,117,110,116,115,0,0,0,0,0,0,0,71,67,83,95,66,101,114,110,95,49,56,57,56,95,66,101,114,110], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2200200);
/* memory initializer */ allocate([102,105,108,116,101,114,95,99,111,109,112,108,101,120,0,0,83,117,98,86,105,101,119,101,114,32,118,49,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,101,120,112,101,114,105,109,101,110,116,97,108,0,0,0,0,76,111,115,115,108,101,115,115,32,74,80,69,71,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,32,118,105,100,101,111,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,104,97,110,110,101,108,32,99,111,100,105,110,103,32,109,111,100,101,32,37,120,33,10,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,98,105,116,115,58,32,37,100,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,114,101,111,114,100,101,114,105,110,103,46,10,0,0,0,0,108,101,102,116,0,0,0,0,73,110,100,117,115,116,114,105,97,108,0,0,0,0,0,0,33,105,110,112,117,116,45,62,102,105,108,116,101,114,95,102,114,97,109,101,32,124,124,32,40,33,105,110,112,117,116,45,62,115,116,97,114,116,95,102,114,97,109,101,32,38,38,32,33,105,110,112,117,116,45,62,101,110,100,95,102,114,97,109,101,41,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,99,111,109,112,117,116,101,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,10,0,0,0,0,0,0,115,58,37,100,120,37,100,32,114,58,37,102,32,110,58,37,100,10,0,0,0,0,0,0,52,52,52,112,49,48,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,70,70,82,69,80,79,82,84,32,101,110,118,105,114,111,110,109,101,110,116,32,118,97,114,105,97,98,108,101,58,32,37,115,10,0,0,0,0,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,73,69,67,32,54,49,57,51,55,32,40,117,115,101,100,32,111,110,32,83,47,80,68,73,70,32,45,32,73,69,67,57,53,56,41,0,0,0,0,0,67,111,100,101,99,32,99,104,97,110,103,101,32,105,110,32,73,69,67,32,54,49,57,51,55,0,0,0,0,0,0,0,67,111,110,99,97,116,101,110,97,116,101,32,97,117,100,105,111,32,97,110,100,32,118,105,100,101,111,32,115,116,114,101,97,109,115,46,0,0,0,0,83,111,88,32,110,97,116,105,118,101,0,0,0,0,0,0,83,111,88,32,110,97,116,105,118,101,0,0,0,0,0,0,83,105,101,114,114,97,32,83,79,76,0,0,0,0,0,0,104,100,55,50,48,0,0,0,76,117,99,97,115,65,114,116,115,32,83,109,117,115,104,0,71,67,83,95,87,71,83,95,56,52,0,0,0,0,0,0,114,101,105,110,105,116,32,102,105,108,116,101,114,103,114,97,112,104,32,111,110,32,105,110,112,117,116,32,112,97,114,97,109,101,116,101,114,32,99,104,97,110,103,101,115,0,0,0,97,108,108,111,119,32,117,110,111,102,102,105,99,105,97,108,32,101,120,116,101,110,115,105,111,110,115,0,0,0,0,0,100,115,105,99,105,110,118,105,100,101,111,0,0,0,0,0,58,0,0,0,0,0,0,0,83,117,99,99,101,115,115,102,117,108,108,121,32,112,97,114,115,101,100,32,97,32,103,114,111,117,112,32,111,102,32,111,112,116,105,111,110,115,46,10,0,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,87,101,98,86,84,84,32,99,97,112,116,105,111,110,115,32,107,105,110,100,0,0,0,0,100,97,116,97,0,0,0,0,102,111,117,110,100,32,110,111,32,39,102,109,116,32,39,32,116,97,103,32,98,101,102,111,114,101,32,116,104,101,32,39,83,77,86,48,39,32,116,97,103,10,0,0,0,0,0,0,98,97,110,100,0,0,0,0,99,111,108,111,114,98,97,108,97,110,99,101,0,0,0,0,83,109,111,111,116,104,32,83,116,114,101,97,109,105,110,103,32,77,117,120,101,114,0,0,86,101,114,115,105,111,110,0,76,111,107,105,32,83,68,76,32,77,74,80,69,71,0,0,105,110,116,101,110,115,105,116,121,0,0,0,0,0,0,0,76,111,107,105,32,83,68,76,32,77,74,80,69,71,0,0,68,114,111,112,112,101,100,32,99,111,114,114,117,112,116,101,100,32,112,97,99,107,101,116,32,40,115,116,114,101,97,109,32,61,32,37,100,41,10,0,83,109,97,99,107,101,114,0,104,100,52,56,48,0,0,0,83,112,101,99,105,102,105,101,114,32,115,101,112,97,114,97,116,111,114,32,105,110,32,39,37,115,39,32,105,115,32,39,37,99,39,44,32,98,117,116,32,111,110,108,121,32,99,104,97,114,97,99,116,101,114,115,32,39,37,115,39,32,97,114,101,32,97,108,108,111,119,101,100,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,116,97,114,116,32,116,105,109,101,32,40,111,102,102,115,101,116,41,32,111,102,32,116,104,101,32,115,117,98,116,105,116,108,101,115,44,32,105,110,32,109,115,0,0,0,0,0,66,101,97,109,32,83,111,102,116,119,97,114,101,32,83,73,70,70,0,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,115,116,114,101,97,109,115,0,0,0,0,0,71,67,83,95,87,71,83,95,55,50,66,69,0,0,0,0,114,101,105,110,105,116,95,102,105,108,116,101,114,0,0,0,117,110,111,102,102,105,99,105,97,108,0,0,0,0,0,0,84,114,117,101,118,105,115,105,111,110,32,84,97,114,103,97,32,105,109,97,103,101,0,0,83,105,101,114,114,97,32,86,77,68,0,0,0,0,0,0,115,112,100,105,102,95,102,108,97,103,115,0,0,0,0,0,61,0,0,0,0,0,0,0,60,99,32,116,61,34,37,108,108,117,34,32,100,61,34,37,108,108,117,34,32,47,62,10,0,0,0,0,0,0,0,0,103,99,0,0,0,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,95,115,105,122,101,0,0,0,0,0,0,0,116,61,37,100,32,37,100,13,10,97,61,116,111,111,108,58,108,105,98,97,118,102,111,114,109,97,116,32,53,53,46,51,51,46,49,48,48,13,10,0,114,101,108,97,116,105,118,101,32,116,105,109,101,32,119,105,116,104,111,117,116,32,112,114,101,118,105,111,117,115,32,97,98,115,111,108,117,116,101,32,116,105,109,101,0,0,0,0,85,115,101,32,82,70,67,32,50,49,57,48,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,105,110,115,116,101,97,100,32,111,102,32,82,70,67,32,52,54,50,57,32,102,111,114,32,72,46,50,54,51,0,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,10,0,0,0,0,0,0,73,84,82,75,0,0,0,0,101,97,99,51,0,0,0,0,114,97,119,32,86,67,45,49,0,0,0,0,0,0,0,0,101,103,97,0,0,0,0,0,71,67,83,95,87,71,83,95,55,50,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,110,111,114,109,97,108,0,0,116,97,114,103,97,0,0,0,115,49,54,108,101,0,0,0,115,49,54,108,101,0,0,0,115,116,114,101,97,109,95,115,101,103,109,101,110,116,44,115,115,101,103,109,101,110,116,0,37,115,99,111,110,102,105,103,117,114,97,116,105,111,110,58,32,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,10,0,83,101,103,97,32,70,73,76,77,32,47,32,67,80,75,0,83,68,82,50,0,0,0,0,100,105,115,97,98,108,101,32,65,86,80,97,114,115,101,114,115,44,32,116,104,105,115,32,110,101,101,100,115,32,110,111,102,105,108,108,105,110,32,116,111,111,0,0,0,0,0,0,84,111,111,32,108,105,116,116,108,101,32,71,69,79,66,32,100,97,116,97,10,0,0,0,79,103,103,83,0,0,0,0,50,48,48,54,47,48,52,47,48,49,32,49,49,58,49,49,58,49,49,0,0,0,0,0,85,115,101,114,68,97,116,97,37,115,45,83,68,45,37,100,0,0,0,0,0,0,0,0,80,97,108,101,116,116,101,0,115,97,109,112,108,101,95,99,111,100,105,110,103,0,0,0,115,111,117,114,99,101,32,109,97,114,107,101,100,32,97,115,32,105,110,116,101,114,108,97,99,101,100,32,98,117,116,32,99,111,100,101,99,32,112,114,111,102,105,108,101,32,105,115,32,112,114,111,103,114,101,115,115,105,118,101,10,0,0,0,114,101,97,100,32,112,97,115,116,32,101,110,100,32,111,102,32,75,76,86,32,64,32,37,35,108,108,120,10,0,0,0,118,105,100,101,111,32,99,111,109,112,114,101,115,115,105,111,110,32,37,115,0,0,0,0,116,105,109,101,32,98,97,115,101,32,110,111,116,32,115,101,116,10,0,0,0,0,0,0,99,103,97,0,0,0,0,0,116,105,116,108,101,0,0,0,71,67,83,95,67,111,110,97,107,114,121,95,49,57,48,53,0,0,0,0,0,0,0,0,114,101,97,100,32,115,116,114,101,97,109,32,102,105,108,116,101,114,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,102,114,111,109,32,97,32,102,105,108,101,0,115,116,114,105,99,116,108,121,32,99,111,110,102,111,114,109,32,116,111,32,97,108,108,32,116,104,101,32,116,104,105,110,103,115,32,105,110,32,116,104,101,32,115,112,101,99,32,110,111,32,109,97,116,116,101,114,32,119,104,97,116,32,116,104,101,32,99,111,110,115,101,113,117,101,110,99,101,115,0,0,84,114,121,32,116,111,32,102,105,120,32,112,116,115,32,118,97,108,117,101,115,32,111,102,32,100,118,98,32,116,101,108,101,116,101,120,116,32,115,116,114,101,97,109,115,46,0,0,97,117,100,105,111,0,0,0,118,99,100,32,109,117,120,101,114,0,0,0,0,0,0,0,79,110,50,32,86,80,54,32,40,70,108,97,115,104,32,118,101,114,115,105,111,110,41,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,44,32,110,111,116,32,119,114,105,116,105,110,103,32,88,105,110,103,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,101,109,99,99,32,40,69,109,115,99,114,105,112,116,101,110,32,71,67,67,45,108,105,107,101,32,114,101,112,108,97,99,101,109,101,110,116,41,32,49,46,49,50,46,48,32,40,99,111,109,109,105,116,32,54,57,54,48,100,50,50,57,54,50,57,57,101,57,54,100,52,51,101,54,57,52,56,48,54,102,53,100,51,53,55,57,57,101,102,56,100,51,57,99,41,0,82,101,99,101,105,118,101,100,32,115,105,103,110,97,108,32,37,100,58,32,116,101,114,109,105,110,97,116,105,110,103,46,10,0,0,0,0,0,0,0,51,103,50,0,0,0,0,0,83,66,97,71,101,110,32,98,105,110,97,117,114,97,108,32,98,101,97,116,115,32,115,99,114,105,112,116,0,0,0,0,67,111,110,118,101,114,116,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,118,101,99,116,111,114,115,99,111,112,101,32,118,105,100,101,111,32,111,117,116,112,117,116,46,0,0,0,0,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,116,105,116,108,101,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,83,65,77,73,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,119,101,98,109,32,109,117,120,101,114,0,0,0,0,0,0,79,110,108,121,32,56,45,98,105,116,32,112,114,101,99,105,115,105,111,110,32,105,115,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,73,110,118,97,108,105,100,32,69,66,77,76,32,110,117,109,98,101,114,32,115,105,122,101,32,116,97,103,32,48,120,37,48,50,120,32,97,116,32,112,111,115,32,37,108,108,117,32,40,48,120,37,108,108,120,41,10,0,0,0,0,0,0,0,78,65,76,32,115,105,122,101,32,37,100,32,62,32,37,100,44,32,116,114,121,32,45,115,108,105,99,101,45,109,97,120,45,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,115,112,108,105,116,32,72,50,54,51,32,112,97,99,107,101,116,44,32,117,115,101,32,45,109,98,95,105,110,102,111,32,37,100,32,111,114,32,45,112,115,32,49,46,10,0,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,32,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,32,37,99,0,0,0,0,0,0,119,104,117,120,103,97,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,86,105,100,101,111,0,0,0,71,67,83,95,68,72,68,78,0,0,0,0,0,0,0,0,102,105,108,116,101,114,95,115,99,114,105,112,116,0,0,0,115,116,114,105,99,116,108,121,32,99,111,110,102,111,114,109,32,116,111,32,97,32,111,108,100,101,114,32,109,111,114,101,32,115,116,114,105,99,116,32,118,101,114,115,105,111,110,32,111,102,32,116,104,101,32,115,112,101,99,32,111,114,32,114,101,102,101,114,101,110,99,101,32,115,111,102,116,119,97,114,101,0,0,0,0,0,0,0,115,116,97,114,116,95,110,117,109,98,101,114,0,0,0,0,118,112,54,102,0,0,0,0,112,105,120,101,108,95,102,111,114,109,97,116,0,0,0,0,102,102,118,49,45,105,109,103,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,115,32,61,61,32,97,118,95,103,101,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,95,110,98,95,99,104,97,110,110,101,108,115,40,108,105,110,107,45,62,99,104,97,110,110,101,108,95,108,97,121,111,117,116,41,32,124,124,32,33,97,118,95,103,101,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,95,110,98,95,99,104,97,110,110,101,108,115,40,108,105,110,107,45,62,99,104,97,110,110,101,108,95,108,97,121,111,117,116,41,0,50,48,58,48,49,58,52,49,0,0,0,0,0,0,0,0,84,80,69,51,0,0,0,0,115,101,116,32,102,105,114,115,116,32,110,117,109,98,101,114,32,105,110,32,116,104,101,32,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,82,84,80,32,111,117,116,112,117,116,0,0,0,0,0,0,98,101,110,99,104,58,32,109,97,120,114,115,115,61,37,105,107,66,10,0,0,0,0,0,99,114,121,112,116,111,58,37,115,0,0,0,0,0,0,0,60,47,109,97,110,105,102,101,115,116,62,10,0,0,0,0,76,101,103,111,32,77,105,110,100,115,116,111,114,109,115,32,82,83,79,0,0,0,0,0,118,105,100,101,111,32,99,111,100,101,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,116,105,109,101,99,111,100,101,95,97,116,95,109,97,114,107,95,111,117,116,0,0,0,0,76,101,103,111,32,77,105,110,100,115,116,111,114,109,115,32,82,83,79,0,0,0,0,0,71,97,109,101,67,117,98,101,32,82,83,68,0,0,0,0,70,76,86,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,119,105,100,101,98,97,110,100,32,40,49,54,107,72,122,41,32,83,112,101,101,120,32,97,117,100,105,111,10,0,97,117,100,105,111,99,111,100,101,99,105,100,0,0,0,0,82,80,76,32,47,32,65,82,77,111,118,105,101,0,0,0,101,108,101,109,101,110,116,32,48,120,37,48,50,120,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,0,82,101,97,108,77,101,100,105,97,0,0,0,0,0,0,0,119,104,115,120,103,97,0,0,101,110,97,98,108,101,32,115,97,102,101,32,109,111,100,101,0,0,0,0,0,0,0,0,71,67,83,95,66,101,108,103,101,95,49,57,55,50,0,0,102,105,108,116,101,114,95,103,114,97,112,104,0,0,0,0,118,101,114,121,0,0,0,0,79,110,50,32,86,80,54,0,116,105,116,108,101,0,0,0,74,117,110,32,32,57,32,50,48,49,52,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,10,0,0,0,0,104,100,114,108,0,0,0,0,82,76,50,0,0,0,0,0,115,116,114,101,97,109,95,105,110,100,101,120,32,60,32,115,45,62,110,98,95,115,116,114,101,97,109,115,0,0,0,0,112,116,115,32,33,61,32,40,40,105,110,116,54,52,95,116,41,48,120,56,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,85,76,76,41,0,105,110,100,101,120,32,61,61,32,115,105,122,101,0,0,0,67,97,110,110,111,116,32,97,112,112,101,110,100,32,112,97,108,101,116,116,101,32,116,111,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,0,40,115,116,97,114,116,38,49,41,32,61,61,32,48,0,0,73,78,70,79,32,115,117,98,99,104,117,110,107,32,116,114,117,110,99,97,116,101,100,10,0,0,0,0,0,0,0,0,115,116,97,114,116,112,116,115,0,0,0,0,0,0,0,0,105,99,104,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,105,110,112,117,116,32,115,116,114,101,97,109,115,46,0,0,0,0,0,0,0,0,115,101,116,32,100,101,108,97,121,32,102,111,114,32,115,97,109,112,108,101,115,32,98,101,102,111,114,101,32,115,101,110,100,105,110,103,32,116,104,101,109,32,116,111,32,118,111,108,117,109,101,32,97,100,106,117,115,116,101,114,0,0,0,0,58,99,104,97,110,110,101,108,115,61,37,100,0,0,0,0,73,110,118,97,108,105,100,32,102,114,101,113,117,101,110,99,121,32,37,102,32,97,110,100,47,111,114,32,119,105,100,116,104,32,37,102,32,60,61,32,48,10,0,0,0,0,0,0,97,114,116,105,115,116,0,0,119,113,117,120,103,97,0,0,71,67,83,95,77,71,73,0,100,101,102,97,117,108,116,0,115,101,116,32,115,116,114,101,97,109,32,102,105,108,116,101,114,103,114,97,112,104,0,0,104,111,119,32,115,116,114,105,99,116,108,121,32,116,111,32,102,111,108,108,111,119,32,116,104,101,32,115,116,97,110,100,97,114,100,115,0,0,0,0,82,101,100,83,112,97,114,107,0,0,0,0,0,0,0,0,118,112,54,0,0,0,0,0,115,105,110,117,115,111,105,100,97,108,0,0,0,0,0,0,84,114,97,110,115,105,116,105,111,110,32,116,105,109,101,44,32,105,110,32,115,101,99,111,110,100,115,44,32,102,111,114,32,118,111,108,117,109,101,32,114,101,110,111,114,109,97,108,105,122,97,116,105,111,110,32,119,104,101,110,32,97,110,32,105,110,112,117,116,32,115,116,114,101,97,109,32,101,110,100,115,46,0,0,0,0,0,0,82,101,97,108,84,101,120,116,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,37,115,98,117,105,108,116,32,111,110,32,37,115,32,37,115,32,119,105,116,104,32,37,115,10,0,0,0,0,0,0,0,32,45,62,32,111,117,116,58,0,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,115,101,116,32,108,105,115,116,32,111,102,32,115,105,103,110,97,108,32,100,101,99,97,121,115,0,0,0,0,0,0,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,102,111,114,99,101,95,107,101,121,95,102,114,97,109,101,115,0,0,0,0,0,0,0,0,121,32,43,32,104,32,60,61,32,116,101,115,116,45,62,104,0,0,0,0,0,0,0,0,71,84,77,111,100,101,108,84,121,112,101,71,101,111,75,101,121,0,0,0,0,0,0,0,71,101,110,101,114,97,116,101,32,115,105,110,101,32,119,97,118,101,32,97,117,100,105,111,32,115,105,103,110,97,108,46,0,0,0,0,0,0,0,0,101,110,100,95,115,99,97,108,101,0,0,0,0,0,0,0,101,110,103,0,0,0,0,0,114,97,116,101,0,0,0,0,114,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,37,115,37,55,105,58,37,45,55,105,0,0,0,0,0,0,119,47,50,0,0,0,0,0,99,104,114,111,109,97,95,97,109,111,117,110,116,0,0,0,108,97,110,100,115,99,97,112,101,0,0,0,0,0,0,0,84,111,116,97,108,32,104,101,105,103,104,116,32,37,117,120,37,117,32,105,115,32,116,111,111,32,109,117,99,104,46,10,0,0,0,0,0,0,0,0,84,104,101,32,105,110,112,117,116,32,110,101,101,100,115,32,97,32,99,111,110,115,116,97,110,116,32,102,114,97,109,101,32,114,97,116,101,59,32,99,117,114,114,101,110,116,32,114,97,116,101,32,111,102,32,37,100,47,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,119,113,115,120,103,97,0,0,71,67,83,95,90,97,110,100,101,114,105,106,0,0,0,0,102,105,108,116,101,114,0,0,98,105,108,105,110,101,97,114,0,0,0,0,0,0,0,0,115,116,114,105,99,116,0,0,115,101,116,32,97,110,103,108,101,32,40,105,110,32,114,97,100,105,97,110,115,41,0,0,79,110,50,32,86,80,53,0,100,101,102,97,117,108,116,0,100,101,102,97,117,108,116,0,32,67,111,112,121,114,105,103,104,116,32,40,99,41,32,37,100,45,37,100,32,116,104,101,32,70,70,109,112,101,103,32,100,101,118,101,108,111,112,101,114,115,0,0,0,0,0,0,116,0,0,0,0,0,0,0,99,48,95,115,101,101,100,0,116,105,102,102,0,0,0,0,109,97,105,110,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,103,108,111,98,97,108,32,111,112,116,105,111,110,115,58,32,0,0,116,105,101,114,116,101,120,115,101,113,118,105,100,101,111,0,99,104,97,112,116,101,114,115,0,0,0,0,0,0,0,0,99,51,0,0,0,0,0,0,114,97,119,32,65,67,45,51,0,0,0,0,0,0,0,0,108,115,0,0,0,0,0,0,37,115,45,0,0,0,0,0,115,101,116,32,116,104,101,32,98,114,105,103,104,116,110,101,115,115,32,101,120,112,114,101,115,115,105,111,110,0,0,0,115,116,101,112,0,0,0,0,108,101,102,116,0,0,0,0,116,101,120,116,0,0,0,0,110,101,97,114,0,0,0,0,116,97,114,103,97,0,0,0,116,97,114,103,97,95,121,50,49,54,0,0,0,0,0,0,37,46,54,103,0,0,0,0,117,121,121,118,121,121,52,49,49,0,0,0,0,0,0,0,65,113,117,97,109,97,114,105,110,101,0,0,0,0,0,0,37,115,0,0,0,0,0,0,97,108,112,104,97,0,0,0,115,113,117,105,115,104,0,0,69,88,84,69,82,78,65,76,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,102,114,111,110,116,32,108,101,102,116,45,111,102,45,99,101,110,116,101,114,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,117,116,105,108,115,46,99,0,0,0,0,0,0,115,112,108,105,110,101,0,0,85,115,105,110,103,32,100,111,117,98,108,101,32,112,114,101,99,105,115,105,111,110,32,109,111,100,101,10,0,0,0,0,116,97,114,103,97,0,0,0,119,111,120,103,97,0,0,0,99,0,0,0,0,0,0,0,92,97,110,37,49,91,92,125,93,37,110,0,0,0,0,0,71,67,83,95,89,111,102,102,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,98,108,97,110,107,0,0,0,82,69,68,67,79,68,69,32,82,51,68,0,0,0,0,0,115,101,116,32,112,114,111,102,105,108,101,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,97,100,112,99,109,95,101,97,95,120,97,115,0,0,0,0,78,111,116,32,73,110,100,105,99,97,116,101,100,32,40,100,101,102,97,117,108,116,41,0,78,111,116,32,73,110,100,105,99,97,116,101,100,32,40,100,101,102,97,117,108,116,41,0,98,108,111,99,107,120,0,0,102,114,97,109,101,32,115,121,110,99,32,101,114,114,111,114,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,116,111,111,32,109,97,110,121,32,83,66,82,32,101,110,118,101,108,111,112,101,115,32,105,110,32,86,65,82,86,65,82,32,116,121,112,101,32,83,66,82,32,102,114,97,109,101,58,32,37,100,10,0,109,115,95,102,111,114,99,101,0,0,0,0,0,0,0,0,118,112,53,0,0,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,116,97,107,0,0,0,0,0,100,101,99,111,100,101,32,112,32,102,114,97,109,101,32,102,97,105,108,101,100,10,0,0,81,67,80,0,0,0,0,0,80,105,120,109,97,112,32,102,111,114,109,97,116,32,37,100,0,0,0,0,0,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,110,117,109,32,115,117,98,102,114,97,109,101,115,32,62,32,51,49,10,0,0,0,0,0,0,0,66,105,116,45,100,101,112,116,104,32,104,105,103,104,101,114,32,116,104,97,110,32,49,54,0,0,0,0,0,0,0,0,98,108,111,99,107,95,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,10,0,92,123,0,0,0,0,0,0,105,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,105,110,100,101,120,32,37,100,10,0,0,0,0,0,0,0,109,105,115,115,105,110,103,32,115,121,110,99,32,105,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,105,110,102,111,32,115,105,122,101,32,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,119,32,62,32,48,32,38,38,32,104,32,62,32,48,0,0,48,46,50,53,47,48,46,49,53,54,32,48,46,53,48,49,47,48,46,53,48,49,32,48,46,54,56,54,47,48,46,55,52,53,0,0,0,0,0,0,80,86,70,32,40,80,111,114,116,97,98,108,101,32,86,111,105,99,101,32,70,111,114,109,97,116,41,0,0,0,0,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,100,99,116,95,99,111,101,102,102,115,10,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,102,108,111,111,114,115,41,46,32,10,0,111,102,102,115,101,116,32,62,32,119,105,100,116,104,32,40,37,100,32,62,32,37,100,41,10,0,0,0,0,0,0,0,70,105,101,108,100,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,0,0,78,117,108,108,32,97,117,100,105,111,32,115,111,117,114,99,101,44,32,114,101,116,117,114,110,32,101,109,112,116,121,32,97,117,100,105,111,32,102,114,97,109,101,115,46,0,0,0,37,115,32,118,101,114,115,105,111,110,32,50,46,50,46,49,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,77,66,32,68,105,114,101,99,116,32,84,121,112,101,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,32,49,46,10,0,0,0,0,79,114,105,103,105,110,97,108,32,102,111,114,109,97,116,32,37,88,10,0,0,0,0,0,98,114,0,0,0,0,0,0,87,97,114,110,105,110,103,58,32,110,111,116,32,99,111,109,112,105,108,101,100,32,119,105,116,104,32,116,104,114,101,97,100,32,115,117,112,112,111,114,116,44,32,117,115,105,110,103,32,116,104,114,101,97,100,32,101,109,117,108,97,116,105,111,110,10,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,108,105,116,101,114,97,108,115,10,0,0,0,0,0,0,100,101,102,108,97,116,101,0,84,101,99,104,110,111,84,114,101,110,100,32,80,86,65,0,98,104,0,0,0,0,0,0,83,111,110,121,32,80,108,97,121,115,116,97,116,105,111,110,32,83,84,82,0,0,0,0,80,67,83,67,105,116,97,116,105,111,110,71,101,111,75,101,121,0,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,98,108,101,110,100,32,109,111,100,101,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,115,108,105,99,101,32,104,101,97,100,101,114,32,40,37,48,50,88,41,10,0,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,123,92,102,115,37,117,125,0,110,111,95,98,105,116,115,116,114,101,97,109,0,0,0,0,83,107,105,112,112,105,110,103,32,77,77,65,80,32,116,114,101,101,10,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,119,97,118,101,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,111,114,99,101,100,32,107,101,121,32,102,114,97,109,101,115,32,97,114,114,97,121,46,10,0,0,0,0,117,110,107,110,111,119,110,32,115,117,98,99,111,100,101,99,32,37,100,0,0,0,0,0,97,116,116,101,109,112,116,105,110,103,32,116,111,32,99,104,97,110,103,101,32,114,101,115,111,108,117,116,105,111,110,32,116,111,32,37,100,120,37,100,10,0,0,0,0,0,0,0,97,118,103,80,80,84,101,120,0,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,33,115,117,112,101,114,98,108,111,99,107,116,121,112,101,95,50,95,51,0,0,0,0,0,80,108,97,121,115,116,97,116,105,111,110,32,80,111,114,116,97,98,108,101,32,80,77,80,0,0,0,0,0,0,0,0,109,97,99,114,111,98,108,111,99,107,115,32,112,101,114,32,115,108,105,99,101,0,0,0,73,110,118,97,108,105,100,32,97,108,112,104,97,32,109,111,100,101,32,37,100,10,0,0,37,100,32,117,110,100,101,99,111,109,112,114,101,115,115,101,100,32,98,121,116,101,115,32,108,101,102,116,32,105,110,32,98,117,102,102,101,114,10,0,101,110,100,0,0,0,0,0,80,74,83,32,40,80,104,111,101,110,105,120,32,74,97,112,97,110,105,109,97,116,105,111,110,32,83,111,99,105,101,116,121,41,32,115,117,98,116,105,116,108,101,115,0,0,0,0,115,101,116,32,108,111,111,112,32,99,111,117,110,116,0,0,119,105,100,116,104,0,0,0,115,118,113,51,0,0,0,0,85,115,101,100,32,99,111,108,111,117,114,115,32,37,100,10,0,0,0,0,0,0,0,0,78,0,0,0,0,0,0,0,111,110,108,121,32,89,85,86,52,50,48,32,97,110,100,32,89,85,86,52,50,50,32,97,114,101,32,115,117,112,112,111,114,116,101,100,10,0,0,0,110,111,32,102,114,97,109,101,32,98,117,102,102,101,114,32,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,97,108,108,32,99,104,97,110,110,101,108,115,10,0,0,37,115,58,37,115,0,0,0,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,97,108,108,32,99,104,97,110,110,101,108,115,10,0,0,85,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,113,112,32,115,101,108,101,99,116,105,111,110,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,85,115,101,32,110,111,110,108,105,110,101,97,114,32,113,117,97,110,116,105,122,101,114,46,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,46,10,0,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,97,117,100,105,111,32,115,97,109,112,108,101,115,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,115,118,113,49,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,37,115,0,0,0,0,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,52,58,50,58,50,46,10,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,83,73,90,10,0,0,0,0,13,10,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,45,32,109,105,110,95,115,105,122,101,32,45,32,114,101,102,95,115,105,122,101,32,62,61,32,114,101,102,95,111,102,102,115,0,0,0,0,0,0,115,116,97,114,116,95,116,105,109,101,58,37,102,32,101,110,100,95,116,105,109,101,58,37,102,32,105,110,100,101,120,58,37,100,10,0,0,0,0,0,113,117,97,110,116,95,109,97,116,32,37,100,32,116,111,111,32,108,97,114,103,101,33,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,113,117,97,110,116,32,109,97,116,114,105,120,32,102,111,114,32,52,120,52,32,98,108,111,99,107,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,0,77,111,100,101,32,37,100,58,32,97,116,116,101,109,112,116,32,116,111,32,114,101,97,100,32,112,97,115,116,32,101,110,100,32,111,102,32,98,117,102,102,101,114,10,0,0,0,0,115,118,113,49,0,0,0,0,68,111,32,97,98,115,111,108,117,116,101,108,121,32,110,111,116,104,105,110,103,32,119,105,116,104,32,116,104,101,32,105,110,112,117,116,32,97,117,100,105,111,46,0,0,0,0,0,117,115,105,110,103,32,104,117,102,102,121,117,118,32,50,46,50,46,48,32,111,114,32,110,101,119,101,114,32,105,110,116,101,114,108,97,99,105,110,103,32,102,108,97,103,10,0,0,108,111,103,50,95,109,97,120,95,112,105,99,95,111,114,100,101,114,95,99,110,116,95,108,115,98,95,109,105,110,117,115,52,32,111,117,116,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,105,110,105,116,105,97,108,32,116,105,108,101,46,10,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,115,101,105,95,114,101,99,111,118,101,114,121,95,102,114,97,109,101,95,99,110,116,58,32,37,100,10,0,0,0,0,0,33,104,45,62,99,117,114,95,112,105,99,95,112,116,114,45,62,108,111,110,103,95,114,101,102,0,0,0,0,0,0,0,56,66,56,0,0,0,0,0,104,97,114,100,119,97,114,101,32,97,99,99,101,108,101,114,97,116,111,114,32,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,112,105,99,116,117,114,101,10,0,0,100,101,102,97,117,108,116,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,112,111,115,32,115,105,122,101,32,37,100,10,0,0,0,0,0,73,110,32,99,104,117,110,107,32,70,76,73,95,67,79,80,89,32,58,32,115,111,117,114,99,101,32,100,97,116,97,32,40,37,100,32,98,121,116,101,115,41,32,104,97,115,32,105,110,99,111,114,114,101,99,116,32,115,105,122,101,44,32,115,107,105,112,112,105,110,103,32,99,104,117,110,107,10,0,0,115,117,110,114,97,115,116,0,122,108,105,98,112,114,105,109,101,95,99,117,114,114,0,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,32,108,112,99,32,116,121,112,101,58,32,76,101,118,105,110,115,111,110,45,68,117,114,98,105,110,32,114,101,99,117,114,115,105,111,110,32,119,105,116,104,32,87,101,108,99,104,32,119,105,110,100,111,119,10,0,105,110,118,97,108,105,100,32,99,111,100,105,110,103,32,116,121,112,101,10,0,0,0,0,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,99,111,108,111,114,115,112,97,99,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,87,0,0,0,0,0,0,0,67,111,112,121,114,105,103,104,116,32,66,105,116,0,0,0,119,117,120,103,97,0,0,0,117,110,107,110,111,119,110,32,99,111,100,101,98,108,111,99,107,32,109,111,100,101,10,0,77,117,108,116,105,112,108,101,32,68,84,83,45,72,68,32,97,117,100,105,111,32,97,115,115,101,116,115,0,0,0,0,74,79,73,78,84,95,83,84,69,82,69,79,10,0,0,0,97,108,108,95,99,104,97,110,110,101,108,95,99,111,117,110,116,115,0,0,0,0,0,0,71,67,83,95,89,97,99,97,114,101,0,0,0,0,0,0,112,114,111,102,105,108,101,0,116,114,117,110,99,0,0,0,115,117,110,114,97,115,116,0,108,106,112,101,103,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,86,77,119,97,114,101,32,83,99,114,101,101,110,32,67,111,100,101,99,32,47,32,86,77,119,97,114,101,32,86,105,100,101,111,0,0,0,0,0,0,97,117,116,111,45,105,110,115,101,114,116,101,100,32,114,101,115,97,109,112,108,101,114,32,37,100,0,0,0,0,0,0,74,111,105,110,116,32,115,116,101,114,101,111,32,100,101,116,101,99,116,101,100,46,10,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,65,100,97,112,116,105,118,101,32,82,76,83,45,76,77,83,32,112,114,101,100,105,99,116,105,111,110,0,0,0,0,0,115,117,98,118,105,101,119,101,114,0,0,0,0,0,0,0,117,115,101,115,102,111,110,116,0,0,0,0,0,0,0,0,98,108,111,99,107,95,114,108,0,0,0,0,0,0,0,0,84,101,99,104,110,111,0,0,87,77,47,79,114,105,103,105,110,97,108,70,105,108,101,110,97,109,101,0,0,0,0,0,40,102,105,108,116,101,114,45,62,102,108,97,103,115,32,38,32,40,40,49,32,60,60,32,49,54,41,32,124,32,40,49,32,60,60,32,49,55,41,41,41,32,33,61,32,40,40,49,32,60,60,32,49,54,41,32,124,32,40,49,32,60,60,32,49,55,41,41,0,0,0,0,100,101,102,97,117,108,116,0,52,50,50,112,49,48,0,0,115,119,114,101,115,97,109,112,108,101,0,0,0,0,0,0,98,108,101,110,100,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,37,115,32,104,119,97,99,99,101,108,32,114,101,113,117,101,115,116,101,100,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,44,32,98,117,116,32,99,97,110,110,111,116,32,98,101,32,105,110,105,116,105,97,108,105,122,101,100,46,10,0,0,0,0,0,0,0,115,114,116,0,0,0,0,0,115,114,116,0,0,0,0,0,115,112,53,120,0,0,0,0,119,115,120,103,97,0,0,0,71,67,83,95,83,116,111,99,107,104,111,108,109,95,49,57,51,56,0,0,0,0,0,0,113,115,99,97,108,101,0,0,119,111,114,107,32,97,114,111,117,110,100,32,118,97,114,105,111,117,115,32,98,117,103,115,32,105,110,32,77,105,99,114,111,115,111,102,116,39,115,32,98,114,111,107,101,110,32,100,101,99,111,100,101,114,115,0,118,109,110,99,0,0,0,0,115,111,110,105,99,0,0,0,115,119,115,99,97,108,101,0,65,112,112,108,121,105,110,103,32,111,112,116,105,111,110,32,37,115,32,40,37,115,41,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,37,115,46,10,0,0,0,0,0,0,37,105,0,0,0,0,0,0,99,97,112,116,105,111,110,115,0,0,0,0,0,0,0,0,102,97,99,116,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,111,112,101,110,105,110,103,32,100,101,99,111,100,101,114,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,58,32,37,115,0,0,0,0,0,0,0,0,115,110,111,119,0,0,0,0,102,111,117,110,100,32,110,111,32,39,102,109,116,32,39,32,116,97,103,32,98,101,102,111,114,101,32,116,104,101,32,39,100,97,116,97,39,32,116,97,103,10,0,0,0,0,0,0,66,65,78,68,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,76,101,110,103,116,104,0,0,115,110,111,119,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2210440);
/* memory initializer */ allocate([65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,0,0,0,0,115,101,112,97,114,97,116,101,32,99,111,108,111,114,32,102,111,114,32,101,97,99,104,32,99,104,97,110,110,101,108,0,115,109,118,106,112,101,103,0,108,105,98,97,118,102,111,114,109,97,116,47,117,116,105,108,115,46,99,0,0,0,0,0,115,109,99,0,0,0,0,0,119,120,103,97,0,0,0,0,98,115,102,115,0,0,0,0,115,116,97,114,116,95,116,105,109,101,0,0,0,0,0,0,71,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,49,57,53,57,0,0,0,0,115,119,102,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,104,97,116,32,115,97,109,112,108,101,32,114,97,116,101,44,32,99,104,111,111,115,101,32,102,114,111,109,32,40,52,52,49,48,48,44,32,50,50,48,53,48,44,32,49,49,48,50,53,41,46,10,0,0,0,0,0,0,97,0,0,0,0,0,0,0,117,115,101,32,102,105,120,101,100,32,113,117,97,108,105,116,121,32,115,99,97,108,101,32,40,86,66,82,41,0,0,0,109,115,0,0,0,0,0,0,74,80,69,71,32,50,48,48,48,0,0,0,0,0,0,0,118,101,114,115,105,111,110,58,32,37,105,32,108,97,121,101,114,58,32,37,105,32,101,120,116,101,110,115,105,111,110,58,32,37,105,10,0,0,0,0,97,118,102,105,108,116,101,114,0,0,0,0,0,0,0,0,60,47,83,109,111,111,116,104,83,116,114,101,97,109,105,110,103,77,101,100,105,97,62,10,0,0,0,0,0,0,0,0,115,109,97,99,107,118,105,100,0,0,0,0,0,0,0,0,115,101,116,32,114,101,100,32,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,0,101,110,97,98,108,101,32,108,105,118,101,45,102,114,105,101,110,100,108,121,32,108,105,115,116,32,103,101,110,101,114,97,116,105,111,110,32,40,117,115,101,102,117,108,32,102,111,114,32,72,76,83,41,0,0,0,115,105,112,114,0,0,0,0,114,101,102,99,111,117,110,116,101,100,95,102,114,97,109,101,115,0,0,0,0,0,0,0,118,61,37,100,13,10,111,61,45,32,37,100,32,37,100,32,73,78,32,37,115,32,37,115,13,10,115,61,37,115,13,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,108,105,110,101,32,37,100,58,32,37,115,32,110,101,97,114,32,37,115,37,46,42,115,37,115,46,10,0,0,0,0,0,0,0,117,110,100,0,0,0,0,0,114,102,99,50,49,57,48,0,97,118,105,111,102,108,97,103,115,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,102,117,108,108,121,32,114,101,97,100,32,98,108,111,99,107,10,0,0,0,0,0,116,114,97,99,107,0,0,0,83,111,110,121,32,79,112,101,110,77,71,32,97,117,100,105,111,0,0,0,0,0,0,0,97,117,100,105,111,47,120,45,100,99,97,0,0,0,0,0,98,108,97,99,107,100,101,116,101,99,116,0,0,0,0,0,118,99,49,0,0,0,0,0,119,118,103,97,0,0,0,0,115,104,111,114,116,101,110,0,86,101,114,116,67,83,95,67,97,115,112,105,97,110,95,83,101,97,0,0,0,0,0,0,71,67,83,95,66,101,114,110,95,49,57,51,56,0,0,0,113,0,0,0,0,0,0,0,100,99,95,99,108,105,112,0,115,103,105,114,108,101,0,0,83,111,110,121,32,79,112,101,110,77,71,32,97,117,100,105,111,0,0,0,0,0,0,0,106,112,101,103,50,48,48,48,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,86,101,114,116,67,83,95,66,97,108,116,105,99,95,83,101,97,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,79,103,103,86,80,56,32,104,101,97,100,101,114,32,112,97,99,107,101,116,0,0,0,0,115,103,105,0,0,0,0,0,86,101,114,116,67,83,95,89,101,108,108,111,119,95,83,101,97,95,49,57,53,54,0,0,97,118,100,101,118,105,99,101,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,115,103,105,0,0,0,0,0,111,117,116,45,111,102,45,109,101,109,111,114,121,32,101,114,114,111,114,46,32,83,107,105,112,112,105,110,103,32,99,111,118,101,114,32,97,114,116,32,98,108,111,99,107,46,10,0,86,101,114,116,67,83,95,78,111,114,116,104,95,65,109,101,114,105,99,97,110,95,86,101,114,116,105,99,97,108,95,68,97,116,117,109,95,49,57,56,56,0,0,0,0,0,0,0,110,111,112,97,114,115,101,0,84,111,111,32,111,108,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,84,104,101,111,114,97,32,40,37,120,41,10,0,0,0,0,0,73,110,118,97,108,105,100,32,101,110,99,114,121,112,116,105,111,110,32,104,101,97,100,101,114,10,0,0,0,0,0,0,115,112,101,101,120,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,86,101,114,116,67,83,95,78,111,114,116,104,95,65,109,101,114,105,99,97,110,95,86,101,114,116,105,99,97,108,95,68,97,116,117,109,95,49,57,50,57,0,0,0,0,0,0,0,68,101,99,111,100,101,114,32,40,99,111,100,101,99,32,37,115,41,32,110,111,116,32,102,111,117,110,100,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,0,0,0,0,115,107,101,108,101,116,111,110,0,0,0,0,0,0,0,0,83,112,101,101,120,32,109,117,120,101,114,0,0,0,0,0,86,101,114,116,67,83,95,78,101,119,108,121,110,0,0,0,72,101,97,100,101,114,115,32,109,105,115,109,97,116,99,104,32,102,111,114,32,115,116,114,101,97,109,32,37,100,58,32,101,120,112,101,99,116,101,100,32,37,100,32,114,101,99,101,105,118,101,100,32,37,100,46,10,0,0,0,0,0,0,0,116,114,107,110,0,0,0,0,79,112,117,115,0,0,0,0,67,111,100,101,99,83,112,101,99,105,102,105,99,83,105,100,101,37,108,108,100,0,0,0,115,97,110,109,0,0,0,0,86,101,114,116,67,83,95,79,83,85,57,49,65,95,101,108,108,105,112,115,111,105,100,0,85,110,107,110,111,119,110,32,115,116,114,105,110,103,32,37,115,32,47,32,37,115,10,0,115,97,109,112,108,101,32,98,121,116,101,32,102,111,114,109,97,116,32,37,115,0,0,0,1,97,117,100,105,111,0,0,86,101,114,116,67,83,95,79,83,85,56,54,70,95,101,108,108,105,112,115,111,105,100,0,99,97,110,110,111,116,32,102,105,108,108,32,100,45,49,48,32,118,105,100,101,111,32,112,97,99,107,101,116,10,0,0,115,97,109,105,0,0,0,0,102,76,97,67,0,0,0,0,102,111,117,110,100,32,101,115,115,101,110,99,101,32,112,114,105,111,114,32,116,111,32,102,105,114,115,116,32,80,97,114,116,105,116,105,111,110,80,97,99,107,10,0,0,0,0,0,75,87,45,68,73,82,65,67,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,71,69,77,95,49,48,67,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,115,51,48,50,109,0,0,0,77,86,67,50,0,0,0,0,115,51,48,50,109,0,0,0,115,97,109,112,108,101,32,114,97,116,101,32,110,111,116,32,115,101,116,10,0,0,0,0,86,101,114,116,67,83,95,87,71,83,95,56,52,95,101,108,108,105,112,115,111,105,100,0,114,118,52,48,0,0,0,0,104,115,120,103,97,0,0,0,86,101,114,116,67,83,95,87,97,114,95,79,102,102,105,99,101,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,115,101,114,118,105,99,101,95,110,97,109,101,0,0,0,0,71,67,83,95,86,111,105,114,111,108,95,85,110,105,102,105,101,0,0,0,0,0,0,0,102,111,117,114,99,99,47,116,97,103,0,0,0,0,0,0,104,112,101,108,95,99,104,114,111,109,97,0,0,0,0,0,102,105,120,95,116,101,108,101,116,101,120,116,95,112,116,115,0,0,0,0,0,0,0,0,118,111,98,32,109,117,120,101,114,0,0,0,0,0,0,0,67,104,105,110,101,115,101,32,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,40,65,86,83,49,45,80,50,44,32,74,105,90,104,117,110,32,112,114,111,102,105,108,101,41,0,0,0,0,86,101,114,116,67,83,95,83,116,114,117,118,101,95,49,56,54,48,95,101,108,108,105,112,115,111,105,100,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,105,110,100,101,120,32,108,105,110,101,32,39,37,115,39,44,32,97,115,115,117,109,105,110,103,32,39,105,100,58,32,117,110,100,44,32,105,110,100,101,120,58,32,48,39,10,0,0,83,108,105,99,101,32,111,102,102,115,101,116,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,86,101,114,116,67,83,95,80,108,101,115,115,105,115,95,49,56,49,55,95,101,108,108,105,112,115,111,105,100,0,0,0,97,118,102,111,114,109,97,116,0,0,0,0,0,0,0,0,79,103,103,0,0,0,0,0,114,118,51,48,0,0,0,0,86,101,114,116,67,83,95,78,87,76,95,49,48,68,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,78,87,76,95,57,68,95,101,108,108,105,112,115,111,105,100,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,68,80,58,10,37,115,10,0,0,0,0,0,0,0,0,79,103,103,0,0,0,0,0,114,118,49,48,0,0,0,0,86,101,114,116,67,83,95,75,114,97,115,115,111,119,115,107,121,95,49,57,52,48,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,78,117,112,112,101,108,86,105,100,101,111,0,0,0,0,0,100,105,115,107,0,0,0,0,86,101,114,116,67,83,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,49,57,54,55,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,105,103,110,111,114,101,95,101,100,105,116,108,105,115,116,0,85,110,115,117,112,112,111,114,116,101,100,32,83,77,65,70,32,99,104,117,110,107,32,37,48,56,120,10,0,0,0,0,86,101,114,116,67,83,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,49,57,50,52,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,104,97,115,104,32,101,110,99,111,100,101,114,32,99,108,97,115,115,0,0,0,0,0,0,83,116,111,114,101,32,97,116,32,109,111,115,116,32,116,104,101,32,112,114,111,118,105,100,101,100,32,110,117,109,98,101,114,32,111,102,32,109,105,108,108,105,115,101,99,111,110,100,115,32,105,110,32,97,32,99,108,117,115,116,101,114,46,0,86,101,114,116,67,83,95,73,78,83,95,101,108,108,105,112,115,111,105,100,0,0,0,0,78,85,84,0,0,0,0,0,82,101,97,100,32,101,114,114,111,114,32,97,116,32,112,111,115,46,32,37,108,108,117,32,40,48,120,37,108,108,120,41,10,0,0,0,0,0,0,0,99,104,114,111,109,97,32,100,99,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,72,101,108,109,101,114,116,95,49,57,48,54,95,101,108,108,105,112,115,111,105,100,0,0,0,84,73,77,69,82,69,83,0,113,115,120,103,97,0,0,0,65,117,100,105,111,0,0,0,86,101,114,116,67,83,95,71,82,83,95,49,57,56,48,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,71,67,83,95,86,111,105,114,111,108,95,49,56,55,53,0,114,112,122,97,0,0,0,0,102,111,114,99,101,32,99,111,100,101,99,32,116,97,103,47,102,111,117,114,99,99,0,0,101,100,103,101,32,112,97,100,100,105,110,103,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,112,101,114,32,70,79,85,82,67,67,47,118,101,114,115,105,111,110,41,0,0,0,0,0,0,117,112,100,97,116,101,0,0,99,97,118,115,0,0,0,0,115,101,108,101,99,116,32,115,101,113,117,101,110,99,101,32,112,97,116,116,101,114,110,32,116,121,112,101,0,0,0,0,86,101,114,116,67,83,95,69,118,101,114,101,115,116,95,49,56,51,48,95,77,111,100,105,102,105,101,100,95,101,108,108,105,112,115,111,105,100,0,0,109,112,103,52,45,105,109,103,0,0,0,0,0,0,0,0,114,111,113,118,105,100,101,111,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,55,53,95,68,101,102,105,110,105,116,105,111,110,95,101,108,108,105,112,115,111,105,100,0,0,0,98,98,111,120,0,0,0,0,97,118,99,111,100,101,99,0,114,111,113,118,105,100,101,111,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,54,55,95,68,101,102,105,110,105,116,105,111,110,95,101,108,108,105,112,115,111,105,100,0,0,0,114,111,113,95,100,112,99,109,0,0,0,0,0,0,0,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,115,116,97,114,116,95,110,117,109,98,101,114,0,0,0,0,114,108,50,0,0,0,0,0,86,101,114,116,67,83,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,51,55,95,65,100,106,117,115,116,109,101,110,116,95,101,108,108,105,112,115,111,105,100,0,0,0,99,114,121,112,116,111,43,37,115,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,114,101,97,108,116,101,120,116,0,0,0,0,0,0,0,0,9,60,47,109,101,100,105,97,62,10,0,0,0,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,83,71,65,95,49,57,50,50,95,101,108,108,105,112,115,111,105,100,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,114,101,115,111,108,117,116,105,111,110,44,32,103,120,102,32,109,117,120,101,114,32,111,110,108,121,32,97,99,99,101,112,116,115,32,80,65,76,32,111,114,32,78,84,83,67,32,114,101,115,111,108,117,116,105,111,110,115,32,99,117,114,114,101,110,116,108,121,10,0,116,114,97,99,107,0,0,0,116,105,109,101,99,111,100,101,95,97,116,95,109,97,114,107,95,105,110,0,0,0,0,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,65,114,99,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,82,71,83,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,118,105,100,101,111,99,111,100,101,99,105,100,0,0,0,0,78,85,84,0,0,0,0,0,114,97,119,32,110,117,108,108,32,118,105,100,101,111,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,73,71,78,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,78,117,108,108,115,111,102,116,32,83,116,114,101,97,109,105,110,103,32,86,105,100,101,111,0,0,0,0,0,0,0,0,110,117,109,95,115,97,109,112,108,101,115,32,40,101,108,101,109,101,110,116,32,48,120,56,53,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,0,0,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,66,101,110,111,105,116,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,115,120,103,97,0,0,0,0,115,97,102,101,0,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,54,54,95,101,108,108,105,112,115,111,105,100,0,0,0,0,71,67,83,95,84,67,95,49,57,52,56,0,0,0,0,0,116,97,103,0,0,0,0,0,101,100,103,101,0,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,118,49,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,53,56,95,101,108,108,105,112,115,111,105,100,0,0,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,78,73,83,84,32,83,80,101,101,99,104,32,72,69,97,100,101,114,32,82,69,115,111,117,114,99,101,115,0,0,0,0,78,67,32,99,97,109,101,114,97,32,102,101,101,100,0,0,86,101,114,116,67,83,95,66,101,115,115,101,108,95,78,97,109,105,98,105,97,95,101,108,108,105,112,115,111,105,100,0,37,115,37,45,49,49,115,32,99,111,110,102,105,103,117,114,97,116,105,111,110,58,32,37,115,10,0,0,0,0,0,0,77,120,80,69,71,32,99,108,105,112,0,0,0,0,0,0,65,86,73,32,0,0,0,0,86,101,114,116,67,83,95,66,101,115,115,101,108,95,77,111,100,105,102,105,101,100,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,117,115,101,32,111,100,109,108,58,37,100,10,0,0,0,0,76,111,111,112,101,110,100,32,112,111,115,105,116,105,111,110,32,105,110,32,109,105,108,108,105,115,101,99,111,110,100,115,46,0,0,0,0,0,0,0,105,110,58,37,100,32,111,117,116,58,37,100,32,116,121,112,101,58,37,100,32,113,58,37,100,32,105,116,101,120,58,37,100,32,112,116,101,120,58,37,100,32,109,118,58,37,100,32,109,105,115,99,58,37,100,32,102,99,111,100,101,58,37,100,32,98,99,111,100,101,58,37,100,32,109,99,45,118,97,114,58,37,108,108,100,32,118,97,114,58,37,108,108,100,32,105,99,111,117,110,116,58,37,100,32,115,107,105,112,99,111,117,110,116,58,37,100,32,104,98,105,116,115,58,37,100,59,10,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,66,101,115,115,101,108,95,49,56,52,49,95,101,108,108,105,112,115,111,105,100,0,0,0,0,112,97,100,115,105,122,101,32,62,61,32,48,0,0,0,0,32,40,37,115,32,45,62,32,37,115,41,0,0,0,0,0,102,114,101,101,105,110,103,32,105,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,44,32,110,101,119,32,37,100,10,0,0,0,0,0,0,86,101,114,116,67,83,95,65,78,83,95,101,108,108,105,112,115,111,105,100,0,0,0,0,100,105,115,99,0,0,0,0,77,88,70,32,40,77,97,116,101,114,105,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,86,101,114,116,67,83,95,65,105,114,121,95,77,111,100,105,102,105,101,100,95,49,56,52,57,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,114,97,108,102,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,86,101,114,116,67,83,95,65,105,114,121,95,49,56,51,48,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,114,101,97,108,95,50,56,56,0,0,0,0,0,0,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,32,115,117,112,112,111,114,116,32,97,32,109,97,120,105,109,117,109,32,111,102,32,37,100,32,99,104,97,110,110,101,108,115,46,32,70,101,101,108,32,102,114,101,101,32,116,111,32,97,115,107,32,102,111,114,32,97,32,104,105,103,104,101,114,32,108,105,109,105,116,46,10,0,0,0,105,110,112,117,116,115,0,0,114,101,97,108,95,49,52,52,0,0,0,0,0,0,0,0,67,84,95,84,114,97,110,115,118,77,101,114,99,97,116,111,114,95,83,111,117,116,104,79,114,105,101,110,116,101,100,0,100,101,108,97,121,0,0,0,114,101,97,108,95,49,52,52,0,0,0,0,0,0,0,0,58,99,104,97,110,110,101,108,95,108,97,121,111,117,116,61,48,120,37,108,108,120,0,0,67,84,95,78,101,119,90,101,97,108,97,110,100,77,97,112,71,114,105,100,0,0,0,0,65,112,112,108,121,32,97,32,98,105,113,117,97,100,32,73,73,82,32,102,105,108,116,101,114,32,119,105,116,104,32,116,104,101,32,103,105,118,101,110,32,99,111,101,102,102,105,99,105,101,110,116,115,46,0,0,113,120,103,97,0,0,0,0,67,84,95,86,97,110,68,101,114,71,114,105,110,116,101,110,0,0,0,0,0,0,0,0,71,67,83,95,84,114,105,110,105,100,97,100,95,49,57,48,51,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,119,105,110,100,111,119,32,108,101,110,103,116,104,0,0,0,114,50,49,48,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,116,111,32,114,101,99,111,114,100,0,0,0,0,0,0,100,105,114,101,99,116,45,113,112,101,108,45,98,108,111,99,107,115,105,122,101,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,112,101,114,32,70,79,85,82,67,67,47,118,101,114,115,105,111,110,41,0,0,0,0,0,102,108,97,115,104,115,118,0,67,84,95,83,105,110,117,115,111,105,100,97,108,0,0,0,116,0,0,0,0,0,0,0,114,50,49,48,0,0,0,0,100,114,111,112,111,117,116,95,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,67,84,95,82,111,98,105,110,115,111,110,0,0,0,0,0,37,115,87,65,82,78,73,78,71,58,32,108,105,98,114,97,114,121,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,113,116,114,108,101,0,0,0,115,116,0,0,0,0,0,0,67,84,95,80,111,108,121,99,111,110,105,99,0,0,0,0,100,101,99,97,121,115,0,0,113,116,114,108,101,0,0,0,77,88,70,32,40,77,97,116,101,114,105,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,116,0,0,0,0,0,0,0,67,84,95,79,114,116,104,111,103,114,97,112,104,105,99,0,32,40,99,111,112,121,41,0,108,105,98,97,118,102,105,108,116,101,114,47,118,115,114,99,95,116,101,115,116,115,114,99,46,99,0,0,0,0,0,0,113,112,101,103,0,0,0,0,77,111,116,105,111,110,32,80,105,120,101,108,115,32,77,86,73,0,0,0,0,0,0,0,67,84,95,77,105,108,108,101,114,67,121,108,105,110,100,114,105,99,97,108,0,0,0,0,115,101,116,32,116,104,101,32,105,110,105,116,105,97,108,32,115,99,97,108,101,32,118,97,108,117,101,0,0,0,0,0,113,100,114,97,119,0,0,0,115,0,0,0,0,0,0,0,67,84,95,71,110,111,109,111,110,105,99,0,0,0,0,0,50,53,0,0,0,0,0,0,97,115,115,117,109,101,32,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,0,67,84,95,67,97,115,115,105,110,105,83,111,108,100,110,101,114,0,0,0,0,0,0,0,115,101,116,32,99,105,114,99,108,101,32,99,101,110,116,101,114,32,112,111,115,105,116,105,111,110,32,111,110,32,120,45,97,120,105,115,0,0,0,0,99,121,0,0,0,0,0,0,67,84,95,69,113,117,105,114,101,99,116,97,110,103,117,108,97,114,0,0,0,0,0,0,112,114,101,115,101,114,118,101,32,112,111,114,116,114,97,105,116,32,103,101,111,109,101,116,114,121,0,0,0,0,0,0,84,111,116,97,108,32,119,105,100,116,104,32,37,117,120,37,117,32,105,115,32,116,111,111,32,109,117,99,104,46,10,0,113,100,109,50,0,0,0,0,100,101,102,97,117,108,116,0,67,84,95,79,98,108,105,113,117,101,83,116,101,114,101,111,103,114,97,112,104,105,99,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,118,105,101,0,0,98,101,0,0,0,0,0,0,117,120,103,97,0,0,0,0,67,84,95,80,111,108,97,114,83,116,101,114,101,111,103,114,97,112,104,105,99,0,0,0,71,67,83,95,84,111,107,121,111,0,0,0,0,0,0,0,113,99,101,108,112,0,0,0,70,108,97,103,115,32,116,111,32,112,97,115,115,32,116,111,32,108,105,98,115,119,115,99,97,108,101,0,0,0,0,0,102,114,97,109,101,115,0,0,100,105,114,101,99,116,95,98,108,111,99,107,115,105,122,101,0,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,75,97,114,108,32,77,111,114,116,111,110,39,115,32,118,105,100,101,111,32,99,111,100,101,99,0,0,0,0,0,0,0,112,116,120,0,0,0,0,0,67,84,95,83,116,101,114,101,111,103,114,97,112,104,105,99,0,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,98,108,97,99,107,0,0,0,67,84,95,69,113,117,105,100,105,115,116,97,110,116,67,111,110,105,99,0,0,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,0,0,0,112,111,115,0,0,0,0,0,117,110,105,102,111,114,109,32,110,111,105,115,101,0,0,0,67,84,95,65,122,105,109,117,116,104,97,108,69,113,117,105,100,105,115,116,97,110,116,0,85,110,97,98,108,101,32,116,111,32,102,105,110,100,32,97,32,115,117,105,116,97,98,108,101,32,111,117,116,112,117,116,32,102,111,114,109,97,116,32,102,111,114,32,39,37,115,39,10,0,0,0,0,0,0,0,111,117,116,112,117,116,32,112,108,97,110,101,32,37,100,32,104,101,105,103,104,116,32,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,105,110,112,117,116,32,37,100,32,112,108,97,110,101,32,37,100,32,104,101,105,103,104,116,32,37,100,10,0,0,0,100,101,102,97,117,108,116,0,77,84,86,0,0,0,0,0,67,84,95,65,108,98,101,114,115,69,113,117,97,108,65,114,101,97,0,0,0,0,0,0,32,91,115,121,110,99,32,35,37,100,58,37,100,93,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,77,83,78,32,84,67,80,32,87,101,98,99,97,109,32,115,116,114,101,97,109,0,0,0,115,119,97,112,32,108,117,109,97,32,102,105,101,108,100,115,0,0,0,0,0,0,0,0,67,84,95,76,97,109,98,101,114,116,65,122,105,109,69,113,117,97,108,65,114,101,97,0,112,114,111,114,101,115,95,107,115,0,0,0,0,0,0,0,69,114,114,111,114,32,115,112,108,105,116,116,105,110,103,32,116,104,101,32,97,114,103,117,109,101,110,116,32,108,105,115,116,58,32,0,0,0,0,0,116,109,112,111,0,0,0,0,115,101,116,32,116,104,101,32,104,117,101,32,97,110,103,108,101,32,114,97,100,105,97,110,115,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,77,80,108,97,121,101,114,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,0,115,101,116,32,115,99,97,108,101,32,104,101,105,103,104,116,0,0,0,0,0,0,0,0,67,84,95,76,97,109,98,101,114,116,67,111,110,102,67,111,110,105,99,95,72,101,108,109,101,114,116,0,0,0,0,0,85,110,107,110,111,119,110,32,112,97,99,107,105,110,103,32,109,111,100,101,46,0,0,0,77,80,76,50,32,115,117,98,116,105,116,108,101,115,0,0,114,111,117,110,100,32,116,111,119,97,114,100,115,32,43,105,110,102,116,121,0,0,0,0,67,84,95,76,97,109,98,101,114,116,67,111,110,102,67,111,110,105,99,95,50,83,80,0,112,114,111,114,101,115,95,97,119,0,0,0,0,0,0,0,115,101,116,100,97,114,0,0,77,73,77,69,32,109,117,108,116,105,112,97,114,116,32,74,80,69,71,0,0,0,0,0,78,79,80,84,83,0,0,0,117,121,118,121,52,50,50,0,67,84,95,77,101,114,99,97,116,111,114,0,0,0,0,0,114,97,119,32,77,80,69,71,32,118,105,100,101,111,0,0,65,113,117,97,0,0,0,0,37,100,120,37,100,0,0,0,110,0,0,0,0,0,0,0,116,105,109,101,0,0,0,0,73,109,109,101,100,105,97,116,101,32,101,120,105,116,32,114,101,113,117,101,115,116,101,100,0,0,0,0,0,0,0,0,115,101,116,32,103,114,101,101,110,32,112,108,97,110,101,0,70,76,67,0,0,0,0,0,67,84,95,79,98,108,105,113,117,101,77,101,114,99,97,116,111,114,95,83,112,104,101,114,105,99,97,108,0,0,0,0,99,45,62,100,115,116,66,112,99,32,62,32,49,52,0,0,108,97,115,116,73,110,67,104,114,66,117,102,32,43,32,49,32,45,32,99,104,114,83,114,99,83,108,105,99,101,89,32,62,61,32,48,0,0,0,0,108,97,110,99,122,111,115,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,104,97,115,32,97,32,100,105,102,102,101,114,101,110,116,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,116,104,97,110,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,117,115,101,100,32,99,104,97,110,110,101,108,115,44,32,105,103,110,111,114,105,110,103,32,108,97,121,111,117,116,10,0,0,0,0,0,0,105,108,108,101,103,97,108,32,105,105,100,10,0,0,0,0,120,103,97,0,0,0,0,0,98,108,97,99,107,0,0,0,112,114,111,114,101,115,95,108,103,112,108,0,0,0,0,0,67,84,95,79,98,108,105,113,117,101,77,101,114,99,97,116,111,114,95,82,111,115,101,110,109,117,110,100,0,0,0,0,92,97,37,50,117,37,49,91,92,125,93,37,110,0,0,0,71,67,83,95,84,77,55,53,0,0,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,115,10,0,0,0,0,0,0,0,115,101,116,32,101,100,103,101,32,109,111,100,101,0,0,0,99,111,112,121,32,111,114,32,100,105,115,99,97,114,100,32,102,114,97,109,101,115,32,98,101,102,111,114,101,32,115,116,97,114,116,32,116,105,109,101,0,0,0,0,0,0,0,0,113,112,101,108,95,99,104,114,111,109,97,50,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,51,0,0,0,0,0,0,0,0,110,111,116,105,110,100,105,99,97,116,101,100,0,0,0,0,110,111,116,105,110,100,105,99,97,116,101,100,0,0,0,0,115,101,116,32,115,99,101,110,101,32,99,104,97,110,103,101,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,76,111,47,82,111,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,116,111,111,32,109,97,110,121,32,83,66,82,32,101,110,118,101,108,111,112,101,115,32,105,110,32,70,73,88,70,73,88,32,116,121,112,101,32,83,66,82,32,102,114,97,109,101,58,32,37,100,10,0,68,105,115,97,98,108,101,32,77,105,100,47,83,105,100,101,32,99,111,100,105,110,103,0,107,109,118,99,0,0,0,0,108,105,98,102,97,97,99,32,37,100,46,37,100,0,0,0,67,84,95,79,98,108,105,113,117,101,77,101,114,99,97,116,111,114,95,76,97,98,111,114,100,101,0,0,0,0,0,0,105,110,112,117,116,32,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,67,111,117,112,108,101,100,32,99,104,97,110,110,101,108,115,32,62,32,54,0,0,0,0,98,108,111,99,107,95,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,10,0,69,120,112,111,110,101,110,116,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,123,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,87,101,98,80,32,76,111,115,115,108,101,115,115,32,118,101,114,115,105,111,110,10,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,99,104,97,110,110,101,108,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,77,97,114,107,101,114,32,98,105,116,32,119,97,115,32,115,101,116,10,0,0,0,0,0,48,47,49,32,48,46,48,57,56,47,49,32,48,46,50,51,53,47,48,46,52,57,56,32,48,46,52,50,51,47,48,32,49,47,48,0,0,0,0,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,98,108,111,99,107,95,113,112,105,115,10,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,116,105,109,101,32,100,111,109,97,105,110,32,116,114,97,110,115,102,111,114,109,115,41,46,32,10,0,84,114,121,105,110,103,32,116,111,32,117,110,112,97,99,107,32,76,90,45,99,111,109,112,114,101,115,115,101,100,32,102,114,97,109,101,32,119,105,116,104,32,110,111,32,76,90,32,98,117,102,102,101,114,10,0,40,115,45,62,109,98,95,104,101,105,103,104,116,32,38,32,49,41,32,61,61,32,48,0,67,84,95,79,98,108,105,113,117,101,77,101,114,99,97,116,111,114,0,0,0,0,0,0,97,118,117,116,105,108,0,0,107,101,101,112,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,0,0,112,114,111,114,101,115,0,0,86,79,80,32,68,81,117,97,110,116,32,105,110,102,111,10,0,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,101,120,116,114,97,100,97,116,97,46,10,0,0,69,110,99,111,100,101,114,32,118,101,114,115,105,111,110,32,37,100,46,37,100,46,37,100,46,37,100,10,0,0,0,0,115,101,116,32,116,104,101,32,97,108,112,104,97,32,103,97,105,110,32,102,111,114,32,116,104,101,32,103,114,101,101,110,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,65,108,116,101,114,110,97,116,105,118,101,108,121,32,117,115,101,32,116,104,101,32,110,111,110,32,101,120,112,101,114,105,109,101,110,116,97,108,32,37,115,32,39,37,115,39,46,10,0,0,0,0,0,0,0,0,84,114,101,101,32,101,120,99,101,101,100,101,100,32,105,116,115,32,103,105,118,101,110,32,100,101,112,116,104,32,40,37,105,41,10,0,0,0,0,0,108,122,119,0,0,0,0,0,115,101,116,32,103,114,101,101,110,32,104,105,103,104,108,105,103,104,116,115,0,0,0,0,67,84,95,84,114,97,110,115,118,77,101,114,99,97,116,111,114,95,77,111,100,105,102,105,101,100,95,65,108,97,115,107,97,0,0,0,0,0,0,0,80,114,111,106,101,99,116,101,100,67,83,84,121,112,101,71,101,111,75,101,121,0,0,0,68,101,99,111,100,101,100,32,111,110,108,121,32,37,105,32,98,121,116,101,115,32,111,102,32,37,105,10,0,0,0,0,99,49,95,109,111,100,101,0,105,110,118,97,108,105,100,32,77,86,32,118,108,99,10,0,77,80,69,71,45,84,83,32,40,77,80,69,71,45,50,32,84,114,97,110,115,112,111,114,116,32,83,116,114,101,97,109,41,0,0,0,0,0,0,0,60,37,99,62,0,0,0,0,37,117,0,0,0,0,0,0,37,108,108,100,0,0,0,0,79,110,108,121,32,100,111,32,77,69,47,77,67,32,40,73,32,102,114,97,109,101,115,32,45,62,32,114,101,102,44,32,80,32,102,114,97,109,101,32,45,62,32,77,69,43,77,67,41,46,0,0,0,0,0,0,67,84,95,84,114,97,110,115,118,101,114,115,101,77,101,114,99,97,116,111,114,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,33,10,0,0,0,0,0,102,109,116,32,99,104,117,110,107,32,119,97,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,0,0,37,108,108,100,0,0,0,0,101,114,114,111,114,32,114,101,115,105,122,105,110,103,32,98,117,102,102,101,114,115,10,0,32,32,83,116,114,101,97,109,32,35,37,100,58,37,100,32,45,62,32,35,37,100,58,37,100,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,112,103,109,0,0,0,0,0,97,118,103,80,73,84,101,120,0,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,84,104,105,115,32,102,105,108,101,32,116,114,105,103,103,101,114,115,32,115,111,109,101,32,117,110,116,101,115,116,101,100,32,99,111,100,101,46,32,80,108,101,97,115,101,32,99,111,110,116,97,99,116,32,116,104,101,32,100,101,118,101,108,111,112,101,114,115,46,10,0,0,109,98,115,95,112,101,114,95,115,108,105,99,101,0,0,0,104,101,97,100,101,114,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,0,112,105,99,116,117,114,101,32,114,101,115,111,108,117,116,105,111,110,32,99,104,97,110,103,101,58,32,37,100,120,37,100,32,45,62,32,37,100,120,37,100,10,0,0,0,0,0,0,105,110,102,108,97,116,101,32,114,101,116,117,114,110,101,100,32,101,114,114,111,114,32,37,100,10,0,0,0,0,0,0,80,114,111,106,95,82,83,79,95,66,111,114,110,101,111,0,84,105,109,101,115,116,97,109,112,32,105,110,32,115,101,99,111,110,100,115,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,112,97,115,115,101,100,0,0,0,103,97,112,108,101,115,115,95,112,108,97,121,98,97,99,107,0,0,0,0,0,0,0,0,108,111,111,112,0,0,0,0,115,97,109,112,108,101,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,117,115,101,100,32,99,111,108,111,117,114,115,32,37,100,10,0,0,0,0,80,114,111,106,95,78,101,116,104,101,114,108,97,110,100,115,95,69,95,73,110,100,105,101,115,95,69,113,117,97,116,111,114,105,97,108,0,0,0,0,73,78,84,69,82,76,65,67,69,68,0,0,0,0,0,0,87,97,114,110,105,110,103,44,32,81,77,65,84,95,83,72,73,70,84,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,37,100,44,32,111,118,101,114,102,108,111,119,115,32,112,111,115,115,105,98,108,101,10,0,0,0,0,0,0,114,101,108,101,97,115,105,110,103,32,122,111,109,98,105,101,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,112,103,109,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,99,104,97,110,110,101,108,32,37,100,10,0,0,0,0,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,99,104,97,110,110,101,108,32,37,100,10,0,0,0,0,102,108,97,103,115,0,0,0,113,112,95,114,100,0,0,0,98,117,103,115,58,32,37,88,32,108,97,118,99,95,98,117,105,108,100,58,37,100,32,120,118,105,100,95,98,117,105,108,100,58,37,100,32,100,105,118,120,95,118,101,114,115,105,111,110,58,37,100,32,100,105,118,120,95,98,117,105,108,100,58,37,100,32,37,115,10,0,0,110,111,110,95,108,105,110,101,97,114,95,113,117,97,110,116,0,0,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,101,120,116,114,97,32,112,105,99,116,117,114,101,32,102,111,108,108,111,119,105,110,103,32,97,32,102,114,97,109,101,45,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,80,114,111,106,95,66,97,104,114,97,105,110,95,71,114,105,100,0,0,0,0,0,0,0,83,117,98,115,116,114,101,97,109,115,32,119,105,116,104,32,86,76,67,32,98,108,111,99,107,32,115,105,122,101,32,99,104,101,99,107,32,105,110,102,111,0,0,0,0,0,0,0,112,105,120,32,102,109,116,32,105,100,32,37,120,10,0,0,99,102,115,104,121,89,112,111,0,0,0,0,0,0,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,49,58,49,58,49,46,10,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,69,79,67,10,0,0,0,0,37,99,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,45,32,109,105,110,95,115,105,122,101,32,62,61,32,111,102,102,115,0,0,0,0,0,80,97,114,115,101,100,32,99,111,109,109,97,110,100,115,58,10,0,0,0,0,0,0,0,116,114,97,110,115,102,111,114,109,32,97,110,100,32,98,108,111,99,107,32,115,105,122,101,32,109,105,115,109,97,116,99,104,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,68,86,66,32,115,117,98,116,105,116,108,101,115,32,119,105,116,104,32,109,117,108,116,105,112,108,101,32,108,97,110,103,117,97,103,101,115,0,0,0,84,104,101,32,98,97,110,100,32,98,108,111,99,107,32,115], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2220680);
/* memory initializer */ allocate([105,122,101,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,105,110,104,101,114,105,116,101,100,10,0,77,111,100,101,32,37,100,58,32,117,110,115,117,112,112,111,114,116,101,100,32,82,76,69,32,99,111,100,101,58,32,37,88,10,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,90,101,97,108,97,110,100,95,83,111,117,116,104,95,73,115,108,97,110,100,95,78,97,116,95,71,114,105,100,0,0,69,114,114,111,114,58,32,118,101,114,62,50,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,104,117,102,102,121,117,118,59,32,117,115,101,32,118,99,111,100,101,99,61,102,102,118,104,117,102,102,10,0,0,0,112,110,103,0,0,0,0,0,110,111,110,45,52,58,50,58,48,32,115,117,112,112,111,114,116,32,105,115,32,99,117,114,114,101,110,116,108,121,32,117,110,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,83,107,105,112,112,105,110,103,32,78,65,76,32,117,110,105,116,32,37,100,10,0,0,0,110,111,110,45,101,120,105,115,116,105,110,103,32,83,80,83,32,37,100,32,114,101,102,101,114,101,110,99,101,100,32,105,110,32,98,117,102,102,101,114,105,110,103,32,112,101,114,105,111,100,10,0,0,0,0,0,112,105,99,116,95,116,121,112,101,0,0,0,0,0,0,0,109,109,99,111,58,32,99,97,110,110,111,116,32,97,115,115,105,103,110,32,99,117,114,114,101,110,116,32,112,105,99,116,117,114,101,32,116,111,32,50,32,108,111,110,103,32,116,101,114,109,32,114,101,102,101,114,101,110,99,101,115,10,0,0,80,73,67,45,65,70,70,0,110,111,32,102,114,97,109,101,33,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,101,101,100,32,102,111,114,32,116,104,101,32,114,97,110,100,111,109,32,109,111,100,101,0,0,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,90,101,97,108,97,110,100,95,78,111,114,116,104,95,73,115,108,97,110,100,95,78,97,116,95,71,114,105,100,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,116,105,108,101,32,37,100,44,37,100,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,121,116,101,32,114,117,110,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,37,100,120,37,100,32,122,108,105,98,112,114,105,109,101,95,99,117,114,114,32,37,100,120,37,100,10,0,0,0,0,0,102,114,97,109,101,32,112,116,115,58,37,102,32,45,62,32,113,117,101,117,101,32,105,100,120,58,37,100,32,97,118,97,105,108,97,98,108,101,58,37,100,10,0,0,0,0,0,0,32,108,112,99,32,116,121,112,101,58,32,70,105,120,101,100,32,112,114,101,45,100,101,102,105,110,101,100,32,99,111,101,102,102,105,99,105,101,110,116,115,10,0,0,0,0,0,0,68,101,99,111,114,114,101,108,97,116,101,100,32,98,105,116,32,100,101,112,116,104,32,62,32,51,50,0,0,0,0,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,32,111,102,32,109,111,114,101,32,116,104,97,110,32,56,32,110,101,101,100,115,32,45,99,111,100,101,114,32,49,32,99,117,114,114,101,110,116,108,121,10,0,0,0,0,99,104,114,111,109,97,32,115,117,98,115,97,109,112,108,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,116,104,105,115,32,99,111,108,111,114,115,112,97,99,101,10,0,0,0,0,90,0,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,115,118,103,97,0,0,0,0,119,58,37,100,32,104,58,37,100,32,112,105,120,102,109,116,58,37,115,32,116,98,58,37,100,47,37,100,32,102,114,58,37,100,47,37,100,32,115,97,114,58,37,100,47,37,100,32,115,119,115,95,112,97,114,97,109,58,37,115,10,0,0,0,101,110,99,111,100,101,32,119,105,116,104,32,65,118,105,100,32,78,105,116,114,105,115,32,99,111,109,112,97,116,105,98,105,108,105,116,121,0,0,0,99,111,100,101,98,108,111,99,107,32,104,101,105,103,104,116,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,68,84,83,45,72,68,32,97,117,100,105,111,32,112,114,101,115,101,110,116,97,116,105,111,110,115,0,0,0,0,0,80,114,111,106,95,69,120,116,101,110,100,101,100,95,80,117,114,112,108,101,95,66,101,108,116,0,0,0,0,0,0,0,67,111,110,116,97,105,110,101,114,32,99,104,97,110,110,101,108,115,32,33,61,32,50,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,115,0,0,0,0,0,0,0,0,71,67,83,95,84,77,54,53,0,0,0,0,0,0,0,0,111,108,100,32,115,116,97,110,100,97,114,100,32,113,112,101,108,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,112,101,114,32,70,79,85,82,67,67,47,118,101,114,115,105,111,110,41,0,0,0,0,0,99,111,112,121,112,114,105,111,114,115,115,0,0,0,0,0,65,112,112,108,101,32,77,74,80,69,71,45,66,0,0,0,72,111,119,32,102,97,115,116,32,116,104,101,32,115,116,114,105,112,32,110,117,109,98,101,114,32,97,100,97,112,116,115,44,32,109,111,114,101,32,105,115,32,115,108,105,103,104,116,108,121,32,98,101,116,116,101,114,44,32,109,117,99,104,32,115,108,111,119,101,114,0,0,112,110,103,0,0,0,0,0,66,77,80,32,100,101,99,111,100,101,114,32,105,115,32,98,114,111,107,101,110,10,0,0,78,117,112,112,101,108,86,105,100,101,111,47,82,84,74,80,69,71,0,0,0,0,0,0,39,97,114,101,115,97,109,112,108,101,39,32,102,105,108,116,101,114,32,110,111,116,32,112,114,101,115,101,110,116,44,32,99,97,110,110,111,116,32,99,111,110,118,101,114,116,32,97,117,100,105,111,32,102,111,114,109,97,116,115,46,10,0,0,80,114,111,106,95,69,103,121,112,116,95,80,117,114,112,108,101,95,66,101,108,116,0,0,73,110,118,97,108,105,100,32,99,111,100,105,110,103,32,109,111,100,101,10,0,0,0,0,73,110,99,111,114,114,101,99,116,32,99,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,37,100,10,0,70,108,111,97,116,105,110,103,32,112,111,105,110,116,32,100,101,99,111,100,105,110,103,0,88,45,85,115,101,115,70,111,110,116,0,0,0,0,0,0,98,108,111,99,107,95,108,114,0,0,0,0,0,0,0,0,82,111,99,107,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,112,105,99,116,111,114,0,0,101,110,97,98,108,101,0,0,99,111,109,109,101,110,116,0,52,50,48,112,49,48,0,0,114,0,0,0,0,0,0,0,80,114,111,106,95,69,103,121,112,116,95,82,101,100,95,66,101,108,116,0,0,0,0,0,37,115,108,105,98,37,45,49,49,115,32,37,50,100,46,37,51,100,46,37,51,100,32,47,32,37,50,100,46,37,51,100,46,37,51,100,10,0,0,0,77,80,69,71,45,49,32,83,121,115,116,101,109,115,32,47,32,77,80,69,71,32,112,114,111,103,114,97,109,32,115,116,114,101,97,109,0,0,0,0,80,114,111,106,95,67,111,108,111,109,98,105,97,95,54,69,0,0,0,0,0,0,0,0,112,103,115,115,117,98,0,0,80,114,111,106,95,67,111,108,111,109,98,105,97,95,51,69,0,0,0,0,0,0,0,0,97,108,112,104,97,109,101,114,103,101,0,0,0,0,0,0,112,99,120,0,0,0,0,0,32,45,62,32,83,116,114,101,97,109,32,35,37,100,58,37,100,32,40,37,115,41,10,0,80,114,111,106,95,67,111,108,111,109,98,105,97,95,66,111,103,111,116,97,0,0,0,0,112,103,97,112,0,0,0,0,112,99,120,0,0,0,0,0,80,114,111,106,95,67,111,108,111,109,98,105,97,95,51,87,0,0,0,0,0,0,0,0,77,80,69,71,45,80,83,32,40,77,80,69,71,45,50,32,80,114,111,103,114,97,109,32,83,116,114,101,97,109,41,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,55,0,0,0,0,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,54,0,0,0,0,0,0,0,0,77,117,115,101,112,97,99,107,32,83,86,56,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,53,0,0,0,0,0,0,0,0,77,117,115,101,112,97,99,107,0,0,0,0,0,0,0,0,118,103,97,0,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,52,0,0,0,0,0,0,0,0,71,67,83,95,84,105,109,98,97,108,97,105,95,49,57,52,56,0,0,0,0,0,0,0,115,116,100,95,113,112,101,108,0,0,0,0,0,0,0,0,99,111,112,121,32,105,110,105,116,105,97,108,32,110,111,110,45,107,101,121,102,114,97,109,101,115,0,0,0,0,0,0,110,117,118,0,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,51,0,0,0,0,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,50,0,0,0,0,0,0,0,0,37,115,37,115,37,115,10,0,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,99,97,110,110,111,116,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,37,115,32,37,115,32,45,45,32,121,111,117,32,97,114,101,32,116,114,121,105,110,103,32,116,111,32,97,112,112,108,121,32,97,110,32,105,110,112,117,116,32,111,112,116,105,111,110,32,116,111,32,97,110,32,111,117,116,112,117,116,32,102,105,108,101,32,111,114,32,118,105,99,101,32,118,101,114,115,97,46,32,77,111,118,101,32,116,104,105,115,32,111,112,116,105,111,110,32,98,101,102,111,114,101,32,116,104,101,32,102,105,108,101,32,105,116,32,98,101,108,111,110,103,115,32,116,111,46,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,95,105,100,32,40,48,120,37,120,41,10,0,0,0,0,87,77,47,77,101,100,105,97,84,104,117,109,98,84,121,112,101,0,0,0,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,49,0,0,0,0,0,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,115,32,107,105,110,100,0,0,0,37,115,32,99,111,100,101,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,87,65,86,69,32,102,111,114,109,97,116,10,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,56,0,0,0,0,0,32,32,37,115,0,0,0,0,102,111,117,110,100,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,39,102,109,116,32,39,32,116,97,103,10,0,77,80,50,47,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,47,51,41,0,0,0,0,97,117,116,104,111,114,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,55,0,0,0,0,0,104,100,95,118,105,100,101,111,0,0,0,0,0,0,0,0,114,116,112,111,0,0,0,0,78,111,109,105,110,97,108,66,105,116,114,97,116,101,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,54,0,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,53,0,0,0,0,0,99,104,97,110,110,101,108,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,52,0,0,0,0,0,115,116,45,62,114,101,113,117,101,115,116,95,112,114,111,98,101,32,60,61,32,48,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,51,0,0,0,0,0,113,118,103,97,0,0,0,0,83,108,97,118,101,32,39,37,115,39,58,32,101,114,114,111,114,32,119,114,105,116,105,110,103,32,104,101,97,100,101,114,58,32,37,115,10,0,0,0,116,101,100,99,97,112,116,105,111,110,115,95,100,101,109,117,120,101,114,0,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,50,0,0,0,0,0,71,67,83,95,84,97,110,97,110,97,114,105,118,101,0,0,70,87,83,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,118,105,100,101,111,32,115,116,114,101,97,109,115,0,0,0,0,0,113,112,101,108,95,99,104,114,111,109,97,0,0,0,0,0,99,111,112,121,105,110,107,102,0,0,0,0,0,0,0,0,83,109,97,99,107,101,114,32,118,105,100,101,111,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,49,0,0,0,0,0,87,114,111,110,103,32,77,80,69,71,32,102,105,108,101,32,102,111,114,109,97,116,10,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,48,0,0,0,0,0,10,37,115,99,111,110,102,105,103,117,114,97,116,105,111,110,58,10,0,0,0,0,0,0,60,81,117,97,108,105,116,121,76,101,118,101,108,32,73,110,100,101,120,61,34,37,100,34,32,66,105,116,114,97,116,101,61,34,37,100,34,32,70,111,117,114,67,67,61,34,37,115,34,32,83,97,109,112,108,105,110,103,82,97,116,101,61,34,37,100,34,32,67,104,97,110,110,101,108,115,61,34,37,100,34,32,66,105,116,115,80,101,114,83,97,109,112,108,101,61,34,49,54,34,32,80,97,99,107,101,116,83,105,122,101,61,34,37,100,34,32,65,117,100,105,111,84,97,103,61,34,37,100,34,32,67,111,100,101,99,80,114,105,118,97,116,101,68,97,116,97,61,34,37,115,34,32,47,62,10,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,52,57,0,0,0,0,0,114,99,0,0,0,0,0,0,112,99,109,95,97,108,97,119,0,0,0,0,0,0,0,0,108,105,118,101,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,52,56,0,0,0,0,0,32,32,70,105,108,101,32,37,115,32,45,62,32,83,116,114,101,97,109,32,35,37,100,58,37,100,10,0,0,0,0,0,112,99,109,95,100,118,100,0,97,61,99,114,121,112,116,111,58,49,32,37,115,32,105,110,108,105,110,101,58,37,115,13,10,0,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,56,0,0,0,104,100,118,100,0,0,0,0,112,99,109,95,98,108,117,114,97,121,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,55,0,0,0,85,115,101,32,77,80,52,65,45,76,65,84,77,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,105,110,115,116,101,97,100,32,111,102,32,77,80,69,71,52,45,71,69,78,69,82,73,67,32,102,111,114,32,65,65,67,0,0,0,0,100,101,102,97,117,108,116,0,73,110,118,97,108,105,100,32,99,111,100,101,99,32,116,97,103,10,0,0,0,0,0,0,78,111,110,45,108,105,110,101,97,114,32,105,110,100,101,120,32,100,101,116,101,99,116,101,100,44,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,54,0,0,0,73,80,82,84,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,53,0,0,0,112,97,109,0,0,0,0,0,114,97,119,32,68,84,83,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,52,0,0,0,114,97,119,32,83,104,111,114,116,101,110,0,0,0,0,0,113,113,118,103,97,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,51,0,0,0,112,97,102,95,118,105,100,101,111,0,0,0,0,0,0,0,71,67,83,95,83,117,100,97,110,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,86,76,67,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,112,101,114,32,70,79,85,82,67,67,41,0,0,0,0,0,0,0,101,114,114,111,114,0,0,0,115,109,97,99,107,118,105,100,101,111,0,0,0,0,0,0,115,49,54,98,101,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,50,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,49,0,0,0,126,0,0,0,0,0,0,0,115,49,54,98,101,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,48,0,0,0,100,111,32,110,111,116,32,102,105,108,108,32,105,110,32,109,105,115,115,105,110,103,32,118,97,108,117,101,115,32,116,104,97,116,32,99,97,110,32,98,101,32,101,120,97,99,116,108,121,32,99,97,108,99,117,108,97,116,101,100,0,0,0,0,75,69,89,82,73,78,71,32,32,32,32,32,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,52,57,0,0,0,32,40,103,114,97,112,104,32,37,100,41,0,0,0,0,0,112,114,101,102,101,114,114,101,100,32,112,97,103,101,32,100,117,114,97,116,105,111,110,44,32,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,0,0,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,52,56,0,0,0,72,101,97,100,101,114,32,112,97,114,115,105,110,103,32,102,97,105,108,101,100,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,109,101,100,105,97,95,116,121,112,101,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,0,0,0,0,0,0,0,80,114,111,106,95,66,76,77,95,49,55,78,95,102,101,101,116,0,0,0,0,0,0,0,115,121,110,99,10,0,0,0,49,0,0,0,0,0,0,0,80,114,111,106,95,66,76,77,95,49,54,78,95,102,101,101,116,0,0,0,0,0,0,0,80,114,111,106,95,66,76,77,95,49,53,78,95,102,101,101,116,0,0,0,0,0,0,0,77,88,70,32,115,116,114,117,99,116,117,114,101,32,108,111,111,112,32,100,101,116,101,99,116,101,100,10,0,0,0,0,49,48,0,0,0,0,0,0,78,111,32,115,116,114,101,97,109,115,32,116,111,32,109,117,120,32,119,101,114,101,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,0,0,80,114,111,106,95,66,76,77,95,49,52,78,95,102,101,101,116,0,0,0,0,0,0,0,49,54,99,105,102,0,0,0,80,114,111,106,95,80,117,101,114,116,111,95,82,105,99,111,95,86,105,114,103,105,110,95,73,115,0,0,0,0,0,0,33,116,115,95,115,116,45,62,112,97,121,108,111,97,100,95,115,105,122,101,0,0,0,0,71,67,83,95,83,101,114,105,110,100,117,110,103,0,0,0,97,99,95,118,108,99,0,0,109,112,101,103,116,115,32,100,101,109,117,120,101,114,0,0,101,120,105,116,32,111,110,32,101,114,114,111,114,0,0,0,80,114,111,106,95,83,116,95,67,114,111,105,120,0,0,0,115,118,99,100,32,109,117,120,101,114,0,0,0,0,0,0,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,118,105,100,101,111,0,0,0,0,0,0,0,0,116,114,105,109,0,0,0,0,105,100,58,32,37,54,51,91,94,44,93,44,32,105,110,100,101,120,58,32,37,117,0,0,76,97,118,102,0,0,0,0,80,114,111,106,95,80,117,101,114,116,111,95,82,105,99,111,95,67,83,50,55,0,0,0,112,107,103,45,99,111,110,102,105,103,32,0,0,0,0,0,102,97,116,97,108,32,101,114,114,111,114,44,32,105,110,112,117,116,32,105,115,32,110,111,116,32,97,32,115,105,110,103,108,101,32,112,97,99,107,101,116,44,32,105,109,112,108,101,109,101,110,116,32,97,32,65,86,80,97,114,115,101,114,32,102,111,114,32,105,116,10,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,53,0,0,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,52,0,0,0,0,0,0,63,0,0,0,0,0,0,0,109,112,52,44,112,115,112,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,51,0,0,0,0,0,0,115,116,105,107,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,50,0,0,0,0,0,0,97,108,108,111,119,32,117,115,105,110,103,32,97,98,115,111,108,117,116,101,32,112,97,116,104,32,119,104,101,110,32,111,112,101,110,105,110,103,32,97,108,105,97,115,44,32,116,104,105,115,32,105,115,32,97,32,112,111,115,115,105,98,108,101,32,115,101,99,117,114,105,116,121,32,105,115,115,117,101,0,77,73,68,73,32,108,105,107,101,32,102,111,114,109,97,116,32,102,111,117,110,100,44,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,49,0,0,0,0,0,0,61,0,0,0,0,0,0,0,99,108,117,115,116,101,114,95,116,105,109,101,95,108,105,109,105,116,0,0,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,53,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,114,97,99,107,32,110,117,109,98,101,114,32,37,100,10,0,0,0,0,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,52,0,0,0,0,0,0,83,72,73,70,84,0,0,0,52,99,105,102,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,102,105,108,116,101,114,105,110,103,46,10,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,51,0,0,0,0,0,0,71,67,83,95,83,101,103,111,114,97,0,0,0,0,0,0,97,109,118,0,0,0,0,0,120,101,114,114,111,114,0,0,99,111,110,116,105,110,117,111,117,115,108,121,32,111,118,101,114,119,114,105,116,101,32,111,110,101,32,102,105,108,101,0,97,118,115,0,0,0,0,0,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,50,0,0,0,0,0,0,109,112,103,50,45,105,109,103,0,0,0,0,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,49,0,0,0,0,0,0,112,107,103,45,99,111,110,102,105,103,126,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,49,48,0,0,0,0,0,84,80,69,50,0,0,0,0,104,108,115,32,109,117,120,101,114,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,57,0,0,0,0,0,0,58,47,47,0,0,0,0,0,32,32,83,116,114,101,97,109,32,35,37,100,58,37,100,32,40,37,115,41,32,45,62,32,37,115,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,105,122,101,32,37,108,108,100,32,105,110,32,115,116,115,100,10,0,0,0,0,0,0,9,9,60,109,101,116,97,100,97,116,97,62,37,115,60,47,109,101,116,97,100,97,116,97,62,10,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,56,0,0,0,0,0,0,118,105,100,101,111,32,115,116,114,101,97,109,32,109,117,115,116,32,98,101,32,116,104,101,32,102,105,114,115,116,32,116,114,97,99,107,10,0,0,0,115,101,97,115,111,110,95,110,117,109,98,101,114,0,0,0,78,111,32,70,80,83,32,116,114,97,99,107,32,116,97,103,44,32,117,115,105,110,103,32,85,77,70,32,102,112,115,32,116,97,103,46,32,84,104,105,115,32,109,105,103,104,116,32,103,105,118,101,32,119,114,111,110,103,32,114,101,115,117,108,116,115,46,10,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,55,0,0,0,0,0,0,89,97,109,97,104,97,32,83,77,65,70,0,0,0,0,0,116,101,120,116,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,54,0,0,0,0,0,0,100,97,116,97,115,116,114,101,97,109,0,0,0,0,0,0,65,109,101,114,105,99,97,110,32,76,97,115,101,114,32,71,97,109,101,115,32,77,77,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,53,0,0,0,0,0,0,101,120,116,114,97,99,116,32,112,116,115,32,97,115,32,116,105,109,101,99,111,100,101,32,118,50,32,102,111,114,109,97,116,44,32,97,115,32,100,101,102,105,110,101,100,32,98,121,32,109,107,118,116,111,111,108,110,105,120,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,32,40,101,108,101,109,101,110,116,32,48,120,56,52,41,32,115,101,116,32,116,111,32,37,105,10,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,52,0,0,0,0,0,0,77,105,99,114,111,68,86,68,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,99,105,102,0,0,0,0,0,99,111,110,99,97,116,32,100,101,109,117,120,101,114,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,51,0,0,0,0,0,0,71,67,83,95,83,99,104,119,97,114,122,101,99,107,0,0,112,97,100,100,105,110,103,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,41,0,0,0,0,0,0,116,105,109,101,115,116,97,109,112,32,101,114,114,111,114,32,100,101,108,116,97,32,116,104,114,101,115,104,111,108,100,0,77,105,99,114,111,68,86,68,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,90,105,112,32,77,111,116,105,111,110,32,66,108,111,99,107,115,32,86,105,100,101,111,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,50,0,0,0,0,0,0,97,117,116,104,111,114,0,0,77,101,116,97,108,32,71,101,97,114,32,83,111,108,105,100,58,32,84,104,101,32,84,119,105,110,32,83,110,97,107,101,115,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,49,0,0,0,0,0,0,126,45,45,0,0,0,0,0,65,86,73,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,62,37,100,32,115,116,114,101,97,109,115,10,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,49,48,0,0,0,0,0,108,111,111,112,101,110,100,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,57,0,0,0,0,0,0,112,97,99,107,101,116,95,104,100,114,95,115,105,122,101,32,60,61,32,97,115,102,45,62,112,97,99,107,101,116,95,115,105,122,101,95,108,101,102,116,0,0,0,0,0,0,0,0,83,116,114,101,97,109,32,109,97,112,112,105,110,103,58,10,0,0,0,0,0,0,0,0,77,68,53,32,116,101,115,116,105,110,103,0,0,0,0,0,97,115,102,95,115,116,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,56,0,0,0,0,0,0,116,118,115,110,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,55,0,0,0,0,0,0,112,116,115,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,54,0,0,0,0,0,0,100,101,102,97,117,108,116,0,67,104,97,110,110,101,108,32,109,97,112,32,100,101,115,99,114,105,98,101,115,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,105,110,112,117,116,32,99,104,97,110,110,101,108,46,10,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,53,0,0,0,0,0,0,115,101,116,32,105,110,105,116,105,97,108,32,118,111,108,117,109,101,0,0,0,0,0,0,116,105,109,101,95,98,97,115,101,61,37,100,47,37,100,58,115,97,109,112,108,101,95,114,97,116,101,61,37,100,58,115,97,109,112,108,101,95,102,109,116,61,37,115,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,52,0,0,0,0,0,0,98,105,113,117,97,100,0,0,113,99,105,102,0,0,0,0,105,110,50,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,51,0,0,0,0,0,0,71,67,83,95,83,97,112,112,101,114,95,72,105,108,108,95,49,57,52,51,0,0,0,0,108,101,110,103,116,104,0,0,110,111,95,112,97,100,100,105,110,103,0,0,0,0,0,0,100,116,115,95,101,114,114,111,114,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,77,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,37,115,10,0,0,122,109,98,118,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,50,0,0,0,0,0,0,116,114,105,97,110,103,117,108,97,114,0,0,0,0,0,0,68,117,114,97,116,105,111,110,32,111,102,32,102,105,114,115,116,32,105,110,112,117,116,46,0,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,49,0,0,0,0,0,0,32,45,45,0,0,0,0,0,32,43,32,0,0,0,0,0,115,101,116,32,116,105,109,101,32,116,111,32,115,116,97,114,116,32,102,97,100,105,110,103,0,0,0,0,0,0,0,0,77,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,56,51,95,87,101,115,116,0,0,49,48,48,48,0,0,0,0,110,98,95,111,117,116,95,99,104,97,110,110,101,108,115,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,56,51,95,87,101,115,116,95,67,101,110,116,114,97,108,0,0,114,116,112,0,0,0,0,0,120,32,43,32,119,32,60,61,32,116,101,115,116,45,62,119,0,0,0,0,0,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,56,51,95,69,97,115,116,95,67,101,110,116,114,97,108,0,0,115,116,97,114,116,95,115,99,97,108,101,0,0,0,0,0,101,112,105,115,111,100,101,95,115,111,114,116,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,56,51,95,69,97,115,116,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,98,102,102,0,0,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,50,55,95,87,101,115,116,0,0,120,48,0,0,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,109,97,116,114,105,120,32,118,101,114,116,105,99,97,108,32,115,105,122,101,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,50,55,95,87,101,115,116,95,67,101,110,116,114,97,108,0,0,112,111,114,116,114,97,105,116,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,50,51,0,0,0,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,50,55,95,69,97,115,116,95,67,101,110,116,114,97,108,0,0,115,113,99,105,102,0,0,0,77,97,116,114,111,115,107,97,32,47,32,87,101,98,77,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,50,55,95,69,97,115,116,0,0,71,67,83,95,83,65,68,54,57,0,0,0,0,0,0,0,114,97,119,32,77,80,69,71,45,52,32,118,105,100,101,111,0,0,0,0,0,0,0,0,102,108,97,103,115,0,0,0,40,97,117,116,111,100,101,116,101,99,116,101,100,32,105,102,32,70,79,85,82,67,67,32,61,61,32,85,77,80,52,41,0,0,0,0,0,0,0,0,116,105,109,101,115,116,97,109,112,32,100,105,115,99,111,110,116,105,110,117,105,116,121,32,100,101,108,116,97,32,116,104,114,101,115,104,111,108,100,0,97,102,116,101,114,32,110,101,119,95,112,114,101,100,0,0,116,0,0,0,0,0,0,0,65,109,101,114,105,99,97,110,32,76,97,115,101,114,32,71,97,109,101,115,32,77,77,32,86,105,100,101,111,0,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,83,101,116,32,102,105,108,101,32,119,104,101,114,101,32,116,111,32,115,116,111,114,101,32,112,101,114,45,102,114,97,109,101,32,100,105,102,102,101,114,101,110,99,101,32,105,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,99,111,108,111,114,32,111,102,32,116,104,101,32,112,97,100,100,101,100,32,97,114,101,97,32,98,111,114,100,101,114,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,32,32,0,0,0,0,0,0,86,82,32,110,97,116,105,118,101,32,115,116,114,101,97,109,32,40,76,88,70,41,0,0,110,0,0,0,0,0,0,0,76,86,70,0,0,0,0,0,117,0,0,0,0,0,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,76,79,65,83,32,65,117,100,105,111,83,121,110,99,83,116,114,101,97,109,0,0,0,0,111,117,116,112,117,116,32,112,108,97,110,101,32,37,100,32,119,105,100,116,104,32,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,105,110,112,117,116,32,37,100,32,112,108,97,110,101,32,37,100,32,119,105,100,116,104,32,37,100,10,0,0,0,0,0,114,97,119,32,108,109,108,109,52,0,0,0,0,0,0,0,105,110,116,101,114,112,111,108,97,116,101,32,118,97,108,117,101,115,32,117,115,105,110,103,32,97,32,116,101,116,114,97,104,101,100,114,111,110,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,119,114,105,116,101,32,104,101,97,100,101,114,32,102,111,114,32,111,117,116,112,117,116,32,102,105,108,101,32,35,37,100,32,40,105,110,99,111,114,114,101,99,116,32,99,111,100,101,99,32,112,97,114,97,109,101,116,101,114,115,32,63,41,58,32,37,115,0,0,0,99,50,0,0,0,0,0,0,108,117,109,97,95,115,119,97,112,0,0,0,0,0,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,116,118,101,115,0,0,0,0,76,79,65,83,47,76,65,84,77,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,115,99,97,108,101,95,104,101,105,103,104,116,0,0,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,117,115,97,103,101,58,32,37,115,32,91,111,112,116,105,111,110,115,93,32,91,91,105,110,102,105,108,101,32,111,112,116,105,111,110,115,93,32,45,105,32,105,110,102,105,108,101,93,46,46,46,32,123,91,111,117,116,102,105,108,101,32,111,112,116,105,111,110,115,93,32,111,117,116,102,105,108,101,125,46,46,46,10,0,0,0,0,0,66,105,116,109,97,112,32,66,114,111,116,104,101,114,115,32,74,86,0,0,0,0,0,0,76,101,102,116,32,97,110,100,32,114,105,103,104,116,32,102,114,97,109,101,114,97,116,101,115,32,100,105,102,102,101,114,32,40,37,100,47,37,100,32,118,115,32,37,100,47,37,100,41,46,10,0,0,0,0,0,117,112,0,0,0,0,0,0,74,65,67,79,115,117,98,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,80,114,111,106,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,120,118,109,99,105,100,99,116,0,0,0,0,0,0,0,0,78,79,0,0,0,0,0,0,80,114,111,106,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,65,110,116,105,113,117,101,87,104,105,116,101,0,0,0,0,78,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,116,111,32,119,104,105,99,104,32,116,104,101,32,101,102,102,101,99,116,32,115,104,111,117,108,100,32,98,101,32,97,112,112,108,105,101,100,46,0,97,98,115,0,0,0,0,0,69,88,73,84,0,0,0,0,80,114,111,106,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,103,0,0,0,0,0,0,0,98,97,99,107,32,114,105,103,104,116,0,0,0,0,0,0,110,117,118,0,0,0,0,0,109,111,118,105,101,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,97,115,116,73,110,67,104,114,66,117,102,32,43,32,49,32,45,32,99,104,114,83,114,99,83,108,105,99,101,89,32,60,32,40,99,104,114,83,114,99,83,108,105,99,101,72,41,0,0,0,0,0,0,0,0,74,65,67,79,115,117,98,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,115,105,110,99,0,0,0,0,82,101,113,117,101,115,116,101,100,32,114,101,115,97,109,112,108,105,110,103,32,101,110,103,105,110,101,32,105,115,32,117,110,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,105,108,108,101,103,97,108,32,105,99,99,10,0,0,0,0,110,116,115,99,45,102,105,108,109,0,0,0,0,0,0,0,115,101,116,32,99,111,108,111,114,32,111,102,32,116,104,101,32,103,114,105,100,0,0,0,79,110,50,32,73,86,70,0,110,101,108,108,121,109,111,115,101,114,0,0,0,0,0,0,80,114,111,106,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,92,97,37,49,91,92,125,93,37,110,0,0,0,0,0,0,71,67,83,95,82,84,51,56,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,58,32,37,100,10,0,0,101,100,103,101,0,0,0,0,117,109,112,52,0,0,0,0,97,100,112,99,109,95,101,97,95,114,51,0,0,0,0,0,100,116,115,95,100,101,108,116,97,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,99,98,112,99,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,82,111,111,109,32,84,121,112,101,0,0,0,0,0,0,0,82,111,111,109,32,84,121,112,101,0,0,0,0,0,0,0,114,101,113,117,101,115,116,101,100,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,46,32,117,115,105,110,103,32,100,101,102,97,117,108,116,32,118,97,108,117,101,58,32,37,48,46,51,102,10,0,0,115,99,116,104,114,101,115,104,0,0,0,0,0,0,0,0,79,110,50,32,73,86,70,0,108,111,114,111,95,115,117,114,109,105,120,108,101,118,0,0,110,101,108,108,121,109,111,115,101,114,0,0,0,0,0,0,82,101,115,101,114,118,101,100,32,83,66,82,32,101,120,116,101,110,115,105,111,110,115,0,109,115,95,111,102,102,0,0,109,109,118,105,100,101,111,0,70,73,76,76,58,37,115,10,0,0,0,0,0,0,0,0,80,114,111,106,95,87,97,115,104,105,110,103,116,111,110,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,100,101,99,111,100,101,32,105,32,102,114,97,109,101,32,102,97,105,108,101,100,10,0,0,105,110,118,97,108,105,100,32,98,121,116,101,115,32,112,101,114,32,115,99,97,110,45,108,105,110,101,10,0,0,0,0,85,110,107,110,111,119,110,32,99,104,97,110,110,101,108,32,116,114,97,110,115,102,111,114,109,32,116,121,112,101,0,0,84,111,111,32,115,109,97,108,108,32,105,110,112,117,116,32,98,117,102,102,101,114,0,0,69,120,112,111,110,101,110,116,32,118,108,99,32,105,110,118,97,108,105,100,10,0,0,0,123,92,117,48,125,0,0,0,72,101,105,103,104,116,32,109,105,115,109,97,116,99,104,46,32,37,100,32,33,61,32,37,100,10,0,0,0,0,0,0,111,112,116,95,109,111,110,111,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,69,88,84,82,65,66,73,84,83,44,32,115,105,122,101,32,61,32,37,105,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,100,105,103,111,86,105,115,105,111,110,32,56,48,48,48,32,118,105,100,101,111,0,73,110,118,97,108,105,100,32,99,111,109,112,114,101,115,115,101,100,32,104,101,97,100,101,114,32,115,105,122,101,10,0,48,47,49,32,48,46,49,48,57,47,49,32,48,46,51,48,49,47,48,46,52,57,56,32,48,46,53,49,55,47,48,32,49,47,48,0,0,0,0,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,118,101,99,116,111,114,115,10,0,0,0,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,99,111,100,101,98,111,111,107,115,41,46,32,10,0,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,112,97,108,101,116,116,101,10,0,0,0,0,0,83,108,105,99,101,32,37,100,32,115,116,97,114,116,115,32,98,101,121,111,110,100,32,112], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2230920);
/* memory initializer */ allocate([105,99,116,117,114,101,32,98,111,117,110,100,97,114,121,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,0,0,80,114,111,106,95,87,97,115,104,105,110,103,116,111,110,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,99,109,100,117,116,105,108,115,46,99,0,0,0,0,0,0,107,101,101,112,95,97,115,112,101,99,116,0,0,0,0,0,77,66,32,83,107,105,112,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,97,116,32,108,101,97,115,116,32,49,54,10,0,0,109,120,112,101,103,0,0,0,67,117,115,116,111,109,32,65,86,73,79,67,111,110,116,101,120,116,32,109,97,107,101,115,32,110,111,32,115,101,110,115,101,32,97,110,100,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,32,119,105,116,104,32,65,86,70,77,84,95,78,79,70,73,76,69,32,102,111,114,109,97,116,46,10,0,0,0,0,0,0,0,0,103,97,0,0,0,0,0,0,84,104,101,32,37,115,32,39,37,115,39,32,105,115,32,101,120,112,101,114,105,109,101,110,116,97,108,32,98,117,116,32,101,120,112,101,114,105,109,101,110,116,97,108,32,99,111,100,101,99,115,32,97,114,101,32,110,111,116,32,101,110,97,98,108,101,100,44,32,97,100,100,32,39,45,115,116,114,105,99,116,32,37,100,39,32,105,102,32,121,111,117,32,119,97,110,116,32,116,111,32,117,115,101,32,105,116,46,10,0,0,0,70,117,110,99,111,109,32,73,83,83,0,0,0,0,0,0,83,101,116,32,100,101,99,111,100,105,110,103,32,112,97,115,115,119,111,114,100,0,0,0,67,97,110,110,111,116,32,98,117,105,108,100,32,86,76,67,32,116,97,98,108,101,10,0,32,73,78,84,69,82,80,79,76,0,0,0,0,0,0,0,114,97,119,0,0,0,0,0,103,104,0,0,0,0,0,0,80,114,111,106,95,87,97,115,104,105,110,103,116,111,110,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,99,111,100,101,99,32,111,112,101,110,32,105,110,32,114,101,97,100,95,100,101,99,95,99,111,110,102,105,103,95,100,101,115,99,114,10,0,0,0,0,71,101,111,103,80,114,105,109,101,77,101,114,105,100,105,97,110,76,111,110,103,71,101,111,75,101,121,0,0,0,0,0,82,117,110,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,109,111,100,101,0,0,0,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,99,104,114,111,109,97,32,97,99,32,98,108,111,99,107,10,0,0,0,60,102,111,110,116,32,99,111,108,111,114,61,34,35,37,48,54,120,34,62,0,0,0,0,115,105,122,101,61,0,0,0,102,114,97,109,101,58,37,108,108,100,32,112,105,99,116,117,114,101,95,98,108,97,99,107,95,114,97,116,105,111,58,37,102,32,112,116,115,58,37,115,32,116,58,37,115,32,116,121,112,101,58,37,99,10,0,0,66,101,114,107,101,108,101,121,47,73,82,67,65,77,47,67,65,82,76,32,83,111,117,110,100,32,70,111,114,109,97,116,0,0,0,0,0,0,0,0,80,114,111,106,95,87,97,115,104,105,110,103,116,111,110,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,109,101,109,99,95,111,110,108,121,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,109,118,99,49,0,0,0,0,110,111,32,102,109,116,32,99,104,117,110,107,32,102,111,117,110,100,10,0,0,0,0,0,37,46,54,103,0,0,0,0,100,105,109,101,110,115,105,111,110,115,32,97,114,101,32,105,110,118,97,108,105,100,10,0,73,110,118,97,108,105,100,32,113,115,99,97,108,101,32,118,97,108,117,101,58,32,48,10,0,0,0,0,0,0,0,0,84,104,101,32,98,105,116,114,97,116,101,32,112,97,114,97,109,101,116,101,114,32,105,115,32,115,101,116,32,116,111,111,32,108,111,119,46,32,73,116,32,116,97,107,101,115,32,98,105,116,115,47,115,32,97,115,32,97,114,103,117,109,101,110,116,44,32,110,111,116,32,107,98,105,116,115,47,115,10,0,97,118,103,73,73,84,101,120,0,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,66,101,114,107,101,108,101,121,47,73,82,67,65,77,47,67,65,82,76,32,83,111,117,110,100,32,70,111,114,109,97,116,0,0,0,0,0,0,0,0,105,110,100,101,120,32,37,100,32,111,117,116,32,111,102,32,116,121,112,101,51,52,95,100,101,108,116,97,32,97,114,114,97,121,10,0,0,0,0,0,80,114,111,82,101,115,32,101,110,99,111,100,101,114,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,58,32,37,100,10,0,117,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,58,32,37,100,10,0,0,0,0,0,0,0,0,109,115,118,105,100,101,111,49,0,0,0,0,0,0,0,0,80,114,111,106,95,86,105,114,103,105,110,105,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,115,116,97,114,116,0,0,0,73,110,116,101,114,112,108,97,121,32,77,86,69,0,0,0,110,101,116,119,111,114,107,0,109,115,118,105,100,101,111,49,0,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,112,107,116,95,115,105,122,101,0,0,0,0,0,0,0,0,114,97,119,32,73,110,103,101,110,105,101,110,116,32,77,74,80,69,71,0,0,0,0,0,83,108,105,99,101,32,115,112,108,105,116,32,37,100,10,0,80,114,111,106,95,86,105,114,103,105,110,105,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,70,82,65,77,69,95,82,65,84,69,0,0,0,0,0,0,83,105,109,117,108,97,116,101,32,101,114,114,111,114,115,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,32,116,111,32,116,101,115,116,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,46,0,0,0,0,0,65,116,116,101,109,112,116,32,116,111,32,115,116,97,114,116,32,97,32,102,114,97,109,101,32,111,117,116,115,105,100,101,32,83,69,84,85,80,32,115,116,97,116,101,10,0,0,0,102,114,97,109,101,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,101,120,99,101,101,100,115,32,99,111,100,101,99,32,99,104,97,110,110,101,108,32,99,111,117,110,116,10,0,0,0,0,0,0,0,0,102,114,97,109,101,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,101,120,99,101,101,100,115,32,99,111,100,101,99,32,99,104,97,110,110,101,108,32,99,111,117,110,116,10,0,0,0,0,0,0,0,0,115,99,97,108,101,0,0,0,83,116,114,105,99,116,108,121,32,101,110,102,111,114,99,101,32,103,111,112,32,115,105,122,101,0,0,0,0,0,0,0,82,101,115,101,114,118,101,32,115,112,97,99,101,32,102,111,114,32,83,86,67,68,32,115,99,97,110,32,111,102,102,115,101,116,32,117,115,101,114,32,100,97,116,97,46,0,0,0,105,103,110,111,114,105,110,103,32,83,69,81,95,83,84,65,82,84,95,67,79,68,69,32,97,102,116,101,114,32,37,88,10,0,0,0,0,0,0,0,109,116,115,50,0,0,0,0,80,114,111,106,95,86,105,114,103,105,110,105,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,78,111,32,115,97,109,112,108,101,115,32,116,111,32,111,117,116,112,117,116,46,10,0,0,112,114,111,103,114,101,115,115,105,118,101,108,121,32,99,111,100,101,100,32,105,110,116,101,114,108,97,99,101,100,32,112,105,99,116,117,114,101,0,0,81,80,58,32,37,100,10,0,123,92,112,111,115,40,37,100,44,37,100,41,125,0,0,0,67,111,100,101,99,32,105,100,32,97,110,100,32,99,111,100,101,99,32,116,121,112,101,32,109,105,115,109,97,116,99,104,46,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,0,0,0,0,66,108,111,99,107,32,108,101,110,103,116,104,32,37,100,32,111,114,32,108,101,110,103,116,104,105,110,99,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,123,92,97,110,57,125,0,0,108,105,98,97,118,99,111,100,101,99,47,105,118,105,95,99,111,109,109,111,110,46,99,0,79,110,108,121,32,111,110,101,32,111,102,32,116,104,101,32,102,105,108,101,110,97,109,101,32,111,114,32,99,111,109,109,97,110,100,115,32,111,112,116,105,111,110,115,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,10,0,69,120,116,101,110,100,101,100,32,116,114,97,110,115,102,111,114,109,32,105,110,102,111,0,81,117,97,110,116,105,122,97,116,105,111,110,32,109,97,116,114,105,120,32,37,100,0,0,77,111,100,101,32,37,100,58,32,82,76,69,45,70,66,32,105,110,118,97,108,105,100,32,99,111,117,110,116,101,114,58,32,37,100,10,0,0,0,0,80,114,111,106,95,86,105,114,103,105,110,105,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,0,0,0,69,114,114,111,114,58,32,112,101,114,45,102,114,97,109,101,32,104,117,102,102,109,97,110,32,116,97,98,108,101,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,104,117,102,102,121,117,118,59,32,117,115,101,32,118,99,111,100,101,99,61,102,102,118,104,117,102,102,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,58,32,37,100,10,0,0,0,0,0,0,69,114,114,111,114,32,99,111,110,115,116,114,117,99,116,105,110,103,32,116,104,101,32,114,101,102,101,114,101,110,99,101,32,108,105,115,116,115,32,102,111,114,32,116,104,101,32,99,117,114,114,101,110,116,32,115,108,105,99,101,46,10,0,0,105,109,97,103,101,50,32,115,101,113,117,101,110,99,101,0,83,69,73,32,70,80,65,32,37,100,32,37,100,32,37,100,32,37,100,32,37,100,32,37,100,10,0,0,0,0,0,0,112,114,101,118,95,115,101,108,101,99,116,101,100,95,116,0,109,109,99,111,58,32,99,97,110,110,111,116,32,97,115,115,105,103,110,32,99,117,114,114,101,110,116,32,112,105,99,116,117,114,101,32,116,111,32,115,104,111,114,116,32,97,110,100,32,108,111,110,103,32,97,116,32,116,104,101,32,115,97,109,101,32,116,105,109,101,10,0,77,66,45,65,70,70,0,0,81,50,54,52,0,0,0,0,109,115,97,49,0,0,0,0,115,101,101,100,0,0,0,0,80,114,111,106,95,86,101,114,109,111,110,116,95,67,83,56,51,0,0,0,0,0,0,0,101,80,73,67,32,106,45,98,32,99,111,109,112,114,101,115,115,105,111,110,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,10,0,0,0,0,85,110,100,101,102,105,110,101,100,32,111,112,99,111,100,101,32,40,37,120,41,32,105,110,32,68,69,76,84,65,95,70,76,73,10,0,0,0,0,0,37,100,120,37,100,32,122,108,105,98,112,114,105,109,101,95,112,114,101,118,10,0,0,0,78,79,80,84,83,32,118,97,108,117,101,32,102,111,114,32,105,110,112,117,116,32,102,114,97,109,101,32,99,97,110,110,111,116,32,98,101,32,97,99,99,101,112,116,101,100,44,32,102,114,97,109,101,32,100,105,115,99,97,114,100,101,100,10,0,0,0,0,0,0,0,0,32,108,112,99,32,116,121,112,101,58,32,78,111,110,101,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,119,97,115,116,101,100,32,98,105,116,115,32,62,32,97,118,97,105,108,97,98,108,101,32,98,105,116,115,32,40,37,100,41,32,45,32,108,101,102,116,61,37,100,10,0,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,32,62,32,56,44,32,102,111,114,99,105,110,103,32,99,111,100,101,114,32,49,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,103,101,32,111,102,32,103,108,111,98,97,108,32,112,97,114,97,109,101,116,101,114,115,10,0,0,0,0,66,0,0,0,0,0,0,0,83,109,97,108,108,32,82,111,111,109,0,0,0,0,0,0,102,105,108,109,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,115,32,112,114,111,118,105,100,101,100,46,10,0,0,0,110,105,116,114,105,115,95,99,111,109,112,97,116,0,0,0,99,111,100,101,98,108,111,99,107,32,119,105,100,116,104,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,100,102,97,46,99,0,0,0,0,0,0,0,0,78,111,116,32,105,109,112,108,101,109,101,110,116,101,100,33,10,0,0,0,0,0,0,0,80,114,111,106,95,86,101,114,109,111,110,116,95,67,83,50,55,0,0,0,0,0,0,0,83,84,69,82,69,79,10,0,99,104,97,110,110,101,108,95,99,111,117,110,116,115,0,0,71,67,83,95,65,109,101,114,115,102,111,111,114,116,0,0,88,118,105,100,32,105,110,116,101,114,108,97,99,105,110,103,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,105,102,32,70,79,85,82,67,67,32,61,61,32,88,86,73,88,41,0,0,0,80,32,99,98,112,121,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,97,117,100,105,111,32,112,97,100,0,0,0,0,0,0,0,109,106,112,101,103,98,0,0,115,116,114,105,112,95,110,117,109,98,101,114,95,97,100,97,112,116,105,118,105,116,121,0,68,105,109,101,110,115,105,111,110,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,112,97,108,101,116,116,101,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,112,97,99,107,101,116,10,0,0,67,97,109,83,116,117,100,105,111,0,0,0,0,0,0,0,97,114,101,115,97,109,112,108,101,0,0,0,0,0,0,0,109,115,115,50,0,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,78,111,114,109,97,108,32,115,116,101,114,101,111,32,100,101,116,101,99,116,101,100,46,10,0,0,0,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,76,101,118,101,108,58,32,37,100,32,45,32,70,108,97,103,115,58,32,37,100,10,0,0,0,0,0,0,65,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,32,109,101,109,111,114,121,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,0,117,115,101,115,0,0,0,0,97,110,97,103,108,121,112,104,95,103,114,101,101,110,95,109,97,103,101,110,116,97,0,0,82,101,103,103,97,101,0,0,87,77,47,76,97,110,103,117,97,103,101,0,0,0,0,0,37,115,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,52,52,52,112,49,50,0,0,50,53,0,0,0,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,105,32,61,61,32,110,98,95,99,111,100,101,99,115,0,0,80,114,111,98,101,32,119,105,116,104,32,115,105,122,101,61,37,100,44,32,112,97,99,107,101,116,115,61,37,100,32,100,101,116,101,99,116,101,100,32,37,115,32,119,105,116,104,32,115,99,111,114,101,61,37,100,10,0,0,0,0,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,115,112,108,105,116,0,0,0,105,109,97,103,101,50,32,115,101,113,117,101,110,99,101,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,10,0,80,114,111,106,95,85,116,97,104,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,109,115,115,49,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,111,112,101,110,105,110,103,32,101,110,99,111,100,101,114,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,45,32,109,97,121,98,101,32,105,110,99,111,114,114,101,99,116,32,112,97,114,97,109,101,116,101,114,115,32,115,117,99,104,32,97,115,32,98,105,116,95,114,97,116,101,44,32,114,97,116,101,44,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,0,0,0,0,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,116,118,110,110,0,0,0,0,85,110,107,110,111,119,110,32,100,101,112,116,104,32,37,100,10,0,0,0,0,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,109,115,114,108,101,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,83,111,117,116,104,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,83,111,117,116,104,95,67,101,110,116,114,97,108,0,0,0,106,112,103,0,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,67,101,110,116,114,97,108,0,105,76,66,67,32,115,116,111,114,97,103,101,0,0,0,0,115,112,97,108,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,78,111,114,116,104,95,67,101,110,116,114,97,108,0,0,0,71,67,83,95,76,111,109,97,95,81,117,105,110,116,97,110,97,0,0,0,0,0,0,0,120,118,105,100,95,105,108,97,99,101,0,0,0,0,0,0,68,67,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,97,112,97,100,0,0,0,0,99,115,99,100,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,78,111,114,116,104,0,0,0,73,70,70,32,40,73,110,116,101,114,99,104,97,110,103,101,32,70,105,108,101,32,70,111,114,109,97,116,41,0,0,0,105,110,118,97,108,105,100,32,115,116,97,114,116,99,111,100,101,10,0,0,0,0,0,0,114,97,119,32,105,100,32,82,111,81,0,0,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,83,111,117,116,104,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,97,114,115,105,110,103,32,97,32,103,114,111,117,112,32,111,102,32,111,112,116,105,111,110,115,58,32,37,115,32,37,115,46,10,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,100,101,99,95,116,121,112,101,32,40,48,120,37,120,41,10,0,0,0,0,0,0,105,100,32,82,111,81,0,0,109,112,101,103,118,105,100,101,111,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,103,117,105,100,32,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,44,32,101,120,112,101,99,116,101,100,32,109,101,116,97,100,97,116,97,95,103,117,105,100,59,32,114,101,109,97,105,110,105,110,103,32,109,101,116,97,100,97,116,97,32,101,110,116,114,105,101,115,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,83,111,117,116,104,95,67,101,110,116,114,97,108,0,0,0,105,100,32,67,105,110,101,109,97,116,105,99,0,0,0,0,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,0,102,109,116,32,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,67,101,110,116,114,97,108,0,109,112,108,50,0,0,0,0,110,101,103,97,116,105,118,101,32,100,97,116,97,95,115,105,122,101,32,97,110,100,47,111,114,32,115,97,109,112,108,101,95,99,111,117,110,116,32,105,110,32,100,115,54,52,58,32,100,97,116,97,95,115,105,122,101,32,61,32,37,108,108,100,44,32,115,97,109,112,108,101,95,99,111,117,110,116,32,61,32,37,108,108,100,10,0,0,97,117,116,111,0,0,0,0,77,80,69,71,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,111,117,116,32,111,102,32,98,111,117,110,100,97,114,121,32,40,37,100,32,37,100,41,10,0,0,0,0,0,65,85,84,72,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,78,111,114,116,104,95,67,101,110,116,114,97,108,0,0,0,101,112,105,115,111,100,101,95,105,100,0,0,0,0,0,0,83,97,109,112,108,105,110,103,70,114,101,113,117,101,110,99,121,0,0,0,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,78,111,114,116,104,0,0,0,80,114,111,106,95,84,101,110,110,101,115,115,101,101,95,67,83,56,51,0,0,0,0,0,115,101,116,32,99,104,97,110,110,101,108,32,99,111,108,111,114,105,110,103,0,0,0,0,80,114,111,106,95,84,101,110,110,101,115,115,101,101,95,67,83,50,55,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,114,111,106,95,83,111,117,116,104,95,68,97,107,111,116,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,115,110,116,115,99,0,0,0,83,108,97,118,101,32,39,37,115,39,58,32,101,114,114,111,114,32,111,112,101,110,105,110,103,58,32,37,115,10,0,0,83,87,82,0,0,0,0,0,32,9,13,10,0,0,0,0,80,114,111,106,95,83,111,117,116,104,95,68,97,107,111,116,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,71,67,83,95,81,111,114,110,111,113,0,0,0,0,0,0,83,87,70,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,86,80,54,44,32,70,76,86,49,32,97,110,100,32,77,74,80,69,71,10,0,0,0,0,115,111,109,101,32,111,108,100,32,108,97,118,99,45,103,101,110,101,114,97,116,101,100,32,77,83,77,80,69,71,52,118,51,32,102,105,108,101,115,32,40,110,111,32,97,117,116,111,100,101,116,101,99,116,105,111,110,41,0,0,0,0,0,0,118,0,0,0,0,0,0,0,73,32,99,98,112,121,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,102,105,110,105,115,104,32,101,110,99,111,100,105,110,103,32,119,105,116,104,105,110,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,0,0,0,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,44,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,37,99,0,0,0,0,0,0,0,66,77,80,32,40,87,105,110,100,111,119,115,32,97,110,100,32,79,83,47,50,32,98,105,116,109,97,112,41,0,0,0,80,114,111,106,95,83,111,117,116,104,95,68,97,107,111,116,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,68,84,83,45,72,68,32,98,105,116,114,97,116,101,32,116,111,111,32,104,105,103,104,44,32,116,101,109,112,111,114,97,114,105,108,121,32,115,101,110,100,105,110,103,32,99,111,114,101,32,111,110,108,121,10,0,80,114,111,106,95,83,111,117,116,104,95,68,97,107,111,116,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,60,83,116,114,101,97,109,73,110,100,101,120,32,84,121,112,101,61,34,97,117,100,105,111,34,32,81,117,97,108,105,116,121,76,101,118,101,108,115,61,34,37,100,34,32,67,104,117,110,107,115,61,34,37,100,34,32,85,114,108,61,34,81,117,97,108,105,116,121,76,101,118,101,108,115,40,123,98,105,116,114,97,116,101,125,41,47,70,114,97,103,109,101,110,116,115,40,97,117,100,105,111,61,123,115,116,97,114,116,32,116,105,109,101,125,41,34,62,10,0,109,52,118,0,0,0,0,0,80,114,111,106,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,67,83,56,51,0,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,97,108,108,111,119,32,108,105,115,116,32,99,97,99,104,105,110,103,0,0,0,0,0,0,80,114,111,106,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,67,83,50,55,95,83,111,117,116,104,0,0,116,104,114,101,97,100,115,0,115,114,116,112,95,111,117,116,95,112,97,114,97,109,115,0,80,114,111,106,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,67,83,50,55,95,78,111,114,116,104,0,0,116,104,101,32,101,110,100,32,111,102,32,108,105,110,101,0,116,118,101,110,0,0,0,0,97,108,98,117,109,0,0,0,80,114,111,106,95,82,104,111,100,101,95,73,115,108,97,110,100,95,67,83,56,51,0,0,108,97,116,109,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,0,0,0,0,0,78,114,46,32,111,102,32,112,97,99,107,101,116,115,32,105,110,32,112,97,99,107,101,116,32,105,110,100,101,120,32,102,111,114,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,32,101,120,99,101,101,100,115,32,102,105,108,101,115,105,122,101,32,40,37,108,108,100,32,97,116,32,37,108,108,100,32,61,32,37,108,108,100,41,10,0,0,0,0,0,0,77,105,99,114,111,115,111,102,116,32,87,105,110,100,111,119,115,32,73,67,79,0,0,0,80,114,111,106,95,82,104,111,100,101,95,73,115,108,97,110,100,95,67,83,50,55,0,0,97,108,98,117,109,0,0,0,77,105,99,114,111,115,111,102,116,32,87,105,110,100,111,119,115,32,73,67,79,0,0,0,109,112,118,95,102,108,97,103,115,0,0,0,0,0,0,0,80,114,111,106,95,80,101,110,110,115,121,108,118,97,110,105,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,67,114,121,111,32,72,78,77,32,118,52,0,0,0,0,0,100,116,115,0,0,0,0,0,80,114,111,106,95,80,101,110,110,115,121,108,118,97,110,105,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,115,104,110,0,0,0,0,0,108,101,0,0,0,0,0,0,113,112,97,108,0,0,0,0,115,101,116,32,115,119,114,32,110,117,109,98,101,114,32,111,102,32,111,117,116,112,117,116,32,115,97,109,112,108,101,32,98,105,116,115,0,0,0,0,80,114,111,106,95,80,101,110,110,115,121,108,118,97,110,105,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,71,67,83,95,81,97,116,97,114,95,49,57,52,56,0,0,111,108,100,95,109,115,109,112,101,103,52,0,0,0,0,0,99,98,112,121,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,80,114,111,106,95,80,101,110,110,115,121,108,118,97,110,105,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,98,109,112,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,110,95,102,111,114,99,101,100,0,0,0,0,0,0,0,0,65,112,112,108,101,32,72,84,84,80,32,76,105,118,101,32,83,116,114,101,97,109,105,110,103,0,0,0,0,0,0,0,80,114,111,106,95,79,114,101,103,111,110,95,67,83,56,51,95,83,111,117,116,104,0,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,108,111,97,115,0,0,0,0,80,114,111,106,95,79,114,101,103,111,110,95,67,83,56,51,95,78,111,114,116,104,0,0,110,111,102,105,108,108,105,110,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,105,110,32,101,110,99,114,121,112,116,105,111,110,32,104,101,97,100,101,114,10,0,0,0,80,114,111,106,95,79,114,101,103,111,110,95,67,83,50,55,95,83,111,117,116,104,0,0,67,97,110,110,111,116,32,119,114,105,116,101,32,108,111,103,32,102,105,108,101,32,39,37,115,39,32,102,111,114,32,112,97,115,115,45,49,32,101,110,99,111,100,105,110,103,58,32,37,115,10,0,0,0,0,0,112,97,103,101,95,100,117,114,97,116,105,111,110,0,0,0,80,114,111,106,95,79,114,101,103,111,110,95,67,83,50,55,95,78,111,114,116,104,0,0,108,105,98,97,118,102,111,114,109,97,116,47,111,103,103,100,101,99,46,99,0,0,0,0,115,104,111,119,0,0,0,0,65,112,112,108,101,32,72,84,84,80,32,76,105,118,101,32,83,116,114,101,97,109,105,110,103,0,0,0,0,0,0,0,80,97,108,101,116,116,101,0,114,97,119,32,72,69,86,67,32,118,105,100,101,111,0,0,80,114,111,106,95,79,107,108,97,104,111,109,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,115,121,110,99,105,110,103,32,102,114,111,109,32,37,108,108,100,10,0,0,0,0,0,0,49,48,0,0,0,0,0,0,80,114,111,106,95,79,107,108,97,104,111,109,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,114,111,106,95,79,107,108,97,104,111,109,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,104,101,97,100,101,114,32,112,97,114,116,105,116,105,111,110,32,112,97,99,107,32,107,101,121,10,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,82,101,99,101,105,118,101,100,32,97,32,112,97,99,107,101,116,32,102,111,114,32,97,110,32,97,116,116,97,99,104,109,101,110,116,32,115,116,114,101,97,109,46,10,0,0,0,0,80,114,111,106,95,79,107,108,97,104,111,109,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,37,115,37,115,0,0,0,0,113,110,116,115,99,0,0,0,111,117,116,112,117,116,95,115,97,109,112,108,101,95,98,105,116,115,0,0,0,0,0,0,72,68,83,32,77,117,120,101,114,0,0,0,0,0,0,0,80,114,111,106,95,79,104,105,111,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,65,65,67,32,98,105,116,115,116,114,101,97,109,32,110,111,116,32,105,110,32,65,68,84,83,32,102,111,114,109,97,116,32,97,110,100,32,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,10,0,71,67,83,95,81,97,116,97,114,0,0,0,0,0,0,0,97,117,116,111,100,101,116,101,99,116,0,0,0,0,0,0,109,112,50,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,115,101,101,107,32,98,97,99,107,32,116,111,32,116,104,101,32,115,116,97,114,116,10,0,0,0,0,0,0,0,114,118,108,99,32,0,0,0,109,111,100,101,0,0,0,0,114,97,119,32,72,46,50,54,52,32,118,105,100,101,111,0,73,110,105,116,105,97,108,32,100,101,109,117,120,45,100,101,99,111,100,101,32,100,101,108,97,121,32,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,46,0,0,0,0,0,68,117,99,107,32,84,114,117,101,77,111,116,105,111,110,32,50,46,48,0,0,0,0,0,80,114,111,106,95,79,104,105,111,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,114,97,119,32,72,46,50,54,51,0,0,0,0,0,0,0,105,100,58,0,0,0,0,0,114,97,119,32,72,46,50,54,49,0,0,0,0,0,0,0,109,112,50,102,105,120,101,100,0,0,0,0,0,0,0,0,65,117,100,105,111,32,112,97,99,107,101,116,32,111,102,32,115,105,122,101,32,37,100,32,40,115,116,97,114,116,105,110,103,32,119,105,116,104,32,37,48,56,88,46,46,46,41,32,105,115,32,105,110,118,97,108,105,100,44,32,119,114,105,116,105,110,103,32,105,116,32,97,110,121,119,97,121,46,10,0,80,114,111,106,95,79,104,105,111,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,37,115,32,0,0,0,0,0,104,101,118,99,0,0,0,0,80,114,111,106,95,79,104,105,111,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,71,88,70,32,40,71,101,110,101,114,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,80,114,111,106,95,78,111,114,116,104,95,68,97,107,111,116,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,119,98,0,0,0,0,0,0,80,83,80,32,77,80,52,32,40,77,80,69,71,45,52,32,80,97,114,116,32,49,52,41,0,0,0,0,0,0,0,0,80,114,111,106,95,78,111,114,116,104,95,68,97,107,111,116,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,116,118,115,104,0,0,0,0,80,114,111,106,95,78,111,114,116,104,95,68,97,107,111,116,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,117,115,101,95,97,98,115,111,108,117,116,101,95,112,97,116,104,0,0,0,0,0,0,0,65,119,97,1,0,0,0,0,71,88,70,32,40,71,101,110,101,114,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,80,114,111,106,95,78,111,114,116,104,95,68,97,107,111,116,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,115,101,116,32,104,97,115,104,32,116,111,32,117,115,101,0,114,97,119,32,71,83,77,0,80,114,111,106,95,78,111,114,116,104,95,67,97,114,111,108,105,110,97,95,67,83,56,51,0,0,0,0,0,0,0,0,83,116,111,114,101,32,97,116,32,109,111,115,116,32,116,104,101,32,112,114,111,118,105,100,101,100,32,97,109,111,117,110,116,32,111,102,32,98,121,116,101,115,32,105,110,32,97,32,99,108,117,115,116,101,114,46,32,0,0,0,0,0,0,0,115,101,116,112,116,115,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,97,116,114,111,115,107,97,100,101,99,46,99,0,0,0,0,0,0,0,67,111,109,112,117,83,101,114,118,101,32,71,114,97,112,104,105,99,115,32,73,110,116,101,114,99,104,97,110,103,101,32,70,111,114,109,97,116,32,40,71,73,70,41,0,0,0,0,86,66,73,32,100,97,116,97,32,110,111,116,32,121,101,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,80,114,111,106,95,78,111,114,116,104,95,67,97,114,111,108,105,110,97,95,67,83,50,55,0,0,0,0,0,0,0,0,82,65,77,80,0,0,0,0,98,103,114,51,50,0,0,0,112,97,108,0,0,0,0,0,115,101,116,32,115,119,114,32,75,97,105,115,101,114,32,87,105,110,100,111,119,32,66,101,116,97,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,56,51,95,76,111,110,103,95,73,115,108,97,110,100,0,0,78,111,32,109,111,114,101,32,111,117,116,112,117,116,32,115,116,114,101,97,109,115,32,116,111,32,119,114,105,116,101,32,116,111,44,32,102,105,110,105,115,104,105,110,103,46,10,0,71,67,83,95,80,117,108,107,111,118,111,95,49,57,52,50,0,0,0,0,0,0,0,0,119,111,114,107,32,97,114,111,117,110,100,32,110,111,116,32,97,117,116,111,100,101,116,101,99,116,101,100,32,101,110,99,111,100,101,114,32,98,117,103,115,0,0,0,0,0,0,0,112,97,114,116,105,116,105,111,110,32,0,0,0,0,0,0,117,112,100,97,116,101,102,105,114,115,116,0,0,0,0,0,99,111,112,121,32,105,110,112,117,116,32,115,116,114,101,97,109,32,116,105,109,101,32,98,97,115,101,32,119,104,101,110,32,115,116,114,101,97,109,32,99,111,112,121,105,110,103,0,71,73,70,32,65,110,105,109,97,116,105,111,110,0,0,0,116,114,117,101,109,111,116,105,111,110,50,0,0,0,0,0,115,101,108,101,99,116,32,103,108,111,98,32,112,97,116,116,101,114,110,32,116,121,112,101,0,0,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,56,51,95,87,101,115,116,0,109,112,103,49,45,105,109,103,0,0,0,0,0,0,0,0,71,46,55,50,57,32,114,97,119,32,102,111,114,109,97,116,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,32,40,37,115,58,32,0,0,71,46,55,50,51,46,49,0,104,50,54,52,0,0,0,0,114,97,119,32,71,46,55,50,50,0,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,56,51,95,69,97,115,116,0,97,114,116,105,115,116,0,0,77,101,103,97,108,117,120,32,70,114,97,109,101,0,0,0,109,112,101,103,116,115,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,50,55,95,76,111,110,103,95,73,115,108,97,110,100,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,107,101,121,32,102,105,108,101,32,37,115,10,0,0,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,108,111,103,32,102,105,108,101,32,39,37,115,39,32,102,111,114,32,112,97,115,115,45,50,32,101,110,99,111,100,105,110,103,10,0,0,0,0,0,0,0,0,9,60,109,101,100,105,97,32,98,105,116,114,97,116,101,61,34,37,100,34,32,117,114,108,61,34,115,116,114,101,97,109,37,100,34,32,98,111,111,116,115,116,114,97,112,73,110,102,111,73,100,61,34,98,111,111,116,115,116,114,97,112,37,100,34,62,10,0,0,0,0,0,102,114,97,109,101,99,114,99,32,116,101,115,116,105,110,103,0,0,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,50,55,95,87,101,115,116,0,111,110,108,121,32,109,111,110,111,32,116,114,97,99,107,115,32,97,114,101,32,97,108,108,111,119,101,100,10,0,0,0,115,121,110,111,112,115,105,115,0,0,0,0,0,0,0,0,115,121,110,99,32,108,111,115,116,32,105,110,32,104,101,97,100,101,114,10,0,0,0,0,70,111,114,99,101,32,100,101,108,97,121,32,40,105,110,32,99,101,110,116,105,115,101,99,111,110,100,115,41,32,97,102,116,101,114,32,116,104,101,32,108,97,115,116,32,102,114,97,109,101,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,115,101,103,109,101,110,116,0,84,101,120,116,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,50,55,95,69,97,115,116,0,97,117,100,105,111,100,97,116,97,114,97,116,101,0,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,56,51,95,87,101,115,116,0,0,0,0,0,0,0,109,112,49,102,108,111,97,116,0,0,0,0,0,0,0,0,99,111,109,112,114,101,115,115,105,111,110,95,116,121,112,101,32,40,101,108,101,109,101,110,116,32,48,120,56,51,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,114,103,98,51,50,0,0,0,110,116,115,99,0,0,0,0,107,97,105,115,101,114,95,98,101,116,97,0,0,0,0,0,102,102,99,111,110,99,97,116,32,118,101,114,115,105,111,110,32,49,46,48,0,0,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,56,51,95,69,97,115,116,0,0,0,0,0,0,0,71,67,83,95,71,68,65,57,52,0,0,0,0,0,0,0,98,117,103,0,0,0,0,0,113,112,101,108,32,0,0,0,99,111,112,121,116,98,0,0,70,114,97,112,115,0,0,0,103,101,110,114,101,0,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,50,55,95,87,101,115,116,0,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,70,76,86,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,32,40,99,111,100,101,99,32,37,115,41,0,0,0,0,0,101,97,99,51,0,0,0,0,82,73,70,70,0,0,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,50,55,95,69,97,115,116,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,109,112,49,0,0,0,0,0,76,111,111,112,115,116,97,114,116,32,112,111,115,105,116,105,111,110,32,105,110,32,109,105,108,108,105,115,101,99,111,110,100,115,46,0,0,0,0,0,80,114,111,106,95,78,101,119,95,74,101,114,115,101,121,95,67,83,56,51,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,115,102,101,110,99,46,99,0,0,0,0,115,116,97,116,115,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,114,111,106,95,78,101,119,95,74,101,114,115,101,121,95,67,83,50,55,0,0,0,0,108,100,101,115,0,0,0,0,70,76,86,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,72,97,109,112,115,104,105], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2241160);
/* memory initializer */ allocate([114,101,95,67,83,56,51,0,70,76,73,47,70,76,67,47,70,76,88,32,97,110,105,109,97,116,105,111,110,0,0,0,112,111,115,0,0,0,0,0,80,114,111,106,95,78,101,119,95,72,97,109,112,115,104,105,114,101,95,67,83,50,55,0,37,46,54,103,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,114,103,115,0,0,0,0,114,97,119,32,70,76,65,67,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,99,104,97,110,110,101,108,58,32,37,115,46,10,0,0,0,0,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,56,51,95,87,101,115,116,0,0,0,118,111,108,117,109,101,0,0,114,97,119,32,70,76,65,67,0,0,0,0,0,0,0,0,105,110,112,117,116,32,99,104,97,110,110,101,108,32,35,37,100,32,110,111,116,32,97,118,97,105,108,97,98,108,101,32,102,114,111,109,32,105,110,112,117,116,32,108,97,121,111,117,116,32,39,37,115,39,10,0,67,97,110,110,111,116,32,99,111,110,110,101,99,116,32,97,117,100,105,111,32,102,105,108,116,101,114,32,116,111,32,110,111,110,32,97,117,100,105,111,32,105,110,112,117,116,10,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,0,65,100,111,98,101,32,70,105,108,109,115,116,114,105,112,0,65,112,112,108,121,32,97,32,116,119,111,45,112,111,108,101,32,97,108,108,45,112,97,115,115,32,102,105,108,116,101,114,46,0,0,0,0,0,0,0,98,97,121,101,114,95,103,114,98,103,49,54,98,101,0,0,89,101,108,108,111,119,71,114,101,101,110,0,0,0,0,0,115,101,108,101,99,116,32,75,97,105,115,101,114,32,87,105,110,100,111,119,101,100,32,83,105,110,99,0,0,0,0,0,112,111,116,32,60,61,32,97,116,101,109,112,111,45,62,119,105,110,100,111,119,0,0,0,105,110,49,0,0,0,0,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,56,51,95,69,97,115,116,0,0,0,71,67,83,95,80,111,105,110,116,101,95,78,111,105,114,101,0,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,58,32,37,108,108,100,10,0,0,0,0,0,0,0,0,65,100,111,98,101,32,70,105,108,109,115,116,114,105,112,0,99,111,100,101,99,95,116,97,103,0,0,0,0,0,0,0,115,99,97,108,97,98,105,108,105,116,121,32,0,0,0,0,99,111,112,121,32,116,105,109,101,115,116,97,109,112,115,0,102,114,97,112,115,0,0,0,102,105,108,101,58,0,0,0,116,114,97,99,107,0,0,0,99,104,58,37,100,32,99,104,108,58,37,115,32,102,109,116,58,37,115,32,114,58,37,100,72,122,32,45,62,32,99,104,58,37,100,32,99,104,108,58,37,115,32,102,109,116,58,37,115,32,114,58,37,100,72,122,10,0,0,0,0,0,0,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,50,55,95,87,101,115,116,0,0,0,115,101,116,32,109,111,100,117,108,97,116,105,111,110,32,116,121,112,101,0,0,0,0,0,102,105,114,115,116,0,0,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,37,115,105,110,37,100,58,0,100,101,102,97,117,108,116,0,100,116,115,0,0,0,0,0,70,70,109,112,101,103,32,109,101,116,97,100,97,116,97,32,105,110,32,116,101,120,116,0,115,116,97,114,116,95,116,105,109,101,0,0,0,0,0,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,50,55,95,69,97,115,116,0,0,0,115,101,116,32,108,105,115,116,32,111,102,32,115,105,103,110,97,108,32,100,101,108,97,121,115,0,0,0,0,0,0,0,110,98,95,105,110,95,99,104,97,110,110,101,108,115,0,0,80,114,111,106,95,78,101,98,114,97,115,107,97,95,67,83,56,51,0,0,0,0,0,0,70,70,109,112,101,103,32,109,101,116,97,100,97,116,97,32,105,110,32,116,101,120,116,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,102,109,112,101,103,50,112,97,115,115,0,0,0,0,0,70,70,77,32,40,70,70,115,101,114,118,101,114,32,108,105,118,101,32,102,101,101,100,41,0,0,0,0,0,0,0,0,80,114,111,106,95,78,101,98,114,97,115,107,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,105,110,105,116,105,97,108,32,121,32,112,111,115,105,116,105,111,110,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,102,0,0,0,0,0,0,0,70,70,77,32,40,70,70,115,101,114,118,101,114,32,108,105,118,101,32,102,101,101,100,41,0,0,0,0,0,0,0,0,80,114,111,106,95,78,101,98,114,97,115,107,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,114,97,116,101,0,0,0,0,69,110,115,111,110,105,113,32,80,97,114,105,115,32,65,117,100,105,111,32,70,105,108,101,0,0,0,0,0,0,0,0,97,115,115,117,109,101,32,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,0,80,114,111,106,95,77,111,110,116,97,110,97,95,67,83,56,51,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,80,114,111,106,95,77,111,110,116,97,110,97,95,67,83,50,55,95,83,111,117,116,104,0,99,104,114,111,109,97,95,109,115,105,122,101,95,121,0,0,32,10,9,0,0,0,0,0,97,108,119,97,121,115,32,97,112,112,108,121,32,116,114,97,110,115,112,111,115,105,116,105,111,110,0,0,0,0,0,0,98,108,97,99,107,0,0,0,112,97,116,116,101,114,110,32,116,104,97,116,32,100,101,115,99,114,105,98,101,32,102,111,114,32,104,111,119,32,109,97,110,121,32,102,105,101,108,100,115,32,97,32,102,114,97,109,101,32,105,115,32,116,111,32,98,101,32,100,105,115,112,108,97,121,101,100,0,0,0,0,80,114,111,106,95,77,111,110,116,97,110,97,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,117,108,116,105,109,101,100,105,97,0,0,0,0,0,0,98,97,121,101,114,95,103,114,98,103,49,54,108,101,0,0,89,101,108,108,111,119,0,0,107,97,105,115,101,114,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,99,100,97,116,97,0,0,0,80,114,111,106,95,77,111,110,116,97,110,97,95,67,83,50,55,95,78,111,114,116,104,0,71,67,83,95,80,97,108,101,115,116,105,110,101,95,49,57,50,51,0,0,0,0,0,0,104,101,105,103,104,116,0,0,102,114,97,109,101,95,98,105,116,115,0,0,0,0,0,0,116,98,32,37,100,47,37,100,44,32,116,105,110,99,114,98,105,116,115,58,37,100,44,32,113,112,95,112,114,101,99,58,37,100,44,32,112,115,58,37,100,44,32,32,37,115,37,115,37,115,37,115,10,0,0,0,99,111,112,121,116,115,0,0,110,0,0,0,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,50,0,0,0,37,100,0,0,0,0,0,0,68,88,65,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,56,51,95,87,101,115,116,0,115,116,97,116,115,95,102,105,108,101,0,0,0,0,0,0,99,111,108,111,114,0,0,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,88,0,0,0,0,0,0,0,118,115,117,98,0,0,0,0,97,99,51,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,56,51,95,69,97,115,116,0,116,101,109,112,111,114,97,108,32,110,111,105,115,101,0,0,111,117,116,112,117,116,32,112,108,97,110,101,32,37,100,32,100,101,112,116,104,32,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,105,110,112,117,116,32,37,100,32,112,108,97,110,101,32,37,100,32,100,101,112,116,104,32,37,100,10,0,0,0,0,0,109,97,114,107,101,114,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,102,95,99,111,100,101,10,0,0,0,116,101,116,114,97,104,101,100,114,97,108,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,50,55,95,87,101,115,116,0,100,118,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,37,115,45,37,100,46,108,111,103,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,114,97,119,32,68,84,83,45,72,68,0,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,100,101,115,99,0,0,0,0,115,101,116,32,116,104,101,32,115,97,116,117,114,97,116,105,111,110,32,101,120,112,114,101,115,115,105,111,110,0,0,0,114,97,119,32,68,84,83,0,115,101,116,32,108,101,118,101,108,32,104,101,105,103,104,116,0,0,0,0,0,0,0,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,50,55,95,69,97,115,116,0,114,97,119,32,68,78,120,72,68,32,40,83,77,80,84,69,32,86,67,45,51,41,0,0,76,101,102,116,32,97,110,100,32,114,105,103,104,116,32,115,105,122,101,115,32,100,105,102,102,101,114,32,40,37,100,120,37,100,32,118,115,32,37,100,120,37,100,41,46,10,0,0,114,111,117,110,100,32,116,111,119,97,114,100,115,32,45,105,110,102,116,121,0,0,0,0,114,97,119,32,68,105,114,97,99,0,0,0,0,0,0,0,80,114,111,106,95,77,105,115,115,105,115,115,105,112,112,105,95,67,83,56,51,95,87,101,115,116,0,0,0,0,0,0,72,121,112,101,114,32,102,97,115,116,32,65,117,100,105,111,32,97,110,100,32,86,105,100,101,111,32,101,110,99,111,100,101,114,10,0,0,0,0,0,67,104,114,111,110,111,109,97,115,116,101,114,32,68,70,65,0,0,0,0,0,0,0,0,120,118,109,99,109,99,0,0,89,69,83,0,0,0,0,0,80,114,111,106,95,77,105,115,115,105,115,115,105,112,112,105,95,67,83,56,51,95,69,97,115,116,0,0,0,0,0,0,65,108,105,99,101,66,108,117,101,0,0,0,0,0,0,0,37,48,50,88,0,0,0,0,110,98,95,102,114,97,109,101,115,0,0,0,0,0,0,0,68,45,67,105,110,101,109,97,32,97,117,100,105,111,0,0,108,111,103,0,0,0,0,0,69,110,100,32,111,102,32,102,105,108,101,0,0,0,0,0,115,101,116,32,114,101,100,32,112,108,97,110,101,0,0,0,66,82,0,0,0,0,0,0,67,82,67,32,116,101,115,116,105,110,103,0,0,0,0,0,80,114,111,106,95,77,105,115,115,105,115,115,105,112,112,105,95,67,83,50,55,95,87,101,115,116,0,0,0,0,0,0,117,115,105,110,103,32,117,110,115,99,97,108,101,100,32,37,115,32,45,62,32,37,115,32,115,112,101,99,105,97,108,32,99,111,110,118,101,114,116,101,114,10,0,0,0,0,0,0,99,104,114,66,117,102,73,110,100,101,120,32,60,32,50,32,42,32,118,67,104,114,66,117,102,83,105,122,101,0,0,0,103,97,117,115,115,105,97,110,0,0,0,0,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,48,120,37,108,108,120,32,105,115,32,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,98,97,121,101,114,95,103,98,114,103,49,54,98,101,0,0,87,104,105,116,101,83,109,111,107,101,0,0,0,0,0,0,99,111,108,111,114,0,0,0,115,101,108,101,99,116,32,66,108,97,99,107,109,97,110,32,78,117,116,116,97,108,108,32,87,105,110,100,111,119,101,100,32,83,105,110,99,0,0,0,80,114,111,106,95,77,105,115,115,105,115,115,105,112,112,105,95,67,83,50,55,95,69,97,115,116,0,0,0,0,0,0,92,102,115,37,117,37,49,91,92,125,93,37,110,0,0,0,71,67,83,95,80,97,100,97,110,103,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,10,0,0,114,121,0,0,0,0,0,0,109,105,115,99,95,98,105,116,115,0,0,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,50,0,0,0,0,0,0,0,0,115,99,97,108,97,98,105,108,105,116,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,114,111,111,109,95,116,121,112,101,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,111,111,109,95,116,121,112,101,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,117,116,111,102,102,32,102,114,101,113,117,101,110,99,121,10,0,0,0,0,0,0,0,76,111,47,82,111,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,115,101,116,32,100,117,112,108,105,99,97,116,101,32,116,104,114,101,115,104,111,108,100,0,80,97,114,97,109,101,116,114,105,99,32,83,116,101,114,101,111,32,115,105,103,110,97,108,101,100,32,116,111,32,98,101,32,110,111,116,45,112,114,101,115,101,110,116,32,98,117,116,32,119,97,115,32,102,111,117,110,100,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,46,10,0,0,0,83,101,108,101,99,116,101,100,32,98,121,32,116,104,101,32,69,110,99,111,100,101,114,0,105,110,100,101,111,50,0,0,73,109,112,108,105,99,105,116,32,83,66,82,32,119,97,115,32,102,111,117,110,100,32,119,105,116,104,32,97,32,102,105,114,115,116,32,111,99,99,117,114,114,101,110,99,101,32,97,102,116,101,114,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,46,10,0,0,99,111,109,109,101,110,116,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,101,110,116,114,105,101,115,32,105,110,32,99,111,108,111,114,109,97,112,10,0,0,86,105,114,116,117,97,108,32,99,111,110,99,97,116,101,110,97,116,105,111,110,32,115,99,114,105,112,116,0,0,0,0,67,104,97,110,110,101,108,32,116,114,97,110,115,102,111,114,109,32,98,105,116,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,115,117,98,102,114,97,109,101,95,108,101,110,32,37,105,10,0,0,98,105,116,114,97,116,101,32,116,111,111,32,108,111,119,58,32,103,111,116,32,37,105,44,32,110,101,101,100,32,50,52,48,48,48,32,111,114,32,104,105,103,104,101,114,10,0,0,104,103,97,105,110,32,118,108,99,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,60,47,117,62,0,0,0,0,87,105,100,116,104,32,109,105,115,109,97,116,99,104,46,32,37,100,32,33,61,32,37,100,10,0,0,0,0,0,0,0,111,112,116,105,109,105,122,101,95,109,111,110,111,0,0,0,73,110,118,97,108,105,100,32,70,76,79,65,84,73,78,70,79,44,32,115,105,122,101,32,61,32,37,105,10,0,0,0,100,101,99,111,100,101,95,102,111,114,109,97,116,56,48,32,112,114,111,98,108,101,109,58,32,100,101,99,111,100,101,32,102,105,110,105,115,104,101,100,32,119,105,116,104,32,100,101,115,116,95,105,110,100,101,120,32,40,37,100,41,32,60,32,100,101,115,116,95,115,105,122,101,32,40,37,100,41,10,0,82,97,110,32,111,117,116,32,111,102,32,109,101,109,111,114,121,32,100,117,114,105,110,103,32,114,97,110,103,101,32,99,111,100,101,114,32,105,110,105,116,10,0,0,0,0,0,0,48,47,49,32,48,46,49,50,57,47,49,32,48,46,52,54,54,47,48,46,52,57,56,32,48,46,55,50,53,47,48,32,49,47,48,0,0,0,0,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,109,111,100,101,115,10,0,0,99,98,45,62,108,111,111,107,117,112,0,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,110,111,32,118,111,114,98,105,115,32,115,105,103,110,97,116,117,114,101,41,46,32,10,0,0,0,0,73,110,118,97,108,105,100,32,118,101,114,116,105,99,97,108,32,114,97,110,103,101,32,37,100,45,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,99,49,100,101,99,46,99,0,0,0,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,70,0,0,0,0,0,0,0,40,105,110,95,104,45,111,117,116,95,104,41,47,50,0,0,77,66,32,77,86,32,84,121,112,101,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,0,0,0,0,0,83,108,105,99,101,32,99,111,117,110,116,32,37,100,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,116,104,101,32,115,117,98,115,97,109,112,108,105,110,103,45,97,112,112,108,105,101,100,32,104,101,105,103,104,116,32,37,100,46,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,67,111,109,109,111,100,111,114,101,32,67,68,88,76,32,118,105,100,101,111,0,0,0,0,112,114,111,98,101,100,32,115,116,114,101,97,109,32,37,100,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,100,101,99,111,100,101,114,0,115,101,116,32,116,104,101,32,98,108,117,101,32,103,97,105,110,32,102,111,114,32,116,104,101,32,103,114,101,101,110,32,99,104,97,110,110,101,108,0,112,97,115,115,119,111,114,100,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,115,108,105,99,101,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,71,111,116,32,108,101,115,115,32,99,111,100,101,115,32,116,104,97,110,32,101,120,112,101,99,116,101,100,58,32,37,105,32,111,102,32,37,105,10,0,32,83,80,82,73,84,69,0,112,97,99,107,98,105,116,115,0,0,0,0,0,0,0,0,115,101,116,32,114,101,100,32,104,105,103,104,108,105,103,104,116,115,0,0,0,0,0,0,67,68,32,71,114,97,112,104,105,99,115,0,0,0,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,114,97,119,32,67,104,105,110,101,115,101,32,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,0,0,71,101,111,103,65,122,105,109,117,116,104,85,110,105,116,115,71,101,111,75,101,121,0,0,67,111,112,121,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,98,108,101,110,100,32,109,111,100,101,0,0,0,0,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,99,104,114,111,109,97,32,100,99,32,98,108,111,99,107,10,0,0,0,60,102,111,110,116,32,102,97,99,101,61,34,37,115,34,62,0,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,98,108,97,99,107,95,109,105,110,95,100,117,114,97,116,105,111,110,58,37,115,32,112,105,120,101,108,95,98,108,97,99,107,95,116,104,58,37,102,32,112,105,120,101,108,95,98,108,97,99,107,95,116,104,95,105,58,37,100,32,112,105,99,116,117,114,101,95,98,108,97,99,107,95,114,97,116,105,111,95,116,104,58,37,102,10,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,115,110,111,119,32,101,110,99,111,100,101,114,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,109,105,115,115,105,110,103,32,87,65,86,69,32,116,97,103,10,0,0,0,0,0,0,0,78,79,80,84,83,0,0,0,118,97,114,105,97,98,108,101,32,115,105,122,101,32,102,114,97,109,101,115,32,97,114,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,0,114,101,115,101,114,118,101,100,32,98,105,116,32,115,101,116,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,111,114,99,101,95,107,101,121,95,102,114,97,109,101,115,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,113,67,111,109,112,0,0,0,73,110,118,97,108,105,100,32,115,116,114,105,110,103,32,39,37,115,39,32,102,111,114,32,97,115,112,101,99,116,32,114,97,116,105,111,10,0,0,0,105,110,100,101,120,32,37,100,32,111,117,116,32,111,102,32,116,121,112,101,51,48,95,100,101,113,117,97,110,116,32,97,114,114,97,121,10,0,0,0,52,52,52,52,0,0,0,0,73,110,118,97,108,105,100,32,97,108,112,104,97,32,109,111,100,101,32,37,100,10,0,0,101,114,114,111,114,44,32,119,114,111,110,103,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,0,0,0,73,69,78,68,32,119,105,116,104,111,117,116,32,97,108,108,32,105,109,97,103,101,10,0,65,112,112,108,101,32,67,65,70,32,40,67,111,114,101,32,65,117,100,105,111,32,70,111,114,109,97,116,41,0,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,112,99,109,95,102,54,52,108,101,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,97,117,100,105,111,32,115,97,109,112,108,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,100,114,111,112,112,101,100,32,97,103,97,105,110,0,0,0,108,121,114,105,99,115,0,0,115,101,116,32,115,116,114,101,97,109,115,0,0,0,0,0,112,107,116,95,112,111,115,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,32,102,111,114,32,118,50,10,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,101,114,114,111,114,95,114,97,116,101,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,112,97,114,115,105,110,103,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,66,97,100,32,104,101,97,100,101,114,44,32,100,105,115,99,97,114,100,32,98,108,111,99,107,10,0,0,0,0,0,0,66,97,100,32,104,101,97,100,101,114,44,32,100,105,115,99,97,114,100,32,98,108,111,99,107,10,0,0,0,0,0,0,65,112,112,108,101,32,67,65,70,32,40,67,111,114,101,32,65,117,100,105,111,32,70,111,114,109,97,116,41,0,0,0,69,114,114,111,114,32,99,114,101,97,116,105,110,103,32,102,105,108,116,101,114,32,39,37,115,39,10,0,0,0,0,0,115,116,114,105,99,116,95,103,111,112,0,0,0,0,0,0,115,99,97,110,95,111,102,102,115,101,116,0,0,0,0,0,37,51,88,32,97,116,32,37,116,100,32,108,101,102,116,32,37,100,10,0,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,32,99,111,117,110,116,32,109,105,115,109,97,116,99,104,10,0,83,117,98,115,97,109,112,108,105,110,103,32,105,110,32,74,80,69,71,45,76,83,0,0,110,111,32,112,105,99,116,117,114,101,10,0,0,0,0,0,123,92,97,110,56,125,0,0,73,110,116,101,114,112,108,97,121,32,67,57,51,0,0,0,69,120,116,114,97,100,97,116,97,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,69,80,72,32,109,97,114,107,101,114,32,110,111,116,32,102,111,117,110,100,46,10,0,0,123,92,97,110,56,125,0,0,111,102,102,115,32,62,61,32,48,32,38,38,32,114,101,102,95,111,102,102,115,32,62,61,32,48,32,38,38,32,98,97,110,100,45,62,114,101,102,95,98,117,102,0,0,0,0,0,37,115,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,52,120,52,32,108,117,109,97,32,98,108,111,99,107,115,32,97,114,101,32,117,110,115,117,112,112,111,114,116,101,100,33,10,0,0,0,0,0,0,0,67,117,115,116,111,109,32,113,117,97,110,116,32,109,97,116,114,105,120,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,77,111,100,101,32,37,100,58,32,105,110,118,97,108,105,100,32,86,81,32,100,97,116,97,10,0,0,0,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,104,111,108,100,32,98,105,116,115,32,102,111,114,32,72,65,77,58,32,37,117,10,0,0,0,0,0,0,0,0,69,114,114,111,114,58,32,89,86,49,50,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,104,117,102,102,121,117,118,59,32,117,115,101,32,118,99,111,100,101,99,61,102,102,118,104,117,102,102,32,111,114,32,102,111,114,109,97,116,61,52,50,50,112,10,0,0,0,0,0,76,117,109,97,32,98,105,116,32,100,101,112,116,104,32,40,37,100,41,32,105,115,32,100,105,102,102,101,114,101,110,116,32,102,114,111,109,32,99,104,114,111,109,97,32,98,105,116,32,100,101,112,116,104,32,40,37,100,41,44,32,116,104,105,115,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,78,111,110,45,109,97,116,99,104,105,110,103,32,78,65,76,32,116,121,112,101,115,32,111,102,32,116,104,101,32,86,67,76,32,78,65,76,85,115,58,32,37,100,32,37,100,10,0,109,111,110,111,0,0,0,0,112,114,101,118,95,116,0,0,109,109,99,111,58,32,117,110,114,101,102,32,108,111,110,103,32,102,97,105,108,117,114,101,10,0,0,0,0,0,0,0,70,82,77,0,0,0,0,0,98,117,102,95,105,110,100,101,120,32,60,61,32,98,117,102,95,115,105,122,101,0,0,0,66,82,83,84,77,32,40,66,105,110,97,114,121,32,82,101,118,111,108,117,116,105,111,110,32,83,116,114,101,97,109,41,0,0,0,0,0,0,0,0,115,108,105,99,101,32,101,110,100,32,110,111,116,32,114,101,97,99,104,101,100,32,98,117,116,32,115,99,114,101,101,110,115,112,97,99,101,32,101,110,100,32,40,37,100,32,108,101,102,116,32,37,48,54,88,44,32,115,99,111,114,101,61,32,37,100,41,10,0,0,0,0,66,97,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,115,101,116,32,112,101,114,109,105,115,115,105,111,110,115,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,0,0,101,110,97,98,108,101,32,116,114,97,110,115,112,97,114,101,110,99,121,32,100,101,116,101,99,116,105,111,110,32,98,101,116,119,101,101,110,32,102,114,97,109,101,115,0,0,0,0,66,105,116,115,32,112,101,114,32,99,111,100,101,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,112,111,115,32,37,100,44,37,100,32,40,105,110,32,37,100,120,37,100,32,103,114,105,100,41,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,37,100,120,37,100,32,100,105,102,102,32,115,116,97,114,116,32,37,100,32,104,101,105,103,104,116,32,37,100,10,0,0,108,105,98,97,118,102,105,108,116,101,114,47,102,95,105,110,116,101,114,108,101,97,118,101,46,99,0,0,0,0,0,0,32,99,111,109,112,114,101,115,115,105,111,110,58,32,37,100,10,0,0,0,0,0,0,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,117,98,102,114,97,109,101,32,112,97,100,100,105,110,103,10,0,0,0,0,0,0,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,32,105,110,118,97,108,105,100,10,0,0,0,0,105,110,118,97,108,105,100,32,118,101,114,115,105,111,110,32,37,100,32,105,110,32,118,101,114,48,49,32,104,101,97,100,101,114,10,0,0,0,0,0,86,0,0,0,0,0,0,0,66,108,97,99,107,32,79,112,115,32,65,117,100,105,111,0,115,109,97,108,108,0,0,0,98,97,121,101,114,95,103,98,114,103,49,54,108,101,0,0,87,104,105,116,101,0,0,0,100,101,102,97,117,108,116,0,98,108,97,99,107,109,97,110,95,110,117,116,116,97,108,108,0,0,0,0,0,0,0,0,49,48,50,52,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,68,87,84,32,100,101,99,111,109,112,111,115,105,116,105,111,110,115,10,0,0,0,97,118,95,105,109,97,103,101,95,99,104,101,99,107,95,115,105,122,101,40,97,118,99,116,120,45,62,119,105,100,116,104,44,32,97,118,99,116,120,45,62,104,101,105,103,104,116,44,32,48,44,32,97,118,99,116,120,41,32,62,61,32,48,0,78,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,99,104,97,110,103,101,100,32,105,110,32,68,67,65,32,100,101,99,111,100,101,114,32,40,37,100,32,45,62,32,37,100,41,10,0,0,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,0,0,0,0,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,77,79,78,79,10,0,0,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,0,0,0,0,0,0,0,71,67,83,95,79,83,95,83,78,56,48,0,0,0,0,0,115,107,105,112,95,99,111,117,110,116,0,0,0,0,0,0,114,101,100,117,99,101,100,32,114,101,115,111,108,117,116,105,111,110,32,86,79,80,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,97,117,100,105,111,32,100,114,105,102,116,32,116,104,114,101,115,104,111,108,100,0,0,0,77,111,116,105,111,110,32,74,80,69,71,0,0,0,0,0,69,110,102,111,114,99,101,32,109,105,110,32,115,116,114,105,112,115,47,102,114,97,109,101,44,32,109,111,114,101,32,105,115,32,119,111,114,115,101,32,97,110,100,32,102,97,115,116,101,114,44,32,109,117,115,116,32,98,101,32,60,61,32,109,97,120,95,115,116,114,105,112,115,0,0,0,0,0,0,0,87,105,100,116,104,47,104,101,105,103,104,116,32,99,104,97,110,103,105,110,103,32,105,110,32,67,65,86,83,0,0,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,99,111,108,111,114,115,32,45,32,37,88,32,102,111,114,32,98,105,116,100,101,112,116,104,32,37,100,10,0,0,0,0,0,0,0,0,65,117,116,111,100,101,115,107,32,82,76,69,0,0,0,0,97,117,116,111,45,105,110,115,101,114,116,101,100,32,115,99,97,108,101,114,32,37,100,0,100,97,116,101,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,85,110,107,110,111,119,110,32,97,109,111,117,110,116,32,111,102,32,100,101,108,97,121,32,37,120,32,33,61,32,48,120,56,56,69,46,10,0,0,0,37,100,32,98,105,116,115,32,112,101,114,32,99,111,100,101,100,32,115,97,109,112,108,101,0,0,0,0,0,0,0,0,71,46,55,50,57,32,66,73,84,32,102,105,108,101,32,102,111,114,109,97,116,0,0,0,82,101,97,100,105,110,103,32,65,76,83,83,112,101,99,105,102,105,99,67,111,110,102,105,103,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,88,45,85,115,101,115,0,0,114,105,103,104,116,95,108,101,102,116,0,0,0,0,0,0,82,97,112,0,0,0,0,0,103,101,110,114,101,0,0,0,112,111,110,103,32,102,114,111,109,58,37,115,32,37,115,10,0,0,0,0,0,0,0,0,97,117,116,104,111,114,0,0,52,50,50,112,49,50,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,32,37,99,0,0,0,0,0,112,114,111,98,101,100,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,83,116,97,116,101,95,80,108,97,110,101,95,87,101,115,116,0,0,109,112,99,56,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,83,116,97,116,101,95,80,108,97,110,101,95,79,108,100,95,67,101,110,116,114,97,108,0,0,0,101,120,112,114,58,0,0,0,66,105,110,97,114,121,32,116,101,120,116,0,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,83,116,97,116,101,95,80,108,97,110,101,95,69,97,115,116,0,0,169,108,121,114,0,0,0,0,109,112,99,55,0,0,0,0,80,114,111,106,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,67,83,56,51,95,73,115,108,97,110,100,0,0,66,105,110,107,0,0,0,0,109,111,118,95,116,101,120,116,0,0,0,0,0,0,0,0,66,114,117,116,101,32,70,111,114,99,101,32,38,32,73,103,110,111,114,97,110,99,101,0,109,111,118,95,116,101,120,116,0,0,0,0,0,0,0,0,80,114,111,106,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,67,83,56,51,95,77,97,105,110,108,97,110,100,0,0,0,0,0,0,0,0,66,101,116,104,101,115,100,97,32,83,111,102,116,119,111,114,107,115,32,86,73,68,0,0,109,111,116,105,111,110,112,105,120,101,108,115,0,0,0,0,65,86,83,0,0,0,0,0,80,114,111,106,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,67,83,50,55,95,73,115,108,97,110,100,0,0,109,109,118,105,100,101,111,0,65,86,82,32,40,65,117,100,105,111,32,86,105,115,117,97,108,32,82,101,115,101,97,114,99,104,41,0,0,0,0,0,80,114,111,106,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,67,83,50,55,95,77,97,105,110,108,97,110,100,0,0,0,0,0,0,0,0,98,97,121,101,114,95,114,103,103,98,49,54,98,101,0,0,87,104,101,97,116,0,0,0,115,101,108,101,99,116,32,99,117,98,105,99,0,0,0,0,80,114,111,106,95,77,97,114,121,108,97,110,100,95,67,83,56,51,0,0,0,0,0,0,71,67,83,95,79,83,71,66,55,48,0,0,0,0,0,0,112,95,99,111,117,110,116,0,110,101,119,32,112,114,101,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,97,100,114,105,102,116,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,0,97,97,115,99,0,0,0,0,97,108,98,117,109,0,0,0,80,114,111,106,95,77,97,114,121,108,97,110,100,95,67,83,50,55,0,0,0,0,0,0,80,114,111,106,95,77,97,105,110,101,95,67,83,56,51,95,87,101,115,116,0,0,0,0,68,101,99,111,100,101,114,115,0,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,97,114,103,117,109,101,110,116,32,102,111,114,32,111,112,116,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,119,114,105,116,101,32,115,116,114,101,97,109,32,99,111,100,101,99,32,105,110,102,111,32,102,97,105,108,101,100,32,99,111,100,101,99,95,116,121,112,101,40,48,120,37,120,41,10,0,0,0,0,0,0,0,0,110,111,116,104,105,110,103,32,116,111,32,112,114,111,98,101,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,116,105,109,101,108,105,110,101,32,100,97,116,97,32,109,105,115,115,105,110,103,10,0,0,80,114,111,106,95,77,97,105,110,101,95,67,83,56,51,95,69,97,115,116,0,0,0,0,119,101,98,118,116,116,95,107,105,110,100,0,0,0,0,0,74,85,78,75,0,0,0,0,80,114,111,106,95,77,97,105,110,101,95,67,83,50,55,95,87,101,115,116,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,78,111,32,112,105,120,101,108,32,102,111,114,109,97,116,32,115,112,101,99,105,102,105,101,100,44,32,37,115,32,102,111,114,32,77,80,69,71,45,50,32,101,110,99,111,100,105,110,103,32,99,104,111,115,101,110,46,10,85,115,101,32,45,112,105,120,95,102,109,116,32,121,117,118,52,50,48,112,32,102,111,114,32,99,111,109,112,97,116,105,98,105,108,105,116,121,32,119,105,116,104,32,111,117,116,100,97,116,101,100,32,109,101,100,105,97,32,112,108,97,121,101,114,115,46,10,0,0,97,114,114,97,110,103,101,114,0,0,0,0,0,0,0,0,109,108,112,0,0,0,0,0,80,114,111,106,95,77,97,105,110,101,95,67,83,50,55,95,69,97,115,116,0,0,0,0,103,114,111,117,112,105,110,103,0,0,0,0,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,104,111,114,116,44,32,117,110,97,98,108,101,32,116,111,32,114,101,97,100,32,109,97,106,111,114,32,115,121,110,99,10,0,0,0,0,84,105,109,101,85,110,105,116,68,101,110,111,109,105,110,97,116,111,114,0,0,0,0,0,80,114,111,106,95,76,111,117,105,115,105,97,110,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,73,110,118,97,105,100,32,85,84,70,56,32,115,101,113,117,101,110,99,101,32,105,110,32,97,118,105,111,95,112,117,116,95,115,116,114,49,54,108,101,10,0,0,0,0,0,0,0,80,114,111,106,95,76,111,117,105,115,105,97,110,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,99,111,108,111,114,0,0,0,80,114,111,106,95,76,111,117,105,115,105,97,110,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,74,80,69,71,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,54,53,53,48,48,120,54,53,53,48,48,10,0,0,0,0,100,101,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,97,100,100,105,116,105,111,110,97,108,32,105,100,51,32,100,97,116,97,44,32,115,107,105,112,112,105,110,103,10,0,102,105,108,101,0,0,0,0,80,114,111,106,95,76,111,117,105,115,105,97,110,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,98,97,121,101,114,95,114,103,103,98,49,54,108,101,0,0,86,105,111,108,101,116,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,39,37,115,39,32,102,111,114,32,111,117,116,112,117,116,32,39,37,115,39,10,0,0,99,117,98,105,99,0,0,0,34,115,116,97,114,116,84,105,109,101,34,0,0,0,0,0,80,114,111,106,95,75,101,110,116,117,99,107,121,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,71,67,83,95,79,83,71,66,95,49,57,51,54,0,0,0,83,87,70,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,49,32,118,105,100,101,111,32,115,116,114,101,97,109,10,0,105,95,99,111,117,110,116,0,73,110,118,97,108,105,100,32,67,111,109,112,108,101,120,105,116,121,32,101,115,116,105,109,97,116,105,111,110,32,109,101,116,104,111,100,32,37,100,10,0,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,101,103,109,101,110,116,115,0,0,37,117,58,37,117,58,37,117,46,37,117,44,37,117,58,37,117,58,37,117,46,37,117,0,97,117,100,105,111,32,115,121,110,99,32,109,101,116,104,111,100,0,0,0,0,0,0,0,87,105,110,110,111,118,32,87,78,86,49,0,0,0,0,0,97,114,116,105,115,116,0,0,80,114,111,106,95,75,101,110,116,117,99,107,121,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,83,112,101,99,105,102,105,101,100,32,72,68,32,114,97,116,101,32,111,102,32,37,100,32,72,122,32,119,111,117,108,100,32,114,101,113,117,105,114,101,32,97,110,32,105,109,112,111,115,115,105,98,108,101,32,114,101,112,101,116,105,116,105,111,110,32,112,101,114,105,111,100,32,111,102,32,37,100,32,102,111,114,32,116,104,101,32,99,117,114,114,101,110,116,32,68,84,83,32,115,116,114,101,97,109,32,40,98,108,111,99,107,115,32,61,32,37,100,44,32,115,97,109,112,108,101,32,114,97,116,101,32,61,32,37,100,41,10,0,0,0,0,0,0,65,86,73,32,40,65,117,100,105,111,32,86,105,100,101,111], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2251400);
/* memory initializer */ allocate([32,73,110,116,101,114,108,101,97,118,101,100,41,0,0,0,80,114,111,106,95,75,101,110,116,117,99,107,121,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,69,110,99,111,100,101,114,115,0,0,0,0,0,0,0,0,60,47,83,116,114,101,97,109,73,110,100,101,120,62,10,0,70,97,105,108,101,100,32,116,111,32,114,101,97,108,108,111,99,97,116,101,32,112,114,111,98,101,32,98,117,102,102,101,114,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,0,0,80,114,111,106,95,75,101,110,116,117,99,107,121,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,52,48,48,120,52,48,48,0,99,97,99,104,101,0,0,0,80,114,111,106,95,75,97,110,115,97,115,95,67,83,56,51,95,83,111,117,116,104,0,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,115,114,116,112,95,111,117,116,95,115,117,105,116,101,0,0,80,114,111,106,95,75,97,110,115,97,115,95,67,83,56,51,95,78,111,114,116,104,0,0,34,0,0,0,0,0,0,0,169,103,114,112,0,0,0,0,80,114,111,106,95,75,97,110,115,97,115,95,67,83,50,55,95,83,111,117,116,104,0,0,82,84,80,32,109,117,120,101,114,32,102,108,97,103,115,0,65,86,73,32,40,65,117,100,105,111,32,86,105,100,101,111,32,73,110,116,101,114,108,101,97,118,101,100,41,0,0,0,115,97,109,112,108,101,115,95,112,101,114,95,102,114,97,109,101,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,32,102,111,114,32,105,110,100,101,120,32,97,116,32,112,111,115,32,37,108,108,100,10,0,0,80,114,111,106,95,75,97,110,115,97,115,95,67,83,50,55,95,78,111,114,116,104,0,0,73,80,82,68,0,0,0,0,80,114,111,106,95,73,111,119,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,83,117,110,32,65,85,0,0,115,97,109,112,108,101,95,114,97,116,101,58,37,100,32,99,104,97,110,110,101,108,95,108,97,121,111,117,116,58,39,37,115,39,32,110,98,95,115,97,109,112,108,101,115,58,37,100,10,0,0,0,0,0,0,0,80,114,111,106,95,73,111,119,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,114,97,119,32,68,78,120,72,68,32,40,83,77,80,84,69,32,86,67,45,51,41,0,0,116,104,100,0,0,0,0,0,98,97,121,101,114,95,98,103,103,114,49,54,98,101,0,0,84,117,114,113,117,111,105,115,101,0,0,0,0,0,0,0,115,101,108,101,99,116,32,115,119,114,32,102,105,108,116,101,114,32,116,121,112,101,0,0,80,114,111,106,95,73,111,119,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,68,117,112,108,105,99,97,116,101,32,102,111,114,109,97,116,115,32,105,110,32,97,118,102,105,108,116,101,114,95,109,101,114,103,101,95,102,111,114,109,97,116,115,40,41,32,100,101,116,101,99,116,101,100,10,0,117,115,105,110,103,32,101,120,116,101,114,110,97,108,32,104,117,102,102,109,97,110,32,116,97,98,108,101,10,0,0,0,71,67,83,95,78,83,87,67,95,57,90,95,50,0,0,0,112,95,116,101,120,95,98,105,116,115,0,0,0,0,0,0,105,110,32,99,111,109,112,108,101,120,105,116,121,32,101,115,116,105,109,97,116,105,111,110,32,112,97,114,116,32,50,0,65,83,84,32,40,65,117,100,105,111,32,83,116,114,101,97,109,41,0,0,0,0,0,0,97,115,121,110,99,0,0,0,119,110,118,49,0,0,0,0,115,50,52,108,101,0,0,0,116,105,116,108,101,0,0,0,80,114,111,106,95,73,111,119,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,65,83,84,32,40,65,117,100,105,111,32,83,116,114,101,97,109,41,0,0,0,0,0,0,109,106,112,101,103,98,0,0,80,114,111,106,95,73,110,100,105,97,110,97,95,67,83,56,51,95,87,101,115,116,0,0,37,115,58,10,32,86,46,46,46,46,46,32,61,32,86,105,100,101,111,10,32,65,46,46,46,46,46,32,61,32,65,117,100,105,111,10,32,83,46,46,46,46,46,32,61,32,83,117,98,116,105,116,108,101,10,32,46,70,46,46,46,46,32,61,32,70,114,97,109,101,45,108,101,118,101,108,32,109,117,108,116,105,116,104,114,101,97,100,105,110,103,10,32,46,46,83,46,46,46,32,61,32,83,108,105,99,101,45,108,101,118,101,108,32,109,117,108,116,105,116,104,114,101,97,100,105,110,103,10,32,46,46,46,88,46,46,32,61,32,67,111,100,101,99,32,105,115,32,101,120,112,101,114,105,109,101,110,116,97,108,10,32,46,46,46,46,66,46,32,61,32,83,117,112,112,111,114,116,115,32,100,114,97,119,95,104,111,114,105,122,95,98,97,110,100,10,32,46,46,46,46,46,68,32,61,32,83,117,112,112,111,114,116,115,32,100,105,114,101,99,116,32,114,101,110,100,101,114,105,110,103,32,109,101,116,104,111,100,32,49,10,32,45,45,45,45,45,45,10,0,0,0,0,0,0,0,115,50,52,108,101,0,0,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,112,114,111,98,105,110,103,32,115,116,114,101,97,109,32,37,100,32,112,112,58,37,100,10,0,0,0,0,0,0,0,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,80,114,111,106,95,73,110,100,105,97,110,97,95,67,83,56,51,95,69,97,115,116,0,0,103,101,110,101,114,97,116,101,32,112,116,115,0,0,0,0,73,110,118,97,108,105,100,32,71,69,79,66,32,100,97,116,97,32,115,105,122,101,58,32,37,117,10,0,0,0,0,0,80,114,111,106,95,73,110,100,105,97,110,97,95,67,83,50,55,95,87,101,115,116,0,0,78,111,32,112,105,120,101,108,32,102,111,114,109,97,116,32,115,112,101,99,105,102,105,101,100,44,32,37,115,32,102,111,114,32,72,46,50,54,52,32,101,110,99,111,100,105,110,103,32,99,104,111,115,101,110,46,10,85,115,101,32,45,112,105,120,95,102,109,116,32,121,117,118,52,50,48,112,32,102,111,114,32,99,111,109,112,97,116,105,98,105,108,105,116,121,32,119,105,116,104,32,111,117,116,100,97,116,101,100,32,109,101,100,105,97,32,112,108,97,121,101,114,115,46,10,0,0,0,109,105,109,105,99,0,0,0,112,114,101,102,101,114,114,101,100,32,112,97,103,101,32,115,105,122,101,32,105,110,32,98,121,116,101,115,32,40,100,101,112,114,101,99,97,116,101,100,41,0,0,0,0,0,0,0,80,114,111,106,95,73,110,100,105,97,110,97,95,67,83,50,55,95,69,97,115,116,0,0,115,116,114,101,97,109,95,105,110,100,101,120,32,60,32,111,103,103,45,62,110,115,116,114,101,97,109,115,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,65,83,70,32,40,65,100,118,97,110,99,101,100,32,47,32,65,99,116,105,118,101,32,83,116,114,101,97,109,105,110,103,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,0,102,114,97,109,101,95,99,111,100,101,32,33,61,32,45,49,0,0,0,0,0,0,0,0,80,114,111,106,95,73,108,108,105,110,111,105,115,95,67,83,56,51,95,87,101,115,116,0,115,121,110,99,32,112,111,105,110,116,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,0,48,49,0,0,0,0,0,0,109,105,99,114,111,100,118,100,0,0,0,0,0,0,0,0,80,114,111,106,95,73,108,108,105,110,111,105,115,95,67,83,56,51,95,69,97,115,116,0,99,111,117,108,100,32,110,111,116,32,103,101,116,32,109,112,101,103,50,32,112,114,111,102,105,108,101,32,97,110,100,32,108,101,118,101,108,10,0,0,80,114,111,106,95,73,108,108,105,110,111,105,115,95,67,83,50,55,95,87,101,115,116,0,112,114,111,98,97,98,108,121,32,105,110,99,111,114,114,101,99,116,32,100,101,99,114,121,112,116,105,111,110,32,107,101,121,10,0,0,0,0,0,0,50,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,116,114,101,97,109,32,105,110,100,101,120,58,32,37,100,10,0,0,0,0,0,0,0,0,80,114,111,106,95,73,108,108,105,110,111,105,115,95,67,83,50,55,95,69,97,115,116,0,98,97,121,101,114,95,98,103,103,114,49,54,108,101,0,0,84,111,109,97,116,111,0,0,102,105,108,116,101,114,95,116,121,112,101,0,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,56,51,95,87,101,115,116,0,0,0,0,65,65,67,32,112,97,99,107,101,116,32,116,111,111,32,115,104,111,114,116,10,0,0,0,71,67,83,95,78,84,70,0,105,95,116,101,120,95,98,105,116,115,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,100,101,116,101,99,116,32,84,83,32,112,97,99,107,101,116,32,115,105,122,101,44,32,100,101,102,97,117,108,116,105,110,103,32,116,111,32,110,111,110,45,70,69,67,47,68,86,72,83,10,0,0,0,0,105,110,32,99,111,109,112,108,101,120,105,116,121,32,101,115,116,105,109,97,116,105,111,110,32,112,97,114,116,32,49,0,118,105,100,101,111,32,115,121,110,99,32,109,101,116,104,111,100,0,0,0,0,0,0,0,112,114,101,108,111,97,100,0,76,79,67,79,0,0,0,0,83,121,110,116,104,80,111,112,0,0,0,0,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,56,51,95,67,101,110,116,114,97,108,0,109,101,116,97,115,111,117,110,100,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,65,83,70,32,40,65,100,118,97,110,99,101,100,32,47,32,65,99,116,105,118,101,32,83,116,114,101,97,109,105,110,103,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,0,84,67,79,78,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,56,51,95,69,97,115,116,0,0,0,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,58,0,0,109,100,101,99,0,0,0,0,42,112,107,116,95,98,117,102,102,101,114,0,0,0,0,0,65,81,84,105,116,108,101,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,50,55,95,87,101,115,116,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,50,55,95,67,101,110,116,114,97,108,0,85,110,115,117,112,112,111,114,116,101,100,32,116,97,103,32,118,101,114,115,105,111,110,46,32,40,62,61,37,100,41,10,0,0,0,0,0,0,0,0,108,105,98,120,50,54,52,0,112,115,112,0,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,50,55,95,69,97,115,116,0,0,0,0,101,110,99,111,100,105,110,103,95,116,111,111,108,0,0,0,109,97,99,101,51,0,0,0,77,111,110,107,101,121,39,115,32,65,117,100,105,111,0,0,67,82,89,79,32,65,80,67,0,0,0,0,0,0,0,0,80,114,111,106,95,71,101,111,114,103,105,97,95,67,83,56,51,95,87,101,115,116,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,111,117,110,100,32,109,101,100,105,97,32,100,97,116,97,32,116,97,103,32,77,80,69,71,32,105,110,100,105,99,97,116,105,110,103,32,116,104,105,115,32,105,115,32,97,32,77,79,86,45,112,97,99,107,101,100,32,77,80,69,71,45,80,83,46,10,0,0,0,0,0,68,101,108,117,120,101,32,80,97,105,110,116,32,65,110,105,109,97,116,105,111,110,0,0,80,114,111,106,95,71,101,111,114,103,105,97,95,67,83,56,51,95,69,97,115,116,0,0,104,97,115,104,0,0,0,0,51,71,80,80,32,65,77,82,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,114,111,106,95,71,101,111,114,103,105,97,95,67,83,50,55,95,87,101,115,116,0,0,99,108,117,115,116,101,114,95,115,105,122,101,95,108,105,109,105,116,0,0,0,0,0,0,102,105,102,111,0,0,0,0,115,105,122,101,32,62,32,48,0,0,0,0,0,0,0,0,101,120,112,105,114,101,58,32,37,120,32,61,32,37,105,45,37,48,50,105,45,37,48,50,105,10,0,0,0,0,0,0,80,114,111,106,95,71,101,111,114,103,105,97,95,67,83,50,55,95,69,97,115,116,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,105,110,112,117,116,32,102,105,108,101,32,39,37,115,39,10,0,81,85,65,78,84,73,90,69,0,0,0,0,0,0,0,0,98,97,121,101,114,95,103,114,98,103,56,0,0,0,0,0,84,104,105,115,116,108,101,0,115,101,108,101,99,116,32,68,111,108,98,121,32,80,114,111,32,76,111,103,105,99,32,73,73,0,0,0,0,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,56,51,95,78,111,114,116,104,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,71,67,83,95,68,97,116,117,109,95,55,51,0,0,0,0,80,114,101,115,115,32,91,113,93,32,116,111,32,115,116,111,112,44,32,91,63,93,32,102,111,114,32,104,101,108,112,10,0,0,0,0,0,0,0,0,104,101,97,100,101,114,95,98,105,116,115,0,0,0,0,0,86,79,76,32,72,101,97,100,101,114,32,116,114,117,110,99,97,116,101,100,10,0,0,0,105,109,97,103,101,50,32,109,117,120,101,114,0,0,0,0,118,115,121,110,99,0,0,0,108,111,99,111,0,0,0,0,74,80,111,112,0,0,0,0,103,108,111,98,0,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,56,51,95,87,101,115,116,0,0,112,97,109,0,0,0,0,0,83,101,108,101,99,116,101,100,32,37,100,47,37,100,32,116,105,109,101,32,98,97,115,101,10,0,0,0,0,0,0,0,108,111,99,111,0,0,0,0,115,116,45,62,99,111,100,101,99,45,62,101,120,116,114,97,100,97,116,97,95,115,105,122,101,32,62,61,32,52,49,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,56,51,95,69,97,115,116,0,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,115,58,0,0,0,108,106,112,101,103,0,0,0,37,108,108,100,0,0,0,0,109,97,105,110,112,105,99,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,50,55,95,78,111,114,116,104,0,84,80,69,49,0,0,0,0,77,111,114,101,32,116,104,97,110,32,97,32,115,105,110,103,108,101,32,118,105,100,101,111,32,115,116,114,101,97,109,32,112,114,101,115,101,110,116,44,32,101,120,112,101,99,116,32,105,115,115,117,101,115,32,100,101,99,111,100,105,110,103,32,105,116,46,10,0,0,0,0,122,108,105,98,0,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,50,55,95,87,101,115,116,0,0,85,110,97,98,108,101,32,116,111,32,114,101,97,100,32,107,101,121,32,102,105,108,101,32,37,115,10,0,0,0,0,0,70,114,97,109,101,32,114,97,116,101,32,118,101,114,121,32,104,105,103,104,32,102,111,114,32,97,32,109,117,120,101,114,32,110,111,116,32,101,102,102,105,99,105,101,110,116,108,121,32,115,117,112,112,111,114,116,105,110,103,32,105,116,46,10,80,108,101,97,115,101,32,99,111,110,115,105,100,101,114,32,115,112,101,99,105,102,121,105,110,103,32,97,32,108,111,119,101,114,32,102,114,97,109,101,114,97,116,101,44,32,97,32,100,105,102,102,101,114,101,110,116,32,109,117,120,101,114,32,111,114,32,45,118,115,121,110,99,32,50,10,0,0,0,0,9,60,98,111,111,116,115,116,114,97,112,73,110,102,111,32,112,114,111,102,105,108,101,61,34,110,97,109,101,100,34,32,117,114,108,61,34,115,116,114,101,97,109,37,100,46,97,98,115,116,34,32,105,100,61,34,98,111,111,116,115,116,114,97,112,37,100,34,32,47,62,10,0,0,0,0,0,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,50,55,95,69,97,115,116,0,0,111,110,108,121,32,52,56,48,48,48,104,122,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,105,115,32,97,108,108,111,119,101,100,10,0,0,169,116,111,111,0,0,0,0,105,110,118,97,108,105,100,32,116,114,97,99,107,32,100,101,115,99,114,105,112,116,105,111,110,32,108,101,110,103,116,104,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,105,110,97,108,95,100,101,108,97,121,0,0,0,0,0,80,114,111,106,95,68,101,108,97,119,97,114,101,95,67,83,56,51,0,0,0,0,0,0,116,121,112,101,0,0,0,0,68,101,116,101,99,116,32,97,117,100,105,111,32,118,111,108,117,109,101,46,0,0,0,0,80,114,111,106,95,68,101,108,97,119,97,114,101,95,67,83,50,55,0,0,0,0,0,0,118,105,100,101,111,100,97,116,97,114,97,116,101,0,0,0,80,114,111,106,95,67,111,110,110,101,99,116,105,99,117,116,95,67,83,56,51,0,0,0,110,117,109,95,99,104,97,110,110,101,108,115,32,40,101,108,101,109,101,110,116,32,48,120,56,50,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,0,0,0,0,109,115,122,104,0,0,0,0,80,114,111,106,95,67,111,110,110,101,99,116,105,99,117,116,95,67,83,50,55,0,0,0,98,97,121,101,114,95,103,98,114,103,56,0,0,0,0,0,84,101,97,108,0,0,0,0,100,112,108,105,105,0,0,0,85,110,115,97,102,101,32,102,105,108,101,32,110,97,109,101,32,39,37,115,39,10,0,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,71,67,83,95,78,71,79,95,49,57,52,56,0,0,0,0,115,97,109,114,70,70,77,80,0,0,0,0,0,0,0,0,109,118,95,98,105,116,115,0,113,117,97,110,116,32,112,114,101,99,105,115,105,111,110,32,37,100,10,0,0,0,0,0,116,121,112,101,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,0,0,0,108,97,103,97,114,105,116,104,0,0,0,0,0,0,0,0,65,110,105,109,101,0,0,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,67,104,97,110,103,101,32,105,110,112,117,116,32,118,111,108,117,109,101,46,0,0,0,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,78,79,80,84,83,0,0,0,107,109,118,99,0,0,0,0,109,111,118,105,0,0,0,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,71,65,66,50,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,117,10,0,0,0,0,0,0,0,0,107,103,118,49,0,0,0,0,108,111,111,112,115,116,97,114,116,0,0,0,0,0,0,0,68,101,116,101,99,116,32,115,105,108,101,110,99,101,46,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,97,115,102,45,62,112,97,99,107,101,116,95,116,105,109,101,115,116,97,109,112,95,101,110,100,32,62,61,32,97,115,102,45,62,112,97,99,107,101,116,95,116,105,109,101,115,116,97,109,112,95,115,116,97,114,116,0,0,0,0,0,0,0,0,106,118,0,0,0,0,0,0,78,111,32,105,110,102,111,114,109,97,116,105,111,110,32,97,98,111,117,116,32,116,104,101,32,105,110,112,117,116,32,102,114,97,109,101,114,97,116,101,32,105,115,32,97,118,97,105,108,97,98,108,101,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,97,32,100,101,102,97,117,108,116,32,118,97,108,117,101,32,111,102,32,50,53,102,112,115,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,46,32,85,115,101,32,116,104,101,32,45,114,32,111,112,116,105,111,110,32,105,102,32,121,111,117,32,119,97,110,116,32,97,32,100,105,102,102,101,114,101,110,116,32,102,114,97,109,101,114,97,116,101,46,10,0,102,102,32,97,115,102,32,115,107,105,112,32,37,100,32,40,117,110,107,110,111,119,110,32,115,116,114,101,97,109,41,10,0,0,0,0,0,0,0,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,82,101,112,108,97,121,71,97,105,110,32,115,99,97,110,110,101,114,46,0,0,0,0,0,106,112,101,103,108,115,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,54,0,0,110,98,95,115,97,109,112,108,101,115,0,0,0,0,0,0,112,97,108,101,116,116,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,53,0,0,78,79,80,84,83,0,0,0,99,37,100,37,110,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,115,116,114,101,97,109,32,105,110,100,101,120,58,32,37,100,46,10,0,0,0,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,52,0,0,115,101,116,32,111,117,116,112,117,116,32,103,97,105,110,0,105,110,112,117,116,32,99,104,97,110,110,101,108,32,39,37,115,39,32,110,111,116,32,97,118,97,105,108,97,98,108,101,32,102,114,111,109,32,105,110,112,117,116,32,108,97,121,111,117,116,32,39,37,115,39,10,0,0,0,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,51,0,0,97,98,117,102,102,101,114,0,115,101,116,116,98,0,0,0,82,101,109,105,120,32,99,104,97,110,110,101,108,115,32,119,105,116,104,32,99,111,101,102,102,105,99,105,101,110,116,115,32,40,112,97,110,110,105,110,103,41,46,0,0,0,0,0,97,108,108,112,97,115,115,0,98,97,121,101,114,95,114,103,103,98,56,0,0,0,0,0,84,97,110,0,0,0,0,0,115,101,108,101,99,116,32,68,111,108,98,121,0,0,0,0,97,116,101,109,112,111,45,62,112,111,115,105,116,105,111,110,91,48,93,32,60,61,32,115,116,111,112,95,104,101,114,101,0,0,0,0,0,0,0,0,111,117,116,50,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,50,0,0,71,67,83,95,71,68,52,57,0,0,0,0,0,0,0,0,80,101,97,107,32,99,111,117,110,116,58,32,37,102,10,0,82,84,80,32,112,97,121,108,111,97,100,32,115,105,122,101,32,105,110,32,98,121,116,101,115,0,0,0,0,0,0,0,78,45,98,105,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,115,112,101,99,105,102,121,32,116,97,114,103,101,116,32,102,105,108,101,32,116,121,112,101,32,40,34,118,99,100,34,44,32,34,115,118,99,100,34,44,32,34,100,118,100,34,44,32,34,100,118,34,44,32,34,100,118,53,48,34,44,32,34,112,97,108,45,118,99,100,34,44,32,34,110,116,115,99,45,115,118,99,100,34,44,32,46,46,46,41,0,0,0,0,0,0,119,109,118,51,0,0,0,0,84,104,114,97,115,104,32,77,101,116,97,108,0,0,0,0,111,117,116,108,105,110,107,45,62,102,111,114,109,97,116,32,61,61,32,111,117,116,95,102,111,114,109,97,116,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,49,0,0,116,121,112,101,0,0,0,0,68,117,114,97,116,105,111,110,32,111,102,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,46,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,86,73,73,0,0,0,0,0,0,0,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,115,58,0,0,0,0,0,73,110,112,117,116,115,32,109,117,115,116,32,104,97,118,101,32,116,104,101,32,115,97,109,101,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,32,102,111,114,32,105,110,37,100,32,118,115,32,37,100,10,0,0,0,0,0,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,46,0,0,0,0,0,0,74,111,105,110,32,109,117,108,116,105,112,108,101,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,105,110,116,111,32,109,117,108,116,105,45,99,104,97,110,110,101,108,32,111,117,116,112,117,116,46,0,0,102,105,114,115,116,95,100,116,115,32,37,115,32,98,117,116,32,110,111,32,112,97,99,107,101,116,32,119,105,116,104,32,100,116,115,32,105,110,32,116,104,101,32,113,117,101,117,101,10,0,0,0,0,0,0,0,110,115,0,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,86,73,0,100,101,108,97,121,115,0,0,87,105,100,101,110,32,116,104,101,32,115,116,101,114,101,111,32,105,109,97,103,101,46,0,106,112,101,103,50,48,48,48,0,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,86,0,0,115,105,122,101,58,37,100,120,37,100,32,114,97,116,101,58,37,100,47,37,100,32,100,117,114,97,116,105,111,110,58,37,102,32,115,97,114,58,37,100,47,37,100,10,0,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,102,105,108,116,101,114,115,33,10,0,110,114,101,115,108,101,118,101,108,115,50,100,101,99,111,100,101,32,37,100,32,105,110,118,97,108,105,100,32,111,114,32,117,110,105,110,105,116,105,97,108,105,122,101,100,10,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,73,86,0,115,116,97,114,116,95,121,0,169,119,114,116,0,0,0,0,115,101,116,32,115,111,117,114,99,101,32,102,105,108,101,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,73,73,73,0,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,116,102,102,0,0,0,0,0,67,111,109,112,114,101,115,115,32,111,114,32,101,120,112,97,110,100,32,97,117,100,105,111,32,100,121,110,97,109,105,99,32,114,97,110,103,101,46,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,73,73,0,80,73,47,53,0,0,0,0,99,120,0,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,73,0,0,110,111,110,101,0,0,0,0,83,112,108,105,116,32,97,117,100,105,111,32,105,110,116,111,32,112,101,114,45,99,104,97,110,110,101,108,32,115,116,114,101,97,109,115,46,0,0,0,115,101,116,32,116,104,101,32,99,111,108,111,114,32,111,102,32,116,104,101,32,117,110,117,115,101,100,32,97,114,101,97,0,0,0,0,0,0,0,0,112,97,116,116,101,114,110,0,80,114,111,106,95,65,114,107,97,110,115,97,115,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,98,97,121,101,114,95,98,103,103,114,56,0,0,0,0,0,83,116,101,101,108,66,108,117,101,0,0,0,0,0,0,0,100,111,108,98,121,0,0,0,82,101,109,97,112,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,46,0,0,0,80,114,111,106,95,65,114,107,97,110,115,97,115,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,71,67,83,95,78,97,112,97,114,105,109,97,95,49,57,55,50,0,0,0,0,0,0,0,79,117,116,112,117,116,32,118,105,100,101,111,32,104,101,105,103,104,116,0,0,0,0,0,112,115,0,0,0,0,0,0,37,100,32,115,112,114,105,116,101,95,119,97,114,112,105,110,103,95,112,111,105,110,116,115,10,0,0,0,0,0,0,0,116,97,114,103,101,116,0,0,118,115,117,98,0,0,0,0,83,77,80,84,69,32,86,67,45,49,0,0,0,0,0,0,83,97,108,115,97,0,0,0,80,114,111,106,95,65,114,107,97,110,115,97,115,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,37,115,37,99,0,0,0,0,106,97,99,111,115,117,98,0,115,101,116,32,116,104,101,32,121,32,111,102,102,115,101,116,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,116,104,101,32,105,110,112,117,116,32,105,109,97,103,101,32,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,0,80,114,111,106,95,65,114,107,97,110,115,97,115,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,32,37,115,0,0,0,0,0,104,115,117,98,0,0,0,0,102,105,114,115,116,95,100,116,115,32,37,115,32,110,111,116,32,109,97,116,99,104,105,110,103,32,102,105,114,115,116,32,100,116,115,32,37,115,32,40,112,116,115,32,37,115,44,32,100,117,114,97,116,105,111,110,32,37,100,41,32,105,110,32,116,104,101,32,113,117,101,117,101,10,0,0,0,0,0,0,106,112,101,103,50,48,48,48,0,0,0,0,0,0,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,83,56,51,95,119,101,115,116,0,0,116,0,0,0,0,0,0,0,105,110,112,117,116,32,37,100,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,37,100,32,112,108,97,110,101,10,0,0,0,0,0,0,0,0,105,110,116,101,114,112,111,108,97,116,101,32,118,97,108,117,101,115,32,117,115,105,110,103,32,116,104,101,32,56,32,112,111,105,110,116,115,32,100,101,102,105,110,105,110,103,32,97,32,99,117,98,101,0,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,99,49,0,0,0,0,0,0,69,110,99,111,100,101,114,32,40,99,111,100,101,99,32,37,115,41,32,110,111,116,32,102,111,117,110,100,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,0,0,0,115,101,108,101,99,116,32,97,108,112,104,97,32,109,111,100,101,0,0,0,0,0,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,83,56,51,95,101,97,115,116,0,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,115,101,116,32,116,104,101,32,104,117,101,32,97,110,103,108,101,32,100,101,103,114,101,101,115,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,108,101,118,101,108,95,104,101,105,103,104,116,0,0,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,111,111,114,100,105,110,97,116,101,95,83,121,115,116,101,109,95,119,101,115,116,0,0,0,0,0,112,97,99,107,101,100,0,0,100,111,119,110,0,0,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,111,111,114,100,105,110,97,116,101,95,83,121,115,116,101,109,95,67,101,110,116,114,97,108,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,111,111,114,100,105,110,97,116,101,95,83,121,115,116,101,109,95,101,97,115,116,0,0,0,0,0,121,117,118,106,52,52,52,112,0,0,0,0,0,0,0,0,83,67,58,37,100,32,124,32,67,79,77,66,83,58,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,40,99,111,109,98,112,101,108,61,37,100,41,32,109,97,116,99,104,61,37,100,32,99,111,109,98,101,100,61,37,115,10,0,0,0,0,0,10,0,0,0,0,0,0,0,37,77,58,37,83,0,0,0,37,100,47,37,100,0,0,0,65,112,112,108,121,32,116,119,111,45,112,111,108,101,32,112,101,97,107,105,110,103,32,101,113,117,97,108,105,122,97,116,105,111,110,32,40,69,81,41,32,102,105,108,116,101,114,46,0,0,0,0,0,0,0,0,97,100,108,101,114,51,50,0,115,0,0,0,0,0,0,0,101,120,112,0,0,0,0,0,69,79,70,0,0,0,0,0,98,97,99,107,32,108,101,102,116,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,98,97,109,97,95,67,83,56,51,95,87,101,115,116,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,108,97,115,116,73,110,76,117,109,66,117,102,32,43,32,49,32,45,32,115,114,99,83,108,105,99,101,89,32,62,61,32,48,0,0,0,0,0,0,0,103,97,117,115,115,0,0,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,48,120,37,108,108,120,32,105,115,32,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,46,10,0,121,117,118,106,52,49,49,112,0,0,0,0,0,0,0,0,83,112,114,105,110,103,71,114,101,101,110,0,0,0,0,0,104,0,0,0,0,0,0,0,115,101,108,101,99,116,32,110,111,110,101,0,0,0,0,0,80,114,111,106,95,65,108,97,98,97,109,97,95,67,83,56,51,95,69,97,115,116,0,0,92,102,115,37,49,91,92,125,93,37,110,0,0,0,0,0,71,67,83,95,78,97,104,114,119,97,110,95,49,57,54,55,0,0,0,0,0,0,0,0,83,97,109,112,108,101,32,100,101,112,116,104,32,37,100,0,114,120,0,0,0,0,0,0,115,116,114,97,116,101,103,121,32,116,111,32,99,104,111,111,115,101,32,98,101,116,119,101,101,110,32,73,47,80,47,66,45,102,114,97,109,101,115,0,97,100,112,99,109,95,101,97,95,114,50,0,0,0,0,0,83,116,97,116,105,99,32,83,112,114,105,116,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,77,105,120,105,110,103,32,76,101,118,101,108,0,0,0,0,77,105,120,105,110,103,32,76,101,118,101,108,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,32,114,97,116,101,46,32,109,117,115,116,32,98,101,32,37,100,32,116,111,32,37,100,32,102,111,114,32,116,104,105,115,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,108,111,114,111,95,99,109,105,120,108,101,118,0,0,0,0,100,117,112,116,104,114,101,115,104,0,0,0,0,0,0,0,83,66,82,32,69,120,116,101,110,115,105,111,110,32,111,118,101,114,32,114,101,97,100,46,10,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,118,99,49,0,0,0,0,0,83,66,82,32,115,105,103,110,97,108,101,100,32,116,111,32,98,101,32,110,111,116,45,112,114,101,115,101,110,116,32,98,117,116,32,119,97,115,32,102,111,117,110,100,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,46,10,0,77,101,114,101,110,103,117,101,0,0,0,0,0,0,0,0,65,100,106,117,115,116,32,97,117,100,105,111,32,116,101,109,112,111,46,0,0,0,0,0,80,114,111,106,95,65,108,97,98,97,109,97,95,67,83,50,55,95,87,101,115,116,0,0,100,101,99,111,100,101,32,105,50,32,102,114,97,109,101,32,102,97,105,108,101,100,10,0,49,46,50,46,53,0,0,0,105,110,118,97,108,105,100,32,98,105,116,115,32,112,101,114,32,112,105,120,101,108,10,0,73,110,118,97,108,105,100,32,100,101,108,116,97,32,112,105,116,99,104,32,104,114,97,110,103,101,59,32,98,114,111,107,101,110,32,101,120,116,114,97,100,97,116,97,63,10,0,0,105,110,118,97,108,105,100,32,115,99,97,108,101,32,102,97,99,116,111,114,32,99,111,100,105,110,103,10,0,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,99,104,97,110,110,101,108,32,108,101,110,40,37,100,41,32,62,32,115,97,109,112,108,101,115,95,112,101,114,95,102,114,97,109,101,40,37,100,41,10,0,0,115,97,109,112,108,101,32,114,97,116,101,32,105,115,32,116,111,111,32,104,105,103,104,58,32,37,100,32,62,32,52,56,107,72,122,10,0,0,0,0,116,111,116,97,108,95,103,97,105,110,32,111,118,101,114,114,101,97,100,10,0,0,0,0,123,92,117,49,125,0,0,0,73,110,118,97,108,105,100,32,87,101,98,80,32,76,111,115,115,108,101,115,115,32,115,105,103,110,97,116,117,114,101,10,0,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,73,110,118,97,108,105,100,32,73,78,84,51,50,73,78,70,79,44,32,115,105,122,101,32,61,32,37,105,10,0,0,0,99,117,114,114,101,110,116,32,115,114,99,95,112,111,115,32,61,32,37,100,44,32,99,111,117,110,116,32,61,32,37,100,44,32,100,101,115,116,95,115,105,122,101,32,61,32,37,100,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,100,101,99,111,100,101,114,32,102,111,114,32,37,100,120,37,100,10,0,108,97,115,116,0,0,0,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,115,117,112,101,114,98,108,111,99,107,115,10,0,0,0,0,99,98,45,62,110,100,105,109,101,110,115,105,111,110,115,32,62,61,32,50,0,0,0,0,118,114,45,62,99,108,97,115,115,105,102,105,99,97,116,105,111,110,115,32,62,32,49,0,73,110,118,97,108,105,100,32,102,114,97,109,105,110,103,32,98,105,116,32,105,110,32,73,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,100,101,112,116,104,32,37,105,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,111,114,105,122,111,110,116,97,108,32,114,97,110,103,101,32,37,100,45,37,100,10,0,109,98,95,104,101,105,103,104,116,32,62,32,48,0,0,0,80,114,111,106,95,65,108,97,98,97,109,97,95,67,83,50,55,95,69,97,115,116,0,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,115,58,0,0,0,0,115,101,116,32,116,104,101,32,121,32,99,114,111,112,32,97,114,101,97,32,101,120,112,114,101,115,115,105,111,110,0,0,69,110,116,114,121,32,112,111,105,110,116,32,105,110,102,111,58,10,66,114,111,107,101,110,76,105,110,107,61,37,105,44,32,67,108,111,115,101,100,69,110,116,114,121,61,37,105,44,32,80,97,110,115,99,97,110,70,108,97,103,61,37,105,10,82,101,102,68,105,115,116,61,37,105,44,32,80,111,115,116,112,114,111,99,61,37,105,44,32,70,97,115,116,85,86,77,67,61,37,105,44,32,69,120,116,77,86,61,37,105,10,68,81,117,97,110,116,61,37,105,44,32,86,83,84,114,97,110,115,102,111,114,109,61,37,105,44,32,79,118,101,114,108,97,112,61,37,105,44,32,81,109,111,100,101,61,37,105,10,0,83,108,105,99,101,32,99,111,117,110,116,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,85,116,32,86,105,100,101,111,32,40,116,104,101,111,114,101,116,105,99,97,108,32,114,97,110,103,101,32,105,115,32,48,45,50,53,54,41,46,10,0,0,0,0,0,0,69,109,112,116,121,32,99,117,115,116,111,109,32,72,117,102,102,109,97,110,32,116,97,98,108,101,33,10,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,102,108,118,0,0,0,0,0,101,110,99,111,100,101,114,0,103,98,0,0,0,0,0,0,84,84,65,32,68,101,99,111,100,101,114,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,115,101,32,86,76,67,115,10,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,72,117,102,102,109,97,110,32,116,114,101,101,32,110,111,100,101,115,58,32,37,105,10,0,0,0,0,0,32,73,78,84,69,82,0,0,99,111,109,112,114,101,115,115,105,111,110,95,97,108,103,111,0,0,0,0,0,0,0,0,114,104,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,54,48,83,0,0,67,111,112,121,32,116,119,111,32,115,116,114,101,97,109,115,32,111,102,32,97,117,100,105,111,32,100,97,116,97,32,105,110,32,97,32,99,111,110,102,105,103,117,114,97,98,108,101,32,111,114,100,101,114,46,0,71,101,111,103,73,110,118,70,108,97,116,116,101,110,105,110,103,71,101,111,75,101,121,0,82,101,97,100,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,116,101,120,116,32,100,101,99,111,100,101,114,0,0,0,0,99,48,95,109,111,100,101,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,10,0,0,0,0,0,60,102,111,110,116,32,115,105,122,101,61,34,37,100,34,62,0,0,0,0,0,0,0,0,102,111,110,116,0,0,0,0,37,46,54,103,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,57,83,0,0,112,105,120,101,108,32,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,105,115,115,105,110,103,32,82,73,70,70,32,116,97,103,10,0,0,0,0,0,0,0,116,111,111,32,115,104,111,114,116,32,105,110,112,117,116,32,102,114,97,109,101,32,40,37,100,32,98,121,116,101,115,41,10,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,101,97,114,108,121,32,66,45,102,114,97,109,101,10,0,0,97,118,103,81,80,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2261640);
/* memory initializer */ allocate([97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,79,118,101,114,114,105,100,105,110,103,32,97,115,112,101,99,116,32,114,97,116,105,111,32,119,105,116,104,32,115,116,114,101,97,109,32,99,111,112,121,32,109,97,121,32,112,114,111,100,117,99,101,32,105,110,118,97,108,105,100,32,102,105,108,101,115,10,0,0,0,0,0,73,110,118,97,108,105,100,32,55,98,105,116,32,99,111,100,101,119,111,114,100,10,0,0,104,105,103,104,32,113,117,97,108,105,116,121,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,32,116,121,112,101,58,32,37,100,10,0,0,0,0,0,101,114,114,111,114,32,119,114,111,110,103,32,109,98,32,99,111,117,110,116,32,121,32,37,100,32,104,32,37,100,10,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,56,83,0,0,66,114,111,107,101,110,32,122,84,88,116,32,99,104,117,110,107,10,0,0,0,0,0,0,67,111,110,118,101,114,115,105,111,110,32,119,105,108,108,32,110,111,116,32,98,101,32,108,111,115,115,108,101,115,115,46,10,0,0,0,0,0,0,0,101,110,100,95,115,97,109,112,108,101,0,0,0,0,0,0,97,65,82,84,0,0,0,0,115,116,114,101,97,109,115,0,98,101,115,116,95,101,102,102,111,114,116,95,116,105,109,101,115,116,97,109,112,0,0,0,67,111,109,112,108,101,116,105,111,110,32,98,105,116,109,97,115,107,32,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,101,114,114,111,114,10,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,77,97,120,46,32,115,101,101,107,32,116,105,109,101,32,37,103,32,109,115,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,55,83,0,0,113,117,97,110,116,105,122,101,114,95,110,111,105,115,101,95,115,104,97,112,105,110,103,0,37,108,108,100,0,0,0,0,83,104,111,119,32,116,105,109,101,32,100,111,109,97,105,110,32,115,116,97,116,105,115,116,105,99,115,32,97,98,111,117,116,32,97,117,100,105,111,32,102,114,97,109,101,115,46,0,116,111,111,32,109,97,110,121,32,116,104,114,101,97,100,115,47,115,108,105,99,101,115,32,40,37,100,41,44,32,114,101,100,117,99,105,110,103,32,116,111,32,37,100,10,0,0,0,70,114,97,109,101,32,115,105,122,101,32,115,109,97,108,108,101,114,32,116,104,97,110,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,70,114,97,109,101,32,115,105,122,101,32,115,109,97,108,108,101,114,32,116,104,97,110,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,78,111,32,115,117,99,104,32,102,105,108,116,101,114,58,32,39,37,115,39,10,0,0,0,82,68,32,111,112,116,105,109,97,108,32,77,66,32,108,101,118,101,108,32,114,101,115,105,100,117,97,108,32,115,107,105,112,112,105,110,103,0,0,0,84,105,109,101,99,111,100,101,32,105,115,32,105,110,32,100,114,111,112,32,102,114,97,109,101,32,102,111,114,109,97,116,46,0,0,0,0,0,0,0,112,105,99,116,117,114,101,32,105,110,32,101,120,116,114,97,100,97,116,97,10,0,0,0,67,97,110,110,111,116,32,105,110,105,116,32,81,85,65,78,84,32,86,76,67,32,37,105,44,37,105,10,0,0,0,0,113,112,58,37,100,32,37,99,32,115,105,122,101,58,37,100,32,114,110,100,58,37,100,37,115,37,115,37,115,37,115,37,115,37,115,37,115,37,115,37,115,32,37,100,47,37,100,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,54,83,0,0,115,117,98,115,116,114,101,97,109,32,37,100,32,108,101,110,103,116,104,32,109,105,115,109,97,116,99,104,10,0,0,0,99,111,109,112,111,110,101,110,116,32,37,100,32,37,100,58,37,100,32,105,100,58,32,37,100,32,113,117,97,110,116,58,37,100,10,0,0,0,0,0,115,111,100,32,111,102,102,115,58,32,48,120,37,120,10,0,123,92,102,115,37,100,125,0,116,98,58,37,100,47,37,100,32,112,116,115,58,37,108,108,100,32,45,62,32,116,98,58,37,100,47,37,100,32,112,116,115,58,37,108,108,100,10,0,68,101,99,111,100,101,100,32,115,105,122,101,32,100,105,102,102,101,114,115,32,40,37,100,32,33,61,32,37,108,117,41,10,0,0,0,0,0,0,0,83,99,97,108,101,100,32,112,114,111,98,97,98,105,108,105,116,105,101,115,32,97,114,101,32,108,97,114,103,101,114,32,116,104,97,110,32,116,97,114,103,101,116,33,10,0,0,0,66,108,111,99,107,32,119,105,116,104,32,108,101,110,103,116,104,105,110,99,32,103,114,101,97,116,101,114,32,116,104,97,110,32,37,122,117,0,0,0,123,92,97,110,55,125,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,104,111,119,32,116,101,120,116,117,97,108,32,105,110,102,111,114,109,97,116,105,111,110,32,102,111,114,32,101,97,99,104,32,97,117,100,105,111,32,102,114,97,109,101,46,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,101,97,118,101,0,0,0,67,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,99,111,108,111,114,32,112,108,97,110,101,115,33,10,0,0,0,0,0,0,109,105,115,109,97,116,99,104,105,110,103,32,115,99,97,110,32,116,97,98,108,101,33,10,0,0,0,0,0,0,0,0,77,111,100,101,32,37,100,58,32,82,76,69,32,99,111,100,101,32,37,88,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,97,116,32,116,104,101,32,99,117,114,114,101,110,116,32,108,105,110,101,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,53,83,0,0,70,70,84,32,105,110,105,116,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,98,105,116,112,108,97,110,101,115,58,32,37,117,10,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,61,49,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,50,32,112,97,115,115,32,104,117,102,102,121,117,118,32,101,110,99,111,100,105,110,103,10,0,0,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,115,112,115,32,99,111,110,102,111,114,109,97,110,99,101,32,119,105,110,100,111,119,44,32,111,114,105,103,105,110,97,108,32,118,97,108,117,101,115,32,97,114,101,32,108,58,37,117,32,114,58,37,117,32,116,58,37,117,32,98,58,37,117,10,0,0,0,0,0,70,105,114,115,116,32,115,108,105,99,101,32,105,110,32,97,32,102,114,97,109,101,32,109,105,115,115,105,110,103,46,10,0,0,0,0,0,0,0,0,98,108,111,99,107,95,108,114,0,0,0,0,0,0,0,0,115,116,97,114,116,95,116,0,109,109,99,111,58,32,117,110,114,101,102,32,115,104,111,114,116,32,37,100,32,99,111,117,110,116,32,37,100,10,0,0,115,112,115,58,37,117,32,112,114,111,102,105,108,101,58,37,100,47,37,100,32,112,111,99,58,37,100,32,114,101,102,58,37,100,32,37,100,120,37,100,32,37,115,32,37,115,32,99,114,111,112,58,37,100,47,37,100,47,37,100,47,37,100,32,37,115,32,37,115,32,37,100,47,37,100,32,98,37,100,32,114,101,111,58,37,100,10,0,72,46,50,54,52,32,47,32,65,86,67,32,47,32,77,80,69,71,45,52,32,65,86,67,32,47,32,77,80,69,71,45,52,32,112,97,114,116,32,49,48,0,0,0,0,0,0,0,105,110,116,101,114,112,108,97,121,118,105,100,101,111,0,0,111,118,101,114,114,101,97,100,105,110,103,32,37,100,32,98,105,116,115,10,0,0,0,0,113,115,99,97,108,101,32,104,97,115,32,102,111,114,98,105,100,100,101,110,32,48,32,118,97,108,117,101,10,0,0,0,114,97,110,100,111,109,0,0,99,111,108,111,114,32,118,97,108,117,101,32,40,65,82,71,66,41,32,116,104,97,116,32,105,115,32,117,115,101,100,32,105,110,115,116,101,97,100,32,111,102,32,116,114,97,110,115,112,97,114,101,110,116,32,99,111,108,111,114,0,0,0,0,116,114,97,110,115,100,105,102,102,0,0,0,0,0,0,0,99,111,100,101,95,115,105,122,101,0,0,0,0,0,0,0,67,104,97,110,103,101,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,32,119,105,116,104,111,117,116,32,97,108,116,101,114,105,110,103,32,116,104,101,32,100,97,116,97,46,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,52,83,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,100,97,116,97,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,66,108,111,99,107,32,112,97,114,97,109,101,116,101,114,115,32,105,110,118,97,108,105,100,58,32,37,100,32,43,32,37,100,32,62,32,37,100,10,0,48,0,0,0,0,0,0,0,78,111,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,115,112,101,99,105,102,105,101,100,46,32,84,104,101,32,101,110,99,111,100,101,114,32,119,105,108,108,32,117,115,101,32,70,108,97,99,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,102,111,114,32,37,100,32,99,104,97,110,110,101,108,115,46,10,0,115,97,109,112,108,101,32,114,97,116,101,32,110,111,116,32,102,111,117,110,100,32,105,110,32,83,84,82,69,65,77,73,78,70,79,32,111,114,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,0,86,101,114,115,105,111,110,32,50,32,110,101,101,100,101,100,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,102,101,97,116,117,114,101,115,32,98,117,116,32,118,101,114,115,105,111,110,32,50,32,105,115,32,101,120,112,101,114,105,109,101,110,116,97,108,32,97,110,100,32,110,111,116,32,101,110,97,98,108,101,100,10,0,0,115,108,105,99,101,95,114,99,116,95,121,95,99,111,101,102,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,89,0,0,0,0,0,0,0,76,97,114,103,101,32,82,111,111,109,0,0,0,0,0,0,103,98,114,97,112,49,54,108,101,0,0,0,0,0,0,0,83,110,111,119,0,0,0,0,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,85,110,107,110,111,119,110,32,83,79,76,32,115,117,98,99,111,100,101,99,10,0,0,0,113,109,97,120,0,0,0,0,119,97,118,101,108,101,116,95,105,100,120,32,105,115,32,116,111,111,32,98,105,103,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,68,84,83,45,88,88,67,72,58,32,73,110,99,111,110,115,105,115,116,97,110,116,32,97,118,99,111,100,101,99,47,100,116,115,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,10,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,51,83,0,0,67,111,110,116,97,105,110,101,114,32,99,104,97,110,110,101,108,115,32,33,61,32,49,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,0,71,67,83,95,78,65,68,56,51,0,0,0,0,0,0,0,66,97,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,98,95,115,116,114,97,116,101,103,121,0,0,0,0,0,0,77,80,69,71,52,32,79,66,77,67,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,118,101,114,121,32,108,105,107,101,108,121,32,98,117,103,103,121,32,101,110,99,111,100,101,114,41,10,0,0,0,109,106,112,101,103,0,0,0,114,101,97,100,32,105,110,112,117,116,32,97,116,32,110,97,116,105,118,101,32,102,114,97,109,101,32,114,97,116,101,0,109,105,110,95,115,116,114,105,112,115,0,0,0,0,0,0,105,108,108,101,103,97,108,32,105,110,116,114,97,32,99,98,112,10,0,0,0,0,0,0,110,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,40,37,100,32,60,32,37,100,41,10,0,0,0,0,0,0,82,101,97,108,86,105,100,101,111,32,52,46,48,0,0,0,83,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,102,111,114,32,101,97,99,104,32,111,117,116,112,117,116,32,97,117,100,105,111,32,102,114,97,109,101,115,46,0,39,115,99,97,108,101,39,32,102,105,108,116,101,114,32,110,111,116,32,112,114,101,115,101,110,116,44,32,99,97,110,110,111,116,32,99,111,110,118,101,114,116,32,112,105,120,101,108,32,102,111,114,109,97,116,115,46,10,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,32,111,114,32,116,111,111,32,115,104,111,114,116,10,0,67,104,114,105,115,116,105,97,110,32,82,111,99,107,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,50,83,0,0,85,110,107,110,111,119,110,32,97,109,111,117,110,116,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,32,37,100,46,10,0,0,0,0,0,0,0,0,79,110,108,121,32,109,111,110,111,32,97,110,100,32,115,116,101,114,101,111,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,113,117,105,114,101,100,32,65,76,83,32,101,120,116,114,97,100,97,116,97,46,10,0,0,0,0,0,0,0,0,100,101,112,101,110,100,115,0,97,110,97,103,108,121,112,104,95,99,121,97,110,95,114,101,100,0,0,0,0,0,0,0,82,38,66,0,0,0,0,0,87,77,47,71,101,110,114,101,0,0,0,0,0,0,0,0,112,105,110,103,0,0,0,0,116,105,116,108,101,0,0,0,52,50,48,112,49,50,0,0,114,97,116,101,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,49,83,0,0,32,37,100,47,37,100,0,0,109,111,118,44,109,112,52,44,109,52,97,44,51,103,112,44,51,103,50,44,109,106,50,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,105,110,100,101,111,53,0,0,82,101,115,97,109,112,108,101,32,97,117,100,105,111,32,100,97,116,97,46,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,45,97,99,111,100,101,99,32,99,111,112,121,32,97,110,100,32,45,118,111,108,32,97,114,101,32,105,110,99,111,109,112,97,116,105,98,108,101,32,40,102,114,97,109,101,115,32,97,114,101,32,110,111,116,32,100,101,99,111,100,101,100,41,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,55,83,0,0,105,110,100,101,111,52,0,0,65,100,100,32,97,32,112,104,97,115,105,110,103,32,101,102,102,101,99,116,32,116,111,32,116,104,101,32,97,117,100,105,111,46,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,54,83,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,53,83,0,0,80,97,100,32,97,117,100,105,111,32,119,105,116,104,32,115,105,108,101,110,99,101,46,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,52,83,0,0,80,97,115,115,32,116,104,101,32,115,111,117,114,99,101,32,117,110,99,104,97,110,103,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,46,0,0,0,0,0,0,0,0,103,98,114,97,112,49,54,98,101,0,0,0,0,0,0,0,83,108,97,116,101,71,114,97,121,0,0,0,0,0,0,0,115,101,116,32,109,97,116,114,105,120,101,100,32,115,116,101,114,101,111,32,101,110,99,111,100,105,110,103,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,51,83,0,0,71,67,83,95,78,65,68,95,77,105,99,104,105,103,97,110,0,0,0,0,0,0,0,0,105,110,100,101,111,51,0,0,114,97,116,101,99,111,110,116,114,111,108,32,109,101,116,104,111,100,0,0,0,0,0,0,114,101,0,0,0,0,0,0,105,110,100,101,111,50,0,0,114,118,52,48,0,0,0,0,67,111,110,116,101,109,112,111,114,97,114,121,32,67,104,114,105,115,116,105,97,110,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,50,83,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,49,83,0,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,102,114,97,109,101,114,97,116,101,115,58,0,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,111,112,116,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,117,100,105,111,32,109,105,120,105,110,103,46,0,0,0,119,114,105,116,101,32,115,116,114,101,97,109,32,100,97,116,97,32,102,97,105,108,101,100,32,99,111,100,101,99,95,116,121,112,101,40,48,120,37,120,41,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,116,115,47,112,116,115,32,99,111,109,98,105,110,97,116,105,111,110,32,37,108,108,105,10,0,0,0,0,0,0,0,114,111,111,116,32,100,105,114,101,99,116,111,114,121,32,115,105,122,101,32,101,120,99,101,101,100,115,32,115,101,99,116,111,114,32,115,105,122,101,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,48,83,0,0,83,101,116,32,107,105,110,100,32,111,102,32,87,101,98,86,84,84,32,116,114,97,99,107,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,57,83,0,0,105,109,99,0,0,0,0,0,111,114,105,103,105,110,97,116,105,111,110,95,116,105,109,101,0,0,0,0,0,0,0,0,65,82,78,71,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,56,83,0,0,77,101,114,103,101,32,116,119,111,32,111,114,32,109,111,114,101,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,105,110,116,111,32,97,32,115,105,110,103,108,101,32,109,117,108,116,105,45,99,104,97,110,110,101,108,32,115,116,114,101,97,109,46,0,0,0,0,0,84,105,109,101,85,110,105,116,78,117,109,101,114,97,116,111,114,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,55,83,0,0,105,102,102,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,54,83,0,0,115,101,110,100,99,109,100,0,67,111,110,118,101,114,116,32,116,104,101,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,111,110,101,32,111,102,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,102,111,114,109,97,116,115,46,0,0,0,0,0,0,0,0,105,100,99,105,110,118,105,100,101,111,0,0,0,0,0,0,115,101,112,97,114,97,116,101,32,109,111,100,101,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,53,83,0,0,116,116,97,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,52,83,0,0,103,98,114,97,112,0,0,0,83,108,97,116,101,66,108,117,101,0,0,0,0,0,0,0,115,101,108,101,99,116,0,0,109,97,116,114,105,120,95,101,110,99,111,100,105,110,103,0,34,115,116,97,114,116,79,102,80,97,114,97,103,114,97,112,104,34,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,51,83,0,0,104,117,102,102,121,117,118,0,71,67,83,95,78,65,68,50,55,0,0,0,0,0,0,0,83,87,70,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,77,80,51,10,0,0,0,0,114,99,95,115,116,114,97,116,101,103,121,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,105,110,105,116,32,122,108,105,98,32,99,111,110,116,101,120,116,10,0,0,0,0,97,102,116,101,114,32,104,101,105,103,104,116,0,0,0,0,10,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,119,104,101,110,32,100,117,109,112,105,110,103,32,112,97,99,107,101,116,115,44,32,97,108,115,111,32,100,117,109,112,32,116,104,101,32,112,97,121,108,111,97,100,0,0,0,0,0,82,101,97,108,86,105,100,101,111,32,51,46,48,0,0,0,67,114,111,115,115,111,118,101,114,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,50,83,0,0,85,110,107,110,111,119,110,32,68,84,83,32,115,97,109,112,108,101,32,114,97,116,101,32,102,111,114,32,72,68,10,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,49,83,0,0,110,111,0,0,0,0,0,0,60,81,117,97,108,105,116,121,76,101,118,101,108,32,73,110,100,101,120,61,34,37,100,34,32,66,105,116,114,97,116,101,61,34,37,100,34,32,70,111,117,114,67,67,61,34,37,115,34,32,77,97,120,87,105,100,116,104,61,34,37,100,34,32,77,97,120,72,101,105,103,104,116,61,34,37,100,34,32,67,111,100,101,99,80,114,105,118,97,116,101,68,97,116,97,61,34,37,115,34,32,47,62,10,0,0,0,0,0,0,0,0,104,117,102,102,121,117,118,0,70,97,100,101,32,105,110,47,111,117,116,32,105,110,112,117,116,32,97,117,100,105,111,46,0,0,0,0,0,0,0,0,68,84,83,32,37,108,108,105,32,60,32,37,108,108,105,32,111,117,116,32,111,102,32,111,114,100,101,114,10,0,0,0,84,111,111,32,104,105,103,104,32,115,121,109,98,111,108,32,102,114,101,113,117,101,110,99,105,101,115,46,32,84,114,101,101,32,99,111,110,115,116,114,117,99,116,105,111,110,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,10,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,48,83,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,108,105,115,116,95,102,108,97,103,115,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,57,83,0,0,104,110,109,52,118,105,100,101,111,0,0,0,0,0,0,0,102,52,118,0,0,0,0,0,97,61,99,111,110,116,114,111,108,58,115,116,114,101,97,109,105,100,61,37,100,13,10,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,56,83,0,0,115,121,110,116,97,120,32,101,114,114,111,114,0,0,0,0,65,100,100,32,101,99,104,111,105,110,103,32,116,111,32,116,104,101,32,97,117,100,105,111,46,0,0,0,0,0,0,0,68,101,99,111,100,105,110,103,32,83,69,73,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,55,83,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,46,114,97,0,0,0,0,0,100,0,0,0,0,0,0,0,68,65,84,65,32,116,97,103,32,105,110,32,109,105,100,100,108,101,32,111,102,32,99,104,117,110,107,44,32,102,105,108,101,32,109,97,121,32,98,101,32,98,114,111,107,101,110,46,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,54,83,0,0,68,101,108,97,121,32,111,110,101,32,111,114,32,109,111,114,101,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,46,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,37,117,46,37,117,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,53,83,0,0,68,117,112,108,105,99,97,116,101,32,80,79,67,32,105,110,32,97,32,115,101,113,117,101,110,99,101,58,32,37,100,46,10,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,67,111,110,118,101,114,116,32,116,104,101,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,115,97,109,112,108,101,95,102,109,116,58,99,104,97,110,110,101,108,95,108,97,121,111,117,116,46,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,100,110,120,104,100,0,0,0,114,97,119,32,84,114,117,101,72,68,0,0,0,0,0,0,103,98,114,112,49,52,108,101,0,0,0,0,0,0,0,0,83,107,121,66,108,117,101,0,65,115,115,117,109,101,32,116,104,101,32,102,105,114,115,116,32,112,116,115,32,115,104,111,117,108,100,32,98,101,32,116,104,105,115,32,118,97,108,117,101,32,40,105,110,32,115,97,109,112,108,101,115,41,46,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,71,67,83,95,77,95,112,111,114,97,108,111,107,111,0,0,81,80,32,102,97,99,116,111,114,32,98,101,116,119,101,101,110,32,80,45,32,97,110,100,32,66,45,102,114,97,109,101,115,0,0,0,0,0,0,0,98,101,102,111,114,101,32,104,101,105,103,104,116,0,0,0,104,101,120,0,0,0,0,0,114,118,51,48,0,0,0,0,66,108,97,99,107,32,77,101,116,97,108,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,49,83,0,0,115,108,105,99,101,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,114,101,97,100,95,102,114,97,109,101,95,105,110,116,101,114,110,97,108,32,115,116,114,101,97,109,61,37,100,44,32,112,116,115,61,37,115,44,32,100,116,115,61,37,115,44,32,115,105,122,101,61,37,100,44,32,100,117,114,97,116,105,111,110,61,37,100,44,32,102,108,97,103,115,61,37,100,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,48,83,0,0,71,101,110,101,114,97,116,101,32,97,110,32,97,117,100,105,111,32,115,105,103,110,97,108,32,103,101,110,101,114,97,116,101,100,32,98,121,32,97,110,32,101,120,112,114,101,115,115,105,111,110,46,0,0,0,0,103,101,110,112,116,115,0,0,78,111,32,101,110,99,114,121,112,116,105,111,110,32,104,101,97,100,101,114,32,102,111,117,110,100,10,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,57,83,0,0,105,112,111,100,0,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,111,102,32,100,101,108,116,97,95,105,100,120,32,105,110,32,115,108,105,99,101,32,104,101,97,100,101,114,32,82,80,83,58,32,37,100,32,62,32,37,100,46,10,0,0,0,0,0,0,0,112,97,103,101,115,105,122,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,56,83,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,110,117,115,45,62,108,97,115,116,95,112,116,115,32,33,61,32,40,40,105,110,116,54,52,95,116,41,48,120,56,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,85,76,76,41,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,55,83,0,0,115,116,114,101,97,109,95,105,110,100,101,120,32,61,61,32,45,49,0,0,0,0,0,0,37,42,115,32,37,42,115,32,37,51,49,115,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,54,83,0,0,99,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,105,110,100,101,120,32,101,110,116,114,105,101,115,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,53,83,0,0,110,101,120,116,95,111,102,115,32,100,105,100,110,39,116,32,99,104,97,110,103,101,46,32,110,111,116,32,100,101,114,105,118,105,110,103,32,112,97,99,107,101,116,32,116,105,109,101,115,116,97,109,112,115,10,0,49,0,0,0,0,0,0,0,37,108,108,100,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,52,83,0,0,80,114,111,118,105,100,101,32,97,110,32,117,110,105,102,111,114,109,108,121,32,99,111,108,111,114,101,100,32,105,110,112,117,116,46,0,0,0,0,0,103,98,114,112,49,52,98,101,0,0,0,0,0,0,0,0,83,105,108,118,101,114,0,0,102,105,114,115,116,95,112,116,115,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,51,83,0,0,72,46,50,54,52,32,98,105,116,115,116,114,101,97,109,32,101,114,114,111,114,44,32,115,116,97,114,116,99,111,100,101,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,71,67,83,95,77,111,110,116,101,95,77,97,114,105,111,0,98,95,113,102,97,99,116,111,114,0,0,0,0,0,0,0,80,69,83,32,112,97,99,107,101,116,32,115,105,122,101,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,0,98,101,102,111,114,101,32,119,105,100,116,104,0,0,0,0,100,117,109,112,32,101,97,99,104,32,105,110,112,117,116,32,112,97,99,107,101,116,0,0,109,117,120,114,97,116,101,0,72,117,102,102,121,117,118,32,70,70,109,112,101,103,32,118,97,114,105,97,110,116,0,0,72,101,97,118,121,32,77,101,116,97,108,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,50,83,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,37,115,32,97,115,32,77,80,69,71,32,115,117,98,116,105,116,108,101,115,10,0,0,0,0,84,82,67,75,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,49,83,0,0,102,114,97,109,101,0,0,0,100,101,109,117,120,101,114,32,105,110,106,101,99,116,105,110,103,32,115,107,105,112,32,37,100,10,0,0,0,0,0,0,67,65,66,65,67,95,77,65,88,95,66,73,78,32,58,32,37,100,10,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,48,83,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,57,83,0,0,0,112,115,112,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,56,83,0,0,0,82,101,110,100,101,114,32,97,32,77,97,110,100,101,108,98,114,111,116,32,102,114,97,99,116,97,108,46,0,0,0,0,169,99,112,121,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,55,83,0,0,0,67,104,97,112,116,101,114,32,37,100,32,110,111,116,32,102,111,117,110,100,32,105,110,32,102,105,108,101,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,54,83,0,0,0,102,114,97,109,101,32,104,97,115,104,32,101,110,99,111,100,101,114,32,99,108,97,115,115,0,0,0,0,0,0,0,0,82,101,115,101,114,118,101,32,97,32,103,105,118,101,110,32,97,109,111,117,110,116,32,111,102,32,115,112,97,99,101,32,40,105,110,32,98,121,116,101,115,41,32,97,116,32,116,104,101,32,98,101,103,105,110,110,105,110,103,32,111,102,32,116,104,101,32,102,105,108,101,32,102,111,114,32,116,104,101,32,105,110,100,101,120,32,40,99,117,101,115,41,46,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,83,0,0,0,104,101,118,99,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,101,99,111,114,100,58,32,37,120,32,61,32,37,105,45,37,48,50,105,45,37,48,50,105,10,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,83,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,65,76,69,84,84,69,0,103,98,114,112,49,50,108,101,0,0,0,0,0,0,0,0,83,105,101,110,110,97,0,0,115,105,109,112,108,105,102,105,101,100,32,49,32,112,97,114,97,109,101,116,101,114,32,97,117,100,105,111,32,116,105,109,101,115,116,97,109,112,32,109,97,116,99,104,105,110,103,44,32,48,40,100,105,115,97,98,108,101,100,41,44,32,49,40,102,105,108,108,105,110,103,32,97,110,100,32,116,114,105,109,109,105,110,103,41,44,32,62,49,40,109,97,120,105,109,117,109,32,115,116,114,101,116,99,104,47,115,113,117,101,101,122,101,32,105,110,32,115,97,109,112,108,101,115,32,112,101,114,32,115,101,99,111,110,100,41,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,83,0,0,0,71,67,83,95,77,104,97,115,116,0,0,0,0,0,0,0,67,114,101,97,116,101,32,108,105,102,101,46,0,0,0,0,115,101,116,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,66,32,102,114,97,109,101,115,32,98,101,116,119,101,101,110,32,110,111,110,45,66,45,102,114,97,109,101,115,0,0,0,0,0,98,101,102,111,114,101,32,102,105,120,101,100,95,118,111,112,95,114,97,116,101,0,0,0,121,0,0,0,0,0,0,0,100,117,109,112,0,0,0,0,37,108,108,117,32,102,114,97,109,101,115,32,115,117,99,99,101,115,115,102,117,108,108,121,32,100,101,99,111,100,101,100,44,32,37,108,108,117,32,100,101,99,111,100,105,110,103,32,101,114,114,111,114,115,10,0,102,102,118,104,117,102,102,0,67,104,114,105,115,116,105,97,110,32,71,97,110,103,115,116,97,0,0,0,0,0,0,0,115,101,108,101,99,116,32,103,108,111,98,47,115,101,113,117,101,110,99,101,32,112,97,116,116,101,114,110,32,116,121,112,101,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,83,0,0,0,112,98,109,0,0,0,0,0,85,110,107,110,111,119,110,32,83,86,88,56,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,39,37,100,39,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,83,0,0,0,102,114,97,109,101,32,97,110,100,32,115,108,105,99,101,0,102,102,95,114,101,97,100,95,112,97,99,107,101,116,32,115,116,114,101,97,109,61,37,100,44,32,112,116,115,61,37,115,44,32,100,116,115,61,37,115,44,32,115,105,122,101,61,37,100,44,32,100,117,114,97,116,105,111,110,61,37,100,44,32,102,108,97,103,115,61,37,100,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,54,48,78,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,37,100,46,116,115,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,57,78,0,0,48,0,0,0,0,0,0,0,51,103,50,0,0,0,0,0,9,60,100,117,114,97,116,105,111,110,62,37,102,60,47,100,117,114,97,116,105,111,110,62,10,0,0,0,0,0,0,0,67,114,101,97,116,101,32,112,97,116,116,101,114,110,32,103,101,110,101,114,97,116,101,100,32,98,121,32,97,110,32,101,108,101,109,101,110,116,97,114,121,32,99,101,108,108,117,108,97,114,32,97,117,116,111,109,97,116,111,110,46,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,56,78,0,0,111,110,108,121,32,49,54,32,66,73,84,32,80,67,77,32,76,69,32,97,108,108,111,119,101,100,32,102,111,114,32,110,111,119,10,0,0,0,0,0,169,103,101,110,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,68,111,32,97,98,115,111,108,117,116,101,108,121,32,110,111,116,104,105,110,103,32,119,105,116,104,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,116,105,109,101,115,32,116,111,32,108,111,111,112,32,116,104,101,32,111,117,116,112,117,116,58,32,45,49,32,45,32,110,111,32,108,111,111,112,44,32,48,32,45,32,105,110,102,105,110,105,116,101,32,108,111,111,112,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,55,78,0,0,111,110,84,101,120,116,68,97,116,97,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,54,78,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,53,78,0,0,114,101,118,105,115,105,111,110,32,40,101,108,101,109,101,110,116,32,48,120,56,48,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,52,78,0,0,115,116,121,112,101,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,103,98,114,112,49,50,98,101,0,0,0,0,0,0,0,0,83,101,97,83,104,101,108,108,0,0,0,0,0,0,0,0,97,115,121,110,99,0,0,0,76,105,110,101,32,37,100,58,32,117,110,107,110,111,119,110,32,107,101,121,119,111,114,100,32,39,37,115,39,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,51,78,0,0,71,67,83,95,77,105,110,110,97,0,0,0,0,0,0,0,0,0,0,12,102,114,109,97,115,97,109,114,0,0,0,0,98,102,0,0,0,0,0,0,116,105,109,101,95,98,97,115,101,46,100,101,110,61,61,48,10,0,0,0,0,0,0,0,68,101,105,110,116,101,114,108,97,99,101,32,116,104,101,32,105,110,112,117,116,32,105,109,97,103,101,46,0,0,0,0,108,105,109,105,116,0,0,0,80,65,77,32,40,80,111,114,116,97,98,108,101,32,65,110,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,66,101,97,116,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,50,78,0,0,105,67,69,32,68,114,97,119,32,70,105,108,101,32,100,101,109,117,120,101,114,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,49,78,0,0,32,32,32,32,84,104,114,101,97,100,105,110,103,32,99,97,112,97,98,105,108,105,116,105,101,115,58,32,0,0,0,0,73,110,118,97,108,105,100,32,116,105,109,101,115,116,97,109,112,115,32,115,116,114,101,97,109,61,37,100,44,32,112,116,115,61,37,115,44,32,100,116,115,61,37,115,44,32,115,105,122,101,61,37,100,10,0,0,65,112,112,108,121,32,77,97,114,116,105,110,32,87,101,115,116,111,110,32,116,104,114,101,101,32,102,105,101,108,100,32,100,101,105,110,116,101,114,108,97,99,101,46,0,0,0,0,65,86,73,88,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,48,78,0,0,83,119,105,116,99,104,105,110,103,32,116,111,32,78,73,32,109,111,100,101,44,32,100,117,101,32,116,111,32,112,111,111,114,32,105,110,116,101,114,108,101,97,118,105,110,103,10,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,117,10,0,0,65,83,84,32,109,117,120,101,114,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,57,78,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,51,103,112,0,0,0,0,0,114,101,116,32,62,61,32,48,0,0,0,0,0,0,0,0,83,69,73,32,37,100,32,108,101,110,58,37,100,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,56,78,0,0,169,99,109,116,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,55,78,0,0,110,98,95,99,111,110,115,117,109,101,100,95,115,97,109,112,108,101,115,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,54,78,0,0,115,105,108,101,110,99,101,95,101,110,100,58,32,37,115,32,124,32,115,105,108,101,110,99,101,95,100,117,114,97,116,105,111,110,58,32,37,115,10,0,77,97,107,101,32,111,114,32,114,101,118,101,114,115,101,32,97,32,118,105,103,110,101,116,116,101,32,101,102,102,101,99,116,46,0,0,0,0,0,0,37,55,91,65,45,90,93,37,110,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,109,97,112,115,32,102,111,114,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,39,37,115,39,46,10,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,53,78,0,0,70,108,105,112,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,118,101,114], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2271880);
/* memory initializer */ allocate([116,105,99,97,108,108,121,46,0,0,0,0,0,0,0,0,103,97,105,110,0,0,0,0,100,101,102,97,117,108,116,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,52,78,0,0,83,105,109,112,108,101,32,102,105,108,116,101,114,103,114,97,112,104,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,101,120,97,99,116,108,121,32,111,110,101,32,105,110,112,117,116,32,97,110,100,32,111,117,116,112,117,116,46,10,0,0,0,0,65,112,112,108,121,32,97,32,104,105,103,104,45,112,97,115,115,32,102,105,108,116,101,114,32,119,105,116,104,32,51,100,66,32,112,111,105,110,116,32,102,114,101,113,117,101,110,99,121,46,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,121,117,118,52,52,52,112,49,52,108,101,0,0,0,0,0,83,101,97,71,114,101,101,110,0,0,0,0,0,0,0,0,115,101,116,32,109,97,120,105,109,117,109,32,102,97,99,116,111,114,32,98,121,32,119,104,105,99,104,32,100,97,116,97,32,105,115,32,115,116,114,101,116,99,104,101,100,47,115,113,117,101,101,122,101,100,32,116,111,32,109,97,107,101,32,105,116,32,109,97,116,99,104,32,116,104,101,32,116,105,109,101,115,116,97,109,112,115,46,0,114,101,97,100,95,115,105,122,101,32,60,61,32,97,116,101,109,112,111,45,62,114,105,110,103,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,51,78,0,0,111,117,116,49,0,0,0,0,71,67,83,95,77,97,115,115,97,119,97,0,0,0,0,0,79,118,101,114,97,108,108,10,0,0,0,0,0,0,0,0,109,97,120,105,109,117,109,32,100,105,102,102,101,114,101,110,99,101,32,98,101,116,119,101,101,110,32,116,104,101,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,115,32,40,86,66,82,41,0,0,0,98,101,102,111,114,101,32,116,105,109,101,95,105,110,99,114,101,109,101,110,116,95,114,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,115,101,116,32,109,97,120,32,114,117,110,116,105,109,101,32,105,110,32,115,101,99,111,110,100,115,0,0,0,0,0,0,112,97,109,0,0,0,0,0,80,111,108,115,107,32,80,117,110,107,0,0,0,0,0,0,111,117,116,108,105,110,107,45,62,99,104,97,110,110,101,108,95,108,97,121,111,117,116,32,61,61,32,111,117,116,95,108,97,121,111,117,116,32,124,124,32,33,111,117,116,108,105,110,107,45,62,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,50,78,0,0,115,101,116,32,109,111,100,117,108,97,116,105,111,110,32,115,112,101,101,100,0,0,0,0,111,117,116,115,97,109,112,108,101,115,114,101,102,45,62,110,98,95,115,97,109,112,108,101,115,32,61,61,32,110,95,111,117,116,0,0,0,0,0,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,49,78,0,0,68,101,99,111,100,101,114,0,100,101,102,97,117,108,116,0,83,104,97,114,112,101,110,32,111,114,32,98,108,117,114,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,0,115,101,101,107,95,102,114,97,109,101,95,103,101,110,101,114,105,99,32,102,97,105,108,101,100,32,97,115,32,116,104,105,115,32,115,116,114,101,97,109,32,115,101,101,109,115,32,116,111,32,99,111,110,116,97,105,110,32,110,111,32,107,101,121,102,114,97,109,101,115,32,97,102,116,101,114,32,116,104,101,32,116,97,114,103,101,116,32,116,105,109,101,115,116,97,109,112,44,32,37,100,32,110,111,110,32,107,101,121,102,114,97,109,101,115,32,102,111,117,110,100,10,0,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,102,111,114,32,102,97,100,101,32,100,117,114,97,116,105,111,110,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,115,101,116,32,115,105,103,110,97,108,32,111,117,116,112,117,116,32,103,97,105,110,0,0,99,104,0,0,0,0,0,0,115,112,115,95,105,100,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,71,101,110,101,114,97,116,101,32,83,77,80,84,69,32,72,68,32,99,111,108,111,114,32,98,97,114,115,46,0,0,0,109,112,52,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,115,101,116,32,116,104,101,32,105,110,105,116,105,97,108,32,120,32,112,111,115,105,116,105,111,110,0,0,0,0,0,0,169,100,101,115,0,0,0,0,84,114,97,110,115,112,111,115,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,115,101,116,32,105,110,105,116,105,97,108,32,112,97,116,116,101,114,110,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,97,115,115,117,109,101,100,32,112,105,99,116,117,114,101,32,102,105,101,108,100,32,112,97,114,105,116,121,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,115,101,116,32,108,101,110,115,32,97,110,103,108,101,0,0,115,101,116,32,99,104,114,111,109,97,32,109,97,116,114,105,120,32,104,111,114,105,122,111,110,116,97,108,32,115,105,122,101,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,84,105,108,101,32,115,101,118,101,114,97,108,32,115,117,99,99,101,115,115,105,118,101,32,102,114,97,109,101,115,32,116,111,103,101,116,104,101,114,46,0,0,0,0,0,0,0,0,100,111,32,110,111,116,32,97,112,112,108,121,32,116,114,97,110,115,112,111,115,105,116,105,111,110,32,105,102,32,116,104,101,32,105,110,112,117,116,32,109,97,116,99,104,101,115,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,103,101,111,109,101,116,114,121,0,0,99,111,108,111,114,0,0,0,82,101,102,101,114,101,110,99,101,32,37,100,32,62,61,32,37,100,10,0,0,0,0,0,98,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,52,78,0,0,121,117,118,52,52,52,112,49,52,98,101,0,0,0,0,0,83,97,110,100,121,66,114,111,119,110,0,0,0,0,0,0,109,97,120,95,115,111,102,116,95,99,111,109,112,0,0,0,83,101,108,101,99,116,32,116,104,101,32,109,111,115,116,32,114,101,112,114,101,115,101,110,116,97,116,105,118,101,32,102,114,97,109,101,32,105,110,32,97,32,103,105,118,101,110,32,115,101,113,117,101,110,99,101,32,111,102,32,99,111,110,115,101,99,117,116,105,118,101,32,102,114,97,109,101,115,46,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,51,78,0,0,71,67,83,95,77,101,114,99,104,105,99,104,0,0,0,0,119,105,100,116,104,0,0,0,113,100,105,102,102,0,0,0,71,114,97,121,32,115,104,97,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,116,105,109,101,108,105,109,105,116,0,0,0,0,0,0,0,104,115,117,98,0,0,0,0,80,71,77,89,85,86,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,32,89,85,86,41,32,105,109,97,103,101,0,0,0,0,0,78,101,103,101,114,112,117,110,107,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,37,48,46,50,102,0,0,0,121,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,69,110,99,111,100,101,114,0,104,0,0,0,0,0,0,0,115,116,45,62,105,110,100,101,120,95,101,110,116,114,105,101,115,0,0,0,0,0,0,0,65,112,112,108,121,32,97,32,116,101,108,101,99,105,110,101,32,112,97,116,116,101,114,110,46,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,48,78,0,0,40,115,101,109,105,41,114,101,103,117,108,97,114,32,112,97,116,116,101,114,110,0,0,0,105,110,112,117,116,32,35,37,100,32,108,105,110,107,32,37,115,32,83,65,82,32,37,100,58,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,111,117,116,112,117,116,32,108,105,110,107,32,37,115,32,83,65,82,32,37,100,58,37,100,10,0,0,0,0,83,119,97,112,32,85,32,97,110,100,32,86,32,99,111,109,112,111,110,101,110,116,115,46,0,0,0,0,0,0,0,0,116,114,105,108,105,110,101,97,114,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,109,111,118,0,0,0,0,0,83,104,111,119,32,116,101,120,116,117,97,108,32,105,110,102,111,114,109,97,116,105,111,110,32,102,111,114,32,101,97,99,104,32,118,105,100,101,111,32,102,114,97,109,101,46,0,0,97,108,112,104,97,95,109,111,100,101,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,85,110,100,101,116,101,114,109,105,110,101,100,32,32,32,32,32,32,0,0,0,0,0,0,101,110,99,111,100,101,114,0,72,95,101,120,112,114,58,37,115,32,104,95,100,101,103,95,101,120,112,114,58,37,115,32,115,95,101,120,112,114,58,37,115,32,98,95,101,120,112,114,58,37,115,10,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,55,78,0,0,99,111,108,111,114,50,0,0,97,115,101,108,101,99,116,0,70,111,114,99,101,32,102,105,101,108,100,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,118,105,100,101,111,32,102,114,97,109,101,46,0,86,105,101,119,115,32,97,114,101,32,105,110,116,101,114,108,101,97,118,101,100,32,98,121,32,99,111,108,117,109,110,115,0,0,0,0,0,0,0,0,114,111,117,110,100,32,97,119,97,121,32,102,114,111,109,32,48,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,54,78,0,0,83,112,108,105,116,32,105,110,112,117,116,32,118,105,100,101,111,32,102,114,97,109,101,115,32,105,110,116,111,32,102,105,101,108,100,115,46,0,0,0,121,117,118,106,52,50,50,112,0,0,0,0,0,0,0,0,70,114,97,109,101,32,35,37,108,108,100,32,97,116,32,37,115,32,105,115,32,115,116,105,108,108,32,105,110,116,101,114,108,97,99,101,100,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,53,78,0,0,37,74,58,37,77,58,37,83,0,0,0,0,0,0,0,0,37,102,0,0,0,0,0,0,67,82,67,51,50,0,0,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,111,32,119,104,105,99,104,32,116,111,32,97,112,112,108,121,32,116,104,101,32,101,102,102,101,99,116,46,0,97,99,111,115,0,0,0,0,69,110,99,111,100,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,52,78,0,0,66,76,0,0,0,0,0,0,115,101,116,32,118,32,112,108,97,110,101,0,0,0,0,0,83,117,98,116,105,116,108,101,32,111,112,116,105,111,110,115,58,0,0,0,0,0,0,0,102,117,108,108,32,99,104,114,111,109,97,32,105,110,116,101,114,112,111,108,97,116,105,111,110,32,102,111,114,32,100,101,115,116,105,110,97,116,105,111,110,32,102,111,114,109,97,116,32,39,37,115,39,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,108,97,115,116,73,110,76,117,109,66,117,102,32,43,32,49,32,45,32,115,114,99,83,108,105,99,101,89,32,60,32,115,114,99,83,108,105,99,101,72,0,0,0,0,0,0,0,0,108,117,109,97,32,98,105,99,117,98,105,99,44,32,99,104,114,111,109,97,32,98,105,108,105,110,101,97,114,0,0,0,82,101,113,117,101,115,116,101,100,32,111,117,116,112,117,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,121,117,118,52,52,52,112,49,50,108,101,0,0,0,0,0,83,97,108,109,111,110,0,0,115,101,116,32,100,117,114,97,116,105,111,110,32,40,105,110,32,115,101,99,111,110,100,115,41,32,111,118,101,114,32,119,104,105,99,104,32,100,97,116,97,32,105,115,32,115,116,114,101,116,99,104,101,100,47,115,113,117,101,101,122,101,100,32,116,111,32,109,97,107,101,32,105,116,32,109,97,116,99,104,32,116,104,101,32,116,105,109,101,115,116,97,109,112,115,46,0,0,0,0,0,0,0,0,115,101,116,32,104,101,105,103,104,116,32,111,102,32,103,114,105,100,32,99,101,108,108,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,51,78,0,0,108,105,98,97,118,99,111,100,101,99,47,97,116,114,97,99,51,112,108,117,115,46,99,0,92,102,110,37,49,50,55,91,94,92,125,93,37,49,91,92,125,93,37,110,0,0,0,0,71,67,83,95,77,97,110,111,99,97,0,0,0,0,0,0,115,101,116,95,105,110,102,111,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,195,138,204,132,195,138,204,140,195,170,204,132,195,170,204,140,0,0,0,0,0,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,109,117,115,116,32,98,101,32,49,49,48,50,53,44,32,50,50,48,53,48,32,111,114,32,52,52,49,48,48,10,0,0,0,0,0,0,115,101,116,32,104,101,105,103,104,116,32,102,111,114,32,116,104,101,32,114,101,99,116,97,110,103,117,108,97,114,32,115,101,97,114,99,104,32,97,114,101,97,0,0,0,0,0,0,109,97,120,105,109,117,109,32,118,105,100,101,111,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,32,40,86,66,82,41,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,49,0,0,0,0,0,0,0,0,111,110,108,121,32,114,101,99,116,97,110,103,117,108,97,114,32,118,111,108,32,115,117,112,112,111,114,116,101,100,10,0,109,105,120,105,110,103,95,108,101,118,101,108,0,0,0,0,109,105,120,105,110,103,95,108,101,118,101,108,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,76,116,47,82,116,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,32,102,114,111,109,32,119,104,105,99,104,32,111,110,101,32,119,105,108,108,32,98,101,32,100,114,111,112,112,101,100,0,0,101,110,97,98,108,101,32,111,114,32,100,105,115,97,98,108,101,32,105,110,116,101,114,97,99,116,105,111,110,32,111,110,32,115,116,97,110,100,97,114,100,32,105,110,112,117,116,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,32,45,32,99,97,110,110,111,116,32,97,112,112,108,121,32,83,66,82,32,116,111,32,101,108,101,109,101,110,116,32,116,121,112,101,32,37,100,10,0,0,0,0,0,0,0,0,83,116,101,114,101,111,32,99,111,100,105,110,103,32,109,101,116,104,111,100,0,0,0,0,112,103,109,121,117,118,0,0,83,66,82,32,119,97,115,32,102,111,117,110,100,32,98,101,102,111,114,101,32,116,104,101,32,102,105,114,115,116,32,99,104,97,110,110,101,108,32,101,108,101,109,101,110,116,46,10,0,0,0,0,0,0,0,0,66,114,105,116,80,111,112,0,84,104,101,32,108,97,115,116,32,37,100,32,118,101,114,116,105,99,97,108,32,112,105,120,101,108,115,32,119,111,110,39,116,32,98,101,32,100,101,110,111,105,115,101,100,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,116,111,112,32,98,108,111,99,107,32,117,110,97,118,97,105,108,97,98,108,101,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,105,110,116,114,97,52,120,52,32,109,111,100,101,32,37,100,32,97,116,32,37,100,32,37,100,10,0,0,105,110,118,97,108,105,100,32,98,105,116,109,97,112,32,115,99,97,110,45,108,105,110,101,32,112,97,100,10,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,114,97,116,101,32,37,100,32,40,109,105,110,61,37,100,44,32,109,97,120,61,37,100,41,10,0,0,0,0,0,98,114,111,107,101,110,32,115,117,98,102,114,97,109,101,10,0,0,0,0,0,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,110,117,109,32,115,117,98,102,114,97,109,101,115,32,62,32,51,49,10,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,58,32,103,111,116,32,37,105,44,32,110,101,101,100,32,37,105,32,111,114,32,102,101,119,101,114,10,0,0,0,0,102,114,97,109,101,95,108,101,110,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,60,117,62,0,0,0,0,0,105,109,97,103,101,32,100,97,116,97,32,110,111,116,32,102,111,117,110,100,10,0,0,0,108,101,102,116,47,114,105,103,104,116,0,0,0,0,0,0,69,110,116,114,111,112,121,32,118,97,114,115,32,115,105,122,101,32,115,104,111,117,108,100,32,98,101,32,37,105,44,32,103,111,116,32,37,105,46,10,0,0,0,0,0,0,0,0,99,117,114,114,101,110,116,32,100,101,115,116,95,105,110,100,101,120,32,61,32,37,100,44,32,99,111,117,110,116,32,61,32,37,100,44,32,100,101,115,116,95,115,105,122,101,32,61,32,37,100,10,0,0,0,0,82,101,102,101,114,101,110,99,101,32,115,101,103,109,97,112,32,40,116,101,109,112,61,37,100,44,117,112,100,97,116,101,61,37,100,41,32,101,110,97,98,108,101,100,32,111,110,32,115,105,122,101,45,99,104,97,110,103,101,33,10,0,0,0,75,101,121,32,112,111,105,110,116,32,99,111,111,114,100,105,110,97,116,101,115,32,40,37,102,59,37,102,41,32,97,110,100,32,40,37,102,59,37,102,41,32,97,114,101,32,116,111,111,32,99,108,111,115,101,32,102,114,111,109,32,101,97,99,104,32,111,116,104,101,114,32,111,114,32,110,111,116,32,115,116,114,105,99,116,108,121,32,105,110,99,114,101,97,115,105,110,103,32,111,110,32,116,104,101,32,120,45,97,120,105,115,10,0,0,0,0,0,0,0,118,112,51,58,32,102,105,114,115,116,32,102,114,97,109,101,32,110,111,116,32,97,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,103,110,97,116,117,114,101,32,105,110,32,73,100,32,104,101,97,100,101,114,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,37,100,32,99,104,97,110,110,101,108,115,44,32,37,100,32,98,105,116,115,47,115,97,109,112,108,101,44,32,98,108,111,99,107,32,97,108,105,103,110,32,61,32,37,100,44,32,115,97,109,112,108,101,32,114,97,116,101,32,61,32,37,100,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,37,115,32,37,115,32,91,37,115,93,58,10,0,0,0,0,121,0,0,0,0,0,0,0,67,104,114,111,109,97,32,115,99,97,108,105,110,103,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,101,120,112,101,99,116,32,119,114,111,110,103,32,112,105,99,116,117,114,101,10,0,0,71,114,97,100,105,101,110,116,32,112,114,101,100,105,99,116,105,111,110,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,111,100,101,99,32,116,121,112,101,32,111,114,32,105,100,32,109,105,115,109,97,116,99,104,101,115,10,0,0,0,0,115,101,116,32,116,104,101,32,103,114,101,101,110,32,103,97,105,110,32,102,111,114,32,116,104,101,32,103,114,101,101,110,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,87,114,111,110,103,32,101,120,116,114,97,100,97,116,97,32,112,114,101,115,101,110,116,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,99,111,114,114,101,99,116,32,116,114,101,101,32,112,97,114,97,109,101,116,101,114,115,32,45,32,108,105,116,101,114,97,108,32,108,101,110,103,116,104,58,32,37,105,44,32,109,97,120,32,99,111,100,101,32,108,101,110,103,116,104,58,32,37,105,10,0,0,0,0,115,101,116,32,116,104,101,32,105,109,97,103,101,32,114,101,115,111,108,117,116,105,111,110,32,40,105,110,32,100,112,105,41,0,0,0,0,0,0,0,115,101,116,32,98,108,117,101,32,109,105,100,116,111,110,101,115,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,71,101,111,103,83,101,109,105,77,105,110,111,114,65,120,105,115,71,101,111,75,101,121,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,37,100,10,0,0,0,83,111,117,114,99,101,32,100,97,116,97,32,111,118,101,114,114,101,97,100,10,0,0,0,118,112,108,97,121,101,114,32,100,101,99,111,100,101,114,0,66,79,84,84,79,77,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,105,110,116,114,97,32,108,117,109,97,32,100,99,10,0,0,0,0,0,123,92,97,110,37,100,125,0,37,49,50,55,91,94,62,93,62,37,110,0,0,0,0,0,67,117,115,116,111,109,32,113,117,97,110,116,32,116,97,98,108,101,10,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,84,104,101,32,57,47,55,32,119,97,118,101,108,101,116,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,108,111,115,115,108,101,115,115,32,109,111,100,101,46,10,0,0,0,0,78,79,80,84,83,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,104,101,97,100,101,114,32,105,115,32,119,114,111,110,103,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,32,102,111,114,32,114,97,119,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,32,120,49,58,37,100,32,120,50,58,37,100,32,121,49,58,37,100,32,121,50,58,37,100,32,119,58,37,100,32,104,58,37,100,32,99,114,111,112,61,37,100,58,37,100,58,37,100,58,37,100,32,100,114,97,119,98,111,120,61,37,100,58,37,100,58,37,100,58,37,100,0,108,111,119,32,100,101,108,97,121,32,66,10,0,0,0,0,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,105,115,66,0,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,32,37,100,10,0,0,119,58,37,100,32,104,58,37,100,32,115,97,114,58,37,100,47,37,100,32,100,97,114,58,37,100,47,37,100,32,45,62,32,115,97,114,58,37,100,47,37,100,32,100,97,114,58,37,100,47,37,100,10,0,0,0,105,115,116,32,38,38,32,33,111,115,116,45,62,102,105,108,116,101,114,0,0,0,0,0,73,110,118,97,108,105,100,32,56,98,105,116,32,99,111,100,101,119,111,114,100,10,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,97,112,99,104,0,0,0,0,112,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,32,99,104,97,110,103,101,100,58,32,111,108,100,58,32,37,100,32,120,32,37,100,44,32,110,101,119,58,32,37,100,32,120,32,37,100,10,0,0,101,114,114,111,114,44,32,115,108,105,99,101,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,104,50,54,49,0,0,0,0,37,100,10,0,0,0,0,0,66,114,111,107,101,110,32,116,69,88,116,32,99,104,117,110,107,10,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,97,117,100,105,111,32,115,97,109,112,108,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,112,97,115,115,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,0,0,0,0,169,115,119,114,0,0,0,0,115,112,0,0,0,0,0,0,65,86,70,114,97,109,101,0,77,88,77,32,98,105,116,109,97,115,107,32,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,101,114,114,111,114,10,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,115,101,32,86,76,67,115,10,0,102,45,62,108,105,110,101,115,105,122,101,91,49,93,32,61,61,32,102,45,62,108,105,110,101,115,105,122,101,91,50,93,0,0,0,0,0,0,0,0,77,97,120,46,32,108,97,103,32,116,105,109,101,32,37,103,32,109,115,10,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,99,104,114,111,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,110,97,110,0,0,0,0,0,100,101,99,111,100,105,110,103,32,116,111,32,65,86,95,80,73,88,95,70,77,84,95,78,79,78,69,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,83,99,97,108,101,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,115,105,122,101,32,97,110,100,47,111,114,32,99,111,110,118,101,114,116,32,116,104,101,32,105,109,97,103,101,32,102,111,114,109,97,116,46,0,0,0,0,0,80,97,114,115,101,100,95,37,115,95,37,100,0,0,0,0,115,107,105,112,95,114,100,0,104,50,54,49,0,0,0,0,100,114,111,112,95,102,114,97,109,101,95,116,105,109,101,99,111,100,101,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,32,72,68,82,32,86,76,67,10,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,78,111,32,114,101,115,116,97,114,116,32,104,101,97,100,101,114,32,112,114,101,115,101,110,116,32,105,110,32,115,117,98,115,116,114,101,97,109,32,37,100,46,10,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,105,110,103,32,102,97,99,116,111,114,32,105,110,32,99,111,109,112,111,110,101,110,116,32,37,100,32,37,100,58,37,100,10,0,0,115,111,115,32,111,102,102,115,58,32,48,120,37,120,10,0,123,92,102,110,37,46,42,115,125,0,0,0,0,0,0,0,115,114,0,0,0,0,0,0,73,110,102,108,97,116,101,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,83,99,97,108,101,100,32,112,114,111,98,97,98,105,108,105,116,105,101,115,32,105,110,118,97,108,105,100,10,0,0,0,110,111,110,122,101,114,111,98,105,116,115,32,37,100,32,105,110,118,97,108,105,100,10,0,123,92,97,110,54,125,0,0,84,105,108,101,32,100,97,116,97,95,115,105,122,101,32,109,105,115,109,97,116,99,104,33,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,110,116,101,114,0,0,0,89,86,49,50,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,0,0,0,0,0,67,117,115,116,111,109,32,115,99,97,110,32,112,97,116,116,101,114,110,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,105,110,103,32,109,111,100,101,58,32,37,100,10,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,78,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,62,32,50,0,0,77,97,115,107,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,119,105,100,116,104,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,32,116,104,105,115,32,99,111,108,111,114,115,112,97,99,101,32,97,110,100,32,112,114,101,100,105,99,116,111,114,10,0,0,0,0,99,104,114,111,109,97,95,102,111,114,109,97,116,95,105,100,99,32,33,61,32,49,10,0,103,115,109,0,0,0,0,0,73,110,118,97,108,105,100,32,78,65,76,32,117,110,105,116,32,37,100,44,32,115,107,105,112,112,105,110,103,46,10,0,98,108,111,99,107,95,114,108,0,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,109,109,99,111,58,32,117,110,114,101,102,32,115,104,111,114,116,32,102,97,105,108,117,114,101,10,0,0,0,0,0,0,99,114,111,112,32,118,97,108,117,101,115,32,105,110,118,97,108,105,100,32,37,100,32,37,100,32,37,100,32,37,100,32,47,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,110,101,103,97,116,105,118,101,32,110,117,109,98,101,114,32,111,102,32,122,101,114,111,32,99,111,101,102,102,115,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,104,50,54,52,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,37,100,32,106,117,110,107,32,98,105,116,115,32,97,116,32,101,110,100,44,32,110,101,120,116,32,119,111,117,108,100,32,98,101,32,37,88,10,0,0,0,0,0,0,0,114,117,110,32,111,118,101,114,102,108,111,119,32,97,116,32,37,100,120,37,100,10,0,0,116,114,97,110,115,95,99,111,108,111,114,0,0,0,0,0,115,119,105,116,99,104,32,112,101,114,109,105,115,115,105,111,110,115,0,0,0,0,0,0,101,110,97,98,108,101,32,112,105,99,116,117,114,101,32,111,102,102,115,101,116,116,105,110,103,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,78,111,32,100,105,115,112,108,97,121,32,105,110,102,111,32,45,32,115,107,105,112,112,105,110,103,32,116,105,108,101,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,116,101,114,32,102,114,97,109,101,32,119,105,116,104,111,117,116,32,107,101,121,102,114,97,109,101,10,0,0,0,105,110,112,117,116,37,100,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,70,108,97,99,44,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,119,105,108,108,32,104,97,118,101,32,105,110,99,111,114,114,101,99,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,46,10,0,0,0,0,0,0,0,0,98,108,111,99,107,115,105,122,101,32,37,100,32,62,32,37,100,10,0,0,0,0,0,0,102,45,62,112,108,97,110,101,91,106,93,46,113,117,97,110,116,95,116,97,98,108,101,95,105,110,100,101,120,32,61,61,32,102,45,62,97,118,99,116,120,45,62,99,111,110,116,101,120,116,95,109,111,100,101,108,0,0,0,0,0,0,0,0,113,117,97,110,116,95,116,97,98,108,101,95,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,71,0,0,0,0,0,0,0,108,97,114,103,101,0,0,0,121,117,118,52,52,52,112,49,50,98,101,0,0,0,0,0,83,97,100,100,108,101,66,114,111,119,110,0,0,0,0,0,32,37,48,54,120,37,99,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,99,111,109,112,95,100,117,114,97,116,105,111,110,0,0,0,79,118,101,114,114,101,97,100,32,98,117,102,102,101,114,46,32,73,110,118,97,108,105,100,32,104,101,97,100,101,114,63,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,114,117,110,32,60,32,54,51,0,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,102,114,97,109,101,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,49,52,49,49,50,48,48,0,78,111,110,32,115,116,97,110,100,97,114,100,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,37,100,32,33,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,115,117,98,112,97,99,107,101,116,91,37,105,93,46,99,111,111,107,118,101,114,115,105,111,110,61,37,120,10,0,0,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,115,0,0,71,67,83,95,77,97,108,111,110,103,111,95,49,57,56,55,0,0,0,0,0,0,0,0,113,109,97,120,0,0,0,0,105,108,108,101,103,97,108,32,99,104,114,111,109,97,32,102,111,114,109,97,116,10,0,0,82,101,97,108,86,105,100,101,111,32,50,46,48,0,0,0,76,105,109,105,116,32,115,116,114,105,112,115,47,102,114,97,109,101,44,32,118,105,110,116,97,103,101,32,99,111,109,112,97,116,105,98,108,101,32,105,115,32,49,46,46,51,44,32,111,116,104,101,114,119,105,115,101,32,116,104,101,32,109,111,114,101,32,116,104,101,32,98,101,116,116,101,114,0,0,0,115,116,100,105,110,0,0,0,105,108,108,101,103,97,108,32,105,110,116,114,97,32,99,104,114,111,109,97,32,112,114,101,100,32,109,111,100,101,10,0,73,110,118,97,108,105,100,32,100,105,109,101,110,115,105,111,110,32,37,100,120,37,100,10,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,80,71,77,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,84,111,111,32,109,97,110,121,32,98,108,111,99,107,32,116,121,112,101,32,118,97,108,117,101,115,10,0,0,0,0,0,115,99,97,108,101,0,0,0,73,110,100,105,101,0,0,0,82,111,116,97,116,101,32,116,104,101,32,105,110,112,117,116,32,105,109,97,103,101,46,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,86,101,114,115,105,111,110,32,37,100,32,33,61,32,52,46,10,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,112,97,105,114,46,10,0,0,88,45,68,101,112,101,110,100,115,0,0,0,0,0,0,0,99,111,108,95,105,110,116,101,114,108,101,97,118,101,100,95,108,114,0,0,0,0,0,0,103,105,102,0,0,0,0,0,80,111,112,0,0,0,0,0,101,110,99,111,100,101,114,0,33,108,105,110,107,45,62,102,114,97,109,101,95,114,101,113,117,101,115,116,101,100,32,124,124,32,108,105,110,107,45,62,102,108,97,103,115,32,38,32,70,70,95,76,73,78,75,95,70,76,65,71,95,82,69,81,85,69,83,84,95,76,79,79,80,0,0,0,0,0,0,0,52,52,52,112,49,52,0,0,115,101,116,32,104,111,119,32,109,97,110,121,32,115,97,109,112,108,101,115,32,116,111,32,115,104,111,119,32,105,110,32,116,104,101,32,115,97,109,101,32,112,111,105,110,116,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,67,111,100,101,99,32,39,37,115,39,32,105,115,32,110,111,116,32,114,101,99,111,103,110,105,122,101,100,32,98,121,32,70,70,109,112,101,103,46,10,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,100,101,99,0,0,0,82,101,109,111,118,101,32,97,32,84,86,32,108,111,103,111,32,98,97,115,101,100,32,111,110,32,97,32,109,97,115,107,32,105,109,97,103,101,46,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,103,105,102,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,57,78,0,0,0,79,117,116,112,117,116,32,102,105,108,101,32,35,37,100,32,100,111,101,115,32,110,111,116,32,99,111,110,116,97,105,110,32,97,110,121,32,115,116,114,101,97,109,10,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,56,78,0,0,0,103,55,50,57,0,0,0,0,169,100,97,121,0,0,0,0,67,97,108,99,117,108,97,116,101,32,116,104,101,32,80,83,78,82,32,98,101,116,119,101,101,110,32,116,119,111,32,118,105,100,101,111,32,115,116,114,101,97,109,115,46,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,55,78,0,0,0,84,101,115,116,32,112,105,120,101,108,32,102,111,114,109,97,116,32,100,101,102,105,110,105,116,105,111,110,115,46,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,54,78,0,0,0,103,55,50,54,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,78,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,78,0,0,0,103,55,50,51,95,49,0,0,121,117,118,52,50,50,112,49,52,108,101,0,0,0,0,0,82,111,121,97,108,66,108,117,101,0,0,0,0,0,0,0,115,101,116,32,109,105,110,105,109,117,109,32,100,105,102,102,101,114,101,110,99,101,32,98,101,116,119,101,101,110,32,116,105,109,101,115,116,97,109,112,115,32,97,110,100,32,97,117,100,105,111,32,100,97,116,97,32,40,105,110,32,115,101,99,111,110,100,115,41,32,116,111,32,116,114,105,103,103,101,114,32,112,97,100,100,105,110,103,47,116,114,105,109,109,105,110,103,32,116,104,101,32,100,97,116,97,46,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,78,0,0,0,103,55,50,50,0,0,0,0,71,67,83,95,69,85,82,69,70,56,57,0,0,0,0,0,109,105,110,105,109,117,109,32,118,105,100,101,111,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,32,40,86,66,82,41,0,0,0,0,0,88,118,105,68,37,100,0,0,117,114,108,0,0,0,0,0,112,103,109,0,0,0,0,0,103,55,50,50,0,0,0,0,84,101,114,114,111,114,0,0,80,97,100,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,78,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,78,0,0,0,100,101,99,111,100,101,114,115,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,110,0,0,0,0,0,0,0,119,114,105,116,101,32,115,116,114,101,97,109,32,99,111,100,101,99,32,102,97,105,108,101,100,32,99,111,100,101,99,95,116,121,112,101,40,48,120,37,120,41,10,0,0,0,0,0,110,111,32,102,114,97,109,101,32,105,110,32,114,118,51,48,47,52,48,32,97,110,100,32,110,111,32,115,97,114,0,0,117,110,107,110,111,119,110,32,109,101,100,105,97,32,116,121,112,101,44,32,109,101,100,105,97,116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,44,32,115,117,98,116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,44,32,102,111,114,109,97,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2282120);
/* memory initializer */ allocate([116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,54,48,83,0,0,0,0,0,0,0,0,107,105,110,100,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,57,83,0,0,0,0,0,0,0,0,103,50,109,0,0,0,0,0,100,97,116,101,0,0,0,0,107,101,121,32,32,32,32,102,117,110,99,116,105,111,110,10,63,32,32,32,32,32,32,115,104,111,119,32,116,104,105,115,32,104,101,108,112,10,43,32,32,32,32,32,32,105,110,99,114,101,97,115,101,32,118,101,114,98,111,115,105,116,121,10,45,32,32,32,32,32,32,100,101,99,114,101,97,115,101,32,118,101,114,98,111,115,105,116,121,10,99,32,32,32,32,32,32,83,101,110,100,32,99,111,109,109,97,110,100,32,116,111,32,102,105,114,115,116,32,109,97,116,99,104,105,110,103,32,102,105,108,116,101,114,32,115,117,112,112,111,114,116,105,110,103,32,105,116,10,67,32,32,32,32,32,32,83,101,110,100,47,81,117,101,32,99,111,109,109,97,110,100,32,116,111,32,97,108,108,32,109,97,116,99,104,105,110,103,32,102,105,108,116,101,114,115,10,68,32,32,32,32,32,32,99,121,99,108,101,32,116,104,114,111,117,103,104,32,97,118,97,105,108,97,98,108,101,32,100,101,98,117,103,32,109,111,100,101,115,10,104,32,32,32,32,32,32,100,117,109,112,32,112,97,99,107,101,116,115,47,104,101,120,32,112,114,101,115,115,32,116,111,32,99,121,99,108,101,32,116,104,114,111,117,103,104,32,116,104,101,32,51,32,115,116,97,116,101,115,10,113,32,32,32,32,32,32,113,117,105,116,10,115,32,32,32,32,32,32,83,104,111,119,32,81,80,32,104,105,115,116,111,103,114,97,109,10,0,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,56,83,0,0,0,0,0,0,0,0,169,97,108,98,0,0,0,0,72,101,105,103,104,116,0,0,102,114,119,117,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,55,83,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,54,83,0,0,0,0,0,0,0,0,102,114,97,112,115,0,0,0,115,101,112,97,114,97,116,101,0,0,0,0,0,0,0,0,79,118,101,114,108,97,121,32,97,32,118,105,100,101,111,32,115,111,117,114,99,101,32,111,110,32,116,111,112,32,111,102,32,116,104,101,32,105,110,112,117,116,46,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,53,83,0,0,0,0,0,0,0,0,102,108,118,0,0,0,0,0,97,112,101,114,109,115,0,0,80,97,115,115,32,116,104,101,32,115,111,117,114,99,101,32,117,110,99,104,97,110,103,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,46,0,0,0,0,0,0,0,0,109,112,51,0,0,0,0,0,66,97,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,52,83,0,0,0,0,0,0,0,0,121,117,118,52,50,50,112,49,52,98,101,0,0,0,0,0,82,111,115,121,66,114,111,119,110,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,109,105,110,95,104,97,114,100,95,99,111,109,112,0,0,0,34,99,111,110,116,101,110,116,34,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,51,83,0,0,0,0,0,0,0,0,71,67,83,95,77,97,107,97,115,115,97,114,0,0,0,0,97,117,100,105,111,32,102,114,97,109,101,32,115,105,122,101,32,110,111,116,32,115,101,116,10,0,0,0,0,0,0,0,113,109,105,110,0,0,0,0,49,46,50,46,53,0,0,0,102,102,109,112,101,103,0,0,91,73,78,70,79,82,77,65,84,73,79,78,93,0,0,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,119,114,105,116,101,32,112,114,111,103,114,97,109,45,114,101,97,100,97,98,108,101,32,112,114,111,103,114,101,115,115,32,105,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,80,66,77,32,40,80,111,114,116,97,98,108,101,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,72,97,114,100,99,111,114,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,50,83,0,0,0,0,0,0,0,0,102,108,105,99,0,0,0,0,72,68,32,109,111,100,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,116,104,105,115,32,102,111,114,109,97,116,10,0,0,102,108,97,115,104,115,118,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,49,83,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,115,0,0,0,0,0,0,0,0,60,83,116,114,101,97,109,73,110,100,101,120,32,84,121,112,101,61,34,118,105,100,101,111,34,32,81,117,97,108,105,116,121,76,101,118,101,108,115,61,34,37,100,34,32,67,104,117,110,107,115,61,34,37,100,34,32,85,114,108,61,34,81,117,97,108,105,116,121,76,101,118,101,108,115,40,123,98,105,116,114,97,116,101,125,41,47,70,114,97,103,109,101,110,116,115,40,118,105,100,101,111,61,123,115,116,97,114,116,32,116,105,109,101,125,41,34,62,10,0,117,110,115,112,101,99,105,102,105,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,0,0,0,0,0,0,102,108,97,115,104,115,118,50,0,0,0,0,0,0,0,0,65,100,100,32,110,111,105,115,101,46,0,0,0,0,0,0,115,105,122,101,0,0,0,0,115,101,116,32,102,108,97,103,115,32,97,102,102,101,99,116,105,110,103,32,115,101,103,109,101,110,116,32,108,105,115,116,32,103,101,110,101,114,97,116,105,111,110,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,0,0,0,0,0,0,100,101,98,117,103,61,37,100,10,0,0,0,0,0,0,0,58,58,49,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,0,0,0,0,0,0,169,97,117,116,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,55,83,0,0,0,0,0,0,0,0,82,84,80,32,109,117,120,101,114,0,0,0,0,0,0,0,77,101,114,103,101,32,112,108,97,110,101,115,46,0,0,0,102,108,97,115,104,115,118,0,73,110,100,101,120,32,115,105,122,101,32,37,100,32,40,37,100,32,112,107,116,115,41,32,105,115,32,119,114,111,110,103,44,32,115,104,111,117,108,100,32,98,101,32,37,100,46,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,97,117,100,105,111,32,100,117,114,97,116,105,111,110,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,54,83,0,0,0,0,0,0,0,0,73,78,65,77,0,0,0,0,37,117,58,37,117,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,53,83,0,0,0,0,0,0,0,0,50,53,0,0,0,0,0,0,110,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,52,83,0,0,0,0,0,0,0,0,100,114,99,0,0,0,0,0,116,114,117,101,104,100,0,0,121,117,118,52,50,50,112,49,50,108,101,0,0,0,0,0,82,101,100,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,115,101,116,32,109,105,110,105,109,117,109,32,100,105,102,102,101,114,101,110,99,101,32,98,101,116,119,101,101,110,32,116,105,109,101,115,116,97,109,112,115,32,97,110,100,32,97,117,100,105,111,32,100,97,116,97,32,40,105,110,32,115,101,99,111,110,100,115,41,32,98,101,108,111,119,32,119,104,105,99,104,32,110,111,32,116,105,109,101,115,116,97,109,112,32,99,111,109,112,101,110,115,97,116,105,111,110,32,111,102,32,101,105,116,104,101,114,32,107,105,110,100,32,105,115,32,97,112,112,108,105,101,100,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,51,83,0,0,0,0,0,0,0,0,71,67,83,95,77,97,104,101,95,49,57,55,49,0,0,0,118,105,100,101,111,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,32,98,108,117,114,32,40,86,66,82,41,0,0,0,0,0,0,0,0,76,97,118,99,37,100,46,37,100,46,37,100,0,0,0,0,112,114,111,103,114,101,115,115,0,0,0,0,0,0,0,0,112,98,109,0,0,0,0,0,67,108,117,98,45,72,111,117,115,101,0,0,0,0,0,0,115,50,52,98,101,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,50,83,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,49,83,0,0,0,0,0,0,0,0,67,111,100,101,99,32,39,37,115,39,32,105,115,32,107,110,111,119,110,32,116,111,32,70,70,109,112,101,103,44,32,98,117,116,32,110,111,32,37,115,32,102,111,114,32,105,116,32,97,114,101,32,97,118,97,105,108,97,98,108,101,46,32,70,70,109,112,101,103,32,109,105,103,104,116,32,110,101,101,100,32,116,111,32,98,101,32,114,101,99,111,109,112,105,108,101,100,32,119,105,116,104,32,97,100,100,105,116,105,111,110,97,108,32,101,120,116,101,114,110,97,108,32,108,105,98,114,97,114,105,101,115,46,10,0,0,115,50,52,98,101,0,0,0,65,100,106,117,115,116,32,99,111,108,111,114,115,32,117,115,105,110,103,32,97,32,51,68,32,76,85,84,46,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,115,105,122,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,48,83,0,0,0,0,0,0,0,0,105,103,110,111,114,101,32,105,110,100,101,120,0,0,0,0,102,108,97,99,0,0,0,0,79,77,71,95,66,75,76,83,73,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,57,83,0,0,0,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,100,101,98,117,103,32,118,97,108,117,101,10,0,0,0,0,0,0,83,101,116,32,112,114,101,102,101,114,114,101,100,32,79,103,103,32,112,97,103,101,32,115,105,122,101,46,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,56,83,0,0,0,0,0,0,0,0,67,104,97,110,103,105,110,103,32,115,116,114,101,97,109,32,112,97,114,97,109,101,116,101,114,115,32,105,110,32,109,117,108,116,105,115,116,114,101,97,109,32,111,103,103,0,0,0,169,110,97,109,0,0,0,0,78,101,103,97,116,105,118,101,32,112,116,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,115,116,114,101,97,109,32,37,100,44,32,112,116,115,32,37,108,108,100,10,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,55,83,0,0,0,0,0,0,0,0,114,101,116,117,114,110,32,37,108,108,100,32,37,108,108,100,10,0,0,0,0,0,0,0,115,97,109,112,108,101,95,98,121,116,101,95,102,111,114,109,97,116,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,54,83,0,0,0,0,0,0,0,0,101,115,115,101,110,99,101,32,99,111,110,116,97,105,110,101,114,32,99,111,117,110,116,58,37,100,10,0,0,0,0,0,102,108,97,99,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,53,83,0,0,0,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,68,45,49,48,32,97,101,115,51,32,102,114,97,109,101,10,0,0,67,79,77,80,82,69,83,83,73,79,78,0,0,0,0,0,67,111,109,112,117,116,101,32,97,110,100,32,97,112,112,108,121,32,97,32,108,111,111,107,117,112,32,116,97,98,108,101,32,116,111,32,116,104,101,32,82,71,66,47,89,85,86,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,100,114,111,112,112,105,110,103,32,108,111,119,32,115,99,111,114,101,32,37,105,32,102,114,97,109,101,32,104,101,97,100,101,114,32,102,114,111,109,32,111,102,102,115,101,116,32,37,105,32,116,111,32,37,105,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,52,83,0,0,0,0,0,0,0,0,78,79,80,84,83,0,0,0,121,117,118,52,50,50,112,49,50,98,101,0,0,0,0,0,80,117,114,112,108,101,0,0,109,105,110,95,99,111,109,112,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,51,83,0,0,0,0,0,0,0,0,72,46,50,54,52,32,98,105,116,115,116,114,101,97,109,32,109,97,108,102,111,114,109,101,100,44,32,110,111,32,115,116,97,114,116,99,111,100,101,32,102,111,117,110,100,44,32,117,115,101,32,116,104,101,32,104,50,54,52,95,109,112,52,116,111,97,110,110,101,120,98,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,40,45,98,115,102,32,104,50,54,52,95,109,112,52,116,111,97,110,110,101,120,98,41,10,0,0,0,0,0,0,0,71,67,83,95,72,101,114,97,116,95,78,111,114,116,104,0,113,98,108,117,114,0,0,0,79,117,116,112,117,116,32,111,112,116,105,111,110,32,99,97,114,114,121,105,110,103,32,116,104,101,32,114,97,119,32,112,97,99,107,101,116,32,115,105,122,101,46,0,0,0,0,0,70,70,109,112,101,103,32,118,37,100,46,37,100,46,37,100,32,47,32,108,105,98,97,118,99,111,100,101,99,32,98,117,105,108,100,58,32,37,100,0,97,100,100,32,116,105,109,105,110,103,115,32,102,111,114,32,101,97,99,104,32,116,97,115,107,0,0,0,0,0,0,0,80,80,77,32,40,80,111,114,116,97,98,108,101,32,80,105,120,101,108,77,97,112,41,32,105,109,97,103,101,0,0,0,100,118,100,32,109,117,120,101,114,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,121,110,99,32,99,111,100,101,10,0,0,0,0,0,0,68,114,117,109,32,38,32,66,97,115,115,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,50,83,0,0,0,0,0,0,0,0,73,68,88,47,83,85,66,58,32,37,115,32,45,62,32,37,115,10,0,0,0,0,0,0,68,101,105,110,116,101,114,108,101,97,118,101,32,111,114,32,105,110,116,101,114,108,101,97,118,101,32,102,105,101,108,100,115,46,0,0,0,0,0,0,99,111,109,109,101,110,116,0,102,105,99,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,49,83,0,0,0,0,0,0,0,0,78,111,32,99,111,100,101,99,32,110,97,109,101,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,0,0,0,110,111,32,100,101,99,111,100,97,98,108,101,32,68,84,83,32,102,114,97,109,101,115,0,119,97,118,101,115,121,110,116,104,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,48,83,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,57,83,0,0,0,0,0,0,0,0,73,110,116,101,114,108,97,99,101,32,100,101,116,101,99,116,32,70,105,108,116,101,114,46,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,109,112,52,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,56,83,0,0,0,0,0,0,0,0,169,65,82,84,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,55,83,0,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,100,32,81,84,32,99,104,97,112,116,101,114,32,116,114,97,99,107,32,110,111,116,32,102,111,117,110,100,10,0,0,65,84,82,0,0,0,0,0,102,102,118,49,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,54,83,0,0,0,0,0,0,0,0,105,110,116,101,114,108,101,97,118,101,0,0,0,0,0,0,35,115,116,114,101,97,109,35,44,32,100,116,115,44,32,32,32,32,32,32,32,32,112,116,115,44,32,100,117,114,97,116,105,111,110,44,32,32,32,32,32,115,105,122,101,44,32,104,97,115,104,10,0,0,0,0,65,100,106,117,115,116,32,116,104,101,32,104,117,101,32,97,110,100,32,115,97,116,117,114,97,116,105,111,110,32,111,102,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,114,101,115,101,114,118,101,95,105,110,100,101,120,95,115,112,97,99,101,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,53,83,0,0,0,0,0,0,0,0,67,111,114,114,117,112,116,32,103,101,110,101,114,105,99,32,82,77,45,115,116,121,108,101,32,97,117,100,105,111,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,0,101,120,112,101,99,116,101,100,32,37,100,32,66,32,115,105,122,101,32,104,101,97,100,101,114,44,32,103,111,116,32,37,100,10,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,0,0,0,0,0,0,73,78,67,76,85,68,69,0,121,117,118,52,50,48,112,49,52,108,101,0,0,0,0,0,102,102,118,49,0,0,0,0,80,111,119,100,101,114,66,108,117,101,0,0,0,0,0,0,101,110,97,98,108,101,32,115,111,120,114,32,67,104,101,98,121,115,104,101,118,32,112,97,115,115,98,97,110,100,32,38,32,104,105,103,104,101,114,45,112,114,101,99,105,115,105,111,110,32,105,114,114,97,116,105,111,110,97,108,32,114,97,116,105,111,32,97,112,112,114,111,120,105,109,97,116,105,111,110,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,0,0,0,0,0,0,71,67,83,95,72,105,116,111,95,88,86,73,73,73,95,49,57,54,51,0,0,0,0,0,118,105,100,101,111,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,32,99,111,109,112,114,101,115,115,105,111,110,32,40,86,66,82,41,46,32,67,111,110,115,116,97,110,116,32,111,102,32,114,97,116,101,99,111,110,116,114,111,108,32,101,113,117,97,116,105,111,110,46,32,82,101,99,111,109,109,101,110,100,101,100,32,114,97,110,103,101,32,102,111,114,32,100,101,102,97,117,108,116,32,114,99,95,101,113,58,32,48,46,48,45,49,46,48,0,70,70,109,112,101,37,42,91,94,98,93,98,37,100,0,0,103,105,102,0,0,0,0,0,98,101,110,99,104,109,97,114,107,95,97,108,108,0,0,0,98,101,110,99,104,58,32,117,116,105,109,101,61,37,48,46,51,102,115,10,0,0,0,0,112,112,109,0,0,0,0,0,71,111,97,0,0,0,0,0,103,108,111,98,95,115,101,113,117,101,110,99,101,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,0,0,0,0,0,0,67,111,109,112,117,116,101,32,97,110,100,32,100,114,97,119,32,97,32,104,105,115,116,111,103,114,97,109,46,0,0,0,112,103,109,121,117,118,0,0,99,111,109,112,114,101,115,115,105,111,110,32,37,100,32,97,110,100,32,98,105,116,32,100,101,112,116,104,32,37,100,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,49,83,0,0,0,0,0,0,0,0,68,101,109,117,120,101,114,32,37,115,32,91,37,115,93,58,10,0,0,0,0,0,0,0,72,111,114,105,122,111,110,116,97,108,108,121,32,102,108,105,112,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,48,83,0,0,0,0,0,0,0,0,84,76,65,78,0,0,0,0,114,101,115,101,110,100,95,104,101,97,100,101,114,115,0,0,68,101,98,97,110,100,115,32,118,105,100,101,111,32,113,117,105,99,107,108,121,32,117,115,105,110,103,32,103,114,97,100,105,101,110,116,115,46,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,57,83,0,0,0,0,0,0,0,0,115,101,101,107,97,98,108,101,0,0,0,0,0,0,0,0,9,60,100,101,108,105,118,101,114,121,84,121,112,101,62,115,116,114,101,97,109,105,110,103,60,47,100,101,108,105,118,101,114,121,84,121,112,101,62,10,0,0,0,0,0,0,0,0,80,97,114,115,101,32,101,114,114,111,114,44,32,97,116,32,108,101,97,115,116,32,51,32,97,114,103,117,109,101,110,116,115,32,119,101,114,101,32,101,120,112,101,99,116,101,100,44,32,111,110,108,121,32,37,100,32,103,105,118,101,110,32,105,110,32,115,116,114,105,110,103,32,39,37,115,39,10,0,0,83,101,108,101,99,116,32,111,110,101,32,102,114,97,109,101,32,101,118,101,114,121,32,78,32,102,114,97,109,101,115,46,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,56,83,0,0,0,0,0,0,0,0,103,120,102,32,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,116,114,101,97,109,101,100,32,111,117,116,112,117,116,44,32,112,97,116,99,104,32,119,101,108,99,111,109,101,10,0,0,0,0,0,0,100,97,116,101,0,0,0,0,105,110,118,97,108,105,100,32,116,114,97,99,107,32,105,100,32,37,120,10,0,0,0,0,108,111,111,112,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,55,83,0,0,0,0,0,0,0,0,87,97,114,110,105,110,103,58,32,83,112,101,101,120,32,115,116,114,101,97,109,32,104,97,115,32,109,111,114,101,32,116,104,97,110,32,56,32,102,114,97,109,101,115,32,112,101,114,32,112,97,99,107,101,116,46,32,65,100,111,98,101,32,70,108,97,115,104,32,80,108,97,121,101,114,32,99,97,110,110,111,116,32,104,97,110,100,108,101,32,116,104,105,115,33,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,54,83,0,0,0,0,0,0,0,0,101,120,114,0,0,0,0,0,75,101,121,102,114,97,109,101,32,105,110,100,101,120,32,112,97,114,115,105,110,103,32,102,97,105,108,101,100,10,0,0,71,101,110,101,114,97,116,101,32,97,32,102,114,97,109,101,32,112,97,99,107,101,100,32,115,116,101,114,101,111,115,99,111,112,105,99,32,118,105,100,101,111,46,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,53,83,0,0,0,0,0,0,0,0,101,118,114,99,0,0,0,0,101,110,116,101,114,101,100,32,97,117,100,105,111,32,115,117,98,104,101,97,100,101,114,10,0,0,0,0,0,0,0,0,101,115,99,97,112,101,49,51,48,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,52,83,0,0,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,97,117,100,105,111,32,115,97,109,112,108,101,32,114,97,116,101,32,105,110,100,101,120,32,40,37,100,41,10,0,0,0,0,0,0,121,117,118,52,50,48,112,49,52,98,101,0,0,0,0,0,101,115,99,97,112,101,49,50,52,0,0,0,0,0,0,0,80,108,117,109,0,0,0,0,99,104,101,98,121,0,0,0,76,105,110,101,32,37,100,58,32,105,110,118,97,108,105,100,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,51,83,0,0,0,0,0,0,0,0,71,67,83,95,76,117,122,111,110,95,49,57,49,49,0,0,0,0,0,12,102,114,109,97,97,108,97,99,0,0,0,0,113,99,111,109,112,0,0,0,101,97,116,113,105,0,0,0,86,105,100,101,111,32,117,115,101,115,32,97,32,110,111,110,45,115,116,97,110,100,97,114,100,32,97,110,100,32,119,97,115,116,101,102,117,108,32,119,97,121,32,116,111,32,115,116,111,114,101,32,66,45,102,114,97,109,101,115,32,40,39,112,97,99,107,101,100,32,66,45,102,114,97,109,101,115,39,41,46,32,67,111,110,115,105,100,101,114,32,117,115,105,110,103,32,97,32,116,111,111,108,32,108,105,107,101,32,86,105,114,116,117,97,108,68,117,98,32,111,114,32,97,118,105,100,101,109,117,120,32,116,111,32,102,105,120,32,105,116,46,10,0,70,111,114,99,101,32,99,111,110,115,116,97,110,116,32,102,114,97,109,101,114,97,116,101,46,0,0,0,0,0,0,0,97,100,100,32,116,105,109,105,110,103,115,32,102,111,114,32,98,101,110,99,104,109,97,114,107,105,110,103,0,0,0,0,80,78,71,32,40,80,111,114,116,97,98,108,101,32,78,101,116,119,111,114,107,32,71,114,97,112,104,105,99,115,41,32,105,109,97,103,101,0,0,0,68,97,110,99,101,32,72,97,108,108,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,50,83,0,0,0,0,0,0,0,0,105,67,69,32,68,114,97,119,32,70,105,108,101,0,0,0,101,97,116,103,118,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,49,83,0,0,0,0,0,0,0,0,32,32,32,32,68,101,102,97,117,108,116,32,115,117,98,116,105,116,108,101,32,99,111,100,101,99,58,32,37,115,46,10,0,0,0,0,0,0,0,0,67,111,110,118,101,114,116,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,116,111,32,111,110,101,32,111,102,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,115,46,0,0,101,97,116,103,113,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,115,97,109,112,108,101,32,114,97,116,101,0,84,111,111,32,108,97,114,103,101,32,110,117,109,98,101,114,32,111,102,32,115,107,105,112,112,101,100,32,102,114,97,109,101,115,32,37,108,108,100,32,62,32,54,48,48,48,48,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,48,83,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,100,97,116,97,32,102,111,114,32,112,97,108,101,116,116,101,10,0,0,0,0,101,97,109,97,100,0,0,0,85,110,107,110,111,119,110,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,0,101,97,99,109,118,0,0,0,83,101,116,32,116,104,101,32,102,105,101,108,100,32,111,114,100,101,114,46,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,57,83,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,86,56,0,0,81,117,101,105,110,103,32,99,111,109,109,97,110,100,115,32,111,110,108,121,32,111,110,32,102,105,108,116,101,114,115,32,115,117,112,112,111,114,116,105,110,103,32,116,104,101,32,115,112,101,99,105,102,105,99,32,99,111,109,109,97,110,100,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,10,0,105,110,118,97,108,105,100,32,112,97,99,107,101,116,32,104,101,97,100,101,114,32,108,101,110,103,116,104,32,37,100,32,102,111,114,32,112,107,116,108,101,110,32,37,100,45,37,100,32,97,116,32,37,108,108,100,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,56,83,0,121,114,114,99,0,0,0,0,102,114,97,109,101,115,121,110,99,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,55,83,0,110,98,95,99,104,97,110,110,101,108,115,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,54,83,0,108,97,118,102,105,46,115,105,108,101,110,99,101,95,100,117,114,97,116,105,111,110,0,0,32,37,110,0,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,39,37,115,39,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,114,101,113,117,101,115,116,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,46,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,83,0,76,105,98,97,118,117,116,105,108,32,104,97,115,32,98,101,101,110,32,108,105,110,107,101,100,32,116,111,32,97,32,98,114,111,107,101,110,32,108,108,114,105,110,116,40,41,10,0,115,101,116,32,115,111,102,116,45,107,110,101,101,0,0,0,45,0,0,0,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,46,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,83,0,116,104,114,101,97,100,115,0,37,45,54,115,32,32,32,37,50,100,32,0,0,0,0,0,104,105,103,104,112,97,115,115,0,0,0,0,0,0,0,0,47,100,101,118,47,114,97,110,100,111,109,0,0,0,0,0,121,117,118,52,50,48,112,49,50,108,101,0,0,0,0,0,80,105,110,107,0,0,0,0,115,101,116,32,115,111,120,114,32,114,101,115,97,109,112,108,105,110,103,32,112,114,101,99,105,115,105,111,110,32,40,105,110,32,98,105,116,115,41,0,110,115,97,109,112,108,101,115,32,60,61,32,122,101,114,111,115,32,43,32,110,97,32,43,32,110,98,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,83,0,101,0,0,0,0,0,0,0,71,67,83,95,76,111,109,101,0,0,0,0,0,0,0,0,80,101,97,107,32,99,111,117,110,116,58,32,37,108,108,100,10,0,0,0,0,0,0,0,100,101,108,97,121,0,0,0,68,105,118,88,37,100,98,37,100,37,99,0,0,0,0,0,101,97,99,51,0,0,0,0,98,101,110,99,104,109,97,114,107,0,0,0,0,0,0,0,112,110,103,0,0,0,0,0,69,117,114,111,45,72,111,117,115,101,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,114,101,115,97,109,112,108,101,46,99,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,83,0,115,112,101,101,100,0,0,0,121,117,121,118,52,50,50,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,112,97,100,46,99,0,0,0,68,117,114,97,116,105,111,110,32,111,102,32,108,111,110,103,101,115,116,32,105,110,112,117,116,46,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,83,0,32,32,32,32,68,101,102,97,117,108,116,32,97,117,100,105,111,32,99,111,100,101,99,58,32,37,115,46,10,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,105,110,112,117,116,115,0,0,0,0,100,120,116,111,114,121,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,115,97,109,112,108,101,32,114,97,116,101,115,46,0,117,110,115,112,101,99,105,102,105,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,110,98,95,115,97,109,112,108,101,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,54,48,78,0,0,0,0,0,0,0,0,70,105,101,108,100,32,109,97,116,99,104,105,110,103,32,102,111,114,32,105,110,118,101,114,115,101,32,116,101,108,101,99,105,110,101,46,0,0,0,0,111,117,116,95,103,97,105,110,0,0,0,0,0,0,0,0,48,120,0,0,0,0,0,0,77,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,32,101,120,112,114,101,115,115,105,111,110,115,32,39,37,100,39,32,97,110,100,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,101,120,112,101,99,116,101,100,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,115,32,39,37,100,39,32,102,111,114,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,57,78,0,0,0,0,0,0,0,0,100,120,97,0,0,0,0,0,115,109,112,116,101,104,100,98,97,114,115,0,0,0,0,0,69,120,116,114,97,99,116,32,97,32,102,105,101,108,100,32,102,114,111,109,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,67,111,109,109,97,110,100,32,114,101,112,108,121,32,102,111,114,32,115,116,114,101,97,109,32,37,100,58,32,114,101,116,58,37,100,32,114,101,115,58,10,37,115,0,0,0,0,0,100,118,118,105,100,101,111,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,56,78,0,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,115,116,97,114,116,95,120,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,114,117,108,101,32,99,111,100,101,32,39,37,115,39,32,112,114,111,118,105,100,101,100,10,0,0,0,0,0,0,0,0,105,110,95,116,115,32,33,61,32,40,40,105,110,116,54,52,95,116,41,48,120,56,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,85,76,76,41,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,55,78,0,0,0,0,0,0,0,0,112,97,116,116,101,114,110,0,32,32,32,32,76,97,115,116,32,109,101,115,115,97,103,101,32,114,101,112,101,97,116,101,100,32,37,100,32,116,105,109,101,115,13,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,112,97,114,105,116,121,0,0,100,118,100,115,117,98,0,0,109,117,114,109,117,114,51,0,100,101,102,97,117,108,116,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,54,78,0,0,0,0,0,0,0,0,97,110,103,108,101,0,0,0,98,116,55,48,57,0,0,0,99,104,114,111,109,97,95,109,115,105,122,101,95,120,0,0,69,114,114,111,114,32,111,99,99,117,114,114,101,100,32,105,110,32,102,115,116,97,116,40,41,58,32,37,115,10,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,53,78,0,0,0,0,0,0,0,0,112,97,115,115,116,104,114,111,117,103,104,0,0,0,0,0,100,118,100,115,117,98,0,0,115,101,116,32,105,110,110,101,114,32,98,111,114,100,101,114,32,116,104,105,99,107,110,101,115,115,32,105,110,32,112,105,120,101,108,115,0,0,0,0,70,97,100,101,32,105,110,47,111,117,116,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,0,37,102,10,0,0,0,0,0,115,101,108,101,99,116,32,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,0,100,118,118,105,100,101,111,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,52,78,0,0,0,0,0,0,0,0,66,83,70,95,78,79,84,95,70,79,85,78,68,0,0,0,100,101,102,97,117,108,116,0,99,112,117,102,108,97,103,115,0,0,0,0,0,0,0,0,121,117,118,52,50,48,112,49,50,98,101,0,0,0,0,0,80,101,114,117,0,0,0,0,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,51,78,0,0,0,0,0,0,0,0,71,67,83,95,76,105,98,101,114,105,97,95,49,57,54,52,0,0,0,0,0,0,0,0,79,117,116,112,117,116,32,118,105,100,101,111,32,119,105,100,116,104,0,0,0,0,0,0,102,114,97,109,101,95,110,117,109,98,101,114,0,0,0,0,68,105,118,88,37,100,66,117,105,108,100,37,100,37,99,0,37,100,32,99,104,97,110,110,101,108,115,0,0,0,0,0,100,118,98,115,117,98,0,0,111,104,0,0,0,0,0,0,110,117,109,98,101,114,0,0,81,45,116,101,97,109,32,81,80,69,71,0,0,0,0,0,100,118,98,115,117,98,0,0,65,32,99,97,112,101,108,108,97,0,0,0,0,0,0,0,39,92,39,39,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,50,78,0,0,0,0,0,0,0,0,32,10,9,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,48,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,100,101,115,99,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,49,78,0,0,0,0,0,0,0,0,32,32,32,32,68,101,102,97,117,108,116,32,118,105,100,101,111,32,99,111,100,101,99,58,32,37,115,46,10,0,0,0,37,105,98,112,112,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,121,117,118,50,114,103,98,10,0,69,120,116,114,97,99,116,32,112,108,97,110,101,115,32,97,115,32,103,114,97,121,115,99,97,108,101,32,102,114,97,109,101,115,46,0,0,0,0,0,111,118,101,114,108,97,121,95,104,0,0,0,0,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,102,114,97,109,101,32,115,105,122,101,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,48,78,0,0,0,0,0,0,0,0,98,97,100,32,115,114,99,32,105,109,97,103,101,32,112,111,105,110,116,101,114,115,10,0,112,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,115,119,115,95,102,108,97,103,115,0,0,0,0,0,0,0,97,45,62,112,108,97,110,97,114,0,0,0,0,0,0,0,117,115,101,32,118,97,108,117,101,115,32,102,114,111,109,32,116,104,101,32,110,101,97,114,101,115,116,32,100,101,102,105,110,101,100,32,112,111,105,110,116,115,0,0,0,0,0,0,115,45,62,100,105,116,104,101,114,46,109,101,116,104,111,100,32,60,32,83,87,82,95,68,73,84,72,69,82,95,78,66,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,57,78,0,0,0,0,0,0,0,0,99,116,120,45,62,99,104,97,110,110,101,108,115,32,61,61,32,111,117,116,45,62,99,104,95,99,111,117,110,116,0,0,65,112,112,108,121,32,112,111,115,116,101,114,105,122,101,32,101,102,102,101,99,116,44,32,117,115,105,110,103,32,116,104,101,32,69,76,66,71,32,97,108,103,111,114,105,116,104,109,46,0,0,0,0,0,0,0,99,48,0,0,0,0,0,0,80,114,111,99,101,115,115,105,110,103,32,99,111,109,109,97,110,100,32,116,97,114,103,101,116,58,37,115,32,116,105,109,101,58,37,102,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,0,0,99,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,56,78,0,0,0,0,0,0,0,0,80,114,111,103,114,101,115,115,105,118,101,32,32,32,32,32,32,32,0,0,0,0,0,0,99,112,114,116,0,0,0,0,72,32,97,110,100,32,104,32,111,112,116,105,111,110,115,32,97,114,101,32,105,110,99,111,109,112,97,116,105,98,108,101,32,97,110,100,32,99,97,110,110,111,116,32,98,101,32,115,112,101,99,105,102,105,101,100,32,97,116,32,116,104,101,32,115,97,109,101,32,116,105,109,101,10,0,0,0,0,0,0,68,101,116,101,99,116,32,97,110,100,32,100,114,97,119,32,101,100,103,101,46,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,73,68,67,84,32,112,101,114,109,117,116,97,116,105,111,110,32,110,111,116,32,115,101,116,10,0,0,0,0,0,0,0,99,104,114,111,109,97,32,118,97,108,117,101,115,32,105,110,32,118,101,99,116,111,114,115,99,111,112,101,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,55,78], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2292360);
/* memory initializer */ allocate([0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,102,105,108,116,101,114,32,116,121,112,101,32,105,115,32,110,111,116,32,99,117,114,114,101,110,116,108,121,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,0,99,111,108,117,109,110,115,0,105,110,102,0,0,0,0,0,105,99,99,95,109,111,100,101,32,37,100,32,105,115,32,114,101,115,101,114,118,101,100,46,10,0,0,0,0,0,0,0,100,115,105,99,105,110,118,105,100,101,111,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,54,78,0,0,0,0,0,0,0,0,112,105,120,101,108,32,102,111,114,109,97,116,32,99,104,97,110,103,101,100,10,0,0,0,73,110,118,97,108,105,100,32,100,101,99,111,100,101,32,116,121,112,101,46,32,73,110,118,97,108,105,100,32,104,101,97,100,101,114,63,10,0,0,0,100,112,120,0,0,0,0,0,121,117,118,106,52,50,48,112,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,53,78,0,0,0,0,0,0,0,0,110,111,119,0,0,0,0,0,37,108,108,100,0,0,0,0,91,37,115,32,64,32,37,112,93,32,0,0,0,0,0,0,83,72,65,53,49,50,0,0,115,116,97,114,116,95,102,114,97,109,101,0,0,0,0,0,72,69,73,71,72,84,0,0,97,115,105,110,0,0,0,0,69,78,67,79,68,69,82,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,108,111,119,32,102,114,101,113,117,101,110,99,121,0,0,0,118,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,52,78,0,0,0,0,0,0,0,0,37,115,32,111,117,116,112,117,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,104,97,108,102,32,99,104,114,111,109,97,32,114,101,115,111,108,117,116,105,111,110,44,32,115,119,105,116,99,104,105,110,103,32,116,111,32,102,117,108,108,10,0,0,0,0,0,0,108,117,109,66,117,102,73,110,100,101,120,32,60,32,50,32,42,32,118,76,117,109,66,117,102,83,105,122,101,0,0,0,98,105,99,117,98,108,105,110,0,0,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,105,110,112,117,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,121,117,118,97,52,50,50,112,0,0,0,0,0,0,0,0,100,112,120,0,0,0,0,0,80,101,97,99,104,80,117,102,102,0,0,0,0,0,0,0,109,101,95,109,101,116,104,111,100,32,105,115,32,111,110,108,121,32,97,108,108,111,119,101,100,32,116,111,32,98,101,32,115,101,116,32,116,111,32,122,101,114,111,32,97,110,100,32,101,112,122,115,59,32,102,111,114,32,104,101,120,44,117,109,104,44,102,117,108,108,32,97,110,100,32,111,116,104,101,114,115,32,115,101,101,32,100,105,97,95,115,105,122,101,10,0,115,101,108,101,99,116,32,83,111,88,32,82,101,115,97,109,112,108,101,114,0,0,0,0,104,101,105,103,104,116,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,51,78,0,0,0,0,0,0,0,0,103,117,101,115,115,95,100,99,40,41,32,105,115,32,111,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,0,0,110,32,60,61,32,49,48,50,52,0,0,0,0,0,0,0,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,111,112,116,105,111,110,115,58,0,105,110,100,101,120,32,60,32,50,53,54,0,0,0,0,0,92,102,110,37,49,91,92,125,93,37,110,0,0,0,0,0,71,67,83,95,76,101,105,103,111,110,0,0,0,0,0,0,101,120,116,114,97,100,97,116,97,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,105,110,118,97,108,105,100,32,116,114,101,108,108,105,115,32,115,105,122,101,10,0,0,0,104,0,0,0,0,0,0,0,115,45,62,109,98,95,119,105,100,116,104,62,48,0,0,0,102,114,97,109,101,95,115,105,122,101,0,0,0,0,0,0,97,100,112,99,109,95,101,97,95,114,49,0,0,0,0,0,71,79,80,32,104,101,97,100,101,114,32,105,110,118,97,108,105,100,10,0,0,0,0,0,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,10,0,108,116,114,116,95,115,117,114,109,105,120,108,101,118,0,0,99,121,99,108,101,0,0,0,101,110,118,101,108,111,112,101,32,115,99,97,108,101,102,97,99,116,111,114,32,111,118,101,114,102,108,111,119,32,105,110,32,100,101,113,117,97,110,116,10,0,0,0,0,0,0,0,115,116,101,114,101,111,95,109,111,100,101,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,100,97,116,97,32,102,114,97,109,101,115,32,116,111,32,114,101,99,111,114,100,0,102,45,62,115,108,105,99,101,95,99,111,117,110,116,32,62,32,48,0,0,0,0,0,0,113,112,101,103,0,0,0,0,68,114,97,119,32,97,32,99,111,108,111,114,101,100,32,98,111,120,32,111,110,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,68,101,112,101,110,100,101,110,116,32,99,111,117,112,108,105,110,103,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,116,111,103,101,116,104,101,114,32,119,105,116,104,32,76,84,80,10,0,0,82,117,110,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,68,114,117,109,32,83,111,108,111,0,0,0,0,0,0,0,84,104,101,32,108,97,115,116,32,37,100,32,104,111,114,105,122,111,110,116,97,108,32,112,105,120,101,108,115,32,119,111,110,39,116,32,98,101,32,100,101,110,111,105,115,101,100,10,0,0,0,0,0,0,0,0,84,73,70,70,32,116,97,103,32,116,121,112,101,32,40,37,117,41,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,50,78,0,0,0,0,0,0,0,0,85,115,101,100,32,37,116,105,32,111,102,32,37,105,32,98,121,116,101,115,10,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,119,105,100,116,104,58,32,37,100,46,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,109,97,112,32,117,110,105,116,10,0,0,0,0,105,103,110,111,114,105,110,103,32,108,97,115,116,32,109,105,115,115,105,110,103,32,115,108,105,99,101,10,0,0,0,0,73,110,118,97,108,105,100,32,112,105,116,99,104,32,114,97,110,103,101,59,32,98,114,111,107,101,110,32,101,120,116,114,97,100,97,116,97,63,10,0,68,101,112,101,110,100,101,110,116,32,115,117,98,115,116,114,101,97,109,32,100,101,99,111,100,105,110,103,0,0,0,0,110,101,103,97,116,105,118,101,32,113,117,97,110,116,32,115,116,101,112,10,0,0,0,0,70,111,117,110,100,32,101,109,112,116,121,32,115,117,98,102,114,97,109,101,10,0,0,0,98,108,111,99,107,95,108,101,110,95,98,105,116,115,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,100,32,116,111,32,97,32,118,97,108,105,100,32,118,97,108,117,101,10,0,0,0,0,0,0,0,0,123,92,98,48,125,0,0,0,115,107,105,112,112,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,58,32,37,115,10,0,0,0,0,0,111,102,102,0,0,0,0,0,84,111,111,32,109,97,110,121,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,119,101,105,103,104,116,115,10,0,100,101,99,111,100,101,95,102,111,114,109,97,116,56,48,32,112,114,111,98,108,101,109,58,32,110,101,120,116,32,111,112,32,119,111,117,108,100,32,111,118,101,114,102,108,111,119,32,100,101,115,116,95,105,110,100,101,120,10,0,0,0,0,0,78,111,116,32,97,108,108,32,114,101,102,101,114,101,110,99,101,115,32,97,114,101,32,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,107,101,121,32,112,111,105,110,116,32,99,111,111,114,100,105,110,97,116,101,115,32,40,37,102,59,37,102,41,44,32,120,32,97,110,100,32,121,32,109,117,115,116,32,98,101,32,105,110,32,116,104,101,32,91,48,59,49,93,32,114,97,110,103,101,46,10,0,0,0,0,0,87,97,114,110,105,110,103,44,32,117,110,115,117,112,112,111,114,116,101,100,32,107,101,121,102,114,97,109,101,32,99,111,100,105,110,103,32,116,121,112,101,63,33,10,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,111,117,116,112,117,116,32,98,117,102,102,101,114,10,0,0,0,0,0,87,114,111,110,103,32,112,97,99,107,101,116,32,116,121,112,101,32,105,110,32,73,100,32,104,101,97,100,101,114,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,97,108,105,103,110,10,0,0,0,0,105,110,116,101,114,112,108,97,121,95,100,112,99,109,0,0,112,97,114,115,105,110,103,32,104,101,97,100,101,114,32,102,111,114,32,115,101,99,111,110,100,32,102,105,101,108,100,32,102,97,105,108,101,100,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,49,78,0,0,0,0,0,0,0,0,32,32,32,32,77,105,109,101,32,116,121,112,101,58,32,37,115,46,10,0,0,0,0,0,40,105,110,95,119,45,111,117,116,95,119,41,47,50,0,0,76,117,109,97,32,115,99,97,108,105,110,103,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,101,120,112,101,99,116,32,119,114,111,110,103,32,112,105,99,116,117,114,101,10,0,0,0,0,80,108,97,110,101,32,112,114,101,100,105,99,116,105,111,110,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,85,116,32,86,105,100,101,111,46,10,0,81,117,101,117,101,32,105,110,112,117,116,32,105,115,32,98,97,99,107,119,97,114,100,32,105,110,32,116,105,109,101,10,0,0,0,0,0,0,0,0,37,100,32,98,105,116,115,32,108,101,102,116,32,97,102,116,101,114,32,100,101,99,111,100,105,110,103,32,115,108,105,99,101,10,0,0,0,0,0,0,71,72,65,32,97,109,112,108,105,116,117,100,101,32,109,111,100,101,32,48,0,0,0,0,115,116,97,114,116,32,116,105,109,101,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,101,115,116,105,109,97,116,101,95,116,105,109,105,110,103,115,95,102,114,111,109,95,112,116,115,10,0,0,0,0,0,73,103,110,111,114,105,110,103,32,105,110,118,97,108,105,100,32,119,105,100,116,104,47,104,101,105,103,104,116,32,118,97,108,117,101,115,10,0,0,0,103,103,0,0,0,0,0,0,102,114,97,109,101,95,108,101,110,103,116,104,32,116,111,111,32,108,97,114,103,101,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,73,110,118,97,108,105,100,32,100,101,108,116,97,32,116,111,107,101,110,32,105,110,100,101,120,32,37,100,32,102,111,114,32,116,121,112,101,32,37,100,44,32,110,61,37,100,10,0,32,75,69,89,0,0,0,0,100,112,105,0,0,0,0,0,98,109,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,0,0,0,0,0,0,92,37,49,91,110,78,93,0,71,101,111,103,83,101,109,105,77,97,106,111,114,65,120,105,115,71,101,111,75,101,121,0,65,114,105,97,108,0,0,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,76,90,87,32,100,101,99,111,100,101,114,10,0,124,0,0,0,0,0,0,0,65,76,65,67,32,40,65,112,112,108,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,84,79,80,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,113,115,99,97,108,101,58,37,100,10,0,0,0,0,0,0,32,32,88,49,58,37,48,51,117,32,88,50,58,37,48,51,117,32,89,49,58,37,48,51,117,32,89,50,58,37,48,51,117,0,0,0,0,0,0,0,123,37,42,49,91,67,99,70,102,111,80,83,115,89,121,93,58,37,42,91,94,125,93,125,37,110,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,111,119,110,115,97,109,112,108,105,110,103,32,118,97,108,117,101,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,0,0,0,0,0,0,84,104,105,115,32,99,111,100,101,99,32,105,115,32,117,110,100,101,114,32,100,101,118,101,108,111,112,109,101,110,116,44,32,102,105,108,101,115,32,101,110,99,111,100,101,100,32,119,105,116,104,32,105,116,32,109,97,121,32,110,111,116,32,98,101,32,100,101,99,111,100,97,98,108,101,32,119,105,116,104,32,102,117,116,117,114,101,32,118,101,114,115,105,111,110,115,33,33,33,10,85,115,101,32,118,115,116,114,105,99,116,61,45,50,32,47,32,45,115,116,114,105,99,116,32,45,50,32,116,111,32,117,115,101,32,105,116,32,97,110,121,119,97,121,46,10,0,0,0,0,0,0,65,76,65,67,32,40,65,112,112,108,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,98,108,97,99,107,95,115,116,97,114,116,58,37,115,32,98,108,97,99,107,95,101,110,100,58,37,115,32,98,108,97,99,107,95,100,117,114,97,116,105,111,110,58,37,115,10,0,0,98,108,111,99,107,95,109,97,120,95,100,101,112,116,104,61,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,84,114,101,101,32,115,105,122,101,32,101,120,99,101,101,100,101,100,33,10,0,0,0,0,100,110,120,104,100,0,0,0,65,112,112,108,101,32,73,110,116,101,114,109,101,100,105,97,116,101,32,67,111,100,101,99,0,0,0,0,0,0,0,0,109,105,115,115,105,110,103,32,118,101,114,98,97,116,105,109,32,115,101,99,116,105,111,110,32,97,116,32,98,101,103,105,110,110,105,110,103,32,111,102,32,115,116,114,101,97,109,10,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,0,0,0,0,83,69,71,65,32,67,82,73,32,65,68,88,32,65,68,80,67,77,0,0,0,0,0,0,108,97,118,102,105,46,98,98,111,120,46,104,0,0,0,0,83,69,71,65,32,67,82,73,32,65,68,88,32,65,68,80,67,77,0,0,0,0,0,0,117,110,107,110,111,119,110,32,102,114,97,109,101,32,116,121,112,101,10,0,0,0,0,0,116,111,112,0,0,0,0,0,105,115,80,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,81,117,105,99,107,84,105,109,101,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,100,105,110,103,32,112,97,114,97,109,101,116,101,114,115,32,37,100,32,72,122,32,37,100,32,99,104,10,0,0,100,101,102,97,117,108,116,0,99,111,100,105,110,103,32,109,101,116,104,111,100,32,105,110,118,97,108,105,100,10,0,0,66,108,97,110,107,32,102,114,97,109,101,32,104,97,110,100,108,105,110,103,0,0,0,0,76,84,0,0,0,0,0,0,97,112,99,110,0,0,0,0,37,54,51,91,94,32,93,32,37,108,102,32,37,50,53,53,91,94,32,93,32,37,50,53,53,91,94,10,93,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,104,101,97,100,101,114,32,118,101,114,115,105,111,110,58,32,37,100,10,0,101,114,114,111,114,44,32,119,114,111,110,103,32,115,108,105,99,101,32,100,97,116,97,32,115,105,122,101,10,0,0,0,80,37,99,10,37,100,32,37,100,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,32,37,100,32,97,110,100,32,99,111,108,111,114,32,116,121,112,101,32,37,100,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,0,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,115,116,97,114,116,95,115,97,109,112,108,101,0,0,0,0,97,108,98,117,109,0,0,0,100,110,120,104,100,0,0,0,115,101,116,32,115,101,101,107,112,111,105,110,116,32,40,115,101,99,111,110,100,115,41,0,77,88,77,32,98,105,116,109,97,115,107,32,105,115,32,110,111,116,32,99,111,109,112,108,101,116,101,10,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,10,0,65,115,121,109,109,101,116,114,105,99,32,87,77,86,57,32,114,101,99,116,97,110,103,108,101,32,115,117,98,115,97,109,112,108,105,110,103,0,0,0,70,114,97,109,101,32,115,105,122,101,58,32,37,100,120,37,100,37,99,59,32,98,105,116,114,97,116,101,58,32,37,100,77,98,112,115,59,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,115,59,32,102,114,97,109,101,114,97,116,101,58,32,37,100,47,37,100,10,0,0,0,0,0,0,0,77,97,120,46,32,108,101,97,100,32,116,105,109,101,32,37,103,32,109,115,10,0,0,0,83,116,97,98,105,108,105,122,101,32,115,104,97,107,121,32,118,105,100,101,111,46,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,0,0,0,0,0,65,68,80,67,77,32,52,88,32,77,111,118,105,101,0,0,99,104,114,111,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,32,45,62,32,80,84,83,58,37,115,32,84,58,37,102,10,0,0,0,0,0,0,0,0,77,80,51,111,110,77,80,52,0,0,0,0,0,0,0,0,77,80,51,111,110,77,80,52,0,0,0,0,0,0,0,0,70,108,97,103,115,32,99,111,109,109,111,110,32,102,111,114,32,97,108,108,32,109,112,101,103,118,105,100,101,111,45,98,97,115,101,100,32,101,110,99,111,100,101,114,115,46,0,0,91,93,44,59,10,0,0,0,85,115,101,32,77,80,69,71,45,50,32,105,110,116,114,97,32,86,76,67,32,116,97,98,108,101,46,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,32,68,83,67,70,32,86,76,67,10,0,0,0,76,97,121,111,117,116,32,105,110,100,105,99,97,116,101,115,32,97,32,100,105,102,102,101,114,101,110,116,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,116,104,97,110,32,97,99,116,117,97,108,108,121,32,112,114,101,115,101,110,116,10,0,0,83,117,98,115,116,114,101,97,109,32,37,100,32,99,104,101,99,107,115,117,109,32,102,97,105,108,101,100,46,10,0,0,67,83,61,73,84,85,54,48,49,0,0,0,0,0,0,0,82,101,109,111,118,101,32,106,117,100,100,101,114,32,112,114,111,100,117,99,101,100,32,98,121,32,112,117,108,108,117,112,46,0,0,0,0,0,0,0,113,117,97,110,116,95,105,110,100,101,120,32,105,115,32,105,110,118,97,108,105,100,10,0,115,111,115,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,0,0,0,0,0,0,123,92,99,38,72,37,48,54,88,38,125,0,0,0,0,0,65,86,84,66,0,0,0,0,73,110,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,65,108,108,32,112,114,111,98,97,98,105,108,105,116,105,101,115,32,97,114,101,32,48,33,10,0,0,0,0,0,0,0,80,114,111,103,114,101,115,115,105,111,110,32,111,114,100,101,114,32,80,67,82,76,0,0,66,105,116,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,46,32,84,114,121,32,105,110,99,114,101,97,115,105,110,103,32,116,104,101,32,98,105,116,114,97,116,101,46,10,0,0,0,0,0,123,92,97,110,53,125,0,0,67,111,114,114,117,112,116,101,100,32,116,105,108,101,32,100,97,116,97,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,72,101,108,112,33,32,77,121,115,116,101,114,121,32,111,112,99,111,100,101,32,48,120,54,32,115,101,101,110,10,0,0,67,111,109,109,97,110,100,32,114,101,112,108,121,32,102,111,114,32,99,111,109,109,97,110,100,32,35,37,100,58,32,114,101,116,58,37,115,32,114,101,115,58,37,115,10,0,0,0,83,99,97,108,97,98,105,108,105,116,121,58,32,117,110,115,117,112,112,111,114,116,101,100,32,115,117,98,100,105,118,105,115,105,111,110,33,32,76,117,109,97,32,98,97,110,100,115,58,32,37,100,44,32,99,104,114,111,109,97,32,98,97,110,100,115,58,32,37,100,10,0,116,114,97,110,115,102,111,114,109,32,97,110,100,32,98,108,111,99,107,32,115,105,122,101,32,109,105,115,109,97,116,99,104,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,65,116,116,101,109,112,116,32,116,111,32,117,115,101,32,77,111,100,101,32,49,49,32,102,111,114,32,97,110,32,73,78,84,82,65,32,99,101,108,108,33,10,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,0,0,0,0,0,0,102,108,99,111,101,102,102,115,53,32,37,102,32,105,110,118,97,108,105,100,10,0,0,0,98,112,112,32,37,100,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,112,97,108,101,116,116,101,10,0,0,0,87,105,100,116,104,32,109,117,115,116,32,98,101,32,101,118,101,110,32,102,111,114,32,116,104,105,115,32,99,111,108,111,114,115,112,97,99,101,46,10,0,0,0,0,0,0,0,0,119,105,100,116,104,32,109,117,115,116,32,98,101,32,101,118,101,110,32,102,111,114,32,116,104,105,115,32,99,111,108,111,114,115,112,97,99,101,10,0,83,80,83,32,105,100,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,78,65,76,32,117,110,105,116,32,35,37,100,46,10,0,0,0,0,66,105,116,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,46,32,84,114,121,32,105,110,99,114,101,97,115,105,110,103,32,116,104,101,32,98,105,116,114,97,116,101,46,10,0,0,0,0,0,116,111,112,95,98,111,116,116,111,109,0,0,0,0,0,0,109,109,99,111,58,37,100,32,37,100,32,37,100,10,0,0,112,114,101,118,95,115,101,108,101,99,116,101,100,95,112,116,115,0,0,0,0,0,0,0,82,101,100,117,99,105,110,103,32,108,101,102,116,32,99,114,111,112,112,105,110,103,32,116,111,32,37,100,32,99,104,114,111,109,97,32,115,97,109,112,108,101,115,32,116,111,32,112,114,101,115,101,114,118,101,32,97,108,105,103,110,109,101,110,116,46,10,0,0,0,0,0,115,117,114,114,111,117,110,100,95,109,105,120,95,108,101,118,101,108,0,0,0,0,0,0,73,110,118,97,108,105,100,32,108,101,118,101,108,32,112,114,101,102,105,120,10,0,0,0,114,101,102,101,114,101,110,99,101,32,111,118,101,114,102,108,111,119,32,37,117,32,62,32,37,117,32,111,114,32,37,117,32,62,32,37,117,10,0,0,69,114,114,111,114,32,97,116,32,77,66,58,32,37,100,10,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,97,99,32,118,108,99,32,99,111,100,101,32,97,116,32,37,100,120,37,100,10,0,0,0,103,105,102,32,100,101,99,111,100,101,114,0,0,0,0,0,116,111,103,103,108,101,0,0,111,102,102,115,101,116,116,105,110,103,0,0,0,0,0,0,98,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,52,78,0,0,0,0,0,0,0,0,98,112,112,61,37,100,0,0,80,114,111,99,101,115,115,101,100,32,70,76,73,32,99,104,117,110,107,32,119,104,101,114,101,32,99,104,117,110,107,32,115,105,122,101,32,61,32,37,100,32,97,110,100,32,102,105,110,97,108,32,99,104,117,110,107,32,112,116,114,32,61,32,37,100,10,0,0,0,0,0,100,105,114,97,99,0,0,0,37,100,120,37,100,32,105,110,118,97,108,105,100,32,99,111,108,111,114,32,100,101,112,116,104,32,37,100,10,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,113,117,101,117,101,46,104,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,115,105,122,101,58,32,37,100,10,0,115,119,105,116,99,104,105,110,103,32,98,112,115,32,109,105,100,45,115,116,114,101,97,109,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,65,84,83,67,32,65,47,53,50,65,32,40,65,67,45,51,41,0,0,0,0,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,65,117,116,111,100,101,115,107,32,82,76,69,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,102,118,49,100,101,99,46,99,0,0,0,0,85,0,0,0,0,0,0,0,78,111,116,32,73,110,100,105,99,97,116,101,100,32,40,100,101,102,97,117,108,116,41,0,121,117,118,97,52,52,52,112,0,0,0,0,0,0,0,0,70,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,0,0,80,97,112,97,121,97,87,104,105,112,0,0,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,112,97,108,101,116,116,101,58,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,103,108,111,98,97,108,32,112,97,108,101,116,116,101,0,0,68,101,99,111,100,105,110,103,32,102,105,114,115,116,32,68,86,66,32,115,117,98,116,105,116,108,101,115,32,115,117,98,45,115,116,114,101,97,109,10,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,0,115,111,120,114,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,102,111,114,109,97,116,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,33,97,108,101,118,101,108,32,124,124,32,106,32,60,32,50,53,55,0,0,0,0,0,0,70,114,97,109,101,32,116,111,32,114,101,116,105,114,101,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,98,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,100,32,109,105,115,109,97,116,99,104,101,115,32,108,97,121,111,117,116,32,37,100,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,51,78,0,0,0,0,0,0,0,0,106,115,95,115,117,98,98,97,110,100,95,115,116,97,114,116,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,83,116,114,101,97,109,32,105,115,32,111,108,100,32,97,110,100,32,109,97,121,32,110,111,116,32,119,111,114,107,10,0,115,97,109,112,108,101,95,114,97,116,101,115,0,0,0,0,71,67,83,95,76,97,107,101,0,0,0,0,0,0,0,0,115,101,116,32,99,117,116,111,102,102,32,98,97,110,100,119,105,100,116,104,0,0,0,0,116,101,120,116,117,114,101,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,32,37,100,10,0,0,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,0,114,118,50,48,0,0,0,0,109,97,120,95,115,116,114,105,112,115,0,0,0,0,0,0,103,101,116,95,117,101,95,99,111,100,101,58,32,118,97,108,117,101,32,116,111,111,32,108,97,114,103,101,114,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,108,105,98,97,118,99,111,100,101,99,47,98,109,118,46,99,0,0,0,0,0,0,0,0,100,101,112,116,104,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,100,102,114,97,109,101,115,0,77,105,114,111,32,86,105,100,101,111,88,76,0,0,0,0,116,97,98,108,101,91,106,93,91,48,93,32,61,61,32,105,110,100,101,120,0,0,0,0,68,101,99,105,109,97,116,101,32,102,114,97,109,101,115,32,40,112,111,115,116,32,102,105,101,108,100,32,109,97,116,99,104,105,110,103,32,102,105,108,116,101,114,41,46,0,0,0,84,111,111,32,109,97,110,121,32,99,111,108,111,114,32,118,97,108,117,101,115,10,0,0,98,101,115,116,95,105,100,120,32,62,61,32,48,0,0,0,80,117,110,107,32,82,111,99,107,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,46,10,0,0,0,0,0,112,117,114,101,32,115,105,108,101,110,99,101,32,109,111,110,111,10,0,0,0,0,0,0,113,117,97,110,116,95,99,111,102,32,37,100,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,46,10,0,0,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,0,114,101,112,108,97,99,101,115,0,0,0,0,0,0,0,0,99,111,108,95,105,110,116,101,114,108,101,97,118,101,100,95,114,108,0,0,0,0,0,0,77,117,108,116,105,99,111,108,111,114,32,99,104,97,114,115,101,116,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,0,0,0,0,0,79,116,104,101,114,0,0,0,56,83,86,88,32,102,105,98,111,110,97,99,99,105,0,0,87,77,47,69,110,99,111,100,105,110,103,83,101,116,116,105,110,103,115,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,56,66,80,83,32,118,105,100,101,111,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,118,102,105,108,116,101,114,46,99,0,0,69,110,97,98,108,101,32,65,80,69,32,116,97,103,32,119,114,105,116,105,110,103,0,0,52,50,50,112,49,52,0,0,100,102,97,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,0,0,0,0,0,0,32,32,32,32,67,111,109,109,111,110,32,101,120,116,101,110,115,105,111,110,115,58,32,37,115,46,10,0,0,0,0,0,52,88,32,77,111,118,105,101,0,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,90,105,112,32,77,111,116,105,111,110,32,66,108,111,99,107,115,32,86,105,100,101,111,0,69,115,116,105,109,97,116,105,110,103,32,100,117,114,97,116,105,111,110,32,102,114,111,109,32,98,105,116,114,97,116,101,44,32,116,104,105,115,32,109,97,121,32,98,101,32,105,110,97,99,99,117,114,97,116,101,10,0,0,0,0,0,0,0,90,105,112,32,77,111,116,105,111,110,32,66,108,111,99,107,115,32,86,105,100,101,111,0,90,101,114,111,67,111,100,101,99,32,76,111,115,115,108,101,115,115,32,86,105,100,101,111,0,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,50,58,48,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,50,58,48,0,0,0,0,0,0,0,80,115,121,103,110,111,115,105,115,32,89,79,80,32,86,105,100,101,111,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,48,78,0,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,89,85,86,32,52,58,49,58,49,32,49,50,45,98,105,116,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,89,85,86,32,52,58,49,58,49,32,49,50,45,98,105,116,0,0,0,68,101,110,111,105,115,101,32,102,114,97,109,101,115,32,117,115,105,110,103,32,50,68,32,68,67,84,46,0,0,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,86,32,47,32,88,120,97,110,0,0,0,0,0,0,0,0,88,87,68,32,40,88,32,87,105,110,100,111,119,32,68,117,109,112,41,32,105,109,97,103,101,0,0,0,0,0,0,0,88,87,68,32,40,88,32,87,105,110,100,111,119,32,68,117,109,112,41,32,105,109,97,103,101,0,0,0,0,0,0,0,68,105,118,88,32,115,117,98,116,105,116,108,101,115,32,40,88,83,85,66,41,0,0,0,88,83,85,66,0,0,0,0,77,105,114,111,32,86,105,100,101,111,88,76,0,0,0,0,88,45,102,97,99,101,32,105,109,97,103,101,0,0,0,0,88,45,102,97,99,101,32,105,109,97,103,101,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,0,0,0,0,0,0,88,66,77,32,40,88,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,88,66,77,32,40,88,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,73,73,32,47,32,88,97,110,0,0,0,0,0,0,0,0,87,101,115,116,119,111,111,100,32,65,117,100,105,111,32,40,83,78,68,49,41,0,0,0,87,105,110,110,111,118,32,87,78,86,49,0,0,0,0,0,115,45,62,102,108,105,112,102,108,111,112,95,114,111,117,110,100,105,110,103,0,0,0,0,10,69,110,116,101,114,32,99,111,109,109,97,110,100,58,32,60,116,97,114,103,101,116,62,124,97,108,108,32,60,116,105,109,101,62,124,45,49,32,60,99,111,109,109,97,110,100,62,91,32,60,97,114,103,117,109,101,110,116,62,93,10,0,0,113,115,99,97,108,101,58,37,100,32,114,108,99,58,37,100,32,114,108,58,37,100,32,100,99,58,37,100,32,109,98,114,108,58,37,100,32,106,95,116,121,112,101,58,37,100,32,10,0,0,0,0,0,0,0,0,100,99,97,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,86,111,105,99,101,0,0,0,0,0,0,0,97,108,98,109,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,57,32,80,114,111,102,101,115,115,105,111,110,97,108,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,76,111,115,115,108,101,115,115,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,55,78,0,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,49,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,49,0,0,0,98,114,111,107,101,110,32,101,115,99,97,112,101,32,115,101,113,117,101,110,99,101,10,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,54,78,0,0,0,0,0,0,0,0,87,101,98,80,32,105,109,97,103,101,0,0,0,0,0,0,87,97,118,80,97,99,107,0,87,97,118,80,97,99,107,0,87,101,115,116,119,111,111,100,32,83,116,117,100,105,111,115,32,86,81,65,32,40,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,100,32,65,110,105,109,97,116,105,111,110,41,32,118,105,100,101,111,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,53,78,0,0,0,0,0,0,0,0,71,111,111,103,108,101,32,86,80,57,0,0,0,0,0,0,68,105,115,99,97,114,100,105,110,103,32,105,110,116,101,114,102,114,97,109,101,32,119,105,116,104,111,117,116,32,97,32,112,114,105,111,114,32,107,101,121,102,114,97,109,101,33,10,0,0,0,0,0,0,0,0,79,110,50,32,86,80,54,0,112,105,99,116,117,114,101,32,116,111,111,32,98,105,103,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,52,78,0,0,0,0,0,0,0,0,79,110,50,32,86,80,53,0,84,104,101,111,114,97,0,0,98,103,114,48,0,0,0,0,80,97,108,101,86,105,111,108,101,116,82,101,100,0,0,0,115,101,108,101,99,116,32,83,87,32,82,101,115,97,109,112,108,101,114,0,0,0,0,0,86,111,114,98,105,115,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,51,78,0,0,0,0,0,0,0,0,71,67,83,95,80,83,65,68,53,54,0,0,0,0,0,0,99,117,116,111,102,102,0,0,65,100,106,117,115,116,32,99,111,109,112,111,110,101,110,116,115,32,99,117,114,118,101,115,46,0,0,0,0,0,0,0,86,111,114,98,105,115,0,0,108,111,111,107,115,32,108,105,107,101,32,116,104,105,115,32,102,105,108,101,32,119,97,115,32,101,110,99,111,100,101,100,32,119,105,116,104,32,40,100,105,118,120,52,47,40,111,108,100,41,120,118,105,100,47,111,112,101,110,100,105,118,120,41,32,45,62,32,102,111,114,99,105,110,103,32,108,111,119,95,100,101,108,97,121,32,102,108,97,103,10,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,10,0,100,99,97,0,0,0,0,0,86,77,119,97,114,101,32,83,99,114,101,101,110,32,67,111,100,101,99,32,47,32,86,77,119,97,114,101,32,86,105,100,101,111,0,0,0,0,0,0,118,105,120,108,0,0,0,0,115,116,114,105,110,103,61,115,116,114,105,110,103,0,0,0,68,117,101,116,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,0,0,0,0,0,0,83,105,101,114,114,97,32,86,77,68,32,118,105,100,101,111,0,0,0,0,0,0,0,0,76,117,99,97,115,65,114,116,115,32,86,73,77,65,32,97,117,100,105,111,0,0,0,0,65,84,73,32,86,67,82,49,0,0,0,0,0,0,0,0,97,117,114,97,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,0,0,0,0,0,0,77,117,120,101,114,32,37,115,32,91,37,115,93,58,10,0,49,0,0,0,0,0,0,0,83,77,80,84,69,32,86,67,45,49,0,0,0,0,0,0,83,97,109,112,108,105,110,103,32,114,97,116,101,32,100,105,102,102,101,114,44,32,116,104,105,115,32,98,108,111,99,107,58,32,37,105,44,32,104,101,97,100,101,114,32,98,108,111,99,107,58,32,37,105,10,0,100,114,97,119,32,97,32,108,105,110,101,32,102,111,114,32,101,97,99,104,32,115,97,109,112,108,101,0,0,0,0,0,119,99,116,120,45,62,110,98,95,105,110,100,101,120,32,60,32,49,48,0,0,0,0,0,73,103,110,111,114,105,110,103,32,111,117,116,108,105,101,114,32,110,111,110,32,112,114,105,109,97,114,121,32,115,116,114,101,97,109,32,115,116,97,114,116,116,105,109,101,32,37,102,10,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,115,117,98,116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,0,0,0,0,0,0,99,97,109,115,116,117,100,105,111,0,0,0,0,0,0,0,87,101,98,86,84,84,32,100,101,109,117,120,101,114,0,0,87,77,86,51,32,67,111,109,112,108,101,120,32,80,114,111,102,105,108,101,32,105,115,32,110,111,116,32,102,117,108,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,86,66,76,69,32,76,111,115,115,108,101,115,115,32,67,111,100,101,99,0,0,0,0,0,87,65,86,69,32,102,105,108,101,115,32,104,97,118,101,32,101,120,97,99,116,108,121,32,111,110,101,32,115,116,114,101,97,109,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,0,0,0,0,0,0,66,101,97,109,32,83,111,102,116,119,97,114,101,32,86,66,0,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,52,58,52,32,49,48,45,98,105,116,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,52,58,52,32,49,48,45,98,105,116,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,77,83,32,52,58,52,58,52,58,52,0,0,111,114,105,103,105,110,97,116,105,111,110,95,100,97,116,101,0,0,0,0,0,0,0,0,99,112,105,97,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,77,83,32,52,58,52,58,52,58,52,0,0,85,110,99,111,109,112,114,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2302600);
/* memory initializer */ allocate([115,115,101,100,32,112,97,99,107,101,100,32,52,58,52,58,52,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,52,58,52,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,67,114,111,112,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,78,101,119,32,37,115,32,115,116,114,101,97,109,32,37,100,58,37,100,32,97,116,32,112,111,115,58,37,108,108,100,32,97,110,100,32,68,84,83,58,37,115,115,10,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,40,99,41,32,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,0,0,0,0,0,0,85,116,32,86,105,100,101,111,0,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,67,111,112,121,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,117,110,99,104,97,110,103,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,46,0,0,0,85,116,32,86,105,100,101,111,0,0,0,0,0,0,0,0,87,105,100,116,104,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,0,0,0,0,0,0,99,111,109,98,105,110,101,100,32,109,111,100,101,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,111,111,107,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,0,0,0,0,0,0,73,66,77,32,85,108,116,105,77,111,116,105,111,110,0,0,82,101,110,100,101,114,119,97,114,101,32,84,88,68,32,40,84,101,88,116,117,114,101,32,68,105,99,116,105,111,110,97,114,121,41,32,105,109,97,103,101,0,0,0,0,0,0,0,86,81,70,32,84,119,105,110,86,81,0,0,0,0,0,0,66,108,111,99,107,32,97,108,105,103,110,32,105,115,32,37,100,32,98,105,116,115,44,32,101,120,112,101,99,116,101,100,32,37,100,10,0,0,0,0,84,84,65,32,40,84,114,117,101,32,65,117,100,105,111,41,0,0,0,0,0,0,0,0,73,110,112,117,116,32,99,111,110,116,101,120,116,32,104,97,115,32,110,111,116,32,98,101,101,110,32,112,114,111,112,101,114,108,121,32,97,108,108,111,99,97,116,101,100,32,98,121,32,97,118,102,111,114,109,97,116,95,97,108,108,111,99,95,99,111,110,116,101,120,116,40,41,32,97,110,100,32,105,115,32,110,111,116,32,78,85,76,76,32,101,105,116,104,101,114,10,0,0,0,0,0,0,0,44,32,117,110,107,110,111,119,110,0,0,0,0,0,0,0,84,84,65,32,40,84,114,117,101,32,65,117,100,105,111,41,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,0,0,0,0,0,0,84,101,99,104,83,109,105,116,104,32,83,99,114,101,101,110,32,67,111,100,101,99,32,50,0,0,0,0,0,0,0,0,50,53,0,0,0,0,0,0,84,101,99,104,83,109,105,116,104,32,83,99,114,101,101,110,32,67,97,112,116,117,114,101,32,67,111,100,101,99,0,0,68,83,80,32,71,114,111,117,112,32,84,114,117,101,83,112,101,101,99,104,0,0,0,0,65,100,106,117,115,116,32,99,111,108,111,114,115,32,98,121,32,109,105,120,105,110,103,32,99,111,108,111,114,32,99,104,97,110,110,101,108,115,46,0,68,117,99,107,32,84,114,117,101,77,111,116,105,111,110,32,50,46,48,0,0,0,0,0,48,98,103,114,0,0,0,0,80,97,108,101,84,117,114,113,117,111,105,115,101,0,0,0,10,0,0,0,0,0,0,0,115,119,114,0,0,0,0,0,68,117,99,107,32,84,114,117,101,77,111,116,105,111,110,32,49,46,48,0,0,0,0,0,56,48,56,56,102,108,101,120,32,84,77,86,0,0,0,0,34,100,117,114,97,116,105,111,110,34,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,0,0,0,0,0,0,84,73,70,70,32,105,109,97,103,101,0,0,0,0,0,0,71,67,83,95,76,97,95,67,97,110,111,97,0,0,0,0,83,87,70,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,49,32,97,117,100,105,111,32,115,116,114,101,97,109,10,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,0,0,0,0,83,87,70,32,99,111,109,112,114,101,115,115,101,100,32,102,105,108,101,32,100,101,116,101,99,116,101,100,10,0,0,0,108,111,97,100,32,98,97,99,107,119,97,114,100,32,115,104,97,112,101,32,105,115,110,39,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,91,83,85,66,84,73,84,76,69,93,0,0,0,0,0,0,70,114,97,109,101,32,97,102,116,101,114,32,69,79,70,32,111,110,32,105,110,112,117,116,32,37,115,10,0,0,0,0,65,112,112,108,101,32,81,117,105,99,107,68,114,97,119,0,97,100,100,32,109,101,116,97,100,97,116,97,0,0,0,0,70,114,101,101,115,116,121,108,101,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,108,97,114,103,101,32,68,84,83,32,102,114,97,109,101,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,102,111,114,109,97,116,32,39,37,115,39,46,10,0,0,0,65,100,106,117,115,116,32,116,104,101,32,99,111,108,111,114,32,98,97,108,97,110,99,101,46,0,0,0,0,0,0,0,62,10,0,0,0,0,0,0,109,112,101,103,116,115,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,0,0,0,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,95,102,108,97,103,115,0,0,0,0,0,0,114,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,57,78,0,73,80,54,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,115,116,114,101,97,109,32,35,37,100,58,37,100,58,32,37,115,10,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,56,78,0,85,115,105,110,103,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,32,97,115,32,78,79,87,46,10,0,0,0,100,115,99,112,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,55,78,0,79,110,108,121,32,109,111,110,111,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,118,105,100,101,111,47,120,45,112,110,45,114,101,97,108,118,105,100,101,111,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,54,78,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,37,117,58,37,117,46,37,117,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,78,0,115,101,116,32,102,114,97,109,101,32,114,97,116,101,0,0,71,84,82,97,115,116,101,114,84,121,112,101,71,101,111,75,101,121,0,0,0,0,0,0,37,115,37,55,105,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,114,101,113,117,101,115,116,101,100,32,102,114,97,109,101,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,78,0,114,97,119,32,68,105,114,97,99,0,0,0,0,0,0,0,84,73,70,70,32,105,109,97,103,101,0,0,0,0,0,0,84,105,101,114,116,101,120,32,76,105,109,105,116,101,100,32,83,69,81,32,118,105,100,101,111,0,0,0,0,0,0,0,82,97,119,32,116,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,114,97,119,32,77,76,80,0,84,114,117,101,118,105,115,105,111,110,32,84,97,114,103,97,32,105,109,97,103,101,0,0,80,105,110,110,97,99,108,101,32,84,65,82,71,65,32,67,105,110,101,87,97,118,101,32,89,85,86,49,54,0,0,0,114,103,98,48,0,0,0,0,80,97,108,101,71,114,101,101,110,0,0,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,39,114,100,118,111,39,32,97,116,111,109,10,0,0,0,0,0,0,115,101,116,32,114,101,115,97,109,112,108,105,110,103,32,69,110,103,105,110,101,0,0,0,84,114,117,101,118,105,115,105,111,110,32,84,97,114,103,97,32,105,109,97,103,101,0,0,84,65,75,32,40,84,111,109,39,115,32,108,111,115,115,108,101,115,115,32,65,117,100,105,111,32,75,111,109,112,114,101,115,115,111,114,41,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,78,0,71,67,83,95,75,79,67,0,97,99,0,0,0,0,0,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,51,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,51,32,47,32,83,86,81,51,0,0,0,32,0,0,0,0,0,0,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,49,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,49,32,47,32,83,86,81,49,0,0,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,49,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,49,32,47,32,83,86,81,49,0,0,0,83,117,110,32,82,97,115,116,101,114,102,105,108,101,32,105,109,97,103,101,0,0,0,0,83,117,110,32,82,97,115,116,101,114,102,105,108,101,32,105,109,97,103,101,0,0,0,0,113,100,114,97,119,0,0,0,83,117,98,86,105,101,119,101,114,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,82,104,121,116,104,109,105,99,32,83,111,117,108,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,78,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,66,108,101,110,100,32,116,119,111,32,118,105,100,101,111,32,102,114,97,109,101,115,32,105,110,116,111,32,101,97,99,104,32,111,116,104,101,114,46,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,32,119,105,116,104,32,101,109,98,101,100,100,101,100,32,116,105,109,105,110,103,0,0,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,32,119,105,116,104,32,101,109,98,101,100,100,101,100,32,116,105,109,105,110,103,0,0,0,0,83,117,110,112,108,117,115,32,74,80,69,71,32,40,83,80,53,88,41,0,0,0,0,0,83,111,110,105,99,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,78,0,109,101,116,97,100,97,116,97,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,83,110,111,119,0,0,0,0,83,110,111,119,0,0,0,0,98,117,102,45,62,100,97,116,97,95,115,116,97,99,107,95,116,111,112,32,62,61,32,48,0,0,0,0,0,0,0,0,109,112,101,103,0,0,0,0,83,77,86,32,74,80,69,71,0,0,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,71,114,97,112,104,105,99,115,32,40,83,77,67,41,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,54,48,83,0,0,83,109,97,99,107,101,114,32,118,105,100,101,111,0,0,0,82,101,97,108,65,117,100,105,111,32,83,73,80,82,32,47,32,65,67,69,76,80,46,78,69,84,0,0,0,0,0,0,105,103,110,105,100,120,0,0,68,101,116,101,99,116,32,118,105,100,101,111,32,105,110,116,101,114,118,97,108,115,32,116,104,97,116,32,97,114,101,32,40,97,108,109,111,115,116,41,32,98,108,97,99,107,46,0,79,77,71,95,76,83,73,0,83,104,111,114,116,101,110,0,83,71,73,32,82,76,69,32,56,45,98,105,116,0,0,0,83,71,73,32,105,109,97,103,101,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,57,83,0,0,83,71,73,32,105,109,97,103,101,0,0,0,0,0,0,0,76,117,99,97,115,65,114,116,115,32,83,77,85,83,72,32,118,105,100,101,111,0,0,0,83,65,77,73,32,115,117,98,116,105,116,108,101,0,0,0,83,77,80,84,69,32,51,48,50,77,0,0,0,0,0,0,83,77,80,84,69,32,51,48,50,77,0,0,0,0,0,0,82,101,97,108,86,105,100,101,111,32,52,46,48,0,0,0,100,101,109,117,120,101,114,43,102,102,109,112,101,103,32,45,62,32,105,115,116,95,105,110,100,101,120,58,37,100,32,116,121,112,101,58,37,115,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,32,111,102,102,58,37,115,32,111,102,102,95,116,105,109,101,58,37,115,10,0,0,0,0,0,0,0,0,111,103,103,112,97,103,101,115,105,122,101,0,0,0,0,0,70,105,114,115,116,32,115,108,105,99,101,32,104,101,97,100,101,114,32,105,115,32,105,110,99,111,114,114,101,99,116,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,56,83,0,0,82,101,97,108,86,105,100,101,111,32,51,46,48,0,0,0,67,97,110,110,111,116,32,105,100,101,110,116,105,102,121,32,110,101,119,32,115,116,114,101,97,109,10,0,0,0,0,0,103,101,110,114,101,0,0,0,115,45,62,102,95,99,111,100,101,32,61,61,32,49,0,0,82,101,97,108,86,105,100,101,111,32,49,46,48,0,0,0,78,111,32,99,111,100,101,99,32,116,97,103,32,100,101,102,105,110,101,100,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,114,118,49,48,0,0,0,0,81,117,105,99,107,84,105,109,101,32,118,105,100,101,111,32,40,82,80,90,65,41,0,0,67,111,109,112,117,116,101,32,98,111,117,110,100,105,110,103,32,98,111,120,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,46,0,0,0,0,105,100,32,82,111,81,32,118,105,100,101,111,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,55,83,0,0,105,100,32,82,111,81,32,118,105,100,101,111,0,0,0,0,105,100,32,82,111,81,32,68,80,67,77,0,0,0,0,0,82,76,50,32,118,105,100,101,111,0,0,0,0,0,0,0,82,101,97,108,84,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,110,117,116,45,62,108,97,115,116,95,115,121,110,99,112,111,105,110,116,95,112,111,115,32,61,61,32,42,112,111,115,95,97,114,103,0,0,0,0,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,37,42,115,32,37,42,115,32,37,100,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,54,83,0,0,80,73,0,0,0,0,0,0,53,53,46,51,51,46,49,48,48,0,0,0,0,0,0,0,82,101,97,108,65,117,100,105,111,32,76,111,115,115,108,101,115,115,0,0,0,0,0,0,82,101,97,108,65,117,100,105,111,32,50,46,48,32,40,50,56,46,56,75,41,0,0,0,82,101,97,108,65,117,100,105,111,32,49,46,48,32,40,49,52,46,52,75,41,0,0,0,82,101,97,108,65,117,100,105,111,32,49,46,48,32,40,49,52,46,52,75,41,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,32,49,48,45,98,105,116,0,85,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,32,49,48,45,98,105,116,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,53,83,0,0,81,117,105,99,107,84,105,109,101,32,65,110,105,109,97,116,105,111,110,32,40,82,76,69,41,32,118,105,100,101,111,0,79,80,65,116,111,109,32,109,105,115,105,110,116,101,114,112,114,101,116,101,100,32,97,115,32,79,80,49,97,63,75,76,86,32,102,111,114,32,101,100,105,116,32,117,110,105,116,32,37,105,32,101,120,116,101,110,100,105,110,103,32,105,110,116,111,32,110,101,120,116,32,101,100,105,116,32,117,110,105,116,0,0,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,65,110,105,109,97,116,105,111,110,32,40,82,76,69,41,32,118,105,100,101,111,0,81,45,116,101,97,109,32,81,80,69,71,0,0,0,0,0,65,112,112,108,101,32,81,117,105,99,107,68,114,97,119,0,95,95,68,73,82,95,67,79,85,78,84,0,0,0,0,0,81,68,101,115,105,103,110,32,77,117,115,105,99,32,67,111,100,101,99,32,50,0,0,0,81,67,69,76,80,32,47,32,80,117,114,101,86,111,105,99,101,0,0,0,0,0,0,0,86,46,70,108,97,115,104,32,80,84,88,32,105,109,97,103,101,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,52,83,0,0,112,116,115,32,40,37,115,41,32,60,32,100,116,115,32,40,37,115,41,32,105,110,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,0,65,112,112,108,101,32,80,114,111,82,101,115,32,40,105,67,111,100,101,99,32,80,114,111,41,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,102,114,97,109,101,32,100,105,115,112,108,97,121,32,97,115,112,101,99,116,32,114,97,116,105,111,46,0,0,0,0,0,65,112,112,108,101,32,80,114,111,82,101,115,0,0,0,0,48,114,103,98,0,0,0,0,80,97,108,101,71,111,108,100,101,110,82,111,100,0,0,0,114,101,115,97,109,112,108,101,114,0,0,0,0,0,0,0,65,112,112,108,101,32,80,114,111,82,101,115,32,40,105,67,111,100,101,99,32,80,114,111,41,0,0,0,0,0,0,0,80,114,111,82,101,115,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,51,83,0,0,102,105,114,115,116,32,112,116,115,32,118,97,108,117,101,32,109,117,115,116,32,98,101,32,115,101,116,10,0,0,0,0,71,67,83,95,75,101,114,116,97,117,0,0,0,0,0,0,80,71,77,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,115,101,116,32,97,117,100,105,111,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,40,105,110,32,72,122,41,0,80,71,77,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,116,115,95,112,97,99,107,101,116,115,105,122,101,0,0,0,32,86,79,76,67,0,0,0,80,78,71,32,40,80,111,114,116,97,98,108,101,32,78,101,116,119,111,114,107,32,71,114,97,112,104,105,99,115,41,32,105,109,97,103,101,0,0,0,73,66,77,32,85,108,116,105,77,111,116,105,111,110,0,0,80,78,71,32,40,80,111,114,116,97,98,108,101,32,78,101,116,119,111,114,107,32,71,114,97,112,104,105,99,115,41,32,105,109,97,103,101,0,0,0,77,80,69,71,45,50,32,80,83,32,40,68,86,68,32,86,79,66,41,0,0,0,0,0,80,111,119,101,114,32,66,97,108,108,97,100,0,0,0,0,80,105,99,116,111,114,47,80,67,32,80,97,105,110,116,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,50,83,0,0,67,111,112,121,32,116,104,101,32,108,117,109,97,32,118,97,108,117,101,32,111,102,32,116,104,101,32,115,101,99,111,110,100,32,105,110,112,117,116,32,105,110,116,111,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,32,111,102,32,116,104,101,32,102,105,114,115,116,32,105,110,112,117,116,46,0,0,0,0,0,0,72,68,77,86,32,80,114,101,115,101,110,116,97,116,105,111,110,32,71,114,97,112,104,105,99,32,83,116,114,101,97,109,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,80,67,32,80,97,105,110,116,98,114,117,115,104,32,80,67,88,32,105,109,97,103,101,0,80,67,32,80,97,105,110,116,98,114,117,115,104,32,80,67,88,32,105,109,97,103,101,0,115,117,98,0,0,0,0,0,84,68,82,76,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,49,83,0,0,116,105,109,101,0,0,0,0,10,37,115,32,32,37,45,49,54,115,58,32,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,80,67,77,32,65,45,108,97,119,32,47,32,71,46,55,49,49,32,65,45,108,97,119,0,80,67,77,32,115,105,103,110,101,100,32,49,54,124,50,48,124,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,102,111,114,32,68,86,68,32,109,101,100,105,97,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,124,50,48,124,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,102,111,114,32,66,108,117,45,114,97,121,32,109,101,100,105,97,0,0,0,0,80,65,77,32,40,80,111,114,116,97,98,108,101,32,65,110,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,86,105,100,101,111,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,80,84,83,32,37,108,108,100,44,32,110,101,120,116,58,37,108,108,100,32,105,110,118,97,108,105,100,32,100,114,111,112,112,105,110,103,32,115,116,58,37,100,10,0,0,0,0,0,80,105,99,107,32,111,110,101,32,99,111,110,116,105,110,117,111,117,115,32,115,101,99,116,105,111,110,32,102,114,111,109,32,116,104,101,32,105,110,112,117,116,44,32,100,114,111,112,32,116,104,101,32,114,101,115,116,46,0,0,0,0,0,0,77,80,52,32,40,77,80,69,71,45,52,32,80,97,114,116,32,49,52,41,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,103,110,114,101,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,55,83,0,0,98,117,102,102,101,114,115,105,110,107,0,0,0,0,0,0,115,116,114,101,97,109,32,37,100,44,32,116,105,109,101,115,99,97,108,101,32,110,111,116,32,115,101,116,10,0,0,0,79,80,68,65,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,54,83,0,0,35,104,97,115,104,58,32,37,115,10,0,0,0,0,0,0,109,97,116,114,111,115,107,97,32,97,117,100,105,111,32,109,117,120,101,114,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,53,83,0,0,67,111,114,114,117,112,116,32,115,105,112,114,32,82,77,45,115,116,121,108,101,32,97,117,100,105,111,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,0,0,0,0,76,69,73,84,67,72,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,52,83,0,0,83,116,114,101,97,109,77,117,120,67,111,110,102,105,103,32,105,110,116,101,114,118,97,108,46,0,0,0,0,0,0,0,114,101,116,32,62,61,32,48,0,0,0,0,0,0,0,0,98,103,114,97,54,52,108,101,0,0,0,0,0,0,0,0,72,82,69,83,0,0,0,0,82,101,97,100,32,102,114,111,109,32,97,32,109,111,118,105,101,32,115,111,117,114,99,101,46,0,0,0,0,0,0,0,79,114,99,104,105,100,0,0,78,117,112,112,101,108,86,105,100,101,111,47,82,84,74,80,69,71,0,0,0,0,0,0,114,101,115,97,109,112,108,101,95,99,117,116,111,102,102,0,78,101,108,108,121,109,111,115,101,114,32,65,115,97,111,0,78,101,108,108,121,109,111,115,101,114,32,65,115,97,111,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,51,83,0,0,77,111,98,111,116,105,120,32,77,120,80,69,71,32,118,105,100,101,111,0,0,0,0,0,71,67,83,95,75,97,110,100,97,119,97,108,97,0,0,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,116,105,111,110,32,86,105,100,101,111,32,67,111,109,112,114,101,115,115,111,114,32,49,0,0,0,0,0,0,77,105,99,114,111,115,111,102,116,32,86,105,100,101,111,45,49,0,0,0,0,0,0,0,77,105,99,114,111,115,111,102,116,32,86,105,100,101,111,32,49,0,0,0,0,0,0,0,97,114,0,0,0,0,0,0,104,0,0,0,0,0,0,0,77,83,32,69,120,112,114,101,115,115,105,111,110,32,69,110,99,111,100,101,114,32,83,99,114,101,101,110,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,105,109,103,50,101,110,99,46,99,0,0,0,77,83,32,65,84,67,32,83,99,114,101,101,110,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,50,83,0,0,117,108,116,105,0,0,0,0,77,83,32,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,86,57,32,83,99,114,101,101,110,0,0,0,0,0,0,0,0,65,116,32,108,101,97,115,116,32,111,110,101,32,111,117,116,112,117,116,32,102,105,108,101,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,66,97,108,108,97,100,0,0,115,101,116,32,112,97,116,116,101,114,110,32,116,121,112,101,0,0,0,0,0,0,0,0,80,97,115,115,32,111,110,32,116,104,101,32,105,110,112,117,116,32,116,111,32,78,32,118,105,100,101,111,32,111,117,116,112,117,116,115,46,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,58,32,101,120,112,101,99,116,101,100,32,37,100,32,103,111,116,32,37,100,10,0,0,0,0,0,0,0,0,77,83,32,83,99,114,101,101,110,32,49,0,0,0,0,0,78,101,120,116,32,108,105,110,101,32,105,115,32,98,101,121,111,110,100,32,112,105,99,116,117,114,101,32,98,111,117,110,100,115,32,40,37,100,32,98,121,116,101,115,32,108,101,102,116,41,10,0,0,0,0,0,77,105,99,114,111,115,111,102,116,32,82,76,69,0,0,0,115,45,62,102,108,105,112,102,108,111,112,95,114,111,117,110,100,105,110,103,61,61,48,0,112,103,109,0,0,0,0,0,99,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,116,97,100,97,116,97,32,116,97,103,32,37,115,33,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,49,83,0,0,115,101,116,32,116,104,101,32,114,101,99,111,114,100,105,110,103,32,116,105,109,101,115,116,97,109,112,32,40,39,110,111,119,39,32,116,111,32,115,101,116,32,116,104,101,32,99,117,114,114,101,110,116,32,116,105,109,101,41,0,0,0,0,0,77,80,76,50,32,115,117,98,116,105,116,108,101,0,0,0,37,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,48,83,0,0,116,105,116,108,101,0,0,0,70,108,97,103,115,32,99,111,109,109,111,110,32,102,111,114,32,97,108,108,32,109,112,101,103,118,105,100,101,111,45,98,97,115,101,100,32,101,110,99,111,100,101,114,115,46,0,0,109,112,101,103,116,115,95,102,108,97,103,115,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,57,83,0,0,115,107,105,112,112,105,110,103,32,37,100,32,115,101,103,109,101,110,116,115,32,97,104,101,97,100,44,32,101,120,112,105,114,101,100,32,102,114,111,109,32,112,108,97,121,108,105,115,116,115,10,0,0,0,0,0,112,105,99,45,62,102,46,100,97,116,97,91,48,93,0,0,108,105,118,101,0,0,0,0,68,84,83,32,37,108,108,100,44,32,110,101,120,116,58,37,108,108,100,32,115,116,58,37,100,32,105,110,118,97,108,105,100,32,100,114,111,112,112,105,110,103,10,0,0,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,77,80,50,32,102,105,120,101,100,32,112,111,105,110,116,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,56,83,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,97,117,116,104,111,114,0,0,105,110,118,97,108,105,100,32,116,114,97,99,107,32,116,121,112,101,32,37,120,10,0,0,83,101,116,32,80,84,83,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,118,105,100,101,111,32,102,114,97,109,101,46,0,0,0,0,0,105,103,110,111,114,101,32,108,111,111,112,32,115,101,116,116,105,110,103,32,40,110,101,116,115,99,97,112,101,32,101,120,116,101,110,115,105,111,110,41,0,0,0,0,0,0,0,0,71,73,70,32,109,117,120,101,114,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,55,83,0,0,77,80,49,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,49,41,0,0,0,0,0,0,0,0,80,97,99,107,101,116,115,32,97,114,101,32,110,111,116,32,105,110,32,116,104,101,32,112,114,111,112,101,114,32,111,114,100,101,114,32,119,105,116,104,32,114,101,115,112,101,99,116,32,116,111,32,68,84,83,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,54,83,0,0,77,80,49,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,49,41,0,0,0,0,0,0,0,0,107,101,121,102,114,97,109,101,115,0,0,0,0,0,0,0,116,105,109,101,95,105,110,99,114,32,62,61,32,48,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,53,83,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,115,117,98,115,116,114,105,110,103,58,32,34,37,115,34,10,0,0,0,0,0,0,84,105,109,101,98,97,115,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,52,83,0,0,108,105,98,97,118,102,111,114,109,97,116,47,100,118,46,99,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,109,98,95,110,117,109,32,105,110,32,118,105,100,101,111,32,112,97,99,107,101,116,32,40,37,100,32,37,100,41,32,10,0,0,0,0,0,0,0,0,98,103,114,97,54,52,98,101,0,0,0,0,0,0,0,0,79,114,97,110,103,101,82,101,100,0,0,0,0,0,0,0,115,101,116,32,99,117,116,111,102,102,32,102,114,101,113,117,101,110,99,121,32,114,97,116,105,111,0,0,0,0,0,0,49,46,48,0,0,0,0,0,115,45,62,112,105,99,116,117,114,101,95,115,116,114,117,99,116,117,114,101,32,61,61,32,51,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,51,83,0,0,71,67,83,95,75,97,108,105,97,110,112,117,114,0,0,0,115,101,116,32,116,104,101,32,103,114,111,117,112,32,111,102,32,112,105,99,116,117,114,101,32,40,71,79,80,41,32,115,105,122,101,0,0,0,0,0,113,0,0,0,0,0,0,0,77,80,69,71,45,49,32,118,105,100,101,111,0,0,0,0,84,101,99,104,83,109,105,116,104,32,83,99,114,101,101,110,32,67,97,112,116,117,114,101,32,67,111,100,101,99,0,0,70,111,108,107,108,111,114,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,50,83,0,0,105,100,102,0,0,0,0,0,77,117,115,101,112,97,99,107,32,83,86,56,0,0,0,0,77,117,115,101,112,97,99,107,32,83,86,55,0,0,0,0,51,71,80,80,32,84,105,109,101,100,32,84,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,51,71,80,80,32,84,105,109,101,100,32,84,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,77,111,116,105,111,110,32,80,105,120,101,108,115,32,118,105,100,101,111,0,0,0,0,0,65,109,101,114,105,99,97,110,32,76,97,115,101,114,32,71,97,109,101,115,32,77,77,32,86,105,100,101,111,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,49,83,0,0,116,105,109,101,115,116,97,109,112,0,0,0,0,0,0,0,77,76,80,32,40,77,101,114,105,100,105,97,110,32,76,111,115,115,108,101,115,115,32,80,97,99,107,105,110,103,41,0,109,97,106,111,114,32,115,121,110,99,32,105,110,102,111,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,8,10,11,12,13,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,100,120,49,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,48,83,0,0,98,101,115,116,95,97,115,116,45,62,114,101,109,97,105,110,105,110,103,32,60,61,32,98,101,115,116,95,97,115,116,45,62,112,97,99,107,101,116,95,115,105,122,101,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,117,46,99,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,108,111,111,112,101,110,100,32,118,97,108,117,101,10,0,0,101,114,114,111,114,32,117,115,105,110,103,32,101,120,116,101,114,110,97,108,32,104,117,102,102,109,97,110,32,116,97,98,108,101,44,32,115,119,105,116,99,104,105,110,103,32,98,97,99,107,32,116,111,32,105,110,116,101,114,110,97,108,10,0,65,112,112,108,101,32,77,74,80,69,71,45,66,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,57,83,0,0,77,105,109,105,99,0,0,0,77,105,99,114,111,68,86,68,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,116,105,109,101,115,116,97,109,112,32,100,105,115,99,111,110,116,105,110,117,105,116,121,32,37,108,108,100,44,32,110,101,119,32,111,102,102,115,101,116,61,32,37,108,108,100,10,0,105,110,118,97,108,105,100,32,112,97,100,115,105,122,101,32,37,100,32,97,116,58,37,108,108,100,10,0,0,0,0,0,86,111,120,119,97,114,101,32,77,101,116,97,83,111,117,110,100,0,0,0,0,0,0,0,83,111,110,121,32,80,108,97,121,83,116,97,116,105,111,110,32,77,68,69,67,32,40,77,111,116,105,111,110,32,68,69,67,111,100,101,114,41,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,56,83,0,0,97,117,116,104,0,0,0,0,77,65,67,69,32,40,77,97,99,105,110,116,111,115,104,32,65,117,100,105,111,32,67,111,109,112,114,101,115,115,105,111,110,47,69,120,112,97,110,115,105,111,110,41,32,51,58,49,0,0,0,0,0,0,0,0,115,45,62,109,97,120,98,105,116,115,32,62,61,32,57,32,38,38,32,115,45,62,109,97,120,98,105,116,115,32,60,61,32,49,50,0,0,0,0,0,66,117,102,102,101,114,32,105,110,112,117,116,32,105,109,97,103,101,115,32,97,110,100,32,115,101,110,100,32,116,104,101,109,32,119,104,101,110,32,116,104,101,121,32,97,114,101,32,114,101,113,117,101,115,116,101,100,46,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,112,99,95,116,121,112,101,32,61,61,32,70,70,95,76,80,67,95,84,89,80,69,95,67,72,79,76,69,83,75,89,32,124,124,32,108,112,99,95,116,121,112,101,32,61,61,32,70,70,95,76,80,67,95,84,89,80,69,95,76,69,86,73,78,83,79,78,0,0,0,0,83,121,110,99,32,108,101,118,101,108,32,37,117,10,0,0,76,79,67,79,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,55,83,0,0,73,68,51,118,50,46,37,100,32,116,97,103,32,115,107,105,112,112,101,100,44,32,99,97,110,110,111,116,32,104,97,110,100,108,101,32,37,115,10,0,76,111,115,115,108,101,115,115,32,74,80,69,71,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,90,76,73,66,0,0,0,0,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,77,83,90,72,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,76,97,103,97,114,105,116,104,32,108,111,115,115,108,101,115,115,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,54,83,0,0,75,97,114,108,32,77,111,114,116,111,110,39,115,32,118,105,100,101,111,32,99,111,100,101,99,0,0,0,0,0,0,0,108,97,118,102,105,46,115,105,108,101,110,99,101,95,101,110,100,0,0,0,0,0,0,0,75,101,103,97,32,71,97,109,101,32,86,105,100,101,111,0,66,105,116,109,97,112,32,66,114,111,116,104,101,114,115,32,74,86,32,118,105,100,101,111,0,0,0,0,0,0,0,0,74,80,69,71,45,76,83,0,111,118,101,114,115,105,122,101,32,105,109,97,103,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,83,121,110,116,97,120,32,101,114,114,111,114,32,110,101,97,114,32,34,37,46,56,115,34,10,0,0,0,0,0,0,0,83,101,116,32,116,105,109,101,98,97,115,101,32,102,111,114,32,116,104,101,32,118,105,100,101,111,32,111,117,116,112,117,116,32,108,105,110,107,46,0,67,104,97,110,110,101,108,32,109,97,112,32,100,101,115,99,114,105,98,101,115,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,46,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,53,83,0,0,74,80,69,71,32,50,48,48,48,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,113,117,97,110,116,105,122,97,116,105,111,110,32,102,111,114,109,97,116,10,0,0,0,0,115,111,102,116,45,107,110,101,101,0,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,74,65,67,79,115,117,98,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,74,80,69,71,32,50,48,48,48,0,0,0,0,0,0,0,97,114,101,115,97,109,112,108,101,95,115,119,114,95,111,112,116,115,0,0,0,0,0,0,65,112,112,108,121,32,97,32,108,111,119,45,112,97,115,115,32,102,105,108,116,101,114,32,119,105,116,104,32,51,100,66,32,112,111,105,110,116,32,102,114,101,113,117,101,110,99,121,46,0,0,0,0,0,0,0,114,103,98,97,54,52,108,101,0,0,0,0,0,0,0,0,79,114,97,110,103,101,0,0,99,117,116,111,102,102,0,0,122,101,114,111,115,32,33,61,32,110,115,97,109,112,108,101,115,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,69,114,114,111,114,32,119,104,105,108,101,32,105,110,105,116,105,97,108,105,122,105,110,103,32,99,117,115,116,111,109,32,118,108,99,32,116,97,98,108,101,33,10,0,0,0,0,0,116,49,45,116,50,0,0,0,71,67,83,95,74,65,68,54,57,0,0,0,0,0,0,0,70,108,97,116,32,102,97,99,116,111,114,58,32,37,102,10,0,0,0,0,0,0,0,0,103,0,0,0,0,0,0,0,83,0,0,0,0,0,0,0,32,65,80,0,0,0,0,0,73,110,116,101,114,112,108,97,121,32,77,86,69,32,118,105,100,101,111,0,0,0,0,0,83,116,114,101,116,99,104,105,110,103,32,97,117,100,105,111,32,102,105,102,111,32,102,97,105,108,101,100,44,32,100,105,115,99,97,114,100,101,100,32,37,100,32,115,97,109,112,108,101,115,10,0,0,0,0,0,66,97,100,32,109,97,114,107,101,114,10,0,0,0,0,0,116,115,99,99,0,0,0,0,83,97,109,98,97], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2312840);
/* memory initializer */ allocate([80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,111,117,116,108,105,110,107,45,62,115,97,109,112,108,101,95,114,97,116,101,32,61,61,32,111,117,116,95,114,97,116,101,0,0,0,0,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,86,105,100,101,111,32,73,110,116,101,114,97,99,116,105,118,101,32,53,0,115,101,116,32,100,101,99,97,121,0,0,0,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,86,105,100,101,111,32,73,110,116,101,114,97,99,116,105,118,101,32,52,0,111,117,116,115,97,109,112,108,101,115,114,101,102,45,62,115,97,109,112,108,101,95,114,97,116,101,32,61,61,32,111,117,116,108,105,110,107,45,62,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,51,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,50,0,0,0,108,111,110,103,101,115,116,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,49,83,0,0,115,99,97,108,101,0,0,0,100,101,115,99,0,0,0,0,105,110,112,117,116,115,0,0,73,77,67,32,40,73,110,116,101,108,32,77,117,115,105,99,32,67,111,100,101,114,41,0,115,97,109,112,108,101,95,114,97,116,101,115,0,0,0,0,83,101,110,100,32,99,111,109,109,97,110,100,115,32,116,111,32,102,105,108,116,101,114,115,46,0,0,0,0,0,0,0,73,70,70,0,0,0,0,0,105,100,32,81,117,97,107,101,32,73,73,32,67,73,78,32,118,105,100,101,111,0,0,0,37,115,32,32,37,45,49,54,115,58,32,0,0,0,0,0,72,117,102,102,121,117,118,32,47,32,72,117,102,102,89,85,86,0,0,0,0,0,0,0,115,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,48,83,0,0,72,117,102,102,121,117,118,32,47,32,72,117,102,102,89,85,86,0,0,0,0,0,0,0,69,114,114,111,114,32,98,117,105,108,100,105,110,103,32,116,114,101,101,10,0,0,0,0,115,101,116,32,115,105,103,110,97,108,32,105,110,112,117,116,32,103,97,105,110,0,0,0,72,78,77,32,52,32,118,105,100,101,111,0,0,0,0,0,83,107,105,112,112,101,100,32,80,82,69,70,73,88,32,83,69,73,32,37,100,10,0,0,79,117,116,112,117,116,32,102,114,97,109,101,32,119,105,116,104,32,80,79,67,32,37,100,46,10,0,0,0,0,0,0,124,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,57,83,0,0,84,111,111,32,109,97,110,121,32,114,101,102,115,32,105,110,32,97,32,115,104,111,114,116,32,116,101,114,109,32,82,80,83,46,10,0,0,0,0,0,71,101,110,101,114,97,116,101,32,83,77,80,84,69,32,99,111,108,111,114,32,98,97,114,115,46,0,0,0,0,0,0,73,110,116,101,114,32,115,116,114,101,97,109,32,116,105,109,101,115,116,97,109,112,32,100,105,115,99,111,110,116,105,110,117,105,116,121,32,37,108,108,100,44,32,110,101,119,32,111,102,102,115,101,116,61,32,37,108,108,100,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,56,83,0,0,115,101,116,32,109,97,120,32,105,116,101,114,97,116,105,111,110,115,32,110,117,109,98,101,114,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,72,69,86,67,32,40,72,105,103,104,32,69,102,102,105,99,105,101,110,99,121,32,86,105,100,101,111,32,67,111,100,105,110,103,41,0,0,0,0,0,98,66,115,83,0,0,0,0,98,105,116,95,100,101,112,116,104,60,61,56,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,55,83,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,105,100,44,32,97,115,115,117,109,105,110,103,32,112,97,100,100,105,110,103,10,0,0,0,0,0,102,0,0,0,0,0,0,0,115,101,110,100,32,111,110,101,32,102,114,97,109,101,32,102,111,114,32,101,97,99,104,32,102,105,101,108,100,44,32,98,117,116,32,115,107,105,112,32,115,112,97,116,105,97,108,32,105,110,116,101,114,108,97,99,105,110,103,32,99,104,101,99,107,0,0,0,0,0,0,0,111,110,108,121,32,100,101,105,110,116,101,114,108,97,99,101,32,102,114,97,109,101,115,32,109,97,114,107,101,100,32,97,115,32,105,110,116,101,114,108,97,99,101,100,0,0,0,0,98,105,116,95,100,101,112,116,104,60,61,56,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,54,83,0,0,83,69,73,32,116,121,112,101,32,37,100,32,115,105,122,101,32,37,100,32,116,114,117,110,99,97,116,101,100,32,97,116,32,37,100,10,0,0,0,0,116,98,0,0,0,0,0,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,108,101,110,32,60,61,32,51,50,0,0,0,0,0,0,0,108,97,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,53,83,0,0,99,104,114,111,109,97,95,102,111,114,109,97,116,95,105,100,99,32,37,117,0,0,0,0,114,111,116,97,116,101,32,99,108,111,99,107,119,105,115,101,32,119,105,116,104,32,118,101,114,116,105,99,97,108,32,102,108,105,112,0,0,0,0,0,99,111,109,102,111,114,116,110,111,105,115,101,0,0,0,0,112,97,100,100,105,110,103,0,103,114,97,121,32,99,104,114,111,109,97,10,0,0,0,0,99,111,109,102,111,114,116,110,111,105,115,101,0,0,0,0,98,111,116,116,111,109,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,52,83,0,0,83,101,108,101,99,116,32,97,117,100,105,111,32,102,114,97,109,101,115,32,116,111,32,112,97,115,115,32,105,110,32,111,117,116,112,117,116,46,0,0,109,97,114,107,32,97,115,32,112,114,111,103,114,101,115,115,105,118,101,0,0,0,0,0,114,103,98,97,54,52,98,101,0,0,0,0,0,0,0,0,79,108,105,118,101,68,114,97,98,0,0,0,0,0,0,0,101,110,97,98,108,101,32,108,105,110,101,97,114,32,105,110,116,101,114,112,111,108,97,116,105,111,110,0,0,0,0,0,108,101,102,116,32,98,108,111,99,107,32,117,110,97,118,97,105,108,97,98,108,101,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,105,110,116,114,97,52,120,52,32,109,111,100,101,32,37,100,32,97,116,32,37,100,32,37,100,10,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,51,83,0,0,99,108,108,99,0,0,0,0,71,67,83,95,74,97,109,97,105,99,97,95,49,56,55,53,0,0,0,0,0,0,0,0,72,46,50,54,49,0,0,0,80,67,77,32,99,104,97,110,110,101,108,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,115,119,115,95,102,108,97,103,115,0,0,0,0,0,0,0,116,105,109,101,95,98,97,115,101,0,0,0,0,0,0,0,72,46,50,54,49,0,0,0,66,0,0,0,0,0,0,0,71,83,77,0,0,0,0,0,86,68,80,65,85,32,100,101,99,111,100,105,110,103,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,118,105,100,101,111,32,99,111,108,111,114,115,112,97,99,101,46,10,0,0,0,0,0,0,111,117,116,95,104,0,0,0,83,110,111,119,0,0,0,0,115,101,116,32,116,104,101,32,105,110,112,117,116,32,116,115,32,115,99,97,108,101,0,0,71,73,70,32,40,71,114,97,112,104,105,99,115,32,73,110,116,101,114,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,84,97,110,103,111,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,50,83,0,0,71,73,70,32,40,71,114,97,112,104,105,99,115,32,73,110,116,101,114,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,112,115,110,114,95,37,99,58,37,48,46,50,102,32,0,0,71,46,55,50,57,0,0,0,71,46,55,50,54,32,65,68,80,67,77,0,0,0,0,0,71,46,55,50,51,46,49,0,115,101,116,32,116,104,101,32,120,32,111,102,102,115,101,116,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,116,104,101,32,105,110,112,117,116,32,105,109,97,103,101,32,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,0,71,46,55,50,50,32,65,68,80,67,77,0,0,0,0,0,99,108,106,114,0,0,0,0,71,46,55,50,50,32,65,68,80,67,77,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,49,83,0,0,32,32,32,32,32,32,32,35,37,100,58,32,37,115,32,40,37,115,41,10,0,0,0,0,71,111,50,77,101,101,116,105,110,103,0,0,0,0,0,0,70,111,114,119,97,114,100,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,119,0,0,0,0,0,0,0,70,114,97,112,115,0,0,0,83,101,116,32,112,101,114,109,105,115,115,105,111,110,115,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,97,117,100,105,111,32,102,114,97,109,101,46,0,0,0,0,0,37,115,77,101,116,97,100,97,116,97,58,10,0,0,0,0,70,76,86,32,47,32,83,111,114,101,110,115,111,110,32,83,112,97,114,107,32,47,32,83,111,114,101,110,115,111,110,32,72,46,50,54,51,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,66,97,100,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,10,0,0,0,0,0,65,117,116,111,100,101,115,107,32,65,110,105,109,97,116,111,114,32,70,108,105,99,32,118,105,100,101,111,0,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,48,83,0,0,97,118,101,114,97,103,101,100,32,110,111,105,115,101,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,86,101,114,115,105,111,110,32,50,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,112,105,120,101,108,32,102,111,114,109,97,116,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,118,49,0,0,0,110,101,97,114,101,115,116,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,57,83,0,0,0,99,105,110,101,112,97,107,0,70,76,65,67,32,40,70,114,101,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,0,110,101,103,97,116,101,95,97,108,112,104,97,0,0,0,0,70,76,65,67,32,40,70,114,101,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,0,99,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,32,111,102,32,115,105,122,101,32,37,116,100,10,0,99,105,110,101,112,97,107,0,67,111,114,114,101,99,116,105,110,103,32,115,116,97,114,116,32,116,105,109,101,32,98,121,32,37,108,108,100,10,0,0,115,101,108,101,99,116,32,99,104,114,111,109,97,32,109,111,100,101,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,109,111,100,101,58,32,37,100,10,0,0,0,0,0,0,0,77,105,114,105,108,108,105,115,32,70,73,67,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,56,83,0,0,0,87,97,118,101,32,115,121,110,116,104,101,115,105,115,32,112,115,101,117,100,111,45,99,111,100,101,99,0,0,0,0,0,66,111,116,116,111,109,32,70,105,101,108,100,32,70,105,114,115,116,0,0,0,0,0,0,116,105,116,108,0,0,0,0,67,111,110,99,97,116,101,110,97,116,101,100,32,72,46,50,54,52,32,111,114,32,72,46,50,54,53,32,109,105,103,104,116,32,110,111,116,32,112,108,97,121,32,99,111,114,114,101,99,116,108,121,46,10,0,0,84,101,109,112,111,114,97,108,108,121,32,105,110,116,101,114,108,101,97,118,101,32,118,105,100,101,111,32,105,110,112,117,116,115,46,0,0,0,0,0,116,98,0,0,0,0,0,0,70,70,109,112,101,103,32,118,105,100,101,111,32,99,111,100,101,99,32,35,49,0,0,0,70,70,109,112,101,103,32,118,105,100,101,111,32,99,111,100,101,99,32,35,49,0,0,0,99,111,108,111,114,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,55,83,0,0,0,70,97,105,108,101,100,32,116,111,32,117,110,99,111,109,112,114,101,115,115,32,116,97,103,58,32,37,100,10,0,0,0,99,100,120,108,0,0,0,0,86,105,101,119,115,32,97,114,101,32,105,110,116,101,114,108,101,97,118,101,100,32,98,121,32,108,105,110,101,115,0,0,79,112,101,110,69,88,82,32,105,109,97,103,101,0,0,0,69,86,82,67,32,40,69,110,104,97,110,99,101,100,32,86,97,114,105,97,98,108,101,32,82,97,116,101,32,67,111,100,101,99,41,0,0,0,0,0,69,115,99,97,112,101,32,49,51,48,0,0,0,0,0,0,69,115,99,97,112,101,32,49,50,52,0,0,0,0,0,0,114,111,117,110,100,32,116,111,119,97,114,100,115,32,48,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,81,73,32,86,105,100,101,111,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,71,86,32,118,105,100,101,111,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,54,83,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,71,81,32,118,105,100,101,111,0,0,0,0,0,0,0,112,114,111,103,114,101,115,115,105,118,101,32,102,114,97,109,101,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,97,100,99,111,119,32,86,105,100,101,111,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,67,77,86,32,118,105,100,101,111,0,0,0,0,0,0,0,99,100,103,114,97,112,104,105,99,115,0,0,0,0,0,0,108,105,98,97,118,117,116,105,108,47,117,116,105,108,115,46,99,0,0,0,0,0,0,0,65,84,83,67,32,65,47,53,50,32,69,45,65,67,45,51,0,0,0,0,0,0,0,0,112,97,108,56,0,0,0,0,67,79,77,66,83,58,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,83,0,0,0,68,120,116,111,114,121,0,0,37,72,37,77,37,83,0,0,70,101,101,98,108,101,32,70,105,108,101,115,47,83,99,117,109,109,86,77,32,68,88,65,0,0,0,0,0,0,0,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,37,100,0,0,0,0,0,0,27,91,52,56,59,53,59,37,100,109,27,91,51,56,59,53,59,37,100,109,37,115,27,91,48,109,0,0,0,0,0,0,68,86,68,32,115,117,98,116,105,116,108,101,115,0,0,0,83,72,65,51,56,52,0,0,102,97,100,101,45,111,117,116,0,0,0,0,0,0,0,0,68,86,68,32,115,117,98,116,105,116,108,101,115,0,0,0,97,116,97,110,0,0,0,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,68,101,109,117,120,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,76,70,69,0,0,0,0,0,68,86,66,32,115,117,98,116,105,116,108,101,115,0,0,0,115,101,116,32,117,32,112,108,97,110,101,0,0,0,0,0,68,86,66,32,115,117,98,116,105,116,108,101,115,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,83,0,0,0,79,114,100,101,114,101,100,32,100,105,116,104,101,114,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,102,117,108,108,32,99,104,114,111,109,97,32,105,110,116,101,114,112,111,108,97,116,105,111,110,32,102,111,114,32,100,101,115,116,105,110,97,116,105,111,110,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,102,105,114,115,116,67,104,114,83,114,99,89,32,62,61,32,108,97,115,116,73,110,67,104,114,66,117,102,32,45,32,118,67,104,114,66,117,102,83,105,122,101,32,43,32,49,0,0,97,118,101,114,97,103,105,110,103,32,97,114,101,97,0,0,99,97,118,115,0,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,105,110,32,99,109,112,32,102,117,110,99,116,105,111,110,32,115,101,108,101,99,116,105,111,110,10,0,0,0,0,0,0,0,117,99,104,0,0,0,0,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,32,118,105,100,101,111,0,0,0,0,0,0,0,68,80,88,32,40,68,105,103,105,116,97,108,32,80,105,99,116,117,114,101,32,69,120,99,104,97,110,103,101,41,32,105,109,97,103,101,0,0,0,0,110,118,50,48,98,101,0,0,79,108,105,118,101,0,0,0,108,105,110,101,97,114,95,105,110,116,101,114,112,0,0,0,68,80,88,32,40,68,105,103,105,116,97,108,32,80,105,99,116,117,114,101,32,69,120,99,104,97,110,103,101,41,32,105,109,97,103,101,0,0,0,0,119,0,0,0,0,0,0,0,115,45,62,113,117,97,114,116,101,114,95,115,97,109,112,108,101,0,0,0,0,0,0,0,68,80,67,77,32,73,110,116,101,114,112,108,97,121,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,83,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,92,37,49,91,49,50,51,52,93,97,38,72,37,50,88,38,37,49,91,92,125,93,37,110,0,0,0,0,0,0,0,0,71,67,83,95,73,110,100,105,97,110,95,49,57,55,53,0,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,0,0,0,0,0,0,105,110,118,97,108,105,100,32,122,101,114,111,32,98,108,111,99,107,32,115,105,122,101,32,111,102,32,37,100,32,37,100,32,37,100,10,0,0,0,0,86,67,51,47,68,78,120,72,68,0,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,115,108,105,99,101,32,98,117,102,102,101,114,10,0,0,111,110,108,121,32,115,116,101,114,101,111,32,111,114,32,109,111,110,111,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,115,101,116,32,119,105,100,116,104,32,102,111,114,32,116,104,101,32,114,101,99,116,97,110,103,117,108,97,114,32,115,101,97,114,99,104,32,97,114,101,97,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,80,67,77,32,112,97,99,107,101,116,44,32,100,97,116,97,32,104,97,115,32,115,105,122,101,32,37,100,32,98,117,116,32,97,116,32,108,101,97,115,116,32,97,32,115,105,122,101,32,111,102,32,37,100,32,119,97,115,32,101,120,112,101,99,116,101,100,10,0,0,0,0,86,67,51,47,68,78,120,72,68,0,0,0,0,0,0,0,101,120,116,114,97,100,97,116,97,95,115,105,122,101,0,0,121,117,118,52,50,50,112,49,48,0,0,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,97,120,105,115,32,67,68,82,79,77,32,88,65,0,0,0,0,98,117,102,102,101,114,0,0,80,0,0,0,0,0,0,0,99,57,51,0,0,0,0,0,115,117,114,114,111,117,110,100,95,109,105,120,108,101,118,0,115,117,114,114,111,117,110,100,95,109,105,120,108,101,118,0,78,111,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,115,112,101,99,105,102,105,101,100,46,32,84,104,101,32,101,110,99,111,100,101,114,32,119,105,108,108,32,103,117,101,115,115,32,116,104,101,32,108,97,121,111,117,116,44,32,98,117,116,32,105,116,32,109,105,103,104,116,32,98,101,32,105,110,99,111,114,114,101,99,116,46,10,0,0,0,0,0,68,101,108,97,121,101,100,32,102,114,97,109,101,115,32,115,101,101,110,46,32,82,101,101,110,97,98,108,105,110,103,32,108,111,119,32,100,101,108,97,121,32,114,101,113,117,105,114,101,115,32,97,32,99,111,100,101,99,32,102,108,117,115,104,46,10,0,0,0,0,0,0,66,66,67,32,68,105,114,97,99,32,86,67,45,50,0,0,76,116,47,82,116,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,32,91,68,82,79,80,93,0,83,116,114,101,97,109,32,109,97,121,32,104,97,118,101,32,117,110,104,97,110,100,108,101,100,32,102,101,97,116,117,114,101,115,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,83,0,0,0,69,82,82,79,82,32,58,32,110,111,32,115,117,98,98,97,110,100,32,102,111,117,110,100,32,102,111,114,32,102,114,101,113,117,101,110,99,121,32,37,100,10,0,0,0,0,0,0,65,65,67,32,101,110,99,111,100,101,114,0,0,0,0,0,115,110,111,119,0,0,0,0,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,67,108,117,98,0,0,0,0,100,101,102,97,117,108,116,0,67,104,114,111,110,111,109,97,115,116,101,114,32,68,70,65,0,0,0,0,0,0,0,0,65,117,100,105,111,32,111,112,116,105,111,110,115,58,0,0,99,102,114,97,109,101,32,105,100,32,109,105,115,109,97,116,99,104,32,37,100,32,37,100,10,0,0,0,0,0,0,0,67,97,110,110,111,116,32,104,97,110,100,108,101,32,102,111,114,109,97,116,32,37,105,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,105,103,104,116,58,32,37,100,46,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,109,97,112,32,98,105,116,32,111,114,100,101,114,10,0,0,0,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,100,97,116,97,32,97,116,32,39,37,46,56,115,39,10,0,0,0,0,0,0,68,67,65,32,40,68,84,83,32,67,111,104,101,114,101,110,116,32,65,99,111,117,115,116,105,99,115,41,0,0,0,0,73,110,118,97,108,105,100,32,86,66,77,32,116,114,101,101,59,32,98,114,111,107,101,110,32,101,120,116,114,97,100,97,116,97,63,10,0,0,0,0,110,117,109,95,118,101,99,95,99,111,101,102,102,115,32,43,32,111,102,102,115,101,116,32,60,61,32,40,115,105,122,101,111,102,40,115,45,62,99,104,97,110,110,101,108,91,99,93,46,111,117,116,41,32,47,32,115,105,122,101,111,102,40,40,115,45,62,99,104,97,110,110,101,108,91,99,93,46,111,117,116,41,91,48,93,41,41,0,79,114,100,101,114,91,37,100,93,91,37,100,93,32,37,100,32,62,32,109,97,120,32,40,37,100,41,44,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,48,0,0,0,0,0,0,0,110,101,120,116,95,98,108,111,99,107,95,108,101,110,95,98,105,116,115,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,60,47,98,62,0,0,0,0,115,107,105,112,112,105,110,103,32,117,110,115,117,112,112,111,114,116,101,100,32,99,104,117,110,107,58,32,37,115,10,0,109,105,100,47,115,105,100,101,0,0,0,0,0,0,0,0,78,111,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,116,101,114,109,115,32,109,101,116,10,0,0,0,0,0,100,101,99,111,100,101,95,102,111,114,109,97,116,56,48,32,112,114,111,98,108,101,109,58,32,100,101,115,116,95,105,110,100,101,120,32,40,37,100,41,32,101,120,99,101,101,100,101,100,32,100,101,115,116,95,115,105,122,101,32,40,37,100,41,10,0,0,0,0,0,0,0,82,71,66,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,112,114,111,102,105,108,101,32,48,10,0,102,40,37,102,41,61,37,102,32,45,62,32,121,91,37,100,93,61,37,100,10,0,0,0,86,80,32,118,101,114,115,105,111,110,58,32,37,100,10,0,67,117,114,114,101,110,116,32,70,70,109,112,101,103,32,86,111,114,98,105,115,32,101,110,99,111,100,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,50,32,99,104,97,110,110,101,108,115,46,10,0,0,0,0,0,0,0,0,32,73,110,118,97,108,105,100,32,114,101,115,105,100,117,101,32,116,121,112,101,32,119,104,105,108,101,32,114,101,115,105,100,117,101,32,100,101,99,111,100,101,63,33,32,10,0,0,73,100,32,104,101,97,100,101,114,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,68,67,65,32,40,68,84,83,32,67,111,104,101,114,101,110,116,32,65,99,111,117,115,116,105,99,115,41,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,105,109,97,103,101,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,0,0,65,117,114,97,118,105,115,105,111,110,32,65,85,82,65,0,98,114,101,110,100,101,114,95,112,105,120,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,83,0,0,0,105,116,115,115,99,97,108,101,0,0,0,0,0,0,0,0,67,97,109,83,116,117,100,105,111,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,120,32,99,114,111,112,32,97,114,101,97,32,101,120,112,114,101,115,115,105,111,110,0,0,69,110,116,114,121,32,112,111,105,110,116,58,32,37,48,56,88,10,0,0,0,0,0,0,67,80,105,65,32,118,105,100,101,111,32,102,111,114,109,97,116,0,0,0,0,0,0,0,80,114,101,100,105,99,116,105,111,110,32,109,101,116,104,111,100,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,85,116,32,86,105,100,101,111,46,10,0,0,0,0,0,68,101,99,111,100,105,110,103,32,101,114,114,111,114,10,0,44,32,37,49,46,48,102,107,32,37,115,0,0,0,0,0,84,104,105,115,32,65,86,67,111,100,101,99,67,111,110,116,101,120,116,32,119,97,115,32,97,108,108,111,99,97,116,101,100,32,102,111,114,32,37,115,44,32,98,117,116,32,37,115,32,112,97,115,115,101,100,32,116,111,32,97,118,99,111,100,101,99,95,111,112,101,110,50,40,41,10,0,0,0,0,0,67,111,111,107,32,47,32,67,111,111,107,101,114,32,47,32,71,101,99,107,111,32,40,82,101,97,108,65,117,100,105,111,32,71,50,41,0,0,0,0,115,101,116,32,116,104,101,32,114,101,100,32,103,97,105,110,32,102,111,114,32,116,104,101,32,103,114,101,101,110,32,99,104,97,110,110,101,108,0,0,100,97,116,97,95,108,101,110,103,116,104,58,32,37,100,32,102,114,97,109,101,95,108,101,110,103,116,104,58,32,37,100,32,108,97,115,116,58,32,37,100,32,116,111,116,97,108,58,32,37,100,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,116,111,107,101,110,115,58,32,37,105,10,0,116,97,98,108,101,115,58,32,37,100,32,47,32,37,100,32,99,58,37,100,32,37,100,120,37,100,32,116,58,37,100,32,37,115,37,115,37,115,37,115,10,0,0,0,0,0,0,0,84,73,70,70,32,101,110,99,111,100,101,114,0,0,0,0,115,101,116,32,103,114,101,101,110,32,109,105,100,116,111,110,101,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,54,48,78,0,0,71,101,111,103,69,108,108,105,112,115,111,105,100,71,101,111,75,101,121,0,0,0,0,0,79,108,100,32,115,116,121,108,101,32,76,90,87,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,112,106,115,32,100,101,99,111,100,101,114,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,66,0,0,0,0,0,0,0,99,98,112,95,118,108,99,61,37,100,10,0,0,0,0,0,123,92,37,42,91,94,125,93,125,37,110,0,0,0,0,0,105,110,118,97,108,105,100,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,37,100,10,0,0,0,0,0,0,0,98,109,118,95,118,105,100,101,111,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,57,78,0,0,112,97,115,115,58,52,109,118,32,99,104,97,110,103,101,100,58,37,100,10,0,0,0,0,115,112,97,116,105,97,108,95,100,101,99,111,109,112,111,115,105,116,105,111,110,95,99,111,117,110,116,32,37,100,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,115,105,122,101,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,108,101,110,103,116,104,32,116,111,111,32,108,111,110,103,10,0,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,105,103,110,111,114,105,110,103,32,105,110,118,97,108,105,100,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,40,37,105,44,32,37,105,41,45,62,40,37,117,44,32,37,117,41,44,32,98,108,111,99,107,32,115,105,122,101,32,61,32,37,117,10,0,0,0,0,0,108,97,118,102,105,46,98,98,111,120,46,119,0,0,0,0,69,82,82,79,82,32,97,116,32,77,66,32,37,100,32,37,100,10,0,0,0,0,0,0,114,97,119,100,101,99,0,0,105,115,73,0,0,0,0,0,85,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,37,88,0,0,0,0,0,0,115,101,116,32,109,97,120,32,118,97,108,117,101,32,102,111,114,32,110,111,109,105,110,97,116,111,114,32,111,114,32,100,101,110,111,109,105,110,97,116,111,114,32,105,110,32,116,104,101,32,114,97,116,105,111,0,98,109,112,0,0,0,0,0,112,97,99,107,101,116,32,116,121,112,101,32,49,53,0,0,66,105,116,114,97,116,101,32,98,121,116,101,32,109,105,115,115,105,110,103,44,32,103,117,101,115,115,105,110,103,32,98,105,116,114,97,116,101,32,102,114,111,109,32,112,97,99,107,101,116,32,115,105,122,101,46,10,0,0,0,0,0,0,0,112,114,111,120,121,0,0,0,97,112,99,115,0,0,0,0,102,114,97,109,101,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,0,0,101,114,114,111,114,44,32,119,114,111,110,103,32,115,108,105,99,101,32,99,111,117,110,116,10,0,0,0,0,0,0,0,112,103,109,121,117,118,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,10,0,0,0,0,0,83,101,116,32,105,109,97,103,101,32,114,101,115,111,108,117,116,105,111,110,32,40,105,110,32,100,111,116,115,32,112,101,114,32,109,101,116,101,114,41,0,0,0,0,0,0,0,0,100,101,109,117,120,101,114,32,45,62,32,105,115,116,95,105,110,100,101,120,58,37,100,32,116,121,112,101,58,37,115,32,110,101,120,116,95,100,116,115,58,37,115,32,110,101,120,116,95,100,116,115,95,116,105,109,101,58,37,115,32,110,101,120,116,95,112,116,115,58,37,115,32,110,101,120,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,32,111,102,102,58,37,115,32,111,102,102,95,116,105,109,101,58,37,115,10,0,0,0,0,0,73,68,65,84,32,119,105,116,104,111,117,116,32,73,72,68,82,10,0,0,0,0,0,0,79,110,108,121,32,115,104,111,119,32,102,111,114,99,101,100,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,56,78,0,0,112,99,109,95,102,54,52,98,101,0,0,0,0,0,0,0,77,97,120,105,109,117,109,32,100,117,114,97,116,105,111,110,32,111,102,32,116,104,101,32,111,117,116,112,117,116,0,0,97,114,116,105,115,116,0,0,97,98,117,102,102,101,114,115,105,110,107,0,0,0,0,0,115,101,101,107,95,112,111,105,110,116,0,0,0,0,0,0,102,108,97,103,115,0,0,0,77,88,77,0,0,0,0,0,114,101,102,45,62,98,117,102,45,62,114,101,102,99,111,117,110,116,32,62,32,48,0,0,73,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,32,115,104,111,117,108,100,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,49,54,46,10,0,0,0,102,102,95,77,80,86,95,102,114,97,109,101,95,115,116,97,114,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,66,105,116,114,97,116,101,32,37,100,32,98,112,115,10,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,55,78,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,99,111,109,112,114,101,115,115,101,100,32,116,97,103,10,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,108,117,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,0,0,32,78,66,95,83,65,77,80,76,69,83,58,37,108,108,100,32,78,66,95,67,79,78,83,85,77,69,68,95,83,65,77,80,76,69,83,58,37,108,108,100,0,0,0,0,0,0,0,49,50,56,107,0,0,0,0,49,50,56,107,0,0,0,0,109,112,51,111,110,52,102,108,111,97,116,0,0,0,0,0,109,112,51,111,110,52,0,0,109,112,118,95,102,108,97,103,115,0,0,0,0,0,0,0,61,44,59,91,10,0,0,0,105,110,116,114,97,95,118,108,99,0,0,0,0,0,0,0,82,101,115,101,114,118,101,100,0,0,0,0,0,0,0,0,98,109,112,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,32,83,67,70,73,32,86,76,67,10,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,54,78,0,0,83,117,98,115,116,114,101,97,109,32,37,100,32,112,97,114,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,74,80,69,71,45,76,83,32,116,104,97,116,32,105,115,32,110,111,116,32,60,61,32,56,32,98,105,116,115,47,99,111,109,112,111,110,101,110,116,32,111,114,32,49,54,45,98,105,116,32,103,114,97,121,0,0,115,111,102,32,111,102,102,115,58,32,48,120,37,120,10,0,101,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,118,108,99,32,116,97,98,108,101,10,0,0,0,123,92,37,99,49,125,0,0,116,98,58,37,100,47,37,100,32,45,62,32,116,98,58,37,100,47,37,100,10,0,0,0,66,85,71,33,32,85,110,107,110,111,119,110,32,105,109,97,103,101,116,121,112,101,32,105,110,32,105,109,97,103,101,32,100,101,99,111,100,101,114,46,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,114,111,98,97,98,105,108,105,116,121,32,114,117,110,32,101,110,99,111,117,110,116,101,114,101,100,46,10,0,0,0,75,77,86,67,32,112,97,108,101,116,116,101,32,116,111,111,32,108,97,114,103,101,10,0,80,114,111,103,114,101,115,115,105,111,110,32,111,114,100,101,114,32,82,80,67,76,0,0,123,92,97,110,52,125,0,0,97,102,116,101,114,32,105,110,105,116,10,0,0,0,0,0,84,105,108,101,32,100,97,116,97,32,115,105,122,101,32,105,115,32,122,101,114,111,33,10,0,0,0,0,0,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,55,10,0,80,114,111,99,101,115,115,105,110,103,32,99,111,109,109,97,110,100,32,35,37,100,32,116,97,114,103,101,116,58,37,115,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,10,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,115,105,122,101,58,32,37,100,10,0,0,119,114,111,110,103,32,116,114,97,110,115,102,111,114,109,32,115,105,122,101,33,10,0,0,65,116,116,101,109,112,116,32,116,111,32,97,112,112,108,121,32,77,111,100,101,32,51,47,52,32,116,111,32,97,110,32,73,78,84,69,82,32,99,101,108,108,33,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,53,78,0,0,73,110,118,101,114,115,101,32,113,117,97,110,116,105,122,97,116,105,111,110,32,111,102,32,99,111,101,102,102,105,99,105,101,110,116,115,32,102,97,105,108,101,100,10,0,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,115,105,122,101,32,114,101,99,101,105,118,101,100,58,32,37,117,32,45,62,32,112,97,108,101,116,116,101,32,100,97,116,97,32,111,102,102,115,101,116,58,32,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,117,102,102,121,117,118,101,110,99,46,99,0,115,45,62,98,103,114,51,50,0,0,0,0,0,0,0,0,97,118,95,109,97,108,108,111,99,122,40,41,32,102,97,105,108,101,100,10,0,0,0,0,115,112,115,95,109,97,120,95,115,117,98,95,108,97,121,101,114,115,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,78,111,32,115,116,97,114,116,32,99,111,100,101,32,105,115,32,102,111,117,110,100,46,10,0,0,0,0,0,0,0,0,98,111,116,116,111,109,95,116,111,112,0,0,0,0,0,0,77,80,69,71,45,49,32,118,105,100,101,111,0,0,0,0,110,111,32,109,109,99,111,32,104,101,114,101,10,0,0,0,112,114,101,118,95,112,116,115,0,0,0,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,115,112,115,32,99,114,111,112,112,105,110,103,44,32,111,114,105,103,105,110,97,108,32,118,97,108,117,101,115,32,97,114,101,32,108,58,37,117,32,114,58,37,117,32,116,58,37,117,32,98,58,37,117,10,0,0,0,0,0,0,0,82,70,67,32,51,51,56,57,32,99,111,109,102,111,114,116,32,110,111,105,115,101,32,103,101,110,101,114,97,116,111,114,0,0,0,0,0,0,0,0,99,111,114,114,117,112,116,101,100,32,109,97,99,114,111,98,108,111,99,107,32,37,100,32,37,100,32,40,116,111,116,97,108,95,99,111,101,102,102,61,37,100,41,10,0,0,0,0,82,70,67,32,51,51,56,57,32,99,111,109,102,111,114,116,32,110,111,105,115,101,32,103,101,110,101,114,97,116,111,114,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,52,46,99,0,0,0,0,0,0,0,67,97,110,111,112,117,115,32,76,111,115,115,108,101,115,115,32,67,111,100,101,99,0,0,83,108,105,99,101,32,109,105,115,109,97,116,99,104,32,97,116,32,77,66,58,32,37,100,10,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,100,99,32,37,100,32,97,116,32,37,100,32,37,100,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,115,101,116,32,97,108,108,32,111,117,116,112,117,116,32,102,114,97,109,101,115,32,119,114,105,116,97,98,108,101,0,0,102,108,97,103,115,0,0,0,79,110,108,121,32,109,111,110,111,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,67,105,114,114,117,115,32,76,111,103,105,99,32,65,99,99,117,80,97,107,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,52,78,0,0,73,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,98,105,116,109,97,115,107,115,58,32,82,61,37,88,44,32,71,61,37,88,44,32,66,61,37,88,10,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,99,104,117,110,107,32,116,121,112,101,58,32,37,100,10,0,0,0,0,73,110,112,117,116,32,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,115,109,97,108,108,44,32,105,110,112,117,116,32,109,117,115,116,32,98,101,32,97,116,32,108,101,97,115,116,32,49,54,120,49,54,32,33,10,0,0,0,0,0,102,104,32,61,32,37,100,44,32,102,118,32,37,100,32,32,118,115,32,32,99,104,32,61,32,37,100,44,32,99,118,32,61,32,37,100,10,0,0,0,67,105,110,101,112,97,107,32,47,32,67,86,73,68,0,0,113,117,101,117,101,45,62,97,118,97,105,108,97,98,108,101,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,115,58,32,109,105,110,61,37,100,32,109,97,120,61,37,100,10,0,0,0,0,0,0,0,98,112,115,32,110,111,116,32,102,111,117,110,100,32,105,110,32,83,84,82,69,65,77,73,78,70,79,32,111,114,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,0,99,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,70,76,65,67,72,101,97,100,101,114,77,97,114,107,101,114,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2323080);
/* memory initializer */ allocate([67,105,110,101,112,97,107,0,105,110,118,97,108,105,100,32,109,97,120,32,98,108,111,99,107,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,67,111,100,105,110,103,32,115,108,105,99,101,32,97,115,32,80,67,77,10,0,0,0,0,102,45,62,118,101,114,115,105,111,110,32,62,32,50,0,0,67,111,109,109,111,100,111,114,101,32,67,68,88,76,32,118,105,100,101,111,0,0,0,0,88,0,0,0,0,0,0,0,67,68,32,71,114,97,112,104,105,99,115,32,118,105,100,101,111,0,0,0,0,0,0,0,110,111,116,105,110,100,105,99,97,116,101,100,0,0,0,0,110,118,50,48,108,101,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,79,108,100,76,97,99,101,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,115,105,122,101,58,32,37,100,120,37,100,10,0,0,0,0,112,97,108,101,116,116,101,0,73,110,118,97,108,105,100,32,68,86,66,32,115,117,98,116,105,116,108,101,115,32,115,116,114,101,97,109,32,101,120,116,114,97,100,97,116,97,33,10,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,104,105,110,101,115,101,32,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,40,65,86,83,49,45,80,50,44,32,74,105,90,104,117,110,32,112,114,111,102,105,108,101,41,0,0,0,0,115,101,116,32,115,119,114,32,114,101,115,97,109,112,108,105,110,103,32,112,104,97,115,101,32,115,104,105,102,116,0,0,68,101,112,116,104,32,37,100,0,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,113,109,97,120,32,109,117,115,116,32,98,101,32,97,116,32,108,101,97,115,116,32,50,10,0,0,0,0,0,0,0,0,73,110,116,101,114,112,108,97,121,32,67,57,51,0,0,0,82,101,102,101,114,101,110,99,101,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,68,68,83,49,0,0,0,0,66,105,116,32,114,97,116,101,32,37,105,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,0,0,0,0,0,82,69,86,78,79,32,61,32,37,100,10,0,0,0,0,0,66,82,101,110,100,101,114,32,80,73,88,32,105,109,97,103,101,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,51,78,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,71,67,83,95,73,110,100,105,97,110,95,49,57,53,52,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,115,0,0,0,0,0,0,0,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,32,118,105,100,101,111,0,0,66,77,80,32,40,87,105,110,100,111,119,115,32,97,110,100,32,79,83,47,50,32,98,105,116,109,97,112,41,0,0,0,99,111,100,101,99,32,105,100,115,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,105,116,101,114,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,73,0,0,0,0,0,0,0,66,77,80,32,40,87,105,110,100,111,119,115,32,97,110,100,32,79,83,47,50,32,98,105,116,109,97,112,41,0,0,0,82,101,97,108,86,105,100,101,111,32,49,46,48,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,32,37,100,10,0,0,0,0,0,0,0,65,118,111,105,100,32,119,97,115,116,105,110,103,32,98,121,116,101,115,44,32,105,103,110,111,114,101,32,118,105,110,116,97,103,101,32,77,97,99,79,83,32,100,101,99,111,100,101,114,0,0,0,0,0,0,0,112,111,115,105,116,105,111,110,32,111,117,116,32,111,102,32,98,108,111,99,107,32,98,111,117,110,100,115,32,97,116,32,112,105,99,32,37,100,32,77,66,40,37,100,44,37,100,41,10,0,0,0,0,0,0,0,118,108,99,45,62,116,97,98,108,101,95,115,105,122,101,32,38,38,32,118,108,99,45,62,116,97,98,108,101,95,115,105,122,101,32,61,61,32,118,108,99,45,62,116,97,98,108,101,95,97,108,108,111,99,97,116,101,100,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,101,110,62,48,0,0,0,85,110,107,110,111,119,110,32,112,97,108,101,116,116,101,32,102,111,114,32,37,100,45,99,111,108,111,117,114,32,66,77,80,10,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,65,110,105,109,97,116,105,111,110,32,40,82,76,69,41,32,118,105,100,101,111,0,105,110,99,111,114,114,101,99,116,32,99,111,100,101,115,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,105,110,112,117,116,32,116,115,32,111,102,102,115,101,116,0,84,111,111,32,109,97,110,121,32,112,97,116,116,101,114,110,32,118,97,108,117,101,115,10,0,0,0,0,0,0,0,0,66,105,110,97,114,121,32,116,101,120,116,0,0,0,0,0,85,110,107,110,111,119,110,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,116,114,121,32,115,112,101,99,105,102,121,105,110,103,32,97,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,117,115,105,110,103,32,39,97,102,111,114,109,97,116,61,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,61,115,111,109,101,116,104,105,110,103,39,46,10,0,0,0,0,0,0,83,108,111,119,32,74,97,109,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,50,78,0,0,85,110,107,110,111,119,110,32,102,114,97,109,101,47,99,104,97,110,110,101,108,47,102,114,97,109,101,95,102,97,99,116,111,114,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,37,100,47,37,100,47,37,100,10,0,0,0,0,0,0,66,105,110,107,32,65,117,100,105,111,32,40,82,68,70,84,41,0,0,0,0,0,0,0,112,117,114,101,32,115,105,108,101,110,99,101,32,115,116,101,114,101,111,10,0,0,0,0,80,114,101,100,105,99,116,111,114,32,111,114,100,101,114,32,116,111,111,32,108,97,114,103,101,46,10,0,0,0,0,0,66,105,110,107,32,118,105,100,101,111,0,0,0,0,0,0,88,45,82,101,112,108,97,99,101,115,0,0,0,0,0,0,114,111,119,95,105,110,116,101,114,108,101,97,118,101,100,95,108,114,0,0,0,0,0,0,98,105,110,116,101,120,116,0,66,114,117,116,101,32,70,111,114,99,101,32,38,32,73,103,110,111,114,97,110,99,101,0,66,101,116,104,101,115,100,97,32,86,73,68,32,118,105,100,101,111,0,0,0,0,0,0,79,108,100,105,101,115,0,0,65,118,105,100,32,77,101,114,105,100,105,101,110,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,0,0,101,110,99,111,100,101,100,95,98,121,0,0,0,0,0,0,65,118,105,100,32,77,101,114,105,100,105,101,110,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,0,0,33,108,105,110,107,45,62,102,114,97,109,101,95,114,101,113,117,101,115,116,101,100,0,0,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,118,105,100,101,111,0,0,0,0,0,0,0,0,98,108,111,99,107,32,97,108,105,103,110,32,110,111,116,32,115,101,116,10,0,0,0,0,119,114,105,116,101,95,97,112,101,116,97,103,0,0,0,0,65,118,105,100,32,65,86,73,32,67,111,100,101,99,0,0,52,50,48,112,49,52,0,0,88,87,77,65,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,49,78,0,0,102,117,108,108,0,0,0,0,40,117,110,115,105,103,110,101,100,41,112,107,116,45,62,115,105,122,101,32,60,61,32,48,120,55,102,102,102,102,102,102,102,32,45,32,49,54,0,0,97,108,108,0,0,0,0,0,65,117,114,97,118,105,115,105,111,110,32,65,117,114,97,32,50,0,0,0,0,0,0,0,44,32,37,49,46,48,102,32,37,115,0,0,0,0,0,0,65,84,82,65,67,51,43,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,32,51,43,41,0,65,84,82,65,67,51,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,32,51,41,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,48,78,0,0,65,84,82,65,67,49,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,41,0,0,0,0,0,98,105,110,107,97,117,100,105,111,95,114,100,102,116,0,0,65,83,85,83,32,86,49,0,65,83,85,83,32,86,49,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,77,111,110,107,101,121,39,115,32,65,117,100,105,111,0,0,65,83,67,73,73,47,65,78,83,73,32,97,114,116,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,57,78,0,0,68,101,108,117,120,101,32,80,97,105,110,116,32,65,110,105,109,97,116,105,111,110,0,0,65,77,82,45,87,66,32,40,65,100,97,112,116,105,118,101,32,77,117,108,116,105,45,82,97,116,101,32,87,105,100,101,66,97,110,100,41,0,0,0,65,77,82,45,78,66,32,40,65,100,97,112,116,105,118,101,32,77,117,108,116,105,45,82,97,116,101,32,78,97,114,114,111,119,66,97,110,100,41,0,77,80,69,71,45,52,32,65,117,100,105,111,32,76,111,115,115,108,101,115,115,32,67,111,100,105,110,103,32,40,65,76,83,41,0,0,0,0,0,0,83,117,112,112,111,114,116,32,102,111,114,32,116,104,105,115,32,65,68,88,32,102,111,114,109,97,116,0,0,0,0,0,101,110,99,111,100,101,114,32,45,62,32,116,121,112,101,58,118,105,100,101,111,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,56,78,0,0,112,101,114,102,0,0,0,0,98,105,110,107,118,105,100,101,111,0,0,0,0,0,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,97,117,116,104,111,114,0,0,97,114,116,105,115,116,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,55,78,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,32,37,108,100,32,98,121,116,101,115,10,0,0,0,0,0,0,65,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,32,109,101,109,111,114,121,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,0,112,101,114,102,111,114,109,101,114,0,0,0,0,0,0,0,78,111,32,109,105,109,101,116,121,112,101,32,105,115,32,107,110,111,119,110,32,102,111,114,32,115,116,114,101,97,109,32,37,100,44,32,99,97,110,110,111,116,32,119,114,105,116,101,32,97,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,46,10,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,54,78,0,0,98,102,105,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,53,78,0,0,98,101,116,104,115,111,102,116,118,105,100,0,0,0,0,0,67,108,97,115,115,105,99,32,82,111,99,107,0,0,0,0,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,109,105,109,101,116,121,112,101,32,102,114,111,109,32,97,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,46,10,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,99,111,109,112,117,116,101,32,115,97,109,112,108,101,32,115,105,122,101,10,0,0,97,118,117,105,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,52,78,0,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,97,118,117,105,0,0,0,0,110,118,49,54,0,0,0,0,78,97,118,121,0,0,0,0,112,104,97,115,101,95,115,104,105,102,116,0,0,0,0,0,97,118,115,0,0,0,0,0,65,117,100,105,111,32,73,70,70,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,51,78,0,0,100,101,102,97,117,108,116,95,103,101,116,95,98,117,102,102,101,114,32,99,97,108,108,101,100,32,111,110,32,112,105,99,32,37,112,10,0,0,0,0,65,117,100,105,111,32,73,70,70,0,0,0,0,0,0,0,71,67,83,95,73,68,55,52,0,0,0,0,0,0,0,0,65,70,67,0,0,0,0,0,77,68,32,83,84,85,68,73,79,32,97,117,100,105,111,0,67,82,73,32,65,68,88,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,105,116,101,114,0,0,0,0,65,68,84,83,32,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,0,0,0,0,65,68,80,0,0,0,0,0,113,112,58,37,100,32,102,99,58,37,100,44,37,100,32,37,115,32,115,105,122,101,58,37,100,32,112,114,111,58,37,100,32,97,108,116,58,37,100,32,116,111,112,58,37,100,32,37,115,112,101,108,32,112,97,114,116,58,37,100,32,114,101,115,121,110,99,58,37,100,32,119,58,37,100,32,97,58,37,100,32,114,110,100,58,37,100,32,118,111,116,58,37,100,37,115,32,100,99,58,37,100,32,99,101,58,37,100,47,37,100,47,37,100,32,116,105,109,101,58,37,108,108,100,32,116,105,110,99,114,58,37,100,10,0,0,65,67,84,32,86,111,105,99,101,32,102,105,108,101,32,102,111,114,109,97,116,0,0,0,114,97,119,32,65,67,45,51,0,0,0,0,0,0,0,0,68,101,116,101,99,116,101,100,32,117,110,115,117,112,112,111,114,116,101,100,32,89,67,103,67,111,32,99,111,108,111,114,115,112,97,99,101,46,10,0,114,97,119,32,65,68,84,83,32,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,97,54,52,32,45,32,118,105,100,101,111,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,0,0,0,0,52,88,32,84,101,99,104,110,111,108,111,103,105,101,115,0,113,116,114,108,101,0,0,0,105,116,115,111,102,102,115,101,116,0,0,0,0,0,0,0,97,118,114,110,0,0,0,0,83,97,116,105,114,101,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,50,78,0,0,89,85,86,52,77,80,69,71,32,112,105,112,101,0,0,0,80,115,121,103,110,111,115,105,115,32,89,79,80,0,0,0,77,105,99,114,111,115,111,102,116,32,120,87,77,65,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,49,78,0,0,32,32,37,115,10,0,0,0,48,0,0,0,0,0,0,0,67,104,97,110,110,101,108,115,32,100,105,102,102,101,114,44,32,116,104,105,115,32,98,108,111,99,107,58,32,37,105,44,32,104,101,97,100,101,114,32,98,108,111,99,107,58,32,37,105,10,0,0,0,0,0,0,108,105,110,101,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,105,108,101,32,97,108,108,111,99,97,116,105,111,110,32,116,97,98,108,101,32,100,101,112,116,104,32,40,37,108,108,105,32,98,121,116,101,115,41,10,0,0,0,44,32,37,51,46,50,102,32,37,115,0,0,0,0,0,0,77,80,69,71,49,87,65,86,69,70,79,82,77,65,84,69,88,32,117,110,100,101,114,102,108,111,119,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,87,69,66,86,84,84,10,0,10,13,9,32,0,0,0,0,119,97,118,95,119,114,105,116,101,95,112,97,99,107,101,116,58,32,78,79,80,84,83,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,101,110,99,111,100,101,100,95,98,121,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,86,105,100,101,111,32,101,110,99,111,100,105,110,103,32,102,97,105,108,101,100,10,0,0,77,111,100,101,32,110,111,116,32,115,117,112,111,114,116,101,100,58,32,37,100,32,72,122,44,32,37,100,32,107,98,47,115,46,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,68,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,67,111,109,112,114,101,115,115,115,101,100,32,102,114,97,109,101,32,37,115,32,116,108,101,110,61,37,100,32,100,108,101,110,61,37,108,100,10,0,0,97,117,114,97,50,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,99,111,109,98,105,110,101,100,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,70,111,114,109,97,116,32,37,115,32,112,114,111,98,101,100,32,119,105,116,104,32,115,105,122,101,61,37,100,32,97,110,100,32,115,99,111,114,101,61,37,100,10,0,0,0,0,0,44,32,37,100,32,120,32,37,100,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,52,78,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,97,116,114,97,99,51,112,108,117,115,0,0,0,0,0,0,120,121,122,49,50,98,101,0,78,97,118,97,106,111,87,104,105,116,101,0,0,0,0,0,115,101,116,32,115,119,114,32,114,101,115,97,109,112,108,105,110,103,32,102,105,108,116,101,114,32,115,105,122,101,0,0,34,99,97,112,116,105,111,110,115,34,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,51,78,0,0,112,105,99,45,62,100,97,116,97,91,48,93,33,61,78,85,76,76,32,105,110,32,97,118,99,111,100,101,99,95,100,101,102,97,117,108,116,95,103,101,116,95,98,117,102,102,101,114,10,0,0,0,0,0,0,0,71,67,83,95,72,68,55,50,0,0,0,0,0,0,0,0,97,117,100,105,111,32,102,105,102,111,32,116,111,111,32,115,109,97,108,108,32,116,111,32,109,117,120,32,97,117,100,105,111,32,101,115,115,101,110,99,101,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,95,115,105,122,101,10,0,0,0,0,117,109,104,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,87,97,114,110,105,110,103,58,32,65,86,70,114,97,109,101,46,112,116,115,61,63,32,116,114,121,105,110,103,32,116,111,32,103,117,101,115,115,32,40,37,108,108,100,41,10,0,0,67,108,105,112,105,110,103,32,108,101,110,32,37,100,10,0,69,114,114,111,114,44,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,111,114,32,110,111,116,32,77,80,69,71,52,32,104,101,97,100,101,114,32,40,98,95,99,111,100,101,61,48,41,10,0,0,0,65,86,73,68,58,32,108,101,110,58,37,100,32,37,100,10,0,0,0,0,0,0,0,0,91,69,78,68,32,73,78,70,79,82,77,65,84,73,79,78,93,0,0,0,0,0,0,0,68,101,116,101,99,116,101,100,32,71,66,82,32,99,111,108,111,114,115,112,97,99,101,46,10,0,0,0,0,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,90,76,73,66,0,0,0,0,0,0,0,69,79,70,32,111,110,32,37,115,44,32,37,100,32,115,116,114,101,97,109,115,32,108,101,102,116,32,105,110,32,115,101,103,109,101,110,116,46,10,0,101,110,97,98,108,101,47,100,105,115,97,98,108,101,32,97,99,99,117,114,97,116,101,32,115,101,101,107,105,110,103,32,119,105,116,104,32,45,115,115,0,0,0,0,0,0,0,0,80,111,114,110,32,71,114,111,111,118,101,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,37,105,32,115,97,109,112,108,101,115,32,105,110,32,68,84,83,32,102,114,97,109,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,97,116,114,97,99,51,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,70,105,108,116,101,114,32,37,115,10,0,0,0,0,0,0,32,73,115,76,105,118,101,61,34,116,114,117,101,34,32,76,111,111,107,65,104,101,97,100,70,114,97,103,109,101,110,116,67,111,117,110,116,61,34,37,100,34,32,68,86,82,87,105,110,100,111,119,76,101,110,103,116,104,61,34,48,34,0,0,0,10,83,77,74,80,69,71,0,0,0,0,0,0,0,0,32,40,99,108,101,97,110,32,101,102,102,101,99,116,115,41,0,0,0,0,0,0,0,0,97,116,114,97,99,49,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,48,78,0,0,97,115,118,49,0,0,0,0,115,101,116,32,116,104,101,32,115,101,103,109,101,110,116,32,108,105,115,116,32,102,105,108,101,110,97,109,101,0,0,0,50,53,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,78,111,32,78,97,109,101,0,101,110,99,111,100,101,95,118,105,100,101,111,32,37,100,46,37,100,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,97,115,118,49,0,0,0,0,83,99,114,105,112,116,115,32,119,105,116,104,32,109,105,120,101,100,32,97,98,115,111,108,117,116,101,32,97,110,100,32,114,101,108,97,116,105,118,101,32,116,105,109,101,115,116,97,109,112,115,32,99,97,110,32,103,105,118,101,32,117,110,101,120,112,101,99,116,101,100,32,114,101,115,117,108,116,115,32,40,112,97,117,115,101,44,32,115,101,101,107,105,110,103,44,32,116,105,109,101,32,122,111,110,101,32,99,104,97,110,103,101,41,46,10,0,0,0,0,109,117,108,116,105,112,108,101,32,102,111,117,114,99,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,55,78,0,0,83,107,105,112,112,105,110,103,32,37,115,32,73,68,51,118,50,32,102,114,97,109,101,32,37,115,46,10,0,0,0,0,82,84,80,32,109,97,120,32,112,97,121,108,111,97,100,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,65,77,82,10,0,115,115,97,0,0,0,0,0,84,104,101,32,86,105,100,101,111,32,83,116,114,101,97,109,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,54,78,0,0,114,0,0,0,0,0,0,0,115,115,97,0,0,0,0,0,73,76,78,71,0,0,0,0,37,117,58,37,117,58,37,117,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,53,78,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,110,98,95,115,97,109,112,108,101,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,52,78,0,0,100,105,114,97,99,0,0,0,109,108,112,0,0,0,0,0,120,121,122,49,50,108,101,0,77,111,99,99,97,115,105,110,0,0,0,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,39,114,100,118,111,39,32,97,116,111,109,10,0,0,0,0,0,0,102,105,108,116,101,114,95,115,105,122,101,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,51,78,0,0,100,101,102,97,117,108,116,95,103,101,116,95,98,117,102,102,101,114,32,99,97,108,108,101,100,32,111,110,32,102,114,97,109,101,32,37,112,0,0,0,71,67,83,95,72,117,95,84,122,117,95,83,104,97,110,0,117,109,104,0,0,0,0,0,97,112,101,0,0,0,0,0,73,110,118,97,108,105,100,32,112,116,115,32,40,37,108,108,100,41,32,60,61,32,108,97,115,116,32,40,37,108,108,100,41,10,0,0,0,0,0,0,69,114,114,111,114,44,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,111,114,32,110,111,116,32,77,80,69,71,52,32,104,101,97,100,101,114,32,40,102,95,99,111,100,101,61,48,41,10,0,0,0,110,98,95,99,111,100,101,115,32,60,61,32,50,53,54,0,73,103,110,111,114,105,110,103,32,99,114,111,112,112,105,110,103,32,105,110,102,111,114,109,97,116,105,111,110,46,10,0,122,108,105,98,0,0,0,0,97,99,99,117,114,97,116,101,95,115,101,101,107,0,0,0,80,114,105,109,117,115,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,115,51,50,108,101,0,0,0,97,110,115,105,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,85,110,107,110,111,119,110,32,102,105,108,116,101,114,32,39,37,115,39,46,10,0,0,0,115,51,50,108,101,0,0,0,32,40,118,105,115,117,97,108,32,105,109,112,97,105,114,101,100,41,0,0,0,0,0,0,97,110,109,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,115,101,103,109,101,110,116,32,109,117,120,101,114,0,0,0,114,101,100,117,99,101,32,116,104,101,32,108,97,116,101,110,99,121,32,98,121,32,102,108,117,115,104,105,110,103,32,111,117,116,32,112,97,99,107,101,116,115,32,105,109,109,101,100,105,97,116,101,108,121,0,0,71,69,79,66,0,0,0,0,97,109,114,119,98,0,0,0,78,65,77,69,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,79,112,117,115,32,109,117,120,101,114,0,0,0,0,0,0,101,110,99,111,100,101,114,32,60,45,32,116,121,112,101,58,118,105,100,101,111,32,102,114,97,109,101,95,112,116,115,58,37,115,32,102,114,97,109,101,95,112,116,115,95,116,105,109,101,58,37,115,32,116,105,109,101,95,98,97,115,101,58,37,100,47,37,100,10,0,0,0,97,109,114,110,98,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,78,101,119,32,115,116,114,101,97,109,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,115,101,100,32,116,111,32,98,101,32,97,100,100,101,100,32,105,110,32,98,101,116,119,101,101,110,32,79,103,103,32,99,111,110,116,101,120,116,32,115,97,118,101,47,114,101,115,116,111,114,101,32,111,112,101,114,97,116,105,111,110,115,46,10,0,0,0,0,0,0,0,83,111,114,101,110,115,111,110,32,72,50,54,51,0,0,0,114,95,102,114,97,109,101,95,114,97,116,101,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,101,110,99,114,121,112,116,101,100,32,97,110,100,32,99,111,109,112,114,101,115,115,101,100,0,0,0,0,0,0,0,0,114,101,97,100,95,116,105,109,101,115,116,97,109,112,32,102,97,105,108,101,100,46,10,0,99,104,97,110,110,101,108,95,99,111,117,110,116,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,97,108,115,0,0,0,0,0,48,46,48,46,48,0,0,0,40,99,41,67,82,73,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,101,114,114,111,114,32,103,101,116,116,105,110,103,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,10,0,0,118,101,114,115,105,111,110,32,37,105,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,65,112,112,108,105,99,97,116,105,111,110,32,112,114,111,118,105,100,101,100,32,105,110,118,97,108,105,100,44,32,110,111,110,32,109,111,110,111,116,111,110,105,99,97,108,108,121,32,105,110,99,114,101,97,115,105,110,103,32,100,116,115,32,116,111,32,109,117,120,101,114,32,105,110,32,115,116,114,101,97,109,32,37,100,58,32,37,115,32,62,61,32,37,115,10,0,118,100,112,97,117,0,0,0,77,105,115,116,121,82,111,115,101,0,0,0,0,0,0,0,115,101,108,101,99,116,32,105,109,112,114,111,118,101,100,45,101,45,119,101,105,103,104,116,101,100,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,102,114,97,109,101,45,62,110,98,95,101,120,116,101,110,100,101,100,95,98,117,102,32,61,61,32,48,0,0,0,0,0,114,101,115,101,110,100,95,104,101,97,100,101,114,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,109,112,101,103,116,115,95,102,108,97,103,115,32,114,101,115,101,110,100,95,104,101,97,100,101,114,115,10,0,0,71,67,83,95,71,117,121,97,110,101,95,70,114,97,110,99,97,105,115,101,0,0,0,0,80,67,77,32,90,111,114,107,0,0,0,0,0,0,0,0,104,101,120,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,115,99,97,108,101,32,62,61,32,48,32,38,38,32,115,99,97,108,101,32,60,61,32,51,0,0,0,0,0,0,0,0,67,111,109,112,117,116,101,32,101,120,97,99,116,32,80,67,82,32,102,111,114,32,101,97,99,104,32,116,114,97,110,115,112,111,114,116,32,115,116,114,101,97,109,32,112,97,99,107,101,116,46,0,0,0,0,0,69,114,114,111,114,44,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,111,114,32,110,111,116,32,77,80,69,71,52,32,104,101,97,100,101,114,32,40,113,115,99,97,108,101,61,48,41,10,0,0,0,110,98,95,99,111,109,112,111,110,101,110,116,115,62,61,49,32,38,38,32,110,98,95,99,111,109,112,111,110,101,110,116,115,60,61,52,0,0,0,0,73,110,118,97,108,105,100,32,99,114,111,112,112,101,100,32,100,105,109,101,110,115,105,111,110,115,58,32,37,100,120,37,100,46,10,0,0,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,77,83,90,72,0,0,0,0,0,0,0,100,118,100,0,0,0,0,0,116,105,109,101,95,111,102,102,0,0,0,0,0,0,0,0,66,111,111,116,121,32,66,97,115,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,83,85,66,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,78,111,32,102,105,108,116,101,114,32,110,97,109,101,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,0,0,84,65,76,66,0,0,0,0,32,40,104,101,97,114,105,110,103,32,105,109,112,97,105,114,101,100,41,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,83,112,101,99,105,102,105,101,100,32,116,105,109,101,32,37,102,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,102,111,108,108,111,119,105,110,103,32,116,105,109,101,32,37,102,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,57,78,0,0,0,70,111,114,99,101,100,32,107,101,121,102,114,97,109,101,32,97,116,32,116,105,109,101,32,37,102,10,0,0,0,0,0,109,112,52,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,56,78,0,0,0,110,101,120,116,95,100,116,115,32,60,61,32,48,120,55,102,102,102,102,102,102,102,0,0,80,108,97,110,97,114,32,89,39,67,98,67,114,32,56,45,98,105,116,32,52,58,50,58,48,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,55,78,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,67,78,84,73,0,0,0,0,123,37,42,100,125,123,37,42,100,125,37,99,0,0,0,0,112,97,121,108,111,97,100,95,116,121,112,101,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,54,78,0,0,0,35,118,101,114,115,105,111,110,58,32,49,10,0,0,0,0,116,105,116,108,101,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,78,0,0,0,67,111,114,114,117,112,116,32,105,110,116,52,32,82,77,45,115,116,121,108,101,32,97,117,100,105,111,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,0,0,0,0,118,105,100,101,111,32,100,111,101,115,110,39,116,32,115,101,101,109,32,116,111,32,98,101,32,80,65,76,32,111,114,32,78,84,83,67,46,32,103,117,101,115,115,105,110,103,32,80,65,76,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,78,0,0,0,115,109,99,45,105,110,116,101,114,118,97,108,0,0,0,0,121,117,118,97,52,52,52,112,49,54,108,101,0,0,0,0,70,79,78,84,0,0,0,0,77,105,110,116,67,114,101,97,109,0,0,0,0,0,0,0,105,109,112,114,111,118,101,100,95,101,95,119,101,105,103,104,116,101,100,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,78,0,0,0,118,105,100,101,111,95,103,101,116,95,98,117,102,102,101,114,58,32,105,109,97,103,101,32,112,97,114,97,109,101,116,101,114,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,71,67,83,95,71,97,114,111,117,97,0,0,0,0,0,0,112,99,109,95,122,111,114,107,0,0,0,0,0,0,0,0,104,101,120,0,0,0,0,0,119,97,114,110,105,110,103,44,32,116,111,111,32,109,97,110,121,32,98,32,102,114,97,109,101,115,32,105,110,32,97,32,114,111,119,10,0,0,0,0,115,116,97,116,105,99,32,115,112,114,105,116,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,90,82,76,32,111,118,101,114,102,108,111,119,58,32,37,100,10,0,0,0,0,0,0,0,33,105,109,103,45,62,115,112,108,105,116,95,112,108,97,110,101,115,0,0,0,0,0,0,104,45,62,115,112,115,46,99,114,111,112,95,116,111,112,32,43,32,104,45,62,115,112,115,46,99,114,111,112,95,98,111,116,116,111,109,32,60,32,40,117,110,115,105,103,110,101,100,41,104,45,62,104,101,105,103,104,116,0,0,0,0,0,0,109,115,122,104,0,0,0,0,115,101,116,32,116,104,101,32,115,116,97,114,116,32,116,105,109,101,32,111,102,102,115,101,116,0,0,0,0,0,0,0,83,121,109,112,104,111,110,121,0,0,0,0,0,0,0,0,112,97,116,116,101,114,110,95,116,121,112,101,0,0,0,0,85,115,101,32,45,104,32,116,111,32,103,101,116,32,102,117,108,108,32,104,101,108,112,32,111,114,44,32,101,118,101,110,32,98,101,116,116,101,114,44,32,114,117,110,32,39,109,97,110,32,37,115,39,10,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,78,0,0,0,112,110,109,0,0,0,0,0,116,105,116,108,101,0,0,0,65,117,116,104,111,114,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,78,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,0,0,32,40,102,111,114,99,101,100,41,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,80,117,101,114,116,111,95,82,105,99,111,95,86,105,114,103,105,110,95,73,115,0,73,110,118,97,108,105,100,32,116,105,109,101,32,100,117,114,97,116,105,111,110,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,39,37,115,39,32,105,110,32,116,105,109,101,115,32,108,105,115,116,32,37,115,10,0,0,0,0,0,0,84,73,84,50,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,32,40,100,105,109,101,110,115,105,111,110,115,32,99,97,110,110,111,116,32,101,120,99,101,101,100,32,50,53,54,120,50,53,54,41,10,0,0,0,0,0,0,0,0,37,100,47,37,100,32,105,110,112,117,116,32,116,105,109,101,32,98,97,115,101,32,109,97,116,99,104,101,100,32,37,100,47,37,100,32,99,111,110,116,97,105,110,101,114,32,116,105,109,101,32,98,97,115,101,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,101,103,109,101,110,116,32,102,105,108,101,110,97,109,101,32,116,101,109,112,108,97,116,101,32,39,37,115,39,10,0,80,67,83,95,78,65,68,56,51,95,87,121,111,109,105,110,103,95,87,101,115,116,0,0,118,97,114,105,97,110,116,95,98,105,116,114,97,116,101,0,114,101,99,111,114,100,101,100,0,0,0,0,0,0,0,0,42,42,42,32,37,100,32,100,117,112,33,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,121,111,109,105,110,103,95,87,95,67,101,110,0,99,111,117,108,100,32,110,111,116,32,114,101,97,108,108,111,99,97,116,101,32,102,108,116,32,101,110,116,114,105,101,115,10,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,111,118,101,110,99,46,99,0,0,0,0,116,114,97,99,107,32,100,101,115,99,114,105,112,116,105,111,110,32,108,111,110,103,101,114,32,116,104,97,110,32,109,97,112,32,100,97,116,97,10,0,105,103,110,111,114,101,95,108,111,111,112,0,0,0,0,0,78,69,84,83,67,65,80,69,50,46,48,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,121,111,109,105,110,103,95,69,95,67,101,110,0,101,110,99,114,121,112,116,101,100,0,0,0,0,0,0,0,97,97,99,32,98,105,116,115,116,114,101,97,109,32,101,114,114,111,114,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,121,111,109,105,110,103,95,69,97,115,116,0,0,76,69,65,68,95,80,69,82,70,79,82,77,69,82,0,0,111,110,77,101,116,97,68,97,116,97,0,0,0,0,0,0,87,114,105,116,101,32,116,104,101,32,102,105,108,101,32,104,101,97,100,101,114,0,0,0,80,67,83,95,78,65,68,56,51,95,87,105,115,99,111,110,115,105,110,95,83,111,117,116,104,0,0,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,104,101,97,100,101,114,58,32,37,105,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,105,115,99,111,110,115,105,110,95,67,101,110,0,105,112,99,109,60,52,0,0,121,117,118,97,52,52,52,112,49,54,98,101,0,0,0,0,77,105,100,110,105,103,104,116,66,108,117,101,0,0,0,0,115,101,108,101,99,116,32,109,111,100,105,102,105,101,100,45,101,45,119,101,105,103,104,116,101,100,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,118,101,114,115,105,111,110,0,80,67,83,95,78,65,68,56,51,95,87,105,115,99,111,110,115,105,110,95,78,111,114,116,104,0,0,0,0,0,0,0,80,105,99,116,117,114,101,32,99,104,97,110,103,101,100,32,102,114,111,109,32,115,105,122,101,58,37,100,120,37,100,32,102,109,116,58,37,115,32,116,111,32,115,105,122,101,58,37,100,120,37,100,32,102,109,116,58,37,115,32,105,110,32,114,101,103,101,116,32,98,117,102,102,101,114,40,41,10,0,0,71,67,83,95,71,97,110,100,97,106,105,107,97,95,49,57,55,48,0,0,0,0,0,0,88,49,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,0,105,108,108,101,103,97,108,32,98,32,102,114,97,109,101,32,115,116,114,97,116,101,103,121,10,0,0,0,0,0,0,0,115,112,114,105,116,101,95,98,114,105,103,104,116,110,101,115,115,95,99,104,97,110,103,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,83,83,47,83,69,32,37,100,47,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,104,45,62,115,112,115,46,99,114,111,112,95,114,105,103,104,116,32,43,32,104,45,62,115,112,115,46,99,114,111,112,95,108,101,102,116,32,60,32,40,117,110,115,105,103,110,101,100,41,104,45,62,119,105,100,116,104,0,0,0,0,0,0,0,83,105,101,114,114,97,32,86,77,68,32,118,105,100,101,111,0,0,0,0,0,0,0,0,115,115,0,0,0,0,0,0,83,111,110,97,116,97,0,0,80,67,83,95,78,65,68,56,51,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,83,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,78], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2333320);
/* memory initializer */ allocate([65,114,114,97,121,32,116,111,111,32,98,105,103,46,10,0,32,40,107,97,114,97,111,107,101,41,0,0,0,0,0,0,78,85,76,76,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,97,115,104,105,110,103,116,111,110,95,83,111,117,116,104,0,0,0,0,0,0,69,109,112,116,121,32,116,105,109,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,105,110,32,116,105,109,101,115,32,108,105,115,116,32,37,115,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,43,32,112,114,101,102,105,120,32,99,111,109,98,105,110,97,116,105,111,110,44,32,97,115,115,117,109,105,110,103,32,97,117,100,105,111,46,10,0,0,0,105,100,32,62,61,32,50,51,32,38,38,32,105,100,32,60,32,50,51,32,43,32,52,0,73,110,118,97,108,105,100,32,108,111,111,112,115,116,97,114,116,32,118,97,108,117,101,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,97,115,104,105,110,103,116,111,110,95,78,111,114,116,104,0,0,0,0,0,0,114,97,116,105,110,103,0,0,105,110,118,97,108,105,100,32,112,97,99,107,101,116,95,108,101,110,103,116,104,32,37,100,32,97,116,58,37,108,108,100,10,0,0,0,0,0,0,0,37,100,32,102,114,97,109,101,32,100,117,112,108,105,99,97,116,105,111,110,32,116,111,111,32,108,97,114,103,101,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,86,105,114,103,105,110,105,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,99,111,118,101,114,32,97,114,116,46,10,0,0,0,0,0,0,0,110,101,120,116,95,100,116,115,32,62,61,32,48,0,0,0,100,118,32,100,101,109,117,120,32,99,111,110,116,101,120,116,32,105,110,105,116,32,101,114,114,111,114,10,0,0,0,0,108,101,118,101,108,32,60,61,32,102,115,45,62,115,121,110,99,95,108,101,118,101,108,0,80,67,83,95,78,65,68,56,51,95,86,105,114,103,105,110,105,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,101,109,112,116,121,32,102,114,97,109,101,32,37,115,44,32,115,107,105,112,112,105,110,103,46,10,0,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,118,111,108,117,109,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,86,101,114,109,111,110,116,0,0,0,0,0,0,0,115,105,108,101,110,99,101,95,115,116,97,114,116,58,32,37,115,10,0,0,0,0,0,0,67,97,110,32,110,111,116,32,109,105,120,32,110,97,109,101,100,32,97,110,100,32,110,117,109,98,101,114,101,100,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,58,32,37,115,46,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,116,97,104,95,83,111,117,116,104,0,0,0,0,45,55,48,47,45,55,48,124,45,54,48,47,45,50,48,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,105,110,112,117,116,32,99,104,97,110,110,101,108,32,110,117,109,98,101,114,115,32,105,110,32,111,117,116,112,117,116,32,111,114,100,101,114,46,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,116,97,104,95,67,101,110,116,114,97,108,0,0,37,115,61,37,115,58,0,0,108,111,119,112,97,115,115,0,121,117,118,97,52,50,50,112,49,54,108,101,0,0,0,0,77,101,100,105,117,109,86,105,111,108,101,116,82,101,100,0,109,111,100,105,102,105,101,100,95,101,95,119,101,105,103,104,116,101,100,0,0,0,0,0,115,116,97,114,116,95,104,101,114,101,32,60,61,32,115,116,111,112,95,104,101,114,101,32,38,38,32,102,114,97,103,45,62,112,111,115,105,116,105,111,110,91,49,93,32,60,61,32,115,116,97,114,116,95,104,101,114,101,32,38,38,32,111,118,101,114,108,97,112,32,60,61,32,102,114,97,103,45,62,110,115,97,109,112,108,101,115,0,80,67,83,95,78,65,68,56,51,95,85,116,97,104,95,78,111,114,116,104,0,0,0,0,115,101,116,32,115,116,114,101,97,109,32,115,101,108,101,99,116,105,111,110,32,101,120,112,114,101,115,115,105,111,110,0,97,118,99,116,120,45,62,99,111,100,101,99,95,116,121,112,101,32,61,61,32,65,86,77,69,68,73,65,95,84,89,80,69,95,86,73,68,69,79,0,71,67,83,95,70,97,104,117,100,0,0,0,0,0,0,0,67,114,101,115,116,32,102,97,99,116,111,114,58,32,37,102,10,0,0,0,0,0,0,0,120,49,0,0,0,0,0,0,119,97,114,110,105,110,103,44,32,99,108,105,112,112,105,110,103,32,37,100,32,100,99,116,32,99,111,101,102,102,105,99,105,101,110,116,115,32,116,111,32,37,100,46,46,37,100,10,0,0,0,0,0,0,0,0,72,101,97,100,101,114,32,116,114,117,110,99,97,116,101,100,10,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,78,111,32,115,112,97,99,101,32,102,111,114,32,37,100,32,115,97,109,112,108,101,115,44,32,115,116,114,101,116,99,104,105,110,103,32,97,117,100,105,111,32,102,105,102,111,10,0,118,109,100,118,105,100,101,111,0,0,0,0,0,0,0,0,67,104,97,109,98,101,114,32,77,117,115,105,99,0,0,0,108,105,109,105,116,95,115,105,122,101,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,83,111,117,116,104,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,100,101,99,97,121,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,72,111,119,32,116,111,32,100,101,116,101,114,109,105,110,101,32,116,104,101,32,101,110,100,45,111,102,45,115,116,114,101,97,109,46,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,83,111,117,116,104,95,67,101,110,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,32,109,101,109,111,114,121,32,102,111,114,32,115,116,114,101,97,109,32,111,112,116,105,111,110,115,46,10,0,0,0,0,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,115,97,109,112,108,101,32,102,111,114,109,97,116,115,46,0,0,0,0,0,0,0,32,40,108,121,114,105,99,115,41,0,0,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,102,105,114,115,116,32,115,97,109,112,108,101,32,116,111,32,115,116,97,114,116,32,102,97,100,105,110,103,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,67,101,110,116,114,97,108,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,111,114,99,101,100,32,116,105,109,101,115,32,97,114,114,97,121,10,0,0,105,110,95,103,97,105,110,0,67,104,97,110,110,101,108,115,32,101,120,112,114,101,115,115,105,111,110,115,32,108,105,115,116,32,105,115,32,101,109,112,116,121,10,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,78,111,114,116,104,95,67,101,110,0,0,0,0,0,0,0,115,109,112,116,101,98,97,114,115,0,0,0,0,0,0,0,42,42,42,32,100,114,111,112,33,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,78,111,114,116,104,0,0,0,109,97,120,105,116,101,114,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,84,84,83,32,105,110,118,97,108,105,100,10,0,0,0,37,100,58,37,100,32,37,99,10,0,0,0,0,0,0,0,66,108,117,101,115,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,110,110,101,115,115,101,101,0,0,0,0,0,101,120,116,101,110,100,101,100,32,104,101,97,100,101,114,32,116,111,111,32,108,111,110,103,46,0,0,0,0,0,0,0,114,101,97,100,32,105,110,105,116,105,97,108,32,112,97,116,116,101,114,110,32,102,114,111,109,32,102,105,108,101,0,0,115,101,110,100,95,102,105,101,108,100,95,110,111,115,112,97,116,105,97,108,0,0,0,0,105,110,116,101,114,108,97,99,101,100,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,83,111,117,116,104,95,68,97,107,111,116,97,95,83,0,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,116,121,112,101,58,32,37,100,46,10,0,0,0,0,0,0,115,101,116,32,108,117,109,97,32,101,102,102,101,99,116,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,83,111,117,116,104,95,68,97,107,111,116,97,95,78,0,0,0,0,0,0,0,0,99,108,111,99,107,95,102,108,105,112,0,0,0,0,0,0,115,101,116,32,111,117,116,101,114,32,98,111,114,100,101,114,32,109,97,114,103,105,110,32,105,110,32,112,105,120,101,108,115,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,0,0,0,0,0,0,0,0,112,114,111,103,0,0,0,0,121,117,118,97,52,50,50,112,49,54,98,101,0,0,0,0,77,101,100,105,117,109,84,117,114,113,117,111,105,115,101,0,115,101,108,101,99,116,32,102,45,119,101,105,103,104,116,101,100,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,0,116,105,109,101,98,97,115,101,32,110,111,116,32,115,101,116,32,102,111,114,32,97,117,100,105,111,32,105,110,116,101,114,108,101,97,118,101,10,0,0,80,67,83,95,78,65,68,56,51,95,82,104,111,100,101,95,73,115,108,97,110,100,0,0,80,65,82,65,77,95,67,72,65,78,71,69,32,115,105,100,101,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,71,67,83,95,69,68,56,55,0,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,112,104,111,100,115,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,105,108,108,101,103,97,108,32,77,66,32,116,121,112,101,10,0,0,0,0,0,0,0,0,118,111,112,32,110,111,116,32,99,111,100,101,100,10,0,0,101,114,114,111,114,32,99,111,117,110,116,58,32,37,100,10,0,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,110,111,116,32,97,118,97,105,108,97,98,108,101,32,102,111,114,32,101,114,114,111,114,32,99,111,110,99,101,97,108,105,110,103,10,0,0,0,111,119,0,0,0,0,0,0,68,117,99,107,32,84,114,117,101,77,111,116,105,111,110,32,49,46,48,0,0,0,0,0,79,112,101,114,97,0,0,0,115,101,116,32,116,104,101,32,108,105,109,105,116,32,102,105,108,101,32,115,105,122,101,32,105,110,32,98,121,116,101,115,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,80,101,110,110,115,121,108,118,97,110,105,97,95,83,0,0,0,0,0,0,0,0,109,115,101,95,37,99,58,37,48,46,50,102,32,0,0,0,120,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,80,101,110,110,115,121,108,118,97,110,105,97,95,78,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,58,32,37,115,46,10,0,0,111,118,101,114,108,97,121,95,119,0,0,0,0,0,0,0,32,40,99,111,109,109,101,110,116,41,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,79,114,101,103,111,110,95,83,111,117,116,104,0,0,97,0,0,0,0,0,0,0,83,112,101,99,105,102,105,101,100,32,102,114,97,109,101,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,102,111,108,108,111,119,105,110,103,32,102,114,97,109,101,32,37,100,10,0,0,0,0,0,0,102,111,114,109,97,116,0,0,87,77,47,65,108,98,117,109,65,114,116,105,115,116,0,0,105,110,116,101,114,112,95,109,111,100,101,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,79,114,101,103,111,110,95,78,111,114,116,104,0,0,110,101,103,118,97,108,0,0,99,104,114,111,109,97,95,109,111,100,101,0,0,0,0,0,78,111,116,32,100,117,112,108,105,99,97,116,105,110,103,32,37,100,32,105,110,105,116,105,97,108,32,102,114,97,109,101,115,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,79,107,108,97,104,111,109,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,84,111,112,32,70,105,101,108,100,32,70,105,114,115,116,32,32,32,0,0,0,0,0,0,100,105,114,32,37,115,10,0,116,0,0,0,0,0,0,0,112,101,114,32,114,111,119,47,99,111,108,117,109,110,32,108,117,109,105,110,97,110,99,101,32,103,114,97,112,104,0,0,80,67,83,95,78,65,68,56,51,95,79,107,108,97,104,111,109,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,101,120,116,101,110,100,101,100,32,104,101,97,100,101,114,32,108,101,110,103,116,104,0,0,108,105,110,101,115,0,0,0,122,101,114,111,0,0,0,0,80,67,83,95,78,65,68,56,51,95,79,104,105,111,95,83,111,117,116,104,0,0,0,0,102,114,97,109,101,32,119,105,116,104,32,115,97,109,101,32,102,105,101,108,100,32,111,114,100,101,114,0,0,0,0,0,33,34,118,97,108,105,100,32,101,108,101,109,101,110,116,32,115,105,122,101,34,0,0,0,109,111,110,111,98,0,0,0,111,114,100,101,114,32,61,61,32,48,32,124,124,32,111,114,100,101,114,32,61,61,32,49,32,124,124,32,102,105,101,108,100,32,61,61,32,48,32,124,124,32,102,105,101,108,100,32,61,61,32,49,0,0,0,0,80,67,83,95,78,65,68,56,51,95,79,104,105,111,95,78,111,114,116,104,0,0,0,0,119,58,37,100,32,104,58,37,100,32,116,121,112,101,58,37,115,32,45,62,32,119,58,37,100,32,104,58,37,100,10,0,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,0,48,120,37,48,56,88,0,0,27,91,37,100,59,51,37,100,109,37,115,27,91,48,109,0,83,72,65,53,49,50,47,50,53,54,0,0,0,0,0,0,102,97,100,101,45,105,110,0,116,97,110,0,0,0,0,0,68,69,77,85,88,69,82,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,102,114,111,110,116,32,99,101,110,116,101,114,0,0,0,0,117,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,111,114,116,104,95,68,97,107,111,116,97,95,83,0,0,0,0,0,0,0,0,68,101,115,105,114,101,100,32,100,105,116,104,101,114,105,110,103,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,105,110,32,102,117,108,108,32,99,104,114,111,109,97,32,105,110,116,101,114,112,111,108,97,116,105,111,110,32,102,111,114,32,100,101,115,116,105,110,97,116,105,111,110,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,0,115,0,0,0,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,46,99,0,0,0,0,97,114,101,97,0,0,0,0,111,99,104,0,0,0,0,0,121,117,118,97,52,50,48,112,49,54,108,101,0,0,0,0,77,101,100,105,117,109,83,112,114,105,110,103,71,114,101,101,110,0,0,0,0,0,0,0,102,95,119,101,105,103,104,116,101,100,0,0,0,0,0,0,114,97,110,103,101,32,60,61,50,53,54,32,124,124,32,33,40,115,45,62,99,111,100,101,99,95,105,100,32,61,61,32,65,86,95,67,79,68,69,67,95,73,68,95,77,80,69,71,50,86,73,68,69,79,32,38,38,32,115,45,62,97,118,99,116,120,45,62,115,116,114,105,99,116,95,115,116,100,95,99,111,109,112,108,105,97,110,99,101,32,62,61,32,48,41,0,115,101,116,32,119,105,100,116,104,32,111,102,32,103,114,105,100,32,99,101,108,108,0,0,108,105,98,97,118,99,111,100,101,99,47,101,114,114,111,114,95,114,101,115,105,108,105,101,110,99,101,46,99,0,0,0,80,67,83,95,78,65,68,56,51,95,78,111,114,116,104,95,68,97,107,111,116,97,95,78,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,116,114,97,110,115,109,105,116,116,101,100,32,117,110,105,116,115,33,10,0,0,0,84,104,105,115,32,100,101,99,111,100,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,112,97,114,97,109,101,116,101,114,32,99,104,97,110,103,101,115,44,32,98,117,116,32,80,65,82,65,77,95,67,72,65,78,71,69,32,115,105,100,101,32,100,97,116,97,32,119,97,115,32,115,101,110,116,32,116,111,32,105,116,46,10,0,0,0,0,92,37,49,91,49,50,51,52,93,97,37,49,91,92,125,93,37,110,0,0,0,0,0,0,71,67,83,95,69,68,53,48,0,0,0,0,0,0,0,0,57,58,53,57,58,53,57,46,57,57,44,0,0,0,0,0,117,110,107,110,111,119,110,32,112,114,101,100,105,99,116,105,111,110,32,116,121,112,101,58,32,37,105,10,0,0,0,0,80,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,32,99,104,97,110,103,101,100,58,32,111,108,100,58,32,37,100,32,120,32,37,100,44,32,110,101,119,58,32,37,100,32,120,32,37,100,10,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,115,101,116,32,121,32,102,111,114,32,116,104,101,32,114,101,99,116,97,110,103,117,108,97,114,32,115,101,97,114,99,104,32,97,114,101,97,0,0,0,112,99,109,95,117,51,50,108,101,0,0,0,0,0,0,0,112,104,111,100,115,0,0,0,97,100,112,99,109,95,101,97,95,109,97,120,105,115,95,120,97,0,0,0,0,0,0,0,101,110,99,111,100,101,100,32,112,97,114,116,105,116,105,111,110,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,98,101,102,111,114,101,32,118,111,112,95,99,111,100,101,100,0,0,0,0,0,0,0,0,109,106,112,101,103,95,100,101,99,111,100,101,95,100,99,58,32,98,97,100,32,118,108,99,58,32,37,100,58,37,100,32,40,37,112,41,10,0,0,0,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,95,105,110,105,116,40,41,32,102,97,105,108,101,100,46,10,0,108,116,114,116,95,99,109,105,120,108,101,118,0,0,0,0,32,108,111,119,101,115,116,0,107,120,32,33,61,32,102,95,116,97,98,108,101,123,104,105,103,104,44,108,111,119,125,91,48,93,46,32,68,101,114,105,118,101,100,32,102,114,101,113,117,101,110,99,121,32,116,97,98,108,101,115,32,119,101,114,101,32,110,111,116,32,114,101,103,101,110,101,114,97,116,101,100,46,10,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,116,114,117,101,109,111,116,105,111,110,49,0,0,0,0,0,84,89,80,69,95,70,73,76,58,32,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,0,0,67,104,97,110,115,111,110,0,102,115,0,0,0,0,0,0,101,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,111,114,116,104,95,67,97,114,111,108,105,110,97,0,0,0,0,0,0,0,0,114,101,97,108,108,111,99,32,102,97,105,108,117,114,101,10,0,0,0,0,0,0,0,0,105,110,102,108,97,116,101,32,101,114,114,111,114,32,37,100,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,105,110,118,97,108,105,100,32,98,121,116,101,32,111,114,100,101,114,10,0,0,0,0,0,120,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,102,112,115,58,37,100,44,32,98,114,58,37,100,44,32,113,112,98,105,116,58,37,100,44,32,97,98,116,95,102,108,97,103,58,37,100,44,32,106,95,116,121,112,101,95,98,105,116,58,37,100,44,32,116,108,95,109,118,95,102,108,97,103,58,37,100,44,32,109,98,114,108,95,98,105,116,58,37,100,44,32,99,111,100,101,58,37,100,44,32,108,111,111,112,95,102,105,108,116,101,114,58,37,100,44,32,115,108,105,99,101,115,58,37,100,10,0,0,0,0,73,110,118,97,108,105,100,32,100,101,110,111,105,115,101,32,102,105,108,116,101,114,32,115,116,114,101,110,103,116,104,32,37,100,32,40,109,97,120,61,49,49,41,10,0,0,0,0,110,117,109,95,118,101,99,95,99,111,101,102,102,115,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,98,114,111,107,101,110,32,115,117,98,102,114,97,109,101,10,0,0,0,0,0,0,0,0,112,117,116,95,98,105,116,115,95,112,116,114,40,38,115,45,62,112,98,41,32,45,32,115,45,62,112,98,46,98,117,102,32,61,61,32,97,118,99,116,120,45,62,98,108,111,99,107,95,97,108,105,103,110,0,0,98,108,111,99,107,95,108,101,110,95,98,105,116,115,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,123,92,98,49,125,0,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,69,120,105,102,32,100,97,116,97,10,0,0,0,0,0,0,0,111,110,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,116,101,114,109,115,10,0,0,0,99,98,112,122,32,99,104,117,110,107,32,116,111,111,32,108,97,114,103,101,32,40,37,117,32,98,121,116,101,115,41,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,121,110,99,32,99,111,100,101,10,0,0,0,0,0,0,120,95,115,116,97,114,116,32,62,61,32,48,32,38,38,32,120,95,115,116,97,114,116,32,60,61,32,50,53,53,32,38,38,32,120,95,101,110,100,32,62,61,32,48,32,38,38,32,120,95,101,110,100,32,60,61,32,50,53,53,0,0,0,0,108,32,33,61,32,99,115,117,98,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,89,111,114,107,95,76,111,110,103,95,73,115,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,32,105,110,32,118,111,114,98,105,115,95,102,108,111,111,114,95,100,101,99,111,100,101,46,10,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,109,111,100,101,32,99,111,117,110,116,58,32,37,100,10,0,0,0,0,0,82,101,99,116,97,110,103,108,101,32,111,117,116,115,105,100,101,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,40,98,117,102,95,115,105,122,101,32,38,32,40,97,118,99,116,120,45,62,99,104,97,110,110,101,108,115,32,62,32,49,41,41,32,61,61,32,48,0,83,112,114,105,116,101,32,100,101,99,111,100,101,114,58,32,101,120,112,101,99,116,101,100,32,73,45,102,114,97,109,101,10,0,0,0,0,0,0,0,97,105,102,102,0,0,0,0,65,100,118,97,110,99,101,100,32,86,105,100,101,111,32,111,112,116,105,111,110,115,58,0,37,115,37,115,47,37,115,45,37,115,46,102,102,112,114,101,115,101,116,0,0,0,0,0,120,0,0,0,0,0,0,0,80,114,111,102,105,108,101,32,37,105,58,10,102,114,109,114,116,113,95,112,111,115,116,112,114,111,99,61,37,105,44,32,98,105,116,114,116,113,95,112,111,115,116,112,114,111,99,61,37,105,10,76,111,111,112,70,105,108,116,101,114,61,37,105,44,32,77,117,108,116,105,82,101,115,61,37,105,44,32,70,97,115,116,85,86,77,67,61,37,105,44,32,69,120,116,101,110,100,101,100,32,77,86,61,37,105,10,82,97,110,103,101,114,101,100,61,37,105,44,32,86,83,84,114,97,110,115,102,111,114,109,61,37,105,44,32,79,118,101,114,108,97,112,61,37,105,44,32,83,121,110,99,77,97,114,107,101,114,61,37,105,10,68,81,117,97,110,116,61,37,105,44,32,81,117,97,110,116,105,122,101,114,32,109,111,100,101,61,37,105,44,32,77,97,120,32,66,32,102,114,97,109,101,115,61,37,105,10,0,0,0,0,0,0,0,0,52,58,50,58,50,32,118,105,100,101,111,32,114,101,113,117,105,114,101,115,32,101,118,101,110,32,119,105,100,116,104,46,10,0,0,0,0,0,0,0,83,108,105,99,101,32,100,101,99,111,100,105,110,103,32,114,97,110,32,111,117,116,32,111,102,32,98,105,116,115,10,0,32,40,111,114,105,103,105,110,97,108,41,0,0,0,0,0,78,111,32,99,111,100,101,99,32,112,114,111,118,105,100,101,100,32,116,111,32,97,118,99,111,100,101,99,95,111,112,101,110,50,40,41,10,0,0,0,103,114,0,0,0,0,0,0,102,111,114,109,97,116,58,32,37,100,32,99,104,97,110,115,58,32,37,100,32,98,112,115,58,32,37,100,32,114,97,116,101,58,32,37,100,32,98,108,111,99,107,58,32,37,100,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,115,108,105,99,101,32,37,100,10,0,0,0,0,0,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,105,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,105,122,101,10,0,0,0,0,105,110,118,97,108,105,100,32,118,101,99,116,111,114,32,116,97,98,108,101,32,105,100,32,40,37,100,41,10,0,0,0,66,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,103,109,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,89,111,114,107,95,87,101,115,116,0,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,32,39,37,115,39,44,32,109,117,115,116,32,98,101,32,97,32,112,111,115,105,116,105,118,101,32,105,110,116,101,103,101,114,32,60,61,32,73,78,84,54,52,95,77,65,88,10,0,97,105,102,102,0,0,0,0,97,102,99,0,0,0,0,0,71,101,111,103,65,110,103,117,108,97,114,85,110,105,116,83,105,122,101,71,101,111,75,101,121,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,105,112,32,115,105,122,101,47,111,102,102,115,101,116,10,0,0,0,0,0,0,83,101,116,32,105,102,32,65,83,83,32,116,97,103,115,32,109,117,115,116,32,98,101,32,101,115,99,97,112,101,100,0,80,97,99,107,101,116,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,105,110,118,97,108,105,100,47,117,110,115,117,112,112,111,114,116,101,100,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,58,32,37,100,10,0,0,0,0,0,0,0,0,65,0,0,0,0,0,0,0,102,102,95,104,50,54,52,95,99,104,101,99,107,95,105,110,116,114,97,95,112,114,101,100,95,109,111,100,101,32,60,32,48,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,108,111,114,109,97,112,32,108,101,110,103,116,104,10,0,0,0,0,0,0,0,0,111,110,116,0,0,0,0,0,123,92,97,110,37,42,49,117,125,37,110,0,0,0,0,0,83,111,110,105,99,118,50,32,99,104,97,110,115,58,32,37,100,32,115,97,109,112,114,97,116,101,58,32,37,100,10,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,89,111,114,107,95,67,101,110,116,114,97,108,0,0,0,0,0,0,112,97,115,115,58,37,100,32,99,104,97,110,103,101,100,58,37,100,10,0,0,0,0,0,115,112,97,116,105,97,108,95,100,101,99,111,109,112,111,115,105,116,105,111,110,95,116,121,112,101,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,112,105,120,95,116,104,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,105,110,118,97,108,105,100,32,118,108,99,10,0,0,0,0,97,101,97,0,0,0,0,0,78,111,32,99,104,97,110,110,101,108,115,32,114,101,112,111,114,116,101,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,37,115,13,10,0,0,0,0,108,97,118,102,105,46,98,98,111,120,46,121,50,0,0,0,78,101,101,100,32,68,81,85,65,78,84,10,0,0,0,0,114,118,50,48,32,101,110,99,111,100,101,114,0,0,0,0,117,112,100,97,116,101,32,115,105,122,101,32,102,114,111,109,32,37,100,32,116,111,32,37,100,10,0,0,0,0,0,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,97,100,120,0,0,0,0,0,118,97,114,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,105,115,32,110,111,116,32,103,114,111,111,118,121,44,32,100,117,100,101,10,0,0,109,97,120,0,0,0,0,0,112,97,99,107,101,116,32,116,121,112,101,32,56,0,0,0,66,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,116,104,101,32,99,108,97,105,109,101,100,32,98,105,116,114,97,116,101,46,10,0,0,0,102,114,97,109,101,32,115,105,122,101,32,117,112,112,101,114,32,98,111,117,110,100,58,32,37,100,10,0,0,0,0,0,97,112,99,111,0,0,0,0,111,117,116,32,111,102,32,115,108,105,99,101,32,100,97,116,97,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,115,108,105,99,101,32,114,101,115,111,108,117,116,105,111,110,58,32,37,100,120,37,100,10,0,0,0,0,100,112,109,0,0,0,0,0,112,72,89,115,32,97,102,116,101,114,32,73,68,65,84,10,0,0,0,0,0,0,0,0,102,111,114,99,101,100,95,115,117,98,115,95,111,110,108,121,0,0,0,0,0,0,0,0,97,118,105,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,89,111,114,107,95,69,97,115,116,0,100,117,114,97,116,105,111,110,105,0,0,0,0,0,0,0,112,97,116,104,32,37,115,10,0,0,0,0,0,0,0,0,115,105,0,0,0,0,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,114,116,106,112,101,103,32,113,117,97,110,116,32,100,97,116,97,10,0,68,105,109,101,110,115,105,111,110,115,32,111,102,32,99,117,114,114,101,110,116,32,97,110,100,32,114,101,102,101,114,101,110,99,101,32,112,105,99,116,117,114,101,32,109,105,115,109,97,116,99,104,10,0,0,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,101,120,112,101,99,116,101,100,32,73,45,102,114,97,109,101,10,0,0,0,0,0,0,0,37,103,32,102,114,97,109,101,115,32,112,101,114,32,115,101,99,111,110,100,10,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,77,101,120,105,99,111,95,87,101,115,116,0,0,0,0,0,0,0,118,101,114,115,105,111,110,0,97,100,116,115,0,0,0,0,108,117,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,32,73,78,84,69,82,76,65,67,69,68,58,37,108,108,100,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,69,110,97,98,108,101,32,97,108,116,101,114,110,97,116,101,32,115,99,97,110,116,97,98,108,101,46,0,0,0,0,0,84,111,111,32,109,97,110,121,32,105,110,112,117,116,115,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,116,104,101,32,34,37,115,34,32,102,105,108,116,101,114,46,10,0,97,100,112,0,0,0,0,0,77,80,69,71,32,71,79,80,32,84,105,109,101,99,111,100,101,32,105,110,32,104,104,58,109,109,58,115,115,91,58,59,46,93,102,102,32,102,111,114,109,97,116,0,0,0,0,0,83,105,109,112,108,101,0,0,73,110,105,116,105,110,103,32,86,76,67,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,77,101,120,105,99,111,95,67,101,110,116,0,0,0,0,0,0,0,69,110,100,32,111,102,32,115,116,114,101,97,109,32,105,110,100,105,99,97,116,101,100,46,10,0,0,0,0,0,0,0,74,70,73,70,0,0,0,0,110,98,95,99,111,109,112,111,110,101,110,116,115,32,99,104,97,110,103,105,110,103,32,105,110,32,105,110,116,101,114,108,97,99,101,100,32,112,105,99,116,117,114,101,10,0,0,0,115,111,102,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,0,0,0,0,0,0,102,114,97,109,101,45,62,110,98,95,115,97,109,112,108,101,115,32,62,32,111,102,102,115,101,116,0,0,0,0,0,0,123,92,102,115,125,0,0,0,97,99,116,0,0,0,0,0,73,110,118,97,108,105,100,32,110,111,110,45,112,111,115,105,116,105,118,101,32,118,97,108,117,101,115,32,102,111,114,32,116,104,101,32,116,105,109,101,98,97,115,101,32,110,117,109,58,37,100,32,111,114,32,100,101,110,58,37,100,46,10,0,66,85,71,33,32,85,110,107,110,111,119,110,32,105,109,97,103,101,116,121,112,101,32,105,110,32,112,110,103,102,105,108,116,101,114,32,115,119,105,116,99,104,46,10,0,0,0,0,73,110,116,101,103,101,114,32,111,118,101,114,102,108,111,119,32,101,110,99,111,117,110,116,101,114,101,100,32,105,110,32,99,117,109,117,108,97,116,105,118,101,32,112,114,111,98,97,98,105,108,105,116,121,32,99,97,108,99,117,108,97,116,105,111,110,46,10,0,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,44,32,100,101,99,111,100,105,110,103,32,109,97,121,32,110,111,116,32,119,111,114,107,32,112,114,111,112,101,114,108,121,46,46,46,10,0,0,0,80,114,111,103,114,101,115,115,105,111,110,32,111,114,100,101,114,32,82,76,67,80,0,0,123,92,97,110,51,125,0,0,105,110,105,116,10,0,0,0,77,66,32,115,105,122,101,115,32,109,105,115,109,97,116,99,104,58,32,37,100,32,118,115,46,32,37,100,10,0,0,0,32,83,83,0,0,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,56,10,0,73,110,116,101,108,32,72,46,50,54,51,0,0,0,0,0,91,37,115,93,32,105,110,116,101,114,118,97,108,32,35,37,100,32,115,116,97,114,116,95,116,115,58,37,102,32,101,110,100,95,116,115,58,37,102,32,116,115,58,37,102,10,0,0,83,99,97,108,97,98,108,101,32,105,110,116,101,114,32,102,114,97,109,101,32,105,110,32,110,111,110,32,115,99,97,108,101,97,98,108,101,32,115,116,114,101,97,109,10,0,0,0,68,67,84,32,116,114,97,110,115,102,111,114,109,0,0,0,73,110,118,97,108,105,100,32,86,81,32,116,97,98,108,101,32,105,110,100,101,120,101,115,33,32,80,114,105,109,97,114,121,58,32,37,100,44,32,115,101,99,111,110,100,97,114,121,58,32,37,100,33,10,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,77,101,120,105,99,111,95,69,97,115,116,0,0,0,0,0,0,0,82,101,97,100,32,99,111,101,102,102,105,99,105,101,110,116,115,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,115,105,122,101,32,114,101,99,101,105,118,101,100,58,32,37,117,32,45,62,32,105,109,97,103,101,32,100,97,116,97,32,111,102,102,115,101,116,58,32,37,100,10,0,0,0,0,0,0,0,118,97,108,32,60,32,51,50,32,38,38,32,118,97,108,32,62,48,32,38,38,32,114,101,112,101,97,116,32,60,32,50,53,54,32,38,38,32,114,101,112,101,97,116,62,48,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,104,117,102,102,109,97,110,32,116,97,98,108,101,10,0,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,44,32,100,101,99,111,100,101,114,32,114,101,113,117,105,114,101,115,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,10,0,0,0,0,0,86,80,83,32,37,100,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,10,0,0,73,110,118,97,108,105,100,32,78,65,76,32,117,110,105,116,32,115,105,122,101,46,10,0,108,101,102,116,95,114,105,103,104,116,0,0,0,0,0,0,73,110,99,111,110,115,105,115,116,101,110,116,32,77,77,67,79,32,115,116,97,116,101,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,32,91,37,100,44,32,37,100,93,10,0,0,0,0,0,0,0,0,115,116,97,114,116,95,112,116,115,0,0,0,0,0,0,0,97,99,51,0,0,0,0,0,109,98,95,119,105,100,116,104,47,104,101,105,103,104,116,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,100,113,117,97,110,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,40,37,100,41,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,104,45,62,115,112,115,46,98,105,116,95,100,101,112,116,104,95,99,104,114,111,109,97,32,61,61,32,48,0,0,0,0,104,50,54,51,112,0,0,0,104,45,62,109,116,121,112,101,32,60,32,40,115,105,122,101,111,102,40,102,102,95,104,50,54,49,95,109,116,121,112,101,95,109,97,112,41,32,47,32,115,105,122,101,111,102,40,40,102,102,95,104,50,54,49,95,109,116,121,112,101,95,109,97,112,41,91,48,93,41,41,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,115,101,116,32,71,73,70,32,102,108,97,103,115,0,0,0,114,119,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,103,55,50,54,46,99,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,74,101,114,115,101,121,0,0,0,0,68,105,115,112,108,97,121,32,105,110,102,111,58,32,109,105,115,115,105,110,103,32,98,105,116,109,97,115,107,115,33,10,0,0,0,0,0,0,0,0,73,110,32,99,104,117,110,107,32,70,76,73,95,67,79,80,89,32,58,32,115,111,117,114,99,101,32,100,97,116,97,32,40,37,100,32,98,121,116,101,115,41,32,98,105,103,103,101,114,32,116,104,97,110,32,105,109,97,103,101,44,32,115,107,105,112,112,105,110,103,32,99,104,117,110,107,10,0,0,0,97,97,99,0,0,0,0,0,73,110,112,117,116,32,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,44,32,105,110,112,117,116,32,109,117,115,116,32,98,101,32,109,97,120,32,52,48,57,54,120,52,48,57,54,32,33,10,0,0,0,0,0,0,70,114,97,109,101,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,32,100,105,102,102,101,114,115,32,102,114,111,109,32,102,105,114,115,116,32,102,114,97,109,101,33,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,97,120,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,99,104,97,110,103,101,32,100,101,116,101,99,116,101,100,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,0,101,120,116,114,97,100,97,116,97,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,0,0,0,0,0,0,0,82,111,111,109,32,84,121,112,101,0,0,0,0,0,0,0,121,117,118,97,52,50,48,112,49,54,98,101,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,97,54,52,0,0,0,0,0,77,101,100,105,117,109,83,108,97,116,101,66,108,117,101,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,105,98,97,118,99,111,100,101,99,47,100,118,100,115,117,98,101,110,99,46,99,0,0,100,118,100,115,117,98,100,101,99,0,0,0,0,0,0,0,114,101,103,105,111,110,32,100,101,112,116,104,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,116,105,109,101,95,98,97,115,101,0,0,0,0,0,0,0,115,101,108,101,99,116,32,104,105,103,104,32,115,104,105,98,97,116,97,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,0,0,0,0,0,0,0,80,97,99,107,105,110,103,32,116,111,32,49,54,98,105,116,32,114,101,113,117,105,114,101,100,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,111,111,32,109,97,110,121], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2343560);
/* memory initializer */ allocate([32,116,104,114,101,97,100,115,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,72,97,109,112,115,104,105,114,101,0,97,99,32,116,101,120,32,100,97,109,97,103,101,100,32,37,100,44,32,37,100,10,0,0,80,73,67,84,85,82,69,95,78,85,77,58,32,37,100,10,0,0,0,0,0,0,0,0,66,76,67,75,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,33,10,0,0,0,0,70,83,73,90,69,57,54,32,61,32,37,100,32,98,121,116,101,115,10,0,0,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,0,0,0,99,111,100,101,99,100,97,116,97,95,108,101,110,103,116,104,61,37,100,10,0,0,0,0,85,110,97,98,108,101,32,116,111,32,114,101,99,111,100,101,32,115,117,98,116,105,116,108,101,32,101,118,101,110,116,32,34,37,115,34,32,102,114,111,109,32,37,115,32,116,111,32,85,84,70,45,56,10,0,0,71,67,83,95,69,103,121,112,116,95,49,57,48,55,0,0,115,97,109,112,108,101,95,102,109,116,115,0,0,0,0,0,108,111,103,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,77,80,69,71,52,32,80,84,83,58,32,37,108,108,100,10,0,0,0,0,0,0,0,0,52,120,109,0,0,0,0,0,101,114,114,111,114,32,100,99,10,0,0,0,0,0,0,0,114,118,49,48,0,0,0,0,116,111,111,32,109,97,110,121,32,116,104,114,101,97,100,115,47,115,108,105,99,101,115,32,37,100,44,32,114,101,100,117,99,105,110,103,32,116,111,32,37,100,10,0,0,0,0,0,115,107,105,112,95,101,109,112,116,121,95,99,98,0,0,0,114,117,110,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,85,110,107,110,111,119,110,32,98,105,116,102,105,101,108,100,115,32,37,48,88,32,37,48,88,32,37,48,88,10,0,0,65,117,116,111,100,101,115,107,32,65,110,105,109,97,116,111,114,32,70,108,105,99,32,118,105,100,101,111,0,0,0,0,114,101,116,32,62,61,32,48,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,109,111,116,105,111,110,32,118,97,108,117,101,115,10,0,67,97,110,110,111,116,32,115,101,108,101,99,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,102,111,114,32,116,104,101,32,108,105,110,107,32,98,101,116,119,101,101,110,32,102,105,108,116,101,114,115,32,37,115,32,97,110,100,32,37,115,46,10,0,0,0,83,112,101,101,99,104,0,0,116,105,109,101,95,115,116,111,112,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,118,97,100,97,95,87,101,115,116,0,0,0,91,49,50,45,49,51,93,32,37,100,10,0,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,65,83,83,32,101,118,101,110,116,46,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,102,114,97,109,101,10,0,0,0,107,32,105,110,118,97,108,105,100,32,102,111,114,32,114,105,99,101,32,99,111,100,101,46,10,0,0,0,0,0,0,0,100,105,115,112,111,115,105,116,105,111,110,0,0,0,0,0,114,111,119,95,105,110,116,101,114,108,101,97,118,101,100,95,114,108,0,0,0,0,0,0,78,101,119,32,65,103,101,0,116,105,116,108,101,0,0,0,87,77,47,69,110,99,111,100,101,100,66,121,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,73,70,70,0,0,0,0,65,68,84,83,32,109,117,120,101,114,0,0,0,0,0,0,52,52,52,112,49,54,0,0,82,73,70,70,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,118,97,100,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,0,47,46,102,102,109,112,101,103,0,0,0,0,0,0,0,0,32,40,100,117,98,41,0,0,80,67,83,95,78,65,68,56,51,95,78,101,118,97,100,97,95,69,97,115,116,0,0,0,69,109,112,116,121,32,102,114,97,109,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,105,110,32,102,114,97,109,101,32,108,105,115,116,32,37,115,10,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,98,114,97,115,107,97,0,0,0,0,0,0,101,110,99,111,100,101,114,32,45,62,32,116,121,112,101,58,97,117,100,105,111,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,111,110,116,97,110,97,0,0,0,0,0,0,0,116,121,112,101,32,37,100,44,32,108,101,110,32,37,100,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,83,116,95,67,114,111,105,120,0,0,0,0,0,0,99,111,109,112,114,101,115,115,105,111,110,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,80,117,101,114,116,111,95,82,105,99,111,0,0,0,80,67,83,95,78,65,68,50,55,95,87,121,111,109,105,110,103,95,87,101,115,116,0,0,80,67,83,95,78,65,68,50,55,95,87,121,111,109,105,110,103,95,87,95,67,101,110,0,121,117,118,97,52,52,52,112,49,48,108,101,0,0,0,0,121,117,118,52,109,112,101,103,112,105,112,101,0,0,0,0,77,101,100,105,117,109,83,101,97,71,114,101,101,110,0,0,104,105,103,104,95,115,104,105,98,97,116,97,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,121,111,109,105,110,103,95,69,95,67,101,110,0,83,117,98,116,105,116,108,101,115,32,112,97,99,107,101,116,32,105,115,32,116,111,111,32,98,105,103,32,102,111,114,32,114,101,99,111,100,105,110,103,10,0,0,0,0,0,0,0,121,111,112,0,0,0,0,0,71,67,83,95,68,111,117,97,108,97,0,0,0,0,0,0,108,111,103,0,0,0,0,0,48,0,0,0,0,0,0,0,109,121,32,103,117,101,115,115,32,105,115,32,37,100,32,98,105,116,115,32,59,41,10,0,101,114,114,111,114,32,121,61,37,100,32,120,61,37,100,10,0,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,10,0,0,0,0,0,0,102,108,105,99,0,0,0,0,72,117,109,111,117,114,0,0,114,101,99,111,114,100,32,111,114,32,116,114,97,110,115,99,111,100,101,32,115,116,111,112,32,116,105,109,101,0,0,0,80,67,83,95,78,65,68,50,55,95,87,121,111,109,105,110,103,95,69,97,115,116,0,0,120,119,109,97,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,105,115,99,111,110,115,105,110,95,83,111,117,116,104,0,0,0,0,0,0,0,37,115,37,115,47,37,115,46,102,102,112,114,101,115,101,116,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,102,111,114,32,37,115,32,119,97,115,32,37,115,32,119,104,105,99,104,32,105,115,32,110,111,116,32,119,105,116,104,105,110,32,37,102,32,45,32,37,102,10,0,0,0,0,69,120,112,101,99,116,101,100,32,110,117,109,98,101,114,32,102,111,114,32,37,115,32,98,117,116,32,102,111,117,110,100,58,32,37,115,10,0,0,0,232,238,18,0,48,228,18,0,0,0,0,0,0,0,0,0,48,228,18,0,0,0,0,0,48,228,18,0,0,0,0,0,2,0,0,0,255,255,255,255,96,158,16,0,0,0,0,0,96,158,16,0,0,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,12,0,0,0,13,0,0,0,255,255,255,255,0,0,0,0,248,111,22,0,0,0,0,0,232,8,18,0,0,0,0,0,136,230,18,0,152,230,18,0,0,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,176,230,18,0,0,0,0,0,176,230,18,0,0,0,0,0,96,87,8,0,0,0,0,0,96,127,17,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,8,207,17,0,0,0,0,0,8,207,17,0,0,0,0,0,0,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,42,0,0,0,255,255,255,255,2,0,0,0,41,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,4,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,200,230,18,0,16,236,18,0,0,0,0,0,0,0,0,0,7,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,232,238,18,0,48,228,18,0,232,29,28,0,184,29,28,0,0,0,0,0,0,0,0,0,24,125,10,0,0,0,0,0,232,238,18,0,0,0,0,0,168,237,18,0,0,0,0,0,3,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,184,87,30,0,108,0,0,0,144,88,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,228,18,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,72,1,16,0,8,2,16,0,0,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,56,238,18,0,0,0,0,0,3,0,0,0,255,255,255,255,56,238,18,0,0,0,0,0,120,217,32,0,108,0,0,0,144,88,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,111,22,0,232,238,18,0,48,228,18,0,0,0,0,0,232,238,18,0,48,228,18,0,0,0,0,0,0,0,0,0,6,0,0,0,255,255,255,255,104,111,22,0,0,0,0,0,112,248,18,0,0,0,0,0,112,248,18,0,0,0,0,0,6,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,43,1,0,0,255,255,255,255,1,0,0,0,255,255,255,255,42,0,0,0,255,255,255,255,0,0,0,0,55,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,82,0,0,0,84,0,0,0,86,0,0,0,58,1,0,0,60,1,0,0,8,0,0,0,32,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,61,1,0,0,66,0,0,0,70,0,0,0,72,0,0,0,46,1,0,0,48,1,0,0,54,0,0,0,80,0,0,0,74,0,0,0,50,1,0,0,52,1,0,0,56,0,0,0,76,0,0,0,78,0,0,0,54,1,0,0,56,1,0,0,58,0,0,0,92,0,0,0,98,0,0,0,104,0,0,0,94,0,0,0,100,0,0,0,106,0,0,0,96,0,0,0,102,0,0,0,108,0,0,0,2,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,48,228,18,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,56,82,22,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,0,0,0,255,255,255,255,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,111,22,0,0,0,0,0,0,0,0,0,255,255,255,255,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,16,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,232,8,18,0,0,0,0,0,7,6,8,5,9,4,10,3,11,2,12,1,13,0,14,0,6,5,7,4,8,3,9,2,10,1,11,0,12,0,0,0,2,1,3,0,4,0,0,0,1,0,0,0,255,255,255,255,6,5,7,4,8,3,9,2,10,1,11,0,12,0,0,0,1,0,0,0,255,255,255,255,248,81,22,0,0,0,0,0,5,4,6,3,7,2,8,1,9,0,10,0,0,0,0,0,1,0,2,0,0,0,0,0,7,0,0,0,6,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,2,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,16,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,11,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,30,0,0,0,28,0,0,0,27,0,0,0,29,0,0,0,2,0,0,0,3,0,0,0,43,0,0,0,44,0,0,0,47,0,0,0,48,0,0,0,45,0,0,0,46,0,0,0,49,0,0,0,50,0,0,0,22,0,0,0,19,0,0,0,24,0,0,0,21,0,0,0,11,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,6,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,4,3,5,2,6,1,7,0,8,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,248,111,22,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,6,0,0,0,0,0,0,7,6,0,0,0,0,0,0,15,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,0,0,0,255,255,255,255,43,1,0,0,255,255,255,255,5,0,0,0,255,255,255,255,74,0,0,0,255,255,255,255,2,0,0,0,28,0,0,0,4,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,11,0,0,0,8,0,0,0,66,0,0,0,32,0,0,0,10,0,0,0,9,0,0,0,0,0,0,0,4,0,0,0,33,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,42,0,0,0,28,0,0,0,36,1,0,0,255,255,255,255,0,0,0,0,4,3,5,2,6,1,7,0,8,0,0,0,0,0,0,0,3,0,0,0,30,0,0,0,46,0,0,0,8,0,0,0,11,0,0,0,255,255,255,255,5,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,2,1,3,0,4,0,0,0,12,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,3,0,0,0,11,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,5,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,5,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,28,0,0,0,42,0,0,0,41,0,0,0,36,1,0,0,35,1,0,0,32,0,0,0,31,0,0,0,8,0,0,0,255,255,255,255,128,187,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,64,31,0,0,0,0,0,0,42,0,0,0,255,255,255,255,2,0,0,0,45,0,0,0,27,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,74,0,0,0,78,0,0,0,102,0,0,0,255,255,255,255,74,0,0,0,255,255,255,255,2,1,3,0,4,0,0,0,8,0,0,0,31,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,255,255,255,255,2,0,0,0,28,0,0,0,41,0,0,0,35,1,0,0,11,0,0,0,8,0,0,0,66,0,0,0,31,0,0,0,10,0,0,0,255,255,255,255,2,0,0,0,22,0,0,0,19,0,0,0,24,0,0,0,21,0,0,0,8,0,0,0,11,0,0,0,10,0,0,0,255,255,255,255,0,0,0,0,232,8,18,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,28,0,0,0,41,0,0,0,35,1,0,0,8,0,0,0,66,0,0,0,31,0,0,0,10,0,0,0,255,255,255,255,0,0,0,0,3,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,46,0,0,0,255,255,255,255,1,0,2,0,0,0,0,0,0,0,0,0,255,255,255,255,68,172,0,0,128,187,0,0,0,125,0,0,34,86,0,0,192,93,0,0,128,62,0,0,0,0,0,0,0,0,0,0,68,172,0,0,128,187,0,0,0,125,0,0,34,86,0,0,192,93,0,0,128,62,0,0,0,0,0,0,0,0,0,0,8,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,12,0,0,0,13,0,0,0,14,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,3,0,0,0,30,0,0,0,42,1,0,0,12,0,0,0,14,0,0,0,13,0,0,0,0,0,0,0,5,0,0,0,4,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,3,0,0,0,2,0,0,0,8,0,0,0,32,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,5,0,0,0,8,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,184,207,34,0,108,0,0,0,144,88,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,4,0,0,0,2,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,22,0,0,0,19,0,0,0,24,0,0,0,21,0,0,0,8,0,0,0,11,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,232,8,18,0,0,0,0,0,0,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,1,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,35,0,0,0,44,1,0,0,5,0,0,0,43,1,0,0,33,0,0,0,4,0,0,0,7,0,0,0,6,0,0,0,42,1,0,0,30,0,0,0,54,0,0,0,56,0,0,0,58,0,0,0,76,0,0,0,80,0,0,0,70,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,108,0,0,0,106,0,0,0,104,0,0,0,102,0,0,0,100,0,0,0,98,0,0,0,96,0,0,0,94,0,0,0,92,0,0,0,32,0,0,0,8,0,0,0,84,0,0,0,86,0,0,0,58,1,0,0,60,1,0,0,255,255,255,255,8,0,0,0,255,255,255,255,7,0,0,0,4,0,0,0,0,0,0,0,255,255,255,255,8,0,0,0,2,0,0,0,28,0,0,0,29,0,0,0,32,0,0,0,31,0,0,0,42,0,0,0,41,0,0,0,36,1,0,0,35,1,0,0,86,0,0,0,85,0,0,0,58,1,0,0,57,1,0,0,255,255,255,255,0,0,0,0,4,0,0,0,74,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,2,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,30,0,0,0,3,0,0,0,44,0,0,0,46,0,0,0,62,0,0,0,22,0,0,0,19,0,0,0,24,0,0,0,21,0,0,0,8,0,0,0,11,0,0,0,10,0,0,0,255,255,255,255,0,0,0,0,17,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,5,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,48,228,18,0,232,29,28,0,0,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,136,248,18,0,0,0,0,0,56,249,18,0,0,0,0,0,9,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,8,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,0,197,28,0,108,0,0,0,144,88,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,111,22,0,232,238,18,0,48,228,18,0,0,0,0,0,114,101,115,105,100,117,101,95,101,110,99,111,100,101,0,0,114,101,97,100,121,95,114,101,115,105,100,117,101,0,0,0,112,117,116,95,118,101,99,116,111,114,0,0,0,0,0,0,111,117,116,112,117,116,95,112,97,99,107,101,116,0,0,0,109,112,101,103,95,109,117,120,95,101,110,100,0,0,0,0,105,110,105,116,95,112,97,115,115,50,0,0,0,0,0,0,103,101,116,95,113,109,105,110,109,97,120,0,0,0,0,0,102,108,117,115,104,95,112,97,99,107,101,116,0,0,0,0,102,108,111,111,114,95,101,110,99,111,100,101,0,0,0,0,102,102,95,114,97,116,101,95,101,115,116,105,109,97,116,101,95,113,115,99,97,108,101,0,102,102,95,114,97,116,101,95,99,111,110,116,114,111,108,95,105,110,105,116,0,0,0,0,97,115,102,95,114,101,97,100,95,112,97,99,107,101,116,0,97,115,102,95,112,97,114,115,101,95,112,97,99,107,101,116,0,0,0,0,0,0,0,0,2,0,0,192,3,0,0,192,4,0,0,192,5,0,0,192,6,0,0,192,7,0,0,192,8,0,0,192,9,0,0,192,10,0,0,192,11,0,0,192,12,0,0,192,13,0,0,192,14,0,0,192,15,0,0,192,16,0,0,192,17,0,0,192,18,0,0,192,19,0,0,192,20,0,0,192,21,0,0,192,22,0,0,192,23,0,0,192,24,0,0,192,25,0,0,192,26,0,0,192,27,0,0,192,28,0,0,192,29,0,0,192,30,0,0,192,31,0,0,192,0,0,0,179,1,0,0,195,2,0,0,195,3,0,0,195,4,0,0,195,5,0,0,195,6,0,0,195,7,0,0,195,8,0,0,195,9,0,0,195,10,0,0,195,11,0,0,195,12,0,0,195,13,0,0,211,14,0,0,195,15,0,0,195,0,0,12,187,1,0,12,195,2,0,12,195,3,0,12,195,4,0,12,211,0,0,0,0,14,0,14,0,24,0,39,0,40,0,41,0,58,0,100,0,141,0,179,0,219,0,24,1,102,1,184,1,17,2,184,2,184,2,17,2,184,1,102,1,24,1,219,0,179,0,141,0,100,0,58,0,41,0,40,0,39,0,24,0,14,0,14,0,244,255,18,0,41,0,64,0,112,0,198,0,99,1,98,4,98,4,99,1,198,0,112,0,64,0,41,0,18,0,244,255,252,255,30,0,137,0,70,2,70,2,137,0,30,0,252,255,234,255,183,1,183,1,234,255,0,130,128,0,0,0,0,0,0,128,0,0,2,130,128,0,2,128,128,0,2,130,0,0,2,0,0,0,0,128,0,0,0,2,0,0,0,130,128,0,2,130,128,0,0,2,0,0,2,2,128,0,2,128,128,0,0,0,128,0,2,0,0,0,2,2,0,0,0,2,128,0,0,2,128,0,0,130,0,0,0,130,0,0,0,128,128,0,0,128,128,0,2,2,128,0,2,128,0,0,2,0,128,0,2,0,128,0,2,128,0,0,0,0,0,0,2,2,0,0,2,130,0,0,0,0,128,0,0,128,0,0,2,130,128,0,2,0,0,0,0,128,128,0,0,130,128,0,0,0,128,0,0,0,128,0,0,2,0,0,2,128,128,0,0,128,0,0,0,130,0,0,2,0,128,0,0,2,0,0,2,0,0,0,2,2,128,0,2,130,0,0,2,130,128,0,2,128,0,0,0,128,128,0,2,2,128,0,2,0,128,0,2,2,0,0,2,130,0,0,0,130,128,0,2,2,0,0,0,2,128,0,0,2,128,0,0,0,0,0,2,128,0,0,0,130,0,0,0,0,0,0,2,128,128,0,16,64,8,64,0,64,0,64,0,64,0,0,16,64,8,0,0,0,8,0,16,0,0,0,16,0,8,64,16,64,0,64,16,0,0,64,16,64,8,64,0,64,8,64,0,0,0,64,0,64,0,64,0,0,8,0,16,0,0,0,16,0,8,64,0,64,8,0,16,0,8,0,16,64,0,64,0,0,0,0,0,0,0,64,0,64,0,0,16,64,8,0,0,0,8,64,16,0,8,0,16,0,0,64,0,0,0,0,0,64,8,0,16,64,0,0,0,64,8,64,0,0,8,64,16,64,0,0,0,0,0,0,16,64,8,0,16,0,8,64,0,0,8,0,16,64,0,64,0,0,8,64,0,64,8,64,0,64,0,0,0,0,8,64,0,64,0,64,16,0,0,0,16,64,8,64,16,64,8,0,16,0,0,0,0,64,0,0,0,0,0,64,16,64,0,0,0,64,8,64,0,0,8,0,16,0,0,64,16,0,8,0,16,64,0,64,16,0,0,64,16,0,8,0,0,64,8,0,0,0,0,0,0,64,0,64,16,64,0,0,0,0,0,64,16,0,8,64,16,64,8,64,0,64,8,0,4,1,0,0,0,1,1,4,0,0,0,0,4,0,1,4,0,1,0,4,0,0,0,0,4,1,1,0,0,1,0,4,4,0,1,0,4,0,0,4,4,0,0,4,0,0,1,0,4,1,1,4,4,0,1,0,0,0,1,4,4,1,0,0,0,0,0,4,4,0,0,0,0,1,1,4,0,1,0,0,0,1,1,0,0,0,1,4,4,0,1,4,4,1,1,0,4,1,0,4,0,1,1,0,0,0,1,0,4,1,0,4,4,0,0,0,4,1,1,4,0,1,0,0,0,0,0,4,0,1,1,4,0,0,0,4,4,0,1,0,4,1,0,0,0,0,1,0,0,1,1,4,0,1,0,4,0,0,0,0,0,1,0,0,4,0,1,0,4,1,1,4,0,1,0,4,4,0,0,4,0,1,0,0,0,0,0,0,4,0,1,4,4,1,0,4,0,0,1,0,0,0,0,4,4,1,1,4,4,0,0,0,4,1,1,0,0,1,1,0,4,0,0,4,0,0,1,4,4,1,0,4,4,1,0,0,0,0,1,4,4,1,1,0,4,0,0,0,4,0,1,4,0,1,1,0,0,16,64,128,64,16,0,128,64,16,0,128,64,0,0,0,64,16,64,0,64,0,64,128,0,0,64,128,0,16,0,128,0,0,0,0,0,16,64,0,0,16,64,0,64,16,64,128,64,0,0,128,0,0,0,0,64,0,64,0,0,0,64,128,0,0,0,128,0,16,0,0,0,0,64,0,0,16,64,128,64,0,0,0,0,0,64,0,0,16,0,128,64,16,0,0,64,0,64,128,0,0,0,128,64,16,0,0,64,0,64,0,0,16,0,0,64,16,64,0,64,16,64,128,64,0,0,128,64,0,64,0,0,0,64,128,0,16,64,0,64,16,64,128,64,0,0,128,0,0,0,0,0,0,0,0,0,16,64,0,64,16,0,0,64,0,64,0,64,0,64,128,0,0,0,128,0,16,64,128,64,16,0,128,64,16,0,128,64,0,0,0,64,16,64,128,64,0,0,128,0,0,0,128,0,16,0,0,0,0,64,128,0,16,0,128,64,16,64,0,64,0,64,128,0,16,0,128,64,16,0,0,0,0,64,0,0,16,64,128,64,0,0,0,0,0,64,0,0,16,0,0,64,16,64,0,128,0,0,0,128,0,4,1,0,0,4,1,128,0,0,33,0,0,4,0,128,0,0,0,0,0,0,32,0,0,4,1,128,0,4,32,0,0,4,0,128,0,0,1,128,0,4,32,128,0,0,33,0,0,4,33,128,0,4,0,0,0,0,32,0,0,0,1,0,0,4,32,0,0,4,32,0,0,0,0,128,0,0,32,128,0,4,33,128,0,4,33,128,0,0,1,0,0,4,33,128,0,0,32,0,0,0,0,0,0,0,33,128,0,4,1,0,0,0,1,0,0,0,33,128,0,4,0,0,0,4,0,128,0,0,33,128,0,0,0,0,0,0,1,0,0,0,32,0,0,4,1,128,0,0,33,128,0,4,32,128,0,0,1,0,0,0,32,0,0,4,33,128,0,4,1,128,0,4,32,128,0,0,0,0,0,0,1,0,0,4,33,128,0,4,33,128,0,4,0,0,0,0,33,128,0,4,33,0,0,4,1,0,0,0,0,0,0,4,32,0,0,0,33,128,0,4,0,128,0,0,1,128,0,0,32,0,0,4,0,0,0,0,0,0,0,4,32,128,0,4,1,128,0,0,32,8,0,0,16,0,0,32,16,0,32,0,0,8,32,32,16,0,0,32,16,8,0,0,0,8,32,32,16,0,0,32,0,0,32,0,16,8,32,32,0,0,0,32,0,8,0,0,16,8,0,32,0,0,32,0,16,0,0,0,16,8,32,0,0,0,0,0,0,8,0,32,0,8,32,0,16,0,32,0,0,0,32,32,0,8,32,0,16,8,0,0,0,8,0,32,16,8,0,32,16,0,0,0,0,8,32,32,0,0,32,32,16,8,32,0,0,0,32,32,0,0,32,32,16,0,0,0,16,0,32,0,16,8,0,0,0,8,0,32,16,0,32,32,0,8,32,32,16,0,0,32,0,8,32,0,0,8,0,0,16,0,0,32,0,0,32,0,16,0,0,0,16,8,32,0,0,8,0,0,16,8,32,32,16,0,32,32,0,0,0,32,16,8,32,32,0,0,32,32,16,0,0,0,0,8,0,32,16,8,0,0,0,0,32,0,0,0,0,32,16,8,32,32,0,0,32,0,0,8,0,32,0,8,32,0,16,0,0,0,0,0,32,32,16,0,0,0,16,8,0,32,0,8,32,0,16,0,0,16,0,1,0,16,2,1,4,0,2,0,0,0,0,0,4,0,0,1,4,0,2,1,4,16,0,0,4,16,2,1,4,16,2,0,0,16,0,0,0,0,0,1,0,0,2,1,0,0,0,0,0,0,2,1,0,16,2,1,4,0,0,0,4,0,2,1,4,16,0,1,0,16,0,0,4,0,2,1,0,0,2,0,0,16,2,0,4,16,2,1,0,16,0,0,0,16,2,0,4,0,0,1,4,0,0,1,4,16,2,0,4,16,0,1,0,0,0,0,0,0,2,0,4,16,0,0,0,0,2,0,4,16,0,0,0,16,0,1,4,0,2,1,4,0,2,1,0,16,2,1,0,16,2,1,0,0,0,1,0,16,0,0,0,0,2,0,4,0,2,0,0,16,0,0,4,16,2,1,4,0,0,1,4,16,0,0,4,16,2,1,4,0,0,1,0,0,2,1,4,16,2,0,0,16,2,0,4,16,0,0,0,0,0,1,0,0,0,1,4,16,2,0,0,0,0,1,4,16,0,0,0,16,2,0,4,0,0,1,0,0,2,0,4,0,2,0,4,0,0,1,0,16,0,32,8,0,8,0,8,0,0,0,0,2,0,32,8,2,8,0,0,0,8,32,8,0,8,32,0,0,0,0,0,0,8,32,0,2,0,0,0,2,8,32,8,2,8,0,8,2,0,0,8,2,8,32,8,2,0,0,8,0,0,32,0,0,0,0,0,2,8,32,0,0,8,0,8,0,8,32,8,0,0,0,8,2,0,32,0,2,0,32,0,2,8,0,8,2,8,32,8,0,0,0,0,0,0,0,0,0,0,32,0,2,8,32,0,0,8,0,8,0,8,32,8,2,0,0,0,2,0,32,8,2,0,0,0,2,0,0,8,2,8,0,8,0,0,32,0,0,0,32,0,2,8,0,8,0,0,32,8,2,0,0,8,0,8,32,0,0,0,32,0,0,8,0,0,2,8,32,0,2,8,0,0,0,8,0,0,2,0,32,8,0,8,0,0,0,0,32,8,2,8,32,0,2,0,32,0,0,8,0,0,2,8,0,8,0,8,32,8,0,8,0,0,0,0,32,8,2,8,0,8,2,0,0,8,2,0,32,8,0,0,32,8,0,0,32,0,2,0,0,0,0,8,0,8,2,8,42,0,0,0,62,0,0,0,100,114,97,99,0,0,0,0,117,0,0,0,65,67,45,51,1,0,0,0,3,80,1,0,66,83,83,68,1,0,0,0,26,0,1,0,68,84,83,49,1,0,0,0,4,80,1,0,68,84,83,50,1,0,0,0,4,80,1,0,68,84,83,51,1,0,0,0,4,80,1,0,72,69,86,67,0,0,0,0,53,54,50,72,75,76,86,65,2,0,0,0,65,86,76,75,86,67,45,49,0,0,0,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,9,11,13,14,15,63,7,7,11,12,14,15,63,63,9,11,13,14,15,63,63,63,11,11,13,14,63,63,63,63,11,13,14,63,63,63,63,63,13,14,63,63,63,63,63,63,13,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,4,5,6,7,9,11,13,15,5,5,7,8,11,13,15,17,6,7,9,11,13,15,15,17,7,7,9,11,13,15,17,19,7,9,11,13,14,16,19,23,9,11,13,14,16,19,23,29,9,11,13,15,17,21,28,35,11,13,16,17,21,28,35,41,4,4,5,5,6,7,7,9,4,4,5,6,7,7,9,9,5,5,6,7,7,9,9,10,5,5,6,7,7,9,9,10,5,6,7,7,8,9,10,12,6,7,7,8,9,10,12,15,6,7,7,9,10,11,14,17,7,7,9,10,11,14,17,21,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,4,4,4,4,4,4,5,5,4,4,4,4,4,5,5,6,4,4,4,4,5,5,6,7,4,4,4,4,5,6,7,7,4,7,9,11,13,14,63,63,7,7,11,12,14,63,63,63,9,11,13,14,63,63,63,63,11,11,13,14,63,63,63,63,11,13,14,63,63,63,63,63,13,14,63,63,63,63,63,63,13,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,4,5,6,7,9,11,13,15,5,5,7,8,11,13,15,17,6,7,9,11,13,15,15,17,7,7,9,11,13,15,17,19,7,9,11,13,14,16,19,23,9,11,13,14,16,19,23,29,9,11,13,15,17,21,28,35,11,13,16,17,21,28,35,41,4,4,5,5,6,7,7,9,4,4,5,6,7,7,9,9,5,5,6,7,7,9,9,10,5,5,6,7,7,9,9,10,5,6,7,7,8,9,10,12,6,7,7,8,9,10,12,15,6,7,7,9,10,11,14,17,7,7,9,10,11,14,17,21,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,4,4,4,4,4,4,5,5,4,4,4,4,4,5,5,6,4,4,4,4,5,5,6,7,4,4,4,4,5,6,7,7,42,39,45,32,55,51,53,28,41,50,35,46,33,37,44,52,30,48,40,49,29,36,43,54,15,4,25,19,9,1,26,16,5,11,23,8,12,7,17,0,22,3,10,14,6,20,27,24,7,15,23,31,39,47,55,63,6,14,22,30,38,46,54,62,5,13,21,29,37,45,53,61,4,12,20,28,1,9,17,25,33,41,49,57,2,10,18,26,34,42,50,58,3,11,19,27,35,43,51,59,36,44,52,60,20,0,0,0,34,0,0,0,11,0,0,0,17,0,0,0,71,0,0,0,91,0,0,0,30,0,0,0,50,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,3,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,3,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,1,0,0,0,6,0,0,0,7,0,0,0,129,0,0,0,1,0,0,0,3,80,1,0,138,0,0,0,1,0,0,0,4,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,76,86,65,2,0,0,0,65,86,76,75,73,68,51,32,2,0,0,0,51,68,73,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,216,0,67,0,226,0,70,0,236,0,74,0,246,0,77,0,1,1,80,0,12,1,84,0,24,1,88,0,38,1,92,0,51,1,96,0,65,1,100,0,78,1,104,0,94,1,109,0,109,1,114,0,126,1,119,0,143,1,124,0,160,1,130,0,178,1,136,0,198,1,142,0,219,1,148,0,239,1,155,0,7,2,162,0,29,2,169,0,52,2,176,0,78,2,185,0,105,2,193,0,132,2,201,0,161,2,210,0,191,2,220,0,223,2,230,0,255,2,240,0,33,3,251,0,70,3,6,1,108,3,18,1,146,3,30,1,187,3,43,1,229,3,56,1,17,4,70,1,65,4,85,1,114,4,100,1,164,4,116,1,217,4,132,1,17,5,150,1,74,5,168,1,135,5,187,1,198,5,206,1,8,6,227,1,77,6,249,1,148,6,15,2,224,6,39,2,46,7,64,2,129,7,89,2,215,7,116,2,49,8,144,2,142,8,174,2,240,8,204,2,85,9,236,2,192,9,13,3,47,10,48,3,164,10,85,3,30,11,123,3,157,11,162,3,32,12,204,3,171,12,248,3,61,13,37,4,211,13,84,4,114,14,134,4,22,15,185,4,195,15,240,4,120,16,40,5,51,17,99,5,247,17,161,5,198,18,225,5,155,19,36,6,124,20,106,6,101,21,179,6,90,22,0,7,90,23,80,7,101,24,163,7,122,25,251,7,157,26,86,8,206,27,181,8,12,29,25,9,87,30,128,9,178,31,237,9,29,33,95,10,150,34,213,10,34,36,81,11,191,37,210,11,110,39,90,12,50,41,231,12,8,43,122,13,244,44,20,14,244,46,181,14,12,49,93,15,62,51,12,16,135,53,196,16,235,55,131,17,105,58,75,18,5,61,28,19,190,63,247,19,150,66,219,20,143,69,201,21,170,72,194,22,233,75,198,23,76,79,214,24,213,82,242,25,136,86,26,27,101,90,80,28,109,94,147,29,164,98,229,30,12,103,70,32,165,107,183,33,114,112,56,35,120,117,203,36,181,122,111,38,255,127,38,40,255,127,241,41,255,127,208,43,255,127,197,45,255,127,208,47,255,127,242,49,255,127,44,52,255,127,129,54,255,127,240,56,255,127,122,59,255,127,34,62,255,127,231,64,255,127,238,255,140,0,140,0,238,255,37,0,116,0,206,0,74,1,39,0,121,0,216,0,90,1,41,0,127,0,225,0,105,1,42,0,132,0,235,0,121,1,44,0,137,0,245,0,136,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2353800);
/* memory initializer */ allocate([46,0,144,0,0,1,154,1,48,0,150,0,11,1,172,1,51,0,157,0,24,1,193,1,53,0,165,0,37,1,214,1,55,0,172,0,50,1,234,1,58,0,179,0,63,1,255,1,60,0,187,0,77,1,22,2,63,0,195,0,92,1,45,2,66,0,205,0,108,1,71,2,69,0,214,0,124,1,97,2,72,0,223,0,140,1,123,2,75,0,233,0,158,1,151,2,79,0,244,0,177,1,182,2,82,0,254,0,197,1,213,2,86,0,9,1,216,1,244,2,90,0,22,1,239,1,24,3,94,0,34,1,4,2,58,3,98,0,47,1,26,2,94,3,102,0,60,1,50,2,133,3,107,0,75,1,76,2,174,3,112,0,89,1,102,2,215,3,117,0,105,1,129,2,3,4,122,0,121,1,158,2,50,4,127,0,138,1,189,2,99,4,133,0,155,1,220,2,148,4,139,0,174,1,252,2,200,4,145,0,193,1,31,3,0,5,152,0,213,1,67,3,57,5,159,0,234,1,104,3,117,5,166,0,0,2,143,3,179,5,173,0,23,2,183,3,243,5,181,0,46,2,225,3,54,6,189,0,72,2,14,4,127,6,197,0,98,2,61,4,202,6,206,0,125,2,109,4,23,7,215,0,153,2,159,4,103,7,225,0,183,2,213,4,188,7,235,0,214,2,11,5,20,8,246,0,247,2,69,5,113,8,1,1,24,3,129,5,209,8,12,1,60,3,192,5,53,9,24,1,97,3,2,6,159,9,37,1,135,3,70,6,12,10,50,1,176,3,142,6,128,10,63,1,218,3,217,6,247,10,78,1,6,4,40,7,117,11,93,1,52,4,122,7,249,11,108,1,100,4,207,7,130,12,124,1,150,4,40,8,16,13,142,1,203,4,134,8,166,13,159,1,1,5,230,8,65,14,178,1,59,5,76,9,227,14,197,1,118,5,182,9,142,15,217,1,181,5,38,10,64,16,239,1,246,5,154,10,250,16,5,2,58,6,19,11,188,17,28,2,129,6,145,11,133,18,52,2,204,6,21,12,89,19,77,2,26,7,160,12,55,20,103,2,106,7,47,13,29,21,131,2,192,7,199,13,15,22,159,2,24,8,99,14,10,23,189,2,116,8,8,15,17,24,221,2,213,8,180,15,38,25,254,2,58,9,103,16,68,26,32,3,163,9,34,17,112,27,68,3,18,10,231,17,171,28,105,3,132,10,178,18,240,29,144,3,253,10,137,19,72,31,184,3,122,11,103,20,172,32,227,3,254,11,81,21,35,34,15,4,135,12,69,22,169,35,62,4,22,13,68,23,65,37,110,4,171,13,76,24,232,38,161,4,71,14,97,25,164,40,214,4,234,14,132,26,117,42,13,5,149,15,179,27,91,44,71,5,70,16,239,28,85,46,131,5,0,17,58,30,102,48,194,5,195,17,148,31,146,50,4,6,142,18,252,32,210,52,73,6,98,19,117,34,46,55,144,6,63,20,255,35,164,57,220,6,39,21,154,37,55,60,42,7,25,22,73,39,232,62,124,7,21,23,9,41,182,65,209,7,29,24,223,42,166,68,43,8,48,25,199,44,180,71,136,8,80,26,198,46,231,74,234,8,125,27,222,48,64,78,79,9,183,28,12,51,190,81,186,9,255,29,84,53,101,85,41,10,85,31,180,55,50,89,157,10,188,32,49,58,46,93,22,11,49,34,201,60,86,97,149,11,184,35,128,63,175,101,25,12,81,37,86,66,57,106,164,12,251,38,76,69,247,110,52,13,184,40,100,72,235,115,203,13,138,42,159,75,24,121,104,14,111,44,254,78,126,126,13,15,107,46,133,82,255,127,185,15,126,48,53,86,255,127,109,16,167,50,13,90,255,127,40,17,234,52,18,94,255,127,237,17,71,55,69,98,255,127,185,18,191,57,168,102,255,127,143,19,82,60,60,107,255,127,111,20,4,63,6,112,255,127,88,21,211,65,5,117,255,127,76,22,195,68,62,122,255,127,75,23,213,71,179,127,255,127,85,24,10,75,255,127,255,127,107,25,99,78,255,127,255,127,141,26,227,81,255,127,255,127,189,27,139,85,255,127,255,127,250,28,92,89,255,127,255,127,69,30,89,93,255,127,255,127,159,31,132,97,255,127,255,127,8,33,222,101,255,127,255,127,129,34,106,106,255,127,255,127,12,36,41,111,255,127,255,127,167,37,31,116,255,127,255,127,243,255,8,0,76,0,222,0,222,0,76,0,8,0,243,255,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,1,0,0,0,1,80,1,0,4,0,0,0,1,0,0,0,1,80,1,0,15,0,0,0,1,0,0,0,2,80,1,0,16,0,0,0,0,0,0,0,13,0,0,0,27,0,0,0,0,0,0,0,28,0,0,0,36,0,0,0,0,0,0,0,53,54,50,72,66,0,0,0,0,0,0,0,88,0,0,0,209,0,0,0,0,0,0,0,117,0,0,0,234,0,0,0,0,0,0,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,22,30,38,46,54,62,4,12,20,28,36,44,52,60,2,10,18,26,34,42,50,58,0,8,16,24,32,40,48,56,7,15,23,31,39,47,55,63,5,13,21,29,37,45,53,61,3,11,19,27,35,43,51,59,1,9,17,25,33,41,49,57,128,0,0,0,1,0,0,0,24,0,1,0,129,0,0,0,1,0,0,0,3,80,1,0,130,0,0,0,1,0,0,0,4,80,1,0,131,0,0,0,1,0,0,0,45,80,1,0,132,0,0,0,1,0,0,0,41,80,1,0,133,0,0,0,1,0,0,0,4,80,1,0,134,0,0,0,1,0,0,0,4,80,1,0,161,0,0,0,1,0,0,0,41,80,1,0,162,0,0,0,1,0,0,0,4,80,1,0,144,0,0,0,3,0,0,0,6,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,96,109,8,0,224,199,13,0,64,4,36,0,80,24,36,0,80,109,8,0,208,199,13,0,48,4,36,0,72,24,36,0,48,109,8,0,176,199,13,0,16,4,36,0,56,24,36,0,240,108,8,0,112,199,13,0,208,3,36,0,24,24,36,0,0,0,0,0,0,1,1,1,1,1,2,3,4,5,6,6,6,6,5,4,3,2,1,1,1,1,1,0,0,0,0,0,0,0,0,1,1,1,3,7,7,3,1,1,1,0,0,0,0,1,2,7,7,2,1,0,0,7,7,0,0,0,0,0,80,217,153,149,51,95,23,70,175,124,30,84,181,16,218,163,72,192,206,93,185,208,99,65,135,44,79,50,34,59,232,138,104,171,241,202,83,225,65,77,166,179,167,201,152,219,117,238,109,102,146,226,2,156,141,68,170,141,120,26,147,253,195,149,196,225,212,75,161,144,9,65,130,54,39,240,14,125,204,91,230,162,180,58,71,66,52,75,137,108,48,175,165,210,28,36,217,121,231,239,240,151,134,71,128,13,149,207,80,93,220,102,190,191,28,80,73,184,206,66,155,233,61,184,105,251,130,179,28,212,123,16,218,166,145,70,131,105,17,178,205,170,40,142,106,0,0,0,1,0,0,0,3,80,1,0,122,0,0,0,1,0,0,0,41,80,1,0,123,0,0,0,1,0,0,0,4,80,1,0,86,0,0,0,3,0,0,0,7,112,1,0,89,0,0,0,3,0,0,0,1,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,32,0,0,0,35,33,65,77,82,10,0,0,35,33,65,77,82,45,87,66,10,0,0,0,0,0,0,0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2364040);



var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}


  
  
  
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  
  
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value;
      return value;
    }
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  
  var MEMFS={ops_table:null,CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            },
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            if (canOwn && offset === 0) {
              node.contents = buffer; // this could be a subarray of Emscripten HEAP, or allocated from some other source.
              node.contentMode = (buffer.buffer === HEAP8.buffer) ? MEMFS.CONTENT_OWNING : MEMFS.CONTENT_FIXED;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          fileStore.createIndex('timestamp', 'timestamp', { unique: false });
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function() {
          callback(this.error);
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function() { callback(this.error); };
  
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');
  
          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;
  
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }
  
            entries[cursor.primaryKey] = { timestamp: cursor.key };
  
            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function() { callback(this.error); };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function() { done(this.error); };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so 
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          return flags;
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          stream.position = position;
          return position;
        }}};
  
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:null,genericErrors:{},handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); },
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); },
            },
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 2097155;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 2097155) !== 0 ||  // opening for write
              (flags & 512)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        if (stream.__proto__) {
          // reuse the object
          stream.__proto__ = FS.FSStream.prototype;
        } else {
          var newStream = new FS.FSStream();
          for (var p in stream) {
            newStream[p] = stream[p];
          }
          stream = newStream;
        }
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getStreamFromPtr:function (ptr) {
        return FS.streams[ptr - 1];
      },getPtrForStream:function (stream) {
        return stream ? stream.fd + 1 : 0;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            callback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = '';
          var utf8 = new Runtime.UTF8Processor();
          for (var i = 0; i < length; i++) {
            ret += utf8.processCChar(buf[i]);
          }
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var utf8 = new Runtime.UTF8Processor();
          var buf = new Uint8Array(utf8.processJSString(data));
          FS.write(stream, buf, 0, buf.length, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=FS.getPtrForStream(stdin);
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=FS.getPtrForStream(stdout);
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=FS.getPtrForStream(stderr);
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          function LazyUint8Array() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
  
              if (!hasByteServing) chunkSize = datalength;
  
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
  
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
  
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
  
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};
  
  
  
  
  function _mkport() { throw 'TODO' }var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
  
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
  
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
  
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
  
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
  
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
  
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
  
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              var url = 'ws://' + addr + ':' + port;
              // the node ws library API is slightly different than the browser's
              var opts = ENVIRONMENT_IS_NODE ? {headers: {'websocket-protocol': ['binary']}} : ['binary'];
              // If node we use the ws library.
              var WebSocket = ENVIRONMENT_IS_NODE ? require('ws') : window['WebSocket'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
  
  
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
  
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
  
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
  
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
  
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
  
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
  
  
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
  
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
  
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
  
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
  
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
  
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
  
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
  
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
  
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
  
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
  
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
  
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
  
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
  
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
  
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
  
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
  
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
  
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
  
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
  
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
  
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
  
  
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
  
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      return FS.getStreamFromPtr(stream).fd;
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var fd = _fileno(stream);
      var bytesWritten = _write(fd, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  
  
   
  Module["_strlen"] = _strlen;
  
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
  
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
  
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
  
          // Handle precision.
          var precisionSet = false, precision = -1;
          if (next == 46) {
            precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          }
          if (precision < 0) {
            precision = 6; // Standard default.
            precisionSet = false;
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
  
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
  
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
  
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
  
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
  
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
  
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
  
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
  
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
  
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
  
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
  
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
  
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length;
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }function _vfprintf(s, f, va_arg) {
      return _fprintf(s, f, HEAP32[((va_arg)>>2)]);
    }

  
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }

  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }

  
  
  
  
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
  
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'root';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/emscripten';
        ENV['LANG'] = 'en_US.UTF-8';
        ENV['_'] = './this.program';
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr;
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
  
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
  
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        writeAsciiToMemory(line, poolPtr);
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
  
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }


  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr;
      var fd = _fileno(stream);
      var ret = _write(fd, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }


  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }


  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }

  
  
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
  
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
  
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
  
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
  
      // Apply sign.
      ret *= multiplier;
  
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str;
      }
  
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
  
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
  
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)),ret>>>0)|0);
      }
  
      return ret;
    }function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }

  function _setrlimit(resource, rlp) {
      // int setrlimit(int resource, const struct rlimit *rlp)
      return 0;
    }

  
  
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      var fd = _fileno(stream);
      return _write(fd, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  
  
  function _strerror_r(errnum, strerrbuf, buflen) {
      if (errnum in ERRNO_MESSAGES) {
        if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
          return ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          var msg = ERRNO_MESSAGES[errnum];
          writeAsciiToMemory(msg, strerrbuf);
          return 0;
        }
      } else {
        return ___setErrNo(ERRNO_CODES.EINVAL);
      }
    }function _strerror(errnum) {
      if (!_strerror.buffer) _strerror.buffer = _malloc(256);
      _strerror_r(errnum, _strerror.buffer, 256);
      return _strerror.buffer;
    }
  
  function ___errno_location() {
      return ___errno_state;
    }function _perror(s) {
      // void perror(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/perror.html
      var stdout = HEAP32[((_stdout)>>2)];
      if (s) {
        _fputs(s, stdout);
        _fputc(58, stdout);
        _fputc(32, stdout);
      }
      var errnum = HEAP32[((___errno_location())>>2)];
      _puts(_strerror(errnum));
    }


  
  
  
  
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)|0)]=streamObj.ungotten.pop();
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(streamObj.fd, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }function _getchar() {
      // int getchar(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getchar.html
      return _fgetc(HEAP32[((_stdin)>>2)]);
    }


  
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var fd = _fileno(stream);
      var ret = _lseek(fd, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStreamFromPtr(stream);
      stream.eof = false;
      return 0;
    }

  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }

  
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      var fd = _fileno(stream);
      _fsync(fd);
      return _close(fd);
    }


  function _ferror(stream) {
      // int ferror(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ferror.html
      stream = FS.getStreamFromPtr(stream);
      return Number(stream && stream.error);
    }

  
  function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 512;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 1024;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var fd = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return fd === -1 ? 0 : FS.getPtrForStream(FS.getStream(fd));
    }

  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }

  
   
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;

  function _abort() {
      Module['abort']();
    }

  
  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 
  Module["_memcpy"] = _memcpy;function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return Module['dynCall_iii'](cmp, base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }

  var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;

  
  var ___strtok_state=0;
  
  function _strtok_r(s, delim, lasts) {
      var skip_leading_delim = 1;
      var spanp;
      var c, sc;
      var tok;
  
  
      if (s == 0 && (s = getValue(lasts, 'i8*')) == 0) {
        return 0;
      }
  
      cont: while (1) {
        c = getValue(s++, 'i8');
        for (spanp = delim; (sc = getValue(spanp++, 'i8')) != 0;) {
          if (c == sc) {
            if (skip_leading_delim) {
              continue cont;
            } else {
              setValue(lasts, s, 'i8*');
              setValue(s - 1, 0, 'i8');
              return s - 1;
            }
          }
        }
        break;
      }
  
      if (c == 0) {
        setValue(lasts, 0, 'i8*');
        return 0;
      }
      tok = s - 1;
  
      for (;;) {
        c = getValue(s++, 'i8');
        spanp = delim;
        do {
          if ((sc = getValue(spanp++, 'i8')) == c) {
            if (c == 0) {
              s = 0;
            } else {
              setValue(s - 1, 0, 'i8');
            }
            setValue(lasts, s, 'i8*');
            return tok;
          }
        } while (sc != 0);
      }
      abort('strtok_r error!');
    }function _strtok(s, delim) {
      return _strtok_r(s, delim, ___strtok_state);
    }

  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  
  var ___tm_current=allocate(44, "i8", ALLOC_STATIC);
  
  
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  
  
  var _tzname=allocate(8, "i32*", ALLOC_STATIC);
  
  var _daylight=allocate(1, "i32*", ALLOC_STATIC);
  
  var _timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
  
      HEAP32[((_timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60;
  
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((_daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset());
  
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((_tzname)>>2)]=winterNamePtr;
      HEAP32[(((_tzname)+(4))>>2)]=summerNamePtr;
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();
  
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(36))>>2)]=start.getTimezoneOffset() * 60;
  
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(32))>>2)]=dst;
  
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone;
  
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }

  var _llvm_memset_p0i8_i64=_memset;

  function _llvm_va_copy(ppdest, ppsrc) {
      // copy the list start
      HEAP8[(ppdest)]=HEAP8[(ppsrc)];HEAP8[(((ppdest)+(1))|0)]=HEAP8[(((ppsrc)+(1))|0)];HEAP8[(((ppdest)+(2))|0)]=HEAP8[(((ppsrc)+(2))|0)];HEAP8[(((ppdest)+(3))|0)]=HEAP8[(((ppsrc)+(3))|0)];
      
      // copy the list's current offset (will be advanced with each call to va_arg)
      HEAP8[((ppdest+4)|0)]=HEAP8[((ppsrc+4)|0)];HEAP8[(((ppdest+4)+(1))|0)]=HEAP8[(((ppsrc+4)+(1))|0)];HEAP8[(((ppdest+4)+(2))|0)]=HEAP8[(((ppsrc+4)+(2))|0)];HEAP8[(((ppdest+4)+(3))|0)]=HEAP8[(((ppsrc+4)+(3))|0)];
    }

  function _llvm_va_end() {}



  function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    }

  function _llvm_lifetime_start() {}

  function _llvm_lifetime_end() {}


  function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))|0)]=byte_;
      }
      HEAP8[(((s)+(i))|0)]=0;
      return s;
    }

  function _strcspn(pstr, pset) {
      var str = pstr, set, strcurr, setcurr;
      while (1) {
        strcurr = HEAP8[(str)];
        if (!strcurr) return str - pstr;
        set = pset;
        while (1) {
          setcurr = HEAP8[(set)];
          if (!setcurr || setcurr == strcurr) break;
          set++;
        }
        if (setcurr) return str - pstr;
        str++;
      }
    }

  
  function _gmtime_r(time, tmPtr) {
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getUTCSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getUTCMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getUTCHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getUTCDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getUTCMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getUTCFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getUTCDay();
      HEAP32[(((tmPtr)+(36))>>2)]=0;
      HEAP32[(((tmPtr)+(32))>>2)]=0;
      var start = new Date(date); // define date using UTC, start from Jan 01 00:00:00 UTC
      start.setUTCDate(1);
      start.setUTCMonth(0);
      start.setUTCHours(0);
      start.setUTCMinutes(0);
      start.setUTCSeconds(0);
      start.setUTCMilliseconds(0);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone;
  
      return tmPtr;
    }function _gmtime(time) {
      return _gmtime_r(time, ___tm_current);
    }

  
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  
  
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
  
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
  
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
      
      var date = {
        tm_sec: HEAP32[((tm)>>2)],
        tm_min: HEAP32[(((tm)+(4))>>2)],
        tm_hour: HEAP32[(((tm)+(8))>>2)],
        tm_mday: HEAP32[(((tm)+(12))>>2)],
        tm_mon: HEAP32[(((tm)+(16))>>2)],
        tm_year: HEAP32[(((tm)+(20))>>2)],
        tm_wday: HEAP32[(((tm)+(24))>>2)],
        tm_yday: HEAP32[(((tm)+(28))>>2)],
        tm_isdst: HEAP32[(((tm)+(32))>>2)]
      };
  
      var pattern = Pointer_stringify(format);
  
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
  
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
  
      function leadingSomething(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
  
      function leadingNulls(value, digits) {
        return leadingSomething(value, digits, '0');
      };
  
      function compareByDay(date1, date2) {
        function sgn(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
  
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
  
      function getFirstWeekStartDate(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
  
      function getWeekBasedYear(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
  
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls(Math.floor(year/100),2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
  
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
  
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
  
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
  
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ),
          // or by no characters if no timezone is determinable. 
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich). 
          // If tm_isdst is zero, the standard time offset is used. 
          // If tm_isdst is greater than zero, the daylight savings time offset is used. 
          // If tm_isdst is negative, no characters are returned. 
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%Z': function(date) {
          // Replaced by the timezone name or abbreviation, or by no bytes if no timezone information exists. [ tm_isdst]
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
  
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
  
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }

  
  
  function __getFloat(text) {
      return /^[+-]?[0-9]*\.?[0-9]+([eE][+-]?[0-9]+)?/.exec(text);
    }function __scanString(format, get, unget, varargs) {
      if (!__scanString.whiteSpace) {
        __scanString.whiteSpace = {};
        __scanString.whiteSpace[32] = 1;
        __scanString.whiteSpace[9] = 1;
        __scanString.whiteSpace[10] = 1;
        __scanString.whiteSpace[11] = 1;
        __scanString.whiteSpace[12] = 1;
        __scanString.whiteSpace[13] = 1;
      }
      // Supports %x, %4x, %d.%d, %lld, %s, %f, %lf.
      // TODO: Support all format specifiers.
      format = Pointer_stringify(format);
      var soFar = 0;
      if (format.indexOf('%n') >= 0) {
        // need to track soFar
        var _get = get;
        get = function get() {
          soFar++;
          return _get();
        }
        var _unget = unget;
        unget = function unget() {
          soFar--;
          return _unget();
        }
      }
      var formatIndex = 0;
      var argsi = 0;
      var fields = 0;
      var argIndex = 0;
      var next;
  
      mainLoop:
      for (var formatIndex = 0; formatIndex < format.length;) {
        if (format[formatIndex] === '%' && format[formatIndex+1] == 'n') {
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          HEAP32[((argPtr)>>2)]=soFar;
          formatIndex += 2;
          continue;
        }
  
        if (format[formatIndex] === '%') {
          var nextC = format.indexOf('c', formatIndex+1);
          if (nextC > 0) {
            var maxx = 1;
            if (nextC > formatIndex+1) {
              var sub = format.substring(formatIndex+1, nextC);
              maxx = parseInt(sub);
              if (maxx != sub) maxx = 0;
            }
            if (maxx) {
              var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
              argIndex += Runtime.getAlignSize('void*', null, true);
              fields++;
              for (var i = 0; i < maxx; i++) {
                next = get();
                HEAP8[((argPtr++)|0)]=next;
                if (next === 0) return i > 0 ? fields : fields-1; // we failed to read the full length of this field
              }
              formatIndex += nextC - formatIndex + 1;
              continue;
            }
          }
        }
  
        // handle %[...]
        if (format[formatIndex] === '%' && format.indexOf('[', formatIndex+1) > 0) {
          var match = /\%([0-9]*)\[(\^)?(\]?[^\]]*)\]/.exec(format.substring(formatIndex));
          if (match) {
            var maxNumCharacters = parseInt(match[1]) || Infinity;
            var negateScanList = (match[2] === '^');
            var scanList = match[3];
  
            // expand "middle" dashs into character sets
            var middleDashMatch;
            while ((middleDashMatch = /([^\-])\-([^\-])/.exec(scanList))) {
              var rangeStartCharCode = middleDashMatch[1].charCodeAt(0);
              var rangeEndCharCode = middleDashMatch[2].charCodeAt(0);
              for (var expanded = ''; rangeStartCharCode <= rangeEndCharCode; expanded += String.fromCharCode(rangeStartCharCode++));
              scanList = scanList.replace(middleDashMatch[1] + '-' + middleDashMatch[2], expanded);
            }
  
            var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
            argIndex += Runtime.getAlignSize('void*', null, true);
            fields++;
  
            for (var i = 0; i < maxNumCharacters; i++) {
              next = get();
              if (negateScanList) {
                if (scanList.indexOf(String.fromCharCode(next)) < 0) {
                  HEAP8[((argPtr++)|0)]=next;
                } else {
                  unget();
                  break;
                }
              } else {
                if (scanList.indexOf(String.fromCharCode(next)) >= 0) {
                  HEAP8[((argPtr++)|0)]=next;
                } else {
                  unget();
                  break;
                }
              }
            }
  
            // write out null-terminating character
            HEAP8[((argPtr++)|0)]=0;
            formatIndex += match[0].length;
            
            continue;
          }
        }      
        // remove whitespace
        while (1) {
          next = get();
          if (next == 0) return fields;
          if (!(next in __scanString.whiteSpace)) break;
        }
        unget();
  
        if (format[formatIndex] === '%') {
          formatIndex++;
          var suppressAssignment = false;
          if (format[formatIndex] == '*') {
            suppressAssignment = true;
            formatIndex++;
          }
          var maxSpecifierStart = formatIndex;
          while (format[formatIndex].charCodeAt(0) >= 48 &&
                 format[formatIndex].charCodeAt(0) <= 57) {
            formatIndex++;
          }
          var max_;
          if (formatIndex != maxSpecifierStart) {
            max_ = parseInt(format.slice(maxSpecifierStart, formatIndex), 10);
          }
          var long_ = false;
          var half = false;
          var longLong = false;
          if (format[formatIndex] == 'l') {
            long_ = true;
            formatIndex++;
            if (format[formatIndex] == 'l') {
              longLong = true;
              formatIndex++;
            }
          } else if (format[formatIndex] == 'h') {
            half = true;
            formatIndex++;
          }
          var type = format[formatIndex];
          formatIndex++;
          var curr = 0;
          var buffer = [];
          // Read characters according to the format. floats are trickier, they may be in an unfloat state in the middle, then be a valid float later
          if (type == 'f' || type == 'e' || type == 'g' ||
              type == 'F' || type == 'E' || type == 'G') {
            next = get();
            while (next > 0 && (!(next in __scanString.whiteSpace)))  {
              buffer.push(String.fromCharCode(next));
              next = get();
            }
            var m = __getFloat(buffer.join(''));
            var last = m ? m[0].length : 0;
            for (var i = 0; i < buffer.length - last + 1; i++) {
              unget();
            }
            buffer.length = last;
          } else {
            next = get();
            var first = true;
            
            // Strip the optional 0x prefix for %x.
            if ((type == 'x' || type == 'X') && (next == 48)) {
              var peek = get();
              if (peek == 120 || peek == 88) {
                next = get();
              } else {
                unget();
              }
            }
            
            while ((curr < max_ || isNaN(max_)) && next > 0) {
              if (!(next in __scanString.whiteSpace) && // stop on whitespace
                  (type == 's' ||
                   ((type === 'd' || type == 'u' || type == 'i') && ((next >= 48 && next <= 57) ||
                                                                     (first && next == 45))) ||
                   ((type === 'x' || type === 'X') && (next >= 48 && next <= 57 ||
                                     next >= 97 && next <= 102 ||
                                     next >= 65 && next <= 70))) &&
                  (formatIndex >= format.length || next !== format[formatIndex].charCodeAt(0))) { // Stop when we read something that is coming up
                buffer.push(String.fromCharCode(next));
                next = get();
                curr++;
                first = false;
              } else {
                break;
              }
            }
            unget();
          }
          if (buffer.length === 0) return 0;  // Failure.
          if (suppressAssignment) continue;
  
          var text = buffer.join('');
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          switch (type) {
            case 'd': case 'u': case 'i':
              if (half) {
                HEAP16[((argPtr)>>1)]=parseInt(text, 10);
              } else if (longLong) {
                (tempI64 = [parseInt(text, 10)>>>0,(tempDouble=parseInt(text, 10),(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[((argPtr)>>2)]=tempI64[0],HEAP32[(((argPtr)+(4))>>2)]=tempI64[1]);
              } else {
                HEAP32[((argPtr)>>2)]=parseInt(text, 10);
              }
              break;
            case 'X':
            case 'x':
              HEAP32[((argPtr)>>2)]=parseInt(text, 16);
              break;
            case 'F':
            case 'f':
            case 'E':
            case 'e':
            case 'G':
            case 'g':
            case 'E':
              // fallthrough intended
              if (long_) {
                HEAPF64[((argPtr)>>3)]=parseFloat(text);
              } else {
                HEAPF32[((argPtr)>>2)]=parseFloat(text);
              }
              break;
            case 's':
              var array = intArrayFromString(text);
              for (var j = 0; j < array.length; j++) {
                HEAP8[(((argPtr)+(j))|0)]=array[j];
              }
              break;
          }
          fields++;
        } else if (format[formatIndex].charCodeAt(0) in __scanString.whiteSpace) {
          next = get();
          while (next in __scanString.whiteSpace) {
            if (next <= 0) break mainLoop;  // End of input.
            next = get();
          }
          unget(next);
          formatIndex++;
        } else {
          // Not a specifier.
          next = get();
          if (format[formatIndex].charCodeAt(0) !== next) {
            unget(next);
            break mainLoop;
          }
          formatIndex++;
        }
      }
      return fields;
    }function _sscanf(s, format, varargs) {
      // int sscanf(const char *restrict s, const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var index = 0;
      function get() { return HEAP8[(((s)+(index++))|0)]; };
      function unget() { index--; };
      return __scanString(format, get, unget, varargs);
    }

  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }

  function _signal(sig, func) {
      // TODO
      return 0;
    }

  function _atoi(ptr) {
      return _strtol(ptr, null, 10);
    }

  function _tcsetattr(fildes, optional_actions, termios_p) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/tcsetattr.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return -1;
      }
      return 0;
    }

  function _isatty(fildes) {
      // int isatty(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/isatty.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // HACK - implement tcgetattr
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return 0;
      }
      return 1;
    }

  function _tcgetattr(fildes, termios_p) {
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/tcgetattr.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return -1;
      }
      return 0;
    }

  function _setvbuf(stream, buf, type, size) {
      // int setvbuf(FILE *restrict stream, char *restrict buf, int type, size_t size);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/setvbuf.html
      // TODO: Implement custom buffering.
      return 0;
    }

  var _log=Math_log;

  var _llvm_va_start=undefined;

  function _vsnprintf(s, n, format, va_arg) {
      return _snprintf(s, n, format, HEAP32[((va_arg)>>2)]);
    }

  
  function _rint(x) {
      if (Math.abs(x % 1) !== 0.5) return Math.round(x);
      return x + x % 2 + ((x < 0) ? 1 : -1);
    }var _lrintf=_rint;

  function _log2(x) {
      return Math.log(x) / Math.LN2;
    }

  var _lrint=_rint;

  
  
  function _ungetc(c, stream) {
      // int ungetc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ungetc.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        return -1;
      }
      if (c === -1) {
        // do nothing for EOF character
        return c;
      }
      c = unSign(c & 0xFF);
      stream.ungotten.push(c);
      stream.eof = false;
      return c;
    }function _fscanf(stream, format, varargs) {
      // int fscanf(FILE *restrict stream, const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) {
        return -1;
      }
      var buffer = [];
      function get() {
        var c = _fgetc(stream);
        buffer.push(c);
        return c;
      };
      function unget() {
        _ungetc(buffer.pop(), stream);
      };
      return __scanString(format, get, unget, varargs);
    }function _scanf(format, varargs) {
      // int scanf(const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var stdin = HEAP32[((_stdin)>>2)];
      return _fscanf(stdin, format, varargs);
    }

  
  var ___DEFAULT_POLLMASK=5;function _select(nfds, readfds, writefds, exceptfds, timeout) {
      // readfds are supported,
      // writefds checks socket open status
      // exceptfds not supported
      // timeout is always 0 - fully async
      assert(nfds <= 64, 'nfds must be less than or equal to 64');  // fd sets have 64 bits
      assert(!exceptfds, 'exceptfds not supported');
  
      var total = 0;
      
      var srcReadLow = (readfds ? HEAP32[((readfds)>>2)] : 0),
          srcReadHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0);
      var srcWriteLow = (writefds ? HEAP32[((writefds)>>2)] : 0),
          srcWriteHigh = (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0);
      var srcExceptLow = (exceptfds ? HEAP32[((exceptfds)>>2)] : 0),
          srcExceptHigh = (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);
  
      var dstReadLow = 0,
          dstReadHigh = 0;
      var dstWriteLow = 0,
          dstWriteHigh = 0;
      var dstExceptLow = 0,
          dstExceptHigh = 0;
  
      var allLow = (readfds ? HEAP32[((readfds)>>2)] : 0) |
                   (writefds ? HEAP32[((writefds)>>2)] : 0) |
                   (exceptfds ? HEAP32[((exceptfds)>>2)] : 0);
      var allHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0) |
                    (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0) |
                    (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);
  
      function get(fd, low, high, val) {
        return (fd < 32 ? (low & val) : (high & val));
      }
  
      for (var fd = 0; fd < nfds; fd++) {
        var mask = 1 << (fd % 32);
        if (!(get(fd, allLow, allHigh, mask))) {
          continue;  // index isn't in the set
        }
  
        var stream = FS.getStream(fd);
        if (!stream) {
          ___setErrNo(ERRNO_CODES.EBADF);
          return -1;
        }
  
        var flags = ___DEFAULT_POLLMASK;
  
        if (stream.stream_ops.poll) {
          flags = stream.stream_ops.poll(stream);
        }
  
        if ((flags & 1) && get(fd, srcReadLow, srcReadHigh, mask)) {
          fd < 32 ? (dstReadLow = dstReadLow | mask) : (dstReadHigh = dstReadHigh | mask);
          total++;
        }
        if ((flags & 4) && get(fd, srcWriteLow, srcWriteHigh, mask)) {
          fd < 32 ? (dstWriteLow = dstWriteLow | mask) : (dstWriteHigh = dstWriteHigh | mask);
          total++;
        }
        if ((flags & 2) && get(fd, srcExceptLow, srcExceptHigh, mask)) {
          fd < 32 ? (dstExceptLow = dstExceptLow | mask) : (dstExceptHigh = dstExceptHigh | mask);
          total++;
        }
      }
  
      if (readfds) {
        HEAP32[((readfds)>>2)]=dstReadLow;
        HEAP32[(((readfds)+(4))>>2)]=dstReadHigh;
      }
      if (writefds) {
        HEAP32[((writefds)>>2)]=dstWriteLow;
        HEAP32[(((writefds)+(4))>>2)]=dstWriteHigh;
      }
      if (exceptfds) {
        HEAP32[((exceptfds)>>2)]=dstExceptLow;
        HEAP32[(((exceptfds)+(4))>>2)]=dstExceptHigh;
      }
      
      return total;
    }


  function _getrusage(resource, rlp) {
      // int getrusage(int resource, struct rusage *rlp);
      HEAP32[((rlp)>>2)]=1;
      HEAP32[(((rlp)+(4))>>2)]=2;
      HEAP32[(((rlp)+(8))>>2)]=3;
      HEAP32[(((rlp)+(12))>>2)]=4;
      return 0;
    }

  var _cos=Math_cos;

  var _sqrt=Math_sqrt;

  var _sin=Math_sin;

  function _hypot(a, b) {
       return Math.sqrt(a*a + b*b);
    }

  function _cbrt(x) {
      return Math.pow(x, 1/3);
    }

  
   
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;


  var _sqrtf=Math_sqrt;

  var _fabs=Math_abs;

  var _ceilf=Math_ceil;

  function _strspn(pstr, pset) {
      var str = pstr, set, strcurr, setcurr;
      while (1) {
        strcurr = HEAP8[(str)];
        if (!strcurr) return str - pstr;
        set = pset;
        while (1) {
          setcurr = HEAP8[(set)];
          if (!setcurr || setcurr == strcurr) break;
          set++;
        }
        if (!setcurr) return str - pstr;
        str++;
      }
    }

  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }

  function _llvm_bswap_i16(x) {
      return ((x&0xff)<<8) | ((x>>8)&0xff);
    }

  var _atan2=Math_atan2;

  var _llvm_pow_f64=Math_pow;

  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }

  var _floor=Math_floor;

  function _log10(x) {
      return Math.log(x) / Math.LN10;
    }

  var _exp=Math_exp;

  var _fabsf=Math_abs;

  function _sinh(x) {
      var p = Math.pow(Math.E, x);
      return (p - (1 / p)) / 2;
    }

  function ___assert_fail(condition, filename, line, func) {
      ABORT = true;
      throw 'Assertion failed: ' + Pointer_stringify(condition) + ', at: ' + [filename ? Pointer_stringify(filename) : 'unknown filename', line, func ? Pointer_stringify(func) : 'unknown function'] + ' at ' + stackTrace();
    }

  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }

   
  Module["_strcpy"] = _strcpy;

  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x+y > 4294967295),(x+y)>>>0)|0);
    }

  function _bsearch(key, base, num, size, compar) {
      function cmp(x, y) {
        return Module['dynCall_iii'](compar, x, y);
      };
      var left = 0;
      var right = num;
      var mid, test, addr;
  
      while (left < right) {
        mid = (left + right) >>> 1;
        addr = base + (mid * size);
        test = cmp(key, addr);
        if (test < 0) {
          right = mid;
        } else if (test > 0) {
          left = mid + 1;
        } else {
          return addr;
        }
      }
  
      return 0;
    }

  function _access(path, amode) {
      // int access(const char *path, int amode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/access.html
      path = Pointer_stringify(path);
      if (amode & ~7) {
        // need a valid mode
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      var perms = '';
      if (amode & 4) perms += 'r';
      if (amode & 2) perms += 'w';
      if (amode & 1) perms += 'x';
      if (perms /* otherwise, they've just passed F_OK */ && FS.nodePermissions(node, perms)) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      }
      return 0;
    }


  
  function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[((buf)>>2)]=stat.dev;
        HEAP32[(((buf)+(4))>>2)]=0;
        HEAP32[(((buf)+(8))>>2)]=stat.ino;
        HEAP32[(((buf)+(12))>>2)]=stat.mode;
        HEAP32[(((buf)+(16))>>2)]=stat.nlink;
        HEAP32[(((buf)+(20))>>2)]=stat.uid;
        HEAP32[(((buf)+(24))>>2)]=stat.gid;
        HEAP32[(((buf)+(28))>>2)]=stat.rdev;
        HEAP32[(((buf)+(32))>>2)]=0;
        HEAP32[(((buf)+(36))>>2)]=stat.size;
        HEAP32[(((buf)+(40))>>2)]=4096;
        HEAP32[(((buf)+(44))>>2)]=stat.blocks;
        HEAP32[(((buf)+(48))>>2)]=Math.floor(stat.atime.getTime() / 1000);
        HEAP32[(((buf)+(52))>>2)]=0;
        HEAP32[(((buf)+(56))>>2)]=Math.floor(stat.mtime.getTime() / 1000);
        HEAP32[(((buf)+(60))>>2)]=0;
        HEAP32[(((buf)+(64))>>2)]=Math.floor(stat.ctime.getTime() / 1000);
        HEAP32[(((buf)+(68))>>2)]=0;
        HEAP32[(((buf)+(72))>>2)]=stat.ino;
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fstat(fildes, buf) {
      // int fstat(int fildes, struct stat *buf);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/fstat.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      return _stat(stream.path, buf);
    }



  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _rename(old_path, new_path) {
      // int rename(const char *old, const char *new);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rename.html
      old_path = Pointer_stringify(old_path);
      new_path = Pointer_stringify(new_path);
      try {
        FS.rename(old_path, new_path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  
  function _mknod(path, mode, dev) {
      // int mknod(const char *path, mode_t mode, dev_t dev);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mknod.html
      path = Pointer_stringify(path);
      // we don't want this in the JS API as the JS API
      // uses mknod to create all nodes.
      switch (mode & 61440) {
        case 32768:
        case 8192:
        case 24576:
        case 4096:
        case 49152:
          break;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      try {
        FS.mknod(path, mode, dev);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _mkdir(path, mode) {
      // int mkdir(const char *path, mode_t mode);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mkdir.html
      path = Pointer_stringify(path);
      try {
        FS.mkdir(path, mode, 0);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _uncompress() {
  Module['printErr']('missing function: uncompress'); abort(-1);
  }

  function _globfree() {
  Module['printErr']('missing function: globfree'); abort(-1);
  }


  function _glob() {
  Module['printErr']('missing function: glob'); abort(-1);
  }

  function _inflateInit_() {
  Module['printErr']('missing function: inflateInit_'); abort(-1);
  }

  function _inflateEnd() {
  Module['printErr']('missing function: inflateEnd'); abort(-1);
  }

  function _inflate() {
  Module['printErr']('missing function: inflate'); abort(-1);
  }

  var _ceil=Math_ceil;

  function _llrint(x) {
      x = (x < 0) ? -Math.round(-x) : Math.round(x);
      return ((asm["setTempRet0"]((tempDouble=x,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)),x>>>0)|0);
    }

  
  function __parseInt64(str, endptr, base, min, max, unsign) {
      var isNegative = false;
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
  
      // Check for a plus/minus sign.
      if (HEAP8[(str)] == 45) {
        str++;
        isNegative = true;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
  
      // Find base.
      var ok = false;
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            ok = true; // we saw an initial zero, perhaps the entire thing is just "0"
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      var start = str;
  
      // Get digits.
      var chr;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          str++;
          ok = true;
        }
      }
  
      if (!ok) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return ((asm["setTempRet0"](0),0)|0);
      }
  
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str;
      }
  
      try {
        var numberString = isNegative ? '-'+Pointer_stringify(start, str - start) : Pointer_stringify(start, str - start);
        i64Math.fromString(numberString, finalBase, min, max, unsign);
      } catch(e) {
        ___setErrNo(ERRNO_CODES.ERANGE); // not quite correct
      }
  
      return ((asm["setTempRet0"](((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)),((HEAP32[((tempDoublePtr)>>2)])|0))|0);
    }function _strtoll(str, endptr, base) {
      return __parseInt64(str, endptr, base, '-9223372036854775808', '9223372036854775807');  // LLONG_MIN, LLONG_MAX.
    }

  
  function _trunc(x) {
      return (x < 0) ? Math.ceil(x) : Math.floor(x);
    }var _truncf=_trunc;

  function _exp2(x) {
      return Math.pow(2, x);
    }

  var _expf=Math_exp;

  function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }

  function _inflateReset() {
  Module['printErr']('missing function: inflateReset'); abort(-1);
  }

  function _inflateSync() {
  Module['printErr']('missing function: inflateSync'); abort(-1);
  }

  function _deflateInit_() {
  Module['printErr']('missing function: deflateInit_'); abort(-1);
  }

  function _deflate() {
  Module['printErr']('missing function: deflate'); abort(-1);
  }

  function _deflateEnd() {
  Module['printErr']('missing function: deflateEnd'); abort(-1);
  }

  function _deflateBound() {
  Module['printErr']('missing function: deflateBound'); abort(-1);
  }

  function _compress2() {
  Module['printErr']('missing function: compress2'); abort(-1);
  }

  var _log2f=_log2;

  var _llvm_pow_f32=Math_pow;

  var _atan=Math_atan;


  function _deflateReset() {
  Module['printErr']('missing function: deflateReset'); abort(-1);
  }

  var _exp2f=_exp2;

  var _llvm_memcpy_p0i8_p0i8_i64=_memcpy;

  var _tan=Math_tan;

  function _frexp(x, exp_addr) {
      var sig = 0, exp_ = 0;
      if (x !== 0) {
        var sign = 1;
        if (x < 0) {
          x = -x;
          sign = -1;
        }
        var raw_exp = Math.log(x)/Math.log(2);
        exp_ = Math.ceil(raw_exp);
        if (exp_ === raw_exp) exp_ += 1;
        sig = sign*x/Math.pow(2, exp_);
      }
      HEAP32[((exp_addr)>>2)]=exp_;
      return sig;
    }

  var _floorf=Math_floor;

  function _deflateInit2_() {
  Module['printErr']('missing function: deflateInit2_'); abort(-1);
  }

  function _crc32() {
  Module['printErr']('missing function: crc32'); abort(-1);
  }

  var _sinf=Math_sin;

  var _log10f=_log10;

  var _cosf=Math_cos;

  function _compress() {
  Module['printErr']('missing function: compress'); abort(-1);
  }

  var _cbrtf=_cbrt;

  var _atan2f=Math_atan2;

  var _atanf=Math_atan;

  var _llrintf=_llrint;

  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 79:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }



  function _cosh(x) {
      var p = Math.pow(Math.E, x);
      return (p + (1 / p)) / 2;
    }

  function _tanh(x) {
      return _sinh(x) / _cosh(x);
    }

  var _asin=Math_asin;

  var _acos=Math_acos;

  function _mmap(start, num, prot, flags, fd, offset) {
      /* FIXME: Since mmap is normally implemented at the kernel level,
       * this implementation simply uses malloc underneath the call to
       * mmap.
       */
      var MAP_PRIVATE = 2;
      var ptr;
      var allocated = false;
  
      if (!_mmap.mappings) _mmap.mappings = {};
  
      if (fd == -1) {
        ptr = _malloc(num);
        if (!ptr) return -1;
        _memset(ptr, 0, num);
        allocated = true;
      } else {
        var info = FS.getStream(fd);
        if (!info) return -1;
        try {
          var res = FS.mmap(info, HEAPU8, start, num, offset, prot, flags);
          ptr = res.ptr;
          allocated = res.allocated;
        } catch (e) {
          FS.handleFSError(e);
          return -1;
        }
      }
  
      _mmap.mappings[ptr] = { malloc: ptr, num: num, allocated: allocated };
      return ptr;
    }

  function _munmap(start, num) {
      if (!_mmap.mappings) _mmap.mappings = {};
      // TODO: support unmmap'ing parts of allocations
      var info = _mmap.mappings[start];
      if (!info) return 0;
      if (num == info.num) {
        _mmap.mappings[start] = null;
        if (info.allocated) {
          _free(info.malloc);
        }
      }
      return 0;
    }


  function _fcntl(fildes, cmd, varargs, dup2) {
      // int fcntl(int fildes, int cmd, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/fcntl.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      switch (cmd) {
        case 0:
          var arg = HEAP32[((varargs)>>2)];
          if (arg < 0) {
            ___setErrNo(ERRNO_CODES.EINVAL);
            return -1;
          }
          var newStream;
          try {
            newStream = FS.open(stream.path, stream.flags, 0, arg);
          } catch (e) {
            FS.handleFSError(e);
            return -1;
          }
          return newStream.fd;
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          return stream.flags;
        case 4:
          var arg = HEAP32[((varargs)>>2)];
          stream.flags |= arg;
          return 0;
        case 12:
        case 12:
          var arg = HEAP32[((varargs)>>2)];
          var offset = 0;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=2;
          return 0;
        case 13:
        case 14:
        case 13:
        case 14:
          // Pretend that the locking is successful.
          return 0;
        case 8:
        case 9:
          // These are for sockets. We don't have them fully implemented yet.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      // Should never be reached. Only to silence strict warnings.
      return -1;
    }

  function _fdopen(fildes, mode) {
      // FILE *fdopen(int fildes, const char *mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fdopen.html
      mode = Pointer_stringify(mode);
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      if ((mode.indexOf('w') != -1 && !stream.isWrite) ||
          (mode.indexOf('r') != -1 && !stream.isRead) ||
          (mode.indexOf('a') != -1 && !stream.isAppend) ||
          (mode.indexOf('+') != -1 && (!stream.isRead || !stream.isWrite))) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      } else {
        stream.error = false;
        stream.eof = false;
        return FS.getPtrForStream(stream);
      }
    }

   
  Module["_llvm_uadd_with_overflow_i64"] = _llvm_uadd_with_overflow_i64;

  function _mktime(tmPtr) {
      _tzset();
      var year = HEAP32[(((tmPtr)+(20))>>2)];
      var timestamp = new Date(year >= 1900 ? year : year + 1900,
                               HEAP32[(((tmPtr)+(16))>>2)],
                               HEAP32[(((tmPtr)+(12))>>2)],
                               HEAP32[(((tmPtr)+(8))>>2)],
                               HEAP32[(((tmPtr)+(4))>>2)],
                               HEAP32[((tmPtr)>>2)],
                               0).getTime() / 1000;
      HEAP32[(((tmPtr)+(24))>>2)]=new Date(timestamp).getDay();
      var yday = Math.round((timestamp - (new Date(year, 0, 1)).getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      return timestamp;
    }

  function _clock() {
      if (_clock.start === undefined) _clock.start = Date.now();
      return Math.floor((Date.now() - _clock.start) * (1000000/1000));
    }

  function _gettimeofday(ptr) {
      var now = Date.now();
      HEAP32[((ptr)>>2)]=Math.floor(now/1000); // seconds
      HEAP32[(((ptr)+(4))>>2)]=Math.floor((now-1000*Math.floor(now/1000))*1000); // microseconds
      return 0;
    }

  
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[((rqtp)>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(4))>>2)];
      if (rmtp !== 0) {
        HEAP32[((rmtp)>>2)]=0;
        HEAP32[(((rmtp)+(4))>>2)]=0;
      }
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }


  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }

  
  function _copysign(a, b) {
      return __reallyNegative(a) === __reallyNegative(b) ? a : -a;
    }var _copysignl=_copysign;

  
  function _fmod(x, y) {
      return x % y;
    }var _fmodl=_fmod;






  var Browser={mainLoop:{scheduler:null,method:"",shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
        // Canvas event setup
  
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
  
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
  
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        var ctx;
        var errorInfo = '?';
        function onContextCreationError(event) {
          errorInfo = event.statusMessage || errorInfo;
        }
        try {
          if (useWebGL) {
            var contextAttributes = {
              antialias: false,
              alpha: false
            };
  
            if (webGLContextAttributes) {
              for (var attribute in webGLContextAttributes) {
                contextAttributes[attribute] = webGLContextAttributes[attribute];
              }
            }
  
  
            canvas.addEventListener('webglcontextcreationerror', onContextCreationError, false);
            try {
              ['experimental-webgl', 'webgl'].some(function(webglId) {
                return ctx = canvas.getContext(webglId, contextAttributes);
              });
            } finally {
              canvas.removeEventListener('webglcontextcreationerror', onContextCreationError, false);
            }
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas: ' + [errorInfo, e]);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
  
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          GLctx = Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
  
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
  
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
  
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          setTimeout(func, 1000/60);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           window['setTimeout'];
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        return Math.max(-1, Math.min(1, event.type === 'DOMMouseScroll' ? event.detail : -event.wheelDelta));
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var x, y;
          
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
          if (event.type == 'touchstart' ||
              event.type == 'touchend' ||
              event.type == 'touchmove') {
            var t = event.touches.item(0);
            if (t) {
              x = t.pageX - (scrollX + rect.left);
              y = t.pageY - (scrollY + rect.top);
            } else {
              return;
            }
          } else {
            x = event.pageX - (scrollX + rect.left);
            y = event.pageY - (scrollY + rect.top);
          }
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function xhr_onload() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); NODEFS.staticInit(); }
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
___buildEnvironment(ENV);
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
___strtok_state = Runtime.staticAlloc(4);
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

staticSealed = true; // seal the static portion of memory

STACK_MAX = STACK_BASE + 5242880;

DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");

 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);

var Math_min = Math.min;
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiifi(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiifi"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiif(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiif"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiffiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiffiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viifi(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viifi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viidi(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viidi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiif"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_fiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    return Module["dynCall_iiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiiiiiiiffi(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    return Module["dynCall_fiiiiiiiffi"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iffiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iffiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiif"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    return Module["dynCall_iiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiidiiidi(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    return Module["dynCall_iiiiiiidiiidi"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiffi(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiffi"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_dd(index,a1) {
  try {
    return Module["dynCall_dd"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14) {
  try {
    Module["dynCall_viiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiifi(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiifi"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiif(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiif"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    Module["dynCall_viiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_diii(index,a1,a2,a3) {
  try {
    return Module["dynCall_diii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_didd(index,a1,a2,a3) {
  try {
    return Module["dynCall_didd"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_did(index,a1,a2) {
  try {
    return Module["dynCall_did"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    Module["dynCall_viiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiif(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiif"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiifii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiifii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    return Module["dynCall_iiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viif(index,a1,a2,a3) {
  try {
    Module["dynCall_viif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiffi(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiffi"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiddddd(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    Module["dynCall_viiiiiiiddddd"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env._stdout|0;var p=env._stderr|0;var q=+env.NaN;var r=+env.Infinity;var s=0;var t=0;var u=0;var v=0;var w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0.0;var F=0;var G=0;var H=0;var I=0;var J=0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=global.Math.floor;var Q=global.Math.abs;var R=global.Math.sqrt;var S=global.Math.pow;var T=global.Math.cos;var U=global.Math.sin;var V=global.Math.tan;var W=global.Math.acos;var X=global.Math.asin;var Y=global.Math.atan;var Z=global.Math.atan2;var _=global.Math.exp;var $=global.Math.log;var aa=global.Math.ceil;var ba=global.Math.imul;var ca=env.abort;var da=env.assert;var ea=env.asmPrintInt;var fa=env.asmPrintFloat;var ga=env.min;var ha=env.invoke_iiiiiiii;var ia=env.invoke_viiiiiifi;var ja=env.invoke_viiiii;var ka=env.invoke_vi;var la=env.invoke_vii;var ma=env.invoke_iiiiiii;var na=env.invoke_viiiif;var oa=env.invoke_viiiffiii;var pa=env.invoke_ii;var qa=env.invoke_viiiiiiiiiii;var ra=env.invoke_viifi;var sa=env.invoke_viidi;var ta=env.invoke_viiiiiiiiiif;var ua=env.invoke_fiii;var va=env.invoke_iiiiiiiiiiii;var wa=env.invoke_fiiiiiiiffi;var xa=env.invoke_iiii;var ya=env.invoke_iffiiiii;var za=env.invoke_viiiiiiii;var Aa=env.invoke_viiiiiiif;var Ba=env.invoke_fii;var Ca=env.invoke_iiiiiiiiii;var Da=env.invoke_iiiiiiidiiidi;var Ea=env.invoke_viiiffi;var Fa=env.invoke_dd;var Ga=env.invoke_viiiiiiiiiiiiii;var Ha=env.invoke_viiiiifi;var Ia=env.invoke_viiiiiii;var Ja=env.invoke_viiiiiiiii;var Ka=env.invoke_viiiiiif;var La=env.invoke_viiiiiiiiii;var Ma=env.invoke_iii;var Na=env.invoke_iiiiii;var Oa=env.invoke_diii;var Pa=env.invoke_didd;var Qa=env.invoke_viiiiii;var Ra=env.invoke_did;var Sa=env.invoke_viiiiiiiiiiii;var Ta=env.invoke_viiif;var Ua=env.invoke_viiiifii;var Va=env.invoke_viii;var Wa=env.invoke_v;var Xa=env.invoke_iiiiiiiii;var Ya=env.invoke_iiiii;var Za=env.invoke_viif;var _a=env.invoke_viiffi;var $a=env.invoke_viiiiiiiddddd;var ab=env.invoke_viiii;var bb=env._llvm_lifetime_end;var cb=env._lseek;var db=env._sysconf;var eb=env.__scanString;var fb=env._fclose;var gb=env._mkdir;var hb=env._strtoul;var ib=env._fflush;var jb=env._sinf;var kb=env._strtol;var lb=env._fputc;var mb=env._strtok;var nb=env._fwrite;var ob=env._deflateBound;var pb=env._send;var qb=env._llvm_pow_f32;var rb=env._fputs;var sb=env._cbrt;var tb=env._isspace;var ub=env._localtime;var vb=env._mmap;var wb=env._read;var xb=env._ceil;var yb=env._strstr;var zb=env._fileno;var Ab=env._perror;var Bb=env._fsync;var Cb=env._munmap;var Db=env._signal;var Eb=env._tanh;var Fb=env._fmod;var Gb=env._compress2;var Hb=env._round;var Ib=env._memchr;var Jb=env._llvm_va_end;var Kb=env._cosf;var Lb=env._snprintf;var Mb=env._fgetc;var Nb=env._stat;var Ob=env._cosh;var Pb=env.__getFloat;var Qb=env._mknod;var Rb=env._hypot;var Sb=env._deflateInit_;var Tb=env._fgets;var Ub=env._close;var Vb=env._strchr;var Wb=env._tcgetattr;var Xb=env._clock;var Yb=env.___setErrNo;var Zb=env._uncompress;var _b=env._access;var $b=env._ftell;var ac=env._exit;var bc=env._inflateReset;var cc=env._strrchr;var dc=env._atan2f;var ec=env._setrlimit;var fc=env._fcntl;var gc=env._log2;var hc=env._strcspn;var ic=env.__isLeapYear;var jc=env._copysign;var kc=env._ferror;var lc=env._llvm_uadd_with_overflow_i32;var mc=env._gmtime;var nc=env._localtime_r;var oc=env._sinh;var pc=env._emscripten_memcpy_big;var qc=env._recv;var rc=env.__parseInt64;var sc=env._trunc;var tc=env._cos;var uc=env._putchar;var vc=env._mkport;var wc=env._bsearch;var xc=env._deflateInit2_;var yc=env.__exit;var zc=env._nanosleep;var Ac=env._strftime;var Bc=env._rename;var Cc=env._tzset;var Dc=env._fabsf;var Ec=env._floorf;var Fc=env._llvm_va_copy;var Gc=env._rint;var Hc=env._crc32;var Ic=env._printf;var Jc=env._pread;var Kc=env._fopen;var Lc=env._open;var Mc=env._sqrtf;var Nc=env._select;var Oc=env._getchar;var Pc=env._usleep;var Qc=env._frexp;var Rc=env.__arraySum;var Sc=env._log;var Tc=env._puts;var Uc=env._mktime;var Vc=env._fdopen;var Wc=env._exp2;var Xc=env._scanf;var Yc=env._qsort;var Zc=env._deflateEnd;var _c=env._rmdir;var $c=env._inflate;var ad=env._log10;var bd=env._deflateReset;var cd=env._isatty;var dd=env.__formatString;var ed=env._getenv;var fd=env._gettimeofday;var gd=env._atoi;var hd=env._vfprintf;var id=env._llvm_pow_f64;var jd=env._sbrk;var kd=env._fscanf;var ld=env.___errno_location;var md=env._strerror;var nd=env._getrusage;var od=env._fstat;var pd=env._llvm_lifetime_start;var qd=env._strspn;var rd=env.__parseInt;var sd=env._ungetc;var td=env._exp;var ud=env._expf;var vd=env._gmtime_r;var wd=env._vsnprintf;var xd=env._sscanf;var yd=env.___assert_fail;var zd=env._fread;var Ad=env._strtok_r;var Bd=env._globfree;var Cd=env._abort;var Dd=env._fprintf;var Ed=env._strtoll;var Fd=env._tan;var Gd=env.___buildEnvironment;var Hd=env.__reallyNegative;var Id=env.__addDays;var Jd=env._inflateSync;var Kd=env._atanf;var Ld=env._fabs;var Md=env._floor;var Nd=env._fseek;var Od=env._sqrt;var Pd=env._write;var Qd=env._inflateInit_;var Rd=env._sin;var Sd=env._ceilf;var Td=env._tcsetattr;var Ud=env._atan;var Vd=env._asin;var Wd=env._glob;var Xd=env._compress;var Yd=env._deflate;var Zd=env._unlink;var _d=env._acos;var $d=env._pwrite;var ae=env._strerror_r;var be=env._atan2;var ce=env._llrint;var de=env._llvm_bswap_i16;var ee=env._time;var fe=env._llvm_bswap_i32;var ge=env._setvbuf;var he=env._inflateEnd;var ie=0.0;
// EMSCRIPTEN_START_FUNCS
function df(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7&-8;return b|0}function ef(){return i|0}function ff(a){a=a|0;i=a}function gf(a,b){a=a|0;b=b|0;if((s|0)==0){s=a;t=b}}function hf(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function jf(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function kf(a){a=a|0;F=a}function lf(a){a=a|0;G=a}function mf(a){a=a|0;H=a}function nf(a){a=a|0;I=a}function of(a){a=a|0;J=a}function pf(a){a=a|0;K=a}function qf(a){a=a|0;L=a}function rf(a){a=a|0;M=a}function sf(a){a=a|0;N=a}function tf(a){a=a|0;O=a}function uf(){}function vf(){Dsb(c[1068572]|0);c[1068572]=0;DBb(4274296);DBb(5221440);DBb(8776280);DBb(4597456);return}function wf(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;hd(c[o>>2]|0,d|0,e|0)|0;return}function xf(a){a=a|0;c[1154410]=a;return}function yf(a){a=a|0;var b=0;b=c[1154410]|0;if((b|0)==0){ac(a|0)}me[b&511](a);ac(a|0)}function zf(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=+f;g=+g;var j=0,k=0,l=0.0,m=0;j=i;i=i+8|0;k=j|0;l=+HBb(d,k);do{if((a[c[k>>2]|0]|0)==0){if(l<f|l>g){m=2356064;break}if((e|0)==1024){if(+(~~+l>>>0>>>0)+ +((E=+l,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0)|0)*4294967296.0!=l){m=2202216;break}i=j;return+l}else if((e|0)==128){if(+(~~l|0)!=l){m=2121360;break}i=j;return+l}else{i=j;return+l}}else{m=2356120}}while(0);yDb(0,8,m,(m=i,i=i+32|0,c[m>>2]=b,c[m+8>>2]=d,h[m+16>>3]=f,h[m+24>>3]=g,m)|0);i=m;yf(1);return 0.0}function Af(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=e|0;if((VEb(f,b,d)|0)<0){yDb(0,8,2060832,(g=i,i=i+24|0,c[g>>2]=(d|0)!=0?2014360:1973904,c[g+8>>2]=a,c[g+16>>2]=b,g)|0);i=g;yf(1);return 0}else{i=e;return(F=c[f+4>>2]|0,c[f>>2]|0)|0}return 0}function Bf(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+64|0;h=a|0;a=c[h>>2]|0;if((a|0)==0){j=uc(10)|0;i=g;return}k=g|0;if((f|0)==0){l=1;m=h;n=a;while(1){o=c[m+4>>2]|0;do{if((o&d|0)==(d|0)){if((o&e|0)!=0){p=l;break}if((l|0)==0){q=n}else{Tc(b|0)|0;q=c[m>>2]|0}sAb(k,q,64)|0;r=m+16|0;if((c[r>>2]|0)!=0){tAb(k,1920312,64)|0;tAb(k,c[r>>2]|0,64)|0}r=c[m+12>>2]|0;Ic(1899232,(s=i,i=i+16|0,c[s>>2]=k,c[s+8>>2]=r,s)|0)|0;i=s;p=0}else{p=l}}while(0);o=m+20|0;r=c[o>>2]|0;if((r|0)==0){break}else{l=p;m=o;n=r}}j=uc(10)|0;i=g;return}else{t=1;u=h;v=a}while(1){a=c[u+4>>2]|0;do{if((a&d|0)==(d|0)){if((a&f|0)==0){w=t;break}if((a&e|0)!=0){w=t;break}if((t|0)==0){x=v}else{Tc(b|0)|0;x=c[u>>2]|0}sAb(k,x,64)|0;h=u+16|0;if((c[h>>2]|0)!=0){tAb(k,1920312,64)|0;tAb(k,c[h>>2]|0,64)|0}h=c[u+12>>2]|0;Ic(1899232,(s=i,i=i+16|0,c[s>>2]=k,c[s+8>>2]=h,s)|0)|0;i=s;w=0}else{w=t}}while(0);a=u+20|0;h=c[a>>2]|0;if((h|0)==0){break}else{t=w;u=a;v=h}}j=uc(10)|0;i=g;return}function Cf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;c[e>>2]=a;if((c[a+8>>2]|0)==0){f=a}else{BEb(e,0,b,0)|0;uc(10)|0;f=c[e>>2]|0}a=JEb(f,0)|0;if((a|0)==0){i=d;return}else{g=a}do{Cf(g,b);g=JEb(c[e>>2]|0,g)|0;}while((g|0)!=0);i=d;return}function Df(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=Vb(d|0,58)|0;if((h|0)==0){j=SGb(d|0)|0}else{j=h-d|0}h=f|0;k=c[h>>2]|0;l=(k|0)==0;a:do{if(l){m=f;n=9}else{o=f;p=k;while(1){if((RGb(d,p,j)|0)==0){if((SGb(p|0)|0)==(j|0)){break}}q=o+20|0;r=c[q>>2]|0;if((r|0)==0){m=q;n=9;break a}else{o=q;p=r}}if((p|0)==0){m=o;n=9}else{s=o;n=20}}}while(0);b:do{if((n|0)==9){if((a[d]|0)!=110){s=m;n=20;break}if((a[d+1|0]|0)!=111){s=m;n=20;break}j=d+2|0;r=Vb(j|0,58)|0;if((r|0)==0){t=SGb(j|0)|0}else{t=r-j|0}if(l){u=f;v=e;break}else{w=f;x=k}while(1){if((RGb(j,x,t)|0)==0){if((SGb(x|0)|0)==(t|0)){break}}r=w+20|0;q=c[r>>2]|0;if((q|0)==0){u=r;v=e;break b}else{w=r;x=q}}if((c[w>>2]|0)==0){u=w;v=e;break}u=w;v=(c[w+4>>2]&2|0)==0?e:2337168}}while(0);if((n|0)==20){u=s;v=(c[s+4>>2]&2|0)==0?e:2312168}c:do{if((c[u>>2]|0)==0){e=c[h>>2]|0;d:do{if((e|0)!=0){s=f;n=e;while(1){if((RGb(2292096,n,7)|0)==0){if((SGb(n|0)|0)==7){break}}w=s+20|0;x=c[w>>2]|0;if((x|0)==0){break d}else{s=w;n=x}}if((n|0)!=0){y=s;break c}}}while(0);yDb(0,16,2276056,(z=i,i=i+8|0,c[z>>2]=d,z)|0);i=z;A=-22;i=g;return A|0}else{y=u}}while(0);u=y+4|0;if((c[u>>2]&1|0)!=0&(v|0)==0){yDb(0,16,2260304,(z=i,i=i+8|0,c[z>>2]=d,z)|0);i=z;A=-22;i=g;return A|0}z=Ef(b,y,d,v)|0;if((z|0)<0){A=z;i=g;return A|0}A=c[u>>2]&1;i=g;return A|0}function Ef(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,F=0,G=0,H=0;j=i;i=i+104|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=d+4|0;s=c[q>>2]|0;if((s&49152|0)==0){t=c[d+8>>2]|0}else{t=b+(c[d+8>>2]|0)|0}do{if((s&32768|0)==0){u=t;v=s}else{w=t;x=Vb(e|0,58)|0;y=t+4|0;z=(c[y>>2]|0)+1|0;if((z|0)>=134217727){yDb(0,16,2343568,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;yf(1);return 0}B=XDb(c[w>>2]|0,z<<4)|0;if((B|0)==0){yDb(0,16,2342256,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;yf(1);return 0}else{C=c[y>>2]|0;TGb(B+(C<<4)|0,0,z-C<<4|0)|0;c[y>>2]=z;c[w>>2]=B;B=eEb((x|0)==0?9203112:x+1|0)|0;x=(c[y>>2]|0)-1|0;c[(c[w>>2]|0)+(x<<4)>>2]=B;u=(c[w>>2]|0)+(x<<4)+8|0;v=c[q>>2]|0;break}}}while(0);do{if((v&8|0)==0){if((v&130|0)!=0){D=+HBb(f,o);if((a[c[o>>2]|0]|0)!=0){F=2356120;yDb(0,8,F,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-2147483648.0,h[A+24>>3]=2147483647.0,A)|0);i=A;yf(1);return 0}if(D<-2147483648.0|D>2147483647.0){F=2356064;yDb(0,8,F,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-2147483648.0,h[A+24>>3]=2147483647.0,A)|0);i=A;yf(1);return 0}if(+(~~+D>>>0>>>0)+ +((E=+D,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0)|0)*4294967296.0!=D){F=2202216;yDb(0,8,F,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-2147483648.0,h[A+24>>3]=2147483647.0,A)|0);i=A;yf(1);return 0}else{c[u>>2]=~~D;break}}if((v&1024|0)!=0){D=+HBb(f,n);if((a[c[n>>2]|0]|0)!=0){G=2356120;yDb(0,8,G,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-9223372036854776000.0,h[A+24>>3]=9223372036854776000.0,A)|0);i=A;yf(1);return 0}if(D<-9223372036854776000.0|D>9223372036854776000.0){G=2356064;yDb(0,8,G,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-9223372036854776000.0,h[A+24>>3]=9223372036854776000.0,A)|0);i=A;yf(1);return 0}t=~~+D>>>0;s=(E=+D,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);if(+(t>>>0)+ +(s|0)*4294967296.0!=D){G=2202216;yDb(0,8,G,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-9223372036854776000.0,h[A+24>>3]=9223372036854776000.0,A)|0);i=A;yf(1);return 0}else{x=u;c[x>>2]=t;c[x+4>>2]=s;break}}if((v&65536|0)!=0){if((VEb(m,f,1)|0)<0){yDb(0,8,2060832,(A=i,i=i+24|0,c[A>>2]=2014360,c[A+8>>2]=e,c[A+16>>2]=f,A)|0);i=A;yf(1);return 0}else{s=c[m+4>>2]|0;x=u;c[x>>2]=c[m>>2];c[x+4>>2]=s;break}}if((v&256|0)!=0){D=+HBb(f,l);if((a[c[l>>2]|0]|0)==0){g[u>>2]=D;break}else{yDb(0,8,2356120,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-r,h[A+24>>3]=r,A)|0);i=A;yf(1);return 0}}if((v&131072|0)!=0){D=+HBb(f,k);if((a[c[k>>2]|0]|0)==0){h[u>>3]=D;break}else{yDb(0,8,2356120,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-r,h[A+24>>3]=r,A)|0);i=A;yf(1);return 0}}s=c[d+8>>2]|0;if((s|0)==0){break}x=ze[s&511](b,e,f)|0;if((x|0)>=0){break}s=p|0;TGb(s|0,0,64)|0;a[s]=0;GBb(x,s,64)|0;yDb(0,16,2197896,(A=i,i=i+24|0,c[A>>2]=f,c[A+8>>2]=e,c[A+16>>2]=s,A)|0);i=A;H=x;i=j;return H|0}else{x=eEb(f)|0;$Db(u);c[u>>2]=x}}while(0);if((c[q>>2]&2048|0)==0){H=0;i=j;return H|0}else{yf(0);return 0}return 0}function Ff(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=b|0;f=b+4|0;g=c[f>>2]|0;yDb(0,48,2245800,(h=i,i=i+16|0,c[h>>2]=c[c[e>>2]>>2],c[h+8>>2]=g,h)|0);i=h;g=b+12|0;j=b+8|0;b=0;while(1){if((b|0)>=(c[g>>2]|0)){k=7;break}l=c[j>>2]|0;m=l+(b*12|0)|0;n=c[e>>2]|0;o=c[n+8>>2]|0;p=c[m>>2]|0;if((o|0)!=0){if((c[p+4>>2]&o|0)==0){k=5;break}}o=l+(b*12|0)+4|0;q=c[p+12>>2]|0;r=l+(b*12|0)+8|0;s=c[r>>2]|0;yDb(0,48,2220392,(h=i,i=i+24|0,c[h>>2]=c[o>>2],c[h+8>>2]=q,c[h+16>>2]=s,h)|0);i=h;s=Ef(a,c[m>>2]|0,c[o>>2]|0,c[r>>2]|0)|0;if((s|0)<0){t=s;k=8;break}else{b=b+1|0}}if((k|0)==5){a=c[p+12>>2]|0;p=c[n>>2]|0;n=c[f>>2]|0;yDb(0,16,2233160,(h=i,i=i+32|0,c[h>>2]=c[l+(b*12|0)+4>>2],c[h+8>>2]=a,c[h+16>>2]=p,c[h+24>>2]=n,h)|0);i=h;t=-22;i=d;return t|0}else if((k|0)==7){yDb(0,48,2211272,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;t=0;i=d;return t|0}else if((k|0)==8){i=d;return t|0}return 0}function Gf(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((b|0)<=1){g=0;return g|0}h=e|0;i=1;while(1){j=c[d+(i<<2)>>2]|0;k=j+1|0;if((a[j]|0)==45){l=Vb(k|0,58)|0;if((l|0)==0){m=SGb(k|0)|0}else{m=l-k|0}l=c[h>>2]|0;n=(l|0)==0;a:do{if(n){o=e;p=12}else{q=e;r=l;while(1){if((RGb(k,r,m)|0)==0){if((SGb(r|0)|0)==(m|0)){break}}s=q+20|0;t=c[s>>2]|0;if((t|0)==0){o=s;p=12;break a}else{q=s;r=t}}if((r|0)==0){o=q;p=12}else{u=q}}}while(0);b:do{if((p|0)==12){p=0;if((a[k]|0)!=110){u=o;break}if((a[j+2|0]|0)!=111){u=o;break}t=j+3|0;s=Vb(t|0,58)|0;if((s|0)==0){v=SGb(t|0)|0}else{v=s-t|0}if(n){u=e;break}else{w=e;x=l}while(1){if((RGb(t,x,v)|0)==0){if((SGb(x|0)|0)==(v|0)){u=w;break b}}s=w+20|0;y=c[s>>2]|0;if((y|0)==0){u=s;break}else{w=s;x=y}}}}while(0);l=c[u>>2]|0;if((l|0)==0){if((QGb(k,f)|0)==0){g=i;p=26;break}}else{if((QGb(f,l)|0)==0){g=i;p=26;break}}z=(c[u+4>>2]&1)+i|0}else{z=i}l=z+1|0;if((l|0)<(b|0)){i=l}else{g=0;p=26;break}}if((p|0)==26){return g|0}return 0}function Hf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=Gf(b,d,e,2202200)|0;if((g|0)==0){h=Gf(b,d,e,2195184)|0;if((h|0)!=0){j=h;k=3}}else{j=g;k=3}do{if((k|0)==3){g=c[d+(j+1<<2)>>2]|0;if((g|0)==0){break}If(0,0,g)|0}}while(0);j=Gf(b,d,e,2178920)|0;g=ed(2166664)|0;do{if(!((g|0)==0&(j|0)==0)){Jf(g)|0;h=c[1149632]|0;if((h|0)==0){break}nb(2160024,14,1,h|0)|0;if((b|0)>0){h=b-1|0;l=0;do{m=c[d+(l<<2)>>2]|0;n=a[m]|0;a:do{if(n<<24>>24==0){k=10}else{o=m;p=n;while(1){if(!((p-43&255)>>>0<16>>>0)){if(!((p-64&255)>>>0<27>>>0|p<<24>>24==95|(p-97&255)>>>0<26>>>0)){break}}q=o+1|0;r=a[q]|0;if(r<<24>>24==0){k=10;break a}else{o=q;p=r}}o=c[1149632]|0;if(p<<24>>24==0){s=o;k=15;break}lb(34,o|0)|0;o=a[m]|0;if(!(o<<24>>24==0)){r=m;q=o;do{o=q&255;do{if((q<<24>>24|0)==92|(q<<24>>24|0)==34|(q<<24>>24|0)==36|(q<<24>>24|0)==96){Dd(c[1149632]|0,2199648,(t=i,i=i+8|0,c[t>>2]=o,t)|0)|0;i=t}else{u=c[1149632]|0;if((q-32&255)>>>0>94>>>0){Dd(u|0,2198392,(t=i,i=i+8|0,c[t>>2]=o,t)|0)|0;i=t;break}else{lb(o|0,u|0)|0;break}}}while(0);r=r+1|0;q=a[r]|0;}while(!(q<<24>>24==0))}lb(34,c[1149632]|0)|0}}while(0);if((k|0)==10){k=0;s=c[1149632]|0;k=15}if((k|0)==15){k=0;rb(m|0,s|0)|0}lb(((l|0)<(h|0)?32:10)|0,c[1149632]|0)|0;l=l+1|0;}while((l|0)<(b|0))}ib(c[1149632]|0)|0}}while(0);if((Gf(b,d,e,2153192)|0)==0){i=f;return}c[1282824]=1;i=f;return}function If(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;b=d|0;f=yb(e|0,2018664)|0;c[b>>2]=f;g=(f|0)==0;BDb(g&1);if((f|0)==(e|0)){h=e+((a[e+6|0]|0)==43|6)|0}else{h=e}do{if(g){j=0}else{if((a[h]|0)!=0){j=0;break}i=d;return 0}}while(0);while(1){if(!(j>>>0<8>>>0)){break}if((QGb(c[628288+(j<<3)>>2]|0,h)|0)==0){k=7;break}else{j=j+1|0}}if((k|0)==7){ADb(c[628292+(j<<3)>>2]|0);i=d;return 0}j=kb(h|0,b|0,10)|0;if((a[c[b>>2]|0]|0)!=0){yDb(0,8,2014304,(b=i,i=i+8|0,c[b>>2]=h,b)|0);i=b;yDb(0,8,2011368,(b=i,i=i+8|0,c[b>>2]=2046560,b)|0);i=b;yDb(0,8,2011368,(b=i,i=i+8|0,c[b>>2]=2040504,b)|0);i=b;yDb(0,8,2011368,(b=i,i=i+8|0,c[b>>2]=2037016,b)|0);i=b;yDb(0,8,2011368,(b=i,i=i+8|0,c[b>>2]=2033456,b)|0);i=b;yDb(0,8,2011368,(b=i,i=i+8|0,c[b>>2]=2029328,b)|0);i=b;yDb(0,8,2011368,(b=i,i=i+8|0,c[b>>2]=2025704,b)|0);i=b;yDb(0,8,2011368,(b=i,i=i+8|0,c[b>>2]=2022080,b)|0);i=b;yDb(0,8,2011368,(b=i,i=i+8|0,c[b>>2]=2146152,b)|0);i=b;yf(1);return 0}ADb(j);i=d;return 0}function Jf(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+1120|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+1056|0;c[e>>2]=b;if((c[1149632]|0)!=0){l=0;i=d;return l|0}ee(h|0)|0;m=ub(h|0)|0;a:do{if((b|0)==0){n=0}else{h=0;o=0;p=b;while(1){if((a[p]|0)==0){n=h;break a}q=GEb(e,2211872,2211264,0,f,g)|0;if((q|0)<0){break}r=c[e>>2]|0;if((a[r]|0)!=0){c[e>>2]=r+1}r=c[f>>2]|0;if((QGb(r,2207952)|0)==0){ZDb(h);s=c[g>>2]|0;c[g>>2]=0;t=s;u=0}else{yDb(0,16,2206032,(v=i,i=i+8|0,c[v>>2]=r,v)|0);i=v;t=h;u=c[g>>2]|0}ZDb(u);ZDb(c[f>>2]|0);r=c[e>>2]|0;if((r|0)==0){n=t;break a}else{h=t;o=o+1|0;p=r}}if((o|0)==0){n=h;break}p=k|0;TGb(p|0,0,64)|0;a[p]=0;GBb(q,p,64)|0;yDb(0,16,2210880,(v=i,i=i+8|0,c[v>>2]=p,v)|0);i=v;n=h}}while(0);IAb(j,0,1);q=m+20|0;k=m+16|0;t=m+12|0;e=m+8|0;f=m+4|0;u=m|0;m=(n|0)!=0?n:2205432;while(1){g=m+1|0;b=a[m]|0;if((b<<24>>24|0)==0){break}else if((b<<24>>24|0)!=37){MAb(j,b,1);m=g;continue}b=m+2|0;p=a[g]|0;if(p<<24>>24==0){break}g=p<<24>>24;if((g|0)==112){KAb(j,2202712,(v=i,i=i+8|0,c[v>>2]=561616,v)|0);i=v;m=b;continue}else if((g|0)==116){r=(c[k>>2]|0)+1|0;s=c[t>>2]|0;w=c[e>>2]|0;x=c[f>>2]|0;y=c[u>>2]|0;KAb(j,2202168,(v=i,i=i+48|0,c[v>>2]=(c[q>>2]|0)+1900,c[v+8>>2]=r,c[v+16>>2]=s,c[v+24>>2]=w,c[v+32>>2]=x,c[v+40>>2]=y,v)|0);i=v;m=b;continue}else if((g|0)==37){MAb(j,p,1);m=b;continue}else{m=b;continue}}ZDb(n);if(!((c[j+4>>2]|0)>>>0<(c[j+8>>2]|0)>>>0)){yDb(0,16,2205008,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;l=-12;i=d;return l|0}n=j|0;m=Kc(c[n>>2]|0,2204688)|0;c[1149632]=m;if((m|0)==0){m=c[n>>2]|0;b=ld()|0;p=md(c[b>>2]|0)|0;yDb(0,16,2204024,(v=i,i=i+16|0,c[v>>2]=m,c[v+8>>2]=p,v)|0);i=v;l=-(c[b>>2]|0)|0;i=d;return l|0}else{CDb(746);b=(c[q>>2]|0)+1900|0;q=(c[k>>2]|0)+1|0;k=c[t>>2]|0;t=c[e>>2]|0;e=c[f>>2]|0;f=c[u>>2]|0;u=c[n>>2]|0;yDb(0,32,2203296,(v=i,i=i+64|0,c[v>>2]=561616,c[v+8>>2]=b,c[v+16>>2]=q,c[v+24>>2]=k,c[v+32>>2]=t,c[v+40>>2]=e,c[v+48>>2]=f,c[v+56>>2]=u,v)|0);i=v;QAb(j,0)|0;l=0;i=d;return l|0}return 0}function Kf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+168|0;f=b|0;g=b+128|0;h=b+136|0;j=b+144|0;k=b+152|0;l=b+160|0;c[g>>2]=CRa()|0;c[h>>2]=uN()|0;if((QGb(d,2146152)|0)==0){m=3}else{if((QGb(d,2140168)|0)==0){m=3}}if((m|0)==3){ADb(48)}n=Vb(d|0,58)|0;if((n|0)==0){o=d+(SGb(d|0)|0)|0}else{o=n}n=f|0;f=o-d+1|0;sAb(n,d,f>>>0<128>>>0?f:128)|0;f=g;g=qEb(f,n,0,0,3)|0;if((g|0)==0){m=8}else{if((c[g+40>>2]|0)==0){m=8}else{p=g;m=11}}do{if((m|0)==8){g=a[d]|0;if(!((g<<24>>24|0)==118|(g<<24>>24|0)==97|(g<<24>>24|0)==115)){q=0;break}g=qEb(f,d+1|0,0,0,2)|0;if((g|0)==0){q=0;break}if((c[g+40>>2]|0)==0){q=0}else{p=g;m=11}}}while(0);if((m|0)==11){CBb(8776280,d,e,(c[p+12>>2]|0)==0?32:0)|0;q=1}p=qEb(h,d,0,0,3)|0;do{if((p|0)==0){m=17}else{if((c[p+40>>2]|0)==0){m=17;break}CBb(5221440,d,e,(c[p+12>>2]|0)==0?32:0)|0;if((q|0)!=0){yDb(0,40,2133616,(r=i,i=i+8|0,c[r>>2]=d,r)|0);i=r}c[j>>2]=_rb()|0;s=1;m=23}}while(0);a:do{if((m|0)==17){c[j>>2]=_rb()|0;if((q|0)!=0){s=q;m=23;break}p=qEb(j,d,0,0,3)|0;do{if((p|0)==0){t=Qqb()|0}else{if((c[p+40>>2]|0)==0){t=Qqb()|0;break}h=rEb(c[1068572]|0,d,e,0)|0;if((h|0)>=0){s=1;m=23;break a}yDb(0,16,2127408,(r=i,i=i+8|0,c[r>>2]=d,r)|0);i=r;u=h;i=b;return u|0}}while(0);c[k>>2]=t;p=qEb(k,d,0,0,3)|0;if((p|0)==0){v=0;break}if((c[p+40>>2]|0)==0){v=0;break}h=Rqb()|0;c[l>>2]=h;f=rEb(h,d,e,0)|0;Tqb(l);if((f|0)>=0){CBb(4274296,d,e,(c[p+12>>2]|0)==0?32:0)|0;v=1;break}yDb(0,16,2127408,(r=i,i=i+8|0,c[r>>2]=d,r)|0);i=r;u=f;i=b;return u|0}}while(0);if((m|0)==23){c[k>>2]=Qqb()|0;v=s}u=(v|0)==0?-1414549496:0;i=b;return u|0}function Lf(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+40|0;d=a+36|0;if((c[b>>2]|0)>0){e=0;do{f=c[d>>2]|0;g=f+(e*12|0)+8|0;h=f+(e*12|0)+4|0;if((c[g>>2]|0)>0){f=0;do{$Db((c[h>>2]|0)+(f*36|0)+8|0);DBb((c[h>>2]|0)+(f*36|0)+16|0);DBb((c[h>>2]|0)+(f*36|0)+20|0);DBb((c[h>>2]|0)+(f*36|0)+24|0);Dsb(c[(c[h>>2]|0)+(f*36|0)+28>>2]|0);DBb((c[h>>2]|0)+(f*36|0)+32|0);f=f+1|0;}while((f|0)<(c[g>>2]|0))}$Db(h);e=e+1|0;}while((e|0)<(c[b>>2]|0))}$Db(d);$Db(a+52|0);$Db(a+8|0);Dsb(c[1068572]|0);c[1068572]=0;DBb(4274296);DBb(5221440);DBb(8776280);DBb(4597456);return}function Mf(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=i;TGb(b|0,0,80)|0;k=b+40|0;c[k>>2]=h;l=cEb(h*12|0)|0;m=l;n=b+36|0;c[n>>2]=m;if((l|0)==0){yf(1);return 0}o=c[k>>2]|0;a:do{if((o|0)>0){c[l>>2]=g;if((o|0)>1){p=1;q=m}else{break}while(1){c[q+(p*12|0)>>2]=g+(p*12|0);k=p+1|0;if((k|0)>=(o|0)){break a}p=k;q=c[n>>2]|0}}}while(0);c[b>>2]=913312;c[b+4>>2]=9203112;c[1068572]=Csb(16,16,0,16,16,0,4,0,0,0)|0;yDb(0,48,2121328,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;b:do{if((d|0)>1){p=(h|0)>0;o=f|0;m=b+44|0;l=g|0;k=1;r=-2;c:while(1){s=r+1|0;t=k;d:while(1){u=t+1|0;v=c[e+(t<<2)>>2]|0;yDb(0,48,2116536,(q=i,i=i+8|0,c[q>>2]=v,q)|0);i=q;e:do{if((a[v]|0)==45){w=v+1|0;x=a[w]|0;if((x<<24>>24|0)==0){y=15;break}else if((x<<24>>24|0)==45){if((a[v+2|0]|0)==0){break d}}if((s|0)==(u|0)){y=15;break}f:do{if(p){z=0;while(1){A=c[g+(z*12|0)+4>>2]|0;if((A|0)!=0){if((QGb(A,w)|0)==0){break}}A=z+1|0;if((A|0)<(h|0)){z=A}else{break f}}if(!((z|0)>-1)){break}A=c[e+(u<<2)>>2]|0;if((A|0)==0){y=27;break c}B=c[n>>2]|0;C=B+(z*12|0)+4|0;D=B+(z*12|0)+8|0;E=c[D>>2]|0;F=E+1|0;if((F|0)>=59652323){y=29;break c}G=XDb(c[C>>2]|0,F*36|0)|0;if((G|0)==0){y=31;break c}H=c[D>>2]|0;TGb(G+(H*36|0)|0,0,(F-H|0)*36|0|0)|0;c[D>>2]=F;F=G;c[C>>2]=F;C=F+(E*36|0)|0;UGb(C|0,m|0,36)|0;c[F+(E*36|0)+4>>2]=A;c[C>>2]=c[B+(z*12|0)>>2];c[F+(E*36|0)+28>>2]=c[1068572];c[F+(E*36|0)+32>>2]=c[1068574];c[F+(E*36|0)+16>>2]=c[2194070];c[F+(E*36|0)+20>>2]=c[1305360];c[F+(E*36|0)+24>>2]=c[1149364];c[2194070]=0;c[1305360]=0;c[1149364]=0;c[1068572]=0;c[1068574]=0;c[1068572]=Csb(16,16,0,16,16,0,4,0,0,0)|0;TGb(m|0,0,36)|0;yDb(0,48,2089224,(q=i,i=i+16|0,c[q>>2]=c[g+(z*12|0)>>2],c[q+8>>2]=A,q)|0);i=q;I=t+2|0;break e}}while(0);A=Vb(w|0,58)|0;if((A|0)==0){J=SGb(w|0)|0}else{J=A-w|0}A=c[o>>2]|0;g:do{if((A|0)!=0){E=f;F=A;while(1){if((RGb(w,F,J)|0)==0){if((SGb(F|0)|0)==(J|0)){break}}B=E+20|0;C=c[B>>2]|0;if((C|0)==0){break g}else{E=B;F=C}}z=E|0;if((F|0)==0){break}C=c[E+4>>2]|0;do{if((C&2048|0)==0){if((C&1|0)==0){K=2312168;L=u;break}B=c[e+(u<<2)>>2]|0;if((B|0)==0){y=45;break c}else{K=B;L=t+2|0}}else{K=c[e+(u<<2)>>2]|0;L=t+2|0}}while(0);Nf(b,E,w,K);C=c[E+12>>2]|0;yDb(0,48,2084400,(q=i,i=i+24|0,c[q>>2]=c[z>>2],c[q+8>>2]=C,c[q+16>>2]=K,q)|0);i=q;I=L;break e}}while(0);M=e+(u<<2)|0;A=c[M>>2]|0;if((A|0)==0){N=x}else{O=Kf(0,w,A)|0;if((O|0)>-1){A=c[M>>2]|0;yDb(0,48,2078952,(q=i,i=i+16|0,c[q>>2]=w,c[q+8>>2]=A,q)|0);i=q;I=t+2|0;break}if(!((O|0)==-1414549496)){y=52;break c}N=a[w]|0}if(!(N<<24>>24==110)){y=66;break c}if((a[v+2|0]|0)!=111){y=66;break c}A=v+3|0;C=Vb(A|0,58)|0;if((C|0)==0){P=SGb(A|0)|0}else{P=C-A|0}C=c[o>>2]|0;h:do{if((C|0)==0){Q=f}else{F=f;B=C;while(1){if((RGb(A,B,P)|0)==0){if((SGb(B|0)|0)==(P|0)){Q=F;break h}}G=F+20|0;D=c[G>>2]|0;if((D|0)==0){Q=G;break}else{F=G;B=D}}}}while(0);if((Q|0)==0){y=66;break c}A=Q|0;if((c[A>>2]|0)==0){y=66;break c}if((c[Q+4>>2]&2|0)==0){y=66;break c}Nf(b,Q,w,2337168);C=c[Q+12>>2]|0;yDb(0,48,2069448,(q=i,i=i+16|0,c[q>>2]=c[A>>2],c[q+8>>2]=C,q)|0);i=q;I=u}else{y=15}}while(0);if((y|0)==15){y=0;C=c[n>>2]|0;A=C+4|0;x=C+8|0;B=c[x>>2]|0;F=B+1|0;if((F|0)>=59652323){y=16;break c}z=XDb(c[A>>2]|0,F*36|0)|0;if((z|0)==0){y=18;break c}E=c[x>>2]|0;TGb(z+(E*36|0)|0,0,(F-E|0)*36|0|0)|0;c[x>>2]=F;F=z;c[A>>2]=F;A=F+(B*36|0)|0;UGb(A|0,m|0,36)|0;c[F+(B*36|0)+4>>2]=v;c[A>>2]=c[C>>2];c[F+(B*36|0)+28>>2]=c[1068572];c[F+(B*36|0)+32>>2]=c[1068574];c[F+(B*36|0)+16>>2]=c[2194070];c[F+(B*36|0)+20>>2]=c[1305360];c[F+(B*36|0)+24>>2]=c[1149364];c[2194070]=0;c[1305360]=0;c[1149364]=0;c[1068572]=0;c[1068574]=0;c[1068572]=Csb(16,16,0,16,16,0,4,0,0,0)|0;TGb(m|0,0,36)|0;yDb(0,48,2102664,(q=i,i=i+8|0,c[q>>2]=c[l>>2],q)|0);i=q;I=u}if((I|0)<(d|0)){t=I}else{break b}}if((u|0)<(d|0)){k=u;r=u}else{break b}}if((y|0)==16){yDb(0,16,2343568,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;yf(1);return 0}else if((y|0)==18){yDb(0,16,2342256,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;yf(1);return 0}else if((y|0)==27){yDb(0,16,2094544,(q=i,i=i+8|0,c[q>>2]=w,q)|0);i=q;R=-22;i=j;return R|0}else if((y|0)==29){yDb(0,16,2343568,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;yf(1);return 0}else if((y|0)==31){yDb(0,16,2342256,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;yf(1);return 0}else if((y|0)==45){yDb(0,16,2094544,(q=i,i=i+8|0,c[q>>2]=w,q)|0);i=q;R=-22;i=j;return R|0}else if((y|0)==52){r=c[M>>2]|0;yDb(0,16,2074104,(q=i,i=i+16|0,c[q>>2]=w,c[q+8>>2]=r,q)|0);i=q;R=O;i=j;return R|0}else if((y|0)==66){yDb(0,16,2064888,(q=i,i=i+8|0,c[q>>2]=w,q)|0);i=q;R=-1414549496;i=j;return R|0}}}while(0);if((c[b+56>>2]|0)!=0|(c[2194070]|0)!=0|(c[1305360]|0)!=0|(c[1149364]|0)!=0){yDb(0,24,2060776,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}yDb(0,48,2057552,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;R=0;i=j;return R|0}function Nf(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=(c[b+4>>2]&57344|0)==0?a|0:a+44|0;a=g+8|0;h=g+12|0;g=c[h>>2]|0;j=g+1|0;if((j|0)>=178956970){yDb(0,16,2343568,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;yf(1)}l=XDb(c[a>>2]|0,j*12|0)|0;if((l|0)==0){yDb(0,16,2342256,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;yf(1)}else{k=c[h>>2]|0;TGb(l+(k*12|0)|0,0,(j-k|0)*12|0|0)|0;c[h>>2]=j;j=l;c[a>>2]=j;c[j+(g*12|0)>>2]=b;c[(c[a>>2]|0)+(g*12|0)+4>>2]=d;c[(c[a>>2]|0)+(g*12|0)+8>>2]=e;i=f;return}}function Of(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;a=b|0;c[a>>2]=qBb()|0;e=rBb(a,d)|0;if((e|0)<0){f=e;i=b;return f|0}pBb(c[a>>2]|0);f=0;i=b;return f|0}function Pf(a){a=a|0;return Jf(0)|0}function Qf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;d=i;i=i+8|0;b=d|0;f=kb(e|0,b|0,10)|0;if((a[c[b>>2]|0]|0)==0){VDb(f);i=d;return 0}else{yDb(0,8,2001e3,(d=i,i=i+8|0,c[d>>2]=e,d)|0);i=d;yf(1);return 0}return 0}function Rf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0.0,k=0,l=0;b=i;i=i+16|0;f=b|0;g=b+8|0;j=+HBb(e,f);do{if((a[c[f>>2]|0]|0)==0){if(j<0.0|j>2147483647.0){k=2356064;break}if(+(~~+j>>>0>>>0)+ +((E=+j,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0)|0)*4294967296.0!=j){k=2202216;break}l=~~j;c[g>>2]=l;c[g+4>>2]=l+1;if((ec(0,g|0)|0)==0){i=b;return 0}Ab(1995472);i=b;return 0}else{k=2356120}}while(0);yDb(0,8,k,(k=i,i=i+32|0,c[k>>2]=d,c[k+8>>2]=e,h[k+16>>3]=0.0,h[k+24>>3]=2147483647.0,k)|0);i=k;yf(1);return 0}function Sf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+128|0;e=d|0;if((GBb(b,e,128)|0)<0){f=md(-b|0)|0}else{f=e}yDb(0,16,1992312,(e=i,i=i+16|0,c[e>>2]=a,c[e+8>>2]=f,e)|0);i=e;i=d;return}function Tf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=Gf(a,b,d,1988776)|0;if((c[1282824]|f|0)!=0){i=e;return}yDb(0,32,2217336,(f=i,i=i+8|0,c[f>>2]=561616,f)|0);i=f;yDb(0,32,2215968,(f=i,i=i+16|0,c[f>>2]=c[140406],c[f+8>>2]=2014,f)|0);i=f;yDb(0,32,2356056,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;yDb(0,32,2215408,(f=i,i=i+32|0,c[f>>2]=2239048,c[f+8>>2]=2214736,c[f+16>>2]=2214264,c[f+24>>2]=2213360,f)|0);i=f;yDb(0,32,2212248,(f=i,i=i+8|0,c[f>>2]=2239048,f)|0);i=f;Uf(5);Uf(3);i=e;return}function Uf(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=(b&1|0)!=0?2239048:9203112;f=(b&2|0)!=0;if(f){g=jGb()|0;yDb(0,32,2232608,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2229104,c[h+16>>2]=52,c[h+24>>2]=66,c[h+32>>2]=100,c[h+40>>2]=g>>>16,c[h+48>>2]=g>>>8&255,c[h+56>>2]=g&255,h)|0);i=h}g=(b&4|0)!=0;do{if(g){b=kGb()|0;if((QGb(2226680,b)|0)==0){break}if(!(a[58256]|0)){yDb(0,32,2225864,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[58256]=1}yDb(0,32,2224744,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2229104,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=K0a()|0;yDb(0,32,2232608,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2223808,c[h+16>>2]=55,c[h+24>>2]=52,c[h+32>>2]=102,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=L0a()|0;if((QGb(2226680,b)|0)==0){break}if(!(a[58256]|0)){yDb(0,32,2225864,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[58256]=1}yDb(0,32,2224744,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2223808,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=NS()|0;yDb(0,32,2232608,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2222912,c[h+16>>2]=55,c[h+24>>2]=33,c[h+32>>2]=100,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=OS()|0;if((QGb(2226680,b)|0)==0){break}if(!(a[58256]|0)){yDb(0,32,2225864,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[58256]=1}yDb(0,32,2224744,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2222912,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=Th()|0;yDb(0,32,2232608,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2221672,c[h+16>>2]=55,c[h+24>>2]=10,c[h+32>>2]=100,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=Uh()|0;if((QGb(2226680,b)|0)==0){break}if(!(a[58256]|0)){yDb(0,32,2225864,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[58256]=1}yDb(0,32,2224744,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2221672,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=Fi()|0;yDb(0,32,2232608,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2221040,c[h+16>>2]=4,c[h+24>>2]=2,c[h+32>>2]=100,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=Gi()|0;if((QGb(2226680,b)|0)==0){break}if(!(a[58256]|0)){yDb(0,32,2225864,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[58256]=1}yDb(0,32,2224744,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2221040,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=rsb()|0;yDb(0,32,2232608,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2220384,c[h+16>>2]=2,c[h+24>>2]=5,c[h+32>>2]=102,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=ssb()|0;if((QGb(2226680,b)|0)==0){break}if(!(a[58256]|0)){yDb(0,32,2225864,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[58256]=1}yDb(0,32,2224744,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2220384,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){f=Nqb()|0;yDb(0,32,2232608,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2220104,c[h+16>>2]=0,c[h+24>>2]=18,c[h+32>>2]=100,c[h+40>>2]=f>>>16,c[h+48>>2]=f>>>8&255,c[h+56>>2]=f&255,h)|0);i=h}if(!g){i=d;return}g=Oqb()|0;if((QGb(2226680,g)|0)==0){i=d;return}if(!(a[58256]|0)){yDb(0,32,2225864,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[58256]=1}yDb(0,32,2224744,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2220104,c[h+16>>2]=g,h)|0);i=h;i=d;return}function Vf(a,b,d){a=a|0;b=b|0;d=d|0;d=i;CDb(486);yDb(0,32,2217336,(b=i,i=i+8|0,c[b>>2]=561616,b)|0);i=b;yDb(0,32,2356056,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;yDb(0,32,2215408,(b=i,i=i+32|0,c[b>>2]=9203112,c[b+8>>2]=2214736,c[b+16>>2]=2214264,c[b+24>>2]=2213360,b)|0);i=b;yDb(0,32,2212248,(b=i,i=i+8|0,c[b>>2]=9203112,b)|0);i=b;Uf(2);i=d;return 0}function Wf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;e=i;i=i+456|0;CDb(486);d=e|0;UGb(d|0,2226680,454)|0;b=yb(d|0,2238184)|0;if((b|0)!=0){f=b;do{a[f]=a[2237464]|0;a[f+1|0]=a[2237465]|0;a[f+2|0]=a[2237466]|0;f=yb(d|0,2238184)|0;}while((f|0)!=0)}f=yb(d|0,2236544)|0;if((f|0)!=0){b=f;do{UGb(b|0,2235864,11)|0;b=yb(d|0,2236544)|0;}while((b|0)!=0)}b=mb(d|0,2235088)|0;yDb(0,32,2234152,(d=i,i=i+8|0,c[d>>2]=2239048,d)|0);i=d;if((b|0)==0){i=e;return 0}else{g=b}do{yDb(0,32,2233152,(d=i,i=i+24|0,c[d>>2]=2239048,c[d+8>>2]=2239048,c[d+16>>2]=g,d)|0);i=d;g=mb(0,2235088)|0;}while((g|0)!=0);i=e;return 0}function Xf(a,b,d){a=a|0;b=b|0;d=d|0;d=i;Ic(1984416,(b=i,i=i+24|0,c[b>>2]=561616,c[b+8>>2]=561616,c[b+16>>2]=561616,b)|0)|0;i=b;i=d;return 0}function Yf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=i;Tc(431208)|0;b=1978768;while(1){a=QC(0)|0;a:do{if((a|0)==0){e=0;f=0;g=0;h=0;j=0}else{k=0;l=0;m=0;n=a;while(1){b:do{if((l|0)==0){o=n;while(1){p=c[o>>2]|0;if((QGb(p,b)|0)>0){q=o;r=p;break b}p=QC(o)|0;if((p|0)==0){e=m;f=0;g=k;h=0;j=0;break a}else{o=p}}}else{o=n;while(1){p=c[o>>2]|0;if((QGb(p,l)|0)<0){if((QGb(p,b)|0)>0){q=o;r=p;break b}}p=QC(o)|0;if((p|0)==0){e=m;f=l;g=k;h=0;j=0;break a}else{o=p}}}}while(0);o=c[q+4>>2]|0;p=QC(q)|0;if((p|0)==0){e=o;f=r;g=1;h=0;j=0;break}else{k=1;l=r;m=o;n=p}}}}while(0);c:while(1){s=e;t=f;u=g;a=j;while(1){v=PC(a)|0;w=(t|0)==0;if((v|0)==0){break c}x=c[v>>2]|0;if(!w){if((QGb(x,t)|0)>=0){y=u;z=t;A=s;break}}if((QGb(x,b)|0)>0){B=c[v+4>>2]|0;C=x;D=0}else{B=s;C=t;D=u}if((C|0)==0){s=B;t=0;u=D;a=v}else{y=D;z=C;A=B;break}}a=(QGb(x,z)|0)==0;e=A;f=z;g=y;h=a?1:h;j=v}if(w){break}Ic(1976216,(a=i,i=i+32|0,c[a>>2]=(h|0)!=0?1973896:1920312,c[a+8>>2]=(u|0)!=0?1972488:1920312,c[a+16>>2]=t,c[a+24>>2]=(s|0)!=0?s:1920312,a)|0)|0;i=a;b=t}i=d;return 0}function Zf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;b=d|0;a=_f(b)|0;Tc(430720)|0;e=c[b>>2]|0;if((a|0)==0){f=e;ZDb(f);i=d;return 0}else{g=0}do{b=c[e+(g<<2)>>2]|0;uc(32)|0;h=b|0;j=(q0a(c[h>>2]|0)|0)!=0;Ic((j?1973896:1959920)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;k=(p0a(c[h>>2]|0)|0)!=0;Ic((k?1972488:1959920)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;switch(c[b+4>>2]|0){case 0:{l=86;break};case 4:{l=84;break};case 1:{l=65;break};case 2:{l=68;break};case 3:{l=83;break};default:{l=63}}uc(l|0)|0;k=b+16|0;Ic(((c[k>>2]&1|0)!=0?1955480:1959920)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;Ic(((c[k>>2]&2|0)!=0?1953328:1959920)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;Ic(((c[k>>2]&4|0)!=0?1951024:1959920)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;k=b+8|0;m=c[b+12>>2]|0;Ic(1949064,(j=i,i=i+16|0,c[j>>2]=c[k>>2],c[j+8>>2]=(m|0)==0?9203112:m,j)|0)|0;i=j;m=0;a:while(1){b=c[h>>2]|0;n=Q$a(m)|0;if((n|0)==0){o=0;break}else{p=n}while(1){if((c[p+12>>2]|0)==(b|0)){if((S$a(p)|0)!=0){break}}n=Q$a(p)|0;if((n|0)==0){o=0;break a}else{p=n}}if((p|0)==0){o=0;break}if((QGb(c[p>>2]|0,c[k>>2]|0)|0)==0){m=p}else{q=15;break}}if((q|0)==15){q=0;m=c[h>>2]|0;Ic(2250184,(j=i,i=i+8|0,c[j>>2]=2292080,j)|0)|0;i=j;b=Q$a(0)|0;b:do{if((b|0)!=0){n=b;while(1){if((c[n+12>>2]|0)==(m|0)){if((S$a(n)|0)!=0){break}}r=Q$a(n)|0;if((r|0)==0){break b}else{n=r}}if((n|0)==0){break}else{s=n}while(1){Ic(2249144,(j=i,i=i+8|0,c[j>>2]=c[s>>2],j)|0)|0;i=j;r=Q$a(s)|0;if((r|0)==0){break b}else{t=r}while(1){if((c[t+12>>2]|0)==(m|0)){if((S$a(t)|0)!=0){break}}r=Q$a(t)|0;if((r|0)==0){break b}else{t=r}}if((t|0)==0){break}else{s=t}}}}while(0);uc(41)|0;o=0}c:while(1){m=c[h>>2]|0;b=Q$a(o)|0;if((b|0)==0){break}else{u=b}while(1){if((c[u+12>>2]|0)==(m|0)){if((R$a(u)|0)!=0){break}}b=Q$a(u)|0;if((b|0)==0){break c}else{u=b}}if((u|0)==0){break}if((QGb(c[u>>2]|0,c[k>>2]|0)|0)==0){o=u}else{q=32;break}}if((q|0)==32){q=0;k=c[h>>2]|0;Ic(2250184,(j=i,i=i+8|0,c[j>>2]=2293688,j)|0)|0;i=j;m=Q$a(0)|0;d:do{if((m|0)!=0){b=m;while(1){if((c[b+12>>2]|0)==(k|0)){if((R$a(b)|0)!=0){break}}n=Q$a(b)|0;if((n|0)==0){break d}else{b=n}}if((b|0)==0){break}else{v=b}while(1){Ic(2249144,(j=i,i=i+8|0,c[j>>2]=c[v>>2],j)|0)|0;i=j;n=Q$a(v)|0;if((n|0)==0){break d}else{w=n}while(1){if((c[w+12>>2]|0)==(k|0)){if((R$a(w)|0)!=0){break}}n=Q$a(w)|0;if((n|0)==0){break d}else{w=n}}if((w|0)==0){break}else{v=w}}}}while(0);uc(41)|0}uc(10)|0;g=g+1|0;}while(g>>>0<a>>>0);f=e;ZDb(f);i=d;return 0}function _f(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=0;e=0;while(1){f=h0(e)|0;if((f|0)==0){break}else{d=d+1|0;e=f}}e=dEb(d,4)|0;f=e;if((e|0)==0){yDb(0,16,2247016,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;yf(1);return 0}h=h0(0)|0;if((h|0)==0){j=0}else{k=0;l=h;while(1){h=k+1|0;c[f+(k<<2)>>2]=l;m=h0(l)|0;if((m|0)==0){j=h;break}else{k=h;l=m}}}if((j|0)==(d|0)){Yc(e|0,d|0,4,324);c[a>>2]=f;i=b;return d|0}else{yDb(0,0,2245768,(g=i,i=i+24|0,c[g>>2]=2244984,c[g+8>>2]=2241232,c[g+16>>2]=1344,g)|0);i=g;Cd();return 0}return 0}function $f(a,b,c){a=a|0;b=b|0;c=c|0;ag(0);return 0}function ag(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+8|0;d=b|0;e=_f(d)|0;Ic(2262616,(f=i,i=i+8|0,c[f>>2]=(a|0)!=0?2261696:2260288,f)|0)|0;i=f;g=c[d>>2]|0;if((e|0)==0){h=g;ZDb(h);i=b;return}d=(a|0)==0;a=0;do{j=c[g+(a<<2)>>2]|0;k=j|0;l=c[k>>2]|0;m=Q$a(0)|0;a:do{if((m|0)!=0){n=j+4|0;o=j+8|0;p=l;q=m;while(1){r=q;b:while(1){do{if((c[r+12>>2]|0)==(p|0)){if(d){if((S$a(r)|0)==0){break}else{break b}}else{if((R$a(r)|0)==0){break}else{break b}}}}while(0);s=Q$a(r)|0;if((s|0)==0){break a}else{r=s}}if((r|0)==0){break a}switch(c[n>>2]|0){case 4:{t=84;break};case 0:{t=86;break};case 1:{t=65;break};case 2:{t=68;break};case 3:{t=83;break};default:{t=63}}Ic(2259608,(f=i,i=i+8|0,c[f>>2]=t,f)|0)|0;i=f;s=r+16|0;Ic(((c[s>>2]&4096|0)!=0?2255640:1959920)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;Ic(((c[s>>2]&8192|0)!=0?1951024:1959920)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;Ic(((c[s>>2]&512|0)!=0?2253304:1959920)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;Ic(((c[s>>2]&1|0)!=0?2252224:1959920)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;Ic(((c[s>>2]&2|0)!=0?1973896:1959920)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;s=r|0;u=c[r+4>>2]|0;Ic(1949064,(f=i,i=i+16|0,c[f>>2]=c[s>>2],c[f+8>>2]=(u|0)==0?9203112:u,f)|0)|0;i=f;u=c[o>>2]|0;if((QGb(c[s>>2]|0,u)|0)!=0){Ic(2251128,(f=i,i=i+8|0,c[f>>2]=u,f)|0)|0;i=f}uc(10)|0;p=c[k>>2]|0;q=Q$a(r)|0;if((q|0)==0){break a}}}}while(0);a=a+1|0;}while(a>>>0<e>>>0);h=g;ZDb(h);i=b;return}function bg(a,b,c){a=a|0;b=b|0;c=c|0;ag(1);return 0}function cg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;Tc(430696)|0;d=R_(0)|0;if((d|0)==0){e=uc(10)|0;return 0}else{f=d}do{Tc(c[f>>2]|0)|0;f=R_(f)|0;}while((f|0)!=0);e=uc(10)|0;return 0}function dg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;d=i;i=i+8|0;b=d|0;c[b>>2]=0;Tc(430656)|0;a=xy(b,0)|0;if((a|0)!=0){e=a;do{Tc(e|0)|0;e=xy(b,0)|0;}while((e|0)!=0)}Tc(430648)|0;e=xy(b,1)|0;if((e|0)==0){i=d;return 0}else{f=e}do{Tc(f|0)|0;f=xy(b,1)|0;}while((f|0)!=0);i=d;return 0}function eg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+64|0;d=e|0;Tc(430432)|0;b=Si(0)|0;if((b|0)==0){i=e;return 0}f=d|0;g=d+60|0;d=b;do{b=d+12|0;h=d+20|0;j=c[d+8>>2]|0;if((j|0)==0){k=f;l=13}else{m=f;n=0;while(1){if(!((c[j+(n*60|0)>>2]|0)!=0&m>>>0<g>>>0)){break}switch(c[j+(n*60|0)+4>>2]|0){case 1:{o=65;break};case 4:{o=84;break};case 3:{o=83;break};case 2:{o=68;break};case 0:{o=86;break};default:{o=63}}a[m]=o;m=m+1|0;n=n+1|0}if((n|0)==0){k=m;l=13}else{p=m}}if((l|0)==13){l=0;a[k]=(c[h>>2]&1|0)!=0?78:124;p=k+1|0}a[p]=45;j=p+2|0;a[p+1|0]=62;q=c[b>>2]|0;if((q|0)==0){r=j;l=25}else{s=j;j=0;while(1){if(!((c[q+(j*60|0)>>2]|0)!=0&s>>>0<g>>>0)){break}switch(c[q+(j*60|0)+4>>2]|0){case 4:{t=84;break};case 3:{t=83;break};case 2:{t=68;break};case 1:{t=65;break};case 0:{t=86;break};default:{t=63}}a[s]=t;s=s+1|0;j=j+1|0}if((j|0)==0){r=s;l=25}else{u=s}}if((l|0)==25){l=0;a[r]=(c[h>>2]&2|0)!=0?78:124;u=r+1|0}a[u]=0;q=c[h>>2]|0;b=(c[d+48>>2]|0)!=0?67:46;m=c[d>>2]|0;n=c[d+4>>2]|0;Ic(1930144,(v=i,i=i+48|0,c[v>>2]=(q&196608|0)!=0?84:46,c[v+8>>2]=(q&4|0)!=0?83:46,c[v+16>>2]=b,c[v+24>>2]=m,c[v+32>>2]=f,c[v+40>>2]=n,v)|0)|0;i=v;d=Si(d)|0;}while((d|0)!=0);i=e;return 0}function fg(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;b=e|0;Ic(1928416,(a=i,i=i+8|0,c[a>>2]=1926704,a)|0)|0;i=a;f=SEb(0,b)|0;if((f|0)==0){i=e;return 0}else{g=0;h=f}do{f=c[b>>2]|0;j=d[f]|0;k=d[f+1|0]|0;l=d[f+2|0]|0;Ic(1925104,(a=i,i=i+32|0,c[a>>2]=h,c[a+8>>2]=j,c[a+16>>2]=k,c[a+24>>2]=l,a)|0)|0;i=a;g=g+1|0;h=SEb(g,b)|0;}while((h|0)!=0);i=e;return 0}function gg(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;e=i;Tc(430176)|0;b=cFb(0)|0;if((b|0)==0){i=e;return 0}else{f=b}do{b=dFb(f)|0;a=(tsb(b)|0)!=0;g=(usb(b)|0)!=0;b=d[f+7|0]|0;h=c[f>>2]|0;j=d[f+4|0]|0;k=$Eb(f)|0;Ic(1921872,(l=i,i=i+64|0,c[l>>2]=a?73:46,c[l+8>>2]=g?79:46,c[l+16>>2]=(b&8|0)!=0?72:46,c[l+24>>2]=(b&2|0)!=0?80:46,c[l+32>>2]=(b&4|0)!=0?66:46,c[l+40>>2]=h,c[l+48>>2]=j,c[l+56>>2]=k,l)|0)|0;i=l;f=cFb(f)|0;}while((f|0)!=0);i=e;return 0}function hg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+16|0;b=d|0;a=d+8|0;Tc(430128)|0;e=0;do{f=_Gb(1,0,e|0)|0;g=F;h=lBb(f,g)|0;c[a>>2]=h;if((h|0)!=0){h=mBb(f,g)|0;Ic(1918848,(j=i,i=i+16|0,c[j>>2]=c[a>>2],c[j+8>>2]=h,j)|0)|0;i=j}e=e+1|0;}while((e|0)<63);Tc(430072)|0;if((oBb(0,b,a)|0)==0){k=0}else{i=d;return 0}do{e=c[a>>2]|0;if((e|0)!=0){Ic(1909456,(j=i,i=i+8|0,c[j>>2]=e,j)|0)|0;i=j;e=0;h=1;while(1){g=c[b>>2]|0;f=c[b+4>>2]|0;if(!((g&h|0)==0&(f&e|0)==0)){l=YGb(h,e,-1,-1)|0;m=(g&l|0)!=0|(f&F|0)!=0?1906336:9203112;f=lBb(h,e)|0;Ic(1908024,(j=i,i=i+16|0,c[j>>2]=m,c[j+8>>2]=f,j)|0)|0;i=j}f=h<<1|0>>>31;m=e<<1|h>>>31;if((f|0)==0&(m|0)==0){break}else{e=m;h=f}}uc(10)|0}k=k+1|0;}while((oBb(k,b,a)|0)==0);i=d;return 0}function ig(a,b,c){a=a|0;b=b|0;c=c|0;c=i;i=i+128|0;b=c|0;Tc(AFb(b,128,-1)|0)|0;Tc(AFb(b,128,0)|0)|0;Tc(AFb(b,128,1)|0)|0;Tc(AFb(b,128,2)|0)|0;Tc(AFb(b,128,3)|0)|0;Tc(AFb(b,128,4)|0)|0;Tc(AFb(b,128,5)|0)|0;Tc(AFb(b,128,6)|0)|0;Tc(AFb(b,128,7)|0)|0;Tc(AFb(b,128,8)|0)|0;Tc(AFb(b,128,9)|0)|0;i=c;return 0}function jg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;b=d|0;CDb(486);f=eEb((e|0)!=0?e:9203112)|0;c[b>>2]=f;e=Vb(f|0,61)|0;if((e|0)==0){g=0;h=f}else{a[e]=0;g=e+1|0;h=c[b>>2]|0}if((a[h]|0)==0){vg(h,g);j=b;$Db(j);i=d;return 0}if((QGb(h,1904824)|0)==0){kg(g,0);j=b;$Db(j);i=d;return 0}if((QGb(h,1903e3)|0)==0){kg(g,1);j=b;$Db(j);i=d;return 0}if((QGb(h,1901736)|0)==0){e=WC(g)|0;if((e|0)==0){yDb(0,16,2314336,(k=i,i=i+8|0,c[k>>2]=g,k)|0);i=k;j=b;$Db(j);i=d;return 0}f=c[e+4>>2]|0;Ic(2297432,(k=i,i=i+16|0,c[k>>2]=c[e>>2],c[k+8>>2]=f,k)|0)|0;i=k;f=c[e+12>>2]|0;if((f|0)!=0){Ic(2310184,(k=i,i=i+8|0,c[k>>2]=f,k)|0)|0;i=k}f=c[e+20>>2]|0;if((f|0)==0){j=b;$Db(j);i=d;return 0}Cf(f,2);j=b;$Db(j);i=d;return 0}if((QGb(h,1900616)|0)==0){f=UC(g,0,0)|0;if((f|0)==0){yDb(0,16,2314336,(k=i,i=i+8|0,c[k>>2]=g,k)|0);i=k;j=b;$Db(j);i=d;return 0}e=c[f+4>>2]|0;Ic(2312152,(k=i,i=i+16|0,c[k>>2]=c[f>>2],c[k+8>>2]=e,k)|0)|0;i=k;e=c[f+12>>2]|0;if((e|0)!=0){Ic(2310184,(k=i,i=i+8|0,c[k>>2]=e,k)|0)|0;i=k}e=c[f+8>>2]|0;if((e|0)!=0){Ic(2304944,(k=i,i=i+8|0,c[k>>2]=e,k)|0)|0;i=k}e=c[f+20>>2]|0;do{if((e|0)!=0){l=g0(e)|0;if((l|0)==0){break}Ic(2301808,(k=i,i=i+8|0,c[k>>2]=c[l+8>>2],k)|0)|0;i=k}}while(0);e=c[f+16>>2]|0;do{if((e|0)!=0){l=g0(e)|0;if((l|0)==0){break}Ic(2300240,(k=i,i=i+8|0,c[k>>2]=c[l+8>>2],k)|0)|0;i=k}}while(0);e=c[f+24>>2]|0;do{if((e|0)!=0){l=g0(e)|0;if((l|0)==0){break}Ic(2298912,(k=i,i=i+8|0,c[k>>2]=c[l+8>>2],k)|0)|0;i=k}}while(0);e=c[f+36>>2]|0;if((e|0)==0){j=b;$Db(j);i=d;return 0}Cf(e,1);j=b;$Db(j);i=d;return 0}if((QGb(h,1899224)|0)!=0){vg(h,g);j=b;$Db(j);i=d;return 0}h=Ri(g)|0;if((g|0)==0){yDb(0,16,2341104,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;j=b;$Db(j);i=d;return 0}if((h|0)==0){yDb(0,16,2339688,(k=i,i=i+8|0,c[k>>2]=g,k)|0);i=k;j=b;$Db(j);i=d;return 0}Ic(2338552,(k=i,i=i+8|0,c[k>>2]=c[h>>2],k)|0)|0;i=k;g=c[h+4>>2]|0;if((g|0)!=0){Ic(2337160,(k=i,i=i+8|0,c[k>>2]=g,k)|0)|0;i=k}g=h+20|0;if((c[g>>2]&4|0)!=0){Tc(431176)|0}Tc(431160)|0;e=h+8|0;f=Ui(c[e>>2]|0)|0;if((f|0)>0){l=0;do{m=aj(c[e>>2]|0,l)|0;n=lGb(bj(c[e>>2]|0,l)|0)|0;Ic(2325216,(k=i,i=i+24|0,c[k>>2]=l,c[k+8>>2]=m,c[k+16>>2]=n,k)|0)|0;i=k;l=l+1|0;}while((l|0)<(f|0))}do{if((c[g>>2]&1|0)==0){if((f|0)!=0){break}Tc(431128)|0}else{Tc(431064)|0}}while(0);Tc(431112)|0;f=h+12|0;l=Ui(c[f>>2]|0)|0;if((l|0)>0){e=0;do{n=aj(c[f>>2]|0,e)|0;m=lGb(bj(c[f>>2]|0,e)|0)|0;Ic(2325216,(k=i,i=i+24|0,c[k>>2]=e,c[k+8>>2]=n,c[k+16>>2]=m,k)|0)|0;i=k;e=e+1|0;}while((e|0)<(l|0))}do{if((c[g>>2]&2|0)==0){if((l|0)!=0){break}Tc(431032)|0}else{Tc(431064)|0}}while(0);l=c[h+16>>2]|0;if((l|0)!=0){Cf(l,65560)}if((c[g>>2]&196608|0)==0){j=b;$Db(j);i=d;return 0}Tc(430960)|0;j=b;$Db(j);i=d;return 0}function kg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;if((a|0)==0){yDb(0,16,2296232,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}f=(b|0)!=0;if(f){g=F0a(a)|0}else{g=G0a(a)|0}if((g|0)!=0){sg(g);i=d;return}g=i0(a)|0;if((g|0)==0){yDb(0,16,2291296,(e=i,i=i+8|0,c[e>>2]=a,e)|0);i=e;i=d;return}h=g|0;g=c[h>>2]|0;j=Q$a(0)|0;do{if((j|0)!=0){k=(b|0)==0;l=0;m=g;n=j;a:while(1){o=n;b:while(1){do{if((c[o+12>>2]|0)==(m|0)){if(k){if((S$a(o)|0)==0){break}else{break b}}else{if((R$a(o)|0)==0){break}else{break b}}}}while(0);p=Q$a(o)|0;if((p|0)==0){break a}else{o=p}}if((o|0)==0){break}sg(o);p=c[h>>2]|0;q=Q$a(o)|0;if((q|0)==0){r=22;break}else{l=1;m=p;n=q}}if((r|0)==22){i=d;return}if((l|0)==0){break}i=d;return}}while(0);yDb(0,16,2294760,(e=i,i=i+16|0,c[e>>2]=a,c[e+8>>2]=f?2293688:2292080,e)|0);i=e;i=d;return}function lg(){var a=0,b=0,c=0;a=Oc()|0;b=(((a-97|0)>>>0<26>>>0?a^32:a)|0)==89|0;c=a;while(1){if((c|0)==(-1|0)|(c|0)==10){break}c=Oc()|0}return b|0}function mg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=dCb(b,1898016)|0;if((g|0)==0){h=ld()|0;j=md(c[h>>2]|0)|0;yDb(0,16,1891952,(k=i,i=i+16|0,c[k>>2]=b,c[k+8>>2]=j,k)|0);i=k;l=-(c[h>>2]|0)|0;i=f;return l|0}Nd(g|0,0,2)|0;c[e>>2]=$b(g|0)|0;Nd(g|0,0,0)|0;h=c[e>>2]|0;if((h|0)==-1){j=ld()|0;m=md(c[j>>2]|0)|0;yDb(0,16,1889040,(k=i,i=i+8|0,c[k>>2]=m,k)|0);i=k;fb(g|0)|0;l=-(c[j>>2]|0)|0;i=f;return l|0}j=WDb(h+1|0)|0;c[d>>2]=j;if((j|0)==0){yDb(0,16,1887184,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;fb(g|0)|0;l=-12;i=f;return l|0}h=zd(j|0,1,c[e>>2]|0,g|0)|0;j=c[e>>2]|0;do{if(h>>>0<j>>>0){ZDb(c[d>>2]|0);if((kc(g|0)|0)==0){n=-541478725;break}m=ld()|0;o=md(c[m>>2]|0)|0;yDb(0,16,1885536,(k=i,i=i+16|0,c[k>>2]=b,c[k+8>>2]=o,k)|0);i=k;n=-(c[m>>2]|0)|0}else{c[e>>2]=j+1;a[(c[d>>2]|0)+j|0]=0;n=0}}while(0);fb(g|0)|0;l=n;i=f;return l|0}function ng(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g|0;j=ed(1884176)|0;c[h>>2]=j;c[h+4>>2]=ed(1883040)|0;c[h+8>>2]=1881736;if((e|0)!=0){sAb(a,d,b)|0;k=Kc(a|0,1880536)|0;i=g;return k|0}e=(f|0)==0;l=0;m=j;while(1){do{if((m|0)==0){n=0}else{j=(l|0)!=1?9203112:2355304;Lb(a|0,b|0,2356032,(o=i,i=i+24|0,c[o>>2]=m,c[o+8>>2]=j,c[o+16>>2]=d,o)|0)|0;i=o;p=Kc(a|0,1880536)|0;if((p|0)!=0|e){n=p;break}Lb(a|0,b|0,2349520,(o=i,i=i+32|0,c[o>>2]=m,c[o+8>>2]=j,c[o+16>>2]=f,c[o+24>>2]=d,o)|0)|0;i=o;n=Kc(a|0,1880536)|0}}while(0);o=l+1|0;if(!((o|0)<3&(n|0)==0)){k=n;break}l=o;m=c[h+(o<<2)>>2]|0}i=g;return k|0}function og(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=hU(a,b,d)|0;if((f|0)>=0){i=e;return f|0}yDb(a,16,2346512,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;i=e;return f|0}function pg(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+16|0;j=h|0;k=h+8|0;c[j>>2]=0;l=e+8|0;m=(c[l>>2]|0)!=0?1:2;c[k>>2]=CRa()|0;do{if((g|0)==0){if((c[l>>2]|0)==0){n=q0a(d)|0;break}else{n=p0a(d)|0;break}}else{n=g}}while(0);g=c[(c[f+8>>2]|0)+8>>2]|0;if((g|0)==0){o=118;p=m|16}else if((g|0)==3){o=115;p=m|32}else if((g|0)==1){o=97;p=m|8}else{o=0;p=m}m=BBb(b,9203112,0,2)|0;a:do{if((m|0)!=0){g=e;d=k;l=(n|0)==0;q=n+44|0;r=q;s=m;b:while(1){t=s|0;u=c[t>>2]|0;v=Vb(u|0,58)|0;w=(v|0)!=0;do{if(w){x=v+1|0;y=hU(e,f,x)|0;if((y|0)<0){yDb(g,16,2346512,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z}if((y|0)==0){break}else if((y|0)!=1){A=0;break b}a[v]=0;B=c[t>>2]|0;C=17}else{B=u;C=17}}while(0);do{if((C|0)==17){C=0;c:do{if((qEb(d,B,0,p,2)|0)==0){do{if(!l){if((c[q>>2]|0)==0){break}if((qEb(r,c[t>>2]|0,0,p,2)|0)!=0){C=21;break c}}}while(0);u=c[t>>2]|0;if((a[u]|0)!=(o|0)){break}if((qEb(d,u+1|0,0,p,2)|0)==0){break}CBb(j,(c[t>>2]|0)+1|0,c[s+4>>2]|0,0)|0}else{C=21}}while(0);if((C|0)==21){C=0;CBb(j,c[t>>2]|0,c[s+4>>2]|0,0)|0}if(!w){break}a[v]=58}}while(0);s=BBb(b,9203112,s,2)|0;if((s|0)==0){break a}}i=h;return A|0}}while(0);A=c[j>>2]|0;i=h;return A|0}function qg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=a+24|0;f=c[e>>2]|0;if((f|0)==0){g=0;i=d;return g|0}h=cEb(f<<2)|0;f=h;if((h|0)==0){yDb(0,16,2345128,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=0;i=d;return g|0}if((c[e>>2]|0)==0){g=f;i=d;return g|0}h=a+28|0;j=0;while(1){k=c[(c[h>>2]|0)+(j<<2)>>2]|0;c[f+(j<<2)>>2]=pg(b,c[(c[k+8>>2]|0)+48>>2]|0,a,k,0)|0;k=j+1|0;if(k>>>0<(c[e>>2]|0)>>>0){j=k}else{g=f;break}}i=d;return g|0}function rg(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;if((2147483647/(b|0)|0|0)<=(e|0)){yDb(0,16,2343568,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;yf(1);return 0}if((c[d>>2]|0)>=(e|0)){h=a;i=f;return h|0}j=XDb(a,ba(e,b)|0)|0;if((j|0)==0){yDb(0,16,2342256,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;yf(1);return 0}g=c[d>>2]|0;TGb(j+(ba(g,b)|0)|0,0,ba(e-g|0,b)|0)|0;c[d>>2]=e;h=j;i=f;return h|0}function sg(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+144|0;d=b|0;e=b+16|0;f=(R$a(a)|0)!=0;g=c[a>>2]|0;h=c[a+4>>2]|0;Ic(2287136,(j=i,i=i+24|0,c[j>>2]=f?2284144:2282912,c[j+8>>2]=g,c[j+16>>2]=(h|0)==0?9203112:h,j)|0)|0;i=j;if((c[a+8>>2]|0)>>>0<2>>>0){Ic(2281480,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;h=c[a+16>>2]&12288;if((h|0)==12288){Ic(2280456,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}else if((h|0)==4096){Ic(2279360,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}else if((h|0)==8192){Ic(2278248,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}else{Ic(2277120,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}uc(10)|0}h=c[a+20>>2]|0;if((h|0)!=0){Ic(2276024,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;g=c[h>>2]|0;if((g|0)!=0){f=h;h=g;do{g=c[f+4>>2]|0;Ic(2275360,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;f=f+8|0;h=c[f>>2]|0;}while((h|0)!=0)}uc(10)|0}h=c[a+24>>2]|0;if((h|0)!=0){Ic(2270952,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;f=c[h>>2]|0;if(!((f|0)==-1)){g=h;h=f;do{f=ZEb(h)|0;Ic(2268768,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;g=g+4|0;h=c[g>>2]|0;}while(!((h|0)==-1))}uc(10)|0}h=c[a+28>>2]|0;if((h|0)!=0){Ic(2267576,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;g=c[h>>2]|0;if((g|0)!=0){f=d|0;d=h;h=g;do{Lb(f|0,16,2266240,(j=i,i=i+8|0,c[j>>2]=h,j)|0)|0;i=j;Ic(2268768,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;d=d+4|0;h=c[d>>2]|0;}while((h|0)!=0)}uc(10)|0}h=c[a+32>>2]|0;if((h|0)!=0){Ic(2265128,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;d=c[h>>2]|0;if(!((d|0)==-1)){f=h;h=d;do{d=wFb(h)|0;Ic(2268768,(j=i,i=i+8|0,c[j>>2]=d,j)|0)|0;i=j;f=f+4|0;h=c[f>>2]|0;}while(!((h|0)==-1))}uc(10)|0}h=c[a+36>>2]|0;if((h|0)!=0){Ic(2264072,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;f=c[h>>2]|0;d=c[h+4>>2]|0;if(!((f|0)==0&(d|0)==0)){g=e|0;e=h;h=d;d=f;do{iBb(g,128,0,d,h);Ic(2268768,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;e=e+8|0;d=c[e>>2]|0;h=c[e+4>>2]|0;}while(!((d|0)==0&(h|0)==0))}uc(10)|0}h=c[a+44>>2]|0;if((h|0)==0){i=b;return}Cf(h,3);i=b;return}function tg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a>>2]|0;a=c[d+4>>2]|0;e=c[b>>2]|0;b=c[e+4>>2]|0;if((a|0)==(b|0)){f=QGb(c[d+8>>2]|0,c[e+8>>2]|0)|0;return f|0}else{f=a-b|0;return f|0}return 0}function ug(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+1040|0;g=f|0;Fc(g|0,e|0);wDb(a,b,d,e);e=f+16|0;uDb(a,b,d,g|0,e,1024,851e3);rb(e|0,c[1149632]|0)|0;ib(c[1149632]|0)|0;i=f;return}function vg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;d=i;do{if((b|0)==0){e=0;f=0}else{if((a[b]|0)==0){e=0;f=0;break}if((QGb(b,1944968)|0)==0){e=1;f=0;break}if((QGb(b,2335280)|0)==0){e=1;f=1;break}yDb(0,16,2191008,(g=i,i=i+8|0,c[g>>2]=b,g)|0);i=g;e=0;f=0}}while(0);yDb(0,32,2253904,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;yDb(0,32,2239536,(g=i,i=i+8|0,c[g>>2]=561616,g)|0);i=g;yDb(0,32,2269448,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;Ic(2111088,(g=i,i=i+8|0,c[g>>2]=561616,g)|0)|0;i=g;Bf(625312,2051656,2048,0,0);Bf(625312,2005208,0,59396,0);if(e){Bf(625312,1967200,4,59392,0);Bf(625312,1938264,0,2612,57344);Bf(625312,1913280,4,560,57344);Bf(625312,1892528,16,36,0);Bf(625312,2349496,20,32,0);Bf(625312,2328408,32,20,0);Bf(625312,2303472,36,16,0)}else{Bf(625312,1938264,0,2612,57344);Bf(625312,1892528,16,36,0);Bf(625312,2328408,32,20,0)}Bf(625312,2285072,512,0,0);uc(10)|0;if((f|0)==0){i=d;return}Cf(CRa()|0,3);Cf(uN()|0,3);Cf(_rb()|0,3);Cf(Qqb()|0,8);Cf(dj()|0,65560);i=d;return}function wg(){var a=0,b=0;a=i;yDb(0,32,2253904,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;yDb(0,32,2239536,(b=i,i=i+8|0,c[b>>2]=561616,b)|0);i=b;yDb(0,32,2269448,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;i=a;return}function xg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+208|0;e=d|0;f=d+80|0;TGb(e|0,0,80)|0;g=Mf(e,a,b,625312,986104,2)|0;do{if((g|0)<0){yDb(0,8,2227488,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=g}else{b=Ff(0,e|0)|0;if((b|0)<0){yDb(0,8,2216048,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=b;break}b=e+36|0;a=yg((c[b>>2]|0)+12|0,2206152,16)|0;if((a|0)<0){yDb(0,8,2198360,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=a;break}a=yg(c[b>>2]|0,2188136,488)|0;if((a|0)<0){yDb(0,8,2171944,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=a;break}Lf(e);k=a;i=d;return k|0}}while(0);Lf(e);e=f|0;GBb(j,e,128)|0;yDb(0,8,2162840,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;k=j;i=d;return k|0}function yg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+440|0;f=e|0;h=a+8|0;if((c[h>>2]|0)<=0){j=0;i=e;return j|0}k=a+4|0;a=f;l=f+168|0;m=f+188|0;n=f+8|0;o=f+160|0;p=f+176|0;q=f+156|0;r=f+84|0;s=f|0;t=f+124|0;u=f+120|0;v=u;w=f+128|0;x=f+212|0;y=f+148|0;z=0;while(1){A=c[k>>2]|0;B=A+(z*36|0)|0;TGb(a|0,0,440)|0;c[l>>2]=-1;c[l+4>>2]=2147483647;g[m>>2]=.699999988079071;c[n>>2]=0;c[n+4>>2]=-2147483648;c[o>>2]=-1;c[o+4>>2]=2147483647;c[p>>2]=-1;c[p+4>>2]=-1;c[q>>2]=2147483647;c[r>>2]=1;c[s>>2]=B;C=Ff(a,B)|0;D=A+(z*36|0)+4|0;E=c[D>>2]|0;if((C|0)<0){F=4;break}yDb(0,48,1977480,(G=i,i=i+16|0,c[G>>2]=b,c[G+8>>2]=E,G)|0);i=G;H=Oe[d&1023](f,c[D>>2]|0)|0;A=625312;do{B=c[A+8>>2]|0;I=a+B|0;J=A+4|0;K=c[J>>2]|0;do{if((K&32768|0)==0){if((K&16392|0)!=16392){break}$Db(I)}else{L=I;M=a+(B+4)|0;if((c[M>>2]|0)>0){N=0;do{$Db((c[L>>2]|0)+(N<<4)|0);if((c[J>>2]&8|0)!=0){$Db((c[L>>2]|0)+(N<<4)+8|0)}N=N+1|0;}while((N|0)<(c[M>>2]|0))}$Db(I);c[M>>2]=0}}while(0);A=A+20|0;}while((c[A>>2]|0)!=0);if((c[t>>2]|0)>0){A=0;do{$Db((c[u>>2]|0)+(A*24|0)+20|0);A=A+1|0;}while((A|0)<(c[t>>2]|0))}$Db(v);$Db(w);$Db(x);$Db(y);if((H|0)<0){F=18;break}yDb(0,48,1977104,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;A=z+1|0;if((A|0)<(c[h>>2]|0)){z=A}else{j=0;F=20;break}}if((F|0)==4){yDb(0,16,1977920,(G=i,i=i+16|0,c[G>>2]=b,c[G+8>>2]=E,G)|0);i=G;j=C;i=e;return j|0}else if((F|0)==18){C=c[D>>2]|0;yDb(0,16,1977376,(G=i,i=i+16|0,c[G>>2]=b,c[G+8>>2]=C,G)|0);i=G;j=H;i=e;return j|0}else if((F|0)==20){i=e;return j|0}return 0}function zg(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;f=i;i=i+184|0;g=f|0;j=f+8|0;k=f+16|0;l=f+24|0;m=f+152|0;n=f+160|0;o=f+168|0;p=f+176|0;c[n>>2]=0;q=b+16|0;r=c[q>>2]|0;do{if((r|0)==0){s=0}else{t=WC(r)|0;if((t|0)!=0){s=t;break}yDb(0,8,1984168,(u=i,i=i+8|0,c[u>>2]=c[q>>2],u)|0);i=u;yf(1);s=0}}while(0);q=(QGb(e,2028088)|0)==0;r=q?2027368:e;if((RGb(r,2027368,5)|0)==0){v=0}else{v=(QGb(r,1983560)|0)!=0|0}c[107880]=c[107880]&v;v=tN()|0;c[k>>2]=v;if((v|0)==0){Sf(r,-12);yf(1)}v=c[b+40>>2]|0;if((v|0)!=0){e=l|0;Lb(e|0,128,2071080,(u=i,i=i+8|0,c[u>>2]=c[(c[b+36>>2]|0)+(v-1<<4)+8>>2],u)|0)|0;i=u;CBb((c[b>>2]|0)+20|0,1983088,e,0)|0}e=b+32|0;v=(s|0)==0;do{if(!((c[e>>2]|0)==0|v)){q=s+20|0;if((c[q>>2]|0)==0){break}if((qEb(q,2123248,0,0,2)|0)==0){break}q=l|0;Lb(q|0,128,2071080,(u=i,i=i+8|0,c[u>>2]=c[(c[b+28>>2]|0)+((c[e>>2]|0)-1<<4)+8>>2],u)|0)|0;i=u;CBb((c[b>>2]|0)+20|0,2123248,q,0)|0}}while(0);e=b+48|0;do{if(!((c[e>>2]|0)==0|v)){l=s+20|0;if((c[l>>2]|0)==0){break}if((qEb(l,1982960,0,0,2)|0)==0){break}CBb((c[b>>2]|0)+20|0,1982960,c[(c[b+44>>2]|0)+((c[e>>2]|0)-1<<4)+8>>2]|0,0)|0}}while(0);v=c[b+56>>2]|0;if((v|0)!=0){CBb((c[b>>2]|0)+20|0,1982808,c[(c[b+52>>2]|0)+(v-1<<4)+8>>2]|0,0)|0}v=c[b+64>>2]|0;if((v|0)!=0){CBb((c[b>>2]|0)+20|0,1982648,c[(c[b+60>>2]|0)+(v-1<<4)+8>>2]|0,0)|0}v=c[b+24>>2]|0;l=(v|0)>0;do{if(l){q=c[b+20>>2]|0;t=0;w=0;while(1){if((QGb(c[q+(w<<4)>>2]|0,1972792)|0)==0){x=c[q+(w<<4)+8>>2]|0}else{x=t}y=w+1|0;if((y|0)<(v|0)){t=x;w=y}else{break}}do{if(l){w=c[b+20>>2]|0;t=0;q=0;while(1){if((QGb(c[w+(q<<4)>>2]|0,1982392)|0)==0){z=c[w+(q<<4)+8>>2]|0}else{z=t}y=q+1|0;if((y|0)<(v|0)){t=z;q=y}else{break}}if(!l){A=0;B=z;break}q=c[b+20>>2]|0;t=0;w=0;while(1){if((QGb(c[q+(w<<4)>>2]|0,2188440)|0)==0){C=c[q+(w<<4)+8>>2]|0}else{C=t}y=w+1|0;if((y|0)<(v|0)){t=C;w=y}else{A=C;B=z;break}}}else{A=0;B=0}}while(0);if((x|0)==0){D=0;E=0;G=0}else{D=c[(oh(x,0,0)|0)+12>>2]|0;E=x;G=1}w=c[k>>2]|0;c[w+1112>>2]=D;if((B|0)==0){H=0;I=w;J=0;K=0}else{w=c[(oh(B,1,0)|0)+12>>2]|0;H=w;I=c[k>>2]|0;J=B;K=1}c[I+1116>>2]=H;if((A|0)==0){c[I+1120>>2]=0;if(G){L=0;M=0;N=I;O=45}else{P=0;Q=0;O=46}}else{w=c[(oh(A,3,0)|0)+12>>2]|0;t=c[k>>2]|0;c[t+1120>>2]=w;if(G){L=1;M=A;N=t;O=45}else{P=1;Q=A;O=46}}if((O|0)==45){PS(N,oh(E,0,0)|0);if(K){R=M;S=L;O=47}else{T=M;U=L;O=48}}else if((O|0)==46){if(K){R=Q;S=P;O=47}else{T=Q;U=P;O=48}}if((O|0)==47){t=c[k>>2]|0;QS(t,oh(J,1,0)|0);if(S){V=R}else{break}}else if((O|0)==48){if(U){V=T}else{break}}t=c[k>>2]|0;RS(t,oh(V,3,0)|0)}else{t=c[k>>2]|0;c[t+1112>>2]=0;c[t+1116>>2]=0;c[t+1120>>2]=0}}while(0);V=c[k>>2]|0;T=V+1084|0;c[T>>2]=c[T>>2]|4;T=V+1160|0;V=912112;U=c[V+4>>2]|0;c[T>>2]=c[V>>2];c[T+4>>2]=U;U=b|0;T=aT(k,r,s,(c[U>>2]|0)+20|0)|0;if((T|0)<0){Sf(r,T);yf(1)}Ch(c[(c[U>>2]|0)+20>>2]|0);T=c[k>>2]|0;if((c[T+24>>2]|0)==0){W=T}else{s=0;V=T;while(1){qh(b,V,c[(c[V+28>>2]|0)+(s<<2)>>2]|0)|0;T=s+1|0;R=c[k>>2]|0;if(T>>>0<(c[R+24>>2]|0)>>>0){s=T;V=R}else{W=R;break}}}V=qg(W,c[(c[U>>2]|0)+16>>2]|0)|0;c[m>>2]=V;W=c[k>>2]|0;s=c[W+24>>2]|0;if((AT(W,V)|0)<0){yDb(0,8,1982216,(u=i,i=i+8|0,c[u>>2]=r,u)|0);i=u;KT(k);yf(1)}V=b+8|0;W=c[V>>2]|0;R=c[V+4>>2]|0;T=(W|0)==0&(R|0)==(-2147483648|0);S=c[k>>2]|0;J=S+1056|0;P=c[J>>2]|0;Q=c[J+4>>2]|0;J=(P|0)==0&(Q|0)==(-2147483648|0);K=YGb(J?0:P,J?0:Q,T?0:W,T?0:R)|0;R=F;do{if(!T){if((tT(S,-1,0,-2147483648,K,R,K,R,0)|0)>=0){break}yDb(0,24,1982048,(u=i,i=i+16|0,c[u>>2]=r,h[u+8>>3]=(+(K>>>0)+ +(R|0)*4294967296.0)/1.0e6,u)|0);i=u}}while(0);S=c[k>>2]|0;T=S+24|0;do{if((c[T>>2]|0)==0){X=S}else{W=S+28|0;Q=b+92|0;J=b+248|0;P=b+384|0;L=b+328|0;M=b+108|0;E=b+116|0;N=b+112|0;A=b+104|0;G=b+324|0;I=b+44|0;H=b+424|0;B=b+420|0;D=b+392|0;x=b+400|0;z=b+396|0;C=b+388|0;v=b+380|0;l=b+244|0;t=b+88|0;w=0;a:while(1){q=c[(c[W>>2]|0)+(w<<2)>>2]|0;y=q+8|0;Y=c[y>>2]|0;Z=cEb(296)|0;_=Z;if((Z|0)==0){yf(1)}$=rg(c[1271688]|0,4,4671760,(c[1167940]|0)+1|0)|0;c[1271688]=$;c[$+((c[1167940]|0)-1<<2)>>2]=_;$=Z+4|0;c[$>>2]=q;c[Z>>2]=c[1167942];c[Z+8>>2]=1;c[q+76>>2]=48;aa=Z+88|0;h[aa>>3]=1.0;if((c[Q>>2]|0)>0){ba=0;do{ca=og(S,q,c[(c[t>>2]|0)+(ba<<4)>>2]|0)|0;do{if((ca|0)>0){h[aa>>3]=+h[(c[t>>2]|0)+(ba<<4)+8>>3]}else{if((ca|0)>=0){break}yf(1)}}while(0);ba=ba+1|0;}while((ba|0)<(c[Q>>2]|0))}do{if((c[J>>2]|0)>0){ba=0;aa=0;while(1){ca=og(S,q,c[(c[l>>2]|0)+(ba<<4)>>2]|0)|0;do{if((ca|0)>0){da=c[(c[l>>2]|0)+(ba<<4)+8>>2]|0}else{if((ca|0)>=0){da=aa;break}yf(1);da=aa}}while(0);ca=ba+1|0;if((ca|0)<(c[J>>2]|0)){ba=ca;aa=da}else{break}}if((da|0)==0){break}aa=kb(da|0,j|0,0)|0;if((a[c[j>>2]|0]|0)==0){ea=aa}else{aa=da;ea=d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0}c[(c[y>>2]|0)+52>>2]=ea}}while(0);y=qh(b,S,q)|0;aa=Z+16|0;c[aa>>2]=y;c[Z+104>>2]=pg(c[(c[U>>2]|0)+16>>2]|0,c[(c[(c[$>>2]|0)+8>>2]|0)+48>>2]|0,S,q,y)|0;y=Z+252|0;c[y>>2]=-1;if((c[P>>2]|0)>0){ba=0;do{ca=og(S,q,c[(c[v>>2]|0)+(ba<<4)>>2]|0)|0;do{if((ca|0)>0){c[y>>2]=c[(c[v>>2]|0)+(ba<<4)+8>>2]}else{if((ca|0)>=0){break}yf(1)}}while(0);ba=ba+1|0;}while((ba|0)<(c[P>>2]|0))}ba=Z+80|0;c[ba>>2]=0;c[ba+4>>2]=-2147483648;b:do{switch(c[Y+8>>2]|0){case 0:{if((c[aa>>2]|0)==0){c[aa>>2]=q0a(c[Y+48>>2]|0)|0}if((i0a(Y)|0)!=0){ba=Y+88|0;c[ba>>2]=c[ba>>2]|16384}c[Z+124>>2]=c[Y+124>>2];c[Z+128>>2]=c[Y+120>>2];c[Z+132>>2]=c[Y+140>>2];do{if((c[e>>2]|0)>0){ba=0;y=0;while(1){$=og(S,q,c[(c[I>>2]|0)+(ba<<4)>>2]|0)|0;do{if(($|0)>0){fa=c[(c[I>>2]|0)+(ba<<4)+8>>2]|0}else{if(($|0)>=0){fa=y;break}yf(1);fa=y}}while(0);$=ba+1|0;if(($|0)<(c[e>>2]|0)){ba=$;y=fa}else{break}}if((fa|0)==0){break}if((PEb(Z+108|0,fa)|0)>=0){break}yDb(0,16,1979792,(u=i,i=i+8|0,c[u>>2]=fa,u)|0);i=u;yf(1)}}while(0);y=Z+116|0;c[y>>2]=-1;if((c[L>>2]|0)>0){ba=0;do{$=og(S,q,c[(c[G>>2]|0)+(ba<<4)>>2]|0)|0;do{if(($|0)>0){c[y>>2]=c[(c[G>>2]|0)+(ba<<4)+8>>2]}else{if(($|0)>=0){break}yf(1)}}while(0);ba=ba+1|0;}while((ba|0)<(c[L>>2]|0))}do{if((c[M>>2]|0)>0){ba=0;y=0;while(1){$=og(S,q,c[(c[A>>2]|0)+(ba<<4)>>2]|0)|0;do{if(($|0)>0){ga=c[(c[A>>2]|0)+(ba<<4)+8>>2]|0}else{if(($|0)>=0){ga=y;break}yf(1);ga=y}}while(0);$=ba+1|0;if(($|0)<(c[M>>2]|0)){ba=$;y=ga}else{break}}if((ga|0)==0){break}if((QGb(ga,1979696)|0)==0){c[Z+256>>2]=0;break}y=Z+256|0;if((QGb(ga,1979416)|0)==0){c[y>>2]=1;break}if((c[y>>2]|0)!=0){break}yDb(0,8,1979104,(u=i,i=i+8|0,c[u>>2]=ga,u)|0);i=u;yDb(0,8,1978864,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;yDb(0,8,2269448,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;yf(1)}}while(0);do{if((c[E>>2]|0)>0){y=0;ba=0;while(1){$=og(S,q,c[(c[N>>2]|0)+(y<<4)>>2]|0)|0;do{if(($|0)>0){ha=c[(c[N>>2]|0)+(y<<4)+8>>2]|0}else{if(($|0)>=0){ha=ba;break}yf(1);ha=ba}}while(0);$=y+1|0;if(($|0)<(c[E>>2]|0)){y=$;ba=ha}else{break}}if((ha|0)==0){break}ba=eEb(ha)|0;c[Z+260>>2]=ba;if((ba|0)!=0){break}yf(1)}}while(0);c[Z+284>>2]=-1;break};case 1:{ba=Z+120|0;c[ba>>2]=2147483647;if((c[H>>2]|0)>0){y=0;do{$=og(S,q,c[(c[B>>2]|0)+(y<<4)>>2]|0)|0;do{if(($|0)>0){c[ba>>2]=c[(c[B>>2]|0)+(y<<4)+8>>2]}else{if(($|0)>=0){break}yf(1)}}while(0);y=y+1|0;}while((y|0)<(c[H>>2]|0))}Dh(_)|0;c[Z+136>>2]=c[Y+420>>2];c[Z+140>>2]=c[Y+412>>2];c[Z+144>>2]=c[Y+416>>2];y=Y+448|0;ba=c[y+4>>2]|0;$=Z+152|0;c[$>>2]=c[y>>2];c[$+4>>2]=ba;break};case 2:case 3:{if((c[aa>>2]|0)==0){c[aa>>2]=q0a(c[Y+48>>2]|0)|0}if((c[D>>2]|0)>0){ba=Z+160|0;$=0;do{y=og(S,q,c[(c[C>>2]|0)+($<<4)>>2]|0)|0;do{if((y|0)>0){c[ba>>2]=c[(c[C>>2]|0)+($<<4)+8>>2]}else{if((y|0)>=0){break}yf(1)}}while(0);$=$+1|0;}while(($|0)<(c[D>>2]|0))}if((c[x>>2]|0)>0){ia=0;ja=0}else{break b}while(1){$=og(S,q,c[(c[z>>2]|0)+(ja<<4)>>2]|0)|0;do{if(($|0)>0){ka=c[(c[z>>2]|0)+(ja<<4)+8>>2]|0}else{if(($|0)>=0){ka=ia;break}yf(1);ka=ia}}while(0);$=ja+1|0;if(($|0)<(c[x>>2]|0)){ia=ka;ja=$}else{break}}if((ka|0)==0){break b}if((OEb(Y+120|0,Y+124|0,ka)|0)>=0){break b}yDb(0,8,1978608,(u=i,i=i+8|0,c[u>>2]=ka,u)|0);i=u;yf(1);break};case 4:case-1:{break};default:{O=153;break a}}}while(0);Y=w+1|0;if(Y>>>0<(c[T>>2]|0)>>>0){w=Y}else{O=155;break}}if((O|0)==153){Cd();return 0}else if((O|0)==155){X=c[k>>2]|0;break}}}while(0);QT(X,c[1167942]|0,r,0);c[1271690]=rg(c[1271690]|0,4,4671768,(c[1167942]|0)+1|0)|0;X=cEb(72)|0;if((X|0)==0){yf(1)}c[(c[1271690]|0)+((c[1167942]|0)-1<<2)>>2]=X;O=c[k>>2]|0;c[X>>2]=O;T=O+24|0;O=X+12|0;c[O>>2]=(c[1167940]|0)-(c[T>>2]|0);ka=c[V+4>>2]|0;ja=X+40|0;c[ja>>2]=c[V>>2];c[ja+4>>2]=ka;ka=b+160|0;ja=c[ka+4>>2]|0;V=X+48|0;c[V>>2]=c[ka>>2];c[V+4>>2]=ja;ja=b+72|0;V=c[ja>>2]|0;ka=c[ja+4>>2]|0;ja=X+16|0;c[ja>>2]=V;c[ja+4>>2]=ka;ja=(c[2192648]|0)!=0;ia=ZGb(V,ka,ja?0:K,ja?0:R)|0;R=X+24|0;c[R>>2]=ia;c[R+4>>2]=F;c[X+56>>2]=c[T>>2];c[X+64>>2]=c[b+80>>2];c[X+68>>2]=c[b+84>>2];X=kh(c[(c[U>>2]|0)+16>>2]|0)|0;c[n>>2]=X;U=c[O>>2]|0;if((U|0)<(c[1167940]|0)){O=U;do{U=BBb(c[(c[(c[1271688]|0)+(O<<2)>>2]|0)+104>>2]|0,9203560,0,2)|0;if((U|0)!=0){T=U;do{CBb(n,c[T>>2]|0,0,0)|0;T=BBb(c[(c[(c[1271688]|0)+(O<<2)>>2]|0)+104>>2]|0,9203560,T,2)|0;}while((T|0)!=0)}O=O+1|0;}while((O|0)<(c[1167940]|0));la=c[n>>2]|0}else{la=X}X=BBb(la,9203560,0,2)|0;if((X|0)!=0){la=o;O=p;T=X;do{c[o>>2]=CRa()|0;X=T|0;U=qEb(la,c[X>>2]|0,0,0,3)|0;c[p>>2]=uN()|0;if((U|0)!=0&(qEb(O,c[X>>2]|0,0,0,3)|0)==0){if((c[U+40>>2]&2|0)==0){R=U+4|0;ia=c[R>>2]|0;ja=(c[1167942]|0)-1|0;yDb(0,16,1981840,(u=i,i=i+32|0,c[u>>2]=c[X>>2],c[u+8>>2]=(ia|0)==0?9203560:ia,c[u+16>>2]=ja,c[u+24>>2]=r,u)|0);i=u;yf(1);ma=R}else{ma=U+4|0}U=c[ma>>2]|0;R=(c[1167942]|0)-1|0;yDb(0,24,1981408,(u=i,i=i+32|0,c[u>>2]=c[X>>2],c[u+8>>2]=(U|0)==0?9203560:U,c[u+16>>2]=R,c[u+24>>2]=r,u)|0);i=u}T=BBb(c[n>>2]|0,9203560,T,2)|0;}while((T|0)!=0)}DBb(n);n=b+100|0;T=c[n>>2]|0;if((T|0)>0){r=b+96|0;b=0;ma=c[k>>2]|0;O=T;while(1){if((c[ma+24>>2]|0)==0){na=ma;oa=O}else{T=0;p=ma;do{la=c[(c[p+28>>2]|0)+(T<<2)>>2]|0;do{if((og(p,la,c[(c[r>>2]|0)+(b<<4)>>2]|0)|0)==1){o=c[(c[r>>2]|0)+(b<<4)+8>>2]|0;c[g>>2]=0;R=la+8|0;if((c[(c[R>>2]|0)+100>>2]|0)==0){U=c[la>>2]|0;yDb(0,24,1980688,(u=i,i=i+16|0,c[u>>2]=(c[1167942]|0)-1,c[u+8>>2]=U,u)|0);i=u;break}do{if((a[o]|0)==0){U=BBb(c[la+88>>2]|0,2212176,0,0)|0;if((U|0)==0){pa=o;break}pa=c[U+4>>2]|0}else{pa=o}}while(0);if((a[pa]|0)==0){o=c[la>>2]|0;yDb(0,8,1980176,(u=i,i=i+16|0,c[u>>2]=(c[1167942]|0)-1,c[u+8>>2]=o,u)|0);i=u;yf(1)}lh(pa);if((Hz(g,pa,2,912112,0)|0)<0){yDb(0,8,1980008,(u=i,i=i+8|0,c[u>>2]=pa,u)|0);i=u;yf(1)}o=c[R>>2]|0;Ry(c[g>>2]|0,c[o+96>>2]|0,c[o+100>>2]|0);Sy(c[g>>2]|0);Iz(c[g>>2]|0)|0}}while(0);T=T+1|0;p=c[k>>2]|0;}while(T>>>0<(c[p+24>>2]|0)>>>0);na=p;oa=c[n>>2]|0}T=b+1|0;if((T|0)<(oa|0)){b=T;ma=na;O=oa}else{break}}}if((s|0)>0){qa=0}else{ra=m;$Db(ra);i=f;return 0}do{DBb((c[m>>2]|0)+(qa<<2)|0);qa=qa+1|0;}while((qa|0)<(s|0));ra=m;$Db(ra);i=f;return 0}function Ag(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0.0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;e=i;i=i+200|0;f=e|0;h=e+8|0;j=e+16|0;k=e+24|0;l=e+32|0;m=e+40|0;n=e+48|0;o=e+56|0;p=e+64|0;q=e+72|0;r=e+80|0;s=e+88|0;t=e+96|0;u=e+104|0;v=e+168|0;w=e+176|0;x=e+184|0;y=e+192|0;c[r>>2]=0;z=c[1167948]|0;a:do{if((z|0)>0){A=0;B=z;while(1){C=c[(c[1305380]|0)+(A<<2)>>2]|0;if((c[C+8>>2]|0)==0){if((vh(C)|0)<0){break}D=c[1167948]|0}else{D=B}C=A+1|0;if((C|0)<(D|0)){A=C;B=D}else{break a}}yDb(0,8,2021928,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;yf(1)}}while(0);D=b+168|0;z=c[D>>2]|0;B=c[D+4>>2]|0;do{if(!((z|0)==(-1|0)&(B|0)==2147483647)){A=b+160|0;if((c[A>>2]|0)==(-1|0)&(c[A+4>>2]|0)==2147483647){G=B;H=z}else{c[D>>2]=-1;c[D+4>>2]=2147483647;yDb(0,24,2021136,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;C=c[D>>2]|0;I=c[D+4>>2]|0;if((C|0)==(-1|0)&(I|0)==2147483647){break}if((c[A>>2]|0)==(-1|0)&(c[A+4>>2]|0)==2147483647){G=I;H=C}else{break}}C=b+8|0;I=c[C>>2]|0;J=c[C+4>>2]|0;C=(I|0)==0&(J|0)==(-2147483648|0);K=C?0:I;I=C?0:J;if((G|0)>(I|0)|(G|0)==(I|0)&H>>>0>K>>>0){J=ZGb(H,G,K,I)|0;c[A>>2]=J;c[A+4>>2]=F;break}else{yDb(0,24,2020512,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;c[D>>2]=-1;c[D+4>>2]=2147483647;break}}}while(0);c[1163660]=rg(c[1163660]|0,4,4671752,(c[1167938]|0)+1|0)|0;D=cEb(48)|0;if((D|0)==0){yf(1)}c[(c[1163660]|0)+((c[1167938]|0)-1<<2)>>2]=D;G=D+8|0;c[G>>2]=c[1167936];H=b+160|0;z=c[H+4>>2]|0;B=D+16|0;c[B>>2]=c[H>>2];c[B+4>>2]=z;z=b+8|0;A=c[z+4>>2]|0;J=D+24|0;c[J>>2]=c[z>>2];c[J+4>>2]=A;A=b+176|0;z=c[A+4>>2]|0;I=D+32|0;c[I>>2]=c[A>>2];c[I+4>>2]=z;c[D+40>>2]=c[b+192>>2];z=D+4|0;I=b|0;EBb(z,c[(c[I>>2]|0)+20>>2]|0,0);A=(QGb(d,2028088)|0)==0;K=A?2027368:d;d=EK(q,0,c[b+16>>2]|0,K)|0;A=c[q>>2]|0;if((A|0)==0){Sf(K,d);yf(1);L=c[q>>2]|0}else{L=A}A=D;c[A>>2]=L;D=c[H>>2]|0;d=c[H+4>>2]|0;if(!((D|0)==(-1|0)&(d|0)==2147483647)){C=L+1064|0;c[C>>2]=D;c[C+4>>2]=d}d=c[L+8>>2]|0;C=L+1160|0;L=912112;D=c[L>>2]|0;M=c[L+4>>2]|0;c[C>>2]=D;c[C+4>>2]=M;C=c[1167948]|0;if((C|0)>0){L=b+196|0;N=b+200|0;O=b+204|0;P=0;Q=C;while(1){C=c[(c[1305380]|0)+(P<<2)>>2]|0;R=C+28|0;S=c[R>>2]|0;if((S|0)>0){T=C+24|0;C=0;U=S;while(1){S=c[(c[T>>2]|0)+(C<<2)>>2]|0;V=c[S+16>>2]|0;do{if((V|0)==0){W=U}else{if((c[V>>2]|0)!=0){W=U;break}X=bj(c[(c[V+4>>2]|0)+28>>2]|0,c[V+8>>2]|0)|0;if((X|0)==1){c[N>>2]=1}else if((X|0)==3){c[O>>2]=1}else if((X|0)==0){c[L>>2]=1}gh(S,b,c[q>>2]|0);W=c[R>>2]|0}}while(0);S=C+1|0;if((S|0)<(W|0)){C=S;U=W}else{break}}Y=c[1167948]|0}else{Y=Q}U=P+1|0;if((U|0)<(Y|0)){P=U;Q=Y}else{break}}}Y=d|0;do{if((QGb(c[Y>>2]|0,2020344)|0)==0){if((qAb(K,2020040,0)|0)==0){break}d=Df(b,2315736,2019800,625312)|0;if((d|0)>=0){break}Sf(K,d);yf(1)}}while(0);d=QGb(c[Y>>2]|0,2020344)|0;do{if((c[1163656]|d|0)==0){if((qAb(K,2020040,0)|0)==0){Z=66;break}Y=c[q>>2]|0;Q=tN()|0;c[p>>2]=Q;P=Q+1160|0;c[P>>2]=D;c[P+4>>2]=M;P=aT(p,K,0,0)|0;do{if((P|0)<0){Sf(K,P);yf(1)}else{Q=c[p>>2]|0;if((c[Q+24>>2]|0)==0){KT(p);break}else{_=0;$=Q}do{Q=p0a(c[(c[(c[(c[$+28>>2]|0)+(_<<2)>>2]|0)+8>>2]|0)+48>>2]|0)|0;W=nh(b,Y,c[Q+8>>2]|0,-1)|0;L=c[W+12>>2]|0;O=L+8|0;N=c[O>>2]|0;c[W+60>>2]=Q;UGb(L|0,c[(c[(c[p>>2]|0)+28>>2]|0)+(_<<2)>>2]|0,656)|0;U=L+208|0;c[U>>2]=0;c[U+4>>2]=0;U=WDb(104)|0;c[L+184>>2]=U;UGb(U|0,c[(c[(c[(c[p>>2]|0)+28>>2]|0)+(_<<2)>>2]|0)+184>>2]|0,104)|0;c[O>>2]=N;BRa(N,c[(c[(c[(c[p>>2]|0)+28>>2]|0)+(_<<2)>>2]|0)+8>>2]|0)|0;N=c[O>>2]|0;O=c[N+8>>2]|0;do{if((O|0)==0){if((c[W+352>>2]|0)!=0){break}rh(L,Q,c[N+140>>2]|0)|0}else if((O|0)==1){if((c[W+352>>2]|0)!=0){break}sh(L,Q)}}while(0);_=_+1|0;$=c[p>>2]|0;}while(_>>>0<(c[$+24>>2]|0)>>>0);KT(p)}}while(0);Y=c[1167936]|0;P=Y-(c[(c[q>>2]|0)+24>>2]|0)|0;if((P|0)<(Y|0)){aa=P}else{break}do{P=c[(c[1163658]|0)+(aa<<2)>>2]|0;Y=c[1167940]|0;Q=c[1271688]|0;L=P+12|0;W=0;while(1){if((W|0)>=(Y|0)){Z=62;break}ca=c[Q+(W<<2)>>2]|0;da=ca+4|0;ea=(c[L>>2]|0)+8|0;if((c[(c[(c[da>>2]|0)+8>>2]|0)+8>>2]|0)==(c[(c[ea>>2]|0)+8>>2]|0)){Z=57;break}else{W=W+1|0}}if((Z|0)==57){Z=0;Q=P+24|0;c[Q>>2]=ca;c[P+8>>2]=W;Y=c[(c[ea>>2]|0)+8>>2]|0;if((Y|0)==1){c[P+304>>2]=eEb(2019408)|0;fa=c[(c[(c[L>>2]|0)+8>>2]|0)+8>>2]|0}else{fa=Y}if((fa|0)==0){c[P+304>>2]=eEb(2019224)|0}c[ca+8>>2]=0;c[(c[da>>2]|0)+76>>2]=-16;ga=Q}else if((Z|0)==62){Z=0;ga=P+24|0}if((c[ga>>2]|0)==0){Q=lGb(c[(c[(c[L>>2]|0)+8>>2]|0)+8>>2]|0)|0;yDb(0,8,2018952,(E=i,i=i+8|0,c[E>>2]=Q,E)|0);i=E;yf(1)}aa=aa+1|0;}while((aa|0)<(c[1167936]|0))}else{Z=66}}while(0);b:do{if((Z|0)==66){aa=b+124|0;ga=c[aa>>2]|0;if((ga|0)!=0){if((ga|0)<=0){break}ga=b+120|0;da=b+204|0;ca=b+200|0;fa=b+196|0;ea=b+208|0;p=0;while(1){$=c[ga>>2]|0;c:do{if((c[$+(p*24|0)>>2]|0)==0){_=c[$+(p*24|0)+20>>2]|0;if((_|0)!=0){M=c[1167948]|0;d:do{if((M|0)>0){D=c[1305380]|0;d=0;e:while(1){Q=c[D+(d<<2)>>2]|0;Y=c[Q+28>>2]|0;if((Y|0)>0){O=c[Q+24>>2]|0;Q=0;do{ha=c[O+(Q<<2)>>2]|0;N=c[ha+16>>2]|0;if((N|0)!=0){if((QGb(c[N>>2]|0,_)|0)==0){break e}}Q=Q+1|0;}while((Q|0)<(Y|0))}Y=d+1|0;if((Y|0)<(M|0)){d=Y}else{Z=113;break d}}if((ha|0)==0){Z=113}else{ia=ha}}else{Z=113}}while(0);if((Z|0)==113){Z=0;yDb(0,8,2018560,(E=i,i=i+8|0,c[E>>2]=_,E)|0);i=E;yf(1);ia=0}gh(ia,b,c[q>>2]|0);break}M=c[$+(p*24|0)+4>>2]|0;d=c[$+(p*24|0)+8>>2]|0;D=d+(c[(c[(c[1271690]|0)+(M<<2)>>2]|0)+12>>2]|0)|0;Y=c[(c[1271688]|0)+(D<<2)>>2]|0;if((c[da>>2]|0)!=0){if((c[(c[(c[Y+4>>2]|0)+8>>2]|0)+8>>2]|0)==3){break}}if((c[ca>>2]|0)!=0){if((c[(c[(c[Y+4>>2]|0)+8>>2]|0)+8>>2]|0)==1){break}}if((c[fa>>2]|0)!=0){if((c[(c[(c[Y+4>>2]|0)+8>>2]|0)+8>>2]|0)==0){break}}Q=c[(c[(c[Y+4>>2]|0)+8>>2]|0)+8>>2]|0;if((c[ea>>2]|0)!=0&(Q|0)==2){break}switch(Q|0){case 0:{hh(b,c[q>>2]|0,D)|0;break c;break};case 1:{ih(b,c[q>>2]|0,D)|0;break c;break};case 3:{jh(b,c[q>>2]|0,D);break c;break};case 2:{if((c[(nh(b,c[q>>2]|0,2,D)|0)+352>>2]|0)!=0){break c}yDb(0,8,1993144,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;yf(1);break c;break};case 4:{Q=nh(b,c[q>>2]|0,4,D)|0;c[Q+352>>2]=1;c[Q+344>>2]=1;break c;break};default:{yDb(0,8,2018216,(E=i,i=i+16|0,c[E>>2]=M,c[E+8>>2]=d,E)|0);i=E;yf(1);break c}}}}while(0);p=p+1|0;if((p|0)>=(c[aa>>2]|0)){break b}}}do{if((c[b+196>>2]|0)==0){aa=c[(c[q>>2]|0)+8>>2]|0;p=c[aa+20>>2]|0;if((p|0)==0){break}ea=cU(aa,p,0)|0;p=c[1167940]|0;if((p|0)<=0){break}aa=c[1271688]|0;fa=(ea|0)==1128878145;ea=-1;ca=0;da=0;while(1){ga=c[(c[aa+(da<<2)>>2]|0)+4>>2]|0;$=c[ga+8>>2]|0;L=ba(c[$+124>>2]|0,c[$+120>>2]|0)|0;if(fa){ja=L}else{ja=(c[ga+72>>2]&1024|0)==0?L:1}do{if((c[$+8>>2]|0)==0&(ja|0)>(ca|0)){if(fa){if((c[ga+72>>2]&1024|0)==0){ka=ca;la=ea;break}}ka=ja;la=da}else{ka=ca;la=ea}}while(0);ga=da+1|0;if((ga|0)<(p|0)){ea=la;ca=ka;da=ga}else{break}}if(!((la|0)>-1)){break}hh(b,c[q>>2]|0,la)|0}}while(0);do{if((c[b+200>>2]|0)==0){da=c[q>>2]|0;if((c[(c[da+8>>2]|0)+16>>2]|0)==0){break}ca=c[1167940]|0;if((ca|0)<=0){break}ea=c[1271688]|0;p=0;fa=-1;aa=0;while(1){ga=c[(c[(c[ea+(aa<<2)>>2]|0)+4>>2]|0)+8>>2]|0;if((c[ga+8>>2]|0)==1){$=c[ga+416>>2]|0;ga=($|0)>(p|0);ma=ga?aa:fa;na=ga?$:p}else{ma=fa;na=p}$=aa+1|0;if(($|0)<(ca|0)){p=na;fa=ma;aa=$}else{break}}if(!((ma|0)>-1)){break}ih(b,da,ma)|0}}while(0);aa=c[b+24>>2]|0;if((aa|0)>0){fa=c[b+20>>2]|0;p=0;ca=0;while(1){if((QGb(c[fa+(p<<4)>>2]|0,2188440)|0)==0){oa=c[fa+(p<<4)+8>>2]|0}else{oa=ca}ea=p+1|0;if((ea|0)<(aa|0)){p=ea;ca=oa}else{pa=oa;break}}}else{pa=0}if((c[b+204>>2]|0)!=0){break}if((p0a(c[(c[(c[q>>2]|0)+8>>2]|0)+24>>2]|0)|0)==0&(pa|0)==0){break}ca=c[1167940]|0;p=c[1271688]|0;aa=0;while(1){if((aa|0)>=(ca|0)){break b}if((c[(c[(c[(c[p+(aa<<2)>>2]|0)+4>>2]|0)+8>>2]|0)+8>>2]|0)==3){break}else{aa=aa+1|0}}jh(b,c[q>>2]|0,aa)}}while(0);pa=b+152|0;if((c[pa>>2]|0)>0){oa=b+148|0;ma=0;do{if((Hz(s,c[(c[oa>>2]|0)+(ma<<2)>>2]|0,1,912112,0)|0)<0){yDb(0,8,2017280,(E=i,i=i+8|0,c[E>>2]=c[(c[oa>>2]|0)+(ma<<2)>>2],E)|0);i=E;yf(1)}na=Wy(c[s>>2]|0)|0;la=F;ka=0;if((la|0)<(ka|0)|(la|0)==(ka|0)&na>>>0<1>>>0){yDb(0,8,2016624,(E=i,i=i+8|0,c[E>>2]=c[(c[oa>>2]|0)+(ma<<2)>>2],E)|0);i=E;yf(1)}ka=na;na=WDb(ka)|0;if((na|0)==0){yDb(0,8,2016392,(E=i,i=i+8|0,c[E>>2]=c[(c[oa>>2]|0)+(ma<<2)>>2],E)|0);i=E;yf(1)}mz(c[s>>2]|0,na,ka)|0;la=nh(b,c[q>>2]|0,4,-1)|0;ja=la+344|0;c[ja>>2]=1;c[la+352>>2]=0;c[la+356>>2]=c[(c[oa>>2]|0)+(ma<<2)>>2];c[ja>>2]=1;ja=la+12|0;c[(c[(c[ja>>2]|0)+8>>2]|0)+96>>2]=na;na=c[ja>>2]|0;c[(c[na+8>>2]|0)+100>>2]=ka;ka=c[(c[oa>>2]|0)+(ma<<2)>>2]|0;ja=cc(ka|0,47)|0;if((ja|0)==0){qa=ka}else{qa=(a[ja]|0)==0?ka:ja+1|0}CBb(na+88|0,2212176,qa,16)|0;Iz(c[s>>2]|0)|0;ma=ma+1|0;}while((ma|0)<(c[pa>>2]|0))}pa=c[1167936]|0;ma=pa-(c[(c[q>>2]|0)+24>>2]|0)|0;if((ma|0)<(pa|0)){pa=ma;do{ma=c[(c[1163658]|0)+(pa<<2)>>2]|0;if((c[ma+352>>2]|0)==0){if((c[ma+356>>2]|0)!=0){Z=143}}else{Z=143}do{if((Z|0)==143){Z=0;s=BBb(c[(c[I>>2]|0)+16>>2]|0,1947408,0,2)|0;if((s|0)==0){break}qa=c[s>>2]|0;if((a[qa+5|0]|0)==0){ra=ma+12|0}else{oa=ma+12|0;if((og(c[q>>2]|0,c[oa>>2]|0,qa+6|0)|0)==0){break}else{ra=oa}}if((rEb(c[(c[ra>>2]|0)+8>>2]|0,1947408,c[s+4>>2]|0,0)|0)>=0){break}yf(1)}}while(0);pa=pa+1|0;}while((pa|0)<(c[1167936]|0))}pa=kh(c[(c[I>>2]|0)+16>>2]|0)|0;c[r>>2]=pa;I=c[G>>2]|0;if((I|0)<(c[1167936]|0)){ra=I;do{I=BBb(c[(c[(c[1163658]|0)+(ra<<2)>>2]|0)+328>>2]|0,9203560,0,2)|0;if((I|0)!=0){ma=I;do{CBb(r,c[ma>>2]|0,0,0)|0;ma=BBb(c[(c[(c[1163658]|0)+(ra<<2)>>2]|0)+328>>2]|0,9203560,ma,2)|0;}while((ma|0)!=0)}ra=ra+1|0;}while((ra|0)<(c[1167936]|0));sa=c[r>>2]|0}else{sa=pa}pa=BBb(sa,9203560,0,2)|0;if((pa|0)!=0){sa=t;ra=pa;do{c[t>>2]=CRa()|0;pa=ra|0;ma=qEb(sa,c[pa>>2]|0,0,0,3)|0;do{if((ma|0)!=0){if((c[ma+40>>2]&1|0)==0){I=c[ma+4>>2]|0;aa=(c[1167938]|0)-1|0;yDb(0,16,2016032,(E=i,i=i+32|0,c[E>>2]=c[pa>>2],c[E+8>>2]=(I|0)==0?9203560:I,c[E+16>>2]=aa,c[E+24>>2]=K,E)|0);i=E;yf(1)}aa=c[pa>>2]|0;if((QGb(aa,2066008)|0)==0){break}I=c[ma+4>>2]|0;s=(c[1167938]|0)-1|0;yDb(0,24,2015624,(E=i,i=i+32|0,c[E>>2]=aa,c[E+8>>2]=(I|0)==0?9203560:I,c[E+16>>2]=s,c[E+24>>2]=K,E)|0);i=E}}while(0);ra=BBb(c[r>>2]|0,9203560,ra,2)|0;}while((ra|0)!=0)}DBb(r);r=c[q>>2]|0;do{if((c[(c[r+8>>2]|0)+28>>2]&2|0)!=0){if((WS(r+32|0)|0)!=0){break}Sf((c[q>>2]|0)+32|0,-22);yf(1)}}while(0);r=c[(c[q>>2]|0)+8>>2]|0;do{if((c[r+28>>2]&1|0)==0){lh(K);ra=c[q>>2]|0;sa=Hz(ra+16|0,K,2,ra+1160|0,z)|0;if((sa|0)>=0){break}Sf(K,sa);yf(1)}else{if((QGb(c[r>>2]|0,2015248)|0)!=0){break}if((WS(K)|0)!=0){break}lh(K)}}while(0);ta=+g[b+184>>2];if(ta!=0.0){K=u|0;Lb(K|0,64,2071080,(E=i,i=i+8|0,c[E>>2]=~~(ta*1.0e6),E)|0)|0;i=E;CBb(z,2014904,K,0)|0}c[(c[q>>2]|0)+1080>>2]=~~(+g[b+188>>2]*1.0e6);K=b+336|0;f:do{if((c[K>>2]|0)>0){z=b+332|0;u=b+136|0;r=b+140|0;sa=b+144|0;ra=0;g:while(1){t=kb(c[(c[z>>2]|0)+(ra<<4)+8>>2]|0,v|0,0)|0;if((t|0)>=(c[1167942]|0)){yDb(0,8,2014600,(E=i,i=i+8|0,c[E>>2]=t,E)|0);i=E;yf(1)}ma=c[(c[z>>2]|0)+(ra<<4)>>2]|0;pa=c[v>>2]|0;s=(a[pa]|0)!=0?pa+1|0:pa;pa=c[q>>2]|0;if((t|0)>-1){ua=c[c[(c[1271690]|0)+(t<<2)>>2]>>2]|0}else{ua=0}c[l>>2]=0;c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;mh(s,j,n,l);mh(ma,k,o,m);do{if((ua|0)==0){s=a[k]|0;if(s<<24>>24==103){Z=183}else{if((a[ma]|0)==0){Z=183}}if((Z|0)==183){Z=0;c[u>>2]=1}if(s<<24>>24==115){Z=186}else{if((a[ma]|0)==0){Z=186}}if((Z|0)==186){Z=0;c[r>>2]=1}if(!(s<<24>>24==99)){if((a[ma]|0)!=0){break}}c[sa>>2]=1}else{s=a[j]|0;if(s<<24>>24==103){Z=192}else{if((a[k]|0)==103){Z=192}}if((Z|0)==192){Z=0;c[u>>2]=1}t=s<<24>>24==115;if(t){Z=195}else{if((a[k]|0)==115){Z=195}}if((Z|0)==195){Z=0;c[r>>2]=1}if(s<<24>>24==99){Z=198}else{if((a[k]|0)==99){Z=198}}if((Z|0)==198){Z=0;c[sa>>2]=1}I=s<<24>>24;if((I|0)==103){va=ua+1140|0}else if((I|0)==99){s=c[n>>2]|0;if((s|0)<0){Z=203}else{if(!(s>>>0<(c[ua+1132>>2]|0)>>>0)){Z=203}}if((Z|0)==203){Z=0;yDb(0,8,2012176,(E=i,i=i+16|0,c[E>>2]=2011944,c[E+8>>2]=s,E)|0);i=E;yf(1)}va=(c[(c[ua+1136>>2]|0)+(s<<2)>>2]|0)+32|0}else if((I|0)==112){s=c[n>>2]|0;if((s|0)<0){Z=207}else{if(!(s>>>0<(c[ua+1104>>2]|0)>>>0)){Z=207}}if((Z|0)==207){Z=0;yDb(0,8,2012176,(E=i,i=i+16|0,c[E>>2]=2011696,c[E+8>>2]=s,E)|0);i=E;yf(1)}va=(c[(c[ua+1108>>2]|0)+(s<<2)>>2]|0)+20|0}else if((I|0)==115){va=0}else{Z=209;break g}I=a[k]|0;s=I<<24>>24;if((s|0)==103){wa=pa+1140|0}else if((s|0)==99){aa=c[o>>2]|0;if((aa|0)<0){Z=214}else{if(!(aa>>>0<(c[pa+1132>>2]|0)>>>0)){Z=214}}if((Z|0)==214){Z=0;yDb(0,8,2012176,(E=i,i=i+16|0,c[E>>2]=2011944,c[E+8>>2]=aa,E)|0);i=E;yf(1)}wa=(c[(c[pa+1136>>2]|0)+(aa<<2)>>2]|0)+32|0}else if((s|0)==112){aa=c[o>>2]|0;if((aa|0)<0){Z=218}else{if(!(aa>>>0<(c[pa+1104>>2]|0)>>>0)){Z=218}}if((Z|0)==218){Z=0;yDb(0,8,2012176,(E=i,i=i+16|0,c[E>>2]=2011696,c[E+8>>2]=aa,E)|0);i=E;yf(1)}wa=(c[(c[pa+1108>>2]|0)+(aa<<2)>>2]|0)+20|0}else if((s|0)==115){wa=0}else{Z=220;break g}do{if(t){s=ua+24|0;h:do{if((c[s>>2]|0)==0){xa=va}else{aa=ua+28|0;oa=c[l>>2]|0;qa=0;while(1){na=og(ua,c[(c[aa>>2]|0)+(qa<<2)>>2]|0,oa)|0;if((na|0)>0){break}if((na|0)<0){yf(1)}na=qa+1|0;if(na>>>0<(c[s>>2]|0)>>>0){qa=na}else{xa=va;break h}}xa=(c[(c[aa>>2]|0)+(qa<<2)>>2]|0)+88|0}}while(0);if((xa|0)!=0){ya=xa;break}yDb(0,8,2010480,(E=i,i=i+8|0,c[E>>2]=c[l>>2],E)|0);i=E;yf(1);ya=0}else{ya=va}}while(0);if(!(I<<24>>24==115)){EBb(wa,c[ya>>2]|0,16);break}t=pa+24|0;if((c[t>>2]|0)==0){break}s=pa+28|0;oa=c[m>>2]|0;na=0;do{ja=og(pa,c[(c[s>>2]|0)+(na<<2)>>2]|0,oa)|0;do{if((ja|0)>0){EBb((c[(c[s>>2]|0)+(na<<2)>>2]|0)+88|0,c[ya>>2]|0,16)}else{if((ja|0)>=0){break}yf(1)}}while(0);na=na+1|0;}while(na>>>0<(c[t>>2]|0)>>>0)}}while(0);ra=ra+1|0;if((ra|0)>=(c[K>>2]|0)){break f}}if((Z|0)==209){yDb(0,0,2011488,(E=i,i=i+24|0,c[E>>2]=2035432,c[E+8>>2]=2011352,c[E+16>>2]=469,E)|0);i=E;Cd();return 0}else if((Z|0)==220){yDb(0,0,2011488,(E=i,i=i+24|0,c[E>>2]=2035432,c[E+8>>2]=2011352,c[E+16>>2]=470,E)|0);i=E;Cd();return 0}}}while(0);K=b+156|0;ya=c[K>>2]|0;i:do{if((ya|0)<(c[1167942]|0)){za=ya;Z=248}else{if((ya|0)!=2147483647){yDb(0,8,2014248,(E=i,i=i+8|0,c[E>>2]=ya,E)|0);i=E;yf(1);za=c[K>>2]|0;Z=248;break}c[K>>2]=-1;m=c[1167942]|0;wa=c[1271690]|0;va=0;while(1){if((va|0)>=(m|0)){break i}if((c[(c[c[wa+(va<<2)>>2]>>2]|0)+1132>>2]|0)==0){va=va+1|0}else{break}}c[K>>2]=va;za=va;Z=248}}while(0);j:do{if((Z|0)==248){if(!((za|0)>-1)){break}K=c[(c[1271690]|0)+(za<<2)>>2]|0;ya=(c[b+144>>2]|0)==0;wa=c[K>>2]|0;m=c[A>>2]|0;l=m+1136|0;xa=wa+1132|0;ua=m+1132|0;m=YDb(c[l>>2]|0,(c[ua>>2]|0)+(c[xa>>2]|0)|0,4)|0;if((m|0)==0){break}c[l>>2]=m;if((c[xa>>2]|0)==0){break}m=wa+1136|0;wa=K+24|0;K=f|0;o=f+4|0;k=h|0;n=h+4|0;if(ya){ya=0;do{j=c[(c[m>>2]|0)+(ya<<2)>>2]|0;v=c[J>>2]|0;ra=c[J+4>>2]|0;sa=(v|0)==0&(ra|0)==(-2147483648|0);r=ZGb(sa?0:v,sa?0:ra,c[wa>>2]|0,c[wa+4>>2]|0)|0;c[K>>2]=1;c[o>>2]=1e6;ra=j+4|0;sa=KDb(r,F,f,ra)|0;r=F;v=c[B>>2]|0;u=c[B+4>>2]|0;if((v|0)==(-1|0)&(u|0)==2147483647){Aa=2147483647;Ba=-1}else{c[k>>2]=1;c[n>>2]=1e6;z=KDb(v,u,h,ra)|0;Aa=F;Ba=z}z=j+24|0;u=c[z+4>>2]|0;if(!((u|0)<(r|0)|(u|0)==(r|0)&(c[z>>2]|0)>>>0<sa>>>0)){if(!((Ba|0)==(-1|0)&(Aa|0)==2147483647)){u=j+16|0;v=c[u>>2]|0;pa=c[u+4>>2]|0;u=YGb(Ba,Aa,sa,r)|0;ma=F;if((pa|0)>(ma|0)|(pa|0)==(ma|0)&v>>>0>u>>>0){break j}}u=cEb(40)|0;if((u|0)==0){break j}c[u>>2]=c[j>>2];v=ra;ra=u+4|0;ma=c[v+4>>2]|0;c[ra>>2]=c[v>>2];c[ra+4>>2]=ma;ma=j+16|0;ra=ZGb(c[ma>>2]|0,c[ma+4>>2]|0,sa,r)|0;ma=F;v=0;pa=(ma|0)<(v|0)|(ma|0)==(v|0)&ra>>>0<0>>>0;v=u+16|0;c[v>>2]=pa?0:ra;c[v+4>>2]=pa?0:ma;ma=ZGb(c[z>>2]|0,c[z+4>>2]|0,sa,r)|0;r=F;sa=(Aa|0)>(r|0)|(Aa|0)==(r|0)&Ba>>>0>ma>>>0;z=u+24|0;c[z>>2]=sa?ma:Ba;c[z+4>>2]=sa?r:Aa;EBb(u+32|0,c[j+32>>2]|0,0);j=c[ua>>2]|0;c[ua>>2]=j+1;c[(c[l>>2]|0)+(j<<2)>>2]=u}ya=ya+1|0;}while(ya>>>0<(c[xa>>2]|0)>>>0)}else{ya=0;do{va=c[(c[m>>2]|0)+(ya<<2)>>2]|0;u=c[J>>2]|0;j=c[J+4>>2]|0;r=(u|0)==0&(j|0)==(-2147483648|0);sa=ZGb(r?0:u,r?0:j,c[wa>>2]|0,c[wa+4>>2]|0)|0;c[K>>2]=1;c[o>>2]=1e6;j=va+4|0;r=KDb(sa,F,f,j)|0;sa=F;u=c[B>>2]|0;z=c[B+4>>2]|0;if((u|0)==(-1|0)&(z|0)==2147483647){Ca=2147483647;Da=-1}else{c[k>>2]=1;c[n>>2]=1e6;ma=KDb(u,z,h,j)|0;Ca=F;Da=ma}ma=va+24|0;z=c[ma+4>>2]|0;if(!((z|0)<(sa|0)|(z|0)==(sa|0)&(c[ma>>2]|0)>>>0<r>>>0)){if(!((Da|0)==(-1|0)&(Ca|0)==2147483647)){z=va+16|0;u=c[z>>2]|0;pa=c[z+4>>2]|0;z=YGb(Da,Ca,r,sa)|0;v=F;if((pa|0)>(v|0)|(pa|0)==(v|0)&u>>>0>z>>>0){break j}}z=cEb(40)|0;if((z|0)==0){break j}c[z>>2]=c[va>>2];u=j;j=z+4|0;v=c[u+4>>2]|0;c[j>>2]=c[u>>2];c[j+4>>2]=v;v=va+16|0;va=ZGb(c[v>>2]|0,c[v+4>>2]|0,r,sa)|0;v=F;j=0;u=(v|0)<(j|0)|(v|0)==(j|0)&va>>>0<0>>>0;j=z+16|0;c[j>>2]=u?0:va;c[j+4>>2]=u?0:v;v=ZGb(c[ma>>2]|0,c[ma+4>>2]|0,r,sa)|0;sa=F;r=(Ca|0)>(sa|0)|(Ca|0)==(sa|0)&Da>>>0>v>>>0;ma=z+24|0;c[ma>>2]=r?v:Da;c[ma+4>>2]=r?sa:Ca;sa=c[ua>>2]|0;c[ua>>2]=sa+1;c[(c[l>>2]|0)+(sa<<2)>>2]=z}ya=ya+1|0;}while(ya>>>0<(c[xa>>2]|0)>>>0)}}}while(0);if((c[b+136>>2]|0)==0&(c[1167942]|0)!=0){EBb((c[q>>2]|0)+1140|0,c[(c[c[c[1271690]>>2]>>2]|0)+1140>>2]|0,16);if(!((c[H>>2]|0)==(-1|0)&(c[H+4>>2]|0)==2147483647)){CBb((c[q>>2]|0)+1140|0,1880544,0,0)|0}CBb((c[q>>2]|0)+1140|0,2014152,0,0)|0}do{if((c[b+140>>2]|0)==0){H=c[G>>2]|0;Ca=c[1167936]|0;if((H|0)<(Ca|0)){Ea=H;Fa=Ca}else{break}while(1){Ca=c[(c[1163658]|0)+(Ea<<2)>>2]|0;H=c[Ca+8>>2]|0;if((H|0)<0){Ga=Fa}else{EBb((c[Ca+12>>2]|0)+88|0,c[(c[(c[(c[1271688]|0)+(H<<2)>>2]|0)+4>>2]|0)+88>>2]|0,16);Ga=c[1167936]|0}H=Ea+1|0;if((H|0)<(Ga|0)){Ea=H;Fa=Ga}else{break}}}}while(0);Ga=b+224|0;if((c[Ga>>2]|0)<=0){i=e;return 0}Fa=b+220|0;b=0;Ea=0;while(1){c[y>>2]=0;G=c[(c[Fa>>2]|0)+(b<<4)+8>>2]|0;H=Vb(G|0,61)|0;if((H|0)==0){yDb(0,8,2013336,(E=i,i=i+8|0,c[E>>2]=G,E)|0);i=E;yf(1)}G=H+1|0;a[H]=0;mh(c[(c[Fa>>2]|0)+(b<<4)>>2]|0,w,y,x);H=a[w]|0;do{if(H<<24>>24==115){Ca=c[q>>2]|0;if((c[Ca+24>>2]|0)==0){Ha=Ea;break}Da=c[x>>2]|0;h=0;B=Ca;while(1){Ca=og(B,c[(c[B+28>>2]|0)+(h<<2)>>2]|0,Da)|0;do{if((Ca|0)>0){CBb((c[(c[(c[q>>2]|0)+28>>2]|0)+(h<<2)>>2]|0)+88|0,c[(c[Fa>>2]|0)+(b<<4)+8>>2]|0,(a[G]|0)!=0?G:0,0)|0}else{if((Ca|0)>=0){break}yf(1)}}while(0);Ca=h+1|0;f=c[q>>2]|0;if(Ca>>>0<(c[f+24>>2]|0)>>>0){h=Ca;B=f}else{Ha=Ea;break}}}else{B=H<<24>>24;if((B|0)==103){Ia=(c[q>>2]|0)+1140|0}else if((B|0)==99){B=c[y>>2]|0;if((B|0)<0){Z=293}else{h=c[q>>2]|0;if(B>>>0<(c[h+1132>>2]|0)>>>0){Ja=h}else{Z=293}}if((Z|0)==293){Z=0;yDb(0,8,2012744,(E=i,i=i+8|0,c[E>>2]=B,E)|0);i=E;yf(1);Ja=c[q>>2]|0}Ia=(c[(c[Ja+1136>>2]|0)+(B<<2)>>2]|0)+32|0}else{yDb(0,8,2012600,(E=i,i=i+8|0,c[E>>2]=c[(c[Fa>>2]|0)+(b<<4)>>2],E)|0);i=E;yf(1);Ia=Ea}CBb(Ia,c[(c[Fa>>2]|0)+(b<<4)+8>>2]|0,(a[G]|0)!=0?G:0,0)|0;Ha=Ia}}while(0);G=b+1|0;if((G|0)<(c[Ga>>2]|0)){b=G;Ea=Ha}else{break}}i=e;return 0}function Bg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+32|0;f=d|0;g=d+8|0;h=d+16|0;j=d+24|0;k=(a[e]|0)==45;l=k?e+1|0:e;e=eEb(l)|0;c[h>>2]=e;m=Vb(e|0,44)|0;c[g>>2]=m;do{if((m|0)==0){n=0;o=-1}else{a[m]=0;e=kb(m+1|0,g|0,0)|0;if((e|0)>=(c[1167942]|0)|(e|0)<0){yDb(0,8,2023272,(p=i,i=i+8|0,c[p>>2]=e,p)|0);i=p;yf(1)}q=c[g>>2]|0;if((a[q]|0)==0){r=q}else{s=q+1|0;c[g>>2]=s;r=s}s=0;while(1){q=c[(c[1271690]|0)+(e<<2)>>2]|0;t=c[q+56>>2]|0;if((s|0)>=(t|0)){u=0;v=t;break}t=c[q>>2]|0;if((og(t,c[(c[t+28>>2]|0)+(s<<2)>>2]|0,r)|0)==1){w=9;break}else{s=s+1|0}}if((w|0)==9){u=s;v=c[(c[(c[1271690]|0)+(e<<2)>>2]|0)+56>>2]|0}if((s|0)!=(v|0)){n=u;o=e;break}yDb(0,8,2023064,(p=i,i=i+8|0,c[p>>2]=l,p)|0);i=p;yf(1);n=u;o=e}}while(0);u=c[h>>2]|0;a:do{if((a[u]|0)==91){c[j>>2]=u+1;v=b+120|0;r=b+124|0;g=rg(c[v>>2]|0,24,r,(c[r>>2]|0)+1|0)|0;c[v>>2]=g;v=(c[r>>2]|0)-1|0;r=g+(v*24|0)|0;m=wAb(j,2022792)|0;c[g+(v*24|0)+20>>2]=m;if((m|0)!=0){x=r;w=31;break}yDb(0,16,2022488,(p=i,i=i+8|0,c[p>>2]=c[h>>2],p)|0);i=p;yf(1);x=r;w=31}else{r=kb(u|0,f|0,0)|0;if((r|0)>=(c[1167942]|0)|(r|0)<0){yDb(0,8,2022216,(p=i,i=i+8|0,c[p>>2]=r,p)|0);i=p;yf(1)}if(k){m=b+124|0;if((c[m>>2]|0)<=0){break}v=b+120|0;g=c[f>>2]|0;t=g+1|0;q=0;while(1){y=c[v>>2]|0;z=y+(q*24|0)|0;do{if((r|0)==(c[y+(q*24|0)+4>>2]|0)){A=c[c[(c[1271690]|0)+(r<<2)>>2]>>2]|0;if((og(A,c[(c[A+28>>2]|0)+(c[y+(q*24|0)+8>>2]<<2)>>2]|0,(a[g]|0)==58?t:g)|0)<=0){break}c[z>>2]=1}}while(0);y=q+1|0;if((y|0)<(c[m>>2]|0)){q=y}else{x=z;w=31;break a}}}q=c[(c[1271690]|0)+(r<<2)>>2]|0;if((c[q+56>>2]|0)<=0){break}m=c[f>>2]|0;g=m+1|0;t=b+120|0;v=b+124|0;e=(o|0)>-1;s=0;y=0;A=q;while(1){q=c[A>>2]|0;do{if((og(q,c[(c[q+28>>2]|0)+(y<<2)>>2]|0,(a[m]|0)==58?g:m)|0)<1){B=s}else{C=rg(c[t>>2]|0,24,v,(c[v>>2]|0)+1|0)|0;c[t>>2]=C;D=(c[v>>2]|0)-1|0;E=C+(D*24|0)|0;c[C+(D*24|0)+4>>2]=r;c[C+(D*24|0)+8>>2]=y;F=C+(D*24|0)+12|0;if(e){c[F>>2]=o;c[C+(D*24|0)+16>>2]=n;B=E;break}else{c[F>>2]=r;c[C+(D*24|0)+16>>2]=y;B=E;break}}}while(0);q=y+1|0;z=c[(c[1271690]|0)+(r<<2)>>2]|0;if((q|0)<(c[z+56>>2]|0)){s=B;y=q;A=z}else{x=B;w=31;break}}}}while(0);do{if((w|0)==31){if((x|0)==0){break}G=h;$Db(G);i=d;return 0}}while(0);yDb(0,8,2022040,(p=i,i=i+8|0,c[p>>2]=l,p)|0);i=p;yf(1);G=h;$Db(G);i=d;return 0}function Cg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;e=a+128|0;f=a+132|0;a=rg(c[e>>2]|0,20,f,(c[f>>2]|0)+1|0)|0;c[e>>2]=a;e=(c[f>>2]|0)-1|0;f=a+(e*20|0)|0;g=a+(e*20|0)+8|0;h=a+(e*20|0)+12|0;j=a+(e*20|0)+16|0;k=xd(d|0,2026048,(l=i,i=i+24|0,c[l>>2]=g,c[l+8>>2]=h,c[l+16>>2]=j,l)|0)|0;i=l;m=(k|0)==1;do{if((k|0)==3|(k|0)==1){if(!((c[g>>2]|0)==-1)){break}c[a+(e*20|0)+4>>2]=-1;c[f>>2]=-1;if(!m){i=b;return 0}c[j>>2]=-1;c[h>>2]=-1;i=b;return 0}}while(0);m=f|0;f=a+(e*20|0)+4|0;e=xd(d|0,2025840,(l=i,i=i+40|0,c[l>>2]=m,c[l+8>>2]=f,c[l+16>>2]=g,c[l+24>>2]=h,c[l+32>>2]=j,l)|0)|0;i=l;if((e|0)==3){n=7}else if((e|0)!=5){yDb(0,8,2025624,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;yf(1);n=7}if((n|0)==7){c[j>>2]=-1;c[h>>2]=-1}h=c[m>>2]|0;if(!((h|0)>-1&(h|0)<(c[1167942]|0))){yDb(0,8,2025416,(l=i,i=i+8|0,c[l>>2]=h,l)|0);i=l;yf(1)}h=c[f>>2]|0;j=c[m>>2]|0;if((h|0)<0){n=12}else{e=c[(c[1271690]|0)+(j<<2)>>2]|0;if((h|0)<(c[e+56>>2]|0)){o=h;p=j;q=e}else{n=12}}if((n|0)==12){yDb(0,8,2024432,(l=i,i=i+16|0,c[l>>2]=j,c[l+8>>2]=h,l)|0);i=l;yf(1);h=c[m>>2]|0;o=c[f>>2]|0;p=h;q=c[(c[1271690]|0)+(h<<2)>>2]|0}h=(c[(c[(c[q>>2]|0)+28>>2]|0)+(o<<2)>>2]|0)+8|0;if((c[(c[h>>2]|0)+8>>2]|0)!=1){yDb(0,8,2023792,(l=i,i=i+16|0,c[l>>2]=p,c[l+8>>2]=o,l)|0);i=l;yf(1)}o=c[g>>2]|0;do{if((o|0)>=0){if((o|0)>=(c[(c[h>>2]|0)+416>>2]|0)){break}i=b;return 0}}while(0);h=c[f>>2]|0;yDb(0,8,2023536,(l=i,i=i+24|0,c[l>>2]=c[m>>2],c[l+8>>2]=h,c[l+16>>2]=o,l)|0);i=l;yf(1);i=b;return 0}function Dg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0.0;e=i;i=i+184|0;f=e+128|0;g=e+136|0;h=Af(b,d,0)|0;j=(+(h>>>0)+ +(F|0)*4294967296.0)/1.0e6;h=(E=+j,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[f>>2]=~~+j>>>0;c[f+4>>2]=h;UGb(g|0,mc(f|0)|0,44)|0;f=e|0;Ac(f|0,128,2026544,g|0)|0;Df(a,2315736,f,625312)|0;yDb(0,24,2026224,(f=i,i=i+8|0,c[f>>2]=b,f)|0);i=f;i=e;return 0}function Eg(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2026760,c,625312)|0}function Fg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;d=i;i=i+72|0;b=d|0;c[b>>2]=0;f=(QGb(e,2028088)|0)==0;g=f?2027368:e;e=Hz(b,g,2,912112,0)|0;if((e|0)<0){f=d+8|0;TGb(f|0,0,64)|0;a[f]=0;GBb(e,f,64)|0;yDb(0,16,2026968,(h=i,i=i+16|0,c[h>>2]=g,c[h+8>>2]=f,h)|0);i=h;j=e;i=d;return j|0}else{c[1154408]=c[b>>2];j=0;i=d;return j|0}return 0}function Gg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;a:do{if((RGb(d,2058912,4)|0)==0){e=0;f=d+4|0}else{if((RGb(d,2058768,5)|0)==0){e=1;f=d+5|0;break}if((RGb(d,2058616,5)|0)==0){e=2;f=d+5|0;break}h=c[1167942]|0;b:do{if((h|0)>0){j=c[1271690]|0;k=0;c:while(1){l=c[j+(k<<2)>>2]|0;m=c[l+56>>2]|0;if((m|0)>0){n=c[(c[l>>2]|0)+28>>2]|0;l=0;do{o=c[(c[n+(l<<2)>>2]|0)+8>>2]|0;if((c[o+8>>2]|0)==0){p=((c[o+108>>2]|0)*1e3|0|0)/(c[o+104>>2]|0)|0;if((p|0)==25e3){q=0;break c}if((p|0)==29970|(p|0)==23976){q=1;break c}}l=l+1|0;}while((l|0)<(m|0))}k=k+1|0;if((k|0)>=(h|0)){break b}}yDb(0,32,2058368,(r=i,i=i+8|0,c[r>>2]=(q|0)==0?2058144:2057952,r)|0);i=r;e=q;f=d;break a}}while(0);yDb(0,8,2057488,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;yDb(0,8,2056528,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;yDb(0,8,2054872,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;yf(1);e=3;f=d}}while(0);if((QGb(f,2052792)|0)==0){Df(a,2065344,2050720,625312)|0;Df(a,2070808,2049456,625312)|0;Df(a,1943584,2052792,625312)|0;d=(e|0)==0;Df(a,2188440,d?2048048:2047488,625312)|0;Df(a,2195176,c[628272+(e<<2)>>2]|0,625312)|0;q=a;CBb((c[q>>2]|0)+16|0,2046552,d?2045320:2043912,16)|0;CBb((c[q>>2]|0)+16|0,2069440,2042576,16)|0;CBb((c[q>>2]|0)+16|0,2041904,2042576,16)|0;CBb((c[q>>2]|0)+16|0,2041680,2042576,16)|0;CBb((c[q>>2]|0)+16|0,2041336,2041112,16)|0;CBb((c[q>>2]|0)+16|0,2040912,2040688,16)|0;Df(a,2127120,2040496,625312)|0;Df(a,2124160,2040344,625312)|0;CBb((c[q>>2]|0)+20|0,2039088,2038520,16)|0;CBb((c[q>>2]|0)+20|0,2038336,2038120,16)|0;g[a+184>>2]=.4399999976158142;s=0;i=b;return s|0}if((QGb(f,2037912)|0)==0){Df(a,2065344,2037696,625312)|0;Df(a,2070808,2049456,625312)|0;Df(a,1943584,2037912,625312)|0;q=(e|0)==0;Df(a,2188440,q?2037488:2037280,625312)|0;Df(a,2195176,c[628272+(e<<2)>>2]|0,625312)|0;Df(a,2181624,2037008,625312)|0;d=a;CBb((c[d>>2]|0)+16|0,2046552,q?2045320:2043912,16)|0;CBb((c[d>>2]|0)+16|0,2069440,2036880,16)|0;CBb((c[d>>2]|0)+16|0,2041904,2036048,16)|0;CBb((c[d>>2]|0)+16|0,2041680,2035432,16)|0;CBb((c[d>>2]|0)+16|0,2041336,2035200,16)|0;CBb((c[d>>2]|0)+16|0,2034960,2034736,16)|0;CBb((c[d>>2]|0)+16|0,2040912,2040688,16)|0;Df(a,2127120,2040496,625312)|0;CBb((c[d>>2]|0)+20|0,2039088,2038520,16)|0;s=0;i=b;return s|0}if((QGb(f,2034376)|0)==0){Df(a,2065344,2037696,625312)|0;Df(a,2070808,2034112,625312)|0;Df(a,1943584,2034376,625312)|0;d=(e|0)==0;Df(a,2188440,d?2033808:2033448,625312)|0;Df(a,2195176,c[628272+(e<<2)>>2]|0,625312)|0;Df(a,2181624,2037008,625312)|0;q=a;CBb((c[q>>2]|0)+16|0,2046552,d?2045320:2043912,16)|0;CBb((c[q>>2]|0)+16|0,2069440,2033248,16)|0;CBb((c[q>>2]|0)+16|0,2041904,2032176,16)|0;CBb((c[q>>2]|0)+16|0,2041680,2035432,16)|0;CBb((c[q>>2]|0)+16|0,2041336,2035200,16)|0;CBb((c[q>>2]|0)+20|0,2039088,2031480,16)|0;CBb((c[q>>2]|0)+20|0,2038336,2031168,16)|0;CBb((c[q>>2]|0)+16|0,2040912,2030856,16)|0;Df(a,2127120,2030560,625312)|0;s=0;i=b;return s|0}if((RGb(f,2030144,2)|0)!=0){yDb(0,16,2029080,(r=i,i=i+8|0,c[r>>2]=f,r)|0);i=r;s=-22;i=b;return s|0}Df(a,1943584,2030144,625312)|0;r=(e|0)==0;Df(a,2188440,r?2033808:2033448,625312)|0;if((RGb(f,2029848,4)|0)==0){t=2029544}else{t=r?2037008:2029320}Df(a,2181624,t,625312)|0;Df(a,2195176,c[628272+(e<<2)>>2]|0,625312)|0;Df(a,2127120,2030560,625312)|0;Df(a,2124160,2040344,625312)|0;s=0;i=b;return s|0}function Hg(a,b,d){a=a|0;b=b|0;d=d|0;if((yAb(d,2061752)|0)==0){c[34030]=1;return 0}if((yAb(d,2061520)|0)==0){c[34030]=2;return 0}if((yAb(d,2061192)|0)==0){c[34030]=0;return 0}if((yAb(d,2060768)|0)==0){c[34030]=255;return 0}if(!((c[34030]|0)==-1)){return 0}c[34030]=~~+zf(2264968,d,128,-1.0,2.0);return 0}function Ig(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if((QGb(b,2220304)|0)==0){yDb(0,24,2062560,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=Df(a,2062304,d,625312)|0;i=e;return g|0}else{h=vAb(2062176,(f=i,i=i+8|0,c[f>>2]=b+6,f)|0)|0;i=f;f=Df(a,h,d,625312)|0;ZDb(h);g=f;i=e;return g|0}return 0}function Jg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;if((QGb(b,2219712)|0)==0){yDb(0,24,2063496,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;CBb((c[a>>2]|0)+16|0,2062784,d,0)|0;i=e;return 0}else{CBb((c[a>>2]|0)+16|0,b,d,0)|0;i=e;return 0}return 0}function Kg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;c[1305380]=rg(c[1305380]|0,4,4671792,(c[1167948]|0)+1|0)|0;b=cEb(32)|0;a=(c[1167948]|0)-1|0;c[(c[1305380]|0)+(a<<2)>>2]=b;if((b|0)==0){e=-12;return e|0}c[c[(c[1305380]|0)+(a<<2)>>2]>>2]=a;a=eEb(d)|0;d=(c[1167948]|0)-1|0;c[(c[(c[1305380]|0)+(d<<2)>>2]|0)+4>>2]=a;e=(c[(c[(c[1305380]|0)+(d<<2)>>2]|0)+4>>2]|0)==0?-12:0;return e|0}function Lg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=fh(d)|0;if((b|0)==0){e=-22;return e|0}c[1305380]=rg(c[1305380]|0,4,4671792,(c[1167948]|0)+1|0)|0;d=cEb(32)|0;a=(c[1167948]|0)-1|0;c[(c[1305380]|0)+(a<<2)>>2]=d;if((d|0)==0){e=-12;return e|0}d=c[1305380]|0;c[c[d+(a<<2)>>2]>>2]=a;c[(c[d+((c[1167948]|0)-1<<2)>>2]|0)+4>>2]=b;e=0;return e|0}function Mg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a+148|0;e=a+152|0;a=rg(c[b>>2]|0,4,e,(c[e>>2]|0)+1|0)|0;c[b>>2]=a;c[a+((c[e>>2]|0)-1<<2)>>2]=d;return 0}function Ng(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2064872,c,625312)|0}function Og(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2065344,c,625312)|0}function Pg(a,b,d){a=a|0;b=b|0;d=d|0;d=i;yDb(0,16,2065576,(a=i,i=i+16|0,c[a>>2]=b,c[a+8>>2]=b,a)|0);i=a;i=d;return-22|0}function Qg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;e=vAb(2066520,(f=i,i=i+8|0,c[f>>2]=d,f)|0)|0;i=f;if(!((Df(a,2066272,e,625312)|0)>-1)){ZDb(e);i=b;return 0}CBb((c[a>>2]|0)+16|0,2066008,d,0)|0;ZDb(e);i=b;return 0}function Rg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=i;i=i+48|0;b=d+40|0;c[b>>2]=ee(0)|0;a=ub(b|0)|0;b=d|0;e=c[a+4>>2]|0;f=c[a>>2]|0;Lb(b|0,40,2066896,(g=i,i=i+24|0,c[g>>2]=c[a+8>>2],c[g+8>>2]=e,c[g+16>>2]=f,g)|0)|0;i=g;ZDb(c[636774]|0);c[636774]=eEb(b)|0;i=d;return 0}function Sg(a,b,d){a=a|0;b=b|0;d=d|0;ZDb(c[636774]|0);c[636774]=eEb(d)|0;return 0}function Tg(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2067096,c,625312)|0}function Ug(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a[d]|0;h=vAb(2067912,(j=i,i=i+16|0,c[j>>2]=d+1,c[j+8>>2]=g,j)|0)|0;i=j;j=Df(b,h,e,625312)|0;ZDb(h);i=f;return j|0}function Vg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f|0;sAb(g,e,16)|0;h=Vb(g|0,58)|0;if((h|0)==0){yDb(0,8,2069288,(j=i,i=i+16|0,c[j>>2]=e,c[j+8>>2]=d,j)|0);i=j;yf(1)}a[h]=0;j=~~+zf(d,g,128,0.0,1023.0);g=b+212|0;c[g>>2]=rg(c[g>>2]|0,4,b+216|0,j+1|0)|0;b=~~+zf(d,h+1|0,128,0.0,2147483647.0);c[(c[g>>2]|0)+(j<<2)>>2]=b;i=f;return 0}function Wg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;if((QGb(b,2134520)|0)==0){yDb(0,24,2069800,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;CBb((c[a>>2]|0)+16|0,2069440,d,0)|0;i=e;return 0}else{CBb((c[a>>2]|0)+16|0,b,d,0)|0;i=e;return 0}return 0}function Xg(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2070192,c,625312)|0}function Yg(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2070536,c,625312)|0}function Zg(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2070808,c,625312)|0}function _g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+32|0;f=fBb(d)|0;g=F;if((f|0)==0&(g|0)==0){yDb(0,16,2071608,(h=i,i=i+8|0,c[h>>2]=d,h)|0);i=h;j=-22;i=e;return j|0}d=e|0;Lb(d|0,32,2071312,(h=i,i=i+16|0,c[h>>2]=f,c[h+8>>2]=g,h)|0)|0;i=h;k=c[2194070]|0;l=c[1305360]|0;c[2194070]=0;c[1305360]=0;m=Kf(0,b,d)|0;n=a;EBb((c[n>>2]|0)+16|0,c[2194070]|0,0);EBb((c[n>>2]|0)+20|0,c[1305360]|0,0);DBb(8776280);DBb(5221440);c[2194070]=k;c[1305360]=l;if((m|0)<0){j=m;i=e;return j|0}m=hBb(f,g)|0;Lb(d|0,32,2071080,(h=i,i=i+8|0,c[h>>2]=m,h)|0)|0;i=h;h=Vb(b|0,58)|0;b=(h|0)!=0;if(b){o=(SGb(h|0)|0)+3|0}else{o=3}m=cEb(o)|0;if((m|0)==0){j=-12;i=e;return j|0}sAb(m,2124160,3)|0;if(b){tAb(m,h,o)|0}o=Df(a,m,d,625312)|0;ZDb(m);j=o;i=e;return j|0}function $g(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2072512,c,625312)|0}function ah(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2073864,c,625312)|0}function bh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;yDb(0,24,2074056,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;e=Kf(a,2096304,d)|0;i=b;return e|0}function ch(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;yDb(0,24,2074576,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;e=Kf(a,2094824,d)|0;i=b;return e|0}function dh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+3016|0;g=f|0;h=f+1e3|0;j=f+2e3|0;k=f+3e3|0;l=f+3008|0;m=a[d]|0;d=j|0;a[d]=m;a[j+1|0]=0;j=c[b+24>>2]|0;if((j|0)>0){n=c[b+20>>2]|0;o=0;p=0;while(1){if((QGb(c[n+(o<<4)>>2]|0,d)|0)==0){q=c[n+(o<<4)+8>>2]|0}else{q=p}r=o+1|0;if((r|0)<(j|0)){o=r;p=q}else{s=q;break}}}else{s=0}q=g|0;g=ng(q,1e3,e,m<<24>>24==102|0,s)|0;if((g|0)==0){if((RGb(e,2078928,16)|0)==0){yDb(0,8,2078752,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else{yDb(0,8,2077280,(t=i,i=i+8|0,c[t>>2]=e,t)|0);i=t}yf(1)}e=h|0;if((Tb(e|0,1e3,g|0)|0)==0){u=fb(g|0)|0;i=f;return 0}h=b;do{do{if((hc(e|0,2076144)|0)!=0){sAb(d,e,1e3)|0;if((xAb(d,2075840,k)|0)==0){v=17}else{if((xAb(c[k>>2]|0,2075616,l)|0)==0){v=17}}if((v|0)==17){v=0;yDb(0,8,2075360,(t=i,i=i+16|0,c[t>>2]=q,c[t+8>>2]=e,t)|0);i=t;yf(1)}s=c[k>>2]|0;yDb(0,48,2075136,(t=i,i=i+24|0,c[t>>2]=q,c[t+8>>2]=d,c[t+16>>2]=s,t)|0);i=t;if((QGb(d,2122280)|0)==0){Df(b,2070808,c[k>>2]|0,625312)|0;break}if((QGb(d,2164256)|0)==0){Df(b,2065344,c[k>>2]|0,625312)|0;break}if((QGb(d,2107728)|0)==0){Df(b,2073864,c[k>>2]|0,625312)|0;break}s=(QGb(d,2081056)|0)==0;m=c[k>>2]|0;if(s){Df(b,2079432,m,625312)|0;break}s=c[2194070]|0;p=c[1305360]|0;c[2194070]=0;c[1305360]=0;o=Kf(0,d,m)|0;EBb((c[h>>2]|0)+16|0,c[2194070]|0,0);EBb((c[h>>2]|0)+20|0,c[1305360]|0,0);DBb(8776280);DBb(5221440);c[2194070]=s;c[1305360]=p;if((o|0)>=0){break}o=c[k>>2]|0;yDb(0,8,2074840,(t=i,i=i+32|0,c[t>>2]=q,c[t+8>>2]=e,c[t+16>>2]=d,c[t+24>>2]=o,t)|0);i=t;yf(1)}}while(0);}while((Tb(e|0,1e3,g|0)|0)!=0);u=fb(g|0)|0;i=f;return 0}function eh(a,b,c){a=a|0;b=b|0;c=c|0;return Df(a,2079432,c,625312)|0}function fh(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+1048|0;d=b|0;e=b+8|0;f=b+1040|0;c[d>>2]=0;c[e>>2]=0;if((Gz(d,a,1)|0)<0){yDb(0,16,2064656,(g=i,i=i+8|0,c[g>>2]=a,g)|0);i=g;i=b;return 0}if((Mz(e)|0)<0){Jz(d)|0;i=b;return 0}g=b+16|0;a=mz(c[d>>2]|0,g,1024)|0;h=c[e>>2]|0;if((a|0)>0){j=a;a=h;while(1){Ry(a,g,j);k=mz(c[d>>2]|0,g,1024)|0;l=c[e>>2]|0;if((k|0)>0){j=k;a=l}else{m=l;break}}}else{m=h}Py(m,0);Jz(d)|0;d=(Oz(c[e>>2]|0,f)|0)<0;i=b;return(d?0:c[f>>2]|0)|0}function gh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=a+16|0;g=c[f>>2]|0;h=bj(c[(c[g+4>>2]|0)+28>>2]|0,c[g+8>>2]|0)|0;if((h|0)==0){j=hh(b,d,-1)|0}else if((h|0)==1){j=ih(b,d,-1)|0}else{yDb(0,8,1986656,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;yf(1);j=0}c[j+8>>2]=-1;c[j+300>>2]=a;c[a+4>>2]=j;if((c[j+352>>2]|0)!=0){d=c[j+4>>2]|0;yDb(0,16,1986336,(k=i,i=i+16|0,c[k>>2]=c[j>>2],c[k+8>>2]=d,k)|0);i=k;yf(1)}do{if((c[j+304>>2]|0)!=0){d=c[j+308>>2]|0;if((d|0)==0){b=c[j+312>>2]|0;if((b|0)==0){break}else{l=b;m=1985624;n=1990872}}else{l=d;m=1985920;n=1991376}d=c[j>>2]|0;b=c[j+4>>2]|0;yDb(0,16,1985192,(k=i,i=i+48|0,c[k>>2]=n,c[k+8>>2]=l,c[k+16>>2]=m,c[k+24>>2]=d,c[k+32>>2]=b,c[k+40>>2]=m,k)|0);i=k;yf(1)}}while(0);if((uh(c[a+8>>2]|0,a,c[f>>2]|0)|0)>=0){Vk(f);i=e;return}yDb(0,8,1984384,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;yf(1);Vk(f);i=e;return}function hh(d,e,f){d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+8|0;j=h|0;k=j;l=i;i=i+4|0;i=i+7&-8;m=i;i=i+4|0;i=i+7&-8;n=i;i=i+4|0;i=i+7&-8;o=nh(d,e,0,f)|0;f=c[o+12>>2]|0;p=c[f+8>>2]|0;q=d+48|0;do{if((c[q>>2]|0)>0){r=d+44|0;s=0;t=0;while(1){u=og(e,f,c[(c[r>>2]|0)+(s<<4)>>2]|0)|0;do{if((u|0)>0){v=c[(c[r>>2]|0)+(s<<4)+8>>2]|0}else{if((u|0)>=0){v=t;break}yf(1);v=t}}while(0);u=s+1|0;if((u|0)<(c[q>>2]|0)){s=u;t=v}else{break}}if((v|0)==0){break}if((PEb(o+76|0,v)|0)>=0){break}yDb(0,8,1990152,(w=i,i=i+8|0,c[w>>2]=v,w)|0);i=w;yf(1)}}while(0);v=d+288|0;do{if((c[v>>2]|0)>0){q=d+284|0;t=0;s=0;while(1){r=og(e,f,c[(c[q>>2]|0)+(t<<4)>>2]|0)|0;do{if((r|0)>0){x=c[(c[q>>2]|0)+(t<<4)+8>>2]|0}else{if((r|0)>=0){x=s;break}yf(1);x=s}}while(0);r=t+1|0;if((r|0)<(c[v>>2]|0)){t=r;s=x}else{break}}if((x|0)==0){break}do{if((NEb(k,x,255,0,0)|0)<0){y=22}else{if((c[j>>2]|0)<1){y=22;break}if((c[k+4>>2]|0)<1){y=22}}}while(0);if((y|0)==22){yDb(0,8,1989944,(w=i,i=i+8|0,c[w>>2]=x,w)|0);i=w;yf(1)}s=o+92|0;t=c[j+4>>2]|0;c[s>>2]=c[j>>2];c[s+4>>2]=t}}while(0);j=d+376|0;if((c[j>>2]|0)>0){x=d+372|0;y=o+312|0;k=0;do{v=og(e,f,c[(c[x>>2]|0)+(k<<4)>>2]|0)|0;do{if((v|0)>0){c[y>>2]=c[(c[x>>2]|0)+(k<<4)+8>>2]}else{if((v|0)>=0){break}yf(1)}}while(0);k=k+1|0;}while((k|0)<(c[j>>2]|0))}j=d+368|0;if((c[j>>2]|0)>0){k=d+364|0;x=o+308|0;y=0;do{v=og(e,f,c[(c[k>>2]|0)+(y<<4)>>2]|0)|0;do{if((v|0)>0){c[x>>2]=c[(c[k>>2]|0)+(y<<4)+8>>2]}else{if((v|0)>=0){break}yf(1)}}while(0);y=y+1|0;}while((y|0)<(c[j>>2]|0))}j=o+352|0;do{if((c[j>>2]|0)==0){y=d+56|0;do{if((c[y>>2]|0)>0){k=d+52|0;x=0;v=0;while(1){t=og(e,f,c[(c[k>>2]|0)+(x<<4)>>2]|0)|0;do{if((t|0)>0){z=c[(c[k>>2]|0)+(x<<4)+8>>2]|0}else{if((t|0)>=0){z=v;break}yf(1);z=v}}while(0);t=x+1|0;if((t|0)<(c[y>>2]|0)){x=t;v=z}else{break}}if((z|0)==0){break}if((OEb(p+120|0,p+124|0,z)|0)>=0){break}yDb(0,8,1992776,(w=i,i=i+8|0,c[w>>2]=z,w)|0);i=w;yf(1)}}while(0);c[p+796>>2]=c[1305358];y=d+64|0;do{if((c[y>>2]|0)>0){v=d+60|0;x=0;k=0;while(1){t=og(e,f,c[(c[v>>2]|0)+(x<<4)>>2]|0)|0;do{if((t|0)>0){A=c[(c[v>>2]|0)+(x<<4)+8>>2]|0}else{if((t|0)>=0){A=k;break}yf(1);A=k}}while(0);t=x+1|0;if((t|0)<(c[y>>2]|0)){x=t;k=A}else{break}}if((A|0)==0){break}if((a[A]|0)==43){c[o+368>>2]=1;k=A+1|0;x=(a[k]|0)==0?0:k;if((x|0)==0){break}else{B=x}}else{B=A}x=_Eb(B)|0;c[p+140>>2]=x;if(!((x|0)==-1)){break}yDb(0,8,1989656,(w=i,i=i+8|0,c[w>>2]=B,w)|0);i=w;yf(1)}}while(0);y=p+224|0;x=f+80|0;k=c[y+4>>2]|0;c[x>>2]=c[y>>2];c[x+4>>2]=k;if((c[1271016]|0)!=0){c[p+136>>2]=0}k=d+304|0;do{if((c[k>>2]|0)>0){x=d+300|0;y=0;v=0;while(1){t=og(e,f,c[(c[x>>2]|0)+(y<<4)>>2]|0)|0;do{if((t|0)>0){C=c[(c[x>>2]|0)+(y<<4)+8>>2]|0}else{if((t|0)>=0){C=v;break}yf(1);C=v}}while(0);t=y+1|0;if((t|0)<(c[k>>2]|0)){y=t;v=C}else{break}}if((C|0)==0){break}v=cEb(128)|0;y=v;x=p+300|0;c[x>>2]=y;if((v|0)==0){yDb(0,8,1989352,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;yf(1);D=c[x>>2]|0}else{D=y}b[D>>1]=gd(C|0)|0;y=0;x=C;do{v=Vb(x|0,44)|0;if((v|0)==0){yDb(0,8,1986928,(w=i,i=i+16|0,c[w>>2]=C,c[w+8>>2]=y,w)|0);i=w;yf(1)}x=v+1|0;y=y+1|0;b[D+(y<<1)>>1]=gd(x|0)|0;}while((y|0)!=63)}}while(0);k=d+320|0;do{if((c[k>>2]|0)>0){y=d+316|0;x=0;v=0;while(1){t=og(e,f,c[(c[y>>2]|0)+(x<<4)>>2]|0)|0;do{if((t|0)>0){E=c[(c[y>>2]|0)+(x<<4)+8>>2]|0}else{if((t|0)>=0){E=v;break}yf(1);E=v}}while(0);t=x+1|0;if((t|0)<(c[k>>2]|0)){x=t;v=E}else{break}}if((E|0)==0){break}v=cEb(128)|0;x=v;if((v|0)==0){yDb(0,8,1989352,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;yf(1)}k0a(p,x);b[x>>1]=gd(E|0)|0;v=0;y=E;do{t=Vb(y|0,44)|0;if((t|0)==0){yDb(0,8,1986928,(w=i,i=i+16|0,c[w>>2]=E,c[w+8>>2]=v,w)|0);i=w;yf(1)}y=t+1|0;v=v+1|0;b[x+(v<<1)>>1]=gd(y|0)|0;}while((v|0)!=63)}}while(0);k=d+312|0;do{if((c[k>>2]|0)>0){v=d+308|0;y=0;x=0;while(1){t=og(e,f,c[(c[v>>2]|0)+(y<<4)>>2]|0)|0;do{if((t|0)>0){F=c[(c[v>>2]|0)+(y<<4)+8>>2]|0}else{if((t|0)>=0){F=x;break}yf(1);F=x}}while(0);t=y+1|0;if((t|0)<(c[k>>2]|0)){y=t;x=F}else{break}}if((F|0)==0){break}x=cEb(128)|0;y=x;v=p+304|0;c[v>>2]=y;if((x|0)==0){yDb(0,8,1989024,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;yf(1);G=c[v>>2]|0}else{G=y}b[G>>1]=gd(F|0)|0;y=0;v=F;do{x=Vb(v|0,44)|0;if((x|0)==0){yDb(0,8,1986928,(w=i,i=i+16|0,c[w>>2]=F,c[w+8>>2]=y,w)|0);i=w;yf(1)}v=x+1|0;y=y+1|0;b[G+(y<<1)>>1]=gd(v|0)|0;}while((y|0)!=63)}}while(0);k=d+296|0;do{if((c[k>>2]|0)>0){y=d+292|0;v=0;x=0;while(1){t=og(e,f,c[(c[y>>2]|0)+(v<<4)>>2]|0)|0;do{if((t|0)>0){H=c[(c[y>>2]|0)+(v<<4)+8>>2]|0}else{if((t|0)>=0){H=x;break}yf(1);H=x}}while(0);t=v+1|0;if((t|0)<(c[k>>2]|0)){v=t;x=H}else{break}}if((H|0)==0){I=0;break}x=p+532|0;v=0;y=H;while(1){t=xd(y|0,1988760,(w=i,i=i+24|0,c[w>>2]=l,c[w+8>>2]=m,c[w+16>>2]=n,w)|0)|0;i=w;if((t|0)!=3){yDb(0,8,1988504,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;yf(1)}t=v+1|0;s=XDb(c[x>>2]|0,t<<4)|0;c[x>>2]=s;c[s+(v<<4)>>2]=c[l>>2];c[s+(v<<4)+4>>2]=c[m>>2];q=c[n>>2]|0;r=s+(v<<4)+8|0;if((q|0)>0){c[r>>2]=q;g[s+(v<<4)+12>>2]=1.0}else{c[r>>2]=0;g[s+(v<<4)+12>>2]=+(-(c[n>>2]|0)|0)/100.0}s=Vb(y|0,47)|0;r=(s|0)==0?0:s+1|0;if((r|0)==0){I=t;break}else{v=t;y=r}}}else{I=0}}while(0);c[p+528>>2]=I;c[p+324>>2]=(c[227062]|0)-8;if((c[2128642]|0)!=0){k=p+88|0;c[k>>2]=c[k>>2]|32768}k=d+408|0;do{if((c[k>>2]|0)>0){y=d+404|0;v=0;x=0;while(1){r=og(e,f,c[(c[y>>2]|0)+(x<<4)>>2]|0)|0;do{if((r|0)>0){J=c[(c[y>>2]|0)+(x<<4)+8>>2]|0}else{if((r|0)>=0){J=v;break}yf(1);J=v}}while(0);r=x+1|0;if((r|0)<(c[k>>2]|0)){v=J;x=r}else{break}}if((J|0)==0){break}if((J&1|0)!=0){x=p+88|0;c[x>>2]=c[x>>2]|512;CBb(o+328|0,1947408,1987864,32)|0}if((J&2|0)==0){break}x=p+88|0;c[x>>2]=c[x>>2]|1024;CBb(o+328|0,1947408,1987320,32)|0}}while(0);k=d+416|0;if((c[k>>2]|0)>0){x=d+412|0;v=o+292|0;y=0;while(1){r=og(e,f,c[(c[x>>2]|0)+(y<<4)>>2]|0)|0;do{if((r|0)>0){c[v>>2]=c[(c[x>>2]|0)+(y<<4)+8>>2]}else{if((r|0)>=0){break}yf(1)}}while(0);r=y+1|0;if((r|0)<(c[k>>2]|0)){y=r}else{K=v;break}}}else{K=o+292|0}v=c[K>>2]|0;do{if((v|0)!=0){y=eEb(v)|0;c[K>>2]=y;if((y|0)!=0){break}yf(1)}}while(0);v=d+272|0;if((c[v>>2]|0)>0){y=d+268|0;k=o+112|0;x=0;while(1){r=og(e,f,c[(c[y>>2]|0)+(x<<4)>>2]|0)|0;do{if((r|0)>0){c[k>>2]=c[(c[y>>2]|0)+(x<<4)+8>>2]}else{if((r|0)>=0){break}yf(1)}}while(0);r=x+1|0;if((r|0)<(c[v>>2]|0)){x=r}else{L=k;break}}}else{L=o+112|0}k=c[L>>2]|0;if((k|0)!=0){c[L>>2]=eEb(k)|0}k=d+280|0;if((c[k>>2]|0)>0){x=d+276|0;v=o+84|0;y=0;do{r=og(e,f,c[(c[x>>2]|0)+(y<<4)>>2]|0)|0;do{if((r|0)>0){c[v>>2]=c[(c[x>>2]|0)+(y<<4)+8>>2]}else{if((r|0)>=0){break}yf(1)}}while(0);y=y+1|0;}while((y|0)<(c[k>>2]|0))}k=o+88|0;c[k>>2]=-1;y=d+328|0;if((c[y>>2]|0)>0){x=d+324|0;v=0;do{r=og(e,f,c[(c[x>>2]|0)+(v<<4)>>2]|0)|0;do{if((r|0)>0){c[k>>2]=c[(c[x>>2]|0)+(v<<4)+8>>2]}else{if((r|0)>=0){break}yf(1)}}while(0);v=v+1|0;}while((v|0)<(c[y>>2]|0))}y=ph(o)|0;c[o+304>>2]=y;if((y|0)!=0){break}yf(1)}else{y=d+352|0;if((c[y>>2]|0)<=0){break}v=d+348|0;x=o+360|0;k=0;do{r=og(e,f,c[(c[v>>2]|0)+(k<<4)>>2]|0)|0;do{if((r|0)>0){c[x>>2]=c[(c[v>>2]|0)+(k<<4)+8>>2]}else{if((r|0)>=0){break}yf(1)}}while(0);k=k+1|0;}while((k|0)<(c[y>>2]|0))}}while(0);if((c[j>>2]|0)==0){i=h;return o|0}j=c[o+312>>2]|0;f=c[o+308>>2]|0;do{if((j|0)==0){if((f|0)!=0){M=f;N=1991376;break}i=h;return o|0}else{e=(f|0)!=0;M=e?f:j;N=e?1991376:1990872}}while(0);j=lGb(0)|0;f=c[o>>2]|0;e=c[o+4>>2]|0;yDb(0,16,1992032,(w=i,i=i+40|0,c[w>>2]=N,c[w+8>>2]=M,c[w+16>>2]=j,c[w+24>>2]=f,c[w+32>>2]=e,w)|0);i=w;yf(1);i=h;return o|0}function ih(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;f=nh(a,b,1,d)|0;d=f+12|0;g=c[d>>2]|0;h=c[g+8>>2]|0;c[h+8>>2]=1;j=a+376|0;if((c[j>>2]|0)>0){k=a+372|0;l=f+312|0;m=0;do{n=og(b,g,c[(c[k>>2]|0)+(m<<4)>>2]|0)|0;do{if((n|0)>0){c[l>>2]=c[(c[k>>2]|0)+(m<<4)+8>>2]}else{if((n|0)>=0){break}yf(1)}}while(0);m=m+1|0;}while((m|0)<(c[j>>2]|0))}j=a+368|0;if((c[j>>2]|0)>0){m=a+364|0;k=f+308|0;l=0;do{n=og(b,g,c[(c[m>>2]|0)+(l<<4)>>2]|0)|0;do{if((n|0)>0){c[k>>2]=c[(c[m>>2]|0)+(l<<4)+8>>2]}else{if((n|0)>=0){break}yf(1)}}while(0);l=l+1|0;}while((l|0)<(c[j>>2]|0))}j=f+352|0;do{if((c[j>>2]|0)==0){l=a+32|0;if((c[l>>2]|0)>0){m=a+28|0;k=h+416|0;n=0;do{o=og(b,g,c[(c[m>>2]|0)+(n<<4)>>2]|0)|0;do{if((o|0)>0){c[k>>2]=c[(c[m>>2]|0)+(n<<4)+8>>2]}else{if((o|0)>=0){break}yf(1)}}while(0);n=n+1|0;}while((n|0)<(c[l>>2]|0))}l=a+256|0;do{if((c[l>>2]|0)>0){n=a+252|0;m=0;k=0;while(1){o=og(b,g,c[(c[n>>2]|0)+(m<<4)>>2]|0)|0;do{if((o|0)>0){p=c[(c[n>>2]|0)+(m<<4)+8>>2]|0}else{if((o|0)>=0){p=k;break}yf(1);p=k}}while(0);o=m+1|0;if((o|0)<(c[l>>2]|0)){m=o;k=p}else{break}}if((p|0)==0){break}k=xFb(p)|0;c[h+420>>2]=k;if(!((k|0)==-1)){break}yDb(0,8,1992552,(q=i,i=i+8|0,c[q>>2]=p,q)|0);i=q;yf(1)}}while(0);l=a+40|0;if((c[l>>2]|0)>0){k=a+36|0;m=h+412|0;n=0;do{o=og(b,g,c[(c[k>>2]|0)+(n<<4)>>2]|0)|0;do{if((o|0)>0){c[m>>2]=c[(c[k>>2]|0)+(n<<4)+8>>2]}else{if((o|0)>=0){break}yf(1)}}while(0);n=n+1|0;}while((n|0)<(c[l>>2]|0))}l=a+432|0;if((c[l>>2]|0)>0){n=a+428|0;k=f+340|0;m=0;while(1){o=og(b,g,c[(c[n>>2]|0)+(m<<4)>>2]|0)|0;do{if((o|0)>0){c[k>>2]=c[(c[n>>2]|0)+(m<<4)+8>>2]}else{if((o|0)>=0){break}yf(1)}}while(0);o=m+1|0;if((o|0)<(c[l>>2]|0)){m=o}else{r=k;break}}}else{r=f+340|0}c[r>>2]=eEb(c[r>>2]|0)|0;k=ph(f)|0;c[f+304>>2]=k;if((k|0)==0){yf(1)}k=a+132|0;if((c[k>>2]|0)>0){m=a+128|0;l=f+8|0;n=f+288|0;o=f|0;s=0;do{t=c[m>>2]|0;u=c[(c[1271688]|0)+(c[l>>2]<<2)>>2]|0;v=c[t+(s*20|0)+8>>2]|0;do{if((v|0)==-1){w=55}else{if((c[u>>2]|0)!=(c[t+(s*20|0)>>2]|0)){break}if((c[c[u+4>>2]>>2]|0)==(c[t+(s*20|0)+4>>2]|0)){w=55}}}while(0);do{if((w|0)==55){w=0;u=c[t+(s*20|0)+12>>2]|0;if(!((u|0)==-1)){if((c[o>>2]|0)!=(u|0)){break}}u=c[t+(s*20|0)+16>>2]|0;if(!((u|0)==-1)){if((c[c[d>>2]>>2]|0)!=(u|0)){break}}u=c[n>>2]|0;if(u>>>0<32>>>0){c[n>>2]=u+1;c[f+160+(u<<2)>>2]=v;break}else{u=c[c[d>>2]>>2]|0;yDb(0,8,1992264,(q=i,i=i+16|0,c[q>>2]=c[o>>2],c[q+8>>2]=u,q)|0);i=q;break}}}while(0);s=s+1|0;}while((s|0)<(c[k>>2]|0))}if((c[j>>2]|0)!=0){break}i=e;return f|0}}while(0);j=c[f+312>>2]|0;d=c[f+308>>2]|0;do{if((j|0)==0){if((d|0)!=0){x=d;y=1991376;break}i=e;return f|0}else{w=(d|0)!=0;x=w?d:j;y=w?1991376:1990872}}while(0);j=lGb(1)|0;d=c[f>>2]|0;w=c[f+4>>2]|0;yDb(0,16,1992032,(q=i,i=i+40|0,c[q>>2]=y,c[q+8>>2]=x,c[q+16>>2]=j,c[q+24>>2]=d,c[q+32>>2]=w,q)|0);i=q;yf(1);i=e;return f|0}function jh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=nh(a,b,3,d)|0;d=c[f+12>>2]|0;g=c[d+8>>2]|0;c[g+8>>2]=3;h=a+352|0;if((c[h>>2]|0)>0){j=a+348|0;k=f+360|0;l=0;do{m=og(b,d,c[(c[j>>2]|0)+(l<<4)>>2]|0)|0;do{if((m|0)>0){c[k>>2]=c[(c[j>>2]|0)+(l<<4)+8>>2]}else{if((m|0)>=0){break}yf(1)}}while(0);l=l+1|0;}while((l|0)<(c[h>>2]|0))}if((c[f+352>>2]|0)!=0){i=e;return}f=a+56|0;if((c[f>>2]|0)<=0){i=e;return}h=a+52|0;a=0;l=0;while(1){j=og(b,d,c[(c[h>>2]|0)+(a<<4)>>2]|0)|0;do{if((j|0)>0){n=c[(c[h>>2]|0)+(a<<4)+8>>2]|0}else{if((j|0)>=0){n=l;break}yf(1);n=l}}while(0);j=a+1|0;if((j|0)<(c[f>>2]|0)){a=j;l=n}else{break}}if((n|0)==0){i=e;return}if((OEb(g+120|0,g+124|0,n)|0)>=0){i=e;return}yDb(0,8,1992776,(g=i,i=i+8|0,c[g>>2]=n,g)|0);i=g;yf(1);i=e;return}function kh(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=BBb(b,9203560,0,2)|0;if((f|0)==0){g=0;i=d;return g|0}else{h=f}do{f=h|0;j=c[f>>2]|0;k=Vb(j|0,58)|0;if((k|0)==0){CBb(e,j,c[h+4>>2]|0,0)|0}else{a[k]=0;CBb(e,c[f>>2]|0,c[h+4>>2]|0,0)|0;a[k]=58}h=BBb(b,9203560,h,2)|0;}while((h|0)!=0);g=c[e>>2]|0;i=d;return g|0}function lh(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[1313574]|0;if((d|0)!=0&(c[1167934]|0)!=0){nb(2008928,41,1,c[p>>2]|0)|0;yf(1);e=c[1313574]|0}else{e=d}if((e|0)!=0){i=b;return}e=Iy(a)|0;if((e|0)==0){i=b;return}if((QGb(e,2150656)|0)!=0){i=b;return}if((Jy(a,0)|0)!=0){i=b;return}if((c[107880]|0)==0|(c[1167934]|0)!=0){yDb(0,8,2004960,(f=i,i=i+8|0,c[f>>2]=a,f)|0);i=f;yf(1);i=b;return}e=c[p>>2]|0;Dd(e|0,2007152,(f=i,i=i+8|0,c[f>>2]=a,f)|0)|0;i=f;ib(e|0)|0;yh();Db(2,0)|0;if((lg()|0)==0){yDb(0,8,2006240,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;yf(1)}zh();i=b;return}function mh(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a[b]|0;if(h<<24>>24==0){a[d]=103;i=g;return}a[d]=h;h=a[b]|0;if((h|0)==99|(h|0)==112){if((a[b+1|0]|0)!=58){i=g;return}c[e>>2]=kb(b+2|0,0,0)|0;i=g;return}else if((h|0)==115){e=b+1|0;d=a[e]|0;if((d<<24>>24|0)==0|(d<<24>>24|0)==58){j=d}else{yDb(0,8,2012600,(k=i,i=i+8|0,c[k>>2]=e,k)|0);i=k;yf(1);j=a[e]|0}c[f>>2]=j<<24>>24==58?b+2|0:9203560;i=g;return}else if((h|0)==103){i=g;return}else{yDb(0,8,2012344,(k=i,i=i+8|0,c[k>>2]=h,k)|0);i=k;yf(1);i=g;return}}function nh(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0.0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+1048|0;k=j|0;l=j+8|0;m=j+16|0;n=j+1016|0;o=j+1032|0;p=j+1040|0;q=LT(e,0)|0;r=e+24|0;s=c[r>>2]|0;if((q|0)==0){yDb(0,8,2004576,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;yf(1);u=c[r>>2]|0}else{u=s}r=u-1|0;if(r>>>0<(c[b+216>>2]|0)>>>0){c[q+4>>2]=c[(c[b+212>>2]|0)+(r<<2)>>2]}c[1163658]=rg(c[1163658]|0,4,4671744,(c[1167936]|0)+1|0)|0;r=cEb(376)|0;u=r;if((r|0)==0){yf(1)}c[(c[1163658]|0)+((c[1167936]|0)-1<<2)>>2]=u;v=r;c[v>>2]=(c[1167938]|0)-1;w=r+4|0;c[w>>2]=s-1;s=r+12|0;c[s>>2]=q;x=q+8|0;c[(c[x>>2]|0)+8>>2]=f;y=b+24|0;do{if((c[y>>2]|0)>0){z=b+20|0;A=0;B=0;C=q;while(1){D=og(e,C,c[(c[z>>2]|0)+(A<<4)>>2]|0)|0;do{if((D|0)>0){E=c[(c[z>>2]|0)+(A<<4)+8>>2]|0}else{if((D|0)>=0){E=B;break}yf(1);E=B}}while(0);D=A+1|0;if((D|0)>=(c[y>>2]|0)){break}A=D;B=E;C=c[s>>2]|0}if((E|0)==0){F=c[(c[(c[s>>2]|0)+8>>2]|0)+8>>2]|0;G=17;break}if((QGb(E,1995336)|0)==0){c[r+352>>2]=1;H=c[r+60>>2]|0;break}else{C=oh(E,c[(c[(c[s>>2]|0)+8>>2]|0)+8>>2]|0,1)|0;c[r+60>>2]=C;c[(c[(c[s>>2]|0)+8>>2]|0)+48>>2]=c[C+12>>2];H=C;break}}else{F=f;G=17}}while(0);if((G|0)==17){G=VC(c[e+8>>2]|0,0,e+32|0,0,F)|0;c[(c[(c[s>>2]|0)+8>>2]|0)+48>>2]=G;s=p0a(G)|0;c[r+60>>2]=s;H=s}s=r+60|0;do{if((H|0)==0){c[r+328>>2]=pg(c[(c[b>>2]|0)+16>>2]|0,0,e,q,0)|0}else{c[p>>2]=0;G=c[s>>2]|0;F=r+328|0;c[F>>2]=pg(c[(c[b>>2]|0)+16>>2]|0,c[G+12>>2]|0,e,q,G)|0;G=b+344|0;if((c[G>>2]|0)<=0){break}E=b+340|0;y=0;C=0;while(1){B=og(e,q,c[(c[E>>2]|0)+(y<<4)>>2]|0)|0;do{if((B|0)>0){I=c[(c[E>>2]|0)+(y<<4)+8>>2]|0}else{if((B|0)>=0){I=C;break}yf(1);I=C}}while(0);B=y+1|0;if((B|0)<(c[G>>2]|0)){y=B;C=I}else{break}}if((I|0)==0){break}C=c[c[s>>2]>>2]|0;y=m|0;G=ed(1996968)|0;c[n>>2]=G;c[n+4>>2]=ed(1996688)|0;c[n+8>>2]=1996272;a:do{if((C|0)==0){E=0;B=-1;A=G;while(1){if((A|0)==0){J=B}else{if((B|0)>=0){K=B;break a}Lb(y|0,1e3,1995448,(t=i,i=i+24|0,c[t>>2]=A,c[t+8>>2]=(E|0)!=1?9203560:1995624,c[t+16>>2]=I,t)|0)|0;i=t;J=Hz(p,y,1,912112,0)|0}z=E+1|0;if(!(z>>>0<3>>>0&(J|0)<0)){K=J;break a}E=z;B=J;A=c[n+(z<<2)>>2]|0}}else{A=0;B=-1;E=G;while(1){if((E|0)==0){L=B}else{z=(A|0)!=1?9203560:1995624;Lb(y|0,1e3,1995920,(t=i,i=i+32|0,c[t>>2]=E,c[t+8>>2]=z,c[t+16>>2]=C,c[t+24>>2]=I,t)|0)|0;i=t;D=Hz(p,y,1,912112,0)|0;if((D|0)>=0){K=D;break a}Lb(y|0,1e3,1995448,(t=i,i=i+24|0,c[t>>2]=E,c[t+8>>2]=z,c[t+16>>2]=I,t)|0)|0;i=t;L=Hz(p,y,1,912112,0)|0}z=A+1|0;if(!(z>>>0<3>>>0&(L|0)<0)){K=L;break a}A=z;B=L;E=c[n+(z<<2)>>2]|0}}}while(0);if((K|0)!=0){y=c[v>>2]|0;C=c[w>>2]|0;yDb(0,8,2002496,(t=i,i=i+24|0,c[t>>2]=I,c[t+8>>2]=y,c[t+16>>2]=C,t)|0);i=t;yf(1);break}C=c[p>>2]|0;do{if((Mz(k)|0)<0){yDb(0,8,1997192,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;yf(1)}while(1){y=(lz(C)|0)<<24>>24;M=c[k>>2]|0;if((y|0)==10|(y|0)==0){break}Py(M,y)}Py(M,0);Oz(c[k>>2]|0,l)|0;y=c[l>>2]|0;G=a[y]|0;if((G<<24>>24|0)==0|(G<<24>>24|0)==35){ZDb(y)}else{G=Vb(y|0,61)|0;if((G|0)==0){yDb(0,8,2003840,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;yf(1)}a[G]=0;CBb(F,y,G+1|0,16)|0;ZDb(y)}C=c[p>>2]|0;}while((c[C+52>>2]|0)==0);Iz(C)|0}}while(0);zRa(c[x>>2]|0,c[s>>2]|0)|0;c[(c[x>>2]|0)+8>>2]=f;p=r+64|0;c[p>>2]=-1;c[p+4>>2]=2147483647;l=b+232|0;k=c[l>>2]|0;M=b+228|0;if((k|0)>0){I=0;while(1){w=og(e,q,c[(c[M>>2]|0)+(I<<4)>>2]|0)|0;do{if((w|0)>0){v=(c[M>>2]|0)+(I<<4)+8|0;K=c[v+4>>2]|0;c[p>>2]=c[v>>2];c[p+4>>2]=K}else{if((w|0)>=0){break}yf(1)}}while(0);w=I+1|0;C=c[l>>2]|0;if((w|0)<(C|0)){I=w}else{N=C;break}}}else{N=k}b:do{if((f|0)==0){k=0;while(1){if((k|0)>=(N|0)){break b}k=k+1|0}}else{k=0;while(1){if((k|0)>=(N|0)){break b}if((a[c[(c[M>>2]|0)+(k<<4)>>2]|0]|0)==0){break}else{k=k+1|0}}yDb(0,24,2001784,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}}while(0);M=r+364|0;c[M>>2]=-1;N=b+360|0;if((c[N>>2]|0)>0){f=b+356|0;k=0;do{I=og(e,q,c[(c[f>>2]|0)+(k<<4)>>2]|0)|0;do{if((I|0)>0){c[M>>2]=c[(c[f>>2]|0)+(k<<4)+8>>2]}else{if((I|0)>=0){break}yf(1)}}while(0);k=k+1|0;}while((k|0)<(c[N>>2]|0))}N=b+240|0;do{if((c[N>>2]|0)>0){k=b+236|0;f=0;M=0;while(1){I=og(e,q,c[(c[k>>2]|0)+(f<<4)>>2]|0)|0;do{if((I|0)>0){O=c[(c[k>>2]|0)+(f<<4)+8>>2]|0}else{if((I|0)>=0){O=M;break}yf(1);O=M}}while(0);I=f+1|0;if((I|0)<(c[N>>2]|0)){f=I;M=O}else{break}}if((O|0)==0){break}M=r+56|0;f=0;k=O;while(1){I=Vb(k|0,44)|0;if((I|0)==0){P=0}else{a[I]=0;P=I+1|0}I=S_(k)|0;if((I|0)==0){yDb(0,8,2000968,(t=i,i=i+8|0,c[t>>2]=k,t)|0);i=t;yf(1)}if((f|0)==0){c[M>>2]=I}else{c[f+12>>2]=I}if((P|0)==0){break}else{f=I;k=P}}c[o>>2]=0}}while(0);P=b+248|0;do{if((c[P>>2]|0)>0){t=b+244|0;O=0;N=0;while(1){k=og(e,q,c[(c[t>>2]|0)+(O<<4)>>2]|0)|0;do{if((k|0)>0){Q=c[(c[t>>2]|0)+(O<<4)+8>>2]|0}else{if((k|0)>=0){Q=N;break}yf(1);Q=N}}while(0);k=O+1|0;if((k|0)<(c[P>>2]|0)){O=k;N=Q}else{break}}if((Q|0)==0){break}N=kb(Q|0,o|0,0)|0;if((a[c[o>>2]|0]|0)==0){R=N}else{N=Q;R=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0}c[(c[x>>2]|0)+52>>2]=R}}while(0);R=b+264|0;do{if((c[R>>2]|0)>0){Q=b+260|0;S=-1.0;o=0;while(1){P=og(e,q,c[(c[Q>>2]|0)+(o<<4)>>2]|0)|0;do{if((P|0)>0){T=+h[(c[Q>>2]|0)+(o<<4)+8>>3]}else{if((P|0)>=0){T=S;break}yf(1);T=S}}while(0);P=o+1|0;if((P|0)<(c[R>>2]|0)){S=T;o=P}else{break}}if(T<0.0){break}o=c[x>>2]|0;Q=o+88|0;c[Q>>2]=c[Q>>2]|2;c[o+80>>2]=~~(T*118.0)}}while(0);if((c[(c[e+8>>2]|0)+28>>2]&64|0)!=0){e=(c[x>>2]|0)+88|0;c[e>>2]=c[e>>2]|4194304}e=b|0;zEb(c[(c[e>>2]|0)+28>>2]|0,1999736,0,r+320|0)|0;b=r+332|0;EBb(b,c[(c[e>>2]|0)+32>>2]|0,0);x=c[s>>2]|0;do{if((x|0)!=0){if((N0a(c[x+12>>2]|0)|0)!=24){break}CBb(b,1998552,1997648,0)|0}}while(0);EBb(r+336|0,c[(c[e>>2]|0)+24>>2]|0,0);c[r+8>>2]=g;if(!((g|0)>-1)){U=r+48|0;V=U;W=0;X=-2147483648;Y=V|0;c[Y>>2]=W;Z=V+4|0;c[Z>>2]=X;i=j;return u|0}e=(c[1271688]|0)+(g<<2)|0;c[r+24>>2]=c[e>>2];g=c[e>>2]|0;c[g+8>>2]=0;c[(c[g+4>>2]|0)+76>>2]=-16;U=r+48|0;V=U;W=0;X=-2147483648;Y=V|0;c[Y>>2]=W;Z=V+4|0;c[Z>>2]=X;i=j;return u|0}function oh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=(d|0)!=0;d=f?1994624:1994064;if(f){g=F0a(a)|0}else{g=G0a(a)|0}a:do{if((g|0)==0){h=i0(a)|0;do{if((h|0)!=0){j=c[h>>2]|0;if(f){k=p0a(j)|0}else{k=q0a(j)|0}if((k|0)==0){break}j=c[k>>2]|0;l=c[h+8>>2]|0;yDb(0,40,1993864,(m=i,i=i+24|0,c[m>>2]=d,c[m+8>>2]=j,c[m+16>>2]=l,m)|0);i=m;n=k;break a}}while(0);yDb(0,8,1993704,(m=i,i=i+16|0,c[m>>2]=d,c[m+8>>2]=a,m)|0);i=m;yf(1);n=0}else{n=g}}while(0);if((c[n+8>>2]|0)==(b|0)){i=e;return n|0}yDb(0,8,1993488,(m=i,i=i+16|0,c[m>>2]=d,c[m+8>>2]=a,m)|0);i=m;yf(1);i=e;return n|0}function ph(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+12>>2]|0;e=a+312|0;f=c[e>>2]|0;g=a+308|0;do{if((f|0)!=0){if((c[g>>2]|0)==0){h=f}else{a=c[d>>2]|0;yDb(0,16,1990512,(j=i,i=i+16|0,c[j>>2]=c[1167938],c[j+8>>2]=a,j)|0);i=j;yf(1);j=c[e>>2]|0;if((j|0)==0){break}else{h=j}}k=fh(h)|0;i=b;return k|0}}while(0);h=c[g>>2]|0;if((h|0)==0){k=eEb((c[(c[d+8>>2]|0)+8>>2]|0)==0?2019224:2019408)|0;i=b;return k|0}else{k=eEb(h)|0;i=b;return k|0}return 0}function qh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a+24|0;do{if((c[e>>2]|0)>0){f=a+20|0;g=0;h=0;while(1){i=og(b,d,c[(c[f>>2]|0)+(g<<4)>>2]|0)|0;do{if((i|0)>0){j=c[(c[f>>2]|0)+(g<<4)+8>>2]|0}else{if((i|0)>=0){j=h;break}yf(1);j=h}}while(0);i=g+1|0;if((i|0)<(c[e>>2]|0)){g=i;h=j}else{break}}h=d+8|0;g=c[h>>2]|0;if((j|0)==0){k=g;break}f=oh(j,c[g+8>>2]|0,0)|0;c[(c[h>>2]|0)+48>>2]=c[f+12>>2];l=f;return l|0}else{k=c[d+8>>2]|0}}while(0);l=q0a(c[k+48>>2]|0)|0;return l|0}function rh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+56|0;g=f|0;h=f+24|0;if((d|0)==0){j=e;i=f;return j|0}k=c[d+24>>2]|0;if((k|0)==0){j=e;i=f;return j|0}l=bFb(e)|0;if((l|0)==0){m=0}else{m=(a[l+4|0]&1^1)&255}l=c[b+8>>2]|0;do{if((c[l+680>>2]|0)<0){b=c[l+48>>2]|0;if((b|0)==8){n=g|0;c[n>>2]=12;c[g+4>>2]=13;c[g+8>>2]=0;c[g+12>>2]=4;c[g+16>>2]=-1;o=-1;p=n;break}else if((b|0)==10){b=h|0;c[b>>2]=12;c[h+4>>2]=13;c[h+8>>2]=14;c[h+12>>2]=0;c[h+16>>2]=4;c[h+20>>2]=5;c[h+24>>2]=30;c[h+28>>2]=-1;o=-1;p=b;break}else{o=-1;p=k;break}}else{o=-1;p=k}}while(0);while(1){k=c[p>>2]|0;if((k|0)==-1){break}q=aHa(o,k,e,m,0)|0;if((c[p>>2]|0)==(e|0)){r=12;break}o=q;p=p+4|0}if((r|0)==12){i=f;return((e|0)==-1?q:e)|0}if((e|0)==-1){j=o;i=f;return j|0}q=ZEb(e)|0;e=c[d>>2]|0;d=ZEb(o)|0;yDb(0,24,2050176,(r=i,i=i+24|0,c[r>>2]=q,c[r+8>>2]=e,c[r+16>>2]=d,r)|0);i=r;j=o;i=f;return j|0}function sh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;if((b|0)==0){i=d;return}e=b+32|0;f=c[e>>2]|0;if((f|0)==0){i=d;return}g=a+8|0;a=f;while(1){f=c[a>>2]|0;if((f|0)==-1){break}if((f|0)==(c[(c[g>>2]|0)+420>>2]|0)){h=12;break}else{a=a+4|0}}if((h|0)==12){i=d;return}do{if((c[b+16>>2]|0)<0){h=wFb(c[(c[g>>2]|0)+420>>2]|0)|0;if(!(h>>>0>(wFb(c[c[e>>2]>>2]|0)|0)>>>0)){break}yDb(0,16,2272144,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}}while(0);if((wFb(c[(c[g>>2]|0)+420>>2]|0)|0)!=0){h=wFb(c[(c[g>>2]|0)+420>>2]|0)|0;a=c[b>>2]|0;b=wFb(c[c[e>>2]>>2]|0)|0;yDb(0,24,2157808,(j=i,i=i+24|0,c[j>>2]=h,c[j+8>>2]=a,c[j+16>>2]=b,j)|0);i=j}c[(c[g>>2]|0)+420>>2]=c[c[e>>2]>>2];i=d;return}function th(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=cEb(32)|0;e=d;if((d|0)==0){yf(1)}c[d>>2]=c[1167948];f=d+24|0;g=d+28|0;c[f>>2]=rg(c[f>>2]|0,4,g,(c[g>>2]|0)+1|0)|0;g=cEb(20)|0;c[c[f>>2]>>2]=g;if((g|0)==0){yf(1)}c[(c[c[f>>2]>>2]|0)+4>>2]=b;c[(c[c[f>>2]>>2]|0)+8>>2]=e;c[b+300>>2]=c[c[f>>2]>>2];f=d+16|0;b=d+20|0;c[f>>2]=rg(c[f>>2]|0,4,b,(c[b>>2]|0)+1|0)|0;b=cEb(16)|0;c[c[f>>2]>>2]=b;if((b|0)==0){yf(1)}c[(c[c[f>>2]>>2]|0)+4>>2]=a;c[(c[c[f>>2]>>2]|0)+8>>2]=e;b=a+244|0;d=a+248|0;a=rg(c[b>>2]|0,4,d,(c[d>>2]|0)+1|0)|0;c[b>>2]=a;c[a+((c[d>>2]|0)-1<<2)>>2]=c[c[f>>2]>>2];f=rg(c[1305380]|0,4,4671792,(c[1167948]|0)+1|0)|0;c[1305380]=f;c[f+((c[1167948]|0)-1<<2)>>2]=e;return e|0}function uh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;f=i;i=i+2312|0;g=f|0;h=f+8|0;j=f+16|0;k=f+32|0;l=f+40|0;m=f+48|0;n=f+64|0;o=f+72|0;p=f+80|0;q=f+88|0;r=f+96|0;s=f+104|0;t=f+112|0;u=f+120|0;v=f+1144|0;w=f+1152|0;x=f+1160|0;y=f+1416|0;z=f+1672|0;A=f+1680|0;B=f+1688|0;C=f+1696|0;D=f+1720|0;E=f+1752|0;G=f+1760|0;H=f+1768|0;I=f+1776|0;J=f+2288|0;K=f+2296|0;L=f+2304|0;M=d+12|0;$Db(M);N=e+4|0;O=c[N>>2]|0;P=c[O+28>>2]|0;Q=c[O+40>>2]|0;if((Mz(L)|0)<0){yf(1)}Kz(c[L>>2]|0,2087696,(R=i,i=i+8|0,c[R>>2]=c[c[O+4>>2]>>2],R)|0)|0;i=R;if((Q|0)>1){Q=c[L>>2]|0;O=e+8|0;S=aj(P,c[O>>2]|0)|0;Kz(Q,2036040,(R=i,i=i+8|0,c[R>>2]=S,R)|0)|0;i=R;T=O}else{T=e+8|0}Py(c[L>>2]|0,0);Oz(c[L>>2]|0,M)|0;M=bj(c[(c[N>>2]|0)+28>>2]|0,c[T>>2]|0)|0;if((M|0)==0){L=c[N>>2]|0;e=c[T>>2]|0;O=E;S=I|0;Q=f+2032|0;P=c[d+4>>2]|0;U=P|0;V=c[U>>2]|0;W=c[(c[1163660]|0)+(V<<2)>>2]|0;X=P+12|0;Y=c[(c[X>>2]|0)+8>>2]|0;c[G>>2]=L;c[H>>2]=e;Z=P+4|0;_=c[Z>>2]|0;Lb(S|0,255,1997016,(R=i,i=i+16|0,c[R>>2]=V,c[R+8>>2]=_,R)|0)|0;i=R;_=d|0;V=Ri(1946104)|0;$=b+8|0;aa=lj(_,V,S,0,0,c[$>>2]|0)|0;if((aa|0)<0){ba=aa;i=f;return ba|0}aa=c[Y+120>>2]|0;V=c[Y+124>>2]|0;do{if((V|aa|0)==0){ca=L;da=e}else{Y=c[P+320>>2]|0;Lb(Q|0,255,1944224,(R=i,i=i+24|0,c[R>>2]=aa,c[R+8>>2]=V,c[R+16>>2]=Y,R)|0)|0;i=R;Y=c[Z>>2]|0;Lb(S|0,255,1939400,(R=i,i=i+16|0,c[R>>2]=c[U>>2],c[R+8>>2]=Y,R)|0)|0;i=R;Y=Ri(1932880)|0;ea=lj(J,Y,S,Q,0,c[$>>2]|0)|0;if((ea|0)<0){ba=ea;i=f;return ba|0}ea=Ii(L,e,c[J>>2]|0,0)|0;if((ea|0)<0){ba=ea;i=f;return ba|0}else{ea=c[J>>2]|0;c[G>>2]=ea;c[H>>2]=0;ca=ea;da=0;break}}}while(0);J=BBb(c[P+328>>2]|0,1922712,0,0)|0;if((J|0)!=0){rEb(c[(c[X>>2]|0)+8>>2]|0,1922712,c[J+4>>2]|0,0)|0}do{if((c[P+368>>2]|0)==0){J=c[X>>2]|0;e=c[(c[J+8>>2]|0)+140>>2]|0;L=P+60|0;Q=c[L>>2]|0;if(!((e|0)==-1)){fa=eEb(ZEb(rh(J,Q,e)|0)|0)|0;break}if((Q|0)==0){fa=0;break}if((c[Q+24>>2]|0)==0){fa=0;break}c[A>>2]=0;if((Mz(A)|0)<0){yf(1)}Q=c[(c[L>>2]|0)+24>>2]|0;L=c[(c[X>>2]|0)+8>>2]|0;do{if((c[L+680>>2]|0)<0){e=c[L+48>>2]|0;if((e|0)==8){J=C|0;c[J>>2]=12;c[C+4>>2]=13;c[C+8>>2]=0;c[C+12>>2]=4;c[C+16>>2]=-1;ga=J;break}else if((e|0)==10){e=D|0;c[e>>2]=12;c[D+4>>2]=13;c[D+8>>2]=14;c[D+12>>2]=0;c[D+16>>2]=4;c[D+20>>2]=5;c[D+24>>2]=30;c[D+28>>2]=-1;ga=e;break}else{ga=Q;break}}else{ga=Q}}while(0);Q=c[ga>>2]|0;if(!((Q|0)==-1)){L=ga;e=Q;do{Q=ZEb(e)|0;Kz(c[A>>2]|0,1949888,(R=i,i=i+8|0,c[R>>2]=Q,R)|0)|0;i=R;L=L+4|0;e=c[L>>2]|0;}while(!((e|0)==-1))}e=(Oz(c[A>>2]|0,B)|0)-1|0;a[(c[B>>2]|0)+e|0]=0;fa=c[B>>2]|0}else{e=c[P+300>>2]|0;if((e|0)!=0){nj(c[(c[e+8>>2]|0)+8>>2]|0,-1)}e=c[(c[(c[X>>2]|0)+8>>2]|0)+140>>2]|0;if((e|0)==-1){fa=0;break}fa=eEb(ZEb(e)|0)|0}}while(0);c[E>>2]=fa;do{if((fa|0)!=0){E=c[Z>>2]|0;Lb(S|0,255,1931008,(R=i,i=i+16|0,c[R>>2]=c[U>>2],c[R+8>>2]=E,R)|0)|0;i=R;E=Ri(1929144)|0;X=lj(K,E,1929144,fa,0,c[$>>2]|0)|0;$Db(O);if((X|0)<0){ba=X;i=f;return ba|0}X=Ii(ca,da,c[K>>2]|0,0)|0;if((X|0)<0){ba=X;i=f;return ba|0}else{c[G>>2]=c[K>>2];c[H>>2]=0;break}}}while(0);K=c[Z>>2]|0;Lb(S|0,255,1952016,(R=i,i=i+16|0,c[R>>2]=c[U>>2],c[R+8>>2]=K,R)|0)|0;i=R;K=W+24|0;U=W+16|0;W=xh(c[K>>2]|0,c[K+4>>2]|0,c[U>>2]|0,c[U+4>>2]|0,G,H,S)|0;if((W|0)<0){ba=W;i=f;return ba|0}W=Ii(c[G>>2]|0,c[H>>2]|0,c[_>>2]|0,0)|0;ba=(W|0)<0?W:0;i=f;return ba|0}else if((M|0)==1){M=c[N>>2]|0;N=c[T>>2]|0;T=r;W=s;_=t;H=I|0;I=x|0;x=y|0;y=c[d+4>>2]|0;G=y|0;S=c[G>>2]|0;U=c[(c[1163660]|0)+(S<<2)>>2]|0;K=y+12|0;Z=c[(c[K>>2]|0)+8>>2]|0;c[p>>2]=M;c[q>>2]=N;da=y+4|0;ca=c[da>>2]|0;Lb(H|0,255,1997016,(R=i,i=i+16|0,c[R>>2]=S,c[R+8>>2]=ca,R)|0)|0;i=R;ca=d|0;d=Ri(1993760)|0;S=b+8|0;b=lj(ca,d,H,0,0,c[S>>2]|0)|0;if((b|0)<0){ba=b;i=f;return ba|0}b=vEb(c[ca>>2]|0,1990240,1,0,1)|0;if((b|0)<0){ba=b;i=f;return ba|0}b=y+288|0;do{if((c[b>>2]|0)==0){ha=M;ia=N}else{IAb(u,256,8192);d=jBb(c[b>>2]|0)|0;O=F;KAb(u,1986736,(R=i,i=i+16|0,c[R>>2]=d,c[R+8>>2]=O,R)|0);i=R;O=c[b>>2]|0;if((O|0)>0){d=0;$=O;while(1){O=c[y+160+(d<<2)>>2]|0;if((O|0)==-1){ja=$}else{KAb(u,1982864,(R=i,i=i+16|0,c[R>>2]=d,c[R+8>>2]=O,R)|0);i=R;ja=c[b>>2]|0}O=d+1|0;if((O|0)<(ja|0)){d=O;$=ja}else{break}}}$=u|0;yDb(0,32,1979864,(R=i,i=i+8|0,c[R>>2]=c[$>>2],R)|0);i=R;d=Ri(1977200)|0;O=lj(v,d,1977200,c[$>>2]|0,0,c[S>>2]|0)|0;if((O|0)<0){ba=O;i=f;return ba|0}O=Ii(M,N,c[v>>2]|0,0)|0;if((O|0)<0){ba=O;i=f;return ba|0}else{O=c[v>>2]|0;c[p>>2]=O;c[q>>2]=0;QAb(u,0)|0;ha=O;ia=0;break}}}while(0);u=c[Z+416>>2]|0;do{if((u|0)!=0){v=Z+448|0;if(!((c[v>>2]|0)==0&(c[v+4>>2]|0)==0)){break}N=jBb(u)|0;c[v>>2]=N;c[v+4>>2]=F}}while(0);u=c[(c[(c[K>>2]|0)+8>>2]|0)+420>>2]|0;do{if((u|0)==-1){Z=y+60|0;v=c[Z>>2]|0;if((v|0)==0){ka=0;break}if((c[v+32>>2]|0)==0){ka=0;break}c[n>>2]=0;if((Mz(n)|0)<0){yf(1)}v=c[(c[Z>>2]|0)+32>>2]|0;Z=c[v>>2]|0;if(!((Z|0)==-1)){N=v;v=Z;do{Z=wFb(v)|0;Kz(c[n>>2]|0,1949888,(R=i,i=i+8|0,c[R>>2]=Z,R)|0)|0;i=R;N=N+4|0;v=c[N>>2]|0;}while(!((v|0)==-1))}v=(Oz(c[n>>2]|0,o)|0)-1|0;a[(c[o>>2]|0)+v|0]=0;ka=c[o>>2]|0}else{ka=eEb(wFb(u)|0)|0}}while(0);c[r>>2]=ka;ka=j|0;j=m|0;m=c[(c[(c[K>>2]|0)+8>>2]|0)+412>>2]|0;do{if((m|0)==0){u=y+60|0;o=c[u>>2]|0;if((o|0)==0){la=0;break}if((c[o+28>>2]|0)==0){la=0;break}c[k>>2]=0;if((Mz(k)|0)<0){yf(1)}o=c[(c[u>>2]|0)+28>>2]|0;u=c[o>>2]|0;if((u|0)!=0){n=o;o=u;do{Lb(j|0,16,1947920,(R=i,i=i+8|0,c[R>>2]=o,R)|0)|0;i=R;Kz(c[k>>2]|0,1949888,(R=i,i=i+8|0,c[R>>2]=j,R)|0)|0;i=R;n=n+4|0;o=c[n>>2]|0;}while((o|0)!=0)}o=(Oz(c[k>>2]|0,l)|0)-1|0;a[(c[l>>2]|0)+o|0]=0;la=c[l>>2]|0}else{Lb(ka|0,16,1947920,(R=i,i=i+8|0,c[R>>2]=m,R)|0)|0;i=R;la=eEb(ka)|0}}while(0);c[s>>2]=la;la=(c[(c[K>>2]|0)+8>>2]|0)+448|0;K=c[la>>2]|0;m=c[la+4>>2]|0;do{if((K|0)==0&(m|0)==0){la=y+60|0;l=c[la>>2]|0;if((l|0)==0){ma=0;break}if((c[l+36>>2]|0)==0){ma=0;break}c[g>>2]=0;if((Mz(g)|0)<0){yf(1)}l=c[(c[la>>2]|0)+36>>2]|0;la=c[l>>2]|0;k=c[l+4>>2]|0;if(!((la|0)==0&(k|0)==0)){o=l;l=k;k=la;do{Lb(j|0,16,1986736,(R=i,i=i+16|0,c[R>>2]=k,c[R+8>>2]=l,R)|0)|0;i=R;Kz(c[g>>2]|0,1949888,(R=i,i=i+8|0,c[R>>2]=j,R)|0)|0;i=R;o=o+8|0;k=c[o>>2]|0;l=c[o+4>>2]|0;}while(!((k|0)==0&(l|0)==0))}l=(Oz(c[g>>2]|0,h)|0)-1|0;a[(c[h>>2]|0)+l|0]=0;ma=c[h>>2]|0}else{Lb(ka|0,16,1986736,(R=i,i=i+16|0,c[R>>2]=K,c[R+8>>2]=m,R)|0)|0;i=R;ma=eEb(ka)|0}}while(0);c[t>>2]=ma;ka=c[r>>2]|0;do{if((ka|0)==0){r=c[s>>2]|0;if((r|0)==0&(ma|0)==0){na=ha;oa=ia;break}a[I]=0;pa=r;qa=82}else{a[I]=0;uAb(I,256,1974744,(R=i,i=i+8|0,c[R>>2]=ka,R)|0)|0;i=R;pa=c[s>>2]|0;qa=82}}while(0);do{if((qa|0)==82){if((pa|0)!=0){uAb(I,256,1973008,(R=i,i=i+8|0,c[R>>2]=pa,R)|0)|0;i=R}s=c[t>>2]|0;if((s|0)!=0){uAb(I,256,1967768,(R=i,i=i+8|0,c[R>>2]=s,R)|0)|0;i=R}$Db(T);$Db(W);$Db(_);s=c[da>>2]|0;Lb(H|0,255,1960696,(R=i,i=i+16|0,c[R>>2]=c[G>>2],c[R+8>>2]=s,R)|0)|0;i=R;s=Ri(1958752)|0;ka=lj(w,s,H,I,0,c[S>>2]|0)|0;if((ka|0)<0){ba=ka;i=f;return ba|0}ka=Ii(ha,ia,c[w>>2]|0,0)|0;if((ka|0)<0){ba=ka;i=f;return ba|0}else{ka=c[w>>2]|0;c[p>>2]=ka;c[q>>2]=0;na=ka;oa=0;break}}}while(0);w=c[y+340>>2]|0;a:do{if((w|0)!=0){if((c[U+40>>2]|0)==0){break}y=c[U>>2]|0;ia=c[y+24>>2]|0;ha=y+28|0;y=0;while(1){if(!(y>>>0<ia>>>0)){break a}if((c[(c[(c[(c[ha>>2]|0)+(y<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==0){break}else{y=y+1|0}}Lb(x|0,256,2087696,(R=i,i=i+8|0,c[R>>2]=w,R)|0)|0;i=R;yDb(0,32,1956448,(R=i,i=i+8|0,c[R>>2]=x,R)|0);i=R;y=Ri(1954184)|0;ha=lj(z,y,1954184,x,0,c[S>>2]|0)|0;if((ha|0)<0){ba=ha;i=f;return ba|0}ha=Ii(na,oa,c[z>>2]|0,0)|0;if((ha|0)<0){ba=ha;i=f;return ba|0}else{c[p>>2]=c[z>>2];c[q>>2]=0;break}}}while(0);z=c[da>>2]|0;Lb(H|0,255,1952016,(R=i,i=i+16|0,c[R>>2]=c[G>>2],c[R+8>>2]=z,R)|0)|0;i=R;z=U+24|0;G=U+16|0;U=xh(c[z>>2]|0,c[z+4>>2]|0,c[G>>2]|0,c[G+4>>2]|0,p,q,H)|0;if((U|0)<0){ba=U;i=f;return ba|0}U=Ii(c[p>>2]|0,c[q>>2]|0,c[ca>>2]|0,0)|0;ba=(U|0)<0?U:0;i=f;return ba|0}else{yDb(0,0,1991208,(R=i,i=i+24|0,c[R>>2]=1956992,c[R+8>>2]=1929552,c[R+16>>2]=581,R)|0);i=R;Cd();return 0}return 0}function vh(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0.0,Na=0,Oa=0,Pa=0,Qa=0;d=i;i=i+3432|0;e=d|0;f=d+8|0;j=d+1032|0;k=d+1040|0;l=d+1296|0;m=d+1304|0;n=d+1560|0;o=d+1568|0;p=d+1576|0;q=d+2600|0;r=d+2856|0;s=d+2864|0;t=d+2872|0;u=d+2880|0;v=d+2888|0;w=d+2896|0;x=d+2904|0;y=d+2912|0;z=d+2920|0;A=b+8|0;B=c[A>>2]|0;C=b+4|0;D=c[C>>2]|0;E=(D|0)==0;if(E){F=c[(c[(c[c[b+24>>2]>>2]|0)+4>>2]|0)+304>>2]|0}else{F=D}kj(A);D=ij()|0;c[A>>2]=D;if((D|0)==0){G=-12;i=d;return G|0}do{if(E){D=b+24|0;H=c[(c[c[D>>2]>>2]|0)+4>>2]|0;I=z|0;Lb(I|0,512,1907304,(J=i,i=i+8|0,c[J>>2]=c[H+320>>2],J)|0)|0;i=J;K=eEb(I)|0;c[(c[A>>2]|0)+12>>2]=K;a[I]=0;K=H+332|0;L=BBb(c[K>>2]|0,9203008,0,2)|0;if((L|0)!=0){M=L;do{L=c[M+4>>2]|0;uAb(I,512,2344456,(J=i,i=i+16|0,c[J>>2]=c[M>>2],c[J+8>>2]=L,J)|0)|0;i=J;M=BBb(c[K>>2]|0,9203008,M,2)|0;}while((M|0)!=0)}if((a[I]|0)!=0){a[z+((SGb(I|0)|0)-1)|0]=0}rEb(c[A>>2]|0,2322696,I,0)|0;a[I]=0;M=BBb(c[(c[(c[c[D>>2]>>2]|0)+4>>2]|0)+336>>2]|0,9203008,0,2)|0;if((M|0)!=0){K=M;do{M=c[K+4>>2]|0;uAb(I,512,2344456,(J=i,i=i+16|0,c[J>>2]=c[K>>2],c[J+8>>2]=M,J)|0)|0;i=J;K=BBb(c[(c[(c[c[D>>2]>>2]|0)+4>>2]|0)+336>>2]|0,9203008,K,2)|0;}while((K|0)!=0)}if((a[I]|0)!=0){a[z+((SGb(I|0)|0)-1)|0]=0}K=eEb(I)|0;c[(c[A>>2]|0)+16>>2]=K;K=BBb(c[H+328>>2]|0,2299792,0,0)|0;if((K|0)==0){break}rEb(c[A>>2]|0,2299792,c[K+4>>2]|0,0)|0}}while(0);z=Wk(c[A>>2]|0,F,x,y)|0;if((z|0)<0){G=z;i=d;return G|0}z=c[x>>2]|0;a:do{if(E){do{if((z|0)!=0){if((c[z+12>>2]|0)!=0){break}K=c[y>>2]|0;if((K|0)==0){break}if((c[K+12>>2]|0)==0){break a}}}while(0);yDb(0,16,2282184,(J=i,i=i+8|0,c[J>>2]=F,J)|0);i=J;G=-22;i=d;return G|0}}while(0);F=E|(B|0)!=0;do{if(F|(z|0)==0){N=z}else{B=b+16|0;E=b+20|0;H=z;b:while(1){I=H+4|0;K=H+8|0;D=bj(c[(c[I>>2]|0)+12>>2]|0,c[K>>2]|0)|0;if(D>>>0>1>>>0){yDb(0,8,2023392,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;yf(1)}M=c[H>>2]|0;do{if((M|0)==0){L=c[1167940]|0;c:do{if((L|0)>0){O=c[1271688]|0;P=0;while(1){Q=c[O+(P<<2)>>2]|0;if((c[(c[(c[Q+4>>2]|0)+8>>2]|0)+8>>2]|0)==(D|0)){if((c[Q+8>>2]|0)!=0){R=Q;S=P;break c}}T=P+1|0;if((T|0)<(L|0)){P=T}else{R=Q;S=T;break}}}else{R=0;S=0}}while(0);if((S|0)!=(L|0)){U=R;break}P=c[(c[I>>2]|0)+8>>2]|0;yDb(0,8,2012424,(J=i,i=i+16|0,c[J>>2]=c[K>>2],c[J+8>>2]=P,J)|0);i=J;yf(1);U=R}else{P=kb(M|0,w|0,0)|0;if(!((P|0)>-1&(P|0)<(c[1167942]|0))){O=c[C>>2]|0;yDb(0,8,2020112,(J=i,i=i+16|0,c[J>>2]=P,c[J+8>>2]=O,J)|0);i=J;yf(1)}O=c[c[(c[1271690]|0)+(P<<2)>>2]>>2]|0;T=O+24|0;Q=c[T>>2]|0;if((Q|0)==0){V=35;break b}W=O+28|0;X=c[w>>2]|0;Y=X+1|0;d:do{if((D|0)==0){Z=0;_=Q;while(1){$=c[(c[W>>2]|0)+(Z<<2)>>2]|0;aa=c[(c[$+8>>2]|0)+8>>2]|0;if((aa|0)==0|(aa|0)==3){if((og(O,$,(a[X]|0)==58?Y:X)|0)==1){ba=Z;break d}ca=c[T>>2]|0}else{ca=_}$=Z+1|0;if($>>>0<ca>>>0){Z=$;_=ca}else{da=X;V=46;break b}}}else{_=0;Z=Q;while(1){$=c[(c[W>>2]|0)+(_<<2)>>2]|0;if((c[(c[$+8>>2]|0)+8>>2]|0)==(D|0)){if((og(O,$,(a[X]|0)==58?Y:X)|0)==1){ba=_;break d}ea=c[T>>2]|0}else{ea=Z}$=_+1|0;if($>>>0<ea>>>0){_=$;Z=ea}else{da=X;V=46;break b}}}}while(0);T=c[(c[W>>2]|0)+(ba<<2)>>2]|0;if((T|0)==0){da=X;V=46;break b}U=c[(c[1271688]|0)+((c[T>>2]|0)+(c[(c[(c[1271690]|0)+(P<<2)>>2]|0)+12>>2]|0)<<2)>>2]|0}}while(0);if((U|0)==0){V=54;break}c[U+8>>2]=0;D=U+12|0;c[D>>2]=(c[D>>2]|0)+1;c[(c[U+4>>2]|0)+76>>2]=-16;c[B>>2]=rg(c[B>>2]|0,4,E,(c[E>>2]|0)+1|0)|0;D=cEb(16)|0;M=c[E>>2]|0;c[(c[B>>2]|0)+(M-1<<2)>>2]=D;if((D|0)==0){yf(1);fa=c[E>>2]|0}else{fa=M}M=fa-1|0;c[(c[(c[B>>2]|0)+(M<<2)>>2]|0)+4>>2]=U;c[(c[(c[B>>2]|0)+(M<<2)>>2]|0)+8>>2]=b;M=U+244|0;D=U+248|0;K=rg(c[M>>2]|0,4,D,(c[D>>2]|0)+1|0)|0;c[M>>2]=K;c[K+((c[D>>2]|0)-1<<2)>>2]=c[(c[B>>2]|0)+((c[E>>2]|0)-1<<2)>>2];D=c[H+12>>2]|0;if((D|0)==0){V=24;break}else{H=D}}if((V|0)==24){N=c[x>>2]|0;break}else if((V|0)==35){da=c[w>>2]|0;ga=c[C>>2]|0;yDb(0,8,2016160,(J=i,i=i+16|0,c[J>>2]=da,c[J+8>>2]=ga,J)|0);i=J;yf(1);return 0}else if((V|0)==46){ga=c[C>>2]|0;yDb(0,8,2016160,(J=i,i=i+16|0,c[J>>2]=da,c[J+8>>2]=ga,J)|0);i=J;yf(1);return 0}else if((V|0)==54){yDb(0,0,1991208,(J=i,i=i+24|0,c[J>>2]=2005576,c[J+8>>2]=1929552,c[J+16>>2]=270,J)|0);i=J;Cd();return 0}}}while(0);e:do{if((N|0)!=0){ga=b+16|0;da=q|0;C=s|0;w=s+4|0;U=b|0;fa=p|0;ba=k|0;ea=m|0;ca=f|0;R=b+12|0;S=0;z=N;f:while(1){H=c[(c[ga>>2]|0)+(S<<2)>>2]|0;E=H+12|0;$Db(E);B=z+4|0;D=c[B>>2]|0;K=c[D+12>>2]|0;M=c[D+24>>2]|0;if((Mz(v)|0)<0){yf(1)}Kz(c[v>>2]|0,2087696,(J=i,i=i+8|0,c[J>>2]=c[c[D+4>>2]>>2],J)|0)|0;i=J;if((M|0)>1){M=c[v>>2]|0;D=z+8|0;I=aj(K,c[D>>2]|0)|0;Kz(M,2036040,(J=i,i=i+8|0,c[J>>2]=I,J)|0)|0;i=J;ha=D}else{ha=z+8|0}Py(c[v>>2]|0,0);Oz(c[v>>2]|0,E)|0;E=bj(c[(c[B>>2]|0)+12>>2]|0,c[ha>>2]|0)|0;do{if((E|0)==0){D=Ri(2071200)|0;I=c[H+4>>2]|0;M=I|0;K=c[(c[1271690]|0)+(c[M>>2]<<2)>>2]|0;T=I+108|0;Y=c[T>>2]|0;if((Y|0)==0){O=c[I+4>>2]|0;Q=O+40|0;ia=c[Q>>2]|0;ja=c[Q+4>>2]|0;ka=0;la=c[I+112>>2]|0;ma=O}else{O=c[I+112>>2]|0;ia=O;ja=Y;ka=Y;la=O;ma=c[I+4>>2]|0}c[r>>2]=0;O=I+4|0;Y=c[ma+8>>2]|0;Q=c[Y+8>>2]|0;if((Q|0)==1){V=68;break f}if((ka|0)==0){gU(s,c[K>>2]|0,ma,0);L=c[O>>2]|0;Z=c[L+8>>2]|0;na=c[w>>2]|0;oa=c[C>>2]|0;pa=L;qa=Z;ra=c[Z+8>>2]|0}else{na=la;oa=ka;pa=ma;qa=Y;ra=Q}if((ra|0)==3){Q=c[c[(c[1271690]|0)+(c[M>>2]<<2)>>2]>>2]|0;Y=c[qa+120>>2]|0;Z=c[qa+124>>2]|0;if((Y|0)==0|(Z|0)==0){L=c[Q+24>>2]|0;if((L|0)==0){sa=Y;ta=Z}else{_=c[Q+28>>2]|0;$=0;aa=Y;ua=Z;while(1){va=c[(c[_+($<<2)>>2]|0)+8>>2]|0;if((c[va+8>>2]|0)==0){wa=c[va+120>>2]|0;xa=c[va+124>>2]|0;ya=(ua|0)>(xa|0)?ua:xa;za=(aa|0)>(wa|0)?aa:wa}else{ya=ua;za=aa}wa=$+1|0;if(wa>>>0<L>>>0){$=wa;aa=za;ua=ya}else{sa=za;ta=ya;break}}}if((sa|0)==0|(ta|0)==0){Aa=(ta|0)>576?ta:576;Ba=(sa|0)>720?sa:720}else{Aa=ta;Ba=sa}yDb(Q,32,2026848,(J=i,i=i+16|0,c[J>>2]=Ba,c[J+8>>2]=Aa,J)|0);i=J;Ca=Aa;Da=Ba;Ea=c[(c[O>>2]|0)+8>>2]|0}else{Ca=Z;Da=Y;Ea=qa}c[I+128>>2]=Da;c[Ea+120>>2]=Da;c[I+228>>2]=Da;c[I+124>>2]=Ca;c[Ea+124>>2]=Ca;c[I+232>>2]=Ca;c[Ea+140>>2]=30;c[I+132>>2]=30;ua=ICb()|0;c[I+224>>2]=ua;aa=(ua|0)==0;if(aa){Fa=aa?-12:0;break}Ga=c[O>>2]|0}else{Ga=pa}aa=Ga+80|0;if((c[aa>>2]|0)==0){ua=c[Ga+8>>2]|0;Ha=ua+224|0;Ia=ua+228|0}else{Ha=aa;Ia=Ga+84|0}aa=c[Ia>>2]|0;ua=(aa|0)==0;$=ua?0:c[Ha>>2]|0;IAb(p,0,1);L=c[I+124>>2]|0;_=c[((c[I+280>>2]|0)==0?I+132|0:I+288|0)>>2]|0;P=(c[(c[(c[O>>2]|0)+8>>2]|0)+88>>2]|0)>>>4&524288|2;KAb(p,2062400,(J=i,i=i+64|0,c[J>>2]=c[I+128>>2],c[J+8>>2]=L,c[J+16>>2]=_,c[J+24>>2]=ia,c[J+32>>2]=ja,c[J+40>>2]=$,c[J+48>>2]=ua?1:aa,c[J+56>>2]=P,J)|0);i=J;if(!((oa|0)==0|(na|0)==0)){KAb(p,2058800,(J=i,i=i+16|0,c[J>>2]=oa,c[J+8>>2]=na,J)|0);i=J}P=c[M>>2]|0;aa=c[c[O>>2]>>2]|0;Lb(da|0,255,2205248,(J=i,i=i+24|0,c[J>>2]=c[U>>2],c[J+8>>2]=P,c[J+16>>2]=aa,J)|0)|0;i=J;aa=H|0;P=lj(aa,D,da,c[fa>>2]|0,0,c[A>>2]|0)|0;if((P|0)<0){G=P;V=137;break f}P=c[aa>>2]|0;c[o>>2]=P;if((c[T>>2]|0)==0){Ja=P}else{aa=c[c[O>>2]>>2]|0;Lb(da|0,255,2051088,(J=i,i=i+16|0,c[J>>2]=c[M>>2],c[J+8>>2]=aa,J)|0)|0;i=J;aa=Ri(2041768)|0;ua=lj(t,aa,da,2038200,0,c[A>>2]|0)|0;if((ua|0)<0){G=ua;V=137;break f}ua=Ii(P,0,c[t>>2]|0,0)|0;if((ua|0)<0){G=ua;V=137;break f}ua=c[t>>2]|0;c[o>>2]=ua;Ja=ua}if((c[2128648]|0)!=0){ua=c[c[O>>2]>>2]|0;Lb(da|0,255,2035016,(J=i,i=i+16|0,c[J>>2]=c[M>>2],c[J+8>>2]=ua,J)|0)|0;i=J;ua=Ri(2031008)|0;P=lj(u,ua,da,9203008,0,c[A>>2]|0)|0;if((P|0)<0){G=P;V=137;break f}P=Ii(Ja,0,c[u>>2]|0,0)|0;if((P|0)<0){G=P;V=137;break f}c[o>>2]=c[u>>2]}P=c[c[O>>2]>>2]|0;Lb(da|0,255,2118176,(J=i,i=i+16|0,c[J>>2]=c[M>>2],c[J+8>>2]=P,J)|0)|0;i=J;P=K+40|0;if((c[P>>2]|0)==0&(c[P+4>>2]|0)==(-2147483648|0)){Ka=-2147483648;La=0}else{P=(c[K+68>>2]|0)==0;Ka=P?-2147483648:0;La=P?0:0}P=K+48|0;ua=xh(La,Ka,c[P>>2]|0,c[P+4>>2]|0,o,r,da)|0;if((ua|0)<0){G=ua;V=137;break f}ua=Ii(c[o>>2]|0,0,c[B>>2]|0,c[ha>>2]|0)|0;Fa=(ua|0)<0?ua:0}else if((E|0)==1){ua=Ri(2267056)|0;P=c[H+4>>2]|0;aa=P|0;$=c[(c[1271690]|0)+(c[aa>>2]<<2)>>2]|0;c[j>>2]=0;_=P+4|0;if((c[(c[(c[_>>2]|0)+8>>2]|0)+8>>2]|0)!=1){V=102;break f}IAb(f,0,1);P=c[(c[_>>2]|0)+8>>2]|0;L=c[P+412>>2]|0;X=wFb(c[P+420>>2]|0)|0;KAb(f,2237864,(J=i,i=i+32|0,c[J>>2]=1,c[J+8>>2]=L,c[J+16>>2]=L,c[J+24>>2]=X,J)|0);i=J;X=c[(c[_>>2]|0)+8>>2]|0;L=X+448|0;P=c[L>>2]|0;W=c[L+4>>2]|0;if((P|0)==0&(W|0)==0){KAb(f,2215088,(J=i,i=i+8|0,c[J>>2]=c[X+416>>2],J)|0);i=J}else{KAb(f,2225488,(J=i,i=i+16|0,c[J>>2]=P,c[J+8>>2]=W,J)|0);i=J}W=c[aa>>2]|0;P=c[c[_>>2]>>2]|0;Lb(da|0,255,2205248,(J=i,i=i+24|0,c[J>>2]=c[U>>2],c[J+8>>2]=W,c[J+16>>2]=P,J)|0)|0;i=J;P=H|0;W=lj(P,ua,da,c[ca>>2]|0,0,c[A>>2]|0)|0;if((W|0)<0){G=W;V=137;break f}W=c[P>>2]|0;c[e>>2]=W;P=c[2291710]|0;if((P|0)>0){TGb(ba|0,0,256)|0;uAb(ba,256,2197704,(J=i,i=i+8|0,c[J>>2]=P,J)|0)|0;i=J;Ma=+g[445466];if(Ma!=.1){uAb(ba,256,2186560,(J=i,i=i+8|0,h[J>>3]=Ma,J)|0)|0;i=J}if((c[R>>2]|0)==0){uAb(ba,256,2170592,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0)|0;i=J}yDb(0,32,2162192,(J=i,i=i+8|0,c[J>>2]=ba,J)|0);i=J;P=c[aa>>2]|0;ua=c[c[_>>2]>>2]|0;Lb(da|0,255,2155552,(J=i,i=i+32|0,c[J>>2]=c[U>>2],c[J+8>>2]=2148624,c[J+16>>2]=P,c[J+24>>2]=ua,J)|0)|0;i=J;ua=Ri(2148624)|0;P=lj(l,ua,da,ba,0,c[A>>2]|0)|0;if((P|0)<0){G=P;V=137;break f}P=Ii(W,0,c[l>>2]|0,0)|0;if((P|0)<0){G=P;V=137;break f}P=c[l>>2]|0;c[e>>2]=P;Na=P}else{Na=W}if((c[445464]|0)!=256){yDb(0,24,2142048,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Lb(ea|0,256,2136296,(J=i,i=i+8|0,h[J>>3]=+(c[445464]|0)*.00390625,J)|0)|0;i=J;yDb(0,32,2130120,(J=i,i=i+8|0,c[J>>2]=ea,J)|0);i=J;W=c[aa>>2]|0;P=c[c[_>>2]>>2]|0;Lb(da|0,255,2155552,(J=i,i=i+32|0,c[J>>2]=c[U>>2],c[J+8>>2]=2123376,c[J+16>>2]=W,c[J+24>>2]=P,J)|0)|0;i=J;P=Ri(2123376)|0;W=lj(n,P,da,ea,0,c[A>>2]|0)|0;if((W|0)<0){G=W;V=137;break f}W=Ii(Na,0,c[n>>2]|0,0)|0;if((W|0)<0){G=W;V=137;break f}c[e>>2]=c[n>>2]}W=c[c[_>>2]>>2]|0;Lb(da|0,255,2118176,(J=i,i=i+16|0,c[J>>2]=c[aa>>2],c[J+8>>2]=W,J)|0)|0;i=J;W=$+40|0;if((c[W>>2]|0)==0&(c[W+4>>2]|0)==(-2147483648|0)){Oa=-2147483648;Pa=0}else{W=(c[$+68>>2]|0)==0;Oa=W?-2147483648:0;Pa=W?0:0}W=$+48|0;$=xh(Pa,Oa,c[W>>2]|0,c[W+4>>2]|0,e,j,da)|0;if(($|0)<0){G=$;V=137;break f}$=Ii(c[e>>2]|0,0,c[B>>2]|0,c[ha>>2]|0)|0;Fa=($|0)<0?$:0}else{V=123;break f}}while(0);if((Fa|0)<0){G=Fa;V=137;break}B=c[z+12>>2]|0;if((B|0)==0){break e}else{S=S+1|0;z=B}}if((V|0)==68){yDb(0,16,2066728,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;G=-22;i=d;return G|0}else if((V|0)==102){yDb(0,16,2251672,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;G=-22;i=d;return G|0}else if((V|0)==123){yDb(0,0,1991208,(J=i,i=i+24|0,c[J>>2]=1956992,c[J+8>>2]=1929552,c[J+16>>2]=831,J)|0);i=J;Cd();return 0}else if((V|0)==137){i=d;return G|0}}}while(0);Vk(x);x=c[y>>2]|0;V=(x|0)==0;do{if(F){if(!V){J=b+24|0;Fa=0;ha=x;while(1){uh(b,c[(c[J>>2]|0)+(Fa<<2)>>2]|0,ha)|0;e=c[ha+12>>2]|0;if((e|0)==0){break}else{Fa=Fa+1|0;ha=e}}}Vk(y);ha=oj(c[A>>2]|0,0)|0;if((ha|0)<0){G=ha}else{break}i=d;return G|0}else{if(V){break}ha=b+24|0;Fa=b+28|0;J=x;e=c[Fa>>2]|0;while(1){c[ha>>2]=rg(c[ha>>2]|0,4,Fa,e+1|0)|0;j=cEb(20)|0;Oa=c[Fa>>2]|0;c[(c[ha>>2]|0)+(Oa-1<<2)>>2]=j;if((j|0)==0){yf(1);Qa=c[Fa>>2]|0}else{Qa=Oa}Oa=Qa-1|0;c[(c[(c[ha>>2]|0)+(Oa<<2)>>2]|0)+8>>2]=b;c[(c[(c[ha>>2]|0)+(Oa<<2)>>2]|0)+16>>2]=J;j=c[J+12>>2]|0;c[(c[(c[(c[ha>>2]|0)+(Oa<<2)>>2]|0)+16>>2]|0)+12>>2]=0;if((j|0)==0){break}else{J=j;e=Qa}}}}while(0);c[b+12>>2]=1;G=0;i=d;return G|0}function wh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+16|0;e=c[a+20>>2]|0;a=0;while(1){if((a|0)>=(e|0)){f=0;g=4;break}if((c[(c[(c[d>>2]|0)+(a<<2)>>2]|0)+4>>2]|0)==(b|0)){f=1;g=4;break}else{a=a+1|0}}if((g|0)==4){return f|0}return 0}function xh(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;k=c[f>>2]|0;l=c[k+48>>2]|0;m=(bj(c[k+28>>2]|0,c[g>>2]|0)|0)==0;k=m?2109312:2096872;m=(d|0)==(-1|0)&(e|0)==2147483647;n=(a|0)==0&(b|0)==(-2147483648|0);if(m&n){o=0;i=j;return o|0}p=Ri(k)|0;if((p|0)==0){yDb(0,16,2091264,(q=i,i=i+8|0,c[q>>2]=k,q)|0);i=q;o=-1279870712;i=j;return o|0}r=mj(l,p,h)|0;if((r|0)==0){o=-12;i=j;return o|0}if(m){s=0}else{s=vEb(r,2086240,d,e,1)|0}if((s|0)<0|n){t=s}else{t=vEb(r,2081248,a,b,1)|0}if((t|0)<0){yDb(r,16,2075760,(q=i,i=i+8|0,c[q>>2]=k,q)|0);i=q;o=t;i=j;return o|0}t=Zi(r,0)|0;if((t|0)<0){o=t;i=j;return o|0}t=Ii(c[f>>2]|0,c[g>>2]|0,r,0)|0;if((t|0)<0){o=t;i=j;return o|0}c[f>>2]=r;c[g>>2]=0;o=0;i=j;return o|0}function yh(){var b=0,d=0;b=i;yDb(0,-8,1984248,(d=i,i=i+8|0,c[d>>2]=9203128,d)|0);i=d;if(!(a[548136]|0)){i=b;return}Td(0,0,4654696)|0;i=b;return}function zh(){var b=0,d=0,e=0;b=i;i=i+64|0;d=b|0;if(!(a[545816]|0)){do{if((cd(0)|0)!=0){if((cd(2)|0)==0){break}if((Wb(0,d|0)|0)!=0){break}UGb(4654696,d|0,60)|0;a[548136]=1;e=d|0;c[e>>2]=c[e>>2]&-1516;e=d+4|0;c[e>>2]=c[e>>2]|1;e=d+12|0;c[e>>2]=c[e>>2]&-32843;e=d+8|0;c[e>>2]=c[e>>2]&-305|48;a[d+23|0]=1;a[d+22|0]=0;Td(0,0,d|0)|0}}while(0);Db(3,212)|0}eU()|0;Db(2,212)|0;Db(15,212)|0;Db(24,212)|0;i=b;return}function Ah(b){b=b|0;var d=0;d=i;c[1149826]=b;c[1149828]=(c[1149828]|0)+1;yDb(0,-8,1984248,(b=i,i=i+8|0,c[b>>2]=9203128,b)|0);i=b;if(a[548136]|0){Td(0,0,4654696)|0}if((c[1149828]|0)>3){ac(123)}else{i=d;return}}function Bh(a){a=a|0;return(c[1149828]|0)>1|0}function Ch(a){a=a|0;var b=0,d=0;b=i;d=BBb(a,9203128,0,2)|0;if((d|0)==0){i=b;return}yDb(0,8,1926608,(a=i,i=i+8|0,c[a>>2]=c[d>>2],a)|0);i=a;yf(1);i=b;return}function Dh(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+256|0;d=a+4|0;e=c[(c[d>>2]|0)+8>>2]|0;f=e+448|0;if(!((c[f>>2]|0)==0&(c[f+4>>2]|0)==0)){g=1;i=b;return g|0}h=e+416|0;e=c[h>>2]|0;if((e|0)>(c[a+120>>2]|0)){g=0;i=b;return g|0}j=jBb(e)|0;e=F;c[f>>2]=j;c[f+4>>2]=e;if((j|0)==0&(e|0)==0){g=0;i=b;return g|0}f=b|0;iBb(f,256,c[h>>2]|0,j,e);e=c[c[d>>2]>>2]|0;yDb(0,24,1904720,(d=i,i=i+24|0,c[d>>2]=c[a>>2],c[d+8>>2]=e,c[d+16>>2]=f,d)|0);i=d;g=1;i=b;return g|0}function Eh(b,d){b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0.0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+272|0;f=e|0;j=e+136|0;xf(316);ge(c[p>>2]|0,0,2,0)|0;BDb(1);Hf(b,d,625312);do{if((b|0)>1){k=d+4|0;if((QGb(c[k>>2]|0,1884112)|0)!=0){l=b;m=d;break}a[545816]=1;CDb(360);l=b-1|0;m=k}else{l=b;m=d}}while(0);LX();Sh();Vh();cx();dU()|0;Tf(l,m,625312);zh();if((xg(l,m)|0)<0){yf(1)}m=c[1167938]|0;if((m|0)<1&(c[1167942]|0)==0){wg();yDb(0,24,2342128,(n=i,i=i+8|0,c[n>>2]=561616,n)|0);i=n;yf(1);o=c[1167938]|0}else{o=m}if((o|0)<1){yDb(0,8,2319320,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;yf(1)}nd(0,j|0)|0;o=c[j>>2]|0;m=gHb(o,(o|0)<0|0?-1:0,1e6,0)|0;o=c[j+4>>2]|0;j=YGb(m,F,o,(o|0)<0|0?-1:0)|0;o=F;c[2187442]=j;if((Hh()|0)<0){yf(1)}nd(0,f|0)|0;m=c[f>>2]|0;l=c[f+4>>2]|0;if((c[2128652]|0)!=0){f=gHb(m,(m|0)<0|0?-1:0,1e6,0)|0;m=F;d=ZGb(l,(l|0)<0|0?-1:0,j,o)|0;o=YGb(d,F,f,m)|0;q=(+(o>>>0)+ +(F|0)*4294967296.0)/1.0e6;Ic(2297240,(n=i,i=i+8|0,h[n>>3]=q,n)|0)|0;i=n}o=8648280;m=c[o+4>>2]|0;f=8648288;d=c[f>>2]|0;j=c[f+4>>2]|0;yDb(0,48,2280232,(n=i,i=i+32|0,c[n>>2]=c[o>>2],c[n+8>>2]=m,c[n+16>>2]=d,c[n+24>>2]=j,n)|0);i=n;n=8648280;j=8648288;d=c[j>>2]|0;m=c[j+4>>2]|0;j=YGb(d,m,c[n>>2]|0,c[n+4>>2]|0)|0;if(!(+g[169908]*(+(j>>>0)+ +(F|0)*4294967296.0)<+(d>>>0)+ +(m|0)*4294967296.0)){r=c[1149828]|0;s=(r|0)!=0;t=a[686568]|0;u=t&1;v=s?255:u;yf(v);w=a[686568]|0;x=w&1;i=e;return x|0}yf(69);r=c[1149828]|0;s=(r|0)!=0;t=a[686568]|0;u=t&1;v=s?255:u;yf(v);w=a[686568]|0;x=w&1;i=e;return x|0}function Fh(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+136|0;d=b|0;if((c[2128652]|0)!=0){nd(0,d|0)|0;e=c[d+16>>2]|0;d=e;f=eHb(d<<10|0>>>22,((e|0)<0|0?-1:0)<<10|d>>>22,1024,0)|0;Ic(2214344,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g}if((c[1167948]|0)>0){f=0;do{kj((c[(c[1305380]|0)+(f<<2)>>2]|0)+8|0);d=c[(c[1305380]|0)+(f<<2)>>2]|0;e=d+16|0;if((c[d+20>>2]|0)>0){d=0;h=e;while(1){$Db((c[(c[h>>2]|0)+(d<<2)>>2]|0)+12|0);$Db((c[(c[(c[1305380]|0)+(f<<2)>>2]|0)+16>>2]|0)+(d<<2)|0);j=d+1|0;k=c[(c[1305380]|0)+(f<<2)>>2]|0;l=k+16|0;if((j|0)<(c[k+20>>2]|0)){d=j;h=l}else{m=l;break}}}else{m=e}$Db(m);h=c[(c[1305380]|0)+(f<<2)>>2]|0;d=h+24|0;if((c[h+28>>2]|0)>0){h=0;l=d;while(1){$Db((c[(c[l>>2]|0)+(h<<2)>>2]|0)+12|0);$Db((c[(c[(c[1305380]|0)+(f<<2)>>2]|0)+24>>2]|0)+(h<<2)|0);j=h+1|0;k=c[(c[1305380]|0)+(f<<2)>>2]|0;n=k+24|0;if((j|0)<(c[k+28>>2]|0)){h=j;l=n}else{o=n;break}}}else{o=d}$Db(o);$Db((c[(c[1305380]|0)+(f<<2)>>2]|0)+4|0);$Db((c[1305380]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1167948]|0))}$Db(5221520);$Db(4284312);if((c[1167938]|0)>0){f=0;do{o=c[c[(c[1163660]|0)+(f<<2)>>2]>>2]|0;do{if((o|0)!=0){m=c[o+8>>2]|0;if((m|0)==0){break}if((c[m+28>>2]&1|0)!=0){break}m=c[o+16>>2]|0;if((m|0)==0){break}Iz(m)|0}}while(0);bT(o);DBb((c[(c[1163660]|0)+(f<<2)>>2]|0)+4|0);$Db((c[1163660]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1167938]|0))}if((c[1167936]|0)>0){f=0;do{d=c[(c[1163658]|0)+(f<<2)>>2]|0;m=c[d+56>>2]|0;if((m|0)==0){p=d}else{d=m;while(1){m=c[d+12>>2]|0;T_(d);if((m|0)==0){break}else{d=m}}p=c[(c[1163658]|0)+(f<<2)>>2]|0}c[p+56>>2]=0;JCb((c[(c[1163658]|0)+(f<<2)>>2]|0)+72|0);VRa(c[(c[(c[1163658]|0)+(f<<2)>>2]|0)+372>>2]|0);$Db((c[(c[1163658]|0)+(f<<2)>>2]|0)+112|0);IBb(c[(c[(c[1163658]|0)+(f<<2)>>2]|0)+116>>2]|0);$Db((c[(c[1163658]|0)+(f<<2)>>2]|0)+304|0);$Db((c[(c[1163658]|0)+(f<<2)>>2]|0)+292|0);$Db((c[1163658]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1167936]|0))}if((c[1167942]|0)>0){f=0;do{KT(c[(c[1271690]|0)+(f<<2)>>2]|0);$Db((c[1271690]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1167942]|0))}if((c[1167940]|0)>0){f=0;do{JCb((c[(c[1271688]|0)+(f<<2)>>2]|0)+20|0);JCb((c[(c[1271688]|0)+(f<<2)>>2]|0)+24|0);DBb((c[(c[1271688]|0)+(f<<2)>>2]|0)+104|0);C0a((c[(c[1271688]|0)+(f<<2)>>2]|0)+176|0);JCb((c[(c[1271688]|0)+(f<<2)>>2]|0)+224|0);$Db((c[(c[1271688]|0)+(f<<2)>>2]|0)+244|0);$Db((c[(c[1271688]|0)+(f<<2)>>2]|0)+260|0);$Db((c[1271688]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1167940]|0))}f=c[636776]|0;if((f|0)!=0){fb(f|0)|0}ZDb(c[636774]|0);$Db(5086752);$Db(5086760);$Db(4654632);$Db(4654640);vf();eU()|0;if((c[1149826]|0)!=0){yDb(0,32,2213456,(g=i,i=i+8|0,c[g>>2]=c[1149826],g)|0);i=g}yDb(0,-8,1984248,(g=i,i=i+8|0,c[g>>2]=9203128,g)|0);i=g;if(!(a[548136]|0)){i=b;return}Td(0,0,4654696)|0;i=b;return}function Gh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return}function Hh(){var b=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,gb=0,hb=0,jb=0,kb=0,lb=0,mb=0,ob=0,pb=0,qb=0,sb=0,tb=0,ub=0,vb=0,xb=0,yb=0,zb=0,Ab=0.0,Bb=0,Cb=0.0,Db=0.0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Jc=0,Kc=0,Lc=0,Mc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,yd=0,zd=0,Ad=0,Bd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0;b=i;i=i+24416|0;e=b|0;f=b+80|0;j=b+88|0;k=b+96|0;l=b+128|0;m=b+136|0;n=b+216|0;r=b+248|0;s=b+280|0;t=b+312|0;u=b+344|0;v=b+376|0;w=b+408|0;x=b+440|0;y=b+472|0;z=b+504|0;A=b+536|0;B=b+544|0;C=b+552|0;D=b+560|0;G=b+568|0;H=b+576|0;I=b+584|0;J=b+592|0;K=b+600|0;L=b+608|0;M=b+616|0;N=b+624|0;O=b+632|0;R=b+640|0;S=b+672|0;T=b+704|0;U=b+736|0;V=b+768|0;W=b+800|0;X=b+832|0;Y=b+840|0;Z=b+848|0;_=b+856|0;$=b+864|0;ca=b+992|0;da=b+1e3|0;ea=b+1008|0;fa=b+1136|0;ha=b+5232|0;ia=b+5488|0;ja=b+5744|0;ka=b+5752|0;la=b+5760|0;ma=b+5768|0;na=b+5776|0;oa=b+5840|0;pa=b+22224|0;qa=b+23256|0;ra=b+23264|0;sa=b+23272|0;ta=b+23280|0;ua=b+23288|0;va=b+23296|0;wa=b+23304|0;xa=b+24336|0;ya=b+24344|0;za=b+22232|0;Aa=b+23312|0;Ba=b+24352|0;Ca=sa;Da=ta;Ea=wa;Fa=c[1167948]|0;if((Fa|0)>0){Ga=c[1305380]|0;Ha=c[1271688]|0;Ia=0;Ja=Fa;while(1){Fa=c[Ga+(Ia<<2)>>2]|0;Ka=Fa+28|0;La=c[Ka>>2]|0;if((La|0)>0){Ma=c[Fa+24>>2]|0;Na=Fa+20|0;Oa=Fa+16|0;Fa=0;Pa=La;while(1){La=c[(c[Ma+(Fa<<2)>>2]|0)+4>>2]|0;do{if((La|0)==0){Qa=Pa}else{Ra=La+8|0;if((c[Ra>>2]|0)>-1){Qa=Pa;break}if((c[Na>>2]|0)!=1){Qa=Pa;break}Sa=c[1167940]|0;while(1){Ta=Sa-1|0;if((Sa|0)<=0){break}if((c[(c[c[Oa>>2]>>2]|0)+4>>2]|0)==(c[Ha+(Ta<<2)>>2]|0)){break}else{Sa=Ta}}c[Ra>>2]=Ta;Qa=c[Ka>>2]|0}}while(0);La=Fa+1|0;if((La|0)<(Qa|0)){Fa=La;Pa=Qa}else{break}}Ua=c[1167948]|0}else{Ua=Ja}Pa=Ia+1|0;if((Pa|0)<(Ua|0)){Ia=Pa;Ja=Ua}else{break}}}Ua=c[1167942]|0;if((Ua|0)>0){Ja=0;Ia=Ua;while(1){Ua=c[(c[1271690]|0)+(Ja<<2)>>2]|0;do{if((c[Ua+64>>2]|0)==0){Va=Ia}else{Qa=Ua+56|0;if((c[Qa>>2]|0)<=0){Va=Ia;break}Ta=Ua+12|0;Ha=0;do{Ga=WFb()|0;Pa=(c[(c[1271688]|0)+((c[Ta>>2]|0)+Ha<<2)>>2]|0)+32|0;c[Pa>>2]=Ga;c[Pa+4>>2]=F;Ha=Ha+1|0;}while((Ha|0)<(c[Qa>>2]|0));Va=c[1167942]|0}}while(0);Ua=Ja+1|0;if((Ua|0)<(Va|0)){Ja=Ua;Ia=Va}else{break}}}Va=c[1167938]|0;a:do{if((Va|0)>0){Ia=c[1163660]|0;Ja=0;while(1){Wa=c[c[Ia+(Ja<<2)>>2]>>2]|0;if((c[Wa+24>>2]|0)==0){if((c[(c[Wa+8>>2]|0)+28>>2]&4096|0)==0){break}}Ua=Ja+1|0;if((Ua|0)<(Va|0)){Ja=Ua}else{Xa=0;Ya=0;Za=28;break a}}QT(Wa,Ja,Wa+32|0,1);yDb(0,16,2291456,(_a=i,i=i+8|0,c[_a>>2]=Ja,_a)|0);i=_a;$a=-22}else{Xa=0;Ya=0;Za=28}}while(0);b:do{if((Za|0)==28){while(1){Za=0;if((Ya|0)>=(c[1167948]|0)){break}Wa=oj(c[(c[(c[1305380]|0)+(Ya<<2)>>2]|0)+8>>2]|0,0)|0;if((Wa|0)<0){$a=Wa;break b}Xa=Wa;Ya=Ya+1|0;Za=28}c:do{if((c[1167936]|0)>0){Ja=la|0;Wa=la+4|0;Va=ma|0;Ia=ma+4|0;Ua=va|0;Qa=va+4|0;Ha=ua|0;Ta=ua+4|0;Pa=ra|0;Ga=ra+4|0;Fa=0;Ka=Xa;d:while(1){ab=c[(c[1163658]|0)+(Fa<<2)>>2]|0;bb=ab|0;Oa=c[c[(c[1163660]|0)+(c[bb>>2]<<2)>>2]>>2]|0;Na=ab+8|0;Ma=c[Na>>2]|0;if((Ma|0)>-1){cb=c[(c[1271688]|0)+(Ma<<2)>>2]|0}else{cb=0}e:do{if((c[ab+356>>2]|0)==0){db=ab+12|0;Ma=c[db>>2]|0;La=c[Ma+8>>2]|0;Sa=(cb|0)!=0;do{if(Sa){eb=c[cb+4>>2]|0;gb=c[eb+8>>2]|0;c[Ma+72>>2]=c[eb+72>>2];c[La+796>>2]=c[gb+796>>2];c[La+400>>2]=c[gb+400>>2];hb=gb}else{gb=c[Oa+24>>2]|0;if((gb|0)==0){jb=La+8|0}else{eb=c[Oa+28>>2]|0;kb=La+8|0;lb=0;while(1){mb=c[eb+(lb<<2)>>2]|0;if((mb|0)!=(Ma|0)){if((c[(c[mb+8>>2]|0)+8>>2]|0)==(c[kb>>2]|0)){ob=lb;break}}mb=lb+1|0;if(mb>>>0<gb>>>0){lb=mb}else{ob=mb;break}}if((ob|0)==(gb|0)){jb=kb}else{hb=0;break}}if(!((c[jb>>2]|0)>>>0<2>>>0)){hb=0;break}c[Ma+72>>2]=1;hb=0}}while(0);if((c[ab+352>>2]|0)!=0){if(!Sa){Za=51;break d}if((c[ab+300>>2]|0)!=0){Za=51;break d}Ma=hb+100|0;lb=c[Ma>>2]|0;eb=YGb(lb,(lb|0)<0|0?-1:0,16,0)|0;lb=F;mb=0;if(lb>>>0>mb>>>0|lb>>>0==mb>>>0&eb>>>0>2147483647>>>0){$a=-22;break b}mb=hb+48|0;lb=La+48|0;c[lb>>2]=c[mb>>2];pb=La+8|0;c[pb>>2]=c[hb+8>>2];qb=La+52|0;f:do{if((c[qb>>2]|0)==0){sb=Oa+8|0;tb=c[(c[sb>>2]|0)+32>>2]|0;ub=hb+52|0;do{if((tb|0)!=0){vb=zT(tb,c[ub>>2]|0)|0;if((vb|0)==(c[lb>>2]|0)){break}if((yT(c[(c[sb>>2]|0)+32>>2]|0,c[mb>>2]|0,qa)|0)!=0){break f}}}while(0);c[qb>>2]=c[ub>>2]}}while(0);c[La+72>>2]=c[hb+72>>2];c[La+540>>2]=c[hb+540>>2];c[La+524>>2]=c[hb+524>>2];c[La+408>>2]=c[hb+408>>2];mb=cEb(eb)|0;c[La+96>>2]=mb;if((mb|0)==0){$a=-12;break b}UGb(mb|0,c[hb+96>>2]|0,c[Ma>>2]|0)|0;c[La+100>>2]=c[Ma>>2];c[La+792>>2]=c[hb+792>>2];mb=La+104|0;sb=cb+4|0;tb=(c[sb>>2]|0)+40|0;kb=mb;gb=c[tb+4>>2]|0;c[kb>>2]=c[tb>>2];c[kb+4>>2]=gb;gb=c[Oa+8>>2]|0;tb=c[gb>>2]|0;g:do{if((QGb(tb,2351112)|0)==0){vb=c[355084]|0;xb=(vb|0)<0;do{if(xb){yb=c[sb>>2]|0;zb=c[yb+416>>2]|0;Ab=+(c[yb+412>>2]|0)/+(zb|0);if(Ab<+(c[yb+92>>2]|0)/+(c[yb+96>>2]|0)){Bb=yb;Za=70;break}Cb=.5/Ab;Ab=+(c[yb+40>>2]|0)/+(c[yb+44>>2]|0);if(!(Cb>Ab)){Za=65;break}Db=+(c[hb+104>>2]|0)/+(c[hb+108>>2]|0);if(!(Cb>Db&Ab<.002)){Za=65;break}if(Db<.002|(vb|0)==2){Eb=yb;Fb=zb;Za=67}else{Za=68}}else{Za=65}}while(0);do{if((Za|0)==65){Za=0;if((vb|0)!=2){Za=68;break}ub=c[sb>>2]|0;Eb=ub;Fb=c[ub+416>>2]|0;Za=67}}while(0);if((Za|0)==67){Za=0;c[mb>>2]=Fb;c[La+108>>2]=c[Eb+412>>2]<<1;c[La+112>>2]=2;break}do{if((Za|0)==68){Za=0;if(!xb){Za=72;break}Bb=c[sb>>2]|0;Za=70}}while(0);do{if((Za|0)==70){Za=0;xb=hb+112|0;Db=+(c[Bb+40>>2]|0)/+(c[Bb+44>>2]|0);if(!(+(c[hb+104>>2]|0)/+(c[hb+108>>2]|0)*+(c[xb>>2]|0)>Db*2.0)){Za=72;break}if(Db<.002){Gb=xb}else{break g}}}while(0);if((Za|0)==72){Za=0;if((vb|0)!=0){break}Gb=hb+112|0}xb=hb+104|0;ub=c[xb>>2]|0;zb=c[xb+4>>2]|0;c[kb>>2]=ub;c[kb+4>>2]=zb;c[mb>>2]=ba(ub,c[Gb>>2]|0)|0;c[La+108>>2]=zb<<1|0>>>31;c[La+112>>2]=2}else{if((c[gb+28>>2]&1024|0)!=0){break}if((QGb(tb,2284440)|0)==0){break}if((QGb(tb,2283288)|0)==0){break}if((QGb(tb,2281800)|0)==0){break}if((QGb(tb,2280632)|0)==0){break}if((QGb(tb,2279472)|0)==0){break}if((QGb(tb,2278512)|0)==0){break}if((QGb(tb,2277472)|0)==0){break}zb=c[355084]|0;do{if((zb|0)<0){ub=c[hb+108>>2]|0;if((ub|0)==0){break g}xb=hb+112|0;yb=c[sb>>2]|0;Db=+(c[yb+40>>2]|0)/+(c[yb+44>>2]|0);if(!(+(c[hb+104>>2]|0)/+(ub|0)*+(c[xb>>2]|0)>Db)){Za=87;break}if(Db<.002|(zb|0)==0){Hb=xb}else{break g}}else{Za=87}}while(0);if((Za|0)==87){Za=0;if((zb|0)!=0){break}Hb=hb+112|0}vb=hb+104|0;xb=c[vb>>2]|0;ub=c[vb+4>>2]|0;c[kb>>2]=xb;c[kb+4>>2]=ub;c[mb>>2]=ba(xb,c[Hb>>2]|0)|0}}while(0);do{if((c[qb>>2]|0)==1684237684){tb=hb+104|0;gb=c[tb>>2]|0;Ma=c[hb+108>>2]|0;if(!((gb|0)<(Ma|0)&(gb|0)>0)){break}eb=gHb(gb,(gb|0)<0|0?-1:0,121,0)|0;gb=F;xb=(Ma|0)<0|0?-1:0;if(!((gb|0)>(xb|0)|(gb|0)==(xb|0)&eb>>>0>Ma>>>0)){break}Ma=tb;tb=c[Ma+4>>2]|0;c[kb>>2]=c[Ma>>2];c[kb+4>>2]=tb}}while(0);qb=ab+76|0;tb=c[qb>>2]|0;do{if((tb|0)==0){Ma=cb+108|0;eb=qb;xb=c[Ma>>2]|0;gb=c[Ma+4>>2]|0;c[eb>>2]=xb;c[eb+4>>2]=gb;eb=xb;if((eb|0)==0){xb=mb|0;Ma=La+108|0;Ib=c[xb>>2]|0;Jb=c[Ma>>2]|0;Kb=xb;Mb=Ma;break}else{Nb=eb;Ob=gb;Za=99;break}}else{Nb=tb;Ob=c[ab+80>>2]|0;Za=99}}while(0);if((Za|0)==99){Za=0;c[kb>>2]=Ob;c[kb+4>>2]=Nb;Ib=Ob;Jb=Nb;Kb=mb|0;Mb=La+108|0}iFb(Kb,Mb,Ib,(Ib|0)<0|0?-1:0,Jb,(Jb|0)<0|0?-1:0,2147483647,0)|0;c[ab+372>>2]=RRa(c[lb>>2]|0)|0;switch(c[pb>>2]|0){case 2:case 4:{Pb=Ka;break e;break};case 1:{if((c[445464]|0)!=256){yDb(0,8,2275472,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;yf(1)}tb=hb+448|0;qb=c[tb+4>>2]|0;gb=La+448|0;c[gb>>2]=c[tb>>2];c[gb+4>>2]=qb;c[La+412>>2]=c[hb+412>>2];c[La+416>>2]=c[hb+416>>2];c[La+424>>2]=c[hb+424>>2];c[La+464>>2]=c[hb+464>>2];qb=c[hb+432>>2]|0;gb=La+432|0;c[gb>>2]=qb;c[La+116>>2]=c[hb+116>>2];do{if((qb|0)==1|(qb|0)==1152|(qb|0)==576){tb=c[lb>>2]|0;if((tb|0)!=86017){Qb=tb;break}c[gb>>2]=0;Pb=Ka;break e}else{Qb=c[lb>>2]|0}}while(0);if((Qb|0)!=86019){Pb=Ka;break e}c[gb>>2]=0;Pb=Ka;break e;break};case 0:{c[La+140>>2]=c[hb+140>>2];lb=La+120|0;c[lb>>2]=c[hb+120>>2];qb=c[hb+124>>2]|0;c[La+124>>2]=qb;c[La+176>>2]=c[hb+176>>2];pb=ab+92|0;do{if((c[pb>>2]|0)==0){mb=(c[sb>>2]|0)+80|0;if((c[mb>>2]|0)==0){kb=hb+224|0;Rb=c[kb+4>>2]|0;Sb=c[kb>>2]|0;break}else{kb=mb;Rb=c[kb+4>>2]|0;Sb=c[kb>>2]|0;break}}else{c[Pa>>2]=qb;c[Ga>>2]=c[lb>>2];jFb(Ca,pb,ra);kb=c[sa>>2]|0;mb=c[sa+4>>2]|0;yDb(0,24,2271920,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Rb=mb;Sb=kb}}while(0);pb=(c[db>>2]|0)+80|0;lb=La+224|0;c[lb>>2]=Sb;c[lb+4>>2]=Rb;lb=pb;c[lb>>2]=Sb;c[lb+4>>2]=Rb;lb=(c[sb>>2]|0)+92|0;pb=(c[db>>2]|0)+92|0;qb=c[lb+4>>2]|0;c[pb>>2]=c[lb>>2];c[pb+4>>2]=qb;Pb=Ka;break e;break};case 3:{c[La+120>>2]=c[hb+120>>2];c[La+124>>2]=c[hb+124>>2];Pb=Ka;break e;break};default:{Za=116;break d}}}qb=ab+60|0;if((c[qb>>2]|0)==0){pb=p0a(c[La+48>>2]|0)|0;c[qb>>2]=pb;if((pb|0)==0){Za=119;break d}}if(Sa){pb=cb+12|0;c[pb>>2]=(c[pb>>2]|0)+1}c[ab+16>>2]=1;pb=ab+300|0;lb=La+8|0;do{if((c[pb>>2]|0)==0){gb=c[lb>>2]|0;if(!(gb>>>0<2>>>0)){Tb=gb;break}if((vh(th(cb,ab)|0)|0)==0){Za=126;break}yDb(0,8,2267992,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;yf(1);Za=126}else{Za=126}}while(0);do{if((Za|0)==126){Za=0;sb=c[lb>>2]|0;if((sb|0)!=0){Tb=sb;break}sb=c[pb>>2]|0;do{if((sb|0)!=0){gb=ab+76|0;if((c[gb>>2]|0)!=0){break}zj(Da,c[sb>>2]|0);kb=gb;gb=c[ta+4>>2]|0;c[kb>>2]=c[ta>>2];c[kb+4>>2]=gb}}while(0);do{if(Sa){sb=ab+76|0;if((c[sb>>2]|0)!=0){break}zb=cb+108|0;gb=sb;sb=c[zb>>2]|0;kb=c[zb+4>>2]|0;c[gb>>2]=sb;c[gb+4>>2]=kb;if((sb|0)!=0){break}sb=(c[cb+4>>2]|0)+412|0;kb=c[sb>>2]|0;zb=c[sb+4>>2]|0;c[gb>>2]=kb;c[gb+4>>2]=zb;if((kb|0)!=0){break}c[ab+76>>2]=25;c[ab+80>>2]=1;kb=c[ab+4>>2]|0;yDb(0,24,2266488,(_a=i,i=i+16|0,c[_a>>2]=c[bb>>2],c[_a+8>>2]=kb,_a)|0);i=_a}}while(0);kb=c[qb>>2]|0;do{if((kb|0)!=0){zb=c[kb+20>>2]|0;if((zb|0)==0){break}if((c[ab+84>>2]|0)!=0){break}gb=ab+76|0;sb=nFb(gb,zb)|0;zb=(c[(c[qb>>2]|0)+20>>2]|0)+(sb<<3)|0;sb=gb;gb=c[zb+4>>2]|0;c[sb>>2]=c[zb>>2];c[sb+4>>2]=gb}}while(0);if((c[La+48>>2]|0)==13){kb=ab+76|0;gb=ab+80|0;sb=c[kb>>2]|0;zb=c[gb>>2]|0;iFb(kb,gb,sb,(sb|0)<0|0?-1:0,zb,(zb|0)<0|0?-1:0,65535,0)|0}Tb=c[lb>>2]|0}}while(0);do{if((Tb|0)==3){c[La+104>>2]=1;c[La+108>>2]=1e3;lb=La+120|0;if((c[lb>>2]|0)!=0){Ub=Ka;break}Sa=c[1271688]|0;c[lb>>2]=c[(c[(c[(c[Sa+(c[Na>>2]<<2)>>2]|0)+4>>2]|0)+8>>2]|0)+120>>2];c[La+124>>2]=c[(c[(c[(c[Sa+(c[Na>>2]<<2)>>2]|0)+4>>2]|0)+8>>2]|0)+124>>2];Ub=Ka}else if((Tb|0)==1){Sa=c[c[(c[c[pb>>2]>>2]|0)+16>>2]>>2]|0;c[La+420>>2]=c[Sa+52>>2];lb=La+412|0;c[lb>>2]=c[Sa+48>>2];zb=Sa+40|0;sb=c[zb+4>>2]|0;gb=La+448|0;c[gb>>2]=c[zb>>2];c[gb+4>>2]=sb;c[La+416>>2]=Ji(Sa)|0;Sa=c[lb>>2]|0;c[La+104>>2]=1;c[La+108>>2]=Sa;Ub=Ka}else if((Tb|0)==0){Sa=La+104|0;lb=c[ab+76>>2]|0;sb=c[ab+80>>2]|0;gb=Sa;c[gb>>2]=sb;c[gb+4>>2]=lb;zb=c[pb>>2]|0;do{if((zb|0)==0){Wb=sb;Xb=lb}else{if(!((sb|0)==0|(lb|0)==0)){Wb=sb;Xb=lb;break}kb=(c[c[(c[zb>>2]|0)+16>>2]>>2]|0)+56|0;mb=c[kb>>2]|0;tb=c[kb+4>>2]|0;c[gb>>2]=mb;c[gb+4>>2]=tb;Wb=mb;Xb=tb}}while(0);gb=c[34030]|0;do{if(+(Wb|0)/+(Xb|0)<.001&(gb|0)!=0){if((gb|0)==(-1|0)){if((c[(c[Oa+8>>2]|0)+28>>2]&1024|0)!=0){break}}else if(!((gb|0)==254|(gb|0)==1)){break}yDb(Oa,24,2265352,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a}}while(0);gb=ab+104|0;if((c[gb>>2]|0)>0){zb=ab+100|0;lb=0;sb=c[zb>>2]|0;do{tb=sb+(lb<<3)|0;mb=c[tb>>2]|0;kb=c[tb+4>>2]|0;c[Ha>>2]=1;c[Ta>>2]=1e6;tb=KDb(mb,kb,ua,Sa)|0;sb=c[zb>>2]|0;kb=sb+(lb<<3)|0;c[kb>>2]=tb;c[kb+4>>2]=F;lb=lb+1|0;}while((lb|0)<(c[gb>>2]|0))}lb=c[c[(c[c[pb>>2]>>2]|0)+16>>2]>>2]|0;sb=La+120|0;c[sb>>2]=c[lb+20>>2];zb=c[lb+24>>2]|0;Sa=La+124|0;c[Sa>>2]=zb;kb=(c[db>>2]|0)+80|0;tb=ab+92|0;if((c[tb>>2]|0)==0){mb=lb+28|0;lb=kb;eb=c[mb>>2]|0;Ma=c[mb+4>>2]|0;c[lb>>2]=eb;c[lb+4>>2]=Ma;Yb=Ma;Zb=eb}else{c[Ua>>2]=zb;c[Qa>>2]=c[sb>>2];jFb(Ea,tb,va);tb=kb;kb=c[wa>>2]|0;zb=c[wa+4>>2]|0;c[tb>>2]=kb;c[tb+4>>2]=zb;Yb=zb;Zb=kb}kb=La+224|0;c[kb>>2]=Zb;c[kb+4>>2]=Yb;kb=c[c[qb>>2]>>2]|0;zb=La+140|0;do{if((RGb(kb,2264240,7)|0)==0){if(!((c[zb>>2]|0)==-1)){_b=kb;break}tb=c[(c[c[(c[c[pb>>2]>>2]|0)+16>>2]>>2]|0)+52>>2]|0;if((tb|0)==0){_b=kb;break}eb=ZEb(tb)|0;yDb(0,24,2263072,(_a=i,i=i+8|0,c[_a>>2]=eb,_a)|0);i=_a;_b=c[c[qb>>2]>>2]|0}else{_b=kb}}while(0);do{if((RGb(_b,2261856,10)|0)==0){if(!((c[zb>>2]|0)==-1)){break}kb=c[(c[c[(c[c[pb>>2]>>2]|0)+16>>2]>>2]|0)+52>>2]|0;if((kb|0)==0){break}eb=ZEb(kb)|0;yDb(0,24,2260544,(_a=i,i=i+8|0,c[_a>>2]=eb,_a)|0);i=_a}}while(0);eb=c[(c[c[(c[c[pb>>2]>>2]|0)+16>>2]>>2]|0)+52>>2]|0;c[zb>>2]=eb;do{if((hb|0)==0){Za=169}else{if((c[sb>>2]|0)!=(c[hb+120>>2]|0)){Za=169;break}if((c[Sa>>2]|0)!=(c[hb+124>>2]|0)){Za=169;break}if((eb|0)!=(c[hb+140>>2]|0)){Za=169}}}while(0);if((Za|0)==169){Za=0;c[La+796>>2]=c[1305358]}$b=ab+112|0;eb=c[$b>>2]|0;if((eb|0)==0){Ub=Ka;break}if((RGb(eb,2259720,5)|0)==0){ac=JBb(ab+116|0,eb+5|0,1048464,0,0,0,0,0,0)|0;if((ac|0)<0){Za=173;break d}TGb(ab+120|0,0,16)|0;h[ab+136>>3]=+q;h[ab+144>>3]=+q;Ub=ac;break}Sa=c[(c[db>>2]|0)+8>>2]|0;sb=eb;zb=1;while(1){kb=a[sb]|0;if((kb<<24>>24|0)==44){bc=zb+1|0}else if((kb<<24>>24|0)==0){break}else{bc=zb}sb=sb+1|0;zb=bc}sb=WDb(zb<<3)|0;kb=sb;if((sb|0)==0){yDb(0,8,2217872,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;yf(1)}if((zb|0)>0){sb=Sa+104|0;tb=0;Ma=zb;lb=0;mb=kb;xb=eb;while(1){ub=Vb(xb|0,44)|0;if((ub|0)==0){cc=0}else{a[ub]=0;cc=ub+1|0}do{if((PGb(xb,2216096,8)|0)==0){ub=c[c[(c[1163660]|0)+(c[bb>>2]<<2)>>2]>>2]|0;vb=ub+1132|0;yb=c[vb>>2]|0;if(yb>>>0>(2147483647-Ma|0)>>>0){dc=mb;ec=Ma;Za=188}else{fc=Ma-1+yb|0;yb=YDb(mb,fc,8)|0;gc=yb;if((yb|0)==0){dc=gc;ec=fc;Za=188}else{hc=gc;ic=fc}}if((Za|0)==188){Za=0;yDb(0,8,2217872,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;yf(1);hc=dc;ic=ec}fc=xb+8|0;if((a[fc]|0)==0){jc=0;kc=0}else{gc=Af(2215528,fc,1)|0;jc=F;kc=gc}c[Ja>>2]=1;c[Wa>>2]=1e6;gc=KDb(kc,jc,la,sb)|0;fc=F;if((c[vb>>2]|0)==0){lc=hc;mc=lb;nc=ic;break}yb=ub+1136|0;ub=lb;oc=0;while(1){pc=c[(c[yb>>2]|0)+(oc<<2)>>2]|0;qc=pc+16|0;rc=KDb(c[qc>>2]|0,c[qc+4>>2]|0,pc+4|0,sb)|0;pc=YGb(rc,F,gc,fc)|0;rc=ub+1|0;qc=hc+(ub<<3)|0;c[qc>>2]=pc;c[qc+4>>2]=F;qc=oc+1|0;if(qc>>>0<(c[vb>>2]|0)>>>0){ub=rc;oc=qc}else{lc=hc;mc=rc;nc=ic;break}}}else{oc=Af(2215528,xb,1)|0;c[Va>>2]=1;c[Ia>>2]=1e6;ub=KDb(oc,F,ma,sb)|0;oc=mb+(lb<<3)|0;c[oc>>2]=ub;c[oc+4>>2]=F;lc=mb;mc=lb+1|0;nc=Ma}}while(0);oc=tb+1|0;if((oc|0)<(zb|0)){tb=oc;Ma=nc;lb=mc;mb=lc;xb=cc}else{sc=nc;tc=mc;uc=lc;break}}}else{sc=zb;tc=0;uc=kb}if((tc|0)!=(sc|0)){Za=197;break d}Yc(uc|0,tc|0,8,14);c[gb>>2]=tc;c[ab+100>>2]=uc;Ub=Ka}else{Za=201;break d}}while(0);pb=La+88|0;if((c[pb>>2]&1536|0)==0){Pb=Ub;break}xb=c[ab+292>>2]|0;Lb(Aa|0,1024,2253552,(_a=i,i=i+16|0,c[_a>>2]=(xb|0)==0?2252448:xb,c[_a+8>>2]=Fa,_a)|0)|0;i=_a;if((QGb(c[c[qb>>2]>>2]|0,2264240)|0)==0){CBb(ab+328|0,2251296,Aa,16)|0;Pb=Ub;break}xb=c[pb>>2]|0;if((xb&1024|0)==0){vc=xb}else{if((mg(Aa,xa,ya)|0)<0){yDb(0,8,2250360,(_a=i,i=i+8|0,c[_a>>2]=Aa,_a)|0);i=_a;yf(1)}c[La+672>>2]=c[xa>>2];vc=c[pb>>2]|0}if((vc&512|0)==0){Pb=Ub;break}pb=dCb(Aa,2249248)|0;if((pb|0)==0){xb=md(c[(ld()|0)>>2]|0)|0;yDb(0,8,2248160,(_a=i,i=i+16|0,c[_a>>2]=Aa,c[_a+8>>2]=xb,_a)|0);i=_a;yf(1)}c[ab+296>>2]=pb;Pb=Ub}else{Pb=Ka}}while(0);Oa=Fa+1|0;wc=c[1167936]|0;if((Oa|0)<(wc|0)){Fa=Oa;Ka=Pb}else{Za=33;break}}if((Za|0)==33){if((wc|0)>0){xc=0;yc=Pb}else{zc=Pb;Za=214;break}while(1){Ac=c[(c[1163658]|0)+(xc<<2)>>2]|0;if((c[Ac+16>>2]|0)==0){IEb(c[(c[Ac+12>>2]|0)+8>>2]|0,Ac+328|0)|0;Bc=yc}else{Ka=Ac+60|0;Fa=c[Ka>>2]|0;Ia=c[Ac+8>>2]|0;do{if((Ia|0)>-1){Va=c[(c[1271688]|0)+(Ia<<2)>>2]|0;if((Va|0)==0){break}Wa=c[(c[Va+4>>2]|0)+8>>2]|0;if((Wa|0)==0){break}Va=Wa+860|0;if((c[Va>>2]|0)==0){break}Ja=Wa+864|0;Wa=cEb((c[Ja>>2]|0)+1|0)|0;Qa=Ac+12|0;c[(c[(c[Qa>>2]|0)+8>>2]|0)+860>>2]=Wa;Wa=c[(c[(c[Qa>>2]|0)+8>>2]|0)+860>>2]|0;if((Wa|0)==0){Cc=-12;Dc=1;Za=267;break c}UGb(Wa|0,c[Va>>2]|0,c[Ja>>2]|0)|0;c[(c[(c[Qa>>2]|0)+8>>2]|0)+864>>2]=c[Ja>>2]}}while(0);Ia=Ac+328|0;if((BBb(c[Ia>>2]|0,2247256,0,0)|0)==0){CBb(Ia,2247256,2246232,0)|0}Ja=Ac+12|0;Ec=m0a(c[(c[Ja>>2]|0)+8>>2]|0,Fa,Ia)|0;if((Ec|0)<0){break}Qa=c[Ka>>2]|0;do{if((c[Qa+8>>2]|0)==1){if((c[Qa+16>>2]&65536|0)!=0){break}yj(c[c[Ac+300>>2]>>2]|0,c[(c[(c[Ja>>2]|0)+8>>2]|0)+424>>2]|0)}}while(0);Qa=BBb(c[Ia>>2]|0,9203128,0,2)|0;if((Qa|0)!=0){yDb(0,8,1926608,(_a=i,i=i+8|0,c[_a>>2]=c[Qa>>2],_a)|0);i=_a;yf(1)}Qa=c[(c[Ja>>2]|0)+8>>2]|0;Ka=c[Qa+72>>2]|0;if((Ka|0)!=0&(Ka|0)<1e3){yDb(0,24,2242184,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Fc=c[(c[Ja>>2]|0)+8>>2]|0}else{Fc=Qa}Qa=c[Fc+100>>2]|0;Ka=YGb(c[2004844]|0,c[2004845]|0,Qa,(Qa|0)<0|0?-1:0)|0;c[2004844]=Ka;c[2004845]=F;Bc=Ec}Ka=xc+1|0;if((Ka|0)<(c[1167936]|0)){xc=Ka;yc=Bc}else{zc=Bc;Za=214;break c}}if((Ec|0)==-733130664){yf(1)}Ka=c[Ac+4>>2]|0;Lb(za|0,1024,2245176,(_a=i,i=i+16|0,c[_a>>2]=c[Ac>>2],c[_a+8>>2]=Ka,_a)|0)|0;i=_a;Cc=Ec;Dc=1;Za=267;break}else if((Za|0)==51){yDb(0,0,1899624,(_a=i,i=i+24|0,c[_a>>2]=2288176,c[_a+8>>2]=1893768,c[_a+16>>2]=2335,_a)|0);i=_a;Cd();return 0}else if((Za|0)==116){Cd();return 0}else if((Za|0)==119){Ka=H0a(c[(c[(c[db>>2]|0)+8>>2]|0)+48>>2]|0)|0;Qa=c[bb>>2]|0;Fa=c[ab+4>>2]|0;Lb(za|0,1024,2269048,(_a=i,i=i+24|0,c[_a>>2]=Ka,c[_a+8>>2]=Qa,c[_a+16>>2]=Fa,_a)|0)|0;i=_a;Cc=-22;Dc=1;Za=267;break}else if((Za|0)==173){yDb(0,16,2256568,(_a=i,i=i+8|0,c[_a>>2]=(c[$b>>2]|0)+5,_a)|0);i=_a;$a=ac;break b}else if((Za|0)==197){yDb(0,0,1899624,(_a=i,i=i+24|0,c[_a>>2]=2214864,c[_a+8>>2]=1893768,c[_a+16>>2]=2233,_a)|0);i=_a;Cd();return 0}else if((Za|0)==201){Cd();return 0}}else{zc=Xa;Za=214}}while(0);h:do{if((Za|0)==214){i:do{if((c[1167940]|0)>0){Fa=na|0;Qa=0;j:while(1){Gc=c[(c[1271688]|0)+(Qa<<2)>>2]|0;do{if((c[Gc+12>>2]|0)!=0){Ka=c[Gc+16>>2]|0;if((Ka|0)==0){Za=243;break j}Hc=Gc+4|0;c[(c[(c[Hc>>2]|0)+8>>2]|0)+68>>2]=Gc;c[(c[(c[Hc>>2]|0)+8>>2]|0)+152>>2]=540;c[(c[(c[Hc>>2]|0)+8>>2]|0)+484>>2]=34;Va=c[(c[Hc>>2]|0)+8>>2]|0;c[Va+820>>2]=1;vEb(Va,2221192,1,0,0)|0;Va=Gc+104|0;if((BBb(c[Va>>2]|0,2247256,0,0)|0)==0){CBb(Va,2247256,2246232,0)|0}Jc=m0a(c[(c[Hc>>2]|0)+8>>2]|0,Ka,Va)|0;if((Jc|0)<0){Za=247;break j}Ka=BBb(c[Va>>2]|0,9203128,0,2)|0;if((Ka|0)==0){break}yDb(0,8,1926608,(_a=i,i=i+8|0,c[_a>>2]=c[Ka>>2],_a)|0);i=_a;yf(1)}}while(0);La=Gc+56|0;c[La>>2]=0;c[La+4>>2]=-2147483648;La=Gc+40|0;c[La>>2]=0;c[La+4>>2]=-2147483648;La=Qa+1|0;if((La|0)<(c[1167940]|0)){Qa=La}else{Kc=0;break i}}if((Za|0)==243){Qa=Gc+4|0;Ja=H0a(c[(c[(c[Qa>>2]|0)+8>>2]|0)+48>>2]|0)|0;Ia=c[Gc>>2]|0;La=c[c[Qa>>2]>>2]|0;Lb(za|0,1024,2221976,(_a=i,i=i+24|0,c[_a>>2]=Ja,c[_a+8>>2]=Ia,c[_a+16>>2]=La,_a)|0)|0;i=_a;Lc=-22}else if((Za|0)==247){if((Jc|0)==-733130664){yf(1)}La=c[Gc>>2]|0;Ia=c[c[Hc>>2]>>2]|0;TGb(Fa|0,0,64)|0;a[Fa]=0;GBb(Jc,Fa,64)|0;Lb(za|0,1024,2220472,(_a=i,i=i+24|0,c[_a>>2]=La,c[_a+8>>2]=Ia,c[_a+16>>2]=Fa,_a)|0)|0;i=_a;Lc=Jc}if((c[1167936]|0)>0){Mc=0}else{Cc=Lc;Dc=1;Za=267;break h}while(1){E0a(c[(c[(c[(c[1163658]|0)+(Mc<<2)>>2]|0)+12>>2]|0)+8>>2]|0)|0;Ia=Mc+1|0;if((Ia|0)<(c[1167936]|0)){Mc=Ia}else{Cc=Lc;Dc=1;Za=267;break h}}}else{Kc=zc}}while(0);Fa=c[1167942]|0;if((Fa|0)>0){Ia=c[1271690]|0;La=c[1271688]|0;Ja=0;do{Qa=c[Ia+(Ja<<2)>>2]|0;qb=c[Qa>>2]|0;Ka=c[qb+1104>>2]|0;if((Ka|0)!=0){Va=Qa+12|0;Qa=c[qb+1108>>2]|0;qb=0;do{Wa=c[Qa+(qb<<2)>>2]|0;Ua=c[Wa+16>>2]|0;Ta=Wa+12|0;Ha=0;while(1){if(!(Ha>>>0<Ua>>>0)){Oc=48;break}if((c[(c[La+((c[(c[Ta>>2]|0)+(Ha<<2)>>2]|0)+(c[Va>>2]|0)<<2)>>2]|0)+8>>2]|0)==0){Oc=0;break}else{Ha=Ha+1|0}}c[Wa+8>>2]=Oc;qb=qb+1|0;}while(qb>>>0<Ka>>>0)}Ja=Ja+1|0;}while((Ja|0)<(Fa|0))}if((c[1167938]|0)<=0){Pc=1;Qc=Kc;break}Fa=912112;Ja=c[Fa>>2]|0;La=c[Fa+4>>2]|0;Fa=1;Ia=0;while(1){Ka=(c[1163660]|0)+(Ia<<2)|0;qb=c[c[Ka>>2]>>2]|0;Va=qb+1160|0;c[Va>>2]=Ja;c[Va+4>>2]=La;Rc=FK(qb,(c[Ka>>2]|0)+4|0)|0;if((Rc|0)<0){break}Ka=(QGb(c[c[qb+8>>2]>>2]|0,2238328)|0)==0;qb=Ka?Fa:0;Ka=Ia+1|0;Va=c[1167938]|0;if((Ka|0)<(Va|0)){Fa=qb;Ia=Ka}else{Sc=Rc;Tc=qb;Uc=Va;Za=268;break h}}TGb(Ba|0,0,64)|0;a[Ba]=0;GBb(Rc,Ba,64)|0;Lb(za|0,1024,2239320,(_a=i,i=i+16|0,c[_a>>2]=Ia,c[_a+8>>2]=Ba,_a)|0)|0;i=_a;Cc=-22;Dc=Fa;Za=267}}while(0);if((Za|0)==267){Sc=Cc;Tc=Dc;Uc=c[1167938]|0;Za=268}do{if((Za|0)==268){if((Uc|0)>0){Vc=0}else{Pc=Tc;Qc=Sc;break}while(1){La=c[c[(c[1163660]|0)+(Vc<<2)>>2]>>2]|0;QT(La,Vc,La+32|0,1);La=Vc+1|0;if((La|0)<(c[1167938]|0)){Vc=La}else{Pc=Tc;Qc=Sc;break}}}}while(0);yDb(0,32,2237616,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Fa=c[1167940]|0;if((Fa|0)>0){Ia=0;La=Fa;while(1){Fa=c[(c[1271688]|0)+(Ia<<2)>>2]|0;Ja=Fa+248|0;Va=c[Ja>>2]|0;if((Va|0)>0){qb=Fa+244|0;Ka=Fa|0;Qa=Fa+4|0;Ha=Fa+16|0;Fa=0;Ta=Va;while(1){Va=c[(c[qb>>2]|0)+(Fa<<2)>>2]|0;if((c[(c[Va+8>>2]|0)+4>>2]|0)==0){Wc=Ta}else{Ua=c[c[Qa>>2]>>2]|0;Ga=c[Ha>>2]|0;if((Ga|0)==0){Zc=2236e3}else{Zc=c[Ga>>2]|0}Ga=c[Va+12>>2]|0;yDb(0,32,2236640,(_a=i,i=i+32|0,c[_a>>2]=c[Ka>>2],c[_a+8>>2]=Ua,c[_a+16>>2]=Zc,c[_a+24>>2]=Ga,_a)|0);i=_a;if((c[1167948]|0)>1){yDb(0,32,2235248,(_a=i,i=i+8|0,c[_a>>2]=c[c[(c[(c[qb>>2]|0)+(Fa<<2)>>2]|0)+8>>2]>>2],_a)|0);i=_a}yDb(0,32,1905240,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Wc=c[Ja>>2]|0}Ga=Fa+1|0;if((Ga|0)<(Wc|0)){Fa=Ga;Ta=Wc}else{break}}_c=c[1167940]|0}else{_c=La}Ta=Ia+1|0;if((Ta|0)<(_c|0)){Ia=Ta;La=_c}else{break}}}if((c[1167936]|0)>0){La=0;do{Ia=c[(c[1163658]|0)+(La<<2)>>2]|0;Ta=c[Ia+356>>2]|0;k:do{if((Ta|0)==0){Fa=Ia+300|0;Ja=c[Fa>>2]|0;do{if((Ja|0)!=0){if((c[(c[Ja+8>>2]|0)+4>>2]|0)==0){break}yDb(0,32,2233536,(_a=i,i=i+8|0,c[_a>>2]=c[Ja+12>>2],_a)|0);i=_a;if((c[1167948]|0)>1){yDb(0,32,2235248,(_a=i,i=i+8|0,c[_a>>2]=c[c[(c[Fa>>2]|0)+8>>2]>>2],_a)|0);i=_a}qb=c[Ia+4>>2]|0;Ka=c[Ia+60>>2]|0;if((Ka|0)==0){$c=2236e3}else{$c=c[Ka>>2]|0}yDb(0,32,2232768,(_a=i,i=i+24|0,c[_a>>2]=c[Ia>>2],c[_a+8>>2]=qb,c[_a+16>>2]=$c,_a)|0);i=_a;break k}}while(0);Fa=Ia+8|0;Ja=c[(c[1271688]|0)+(c[Fa>>2]<<2)>>2]|0;qb=c[c[Ja+4>>2]>>2]|0;Ka=c[Ia>>2]|0;Ha=c[Ia+4>>2]|0;yDb(0,32,2229760,(_a=i,i=i+32|0,c[_a>>2]=c[Ja>>2],c[_a+8>>2]=qb,c[_a+16>>2]=Ka,c[_a+24>>2]=Ha,_a)|0);i=_a;Ha=c[Ia+24>>2]|0;if((Ha|0)!=(c[(c[1271688]|0)+(c[Fa>>2]<<2)>>2]|0)){Ka=c[c[Ha+4>>2]>>2]|0;yDb(0,32,2227352,(_a=i,i=i+16|0,c[_a>>2]=c[Ha>>2],c[_a+8>>2]=Ka,_a)|0);i=_a}if((c[Ia+352>>2]|0)==0){Ka=c[(c[(c[1271688]|0)+(c[Fa>>2]<<2)>>2]|0)+16>>2]|0;if((Ka|0)==0){ad=2236e3}else{ad=c[Ka>>2]|0}Ka=c[Ia+60>>2]|0;if((Ka|0)==0){bd=2236e3}else{bd=c[Ka>>2]|0}yDb(0,32,2225080,(_a=i,i=i+16|0,c[_a>>2]=ad,c[_a+8>>2]=bd,_a)|0);i=_a}else{yDb(0,32,2226016,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a}yDb(0,32,1905240,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a}else{Ka=c[Ia>>2]|0;Fa=c[Ia+4>>2]|0;yDb(0,32,2234432,(_a=i,i=i+24|0,c[_a>>2]=Ta,c[_a+8>>2]=Ka,c[_a+16>>2]=Fa,_a)|0);i=_a}}while(0);La=La+1|0;}while((La|0)<(c[1167936]|0))}if((Qc|0)!=0){yDb(0,16,2224e3,(_a=i,i=i+8|0,c[_a>>2]=za,_a)|0);i=_a;$a=Qc;break}if((Pc|0)==0){$a=0;break}La=oa|0;Ta=pa;Ia=WDb(c[1167938]<<2)|0;c[pa>>2]=Ia;if((Ia|0)==0){yf(1)}Ia=c[1167938]|0;if((Ia|0)>0){Fa=0;do{c[(c[pa>>2]|0)+(Fa<<2)>>2]=c[c[(c[1163660]|0)+(Fa<<2)>>2]>>2];Fa=Fa+1|0;}while((Fa|0)<(Ia|0))}$P(c[pa>>2]|0,Ia,La,16384)|0;Ic(2223032,(_a=i,i=i+8|0,c[_a>>2]=La,_a)|0)|0;i=_a;ib(c[o>>2]|0)|0;$Db(Ta);$a=0}}while(0);do{if(($a|0)<0){cd=$a}else{if((c[107880]|0)!=0){yDb(0,32,2264872,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a}pa=WFb()|0;oa=F;l:do{if((c[1149826]|0)==0){Pc=Y|0;Qc=Y+4|0;za=X|0;bd=X+4|0;ad=n|0;$c=r|0;_c=s|0;Wc=t|0;Zc=u|0;Sc=v|0;Tc=w|0;Vc=x|0;Uc=y|0;Dc=z|0;Cc=R|0;Ba=S|0;Rc=T|0;Kc=U|0;Oc=V|0;zc=W|0;Lc=na|0;Mc=l|0;Jc=l+4|0;Hc=m+32|0;Gc=A|0;Xa=A+4|0;ac=B|0;$b=B+4|0;ab=C|0;bb=C+4|0;db=m+16|0;Ec=m+8|0;Ac=K|0;Bc=K+4|0;yc=N|0;xc=N+4|0;Fc=L|0;Pb=L+4|0;wc=M|0;Ub=M+4|0;Aa=O|0;vc=O+4|0;xa=H|0;ya=H+4|0;uc=I|0;tc=I+4|0;sc=J|0;lc=J+4|0;mc=G|0;nc=G+4|0;cc=D|0;ma=D+4|0;ic=k|0;hc=m+64|0;la=j|0;jc=j+4|0;kc=fa|0;ec=ha|0;dc=ia|0;bc=ea;hb=ea|0;_b=da|0;Yb=da+4|0;Zb=c[p>>2]|0;wa=$;va=$|0;Ea=_|0;ua=_+4|0;m:while(1){Xb=WFb()|0;Wb=F;n:do{if((c[107880]|0)!=0){if((c[1149828]|0)!=0){break l}Tb=ZGb(Xb,Wb,c[2202842]|0,c[2202843]|0)|0;cb=F;ta=0;if((cb|0)<(ta|0)|(cb|0)==(ta|0)&Tb>>>0<1e5>>>0|a[545816]){break}TGb(bc|0,0,128)|0;c[hb>>2]=1;c[_b>>2]=0;c[Yb>>2]=0;if((Nc(1,ea|0,0,0,da|0)|0)<=0){c[2202842]=Xb;c[2202843]=Wb;break}Tb=wb(0,ca|0,1)|0;if((Tb|0)==1){dd=d[ca]|0}else{dd=Tb}c[2202842]=Xb;c[2202843]=Wb;switch(dd|0){case 115:{c[1150452]=c[1150452]^1;break n;break};case 104:{do{if((c[2128646]|0)==0){if((c[2128644]|0)==0){c[2128644]=1;break}else{c[2128646]=1;break}}else{c[2128644]=0;c[2128646]=0}}while(0);ADb(48);break};case 113:{break l;break};case 43:{ADb((zDb()|0)+10|0);break n;break};case 45:{ADb((zDb()|0)-10|0);break n;break};default:{}}Wa=(dd|0)==99;o:do{if((dd|0)==99|(dd|0)==67){TGb(dc|0,0,256)|0;nb(2310976,62,1,Zb|0)|0;Tb=0;p:while(1){while(1){TGb(wa|0,0,128)|0;c[va>>2]=1;c[Ea>>2]=0;c[ua>>2]=0;if((Nc(1,$|0,0,0,_|0)|0)<=0){continue}ta=wb(0,Z|0,1)|0;if((ta|0)==1){ed=d[Z]|0}else{ed=ta}if((ed|0)==10|(ed|0)==13){fd=Tb;Za=348;break p}if((ed|0)>0){break}}gd=Tb+1|0;a[fa+Tb|0]=ed;if(gd>>>0<4095>>>0){Tb=gd}else{Za=337;break}}do{if((Za|0)==337){Za=0;TGb(wa|0,0,128)|0;c[va>>2]=1;c[Ea>>2]=0;c[ua>>2]=0;if((Nc(1,$|0,0,0,_|0)|0)<=0){a[fa+gd|0]=0;hd=0;break}Tb=wb(0,Z|0,1)|0;if((Tb|0)==1){id=d[Z]|0}else{id=Tb}if((id|0)==10|(id|0)==13){fd=gd;Za=348;break}a[fa+gd|0]=0;if((id|0)>0){Za=350}else{hd=0}}}while(0);if((Za|0)==348){Za=0;a[fa+fd|0]=0;Za=350}do{if((Za|0)==350){Za=0;Tb=xd(kc|0,2306416,(_a=i,i=i+32|0,c[_a>>2]=Lc,c[_a+8>>2]=ja,c[_a+16>>2]=ec,c[_a+24>>2]=dc,_a)|0)|0;i=_a;if((Tb|0)<=2){hd=Tb;break}Db=+h[ja>>3];yDb(0,48,2302272,(_a=i,i=i+32|0,c[_a>>2]=Lc,h[_a+8>>3]=Db,c[_a+16>>2]=ec,c[_a+24>>2]=dc,_a)|0);i=_a;if((c[1167948]|0)<=0){break o}Tb=Wa&1;if(Wa){gb=0;while(1){kb=c[(c[(c[1305380]|0)+(gb<<2)>>2]|0)+8>>2]|0;do{if((kb|0)!=0){if(+h[ja>>3]<0.0){zb=pj(kb,Lc,ec,dc,kc,4096,Tb)|0;Dd(Zb|0,2300744,(_a=i,i=i+24|0,c[_a>>2]=gb,c[_a+8>>2]=zb,c[_a+16>>2]=kc,_a)|0)|0;i=_a;break}else{nb(2299288,79,1,Zb|0)|0;break}}}while(0);gb=gb+1|0;if((gb|0)>=(c[1167948]|0)){break o}}}else{gb=0;while(1){kb=c[(c[(c[1305380]|0)+(gb<<2)>>2]|0)+8>>2]|0;do{if((kb|0)!=0){Db=+h[ja>>3];if(Db<0.0){zb=pj(kb,Lc,ec,dc,kc,4096,Tb)|0;Dd(Zb|0,2300744,(_a=i,i=i+24|0,c[_a>>2]=gb,c[_a+8>>2]=zb,c[_a+16>>2]=kc,_a)|0)|0;i=_a;break}else{qj(kb,Lc,ec,dc,0,Db)|0;break}}}while(0);gb=gb+1|0;if((gb|0)>=(c[1167948]|0)){break o}}}}}while(0);yDb(0,16,2297720,(_a=i,i=i+16|0,c[_a>>2]=hd,c[_a+8>>2]=kc,_a)|0);i=_a}}while(0);Wa=(dd|0)==68;if((dd|0)==100|(dd|0)==68){c[ka>>2]=0;do{if(Wa){gb=c[(c[(c[(c[c[1271688]>>2]|0)+4>>2]|0)+8>>2]|0)+688>>2]<<1;if((gb|0)==0){c[ka>>2]=1;break}c[ka>>2]=gb;if((gb&24640|0)==0){break}else{jd=gb}do{jd=jd<<1;}while((jd&24640|0)!=0);c[ka>>2]=jd}else{gb=Xc(2296400,(_a=i,i=i+8|0,c[_a>>2]=ka,_a)|0)|0;i=_a;if((gb|0)==1){break}nb(2295064,26,1,Zb|0)|0}}while(0);if((c[1167940]|0)>0){Wa=c[1271688]|0;gb=0;do{c[(c[(c[(c[Wa+(gb<<2)>>2]|0)+4>>2]|0)+8>>2]|0)+688>>2]=c[ka>>2];gb=gb+1|0;}while((gb|0)<(c[1167940]|0))}if((c[1167936]|0)>0){gb=c[1163658]|0;Wa=0;do{c[(c[(c[(c[gb+(Wa<<2)>>2]|0)+12>>2]|0)+8>>2]|0)+688>>2]=c[ka>>2];Wa=Wa+1|0;}while((Wa|0)<(c[1167936]|0))}if((c[ka>>2]|0)==0){kd=0}else{ADb(48);kd=c[ka>>2]|0}Dd(Zb|0,2294008,(_a=i,i=i+8|0,c[_a>>2]=kd,_a)|0)|0;i=_a;if((dd|0)!=63){break}}else if((dd|0)!=63){break}nb(2292528,337,1,Zb|0)|0}}while(0);if((c[1167936]|0)>0){nd=0}else{Za=394;break}q:while(1){Wa=c[(c[1163658]|0)+(nd<<2)>>2]|0;gb=c[(c[1163660]|0)+(c[Wa>>2]<<2)>>2]|0;Tb=gb|0;do{if((c[Wa+344>>2]|0)==0){kb=c[(c[Tb>>2]|0)+16>>2]|0;if((kb|0)!=0){zb=Ty(kb,0,0,1)|0;kb=F;ta=gb+32|0;cb=c[ta+4>>2]|0;if(!(kb>>>0<cb>>>0|kb>>>0==cb>>>0&zb>>>0<(c[ta>>2]|0)>>>0)){break}}ta=c[Wa+20>>2]|0;zb=(ta|0)<0|0?-1:0;cb=Wa+64|0;kb=c[cb+4>>2]|0;if((zb|0)<(kb|0)|(zb|0)==(kb|0)&ta>>>0<(c[cb>>2]|0)>>>0){break q}if((c[(c[Tb>>2]|0)+24>>2]|0)==0){break}cb=gb+8|0;ta=0;do{kb=c[(c[1163658]|0)+((c[cb>>2]|0)+ta<<2)>>2]|0;zb=c[(c[1163660]|0)+(c[kb>>2]<<2)>>2]|0;Da=kb+344|0;c[Da>>2]=c[Da>>2]|1;if((c[zb+40>>2]|0)!=0){Da=kb+32|0;Rb=kb+40|0;Sb=ZGb(c[Da>>2]|0,c[Da+4>>2]|0,c[Rb>>2]|0,c[Rb+4>>2]|0)|0;Rb=(c[(c[kb+12>>2]|0)+8>>2]|0)+104|0;c[Pc>>2]=1;c[Qc>>2]=1e6;kb=KDb(Sb,F,Rb,Y)|0;Rb=F;Sb=zb+16|0;zb=c[Sb>>2]|0;Da=c[Sb+4>>2]|0;sa=(Da|0)>(Rb|0)|(Da|0)==(Rb|0)&zb>>>0>kb>>>0;c[Sb>>2]=sa?kb:zb;c[Sb+4>>2]=sa?Rb:Da}ta=ta+1|0;}while(ta>>>0<(c[(c[Tb>>2]|0)+24>>2]|0)>>>0)}}while(0);Tb=nd+1|0;if((Tb|0)<(c[1167936]|0)){nd=Tb}else{Za=394;break m}}Tb=c[1167936]|0;r:do{if((Tb|0)>0){gb=0;Wa=2147483647;ta=-1;cb=0;while(1){Da=c[(c[1163658]|0)+(cb<<2)>>2]|0;Rb=c[Da+12>>2]|0;sa=Rb+208|0;Sb=c[sa>>2]|0;zb=c[sa+4>>2]|0;c[za>>2]=1;c[bd>>2]=1e6;sa=KDb(Sb,zb,Rb+40|0,X)|0;Rb=F;if((c[Da+348>>2]|0)==0){zb=(c[Da+344>>2]|0)==0&((Rb|0)<(Wa|0)|(Rb|0)==(Wa|0)&sa>>>0<ta>>>0);od=zb?Rb:Wa;pd=zb?sa:ta;qd=zb?Da:gb}else{od=Wa;pd=ta;qd=gb}Da=cb+1|0;rd=c[1167936]|0;if((Da|0)<(rd|0)){gb=qd;Wa=od;ta=pd;cb=Da}else{break}}if((qd|0)==0){sd=rd;Za=400;break}cb=c[qd+300>>2]|0;s:do{if((cb|0)==0){ta=c[qd+8>>2]|0;if(!((ta|0)>-1)){Za=432;break m}td=c[(c[1271688]|0)+(ta<<2)>>2]|0;Za=434}else{ta=c[cb+8>>2]|0;Wa=sj(c[ta+8>>2]|0)|0;t:do{if((Wa|0)>-1){ud=Oh()|0}else{if((Wa|0)==(-541478725|0)){gb=Oh()|0;Da=ta+28|0;if((c[Da>>2]|0)<=0){ud=gb;break}zb=ta+24|0;sa=0;while(1){Rb=c[(c[(c[zb>>2]|0)+(sa<<2)>>2]|0)+4>>2]|0;Sb=c[(c[1163660]|0)+(c[Rb>>2]<<2)>>2]|0;kb=Rb+344|0;c[kb>>2]=c[kb>>2]|1;if((c[Sb+40>>2]|0)!=0){kb=Rb+32|0;ra=Rb+40|0;Ca=ZGb(c[kb>>2]|0,c[kb+4>>2]|0,c[ra>>2]|0,c[ra+4>>2]|0)|0;ra=(c[(c[Rb+12>>2]|0)+8>>2]|0)+104|0;c[la>>2]=1;c[jc>>2]=1e6;Rb=KDb(Ca,F,ra,j)|0;ra=F;Ca=Sb+16|0;Sb=c[Ca>>2]|0;kb=c[Ca+4>>2]|0;Qb=(kb|0)>(ra|0)|(kb|0)==(ra|0)&Sb>>>0>Rb>>>0;c[Ca>>2]=Qb?Rb:Sb;c[Ca+4>>2]=Qb?ra:kb}kb=sa+1|0;if((kb|0)<(c[Da>>2]|0)){sa=kb}else{ud=gb;break t}}}else if((Wa|0)!=(-11|0)){vd=Wa;break s}gb=ta+20|0;sa=c[gb>>2]|0;if((sa|0)>0){Da=ta+16|0;zb=0;kb=0;ra=0;Qb=sa;while(1){sa=c[(c[Da>>2]|0)+(kb<<2)>>2]|0;Ca=c[sa+4>>2]|0;Sb=c[(c[1271690]|0)+(c[Ca>>2]<<2)>>2]|0;do{if((c[Sb+8>>2]|0)==0){if((c[Sb+4>>2]|0)!=0){wd=zb;yd=ra;zd=Qb;break}Rb=Lj(c[sa>>2]|0)|0;Jb=(Rb|0)>(zb|0);wd=Jb?Rb:zb;yd=Jb?Ca:ra;zd=c[gb>>2]|0}else{wd=zb;yd=ra;zd=Qb}}while(0);Ca=kb+1|0;if((Ca|0)<(zd|0)){zb=wd;kb=Ca;ra=yd;Qb=zd}else{break}}if((yd|0)!=0){td=yd;Za=434;break s}}Qb=ta+28|0;if((c[Qb>>2]|0)<=0){Za=611;break r}ra=c[ta+24>>2]|0;kb=0;while(1){c[(c[(c[ra+(kb<<2)>>2]|0)+4>>2]|0)+348>>2]=1;zb=kb+1|0;if((zb|0)<(c[Qb>>2]|0)){kb=zb}else{Za=611;break r}}}}while(0);Ad=(ud|0)<0?ud:0;Za=608}}while(0);do{if((Za|0)==434){Za=0;cb=td|0;ta=c[cb>>2]|0;Wa=c[(c[1271690]|0)+(ta<<2)>>2]|0;kb=Wa|0;Qb=c[kb>>2]|0;u:do{if((c[Wa+64>>2]|0)==0){Bd=Qb;Za=439}else{ra=Wa+56|0;zb=Wa+12|0;gb=0;while(1){if((gb|0)>=(c[ra>>2]|0)){break}Da=c[(c[1271688]|0)+((c[zb>>2]|0)+gb<<2)>>2]|0;Ca=Da+48|0;sa=IDb(c[Ca>>2]|0,c[Ca+4>>2]|0,1e6,0,1e6,0)|0;Ca=F;Sb=WFb()|0;Jb=Da+32|0;Da=ZGb(Sb,F,c[Jb>>2]|0,c[Jb+4>>2]|0)|0;Jb=F;if((Ca|0)>(Jb|0)|(Ca|0)==(Jb|0)&sa>>>0>Da>>>0){Za=440;break u}else{gb=gb+1|0}}Bd=c[kb>>2]|0;Za=439}}while(0);v:do{if((Za|0)==439){Za=0;kb=gT(Bd,m)|0;if((kb|0)==-11){Za=440;break}if((kb|0)<0){do{if(!((kb|0)==-541478725)){Sf(Qb+32|0,kb);if((c[2039022]|0)==0){break}yf(1)}}while(0);c[Wa+4>>2]=1;kb=Wa+56|0;if((c[kb>>2]|0)<=0){Ed=-11;break}gb=Wa+12|0;zb=0;while(1){ra=c[(c[1271688]|0)+((c[gb>>2]|0)+zb<<2)>>2]|0;if((c[ra+12>>2]|0)!=0){Jh(ra,0)|0}if((c[1167936]|0)>0){ra=0;do{Da=c[(c[1163658]|0)+(ra<<2)>>2]|0;do{if((c[Da+8>>2]|0)==((c[gb>>2]|0)+zb|0)){if((c[Da+352>>2]|0)==0){if((c[(c[Da+60>>2]|0)+8>>2]|0)!=3){break}}sa=c[(c[1163660]|0)+(c[Da>>2]<<2)>>2]|0;Jb=Da+344|0;c[Jb>>2]=c[Jb>>2]|1;if((c[sa+40>>2]|0)==0){break}Jb=Da+32|0;Ca=Da+40|0;Sb=ZGb(c[Jb>>2]|0,c[Jb+4>>2]|0,c[Ca>>2]|0,c[Ca+4>>2]|0)|0;Ca=(c[(c[Da+12>>2]|0)+8>>2]|0)+104|0;c[Mc>>2]=1;c[Jc>>2]=1e6;Jb=KDb(Sb,F,Ca,l)|0;Ca=F;Sb=sa+16|0;sa=c[Sb>>2]|0;Rb=c[Sb+4>>2]|0;Ib=(Rb|0)>(Ca|0)|(Rb|0)==(Ca|0)&sa>>>0>Jb>>>0;c[Sb>>2]=Ib?Jb:sa;c[Sb+4>>2]=Ib?Ca:Rb}}while(0);ra=ra+1|0;}while((ra|0)<(c[1167936]|0))}ra=zb+1|0;if((ra|0)<(c[kb>>2]|0)){zb=ra}else{Ed=-11;break v}}}if((c[1167942]|0)>0){zb=c[1271690]|0;kb=0;do{c[(c[zb+(kb<<2)>>2]|0)+8>>2]=0;kb=kb+1|0;}while((kb|0)<(c[1167942]|0))}if((c[1167936]|0)>0){kb=c[1163658]|0;zb=0;do{c[(c[kb+(zb<<2)>>2]|0)+348>>2]=0;zb=zb+1|0;}while((zb|0)<(c[1167936]|0))}if((c[2128644]|0)!=0){XT(0,48,m,c[2128646]|0,c[(c[Qb+28>>2]|0)+(c[Hc>>2]<<2)>>2]|0)}zb=c[Hc>>2]|0;do{if((zb|0)<(c[Wa+56>>2]|0)){kb=Wa+12|0;gb=(c[kb>>2]|0)+zb|0;ra=c[(c[1271688]|0)+(gb<<2)>>2]|0;if((c[ra+8>>2]|0)!=0){break}if((c[2163098]|0)!=0){Da=ra+4|0;Rb=lGb(c[(c[(c[Da>>2]|0)+8>>2]|0)+8>>2]|0)|0;TGb(ad|0,0,32)|0;a[ad]=0;Ca=ra+40|0;Ib=c[Ca>>2]|0;Sb=c[Ca+4>>2]|0;if((Ib|0)==0&(Sb|0)==(-2147483648|0)){Lb(ad|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(ad|0,32,2070656,(_a=i,i=i+16|0,c[_a>>2]=Ib,c[_a+8>>2]=Sb,_a)|0)|0;i=_a}TGb($c|0,0,32)|0;a[$c]=0;Sb=c[Ca>>2]|0;Ib=c[Ca+4>>2]|0;if((Sb|0)==0&(Ib|0)==(-2147483648|0)){Lb($c|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb($c|0,32,2075240,(_a=i,i=i+8|0,h[_a>>3]=(+(Sb>>>0)+ +(Ib|0)*4294967296.0)*1.0e-6,_a)|0)|0;i=_a}TGb(_c|0,0,32)|0;a[_c]=0;Ib=ra+56|0;Sb=c[Ib>>2]|0;Ca=c[Ib+4>>2]|0;if((Sb|0)==0&(Ca|0)==(-2147483648|0)){Lb(_c|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(_c|0,32,2070656,(_a=i,i=i+16|0,c[_a>>2]=Sb,c[_a+8>>2]=Ca,_a)|0)|0;i=_a}TGb(Wc|0,0,32)|0;a[Wc]=0;Ca=c[Ib>>2]|0;Sb=c[Ib+4>>2]|0;if((Ca|0)==0&(Sb|0)==(-2147483648|0)){Lb(Wc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Wc|0,32,2075240,(_a=i,i=i+8|0,h[_a>>3]=(+(Ca>>>0)+ +(Sb|0)*4294967296.0)*1.0e-6,_a)|0)|0;i=_a}TGb(Zc|0,0,32)|0;a[Zc]=0;Sb=c[Ec>>2]|0;Ca=c[Ec+4>>2]|0;if((Sb|0)==0&(Ca|0)==(-2147483648|0)){Lb(Zc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Zc|0,32,2070656,(_a=i,i=i+16|0,c[_a>>2]=Sb,c[_a+8>>2]=Ca,_a)|0)|0;i=_a}TGb(Sc|0,0,32)|0;a[Sc]=0;Ca=c[Ec>>2]|0;Sb=c[Ec+4>>2]|0;Ib=c[Da>>2]|0;if((Ca|0)==0&(Sb|0)==(-2147483648|0)){Lb(Sc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Sc|0,32,2075240,(_a=i,i=i+8|0,h[_a>>3]=(+(Ca>>>0)+ +(Sb|0)*4294967296.0)*(+(c[Ib+40>>2]|0)/+(c[Ib+44>>2]|0)),_a)|0)|0;i=_a}TGb(Tc|0,0,32)|0;a[Tc]=0;Ib=c[db>>2]|0;Sb=c[db+4>>2]|0;if((Ib|0)==0&(Sb|0)==(-2147483648|0)){Lb(Tc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Tc|0,32,2070656,(_a=i,i=i+16|0,c[_a>>2]=Ib,c[_a+8>>2]=Sb,_a)|0)|0;i=_a}TGb(Vc|0,0,32)|0;a[Vc]=0;Sb=c[db>>2]|0;Ib=c[db+4>>2]|0;Ca=c[Da>>2]|0;if((Sb|0)==0&(Ib|0)==(-2147483648|0)){Lb(Vc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Vc|0,32,2075240,(_a=i,i=i+8|0,h[_a>>3]=(+(Sb>>>0)+ +(Ib|0)*4294967296.0)*(+(c[Ca+40>>2]|0)/+(c[Ca+44>>2]|0)),_a)|0)|0;i=_a}TGb(Uc|0,0,32)|0;a[Uc]=0;Ca=ra|0;Ib=(c[(c[1271690]|0)+(c[Ca>>2]<<2)>>2]|0)+24|0;Sb=c[Ib>>2]|0;Da=c[Ib+4>>2]|0;if((Sb|0)==0&(Da|0)==(-2147483648|0)){Lb(Uc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Uc|0,32,2070656,(_a=i,i=i+16|0,c[_a>>2]=Sb,c[_a+8>>2]=Da,_a)|0)|0;i=_a}TGb(Dc|0,0,32)|0;a[Dc]=0;Da=(c[(c[1271690]|0)+(c[Ca>>2]<<2)>>2]|0)+24|0;Ca=c[Da>>2]|0;Sb=c[Da+4>>2]|0;if((Ca|0)==0&(Sb|0)==(-2147483648|0)){Lb(Dc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Dc|0,32,2075240,(_a=i,i=i+8|0,h[_a>>3]=(+(Ca>>>0)+ +(Sb|0)*4294967296.0)*1.0e-6,_a)|0)|0;i=_a}yDb(0,32,2330784,(_a=i,i=i+96|0,c[_a>>2]=gb,c[_a+8>>2]=Rb,c[_a+16>>2]=ad,c[_a+24>>2]=$c,c[_a+32>>2]=_c,c[_a+40>>2]=Wc,c[_a+48>>2]=Zc,c[_a+56>>2]=Sc,c[_a+64>>2]=Tc,c[_a+72>>2]=Vc,c[_a+80>>2]=Uc,c[_a+88>>2]=Dc,_a)|0);i=_a}Rb=ra+72|0;do{if((c[Rb>>2]|0)==0){gb=Qb+1056|0;Sb=c[gb>>2]|0;Ca=c[gb+4>>2]|0;if((Sb|0)==0&(Ca|0)==(-2147483648|0)){break}Da=ra+4|0;if((c[(c[Da>>2]|0)+188>>2]|0)>=64){break}Ib=ra+40|0;do{if((c[Ib>>2]|0)==0&(c[Ib+4>>2]|0)==(-2147483648|0)){sa=Wa+24|0;Jb=c[sa>>2]|0;Mb=c[sa+4>>2]|0;Kb=ZGb(0,0,Sb,Ca)|0;if(!((Jb|0)==(Kb|0)&(Mb|0)==(F|0))){Fd=Ca;Gd=Sb;break}if((c[(c[Qb+4>>2]|0)+8>>2]&512|0)==0){Fd=Ca;Gd=Sb;break}Mb=Qb+24|0;if((c[Mb>>2]|0)==0){Hd=2147483647;Id=-1;Jd=Ca;Kd=Sb}else{Kb=Qb+28|0;Jb=2147483647;Nb=-1;Ob=0;while(1){Hb=c[(c[Kb>>2]|0)+(Ob<<2)>>2]|0;do{if((c[Hb+76>>2]|0)==48){Ld=Jb;Md=Nb}else{Gb=Hb+48|0;Bb=c[Gb>>2]|0;Eb=c[Gb+4>>2]|0;if((Bb|0)==0&(Eb|0)==(-2147483648|0)){Ld=Jb;Md=Nb;break}Fb=Hb+40|0;c[Gc>>2]=1;c[Xa>>2]=1e6;qa=KDb(Bb,Eb,Fb,A)|0;Eb=F;if(!((Jb|0)>(Eb|0)|(Jb|0)==(Eb|0)&Nb>>>0>qa>>>0)){Ld=Jb;Md=Nb;break}qa=c[Gb>>2]|0;Eb=c[Gb+4>>2]|0;c[ac>>2]=1;c[$b>>2]=1e6;Gb=KDb(qa,Eb,Fb,B)|0;Ld=F;Md=Gb}}while(0);Hb=Ob+1|0;if(Hb>>>0<(c[Mb>>2]|0)>>>0){Jb=Ld;Nb=Md;Ob=Hb}else{break}}Hd=Ld;Id=Md;Jd=c[gb+4>>2]|0;Kd=c[gb>>2]|0}if(!((Hd|0)>(Jd|0)|(Hd|0)==(Jd|0)&Id>>>0>Kd>>>0)){Fd=Jd;Gd=Kd;break}Ob=ZGb(Id,Hd,Kd,Jd)|0;Nb=F;yDb(Qb,40,2325800,(_a=i,i=i+16|0,c[_a>>2]=Ob,c[_a+8>>2]=Nb,_a)|0);i=_a;Nb=ZGb(0,0,Id,Hd)|0;c[sa>>2]=Nb;c[sa+4>>2]=F;Fd=c[gb+4>>2]|0;Gd=c[gb>>2]|0}else{Fd=Ca;Gd=Sb}}while(0);c[ab>>2]=1;c[bb>>2]=1e6;Sb=KDb(Gd,Fd,C,(c[Da>>2]|0)+40|0)|0;Ca=F;gb=(c[Da>>2]|0)+188|0;Ib=_Gb(1,0,c[gb>>2]|0)|0;Nb=YGb(Ib,F,Sb,Ca)|0;Ib=F;c[Rb>>2]=1;if(!((Ib|0)>(Ca|0)|(Ib|0)==(Ca|0)&Nb>>>0>Sb>>>0)){break}Nb=c[db>>2]|0;Ib=c[db+4>>2]|0;do{if(!((Nb|0)==0&(Ib|0)==(-2147483648|0))){Ob=c[gb>>2]|0;Jb=_Gb(1,0,Ob-1|0)|0;Mb=YGb(Jb,F,Sb,Ca)|0;Jb=F;if(!((Ib|0)>(Jb|0)|(Ib|0)==(Jb|0)&Nb>>>0>Mb>>>0)){break}Mb=_Gb(1,0,Ob|0)|0;Ob=ZGb(Nb,Ib,Mb,F)|0;c[db>>2]=Ob;c[db+4>>2]=F;c[Rb>>2]=0}}while(0);Ib=c[Ec>>2]|0;Nb=c[Ec+4>>2]|0;if((Ib|0)==0&(Nb|0)==(-2147483648|0)){break}Da=c[gb>>2]|0;Ob=_Gb(1,0,Da-1|0)|0;Mb=YGb(Ob,F,Sb,Ca)|0;Ob=F;if(!((Nb|0)>(Ob|0)|(Nb|0)==(Ob|0)&Ib>>>0>Mb>>>0)){break}Mb=_Gb(1,0,Da|0)|0;Da=ZGb(Ib,Nb,Mb,F)|0;c[Ec>>2]=Da;c[Ec+4>>2]=F;c[Rb>>2]=0}}while(0);if(!((c[db>>2]|0)==0&(c[db+4>>2]|0)==(-2147483648|0))){Rb=Wa+24|0;Da=c[Rb>>2]|0;Mb=c[Rb+4>>2]|0;c[cc>>2]=1;c[ma>>2]=1e6;Rb=KDb(Da,Mb,D,(c[ra+4>>2]|0)+40|0)|0;Mb=YGb(c[db>>2]|0,c[db+4>>2]|0,Rb,F)|0;c[db>>2]=Mb;c[db+4>>2]=F}do{if(!((c[Ec>>2]|0)==0&(c[Ec+4>>2]|0)==(-2147483648|0))){Mb=Wa+24|0;Rb=c[Mb>>2]|0;Da=c[Mb+4>>2]|0;c[mc>>2]=1;c[nc>>2]=1e6;Mb=KDb(Rb,Da,G,(c[ra+4>>2]|0)+40|0)|0;Da=YGb(c[Ec>>2]|0,c[Ec+4>>2]|0,Mb,F)|0;Mb=F;c[Ec>>2]=Da;c[Ec+4>>2]=Mb;if((Da|0)==0&(Mb|0)==(-2147483648|0)){break}Db=(+(Da>>>0)+ +(Mb|0)*4294967296.0)*+h[ra+88>>3];Mb=(E=+Db,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[Ec>>2]=~~+Db>>>0;c[Ec+4>>2]=Mb}}while(0);Mb=c[db>>2]|0;Da=c[db+4>>2]|0;do{if((Mb|0)==0&(Da|0)==(-2147483648|0)){Za=542}else{Db=(+(Mb>>>0)+ +(Da|0)*4294967296.0)*+h[ra+88>>3];Rb=~~+Db>>>0;Nb=(E=+Db,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[db>>2]=Rb;c[db+4>>2]=Nb;if((Rb|0)==0&(Nb|0)==(-2147483648|0)){Za=561;break}Ib=ra+40|0;if((c[Ib>>2]|0)!=0|(c[Ib+4>>2]|0)!=(-2147483648|0)|(c[2192648]|0)!=0){Za=542;break}if((c[(c[Qb+4>>2]|0)+8>>2]&512|0)==0){Za=542;break}Ib=Wa+32|0;if((c[Ib>>2]|0)==0&(c[Ib+4>>2]|0)==(-2147483648|0)){Za=542;break}Ob=ra+4|0;Jb=(c[Ob>>2]|0)+40|0;c[xa>>2]=1;c[ya>>2]=1e6;Kb=KDb(Rb,Nb,Jb,H)|0;Jb=ZGb(Kb,F,c[Ib>>2]|0,c[Ib+4>>2]|0)|0;Ib=F;Db=+(Jb>>>0)+ +(Ib|0)*4294967296.0;Ab=+g[337018];if(!(Db<Ab*-1.0*1.0e6)){if(!(Db>Ab*1.0e6)){Za=542;break}if((c[(c[(c[Ob>>2]|0)+8>>2]|0)+8>>2]|0)==3){Za=542;break}}Kb=Wa+24|0;Nb=ZGb(c[Kb>>2]|0,c[Kb+4>>2]|0,Jb,Ib)|0;Rb=F;c[Kb>>2]=Nb;c[Kb+4>>2]=Rb;yDb(0,48,2323800,(_a=i,i=i+32|0,c[_a>>2]=Jb,c[_a+8>>2]=Ib,c[_a+16>>2]=Nb,c[_a+24>>2]=Rb,_a)|0);i=_a;c[uc>>2]=1;c[tc>>2]=1e6;Rb=KDb(Jb,Ib,I,(c[Ob>>2]|0)+40|0)|0;Nb=ZGb(c[db>>2]|0,c[db+4>>2]|0,Rb,F)|0;Rb=F;c[db>>2]=Nb;c[db+4>>2]=Rb;if((c[Ec>>2]|0)==0&(c[Ec+4>>2]|0)==(-2147483648|0)){Nd=Rb;Od=Nb;Za=543;break}c[sc>>2]=1;c[lc>>2]=1e6;Nb=KDb(Jb,Ib,J,(c[Ob>>2]|0)+40|0)|0;Ob=ZGb(c[Ec>>2]|0,c[Ec+4>>2]|0,Nb,F)|0;c[Ec>>2]=Ob;c[Ec+4>>2]=F;Za=542}}while(0);if((Za|0)==542){Za=0;Nd=c[db+4>>2]|0;Od=c[db>>2]|0;Za=543}w:do{if((Za|0)==543){Za=0;if((Od|0)==0&(Nd|0)==(-2147483648|0)){Za=561;break}Da=ra+40|0;if((c[Da>>2]|0)==0&(c[Da+4>>2]|0)==(-2147483648|0)|(c[2192648]|0)!=0){Za=561;break}Mb=ra+4|0;Ob=(c[Mb>>2]|0)+40|0;c[Ac>>2]=1;c[Bc>>2]=1e6;Nb=KDb(Od,Nd,Ob,K)|0;Ob=F;Ib=c[Da>>2]|0;Jb=c[Da+4>>2]|0;Rb=ZGb(Nb,Ob,Ib,Jb)|0;Kb=F;Ab=+(Rb>>>0)+ +(Kb|0)*4294967296.0;if((c[(c[Qb+4>>2]|0)+8>>2]&512|0)!=0){Db=+g[337018];do{if(!(Ab<Db*-1.0*1.0e6)){if(Ab>Db*1.0e6){if((c[(c[(c[Mb>>2]|0)+8>>2]|0)+8>>2]|0)!=3){break}}Hb=YGb(Nb,Ob,1e5,0)|0;Gb=F;Fb=ra+64|0;Eb=c[Fb>>2]|0;qa=c[Fb+4>>2]|0;Fb=ra+48|0;Bb=c[Fb>>2]|0;jb=c[Fb+4>>2]|0;Fb=(qa|0)>(jb|0)|(qa|0)==(jb|0)&Eb>>>0>Bb>>>0;ob=Fb?qa:jb;if(!((Gb|0)<(ob|0)|(Gb|0)==(ob|0)&Hb>>>0<(Fb?Eb:Bb)>>>0)){Za=561;break w}}}while(0);Ob=Wa+24|0;Nb=ZGb(c[Ob>>2]|0,c[Ob+4>>2]|0,Rb,Kb)|0;Ca=F;c[Ob>>2]=Nb;c[Ob+4>>2]=Ca;yDb(0,48,2321592,(_a=i,i=i+32|0,c[_a>>2]=Rb,c[_a+8>>2]=Kb,c[_a+16>>2]=Nb,c[_a+24>>2]=Ca,_a)|0);i=_a;c[Fc>>2]=1;c[Pb>>2]=1e6;Ca=KDb(Rb,Kb,L,(c[Mb>>2]|0)+40|0)|0;Nb=ZGb(c[db>>2]|0,c[db+4>>2]|0,Ca,F)|0;Ca=F;c[db>>2]=Nb;c[db+4>>2]=Ca;if((c[Ec>>2]|0)==0&(c[Ec+4>>2]|0)==(-2147483648|0)){Pd=Ca;Qd=Nb;break}c[wc>>2]=1;c[Ub>>2]=1e6;Nb=KDb(Rb,Kb,M,(c[Mb>>2]|0)+40|0)|0;Ca=ZGb(c[Ec>>2]|0,c[Ec+4>>2]|0,Nb,F)|0;c[Ec>>2]=Ca;c[Ec+4>>2]=F;Za=561;break}Db=+g[337016];do{if(Ab<Db*-1.0*1.0e6){Za=555}else{if(!(Ab>Db*1.0e6)){break}if((c[(c[(c[Mb>>2]|0)+8>>2]|0)+8>>2]|0)!=3){Za=555}}}while(0);if((Za|0)==555){Za=0;Kb=c[db+4>>2]|0;Rb=c[Hc>>2]|0;yDb(0,24,232e4,(_a=i,i=i+40|0,c[_a>>2]=c[db>>2],c[_a+8>>2]=Kb,c[_a+16>>2]=Ib,c[_a+24>>2]=Jb,c[_a+32>>2]=Rb,_a)|0);i=_a;c[db>>2]=0;c[db+4>>2]=-2147483648}Rb=c[Ec>>2]|0;Kb=c[Ec+4>>2]|0;if((Rb|0)==0&(Kb|0)==(-2147483648|0)){Za=561;break}Ca=(c[Mb>>2]|0)+40|0;c[yc>>2]=1;c[xc>>2]=1e6;Nb=KDb(Rb,Kb,Ca,N)|0;Ca=c[Da>>2]|0;Kb=c[Da+4>>2]|0;Rb=ZGb(Nb,F,Ca,Kb)|0;Db=+(Rb>>>0)+ +(F|0)*4294967296.0;Ab=+g[337016];if(!(Db<Ab*-1.0*1.0e6)){if(!(Db>Ab*1.0e6)){Za=561;break}if((c[(c[(c[Mb>>2]|0)+8>>2]|0)+8>>2]|0)==3){Za=561;break}}Rb=c[Ec+4>>2]|0;Nb=c[Hc>>2]|0;yDb(0,24,2318400,(_a=i,i=i+40|0,c[_a>>2]=c[Ec>>2],c[_a+8>>2]=Rb,c[_a+16>>2]=Ca,c[_a+24>>2]=Kb,c[_a+32>>2]=Nb,_a)|0);i=_a;c[Ec>>2]=0;c[Ec+4>>2]=-2147483648;Za=561}}while(0);if((Za|0)==561){Za=0;Pd=c[db+4>>2]|0;Qd=c[db>>2]|0}if(!((Qd|0)==0&(Pd|0)==(-2147483648|0))){Nb=(c[ra+4>>2]|0)+40|0;c[Aa>>2]=1;c[vc>>2]=1e6;Kb=KDb(Qd,Pd,Nb,O)|0;Nb=Wa+32|0;c[Nb>>2]=Kb;c[Nb+4>>2]=F}if((c[2163098]|0)==0){Rd=ra|0}else{Nb=(c[Hc>>2]|0)+(c[kb>>2]|0)|0;Kb=ra+4|0;Ca=lGb(c[(c[(c[Kb>>2]|0)+8>>2]|0)+8>>2]|0)|0;TGb(Cc|0,0,32)|0;a[Cc]=0;Rb=c[Ec>>2]|0;Ob=c[Ec+4>>2]|0;if((Rb|0)==0&(Ob|0)==(-2147483648|0)){Lb(Cc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Cc|0,32,2070656,(_a=i,i=i+16|0,c[_a>>2]=Rb,c[_a+8>>2]=Ob,_a)|0)|0;i=_a}TGb(Ba|0,0,32)|0;a[Ba]=0;Ob=c[Ec>>2]|0;Rb=c[Ec+4>>2]|0;Sb=c[Kb>>2]|0;if((Ob|0)==0&(Rb|0)==(-2147483648|0)){Lb(Ba|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Ba|0,32,2075240,(_a=i,i=i+8|0,h[_a>>3]=(+(Ob>>>0)+ +(Rb|0)*4294967296.0)*(+(c[Sb+40>>2]|0)/+(c[Sb+44>>2]|0)),_a)|0)|0;i=_a}TGb(Rc|0,0,32)|0;a[Rc]=0;Sb=c[db>>2]|0;Rb=c[db+4>>2]|0;if((Sb|0)==0&(Rb|0)==(-2147483648|0)){Lb(Rc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Rc|0,32,2070656,(_a=i,i=i+16|0,c[_a>>2]=Sb,c[_a+8>>2]=Rb,_a)|0)|0;i=_a}TGb(Kc|0,0,32)|0;a[Kc]=0;Rb=c[db>>2]|0;Sb=c[db+4>>2]|0;Ob=c[Kb>>2]|0;if((Rb|0)==0&(Sb|0)==(-2147483648|0)){Lb(Kc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Kc|0,32,2075240,(_a=i,i=i+8|0,h[_a>>3]=(+(Rb>>>0)+ +(Sb|0)*4294967296.0)*(+(c[Ob+40>>2]|0)/+(c[Ob+44>>2]|0)),_a)|0)|0;i=_a}TGb(Oc|0,0,32)|0;a[Oc]=0;Ob=ra|0;Sb=(c[(c[1271690]|0)+(c[Ob>>2]<<2)>>2]|0)+24|0;Rb=c[Sb>>2]|0;Kb=c[Sb+4>>2]|0;if((Rb|0)==0&(Kb|0)==(-2147483648|0)){Lb(Oc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(Oc|0,32,2070656,(_a=i,i=i+16|0,c[_a>>2]=Rb,c[_a+8>>2]=Kb,_a)|0)|0;i=_a}TGb(zc|0,0,32)|0;a[zc]=0;Kb=(c[(c[1271690]|0)+(c[Ob>>2]<<2)>>2]|0)+24|0;Rb=c[Kb>>2]|0;Sb=c[Kb+4>>2]|0;if((Rb|0)==0&(Sb|0)==(-2147483648|0)){Lb(zc|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(zc|0,32,2075240,(_a=i,i=i+8|0,h[_a>>3]=(+(Rb>>>0)+ +(Sb|0)*4294967296.0)*1.0e-6,_a)|0)|0;i=_a}yDb(0,32,2316200,(_a=i,i=i+64|0,c[_a>>2]=Nb,c[_a+8>>2]=Ca,c[_a+16>>2]=Cc,c[_a+24>>2]=Ba,c[_a+32>>2]=Rc,c[_a+40>>2]=Kc,c[_a+48>>2]=Oc,c[_a+56>>2]=zc,_a)|0);i=_a;Rd=Ob}Ob=c[Ec>>2]|0;Ca=c[Ec+4>>2]|0;Nb=c[(c[1271690]|0)+(c[Rd>>2]<<2)>>2]|0;Sb=Nb+56|0;if((c[Sb>>2]|0)>0){Rb=Nb+12|0;Nb=ra+4|0;Kb=0;do{gb=c[(c[1271688]|0)+((c[Rb>>2]|0)+Kb<<2)>>2]|0;Bb=gb+224|0;do{if((c[Bb>>2]|0)!=0){Eb=KDb(Ob,Ca,(c[Nb>>2]|0)+40|0,(c[gb+4>>2]|0)+40|0)|0;Fb=YGb(Eb,F,-1,-1)|0;Eb=F;Hb=gb+208|0;ob=c[Hb+4>>2]|0;if(!((Eb|0)>(ob|0)|(Eb|0)==(ob|0)&Fb>>>0>(c[Hb>>2]|0)>>>0)){break}ob=gb+216|0;Gb=c[ob+4>>2]|0;if((Eb|0)<(Gb|0)|(Eb|0)==(Gb|0)&Fb>>>0<(c[ob>>2]|0)>>>0){if((c[c[Bb>>2]>>2]|0)==0){Za=591}}else{Za=591}if((Za|0)==591){Za=0;Nh(gb,0)}ob=gb+248|0;if((c[ob>>2]|0)<=0){break}Gb=gb+244|0;jb=0;qa=0;do{jb=(Lj(c[c[(c[Gb>>2]|0)+(qa<<2)>>2]>>2]|0)|0)+jb|0;qa=qa+1|0;Sd=c[ob>>2]|0;}while((qa|0)<(Sd|0));if((jb|0)==0){break}qa=c[Bb>>2]|0;sa=qa+136|0;c[sa>>2]=Fb;c[sa+4>>2]=Eb;c[Hb>>2]=Fb;c[Hb+4>>2]=Eb;if((Sd|0)>0){Ud=0}else{break}do{Gj(c[c[(c[Gb>>2]|0)+(Ud<<2)>>2]>>2]|0,qa,12)|0;Ud=Ud+1|0;}while((Ud|0)<(c[ob>>2]|0))}}while(0);Kb=Kb+1|0;}while((Kb|0)<(c[Sb>>2]|0))}Sb=Jh(ra,m)|0;if((Sb|0)>=0){break}Kb=c[Rd>>2]|0;Nb=c[c[ra+4>>2]>>2]|0;TGb(Lc|0,0,64)|0;a[Lc]=0;GBb(Sb,Lc,64)|0;yDb(0,16,2314504,(_a=i,i=i+24|0,c[_a>>2]=Kb,c[_a+8>>2]=Nb,c[_a+16>>2]=Lc,_a)|0);i=_a;if((c[2039022]|0)==0){break}yf(1)}else{Nb=c[(c[1271690]|0)+(ta<<2)>>2]|0;Kb=c[Nb>>2]|0;Sb=c[(c[Kb+28>>2]|0)+(zb<<2)>>2]|0;Ca=Nb+60|0;if((zb|0)<(c[Ca>>2]|0)){break}Nb=lGb(c[(c[Sb+8>>2]|0)+8>>2]|0)|0;Ob=c[Hc>>2]|0;Rb=c[hc>>2]|0;kb=c[hc+4>>2]|0;TGb(ic|0,0,32)|0;a[ic]=0;Bb=c[db>>2]|0;gb=c[db+4>>2]|0;if((Bb|0)==0&(gb|0)==(-2147483648|0)){Lb(ic|0,32,2080488,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Lb(ic|0,32,2075240,(_a=i,i=i+8|0,h[_a>>3]=(+(Bb>>>0)+ +(gb|0)*4294967296.0)*(+(c[Sb+40>>2]|0)/+(c[Sb+44>>2]|0)),_a)|0)|0;i=_a}yDb(Kb,24,2312992,(_a=i,i=i+48|0,c[_a>>2]=Nb,c[_a+8>>2]=ta,c[_a+16>>2]=Ob,c[_a+24>>2]=Rb,c[_a+32>>2]=kb,c[_a+40>>2]=ic,_a)|0);i=_a;c[Ca>>2]=(c[Hc>>2]|0)+1}}while(0);BZ(m);Ed=0}}while(0);if((Za|0)==440){Za=0;c[Wa+8>>2]=1;Ed=-11}if((Ed|0)==-11){if((c[(c[(c[1271690]|0)+(c[cb>>2]<<2)>>2]|0)+8>>2]|0)==0){Za=611;break r}c[qd+348>>2]=1;Za=611;break r}else{if((Ed|0)<0){vd=Ed;break}Ad=Oh()|0;Za=608;break}}}while(0);if((Za|0)==608){Za=0;if((Ad|0)<0){vd=Ad}else{Za=611;break}}if(!((vd|0)==(-11|0)|(vd|0)==(-541478725|0))){Za=610;break m}}else{sd=Tb;Za=400}}while(0);do{if((Za|0)==400){Za=0;Tb=c[1163658]|0;ta=0;while(1){if((ta|0)>=(sd|0)){Za=410;break}if((c[(c[Tb+(ta<<2)>>2]|0)+348>>2]|0)==0){ta=ta+1|0}else{break}}if((Za|0)==410){Za=0;yDb(0,40,1900992,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;break}if((c[1167942]|0)>0){ta=c[1271690]|0;Qb=0;do{c[(c[ta+(Qb<<2)>>2]|0)+8>>2]=0;Qb=Qb+1|0;}while((Qb|0)<(c[1167942]|0));Vd=c[1167936]|0}else{Vd=sd}if((Vd|0)>0){Qb=0;do{c[(c[Tb+(Qb<<2)>>2]|0)+348>>2]=0;Qb=Qb+1|0;}while((Qb|0)<(c[1167936]|0))}XFb(1e4)|0;Za=611}}while(0);if((Za|0)==611){Za=0;Ih(0,pa,oa,Xb,Wb)}if((c[1149826]|0)!=0){break l}}if((Za|0)==394){yDb(0,40,2249816,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;break}else if((Za|0)==432){yDb(0,0,1899624,(_a=i,i=i+24|0,c[_a>>2]=1898272,c[_a+8>>2]=1893768,c[_a+16>>2]=3385,_a)|0);i=_a;Cd();return 0}else if((Za|0)==610){yDb(0,16,2236344,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;break}}}while(0);Ta=c[1167940]|0;if((Ta|0)>0){La=0;Ia=Ta;while(1){Ta=c[(c[1271688]|0)+(La<<2)>>2]|0;do{if((c[(c[(c[1271690]|0)+(c[Ta>>2]<<2)>>2]|0)+4>>2]|0)==0){if((c[Ta+12>>2]|0)==0){Wd=Ia;break}Jh(Ta,0)|0;Wd=c[1167940]|0}else{Wd=Ia}}while(0);Ta=La+1|0;if((Ta|0)<(Wd|0)){La=Ta;Ia=Wd}else{break}}}Ia=c[1167936]|0;if((Ia|0)>0){La=e+24|0;Ta=e+28|0;Hc=e+8|0;ic=e+16|0;db=e+48|0;hc=0;Lc=Ia;while(1){Ia=c[(c[1163658]|0)+(hc<<2)>>2]|0;Ec=Ia+12|0;zc=c[(c[Ec>>2]|0)+8>>2]|0;Oc=Ia|0;Kc=c[c[(c[1163660]|0)+(c[Oc>>2]<<2)>>2]>>2]|0;x:do{if((c[Ia+16>>2]|0)==0){Xd=Lc}else{Rc=c[zc+8>>2]|0;do{if((Rc|0)==1){if((c[zc+424>>2]|0)<2){Xd=Lc;break x}}else if((Rc|0)==0){if((c[(c[Kc+8>>2]|0)+28>>2]&32|0)==0){break}if((c[(c[zc+12>>2]|0)+12>>2]|0)==14){Xd=Lc;break x}}}while(0);Wb=Ia+4|0;Xb=Ia+296|0;Ba=Ia+344|0;Cc=zc+104|0;vc=zc+668|0;Aa=Rc;while(1){if((Aa|0)==0){Yd=2586104;Zd=2213952;_d=590}else if((Aa|0)==1){Yd=9166848;Zd=2223488;_d=734}else{break}vZ(e);c[La>>2]=0;c[Ta>>2]=0;Kh(0,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;xc=_e[_d&1023](zc,e,0,f)|0;yc=c[Oc>>2]|0;Ub=c[Wb>>2]|0;Kh(2204456,(_a=i,i=i+24|0,c[_a>>2]=Zd,c[_a+8>>2]=yc,c[_a+16>>2]=Ub,_a)|0);i=_a;if((xc|0)<0){yDb(0,8,2196848,(_a=i,i=i+8|0,c[_a>>2]=Zd,_a)|0);i=_a;yf(1)}xc=c[Xb>>2]|0;do{if((xc|0)!=0){Ub=c[vc>>2]|0;if((Ub|0)==0){break}rb(Ub|0,xc|0)|0}}while(0);if((c[f>>2]|0)==0){break}do{if((c[Ba>>2]&2|0)==0){xc=c[Ta>>2]|0;Ub=YGb(c[Yd>>2]|0,c[Yd+4>>2]|0,xc,(xc|0)<0|0?-1:0)|0;c[Yd>>2]=Ub;c[Yd+4>>2]=F;Ub=c[Hc>>2]|0;xc=c[Hc+4>>2]|0;if(!((Ub|0)==0&(xc|0)==(-2147483648|0))){yc=KDb(Ub,xc,Cc,(c[Ec>>2]|0)+40|0)|0;c[Hc>>2]=yc;c[Hc+4>>2]=F}yc=c[ic>>2]|0;xc=c[ic+4>>2]|0;if(!((yc|0)==0&(xc|0)==(-2147483648|0))){Ub=KDb(yc,xc,Cc,(c[Ec>>2]|0)+40|0)|0;c[ic>>2]=Ub;c[ic+4>>2]=F}Ub=c[db>>2]|0;if((Ub|0)>0){xc=KDb(Ub,(Ub|0)<0|0?-1:0,Cc,(c[Ec>>2]|0)+40|0)|0;c[db>>2]=xc}xc=c[Ta>>2]|0;Lh(Kc,e,Ia);if(!((c[(c[(c[Ec>>2]|0)+8>>2]|0)+8>>2]|0)==0&(c[636774]|0)!=0)){break}Mh(Ia,xc)}else{BZ(e)}}while(0);Aa=c[(c[(c[Ec>>2]|0)+8>>2]|0)+8>>2]|0}Xd=c[1167936]|0}}while(0);Ec=hc+1|0;if((Ec|0)<(Xd|0)){hc=Ec;Lc=Xd}else{break}}}yDb(0,-8,1984248,(_a=i,i=i+8|0,c[_a>>2]=9203128,_a)|0);i=_a;if(a[548136]|0){Td(0,0,4654696)|0}if((c[1167938]|0)>0){Lc=0;do{NK(c[c[(c[1163660]|0)+(Lc<<2)>>2]>>2]|0)|0;Lc=Lc+1|0;}while((Lc|0)<(c[1167938]|0))}Lc=WFb()|0;Ih(1,pa,oa,Lc,F);Lc=c[1167936]|0;if((Lc|0)>0){hc=0;Ta=Lc;while(1){Lc=c[(c[1163658]|0)+(hc<<2)>>2]|0;if((c[Lc+16>>2]|0)==0){$d=Ta}else{db=Lc+12|0;$Db((c[(c[db>>2]|0)+8>>2]|0)+672|0);E0a(c[(c[db>>2]|0)+8>>2]|0)|0;$d=c[1167936]|0}db=hc+1|0;if((db|0)<($d|0)){hc=db;Ta=$d}else{break}}}if((c[1167940]|0)>0){ae=0}else{cd=0;break}while(1){Ta=c[(c[1271688]|0)+(ae<<2)>>2]|0;do{if((c[Ta+12>>2]|0)!=0){hc=Ta+4|0;E0a(c[(c[hc>>2]|0)+8>>2]|0)|0;oa=c[Ta+272>>2]|0;if((oa|0)==0){break}me[oa&511](c[(c[hc>>2]|0)+8>>2]|0)}}while(0);Ta=ae+1|0;if((Ta|0)<(c[1167940]|0)){ae=Ta}else{cd=0;break}}}}while(0);ae=c[1163658]|0;if((ae|0)==0){i=b;return cd|0}$d=c[1167936]|0;if(($d|0)>0){be=0;ce=$d;de=ae}else{i=b;return cd|0}while(1){ae=c[de+(be<<2)>>2]|0;if((ae|0)==0){ee=ce}else{if((c[ae+352>>2]|0)!=0){$Db((c[(c[ae+12>>2]|0)+8>>2]|0)+96|0)}$d=ae+296|0;_a=c[$d>>2]|0;if((_a|0)!=0){fb(_a|0)|0;c[$d>>2]=0}$Db((c[(c[ae+12>>2]|0)+8>>2]|0)+860|0);$Db(ae+100|0);$Db(ae+340|0);DBb(ae+328|0);DBb(ae+332|0);DBb(ae+336|0);ee=c[1167936]|0}ae=be+1|0;if((ae|0)>=(ee|0)){break}be=ae;ce=ee;de=c[1163658]|0}i=b;return cd|0}function Ih(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0.0,E=0,G=0,H=0.0,I=0,J=0.0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0.0,S=0.0,T=0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0,_=0.0,aa=0.0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0.0,ja=0,ka=0,la=0.0;j=i;i=i+2064|0;k=j|0;l=j+1024|0;m=j+2048|0;n=j+2056|0;do{if((c[140488]|0)==0){if((b|0)!=0|(c[1154408]|0)!=0){break}i=j;return}}while(0);o=(b|0)!=0;do{if(!o){q=c[140492]|0;r=c[140493]|0;if((q|0)==(-1|0)&(r|0)==(-1|0)){c[140492]=f;c[140493]=g;i=j;return}s=ZGb(f,g,q,r)|0;r=F;q=0;if((r|0)<(q|0)|(r|0)==(q|0)&s>>>0<5e5>>>0){i=j;return}else{c[140492]=f;c[140493]=g;break}}}while(0);s=(c[c[c[1163660]>>2]>>2]|0)+16|0;q=Wy(c[s>>2]|0)|0;r=F;t=0;if((r|0)<(t|0)|(r|0)==(t|0)&q>>>0<1>>>0){t=Ty(c[s>>2]|0,0,0,1)|0;u=F;v=t}else{u=r;v=q}q=k|0;a[q]=0;IAb(l,0,1);if((c[1167936]|0)>0){r=m|0;t=m+4|0;s=n|0;w=n+4|0;x=ZGb(f,g,d,e)|0;y=(+(x>>>0)+ +(F|0)*4294967296.0)/1.0e6;x=y>1.0;e=-2147483648;d=0;g=0;f=0;while(1){z=c[(c[1163658]|0)+(g<<2)>>2]|0;A=z+12|0;B=c[(c[A>>2]|0)+8>>2]|0;do{if((c[z+352>>2]|0)==0){C=c[B+804>>2]|0;if((C|0)==0){D=-1.0;break}D=+(c[C+168>>2]|0)/118.0}else{D=-1.0}}while(0);C=(c[B+8>>2]|0)==0;do{if((f|0)==0){if(!C){E=0;break}G=c[z+20>>2]|0;if(x){H=+(G|0)/y}else{H=0.0}I=SGb(q|0)|0;J=D;Lb(k+I|0,1024-I|0,1974520,(K=i,i=i+32|0,c[K>>2]=G,c[K+8>>2]=H<9.95,h[K+16>>3]=H,h[K+24>>3]=J,K)|0)|0;i=K;KAb(l,1972816,(K=i,i=i+8|0,c[K>>2]=G,K)|0);i=K;KAb(l,1966584,(K=i,i=i+8|0,h[K>>3]=H,K)|0);i=K;I=z|0;L=z+4|0;M=c[L>>2]|0;KAb(l,1976832,(K=i,i=i+24|0,c[K>>2]=c[I>>2],c[K+8>>2]=M,h[K+16>>3]=J,K)|0);i=K;if(o){M=SGb(q|0)|0;Lb(k+M|0,1024-M|0,1960344,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}if((c[1150452]|0)!=0){M=Gc(+D)|0;if((M|0)>-1&M>>>0<52>>>0){N=4617648+(M<<2)|0;c[N>>2]=(c[N>>2]|0)+1;O=0}else{O=0}do{N=SGb(q|0)|0;M=Gc(+(+gc(+(+((c[4617648+(O<<2)>>2]|0)+1|0)))))|0;Lb(k+N|0,1024-N|0,1958488,(K=i,i=i+8|0,c[K>>2]=M,K)|0)|0;i=K;O=O+1|0;}while((O|0)<32)}if((c[B+88>>2]&32768|0)==0){E=1;break}M=B+804|0;if(!((c[M>>2]|0)!=0|o)){E=1;break}N=SGb(q|0)|0;Lb(k+N|0,1024-N|0,1956136,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K;N=B+120|0;P=B+124|0;J=+(G|0);if(o){Q=0;R=0.0;S=0.0;while(1){T=B+720+(Q<<3)|0;U=J*+(ba(c[P>>2]|0,c[N>>2]|0)|0)*255.0*255.0;V=+((c[T>>2]|0)>>>0)+ +((c[T+4>>2]|0)>>>0)*4294967296.0;if((Q|0)==0){W=U}else{W=U*.25}U=R+V;X=S+W;Y=+$(V/W)*-10.0/2.302585092994046;T=SGb(q|0)|0;Z=a[561960+Q|0]|0;Lb(k+T|0,1024-T|0,1953856,(K=i,i=i+16|0,c[K>>2]=Z,h[K+8>>3]=Y,K)|0)|0;i=K;T=c[L>>2]|0;KAb(l,1951616,(K=i,i=i+32|0,c[K>>2]=c[I>>2],c[K+8>>2]=T,c[K+16>>2]=Z|32,h[K+24>>3]=Y,K)|0);i=K;Z=Q+1|0;if((Z|0)<3){Q=Z;R=U;S=X}else{_=U;aa=X;break}}}else{Q=0;S=0.0;R=0.0;while(1){G=(c[M>>2]|0)+224+(Q<<3)|0;J=+(ba(c[P>>2]|0,c[N>>2]|0)|0)*255.0*255.0;X=+((c[G>>2]|0)>>>0)+ +((c[G+4>>2]|0)>>>0)*4294967296.0;if((Q|0)==0){ca=J}else{ca=J*.25}J=S+X;U=R+ca;Y=+$(X/ca)*-10.0/2.302585092994046;G=SGb(q|0)|0;Z=a[561960+Q|0]|0;Lb(k+G|0,1024-G|0,1953856,(K=i,i=i+16|0,c[K>>2]=Z,h[K+8>>3]=Y,K)|0)|0;i=K;G=c[L>>2]|0;KAb(l,1951616,(K=i,i=i+32|0,c[K>>2]=c[I>>2],c[K+8>>2]=G,c[K+16>>2]=Z|32,h[K+24>>3]=Y,K)|0);i=K;Z=Q+1|0;if((Z|0)<3){Q=Z;S=J;R=U}else{_=J;aa=U;break}}}R=+$(_/aa)*-10.0/2.302585092994046;Q=SGb(q|0)|0;Lb(k+Q|0,1024-Q|0,1949664,(K=i,i=i+8|0,h[K>>3]=R,K)|0)|0;i=K;Q=c[L>>2]|0;KAb(l,1947544,(K=i,i=i+24|0,c[K>>2]=c[I>>2],c[K+8>>2]=Q,h[K+16>>3]=R,K)|0);i=K;E=1}else{if(!C){E=f;break}Q=SGb(q|0)|0;R=D;Lb(k+Q|0,1024-Q|0,1979528,(K=i,i=i+8|0,h[K>>3]=R,K)|0)|0;i=K;Q=c[z+4>>2]|0;KAb(l,1976832,(K=i,i=i+24|0,c[K>>2]=c[z>>2],c[K+8>>2]=Q,h[K+16>>3]=R,K)|0);i=K;E=f}}while(0);if(o){da=39}else{if((c[z+344>>2]|0)==0){da=39}else{ea=e;fa=d}}do{if((da|0)==39){da=0;C=c[A>>2]|0;B=C+16|0;Q=c[B>>2]|0;N=c[B+4>>2]|0;if((Q|0)==0&(N|0)==(-2147483648|0)){ea=e;fa=d;break}c[r>>2]=1;c[t>>2]=1e6;B=KDb(Q,N,C+40|0,m)|0;C=F;if((e|0)>(C|0)|(e|0)==(C|0)&d>>>0>B>>>0){ea=e;fa=d;break}B=c[A>>2]|0;C=B+16|0;N=c[C>>2]|0;Q=c[C+4>>2]|0;c[s>>2]=1;c[w>>2]=1e6;C=KDb(N,Q,B+40|0,n)|0;ea=F;fa=C}}while(0);A=g+1|0;if((A|0)<(c[1167936]|0)){e=ea;d=fa;g=A;f=E}else{ga=ea;ha=fa;break}}}else{ga=-2147483648;ha=0}fa=eHb(ha,ga,1e6,0)|0;ea=fa;fa=fHb(ha,ga,1e6,0)|0;E=fa;fa=(ea|0)%60|0;f=(ea|0)/3600|0;g=((ea|0)/60|0|0)%60|0;ea=-1;if(((ha|0)!=0|(ga|0)!=0)&((u|0)>(ea|0)|(u|0)==(ea|0)&v>>>0>-1>>>0)){ia=(+((v<<3|0>>>29)>>>0)+ +(u<<3|v>>>29|0)*4294967296.0)/((+(ha>>>0)+ +(ga|0)*4294967296.0)/1.0e3)}else{ia=-1.0}ea=0;d=(u|0)<(ea|0)|(u|0)==(ea|0)&v>>>0<0>>>0;ea=SGb(q|0)|0;e=k+ea|0;n=1024-ea|0;if(d){Lb(e|0,n|0,1945800,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}else{Lb(e|0,n|0,1943960,(K=i,i=i+8|0,h[K>>3]=(+(v>>>0)+ +(u|0)*4294967296.0)*.0009765625,K)|0)|0;i=K}n=SGb(q|0)|0;Lb(k+n|0,1024-n|0,1938504,(K=i,i=i+32|0,c[K>>2]=f,c[K+8>>2]=g,c[K+16>>2]=fa,c[K+24>>2]=(E*100|0|0)/1e6|0,K)|0)|0;i=K;n=SGb(q|0)|0;e=k+n|0;ea=1024-n|0;if(ia<0.0){Lb(e|0,ea|0,1932520,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}else{Lb(e|0,ea|0,1930608,(K=i,i=i+8|0,h[K>>3]=ia,K)|0)|0;i=K}if(d){KAb(l,1928824,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}else{KAb(l,1927184,(K=i,i=i+16|0,c[K>>2]=v,c[K+8>>2]=u,K)|0);i=K}KAb(l,1925360,(K=i,i=i+16|0,c[K>>2]=ha,c[K+8>>2]=ga,K)|0);i=K;KAb(l,1924048,(K=i,i=i+32|0,c[K>>2]=f,c[K+8>>2]=g,c[K+16>>2]=fa,c[K+24>>2]=E,K)|0);i=K;E=c[1167944]|0;fa=c[1167946]|0;if((fa|E|0)==0){ja=E}else{g=SGb(q|0)|0;Lb(k+g|0,1024-g|0,1922352,(K=i,i=i+16|0,c[K>>2]=E,c[K+8>>2]=fa,K)|0)|0;i=K;ja=c[1167944]|0}KAb(l,1920848,(K=i,i=i+8|0,c[K>>2]=ja,K)|0);i=K;KAb(l,1919112,(K=i,i=i+8|0,c[K>>2]=c[1167946],K)|0);i=K;ja=c[140488]|0;if((ja|b|0)!=0){do{if((ja|0)==1){if((zDb()|0)>=32){da=60;break}b=c[p>>2]|0;Dd(b|0,1914256,(K=i,i=i+8|0,c[K>>2]=q,K)|0)|0;i=K;ka=b}else{da=60}}while(0);if((da|0)==60){yDb(0,32,1914256,(K=i,i=i+8|0,c[K>>2]=q,K)|0);i=K;ka=c[p>>2]|0}ib(ka|0)|0}do{if((c[1154408]|0)==0){if(o){break}i=j;return}else{KAb(l,1909736,(K=i,i=i+8|0,c[K>>2]=o?1908440:1906832,K)|0);i=K;ka=c[l+4>>2]|0;q=(c[l+8>>2]|0)-1|0;Ry(c[1154408]|0,c[l>>2]|0,ka>>>0>q>>>0?q:ka);Sy(c[1154408]|0);QAb(l,0)|0;if(o){Iz(c[1154408]|0)|0;c[1154408]=0;break}else{i=j;return}}}while(0);o=YGb(c[646526]|0,c[646527]|0,c[2291712]|0,c[2291713]|0)|0;l=YGb(o,F,c[2187440]|0,c[2187441]|0)|0;o=YGb(l,F,c[1071076]|0,c[1071077]|0)|0;l=YGb(o,F,c[2004844]|0,c[2004845]|0)|0;o=F;if((l|0)==0&(o|0)==0){la=0.0}else{ka=ZGb(v,u,l,o)|0;la=(+(ka>>>0)+ +(F|0)*4294967296.0)*100.0/(+(l>>>0)+ +(o|0)*4294967296.0)}yDb(0,32,1905240,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;ia=(+((c[2291712]|0)>>>0)+ +(c[2291713]|0)*4294967296.0)*.0009765625;D=(+((c[1071076]|0)>>>0)+ +(c[1071077]|0)*4294967296.0)*.0009765625;aa=(+((c[2187440]|0)>>>0)+ +(c[2187441]|0)*4294967296.0)*.0009765625;_=(+((c[2004844]|0)>>>0)+ +(c[2004845]|0)*4294967296.0)*.0009765625;yDb(0,32,1903288,(K=i,i=i+48|0,h[K>>3]=(+((c[646526]|0)>>>0)+ +(c[646527]|0)*4294967296.0)*.0009765625,h[K+8>>3]=ia,h[K+16>>3]=D,h[K+24>>3]=aa,h[K+32>>3]=_,h[K+40>>3]=la,K)|0);i=K;o=YGb(c[2187440]|0,c[2187441]|0,c[646526]|0,c[646527]|0)|0;l=YGb(o,F,c[2291712]|0,c[2291713]|0)|0;o=YGb(l,F,c[1071076]|0,c[1071077]|0)|0;l=F;ka=ZGb(0,0,c[2004844]|0,c[2004845]|0)|0;if(!((o|0)==(ka|0)&(l|0)==(F|0))){i=j;return}yDb(0,24,1902096,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;i=j;return}function Jh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0.0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0;e=i;i=i+1056|0;f=e|0;g=e+8|0;j=e+16|0;k=e+96|0;l=e+104|0;m=e+112|0;n=e+120|0;o=e+128|0;p=e+136|0;q=e+168|0;r=e+200|0;s=e+208|0;t=e+216|0;u=e+248|0;v=e+280|0;w=e+312|0;x=e+568|0;y=e+576|0;z=e+640|0;A=e+704|0;B=e+712|0;C=e+720|0;D=e+728|0;G=e+736|0;H=e+744|0;I=e+752|0;J=e+760|0;K=e+824|0;L=e+904|0;M=e+912|0;N=e+920|0;O=e+928|0;R=e+1008|0;S=e+1016|0;T=e+1024|0;U=e+1032|0;V=e+1040|0;W=e+1048|0;c[N>>2]=0;X=b+96|0;if((c[X>>2]|0)==0){Y=c[b+4>>2]|0;Z=c[Y+92>>2]|0;if((Z|0)==0){_=0;$=0}else{ba=+((c[(c[Y+8>>2]|0)+176>>2]|0)*-1e6|0|0)/(+(Z|0)/+(c[Y+96>>2]|0));_=(E=+ba,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);$=~~+ba>>>0}Z=b+48|0;c[Z>>2]=$;c[Z+4>>2]=_;_=b+64|0;c[_>>2]=0;c[_+4>>2]=0;do{if((d|0)!=0){$=d+8|0;ca=c[$>>2]|0;da=c[$+4>>2]|0;if((ca|0)==0&(da|0)==(-2147483648|0)){break}if((c[b+12>>2]|0)!=0){break}c[R>>2]=1;c[R+4>>2]=1e6;$=KDb(ca,da,Y+40|0,R)|0;da=YGb(c[Z>>2]|0,c[Z+4>>2]|0,$,F)|0;$=F;c[Z>>2]=da;c[Z+4>>2]=$;c[_>>2]=da;c[_+4>>2]=$}}while(0);c[X>>2]=1}X=b+40|0;if((c[X>>2]|0)==0&(c[X+4>>2]|0)==(-2147483648|0)){_=b+48|0;Z=c[_+4>>2]|0;c[X>>2]=c[_>>2];c[X+4>>2]=Z}Z=b+56|0;if((c[Z>>2]|0)==0&(c[Z+4>>2]|0)==(-2147483648|0)){_=b+64|0;R=c[_+4>>2]|0;c[Z>>2]=c[_>>2];c[Z+4>>2]=R}R=(d|0)==0;do{if(R){vZ(O);c[O+24>>2]=0;c[O+28>>2]=0;ea=0}else{UGb(O|0,d|0,80)|0;_=d+16|0;Y=c[_>>2]|0;$=c[_+4>>2]|0;if((Y|0)==0&($|0)==(-2147483648|0)){fa=19;break}_=b+4|0;da=(c[_>>2]|0)+40|0;c[S>>2]=1;c[S+4>>2]=1e6;ca=KDb(Y,$,da,S)|0;da=F;$=b+48|0;c[$>>2]=ca;c[$+4>>2]=da;c[X>>2]=ca;c[X+4>>2]=da;if((c[(c[(c[_>>2]|0)+8>>2]|0)+8>>2]|0)==0){if((c[b+12>>2]|0)!=0){fa=19;break}}_=b+64|0;c[_>>2]=ca;c[_+4>>2]=da;c[Z>>2]=ca;c[Z+4>>2]=da;fa=19}}while(0);a:while(1){if((fa|0)==19){fa=0;if((c[b+12>>2]|0)==0){fa=190;break}S=c[O+28>>2]|0;if((S|0)>0){ea=S;continue}if(!R){break}if((c[N>>2]|0)==0){ha=0;fa=251;break}else{ea=S}}S=c[Z+4>>2]|0;da=b+64|0;c[da>>2]=c[Z>>2];c[da+4>>2]=S;S=c[X+4>>2]|0;ca=b+48|0;c[ca>>2]=c[X>>2];c[ca+4>>2]=S;S=O+28|0;do{if((ea|0)!=0){if((ea|0)==(c[d+28>>2]|0)){break}_=b+100|0;yDb(0,(c[_>>2]|0)!=0?40:24,2061984,(ia=i,i=i+8|0,c[ia>>2]=c[d+32>>2],ia)|0);i=ia;c[_>>2]=1}}while(0);_=b+4|0;$=c[(c[_>>2]|0)+8>>2]|0;Y=c[$+8>>2]|0;b:do{if((Y|0)==3){ja=p;ka=q;la=B0a($,p,N,O)|0;ma=c[N>>2]|0;na=(la|0)<0;if((ma|0)!=0|na){fa=147}else{if((c[S>>2]|0)!=0){fa=147}}if((fa|0)==147){fa=0;oa=8648280+(la>>>31<<3)|0;pa=YGb(c[oa>>2]|0,c[oa+4>>2]|0,1,0)|0;c[oa>>2]=pa;c[oa+4>>2]=F}if(na|(ma|0)==0){if((c[S>>2]|0)!=0){qa=la;break}na=b+248|0;if((c[na>>2]|0)<=0){qa=la;break}oa=b+244|0;pa=0;while(1){Ij(c[c[(c[oa>>2]|0)+(pa<<2)>>2]>>2]|0,0,0)|0;ra=pa+1|0;if((ra|0)<(c[na>>2]|0)){pa=ra}else{qa=la;break b}}}if((c[b+160>>2]|0)==0){sa=la;ta=ma;fa=158}else{pa=b+168|0;na=c[pa>>2]|0;do{if((na|0)==0){ua=1;va=0;wa=ma}else{oa=p+24|0;ra=b+200|0;xa=ZGb(c[oa>>2]|0,c[oa+4>>2]|0,c[ra>>2]|0,c[ra+4>>2]|0)|0;ra=IDb(xa,F,1e3,0,1e6,0)|0;xa=ra;ra=b+184|0;oa=c[ra>>2]|0;if(!(xa>>>0<oa>>>0)){ua=xa;va=na;wa=ma;break}yDb(c[(c[_>>2]|0)+8>>2]|0,48,2058424,(ia=i,i=i+24|0,c[ia>>2]=oa,c[ia+8>>2]=xa,c[ia+16>>2]=(xa|0)<1?2049728:9203128,ia)|0);i=ia;c[ra>>2]=xa;ua=xa;va=c[pa>>2]|0;wa=c[N>>2]|0}}while(0);c[pa>>2]=wa;c[N>>2]=va;ma=b+172|0;na=c[ma>>2]|0;c[ma>>2]=la;ma=b+176|0;c[ka>>2]=c[ma>>2];c[ka+4>>2]=c[ma+4>>2];c[ka+8>>2]=c[ma+8>>2];c[ka+12>>2]=c[ma+12>>2];c[ka+16>>2]=c[ma+16>>2];c[ka+20>>2]=c[ma+20>>2];c[ka+24>>2]=c[ma+24>>2];c[ka+28>>2]=c[ma+28>>2];c[ma>>2]=c[ja>>2];c[ma+4>>2]=c[ja+4>>2];c[ma+8>>2]=c[ja+8>>2];c[ma+12>>2]=c[ja+12>>2];c[ma+16>>2]=c[ja+16>>2];c[ma+20>>2]=c[ja+20>>2];c[ma+24>>2]=c[ja+24>>2];c[ma+28>>2]=c[ja+28>>2];c[ja>>2]=c[ka>>2];c[ja+4>>2]=c[ka+4>>2];c[ja+8>>2]=c[ka+8>>2];c[ja+12>>2]=c[ka+12>>2];c[ja+16>>2]=c[ka+16>>2];c[ja+20>>2]=c[ka+20>>2];c[ja+24>>2]=c[ka+24>>2];c[ja+28>>2]=c[ka+28>>2];if((ua|0)<1){ya=na}else{sa=na;ta=va;fa=158}}do{if((fa|0)==158){fa=0;if((ta|0)==0){qa=sa;break b}Nh(b,p);na=p+12|0;if(!((c[na>>2]|0)!=0&(c[1167936]|0)>0)){ya=sa;break}ma=b|0;xa=p+24|0;ra=k|0;oa=k+4|0;za=p+4|0;Aa=l|0;Ba=l+4|0;Ca=m|0;Da=m+4|0;Ea=p+8|0;Fa=j+24|0;Ga=j+28|0;Ha=n|0;Ia=n+4|0;Ja=j+8|0;Ka=o|0;La=o+4|0;Ma=j+48|0;Na=g|0;Oa=g+4|0;Pa=f|0;Qa=f+4|0;Ra=0;while(1){Sa=c[(c[1163658]|0)+(Ra<<2)>>2]|0;Ta=Sa|0;Ua=c[(c[1163660]|0)+(c[Ta>>2]<<2)>>2]|0;c:do{if((c[Sa+8>>2]|0)==((c[c[_>>2]>>2]|0)+(c[(c[(c[1271690]|0)+(c[ma>>2]<<2)>>2]|0)+12>>2]|0)|0)){Va=Sa+344|0;if((c[Va>>2]|0)!=0){break}Wa=Ua+24|0;Xa=c[Wa>>2]|0;Ya=c[Wa+4>>2]|0;if(!((Xa|0)==0&(Ya|0)==(-2147483648|0))){Wa=c[da+4>>2]|0;if((Wa|0)<(Ya|0)|(Wa|0)==(Ya|0)&(c[da>>2]|0)>>>0<Xa>>>0){break}}if((c[Sa+16>>2]|0)==0){break}Wa=c[Ua>>2]|0;Za=c[xa>>2]|0;_a=c[xa+4>>2]|0;if((Za|0)==0&(_a|0)==(-2147483648|0)){yDb(0,16,2041168,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;if((c[2039022]|0)==0){break}yf(1);break}$a=Sa+12|0;ab=c[(c[$a>>2]|0)+8>>2]|0;if((c[1071078]|0)==0){c[1071078]=WDb(1048576)|0;bb=(c[(c[1163660]|0)+(c[Ta>>2]<<2)>>2]|0)+24|0;cb=c[xa+4>>2]|0;db=c[xa>>2]|0;eb=c[bb+4>>2]|0;fb=c[bb>>2]|0}else{cb=_a;db=Za;eb=Ya;fb=Xa}Xa=ab+48|0;Ya=(c[Xa>>2]|0)==94209?2:1;Za=(fb|0)==0&(eb|0)==(-2147483648|0);_a=ZGb(db,cb,Za?0:fb,Za?0:eb)|0;Za=F;bb=ab+104|0;gb=Sa+32|0;hb=Sa+40|0;ib=0;while(1){c[ra>>2]=1;c[oa>>2]=1e6;jb=KDb(_a,Za,k,bb)|0;kb=F;c[gb>>2]=jb;c[gb+4>>2]=kb;lb=(c[(c[1163660]|0)+(c[Ta>>2]<<2)>>2]|0)+16|0;mb=c[lb>>2]|0;nb=c[lb+4>>2]|0;if(!((mb|0)==(-1|0)&(nb|0)==2147483647)){lb=ZGb(jb,kb,c[hb>>2]|0,c[hb+4>>2]|0)|0;kb=(c[(c[$a>>2]|0)+8>>2]|0)+104|0;c[Na>>2]=1;c[Oa>>2]=1e6;if((LDb(lb,F,kb,mb,nb,g)|0)>-1){break}}c[xa>>2]=_a;c[xa+4>>2]=Za;nb=c[za>>2]|0;c[Aa>>2]=1;c[Ba>>2]=1e3;c[Ca>>2]=1;c[Da>>2]=1e6;mb=KDb(nb,0,l,m)|0;nb=YGb(c[xa>>2]|0,c[xa+4>>2]|0,mb,F)|0;c[xa>>2]=nb;c[xa+4>>2]=F;c[Ea>>2]=(c[Ea>>2]|0)-(c[za>>2]|0);c[za>>2]=0;if((ib|0)==1){c[na>>2]=0}nb=w0a(ab,c[1071078]|0,1048576,p)|0;if((nb|0)<0){yDb(0,8,2037768,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;yf(1)}vZ(j);c[Fa>>2]=c[1071078];c[Ga>>2]=nb;nb=c[xa>>2]|0;mb=c[xa+4>>2]|0;c[Ha>>2]=1;c[Ia>>2]=1e6;kb=KDb(nb,mb,n,(c[$a>>2]|0)+40|0)|0;c[Ja>>2]=kb;c[Ja+4>>2]=F;kb=c[Ea>>2]|0;c[Ka>>2]=1;c[La>>2]=1e3;mb=KDb(kb,0,o,(c[$a>>2]|0)+40|0)|0;c[Ma>>2]=mb;do{if((c[Xa>>2]|0)==94209){if((ib|0)==0){mb=YGb((c[za>>2]|0)*90|0,0,c[Ja>>2]|0,c[Ja+4>>2]|0)|0;c[Ja>>2]=mb;c[Ja+4>>2]=F;break}else{mb=YGb((c[Ea>>2]|0)*90|0,0,c[Ja>>2]|0,c[Ja+4>>2]|0)|0;c[Ja>>2]=mb;c[Ja+4>>2]=F;break}}}while(0);mb=c[Ga>>2]|0;kb=YGb(c[1071076]|0,c[1071077]|0,mb,(mb|0)<0|0?-1:0)|0;c[1071076]=kb;c[1071077]=F;Lh(Wa,j,Sa);ib=ib+1|0;if((ib|0)>=(Ya|0)){break c}}Ya=c[(c[1163660]|0)+(c[Ta>>2]<<2)>>2]|0;c[Va>>2]=c[Va>>2]|1;if((c[Ya+40>>2]|0)==0){break}ib=ZGb(c[gb>>2]|0,c[gb+4>>2]|0,c[hb>>2]|0,c[hb+4>>2]|0)|0;Wa=(c[(c[$a>>2]|0)+8>>2]|0)+104|0;c[Pa>>2]=1;c[Qa>>2]=1e6;Xa=KDb(ib,F,Wa,f)|0;Wa=F;ib=Ya+16|0;Ya=c[ib>>2]|0;ab=c[ib+4>>2]|0;Za=(ab|0)>(Wa|0)|(ab|0)==(Wa|0)&Ya>>>0>Xa>>>0;c[ib>>2]=Za?Xa:Ya;c[ib+4>>2]=Za?Wa:ab}}while(0);Ta=Ra+1|0;if((Ta|0)<(c[1167936]|0)){Ra=Ta}else{ya=sa;break}}}}while(0);C0a(p);qa=ya}else if((Y|0)==0){ka=t|0;ja=u|0;la=v|0;pa=y|0;Ra=b+20|0;Qa=c[Ra>>2]|0;if((Qa|0)==0){Pa=ICb()|0;c[Ra>>2]=Pa;if((Pa|0)==0){ob=-12}else{pb=Pa;fa=81}}else{pb=Qa;fa=81}d:do{if((fa|0)==81){fa=0;Qa=b+24|0;if((c[Qa>>2]|0)==0){Pa=ICb()|0;c[Qa>>2]=Pa;if((Pa|0)==0){ob=-12;break}qb=c[Ra>>2]|0}else{qb=pb}Pa=c[ca>>2]|0;Ga=c[ca+4>>2]|0;c[r>>2]=1;c[r+4>>2]=1e6;Ja=KDb(Pa,Ga,r,(c[_>>2]|0)+40|0)|0;Ga=O+16|0;c[Ga>>2]=Ja;c[Ga+4>>2]=F;Kh(0,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Ga=x0a(c[(c[_>>2]|0)+8>>2]|0,qb,N,O)|0;Ja=b|0;Pa=c[c[_>>2]>>2]|0;Kh(2022896,(ia=i,i=i+16|0,c[ia>>2]=c[Ja>>2],c[ia+8>>2]=Pa,ia)|0);i=ia;Pa=c[N>>2]|0;Ea=(Ga|0)<0;if((Pa|0)!=0|Ea){fa=86}else{if((c[S>>2]|0)!=0){fa=86}}if((fa|0)==86){fa=0;za=8648280+(Ga>>>31<<3)|0;Ma=YGb(c[za>>2]|0,c[za+4>>2]|0,1,0)|0;c[za>>2]=Ma;c[za+4>>2]=F}if((Pa|0)==0|Ea){if((c[S>>2]|0)!=0){ob=Ga;break}Ea=b+248|0;if((c[Ea>>2]|0)<=0){ob=Ga;break}Pa=b+244|0;za=0;while(1){Ij(c[c[(c[Pa>>2]|0)+(za<<2)>>2]>>2]|0,0,0)|0;Ma=za+1|0;if((Ma|0)<(c[Ea>>2]|0)){za=Ma}else{ob=Ga;break d}}}za=c[b+116>>2]|0;if((za|0)>-1){c[qb+300>>2]=za}za=c[b+280>>2]|0;Ea=qb+80|0;do{if((za|0)==0){rb=0;fa=97}else{if((c[Ea>>2]|0)!=(c[b+284>>2]|0)){rb=0;fa=97;break}Pa=Oe[za&1023](c[(c[_>>2]|0)+8>>2]|0,qb)|0;if((Pa|0)<0){sb=Pa;tb=Ga}else{rb=Pa;fa=97}}}while(0);e:do{if((fa|0)==97){fa=0;c[b+288>>2]=c[Ea>>2];za=oCb(qb)|0;Pa=F;Ma=(za|0)==0&(Pa|0)==(-2147483648|0);if(!Ma){La=qb+136|0;c[La>>2]=za;c[La+4>>2]=Pa;La=(c[_>>2]|0)+40|0;c[s>>2]=1;c[s+4>>2]=1e6;Ka=KDb(za,Pa,La,s)|0;La=F;c[da>>2]=Ka;c[da+4>>2]=La;c[Z>>2]=Ka;c[Z+4>>2]=La}if((c[2163098]|0)!=0){La=c[c[_>>2]>>2]|0;TGb(ka|0,0,32)|0;a[ka]=0;Ka=qb+136|0;Ia=c[Ka>>2]|0;Ha=c[Ka+4>>2]|0;if((Ia|0)==0&(Ha|0)==(-2147483648|0)){Lb(ka|0,32,2080488,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0)|0;i=ia}else{Lb(ka|0,32,2070656,(ia=i,i=i+16|0,c[ia>>2]=Ia,c[ia+8>>2]=Ha,ia)|0)|0;i=ia}TGb(ja|0,0,32)|0;a[ja]=0;Ha=c[Ka>>2]|0;Ia=c[Ka+4>>2]|0;Ka=c[_>>2]|0;if((Ha|0)==0&(Ia|0)==(-2147483648|0)){Lb(ja|0,32,2080488,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0)|0;i=ia}else{Lb(ja|0,32,2075240,(ia=i,i=i+8|0,h[ia>>3]=(+(Ha>>>0)+ +(Ia|0)*4294967296.0)*(+(c[Ka+40>>2]|0)/+(c[Ka+44>>2]|0)),ia)|0)|0;i=ia}TGb(la|0,0,32)|0;a[la]=0;Ka=c[_>>2]|0;if(Ma){Lb(la|0,32,2080488,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0)|0;i=ia}else{Lb(la|0,32,2075240,(ia=i,i=i+8|0,h[ia>>3]=(+(za>>>0)+ +(Pa|0)*4294967296.0)*(+(c[Ka+40>>2]|0)/+(c[Ka+44>>2]|0)),ia)|0)|0;i=ia}Ka=c[qb+84>>2]|0;Ma=c[qb+88>>2]|0;Ia=c[_>>2]|0;Ha=c[Ia+40>>2]|0;xa=c[Ia+44>>2]|0;yDb(0,32,2019528,(ia=i,i=i+80|0,c[ia>>2]=La,c[ia+8>>2]=ka,c[ia+16>>2]=ja,c[ia+24>>2]=za,c[ia+32>>2]=Pa,c[ia+40>>2]=la,c[ia+48>>2]=Ka,c[ia+56>>2]=Ma,c[ia+64>>2]=Ha,c[ia+72>>2]=xa,ia)|0);i=ia}c[S>>2]=0;xa=(c[_>>2]|0)+80|0;if((c[xa>>2]|0)!=0){Ha=xa;xa=qb+124|0;Ma=c[Ha+4>>2]|0;c[xa>>2]=c[Ha>>2];c[xa+4>>2]=Ma}Ma=b+128|0;xa=c[Ma>>2]|0;Ha=qb+68|0;Ka=b+124|0;Pa=c[Ka>>2]|0;za=qb+72|0;do{if((xa|0)==(c[Ha>>2]|0)){if((Pa|0)!=(c[za>>2]|0)){fa=115;break}if((c[b+132>>2]|0)!=(c[Ea>>2]|0)){fa=115}}else{fa=115}}while(0);do{if((fa|0)==115){fa=0;La=c[Ja>>2]|0;Ia=c[c[_>>2]>>2]|0;Fa=b+132|0;na=ZEb(c[Fa>>2]|0)|0;Da=c[Ha>>2]|0;Ca=c[za>>2]|0;Ba=ZEb(c[Ea>>2]|0)|0;yDb(0,32,2015416,(ia=i,i=i+64|0,c[ia>>2]=La,c[ia+8>>2]=Ia,c[ia+16>>2]=xa,c[ia+24>>2]=Pa,c[ia+32>>2]=na,c[ia+40>>2]=Da,c[ia+48>>2]=Ca,c[ia+56>>2]=Ba,ia)|0);i=ia;c[Ma>>2]=c[Ha>>2];c[Ka>>2]=c[za>>2];c[Fa>>2]=c[Ea>>2];if((c[1167948]|0)<=0){break}Fa=b+252|0;Ba=0;do{do{if((wh(c[(c[1305380]|0)+(Ba<<2)>>2]|0,b)|0)!=0){if((c[Fa>>2]|0)==0){break}if((vh(c[(c[1305380]|0)+(Ba<<2)>>2]|0)|0)>=0){break}yDb(0,8,2012e3,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;yf(1)}}while(0);Ba=Ba+1|0;}while((Ba|0)<(c[1167948]|0))}}while(0);za=KEb(DRa()|0,qb,2004048)|0;Ka=b+248|0;Ha=c[Ka>>2]|0;if((Ha|0)<=0){sb=rb;tb=Ga;break}Ma=za;Pa=za;za=b+244|0;xa=Ga;Ba=rb;Fa=0;$a=Ha;while(1){if((c[Ma>>2]|0)==0){Ha=(c[_>>2]|0)+80|0;hb=c[Ha+4>>2]|0;c[Pa>>2]=c[Ha>>2];c[Pa+4>>2]=hb;ub=c[Ka>>2]|0}else{ub=$a}if((Fa|0)<(ub-1|0)){hb=c[Qa>>2]|0;Ha=MCb(hb,qb)|0;if((Ha|0)<0){sb=Ha;tb=xa;break e}else{vb=hb;wb=Ha}}else{vb=qb;wb=Ba}Ha=Gj(c[c[(c[za>>2]|0)+(Fa<<2)>>2]>>2]|0,vb,4)|0;do{if((Ha|0)==-541478725){xb=0}else{if((Ha|0)>=0){xb=Ha;break}TGb(pa|0,0,64)|0;a[pa]=0;GBb(Ha,pa,64)|0;yDb(0,8,1996424,(ia=i,i=i+8|0,c[ia>>2]=pa,ia)|0);i=ia;yf(1);xb=Ha}}while(0);Ha=Fa+1|0;hb=c[Ka>>2]|0;if((Ha|0)<(hb|0)){xa=xb;Ba=wb;Fa=Ha;$a=hb}else{sb=wb;tb=xb;break}}}}while(0);KCb(c[Qa>>2]|0);KCb(qb);ob=(sb|0)<0?sb:tb}}while(0);pa=c[O+48>>2]|0;do{if((pa|0)==0){la=c[_>>2]|0;ja=c[la+8>>2]|0;ka=c[ja+104>>2]|0;if((ka|0)==0){yb=-2147483648;zb=0;Ab=0;break}Ra=c[ja+108>>2]|0;if((Ra|0)==0){yb=-2147483648;zb=0;Ab=0;break}Ga=c[la+240>>2]|0;if((Ga|0)==0){Bb=c[ja+112>>2]|0}else{Bb=(c[Ga+36>>2]|0)+1|0}Ga=gHb(Bb,(Bb|0)<0|0?-1:0,1e6,0)|0;ja=gHb(Ga,F,ka,(ka|0)<0|0?-1:0)|0;ka=eHb(ja,F,Ra,(Ra|0)<0|0?-1:0)|0;Cb=ka;fa=141}else{ka=(c[_>>2]|0)+40|0;c[T>>2]=1;c[T+4>>2]=1e6;Ra=KDb(pa,(pa|0)<0|0?-1:0,ka,T)|0;Cb=Ra;fa=141}}while(0);do{if((fa|0)==141){fa=0;if((c[ca>>2]|0)==0&(c[ca+4>>2]|0)==(-2147483648|0)|(Cb|0)==0){yb=-2147483648;zb=0;Ab=Cb;break}pa=YGb(c[X>>2]|0,c[X+4>>2]|0,Cb,(Cb|0)<0|0?-1:0)|0;yb=F;zb=pa;Ab=Cb}}while(0);c[X>>2]=zb;c[X+4>>2]=yb;if((c[N>>2]|0)==0){qa=ob;break}pa=YGb(c[Z>>2]|0,c[Z+4>>2]|0,Ab,(Ab|0)<0|0?-1:0)|0;c[Z>>2]=pa;c[Z+4>>2]=F;qa=ob}else if((Y|0)==1){pa=y|0;Ra=z|0;ka=x;ja=b+20|0;Ga=c[ja>>2]|0;if((Ga|0)==0){la=ICb()|0;c[ja>>2]=la;if((la|0)==0){ha=-12;fa=251;break a}else{Db=la}}else{Db=Ga}Ga=b+24|0;if((c[Ga>>2]|0)==0){la=ICb()|0;c[Ga>>2]=la;if((la|0)==0){ha=-12;fa=251;break a}Eb=c[ja>>2]|0}else{Eb=Db}Kh(0,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;ja=A0a($,Eb,N,O)|0;la=b|0;Ea=c[c[_>>2]>>2]|0;Kh(1993296,(ia=i,i=i+16|0,c[ia>>2]=c[la>>2],c[ia+8>>2]=Ea,ia)|0);i=ia;do{if((ja|0)>-1){Ea=c[$+412>>2]|0;if((Ea|0)<1){yDb($,16,1989776,(ia=i,i=i+8|0,c[ia>>2]=Ea,ia)|0);i=ia;Fb=-1094995529;fa=35;break}Ea=c[N>>2]|0;if((Ea|0)!=0){Gb=ja;Hb=0;Ib=Ea;fa=38;break}if((c[S>>2]|0)==0){Jb=ja}else{Gb=ja;Hb=0;Ib=0;fa=38}}else{Fb=ja;fa=35}}while(0);if((fa|0)==35){fa=0;Gb=Fb;Hb=(Fb|0)<0;Ib=c[N>>2]|0;fa=38}do{if((fa|0)==38){fa=0;ja=8648280+(Gb>>>31<<3)|0;Ea=YGb(c[ja>>2]|0,c[ja+4>>2]|0,1,0)|0;c[ja>>2]=Ea;c[ja+4>>2]=F;if((Ib|0)==0|Hb){if((c[S>>2]|0)==0){Jb=Gb;break}else{qa=Gb;break b}}ja=Eb+76|0;Ea=c[ja>>2]|0;Ja=gHb(Ea,(Ea|0)<0|0?-1:0,1e6,0)|0;Ea=c[$+412>>2]|0;$a=eHb(Ja,F,Ea,(Ea|0)<0|0?-1:0)|0;Ea=F;Ja=YGb(c[Z>>2]|0,c[Z+4>>2]|0,$a,Ea)|0;c[Z>>2]=Ja;c[Z+4>>2]=F;Ja=YGb(c[X>>2]|0,c[X+4>>2]|0,$a,Ea)|0;c[X>>2]=Ja;c[X+4>>2]=F;Ja=b+136|0;Ea=Eb+80|0;do{if((c[Ja>>2]|0)==(c[Ea>>2]|0)){if((c[b+144>>2]|0)!=(c[$+416>>2]|0)){fa=47;break}$a=b+152|0;Fa=Eb+352|0;if(!((c[$a>>2]|0)==(c[Fa>>2]|0)&(c[$a+4>>2]|0)==(c[Fa+4>>2]|0))){fa=47;break}if((c[b+140>>2]|0)!=(c[Eb+344>>2]|0)){fa=47}}else{fa=47}}while(0);do{if((fa|0)==47){fa=0;Qa=w|0;Fa=c[_>>2]|0;$a=c[Fa+8>>2]|0;Ba=$a+448|0;f:do{if((c[Ba>>2]|0)==0&(c[Ba+4>>2]|0)==0){xa=$a+416|0;Ka=c[xa>>2]|0;do{if((Ka|0)>(c[b+120>>2]|0)){Kb=Fa}else{za=jBb(Ka)|0;Pa=F;c[Ba>>2]=za;c[Ba+4>>2]=Pa;if((za|0)==0&(Pa|0)==0){Kb=c[_>>2]|0;break}else{iBb(Qa,256,c[xa>>2]|0,za,Pa);Pa=c[c[_>>2]>>2]|0;yDb(0,24,1904720,(ia=i,i=i+24|0,c[ia>>2]=c[la>>2],c[ia+8>>2]=Pa,c[ia+16>>2]=Qa,ia)|0);i=ia;break f}}}while(0);xa=c[Kb>>2]|0;yDb(0,8,1986072,(ia=i,i=i+16|0,c[ia>>2]=c[la>>2],c[ia+8>>2]=xa,ia)|0);i=ia;yf(1)}}while(0);Qa=$+448|0;Ba=c[Qa+4>>2]|0;Fa=Eb+352|0;c[Fa>>2]=c[Qa>>2];c[Fa+4>>2]=Ba;Ba=b+144|0;Qa=b+152|0;iBb(pa,64,c[Ba>>2]|0,c[Qa>>2]|0,c[Qa+4>>2]|0);$a=$+416|0;iBb(Ra,64,c[$a>>2]|0,c[Fa>>2]|0,c[Fa+4>>2]|0);xa=c[la>>2]|0;Ka=c[c[_>>2]>>2]|0;Pa=b+140|0;za=c[Pa>>2]|0;Ma=wFb(c[Ja>>2]|0)|0;hb=c[Ba>>2]|0;Ha=Eb+344|0;gb=c[Ha>>2]|0;Va=wFb(c[Ea>>2]|0)|0;Ca=c[$a>>2]|0;yDb(0,32,1982424,(ia=i,i=i+80|0,c[ia>>2]=xa,c[ia+8>>2]=Ka,c[ia+16>>2]=za,c[ia+24>>2]=Ma,c[ia+32>>2]=hb,c[ia+40>>2]=pa,c[ia+48>>2]=gb,c[ia+56>>2]=Va,c[ia+64>>2]=Ca,c[ia+72>>2]=Ra,ia)|0);i=ia;c[Ja>>2]=c[Ea>>2];c[Pa>>2]=c[Ha>>2];Ha=c[Fa+4>>2]|0;c[Qa>>2]=c[Fa>>2];c[Qa+4>>2]=Ha;c[Ba>>2]=c[$a>>2];if((c[1167948]|0)>0){Mb=0}else{break}do{do{if((wh(c[(c[1305380]|0)+(Mb<<2)>>2]|0,b)|0)!=0){$a=c[(c[1305380]|0)+(Mb<<2)>>2]|0;if((vh($a)|0)<0){yDb(0,8,2012e3,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;yf(1)}Ba=$a+28|0;Ha=c[Ba>>2]|0;if((Ha|0)<=0){break}Qa=$a+24|0;$a=0;Fa=Ha;while(1){Ha=c[(c[(c[Qa>>2]|0)+($a<<2)>>2]|0)+4>>2]|0;Pa=c[Ha+60>>2]|0;do{if((c[Pa+8>>2]|0)==1){if((c[Pa+16>>2]&65536|0)!=0){Nb=Fa;break}yj(c[c[Ha+300>>2]>>2]|0,c[(c[(c[Ha+12>>2]|0)+8>>2]|0)+424>>2]|0);Nb=c[Ba>>2]|0}else{Nb=Fa}}while(0);Ha=$a+1|0;if((Ha|0)<(Nb|0)){$a=Ha;Fa=Nb}else{break}}}}while(0);Mb=Mb+1|0;}while((Mb|0)<(c[1167948]|0))}}while(0);Ea=Eb+136|0;Ja=c[Ea>>2]|0;Fa=c[Ea+4>>2]|0;do{if((Ja|0)==0&(Fa|0)==(-2147483648|0)){$a=Eb+144|0;Ba=c[$a>>2]|0;Qa=c[$a+4>>2]|0;if(!((Ba|0)==0&(Qa|0)==(-2147483648|0))){c[Ea>>2]=Ba;c[Ea+4>>2]=Qa;Qa=O+8|0;c[Qa>>2]=0;c[Qa+4>>2]=-2147483648;Qa=(c[_>>2]|0)+40|0;Ba=c[Qa+4>>2]|0;c[x>>2]=c[Qa>>2];c[x+4>>2]=Ba;break}Ba=O+8|0;Qa=c[Ba>>2]|0;$a=c[Ba+4>>2]|0;if((Qa|0)==0&($a|0)==(-2147483648|0)){Ha=c[ca+4>>2]|0;c[Ea>>2]=c[ca>>2];c[Ea+4>>2]=Ha;c[x>>2]=1;c[ka+4>>2]=1e6;break}else{c[Ea>>2]=Qa;c[Ea+4>>2]=$a;c[Ba>>2]=0;c[Ba+4>>2]=-2147483648;Ba=(c[_>>2]|0)+40|0;$a=c[Ba+4>>2]|0;c[x>>2]=c[Ba>>2];c[x+4>>2]=$a;break}}else{$a=$+104|0;c[A>>2]=1;c[A+4>>2]=1e6;Ba=KDb(Ja,Fa,$a,A)|0;Qa=F;c[Z>>2]=Ba;c[Z+4>>2]=Qa;c[da>>2]=Ba;c[da+4>>2]=Qa;c[X>>2]=Ba;c[X+4>>2]=Qa;c[ca>>2]=Ba;c[ca+4>>2]=Qa;Qa=$a;$a=c[Qa+4>>2]|0;c[x>>2]=c[Qa>>2];c[x+4>>2]=$a}}while(0);Fa=c[Ea>>2]|0;Ja=c[Ea+4>>2]|0;if(!((Fa|0)==0&(Ja|0)==(-2147483648|0))){c[B>>2]=1;$a=(c[(c[_>>2]|0)+8>>2]|0)+412|0;c[B+4>>2]=c[$a>>2];Qa=c[ja>>2]|0;c[C>>2]=1;c[C+4>>2]=c[$a>>2];$a=NDb(ka,Fa,Ja,B,Qa,b+80|0,C)|0;c[Ea>>2]=$a;c[Ea+4>>2]=F}$a=b+248|0;Qa=b+244|0;Ja=0;Fa=0;while(1){Ba=c[$a>>2]|0;if((Ja|0)>=(Ba|0)){Ob=Fa;break}if((Ja|0)<(Ba-1|0)){Ba=c[Ga>>2]|0;Ha=MCb(Ba,Eb)|0;if((Ha|0)<0){Ob=Ha;break}else{Pb=Ba}}else{Pb=Eb}Ba=Gj(c[c[(c[Qa>>2]|0)+(Ja<<2)>>2]>>2]|0,Pb,4)|0;Ha=(Ba|0)==-541478725?0:Ba;if((Ha|0)<0){Ob=Ha;break}else{Ja=Ja+1|0;Fa=Ha}}c[Ea>>2]=0;c[Ea+4>>2]=-2147483648;KCb(c[Ga>>2]|0);KCb(Eb);qa=(Ob|0)<0?Ob:Gb;break b}}while(0);Ga=b+248|0;if((c[Ga>>2]|0)<=0){qa=Jb;break}ka=b+244|0;Ra=0;while(1){Ij(c[c[(c[ka>>2]|0)+(Ra<<2)>>2]>>2]|0,0,0)|0;pa=Ra+1|0;if((pa|0)<(c[Ga>>2]|0)){Ra=pa}else{qa=Jb;break}}}else{ha=-1;fa=251;break a}}while(0);if((qa|0)<0){ha=qa;fa=251;break}ca=O+8|0;c[ca>>2]=0;c[ca+4>>2]=-2147483648;ca=O+16|0;c[ca>>2]=0;c[ca+4>>2]=-2147483648;if(R){fa=19;continue}ca=c[S>>2]|0;da=(c[(c[(c[_>>2]|0)+8>>2]|0)+8>>2]|0)==1?qa:ca;$=O+24|0;c[$>>2]=(c[$>>2]|0)+da;c[S>>2]=ca-da;fa=19}if((fa|0)==190){O=c[X>>2]|0;qa=c[X+4>>2]|0;R=b+48|0;c[R>>2]=O;c[R+4>>2]=qa;Jb=c[b+4>>2]|0;Gb=c[Jb+8>>2]|0;Ob=c[Gb+8>>2]|0;do{if((Ob|0)==1){Eb=c[Gb+424>>2]|0;Pb=gHb(Eb,(Eb|0)<0|0?-1:0,1e6,0)|0;Eb=c[Gb+412>>2]|0;C=eHb(Pb,F,Eb,(Eb|0)<0|0?-1:0)|0;Eb=YGb(O,qa,C,F)|0;C=F;c[X>>2]=Eb;c[X+4>>2]=C;Qb=C;Rb=Eb}else if((Ob|0)==0){Eb=b+108|0;C=c[Eb>>2]|0;if((C|0)!=0){Pb=b+112|0;c[U>>2]=c[Pb>>2];c[U+4>>2]=C;C=KDb(O,qa,595624,U)|0;B=YGb(C,F,1,0)|0;C=c[Eb>>2]|0;c[V>>2]=c[Pb>>2];c[V+4>>2]=C;C=KDb(B,F,V,595624)|0;B=F;c[X>>2]=C;c[X+4>>2]=B;Qb=B;Rb=C;break}C=c[d+48>>2]|0;if((C|0)!=0){c[W>>2]=1;c[W+4>>2]=1e6;B=KDb(C,(C|0)<0|0?-1:0,Jb+40|0,W)|0;C=YGb(c[X>>2]|0,c[X+4>>2]|0,B,F)|0;B=F;c[X>>2]=C;c[X+4>>2]=B;Qb=B;Rb=C;break}C=c[Gb+104>>2]|0;if((C|0)==0){Qb=qa;Rb=O;break}B=c[Jb+240>>2]|0;if((B|0)==0){Sb=c[Gb+112>>2]|0}else{Sb=(c[B+36>>2]|0)+1|0}B=gHb(Sb,(Sb|0)<0|0?-1:0,1e6,0)|0;Pb=gHb(B,F,C,(C|0)<0|0?-1:0)|0;C=c[Gb+108>>2]|0;B=eHb(Pb,F,C,(C|0)<0|0?-1:0)|0;C=YGb(O,qa,B,F)|0;B=F;c[X>>2]=C;c[X+4>>2]=B;Qb=B;Rb=C}else{Qb=qa;Rb=O}}while(0);O=c[R+4>>2]|0;qa=b+64|0;c[qa>>2]=c[R>>2];c[qa+4>>2]=O;c[Z>>2]=Rb;c[Z+4>>2]=Qb}else if((fa|0)==251){i=e;return ha|0}if(!((d|0)!=0&(c[1167936]|0)>0)){ha=0;i=e;return ha|0}fa=b|0;Qb=b+4|0;Z=J;Rb=H|0;O=H+4|0;qa=I|0;R=I+4|0;X=d+36|0;Gb=d+8|0;Sb=b+64|0;Jb=K+8|0;W=d+16|0;V=b+48|0;U=L|0;Ob=L+4|0;C=K+16|0;B=d+28|0;Pb=M|0;Eb=M+4|0;x=b+80|0;b=d+48|0;A=K+48|0;Mb=K+36|0;Nb=K+24|0;ia=K+28|0;Kb=d+24|0;w=K|0;Hb=D|0;Ib=D+4|0;N=G|0;Fb=G+4|0;Db=0;while(1){z=c[(c[1163658]|0)+(Db<<2)>>2]|0;y=z|0;ob=c[(c[1163660]|0)+(c[y>>2]<<2)>>2]|0;Ab=c[(c[1271690]|0)+(c[fa>>2]<<2)>>2]|0;g:do{if((c[z+8>>2]|0)==((c[c[Qb>>2]>>2]|0)+(c[Ab+12>>2]|0)|0)){yb=z+344|0;if((c[yb>>2]|0)!=0){break}zb=ob+24|0;Cb=c[zb>>2]|0;T=c[zb+4>>2]|0;zb=(Cb|0)==0&(T|0)==(-2147483648|0);if(!zb){Bb=c[Sb+4>>2]|0;if((Bb|0)<(T|0)|(Bb|0)==(T|0)&(c[Sb>>2]|0)>>>0<Cb>>>0){break}}if((c[z+16>>2]|0)!=0){break}Bb=zb?0:Cb;Cb=zb?0:T;c[Rb>>2]=1;c[O>>2]=1e6;T=z+12|0;zb=KDb(Bb,Cb,H,(c[T>>2]|0)+40|0)|0;tb=F;c[qa>>2]=1;c[R>>2]=1e6;sb=KDb(Bb,Cb,I,(c[Qb>>2]|0)+40|0)|0;qb=F;vZ(K);xb=c[z+20>>2]|0;do{if((xb|0)==0){if((c[X>>2]&1|0)!=0){break}if((c[z+360>>2]|0)==0){break g}}}while(0);wb=c[Gb>>2]|0;vb=c[Gb+4>>2]|0;ub=(xb|0)!=0;do{if((wb|0)==0&(vb|0)==(-2147483648|0)){if(ub){break}rb=c[Sb+4>>2]|0;if(!((rb|0)<(Cb|0)|(rb|0)==(Cb|0)&(c[Sb>>2]|0)>>>0<Bb>>>0)){break}if((c[z+364>>2]|0)==0){break g}}else{if(!(((vb|0)<(qb|0)|(vb|0)==(qb|0)&wb>>>0<sb>>>0)&(ub^1))){break}if((c[z+364>>2]|0)==0){break g}}}while(0);ub=ob+16|0;sb=c[ub>>2]|0;wb=c[ub+4>>2]|0;do{if(!((sb|0)==(-1|0)&(wb|0)==2147483647)){ub=c[Sb>>2]|0;qb=c[Sb+4>>2]|0;vb=YGb(sb,wb,Bb,Cb)|0;xb=F;if((qb|0)<(xb|0)|(qb|0)==(xb|0)&ub>>>0<vb>>>0){break}vb=c[(c[1163660]|0)+(c[y>>2]<<2)>>2]|0;c[yb>>2]=c[yb>>2]|1;if((c[vb+40>>2]|0)==0){break g}ub=z+32|0;xb=z+40|0;qb=ZGb(c[ub>>2]|0,c[ub+4>>2]|0,c[xb>>2]|0,c[xb+4>>2]|0)|0;xb=(c[(c[T>>2]|0)+8>>2]|0)+104|0;c[N>>2]=1;c[Fb>>2]=1e6;ub=KDb(qb,F,xb,G)|0;xb=F;qb=vb+16|0;vb=c[qb>>2]|0;rb=c[qb+4>>2]|0;s=(rb|0)>(xb|0)|(rb|0)==(xb|0)&vb>>>0>ub>>>0;c[qb>>2]=s?ub:vb;c[qb+4>>2]=s?xb:rb;break g}}while(0);Cb=Ab+48|0;Bb=c[Cb>>2]|0;wb=c[Cb+4>>2]|0;do{if(!((Bb|0)==(-1|0)&(wb|0)==2147483647)){Cb=(c[Ab>>2]|0)+1056|0;sb=Ab+40|0;rb=c[sb>>2]|0;xb=c[sb+4>>2]|0;sb=(rb|0)==0&(xb|0)==(-2147483648|0);s=c[Sb>>2]|0;qb=c[Sb+4>>2]|0;vb=YGb(c[Cb>>2]|0,c[Cb+4>>2]|0,Bb,wb)|0;Cb=YGb(vb,F,sb?0:rb,sb?0:xb)|0;xb=F;if((qb|0)<(xb|0)|(qb|0)==(xb|0)&s>>>0<Cb>>>0){break}Cb=c[(c[1163660]|0)+(c[y>>2]<<2)>>2]|0;c[yb>>2]=c[yb>>2]|1;if((c[Cb+40>>2]|0)==0){break g}s=z+32|0;xb=z+40|0;qb=ZGb(c[s>>2]|0,c[s+4>>2]|0,c[xb>>2]|0,c[xb+4>>2]|0)|0;xb=(c[(c[T>>2]|0)+8>>2]|0)+104|0;c[Hb>>2]=1;c[Ib>>2]=1e6;s=KDb(qb,F,xb,D)|0;xb=F;qb=Cb+16|0;Cb=c[qb>>2]|0;sb=c[qb+4>>2]|0;rb=(sb|0)>(xb|0)|(sb|0)==(xb|0)&Cb>>>0>s>>>0;c[qb>>2]=rb?s:Cb;c[qb+4>>2]=rb?xb:sb;break g}}while(0);yb=c[T>>2]|0;wb=c[(c[yb+8>>2]|0)+8>>2]|0;if((wb|0)==1){Bb=c[B>>2]|0;sb=YGb(c[2291712]|0,c[2291713]|0,Bb,(Bb|0)<0|0?-1:0)|0;c[2291712]=sb;c[2291713]=F}else if((wb|0)==0){sb=c[B>>2]|0;Bb=YGb(c[646526]|0,c[646527]|0,sb,(sb|0)<0|0?-1:0)|0;c[646526]=Bb;c[646527]=F;Bb=z+32|0;sb=YGb(c[Bb>>2]|0,c[Bb+4>>2]|0,1,0)|0;c[Bb>>2]=sb;c[Bb+4>>2]=F}else if((wb|0)==2){Bb=c[B>>2]|0;sb=YGb(c[2187440]|0,c[2187441]|0,Bb,(Bb|0)<0|0?-1:0)|0;c[2187440]=sb;c[2187441]=F}else if((wb|0)==3){wb=c[B>>2]|0;sb=YGb(c[1071076]|0,c[1071077]|0,wb,(wb|0)<0|0?-1:0)|0;c[1071076]=sb;c[1071077]=F}sb=c[Gb>>2]|0;wb=c[Gb+4>>2]|0;if((sb|0)==0&(wb|0)==(-2147483648|0)){Tb=-2147483648;Ub=0}else{Bb=KDb(sb,wb,(c[Qb>>2]|0)+40|0,yb+40|0)|0;yb=ZGb(Bb,F,zb,tb)|0;Tb=F;Ub=yb}c[Jb>>2]=Ub;c[Jb+4>>2]=Tb;yb=c[W>>2]|0;Bb=c[W+4>>2]|0;if((yb|0)==0&(Bb|0)==(-2147483648|0)){wb=c[V>>2]|0;sb=c[V+4>>2]|0;c[U>>2]=1;c[Ob>>2]=1e6;xb=KDb(wb,sb,L,(c[T>>2]|0)+40|0)|0;Vb=F;Wb=xb}else{xb=KDb(yb,Bb,(c[Qb>>2]|0)+40|0,(c[T>>2]|0)+40|0)|0;Vb=F;Wb=xb}xb=ZGb(Wb,Vb,zb,tb)|0;c[C>>2]=xb;c[C+4>>2]=F;xb=c[T>>2]|0;do{if((c[(c[xb+8>>2]|0)+8>>2]|0)==1){if((c[W>>2]|0)==0&(c[W+4>>2]|0)==(-2147483648|0)){Xb=xb;break}Bb=O0a(c[(c[Qb>>2]|0)+8>>2]|0,c[B>>2]|0)|0;yb=c[Qb>>2]|0;sb=c[yb+8>>2]|0;if((Bb|0)==0){Yb=c[sb+424>>2]|0}else{Yb=Bb}Bb=c[W>>2]|0;wb=c[W+4>>2]|0;c[Pb>>2]=1;c[Eb>>2]=c[sb+412>>2];sb=NDb(yb+40|0,Bb,wb,M,Yb,x,(c[T>>2]|0)+40|0)|0;wb=ZGb(sb,F,zb,tb)|0;sb=F;c[Jb>>2]=wb;c[Jb+4>>2]=sb;c[C>>2]=wb;c[C+4>>2]=sb;Xb=c[T>>2]|0}else{Xb=xb}}while(0);xb=c[b>>2]|0;tb=KDb(xb,(xb|0)<0|0?-1:0,(c[Qb>>2]|0)+40|0,Xb+40|0)|0;c[A>>2]=tb;tb=c[X>>2]|0;c[Mb>>2]=tb;xb=c[(c[T>>2]|0)+8>>2]|0;zb=c[xb+48>>2]|0;do{if((zb|0)==28|(zb|0)==1|(zb|0)==2|(zb|0)==71){c[Nb>>2]=c[Kb>>2];c[ia>>2]=c[B>>2]}else{if((URa(c[z+372>>2]|0,xb,Nb,ia,c[Kb>>2]|0,c[B>>2]|0,tb&1)|0)==0){break}sb=SAb(c[Nb>>2]|0,c[ia>>2]|0,98,0,0)|0;c[w>>2]=sb;if((sb|0)!=0){break}yf(1)}}while(0);AZ(K,d)|0;tb=c[(c[T>>2]|0)+8>>2]|0;xb=ob|0;do{if((c[tb+8>>2]|0)==0){if((c[(c[(c[xb>>2]|0)+8>>2]|0)+28>>2]&32|0)==0){break}OZ(J,c[Nb>>2]|0,c[tb+140>>2]|0,c[tb+120>>2]|0,c[tb+124>>2]|0)|0;c[Nb>>2]=Z;c[ia>>2]=64;c[Mb>>2]=c[Mb>>2]|1}}while(0);Lh(c[xb>>2]|0,K,z);tb=(c[(c[T>>2]|0)+8>>2]|0)+428|0;c[tb>>2]=(c[tb>>2]|0)+1}}while(0);z=Db+1|0;if((z|0)<(c[1167936]|0)){Db=z}else{ha=0;break}}i=e;return ha|0}function Kh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+1176|0;e=d|0;f=d+136|0;if((c[2128650]|0)==0){i=d;return}nd(0,e|0)|0;g=c[e>>2]|0;h=gHb(g,(g|0)<0|0?-1:0,1e6,0)|0;g=c[e+4>>2]|0;e=YGb(h,F,g,(g|0)<0|0?-1:0)|0;g=F;if((a|0)!=0){h=f;c[h>>2]=b;c[h+4>>2]=0;h=d+152|0;wd(h|0,1024,a|0,f|0)|0;f=c[2187442]|0;a=ZGb(e,g,f,(f|0)<0|0?-1:0)|0;f=F;Ic(2066120,(g=i,i=i+24|0,c[g>>2]=a,c[g+8>>2]=f,c[g+16>>2]=h,g)|0)|0;i=g}c[2187442]=e;i=d;return}function Lh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+208|0;g=f|0;j=f+80|0;k=f+112|0;l=f+144|0;m=f+176|0;n=c[e+56>>2]|0;o=e+12|0;p=c[(c[o>>2]|0)+8>>2]|0;q=p+8|0;r=c[q>>2]|0;s=(r|0)==0;if(s&(c[34030]|0)==255){t=3}else{if((r|0)==1&(c[2291710]|0)<0){t=3}}if((t|0)==3){r=d+16|0;c[r>>2]=0;c[r+4>>2]=-2147483648;r=d+8|0;c[r>>2]=0;c[r+4>>2]=-2147483648}if(s){if((c[p+12>>2]|0)==0){t=6}}else{t=6}do{if((t|0)==6){s=e+20|0;r=c[s>>2]|0;u=(r|0)<0|0?-1:0;v=e+64|0;w=c[v+4>>2]|0;if((u|0)<(w|0)|(u|0)==(w|0)&r>>>0<(c[v>>2]|0)>>>0){c[s>>2]=r+1;break}BZ(d);i=f;return}}while(0);if((n|0)!=0){r=g;s=d;v=g+24|0;w=g+28|0;u=d+24|0;x=d+28|0;y=d+36|0;z=g+52|0;A=g|0;g=d+32|0;B=p+12|0;C=n;do{UGb(r|0,s|0,80)|0;n=U_(C,p,0,v,w,c[u>>2]|0,c[x>>2]|0,c[y>>2]&1)|0;do{if((n|0)==0){if((c[v>>2]|0)==(c[u>>2]|0)){break}if((c[z>>2]|0)==0){t=16;break}D=WDb((c[w>>2]|0)+16|0)|0;if((D|0)==0){E=-12;t=20;break}G=c[w>>2]|0;UGb(D|0,c[v>>2]|0,G)|0;TGb(D+G|0,0,16)|0;c[v>>2]=D;c[A>>2]=0;t=17}else{t=16}}while(0);do{if((t|0)==16){t=0;if((n|0)>0){t=17;break}if((n|0)<0){E=n;t=20}}}while(0);do{if((t|0)==17){t=0;BZ(d);n=SAb(c[v>>2]|0,c[w>>2]|0,98,0,0)|0;c[A>>2]=n;if((n|0)!=0){break}yf(1)}else if((t|0)==20){t=0;n=c[g>>2]|0;D=c[B>>2]|0;if((D|0)==0){H=2122856}else{H=c[D>>2]|0}yDb(0,16,2129256,(I=i,i=i+24|0,c[I>>2]=c[c[C+4>>2]>>2],c[I+8>>2]=n,c[I+16>>2]=H,I)|0);i=I;Sf(9203128,E);if((c[2039022]|0)==0){break}yf(1)}}while(0);UGb(s|0,r|0,80)|0;C=c[C+12>>2]|0;}while((C|0)!=0)}C=c[(c[b+8>>2]|0)+28>>2]|0;do{if((C&128|0)==0){r=c[q>>2]|0;if(!(r>>>0<2>>>0)){break}s=d+16|0;E=c[s>>2]|0;H=c[s+4>>2]|0;if((E|0)==0&(H|0)==(-2147483648|0)){break}B=e+48|0;g=c[B>>2]|0;t=c[B+4>>2]|0;if((g|0)==0&(t|0)==(-2147483648|0)){break}B=YGb(g,t,C>>>17&1^1,0)|0;A=F;if(!((H|0)<(A|0)|(H|0)==(A|0)&E>>>0<B>>>0)){break}w=ZGb(B,A,E,H)|0;v=F;z=0;if((v|0)>(z|0)|(v|0)==(z|0)&w>>>0>2>>>0){J=24}else{J=(r|0)==0?24:48}r=b;w=c[c[o>>2]>>2]|0;yDb(r,J,2117648,(I=i,i=i+48|0,c[I>>2]=c[e>>2],c[I+8>>2]=w,c[I+16>>2]=g,c[I+24>>2]=t,c[I+32>>2]=E,c[I+40>>2]=H,I)|0);i=I;if((c[2039022]|0)!=0){yDb(0,8,2107104,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;yf(1)}yDb(r,J,2096024,(I=i,i=i+16|0,c[I>>2]=B,c[I+8>>2]=A,I)|0);i=I;r=d+8|0;H=c[r>>2]|0;E=c[r+4>>2]|0;t=c[s+4>>2]|0;if(!((E|0)<(t|0)|(E|0)==(t|0)&H>>>0<(c[s>>2]|0)>>>0)){t=(E|0)>(A|0)|(E|0)==(A|0)&H>>>0>B>>>0;c[r>>2]=t?H:B;c[r+4>>2]=t?E:A}c[s>>2]=B;c[s+4>>2]=A}}while(0);J=d+16|0;C=c[J+4>>2]|0;q=e+48|0;c[q>>2]=c[J>>2];c[q+4>>2]=C;c[d+32>>2]=c[e+4>>2];if((c[2163098]|0)!=0){C=lGb(c[(c[(c[o>>2]|0)+8>>2]|0)+8>>2]|0)|0;q=j|0;TGb(q|0,0,32)|0;a[q]=0;j=d+8|0;A=c[j>>2]|0;s=c[j+4>>2]|0;if((A|0)==0&(s|0)==(-2147483648|0)){Lb(q|0,32,2080488,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Lb(q|0,32,2070656,(I=i,i=i+16|0,c[I>>2]=A,c[I+8>>2]=s,I)|0)|0;i=I}s=k|0;TGb(s|0,0,32)|0;a[s]=0;k=c[j>>2]|0;A=c[j+4>>2]|0;j=c[o>>2]|0;if((k|0)==0&(A|0)==(-2147483648|0)){Lb(s|0,32,2080488,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Lb(s|0,32,2075240,(I=i,i=i+8|0,h[I>>3]=(+(k>>>0)+ +(A|0)*4294967296.0)*(+(c[j+40>>2]|0)/+(c[j+44>>2]|0)),I)|0)|0;i=I}j=l|0;TGb(j|0,0,32)|0;a[j]=0;l=c[J>>2]|0;A=c[J+4>>2]|0;if((l|0)==0&(A|0)==(-2147483648|0)){Lb(j|0,32,2080488,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Lb(j|0,32,2070656,(I=i,i=i+16|0,c[I>>2]=l,c[I+8>>2]=A,I)|0)|0;i=I}A=m|0;TGb(A|0,0,32)|0;a[A]=0;m=c[J>>2]|0;l=c[J+4>>2]|0;J=c[o>>2]|0;if((m|0)==0&(l|0)==(-2147483648|0)){Lb(A|0,32,2080488,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Lb(A|0,32,2075240,(I=i,i=i+8|0,h[I>>3]=(+(m>>>0)+ +(l|0)*4294967296.0)*(+(c[J+40>>2]|0)/+(c[J+44>>2]|0)),I)|0)|0;i=I}J=c[d+28>>2]|0;yDb(0,32,2090584,(I=i,i=i+48|0,c[I>>2]=C,c[I+8>>2]=q,c[I+16>>2]=s,c[I+24>>2]=j,c[I+32>>2]=A,c[I+40>>2]=J,I)|0);i=I}I=MK(b,d)|0;if((I|0)>=0){i=f;return}Sf(2085576,I);a[686568]=1;if((c[1167936]|0)>0){K=0}else{i=f;return}do{I=c[(c[1163658]|0)+(K<<2)>>2]|0;d=I+344|0;c[d>>2]=((I|0)==(e|0)?3:1)|c[d>>2];K=K+1|0;}while((K|0)<(c[1167936]|0));i=f;return}function Mh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0.0,k=0,l=0.0,m=0.0;d=i;do{if((c[636776]|0)==0){e=Kc(c[636774]|0,2184032)|0;c[636776]=e;if((e|0)!=0){break}Ab(2168968);yf(1)}}while(0);e=a+12|0;a=c[e>>2]|0;f=c[a+8>>2]|0;if((c[f+8>>2]|0)!=0){i=d;return}g=f+804|0;j=+(c[(c[g>>2]|0)+168>>2]|0)/118.0;Dd(c[636776]|0,2161416,(k=i,i=i+16|0,c[k>>2]=c[a+64>>2],h[k+8>>3]=j,k)|0)|0;i=k;if((c[f+88>>2]&32768|0)!=0){a=(c[g>>2]|0)+224|0;j=+$((+((c[a>>2]|0)>>>0)+ +((c[a+4>>2]|0)>>>0)*4294967296.0)/(+(ba(c[f+124>>2]|0,c[f+120>>2]|0)|0)*255.0*255.0))*-10.0/2.302585092994046;Dd(c[636776]|0,2154800,(k=i,i=i+8|0,h[k>>3]=j,k)|0)|0;i=k}Dd(c[636776]|0,2147752,(k=i,i=i+8|0,c[k>>2]=b,k)|0)|0;i=k;a=(c[e>>2]|0)+16|0;j=+(c[f+104>>2]|0)/+(c[f+108>>2]|0);l=(+((c[a>>2]|0)>>>0)+ +(c[a+4>>2]|0)*4294967296.0)*j;m=l<.01?.01:l;a=c[646526]|0;f=c[646527]|0;Dd(c[636776]|0,2141304,(k=i,i=i+32|0,h[k>>3]=(+(a>>>0)+ +(f|0)*4294967296.0)*.0009765625,h[k+8>>3]=m,h[k+16>>3]=+(b<<3|0)/j/1.0e3,h[k+24>>3]=(+((a<<3|0>>>29)>>>0)+ +(f<<3|a>>>29|0)*4294967296.0)/m/1.0e3,k)|0)|0;i=k;a=c[636776]|0;f=(mGb(c[(c[g>>2]|0)+88>>2]|0)|0)<<24>>24;Dd(a|0,2135400,(k=i,i=i+8|0,c[k>>2]=f,k)|0)|0;i=k;i=d;return}function Nh(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a+228|0;j=c[h>>2]|0;k=a+232|0;l=c[k>>2]|0;m=a+224|0;n=c[m>>2]|0;if((n|0)==0){i=e;return}if((b|0)==0){o=a+216|0;p=2147483647;q=-1;r=c[o+4>>2]|0;s=c[o>>2]|0;t=0;u=n}else{o=b+24|0;v=YGb((c[b+4>>2]|0)*1e3|0,0,c[o>>2]|0,c[o+4>>2]|0)|0;c[f>>2]=1;c[f+4>>2]=1e6;w=a+4|0;x=KDb(v,F,f,(c[w>>2]|0)+40|0)|0;f=F;v=YGb((c[b+8>>2]|0)*1e3|0,0,c[o>>2]|0,c[o+4>>2]|0)|0;c[g>>2]=1;c[g+4>>2]=1e6;o=KDb(v,F,g,(c[w>>2]|0)+40|0)|0;p=F;q=o;r=f;s=x;t=c[b+12>>2]|0;u=c[m>>2]|0}KCb(u);x=c[m>>2]|0;c[x+68>>2]=c[h>>2];c[x+72>>2]=c[k>>2];c[x+80>>2]=30;if((LCb(u,32)|0)<0){yDb(c[(c[a+4>>2]|0)+8>>2]|0,16,2034520,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;i=e;return}TGb(c[u>>2]|0,0,ba(c[u+32>>2]|0,c[u+72>>2]|0)|0)|0;u=c[n>>2]|0;x=c[n+32>>2]|0;if((t|0)>0){n=b+16|0;b=0;do{k=c[(c[n>>2]|0)+(b<<2)>>2]|0;a:do{if((c[k+84>>2]|0)==1){h=c[k>>2]|0;do{if((h|0)>=0){f=k+8|0;o=c[f>>2]|0;if((o+h|0)>(j|0)){break}w=c[k+4>>2]|0;if((w|0)<0){break}g=k+12|0;v=c[g>>2]|0;if((v+w|0)>(l|0)){break}z=c[k+24>>2]|0;if((v|0)<=0){break a}A=(ba(w,x)|0)+(h<<2)|0;w=k+52|0;B=u+A|0;A=c[k+20>>2]|0;C=0;D=o;o=v;while(1){if((D|0)>0){v=B;E=A;G=0;while(1){c[v>>2]=c[z+((d[E]|0)<<2)>>2];H=G+1|0;I=c[f>>2]|0;if((H|0)<(I|0)){v=v+4|0;E=E+1|0;G=H}else{break}}J=I;K=c[g>>2]|0}else{J=D;K=o}G=C+1|0;if((G|0)<(K|0)){B=B+x|0;A=A+(c[w>>2]|0)|0;C=G;D=J;o=K}else{break a}}}}while(0);yDb(0,24,2026352,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}else{yDb(0,24,2030288,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}}while(0);b=b+1|0;}while((b|0)<(t|0))}t=c[m>>2]|0;m=t+136|0;c[m>>2]=s;c[m+4>>2]=r;m=a+208|0;c[m>>2]=s;c[m+4>>2]=r;r=a+248|0;if((c[r>>2]|0)>0){m=a+244|0;s=0;do{Gj(c[c[(c[m>>2]|0)+(s<<2)>>2]>>2]|0,t,12)|0;s=s+1|0;}while((s|0)<(c[r>>2]|0))}r=a+216|0;c[r>>2]=q;c[r+4>>2]=p;i=e;return}function Oh(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0,db=0,eb=0,fb=0.0,gb=0.0,hb=0,ib=0,jb=0,kb=0.0,lb=0.0,mb=0,nb=0,ob=0,pb=0,qb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0.0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Mb=0,Nb=0;b=i;i=i+664|0;d=b|0;e=b+8|0;f=b+16|0;j=b+96|0;k=b+104|0;l=b+112|0;m=b+120|0;n=b+200|0;o=b+592|0;if((c[1167936]|0)<=0){p=0;i=b;return p|0}r=b+528|0;s=b+208|0;t=b+240|0;u=b+272|0;v=b+304|0;w=b+336|0;x=b+368|0;y=b+400|0;z=b+432|0;A=b+464|0;B=b+496|0;C=m+24|0;D=m+28|0;E=m+8|0;G=m+16|0;H=m+36|0;I=l|0;J=l+4|0;K=k|0;L=k+4|0;M=b+600|0;N=b+632|0;O=f+24|0;P=f+28|0;Q=f+8|0;R=f+16|0;S=f+48|0;T=e|0;U=e+4|0;V=d|0;W=d+4|0;X=o|0;Y=o+4|0;Z=0;a:while(1){_=c[(c[1163658]|0)+(Z<<2)>>2]|0;$=_|0;aa=c[(c[1163660]|0)+(c[$>>2]<<2)>>2]|0;ba=_+12|0;ca=c[(c[ba>>2]|0)+8>>2]|0;da=c[_+300>>2]|0;do{if((da|0)!=0){ea=c[da>>2]|0;fa=_+72|0;ga=c[fa>>2]|0;if((ga|0)==0){ha=ICb()|0;c[fa>>2]=ha;if((ha|0)==0){p=-12;ia=187;break a}else{ja=ha}}else{ja=ga}ga=xj(ea,ja,2)|0;if((ga|0)<0){ka=ga}else{ga=_+344|0;ha=ja+136|0;fa=ea+16|0;la=_+92|0;ma=ja+124|0;na=ca+224|0;oa=aa|0;pa=_+8|0;qa=_+76|0;ra=_+80|0;sa=_+32|0;ta=_+20|0;ua=_+64|0;va=ja+296|0;wa=ja+168|0;xa=ja+88|0;ya=_+108|0;za=_+104|0;Aa=_+100|0;Ba=_+116|0;Ca=_+152|0;Da=_+120|0;Ea=_+136|0;Fa=_+144|0;Ga=_+128|0;Ha=_+4|0;Ia=_+296|0;Ja=ja+300|0;Ka=_+88|0;La=ja;Ma=_+40|0;Na=ca+104|0;Oa=Na|0;Pa=ca+108|0;Qa=ca+12|0;Ra=ca+416|0;Sa=ja+76|0;Ta=aa+24|0;while(1){if((c[ga>>2]|0)==0){Ua=c[ha>>2]|0;Va=c[ha+4>>2]|0;if((Ua|0)==0&(Va|0)==(-2147483648|0)){Wa=-2147483648;Xa=0}else{Ya=c[Ta>>2]|0;Za=c[Ta+4>>2]|0;_a=(Ya|0)==0&(Za|0)==(-2147483648|0);$a=KDb(Ua,Va,(c[c[fa>>2]>>2]|0)+56|0,Na)|0;Va=F;c[X>>2]=1;c[Y>>2]=1e6;Ua=KDb(_a?0:Ya,_a?0:Za,o,Na)|0;Za=ZGb($a,Va,Ua,F)|0;Ua=F;c[ha>>2]=Za;c[ha+4>>2]=Ua;Wa=Ua;Xa=Za}Za=c[(c[c[fa>>2]>>2]|0)+16>>2]|0;b:do{if((Za|0)==0){c[ha>>2]=Xa;c[ha+4>>2]=Wa;if((c[la>>2]|0)==0){Ua=c[ma+4>>2]|0;c[na>>2]=c[ma>>2];c[na+4>>2]=Ua}if((c[2163098]|0)!=0){TGb(M|0,0,32)|0;a[M]=0;Ua=c[ha>>2]|0;Va=c[ha+4>>2]|0;if((Ua|0)==0&(Va|0)==(-2147483648|0)){Lb(M|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(M|0,32,2070656,(ab=i,i=i+16|0,c[ab>>2]=Ua,c[ab+8>>2]=Va,ab)|0)|0;i=ab}TGb(N|0,0,32)|0;a[N]=0;Va=c[ha>>2]|0;Ua=c[ha+4>>2]|0;if((Va|0)==0&(Ua|0)==(-2147483648|0)){Lb(N|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(N|0,32,2075240,(ab=i,i=i+8|0,h[ab>>3]=(+(Va>>>0)+ +(Ua|0)*4294967296.0)*(+(c[Oa>>2]|0)/+(c[Pa>>2]|0)),ab)|0)|0;i=ab}Ua=c[Oa>>2]|0;Va=c[Pa>>2]|0;yDb(0,32,1887472,(ab=i,i=i+32|0,c[ab>>2]=M,c[ab+8>>2]=N,c[ab+16>>2]=Ua,c[ab+24>>2]=Va,ab)|0);i=ab}Va=c[oa>>2]|0;Ua=c[(c[ba>>2]|0)+8>>2]|0;$a=c[pa>>2]|0;do{if(($a|0)>-1){_a=c[(c[1271688]|0)+($a<<2)>>2]|0;if((_a|0)==0){bb=0.0;cb=0;db=0;break}Ya=c[_a+4>>2]|0;eb=Ya+48|0;if((c[eb>>2]|0)==0&(c[eb+4>>2]|0)==(-2147483648|0)){bb=0.0;cb=_a;db=1;break}eb=Ya+200|0;if((c[eb>>2]|0)==0&(c[eb+4>>2]|0)==(-2147483648|0)){bb=0.0;cb=_a;db=1;break}eb=c[qa>>2]|0;if((eb|0)==0){bb=0.0;cb=_a;db=1;break}bb=1.0/(+(eb|0)/+(c[ra>>2]|0)*(+(c[Ua+104>>2]|0)/+(c[Ua+108>>2]|0)));cb=_a;db=1}else{bb=0.0;cb=0;db=0}}while(0);fb=+((c[ha>>2]|0)>>>0)+ +(c[ha+4>>2]|0)*4294967296.0;gb=bb+(fb-(+((c[sa>>2]|0)>>>0)+ +(c[sa+4>>2]|0)*4294967296.0));$a=c[34030]|0;if(($a|0)==-1){_a=c[Va+8>>2]|0;do{if((QGb(c[_a>>2]|0,2351112)|0)==0){hb=2}else{eb=c[_a+28>>2]|0;if((eb&1024|0)==0){ib=1}else{ib=eb>>>6&2^2}if(!(db&(ib|0)==1)){hb=ib;break}eb=c[(c[1271690]|0)+(c[cb>>2]<<2)>>2]|0;if((c[(c[eb>>2]|0)+24>>2]|0)!=1){hb=1;break}Ya=eb+16|0;hb=(c[Ya>>2]|0)==0&(c[Ya+4>>2]|0)==0?254:1}}while(0);jb=(hb|0)==1&(c[2192648]|0)!=0?254:hb}else{jb=$a}c:do{switch(jb|0){case 254:{if((c[ta>>2]|0)!=0){kb=gb;ia=44;break c}lb=gb-bb;if(lb<.5){kb=gb;ia=44;break c}_a=Gc(+lb)|0;yDb(0,48,2346760,(ab=i,i=i+8|0,c[ab>>2]=_a,ab)|0);i=ab;_a=Gc(+fb)|0;c[sa>>2]=_a;c[sa+4>>2]=(_a|0)<0|0?-1:0;kb=bb;ia=44;break};case 1:{kb=gb;ia=44;break};case 2:{if(!(gb>-.6)){mb=0;nb=0;break c}if(!(gb>.6)){mb=0;nb=1;break c}_a=Gc(+fb)|0;c[sa>>2]=_a;c[sa+4>>2]=(_a|0)<0|0?-1:0;mb=0;nb=1;break};case 255:case 0:{_a=Gc(+fb)|0;c[sa>>2]=_a;c[sa+4>>2]=(_a|0)<0|0?-1:0;mb=0;nb=1;break};default:{ia=51;break a}}}while(0);do{if((ia|0)==44){ia=0;if(kb<-1.1){mb=0;nb=0;break}if(!(kb>1.1)){mb=0;nb=1;break}$a=Gc(+kb)|0;mb=($a|0)<0|0?-1:0;nb=$a}}while(0);$a=c[ta>>2]|0;_a=ZGb(c[ua>>2]|0,c[ua+4>>2]|0,$a,($a|0)<0|0?-1:0)|0;$a=F;Ya=(mb|0)>($a|0)|(mb|0)==($a|0)&nb>>>0>_a>>>0;eb=Ya?_a:nb;Ya?$a:mb;$a=eb;if(($a|0)==0){c[1167946]=(c[1167946]|0)+1;yDb(0,40,2345488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;break}do{if(($a|0)>1){eb=$a-1|0;if(+($a|0)>+g[337016]*30.0){yDb(0,16,2343880,(ab=i,i=i+8|0,c[ab>>2]=eb,ab)|0);i=ab;c[1167946]=(c[1167946]|0)+1;break b}else{c[1167944]=(c[1167944]|0)+eb;yDb(0,40,2342640,(ab=i,i=i+8|0,c[ab>>2]=eb,ab)|0);i=ab;break}}}while(0);if(($a|0)<=0){break}eb=Va+8|0;Ya=Ua+408|0;_a=Ua+316|0;ob=Ua+12|0;pb=Ua+668|0;qb=Ua+104|0;sb=qb|0;tb=Ua+108|0;ub=Ua+104|0;vb=Ua+804|0;wb=0;xb=0;while(1){vZ(m);c[C>>2]=0;c[D>>2]=0;yb=c[sa+4>>2]|0;c[ha>>2]=c[sa>>2];c[ha+4>>2]=yb;yb=(c[(c[1163660]|0)+(c[$>>2]<<2)>>2]|0)+16|0;zb=c[yb>>2]|0;Ab=c[yb+4>>2]|0;if(!((zb|0)==(-1|0)&(Ab|0)==2147483647)){yb=ZGb(c[sa>>2]|0,c[sa+4>>2]|0,c[Ma>>2]|0,c[Ma+4>>2]|0)|0;Bb=(c[(c[ba>>2]|0)+8>>2]|0)+104|0;c[I>>2]=1;c[J>>2]=1e6;if((LDb(yb,F,Bb,zb,Ab,l)|0)>-1){break}}do{if((c[(c[eb>>2]|0)+28>>2]&32|0)==0){ia=69}else{if((c[(c[ob>>2]|0)+12>>2]|0)!=14){ia=69;break}Ab=c[va>>2]|0;zb=c[vb>>2]|0;c[zb+296>>2]=Ab;Bb=c[Ja>>2]|0;c[zb+300>>2]=Bb;if((Ab|0)==0){Cb=1}else{Cb=(Bb|0)!=0?4:5}c[Ya>>2]=Cb;c[C>>2]=La;c[D>>2]=64;Bb=KDb(c[ha>>2]|0,c[ha+4>>2]|0,qb,(c[ba>>2]|0)+40|0)|0;c[E>>2]=Bb;c[E+4>>2]=F;c[H>>2]=c[H>>2]|1;Bb=c[D>>2]|0;Ab=YGb(c[646526]|0,c[646527]|0,Bb,(Bb|0)<0|0?-1:0)|0;c[646526]=Ab;c[646527]=F;Lh(Va,m,_);Db=xb}}while(0);do{if((ia|0)==69){ia=0;Ab=c[(c[ba>>2]|0)+8>>2]|0;do{if((c[Ab+88>>2]&537133056|0)!=0){Bb=c[Ka>>2]|0;if(!((Bb|0)>-1)){break}c[Ja>>2]=(Bb|0)!=0}}while(0);do{if((c[va>>2]|0)==0){c[Ya>>2]=1}else{Bb=(c[Ja>>2]|0)!=0;if((c[(c[ob>>2]|0)+12>>2]|0)==8){c[Ya>>2]=Bb?2:3;break}else{c[Ya>>2]=Bb?4:5;break}}}while(0);c[wa>>2]=c[Ab+80>>2];if((c[_a>>2]|0)==0){c[xa>>2]=0}Bb=c[ha>>2]|0;zb=c[ha+4>>2]|0;if((Bb|0)==0&(zb|0)==(-2147483648|0)){Eb=+q}else{Eb=(+(Bb>>>0)+ +(zb|0)*4294967296.0)*(+(c[ub>>2]|0)/+(c[tb>>2]|0))}yb=c[ya>>2]|0;do{if((yb|0)<(c[za>>2]|0)){Fb=(c[Aa>>2]|0)+(yb<<3)|0;Gb=c[Fb+4>>2]|0;if((zb|0)<(Gb|0)|(zb|0)==(Gb|0)&Bb>>>0<(c[Fb>>2]|0)>>>0){ia=84;break}c[ya>>2]=yb+1;ia=88}else{ia=84}}while(0);do{if((ia|0)==84){ia=0;yb=c[Ba>>2]|0;if((yb|0)==0){break}h[Ca>>3]=Eb;Bb=+MBb(yb,Da,0)!=0.0;fb=+h[Da>>3];if(Bb){h[Ea>>3]=fb;h[Fa>>3]=+h[Ca>>3];h[Ga>>3]=+h[Ga>>3]+1.0;h[Da>>3]=fb+1.0;ia=88;break}else{h[Da>>3]=fb+1.0;break}}}while(0);if((ia|0)==88){ia=0;c[xa>>2]=1;yDb(0,48,2341280,(ab=i,i=i+8|0,h[ab>>3]=Eb,ab)|0);i=ab}Kh(0,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;if((c[2163098]|0)!=0){TGb(s|0,0,32)|0;a[s]=0;Bb=c[ha>>2]|0;yb=c[ha+4>>2]|0;if((Bb|0)==0&(yb|0)==(-2147483648|0)){Lb(s|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(s|0,32,2070656,(ab=i,i=i+16|0,c[ab>>2]=Bb,c[ab+8>>2]=yb,ab)|0)|0;i=ab}TGb(t|0,0,32)|0;a[t]=0;yb=c[ha>>2]|0;Bb=c[ha+4>>2]|0;if((yb|0)==0&(Bb|0)==(-2147483648|0)){Lb(t|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(t|0,32,2075240,(ab=i,i=i+8|0,h[ab>>3]=(+(yb>>>0)+ +(Bb|0)*4294967296.0)*(+(c[sb>>2]|0)/+(c[tb>>2]|0)),ab)|0)|0;i=ab}Bb=c[sb>>2]|0;yb=c[tb>>2]|0;yDb(0,32,2339912,(ab=i,i=i+32|0,c[ab>>2]=s,c[ab+8>>2]=t,c[ab+16>>2]=Bb,c[ab+24>>2]=yb,ab)|0);i=ab}yb=v0a(Ua,m,ja,n)|0;Bb=c[Ha>>2]|0;Kh(2338784,(ab=i,i=i+16|0,c[ab>>2]=c[$>>2],c[ab+8>>2]=Bb,ab)|0);i=ab;if((yb|0)<0){yDb(0,8,2337488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;yf(1)}if((c[n>>2]|0)==0){Db=xb;break}if((c[2163098]|0)!=0){TGb(u|0,0,32)|0;a[u]=0;yb=c[E>>2]|0;Bb=c[E+4>>2]|0;if((yb|0)==0&(Bb|0)==(-2147483648|0)){Lb(u|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(u|0,32,2070656,(ab=i,i=i+16|0,c[ab>>2]=yb,c[ab+8>>2]=Bb,ab)|0)|0;i=ab}TGb(v|0,0,32)|0;a[v]=0;Bb=c[E>>2]|0;yb=c[E+4>>2]|0;if((Bb|0)==0&(yb|0)==(-2147483648|0)){Lb(v|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(v|0,32,2075240,(ab=i,i=i+8|0,h[ab>>3]=(+(Bb>>>0)+ +(yb|0)*4294967296.0)*(+(c[sb>>2]|0)/+(c[tb>>2]|0)),ab)|0)|0;i=ab}TGb(w|0,0,32)|0;a[w]=0;yb=c[G>>2]|0;Bb=c[G+4>>2]|0;if((yb|0)==0&(Bb|0)==(-2147483648|0)){Lb(w|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(w|0,32,2070656,(ab=i,i=i+16|0,c[ab>>2]=yb,c[ab+8>>2]=Bb,ab)|0)|0;i=ab}TGb(x|0,0,32)|0;a[x]=0;Bb=c[G>>2]|0;yb=c[G+4>>2]|0;if((Bb|0)==0&(yb|0)==(-2147483648|0)){Lb(x|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(x|0,32,2075240,(ab=i,i=i+8|0,h[ab>>3]=(+(Bb>>>0)+ +(yb|0)*4294967296.0)*(+(c[sb>>2]|0)/+(c[tb>>2]|0)),ab)|0)|0;i=ab}yDb(0,32,2335872,(ab=i,i=i+32|0,c[ab>>2]=u,c[ab+8>>2]=v,c[ab+16>>2]=w,c[ab+24>>2]=x,ab)|0);i=ab}yb=c[E>>2]|0;Bb=c[E+4>>2]|0;do{if((yb|0)==0&(Bb|0)==(-2147483648|0)){if((c[(c[ob>>2]|0)+16>>2]&32|0)!=0){break}zb=c[sa>>2]|0;Ab=c[sa+4>>2]|0;c[E>>2]=zb;c[E+4>>2]=Ab;if(!((zb|0)==0&(Ab|0)==(-2147483648|0))){Hb=Ab;Ib=zb;ia=117}}else{Hb=Bb;Ib=yb;ia=117}}while(0);if((ia|0)==117){ia=0;yb=KDb(Ib,Hb,qb,(c[ba>>2]|0)+40|0)|0;c[E>>2]=yb;c[E+4>>2]=F}yb=c[G>>2]|0;Bb=c[G+4>>2]|0;if(!((yb|0)==0&(Bb|0)==(-2147483648|0))){zb=KDb(yb,Bb,qb,(c[ba>>2]|0)+40|0)|0;c[G>>2]=zb;c[G+4>>2]=F}if((c[2163098]|0)!=0){TGb(y|0,0,32)|0;a[y]=0;zb=c[E>>2]|0;Bb=c[E+4>>2]|0;if((zb|0)==0&(Bb|0)==(-2147483648|0)){Lb(y|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(y|0,32,2070656,(ab=i,i=i+16|0,c[ab>>2]=zb,c[ab+8>>2]=Bb,ab)|0)|0;i=ab}TGb(z|0,0,32)|0;a[z]=0;Bb=c[E>>2]|0;zb=c[E+4>>2]|0;yb=c[ba>>2]|0;if((Bb|0)==0&(zb|0)==(-2147483648|0)){Lb(z|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(z|0,32,2075240,(ab=i,i=i+8|0,h[ab>>3]=(+(Bb>>>0)+ +(zb|0)*4294967296.0)*(+(c[yb+40>>2]|0)/+(c[yb+44>>2]|0)),ab)|0)|0;i=ab}TGb(A|0,0,32)|0;a[A]=0;yb=c[G>>2]|0;zb=c[G+4>>2]|0;if((yb|0)==0&(zb|0)==(-2147483648|0)){Lb(A|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(A|0,32,2070656,(ab=i,i=i+16|0,c[ab>>2]=yb,c[ab+8>>2]=zb,ab)|0)|0;i=ab}TGb(B|0,0,32)|0;a[B]=0;zb=c[G>>2]|0;yb=c[G+4>>2]|0;Bb=c[ba>>2]|0;if((zb|0)==0&(yb|0)==(-2147483648|0)){Lb(B|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(B|0,32,2075240,(ab=i,i=i+8|0,h[ab>>3]=(+(zb>>>0)+ +(yb|0)*4294967296.0)*(+(c[Bb+40>>2]|0)/+(c[Bb+44>>2]|0)),ab)|0)|0;i=ab}yDb(0,32,2335872,(ab=i,i=i+32|0,c[ab>>2]=y,c[ab+8>>2]=z,c[ab+16>>2]=A,c[ab+24>>2]=B,ab)|0);i=ab}Bb=c[D>>2]|0;yb=YGb(c[646526]|0,c[646527]|0,Bb,(Bb|0)<0|0?-1:0)|0;c[646526]=yb;c[646527]=F;Lh(Va,m,_);BZ(m);yb=c[Ia>>2]|0;if((yb|0)==0){Db=Bb;break}zb=c[pb>>2]|0;if((zb|0)==0){Db=Bb;break}rb(zb|0,yb|0)|0;Db=Bb}}while(0);Bb=YGb(c[sa>>2]|0,c[sa+4>>2]|0,1,0)|0;c[sa>>2]=Bb;c[sa+4>>2]=F;c[ta>>2]=(c[ta>>2]|0)+1;if(!((c[636774]|0)==0|(Db|0)==0)){Mh(_,Db)}Bb=wb+1|0;if((Bb|0)<($a|0)){wb=Bb;xb=Db}else{break b}}xb=c[(c[1163660]|0)+(c[$>>2]<<2)>>2]|0;c[ga>>2]=c[ga>>2]|1;if((c[xb+40>>2]|0)==0){break}wb=ZGb(c[sa>>2]|0,c[sa+4>>2]|0,c[Ma>>2]|0,c[Ma+4>>2]|0)|0;$a=(c[(c[ba>>2]|0)+8>>2]|0)+104|0;c[K>>2]=1;c[L>>2]=1e6;pb=KDb(wb,F,$a,k)|0;$a=F;wb=xb+16|0;xb=c[wb>>2]|0;Va=c[wb+4>>2]|0;qb=(Va|0)>($a|0)|(Va|0)==($a|0)&xb>>>0>pb>>>0;c[wb>>2]=qb?pb:xb;c[wb+4>>2]=qb?$a:Va}else if((Za|0)==1){c[ha>>2]=Xa;c[ha+4>>2]=Wa;do{if((c[(c[Qa>>2]|0)+16>>2]&16384|0)==0){Va=c[Ra>>2]|0;if((Va|0)==(vCb(ja)|0)){break}yDb(0,16,1886048,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;break b}}while(0);Va=c[oa>>2]|0;$a=c[(c[ba>>2]|0)+8>>2]|0;c[j>>2]=0;vZ(f);c[O>>2]=0;c[P>>2]=0;qb=(c[(c[1163660]|0)+(c[$>>2]<<2)>>2]|0)+16|0;wb=c[qb>>2]|0;xb=c[qb+4>>2]|0;do{if(!((wb|0)==(-1|0)&(xb|0)==2147483647)){qb=ZGb(c[sa>>2]|0,c[sa+4>>2]|0,c[Ma>>2]|0,c[Ma+4>>2]|0)|0;pb=(c[(c[ba>>2]|0)+8>>2]|0)+104|0;c[T>>2]=1;c[U>>2]=1e6;if(!((LDb(qb,F,pb,wb,xb,e)|0)>-1)){break}pb=c[(c[1163660]|0)+(c[$>>2]<<2)>>2]|0;c[ga>>2]=c[ga>>2]|1;if((c[pb+40>>2]|0)==0){break b}qb=ZGb(c[sa>>2]|0,c[sa+4>>2]|0,c[Ma>>2]|0,c[Ma+4>>2]|0)|0;ob=(c[(c[ba>>2]|0)+8>>2]|0)+104|0;c[V>>2]=1;c[W>>2]=1e6;tb=KDb(qb,F,ob,d)|0;ob=F;qb=pb+16|0;pb=c[qb>>2]|0;sb=c[qb+4>>2]|0;Ua=(sb|0)>(ob|0)|(sb|0)==(ob|0)&pb>>>0>tb>>>0;c[qb>>2]=Ua?tb:pb;c[qb+4>>2]=Ua?ob:sb;break b}}while(0);xb=c[ha>>2]|0;wb=c[ha+4>>2]|0;if((xb|0)==0&(wb|0)==(-2147483648|0)|(c[2291710]|0)<0){sb=c[sa>>2]|0;ob=c[sa+4>>2]|0;c[ha>>2]=sb;c[ha+4>>2]=ob;Jb=ob;Kb=sb}else{Jb=wb;Kb=xb}xb=c[Sa>>2]|0;wb=YGb(xb,(xb|0)<0|0?-1:0,Kb,Jb)|0;c[sa>>2]=wb;c[sa+4>>2]=F;if((c[P>>2]|0)==0){if((c[O>>2]|0)!=0){ia=151;break a}}Kh(0,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;if((c[2163098]|0)!=0){TGb(s|0,0,32)|0;a[s]=0;wb=c[ha>>2]|0;xb=c[ha+4>>2]|0;if((wb|0)==0&(xb|0)==(-2147483648|0)){Lb(s|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(s|0,32,2070656,(ab=i,i=i+16|0,c[ab>>2]=wb,c[ab+8>>2]=xb,ab)|0)|0;i=ab}TGb(t|0,0,32)|0;a[t]=0;xb=c[ha>>2]|0;wb=c[ha+4>>2]|0;sb=$a+104|0;if((xb|0)==0&(wb|0)==(-2147483648|0)){Lb(t|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab;Mb=sb|0;Nb=$a+108|0}else{ob=sb|0;sb=$a+108|0;Lb(t|0,32,2075240,(ab=i,i=i+8|0,h[ab>>3]=(+(xb>>>0)+ +(wb|0)*4294967296.0)*(+(c[ob>>2]|0)/+(c[sb>>2]|0)),ab)|0)|0;i=ab;Mb=ob;Nb=sb}sb=c[Mb>>2]|0;ob=c[Nb>>2]|0;yDb(0,32,1882112,(ab=i,i=i+32|0,c[ab>>2]=s,c[ab+8>>2]=t,c[ab+16>>2]=sb,c[ab+24>>2]=ob,ab)|0);i=ab}if((t0a($a,f,ja,j)|0)<0){yDb(0,8,1880816,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;yf(1)}ob=c[Ha>>2]|0;Kh(1879344,(ab=i,i=i+16|0,c[ab>>2]=c[$>>2],c[ab+8>>2]=ob,ab)|0);i=ab;if((c[j>>2]|0)==0){break}ob=c[Q>>2]|0;sb=c[Q+4>>2]|0;if(!((ob|0)==0&(sb|0)==(-2147483648|0))){wb=KDb(ob,sb,$a+104|0,(c[ba>>2]|0)+40|0)|0;c[Q>>2]=wb;c[Q+4>>2]=F}wb=c[R>>2]|0;sb=c[R+4>>2]|0;if(!((wb|0)==0&(sb|0)==(-2147483648|0))){ob=KDb(wb,sb,$a+104|0,(c[ba>>2]|0)+40|0)|0;c[R>>2]=ob;c[R+4>>2]=F}ob=c[S>>2]|0;if((ob|0)>0){sb=KDb(ob,(ob|0)<0|0?-1:0,$a+104|0,(c[ba>>2]|0)+40|0)|0;c[S>>2]=sb}if((c[2163098]|0)!=0){TGb(u|0,0,32)|0;a[u]=0;sb=c[Q>>2]|0;ob=c[Q+4>>2]|0;if((sb|0)==0&(ob|0)==(-2147483648|0)){Lb(u|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(u|0,32,2070656,(ab=i,i=i+16|0,c[ab>>2]=sb,c[ab+8>>2]=ob,ab)|0)|0;i=ab}TGb(v|0,0,32)|0;a[v]=0;ob=c[Q>>2]|0;sb=c[Q+4>>2]|0;wb=c[ba>>2]|0;if((ob|0)==0&(sb|0)==(-2147483648|0)){Lb(v|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(v|0,32,2075240,(ab=i,i=i+8|0,h[ab>>3]=(+(ob>>>0)+ +(sb|0)*4294967296.0)*(+(c[wb+40>>2]|0)/+(c[wb+44>>2]|0)),ab)|0)|0;i=ab}TGb(w|0,0,32)|0;a[w]=0;wb=c[R>>2]|0;sb=c[R+4>>2]|0;if((wb|0)==0&(sb|0)==(-2147483648|0)){Lb(w|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(w|0,32,2070656,(ab=i,i=i+16|0,c[ab>>2]=wb,c[ab+8>>2]=sb,ab)|0)|0;i=ab}TGb(x|0,0,32)|0;a[x]=0;sb=c[R>>2]|0;wb=c[R+4>>2]|0;ob=c[ba>>2]|0;if((sb|0)==0&(wb|0)==(-2147483648|0)){Lb(x|0,32,2080488,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Lb(x|0,32,2075240,(ab=i,i=i+8|0,h[ab>>3]=(+(sb>>>0)+ +(wb|0)*4294967296.0)*(+(c[ob+40>>2]|0)/+(c[ob+44>>2]|0)),ab)|0)|0;i=ab}yDb(0,32,2355424,(ab=i,i=i+32|0,c[ab>>2]=u,c[ab+8>>2]=v,c[ab+16>>2]=w,c[ab+24>>2]=x,ab)|0);i=ab}ob=c[P>>2]|0;wb=YGb(c[2291712]|0,c[2291713]|0,ob,(ob|0)<0|0?-1:0)|0;c[2291712]=wb;c[2291713]=F;Lh(Va,f,_);BZ(f)}else{ia=184;break a}}while(0);KCb(ja)}else{KCb(ja)}Za=xj(ea,ja,2)|0;if((Za|0)<0){ka=Za;break}}}if((ka|0)==(-11|0)|(ka|0)==(-541478725|0)){break}TGb(r|0,0,64)|0;a[r]=0;GBb(ka,r,64)|0;yDb(0,24,1889440,(ab=i,i=i+8|0,c[ab>>2]=r,ab)|0);i=ab}}while(0);_=Z+1|0;if((_|0)<(c[1167936]|0)){Z=_}else{p=0;ia=187;break}}if((ia|0)==51){yDb(0,0,1899624,(ab=i,i=i+24|0,c[ab>>2]=1884432,c[ab+8>>2]=1893768,c[ab+16>>2]=884,ab)|0);i=ab;Cd();return 0}else if((ia|0)==151){yDb(0,0,1899624,(ab=i,i=i+24|0,c[ab>>2]=1883200,c[ab+8>>2]=1893768,c[ab+16>>2]=708,ab)|0);i=ab;Cd();return 0}else if((ia|0)==184){yDb(0,0,1899624,(ab=i,i=i+24|0,c[ab>>2]=1884432,c[ab+8>>2]=1893768,c[ab+16>>2]=1171,ab)|0);i=ab;Cd();return 0}else if((ia|0)==187){i=b;return p|0}return 0}function Ph(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[b+68>>2]|0;g=c[d>>2]|0;if((g|0)==-1){h=d;j=c[h>>2]|0;i=e;return j|0}k=f+264|0;l=f+256|0;m=f;n=f+4|0;o=d;d=g;a:while(1){if((a[(bFb(d)|0)+7|0]&8)==0){h=o;p=16;break}g=c[o>>2]|0;q=0;while(1){r=c[5099056+(q<<4)>>2]|0;if((r|0)==0){break}if((c[5099068+(q<<4)>>2]|0)==(g|0)){p=7;break}else{q=q+1|0}}do{if((p|0)==7){p=0;g=c[k>>2]|0;if((g|0)!=0){if((g|0)!=(c[5099064+(q<<4)>>2]|0)){break}}g=c[l>>2]|0;if((g|0)!=1){if((g|0)!=(c[5099064+(q<<4)>>2]|0)){break}}if((re[c[5099060+(q<<4)>>2]&4095](b)|0)>=0){p=14;break a}if((c[l>>2]|0)!=(c[5099064+(q<<4)>>2]|0)){break}g=c[m>>2]|0;s=c[c[n>>2]>>2]|0;yDb(0,8,2220168,(t=i,i=i+24|0,c[t>>2]=r,c[t+8>>2]=g,c[t+16>>2]=s,t)|0);i=t;yf(1)}}while(0);t=o+4|0;s=c[t>>2]|0;if((s|0)==-1){h=t;p=16;break}else{o=t;d=s}}if((p|0)==14){c[k>>2]=c[5099064+(q<<4)>>2];c[f+284>>2]=c[o>>2];h=o;j=c[h>>2]|0;i=e;return j|0}else if((p|0)==16){j=c[h>>2]|0;i=e;return j|0}return 0}function Qh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=c[a+68>>2]|0;f=c[e+276>>2]|0;do{if((f|0)!=0){if((c[b+80>>2]|0)!=(c[e+284>>2]|0)){break}g=ze[f&511](a,b,d)|0;return g|0}}while(0);g=Y$a(a,b,d)|0;return g|0}function Rh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a;a=c[d>>2]|0;e=c[d+4>>2]|0;d=b;b=c[d>>2]|0;f=c[d+4>>2]|0;if((e|0)<(f|0)|(e|0)==(f|0)&a>>>0<b>>>0){g=-1;return g|0}g=((e|0)>(f|0)|(e|0)==(f|0)&a>>>0>b>>>0)&1;return g|0}function Sh(){if(a[1759352]|0){return}a[1759352]=1;return}function Th(){return 3607140}function Uh(){return 1919848}function Vh(){if(a[1755528]|0){return}a[1755528]=1;Ti(1268520)|0;Ti(1268464)|0;Ti(1268408)|0;Ti(1268352)|0;Ti(1268296)|0;Ti(1268184)|0;Ti(1268128)|0;Ti(1268072)|0;Ti(1268016)|0;Ti(1267960)|0;Ti(1267904)|0;Ti(1267848)|0;Ti(1267792)|0;Ti(1267736)|0;Ti(1267680)|0;Ti(1267624)|0;Ti(1267568)|0;Ti(1267512)|0;Ti(1267456)|0;Ti(1267400)|0;Ti(1267344)|0;Ti(1267288)|0;Ti(1267232)|0;Ti(1267176)|0;Ti(1267120)|0;Ti(1267064)|0;Ti(1267008)|0;Ti(1266952)|0;Ti(1266896)|0;Ti(1266840)|0;Ti(1266784)|0;Ti(1266728)|0;Ti(1266672)|0;Ti(1266616)|0;Ti(1266560)|0;Ti(1266504)|0;Ti(1266448)|0;Ti(1266392)|0;Ti(1266336)|0;Ti(1266280)|0;Ti(1266224)|0;Ti(1266168)|0;Ti(1266112)|0;Ti(1266056)|0;Ti(1266e3)|0;Ti(1262544)|0;Ti(1262488)|0;Ti(1262432)|0;Ti(1262712)|0;Ti(1093976)|0;Ti(1093920)|0;Ti(1093864)|0;Ti(1093808)|0;Ti(1093752)|0;Ti(1093696)|0;Ti(1093640)|0;Ti(1093584)|0;Ti(1093528)|0;Ti(1093472)|0;Ti(1093416)|0;Ti(1093360)|0;Ti(1093304)|0;Ti(1093248)|0;Ti(1093192)|0;Ti(1093136)|0;Ti(1093080)|0;Ti(1093024)|0;Ti(1092968)|0;Ti(1092912)|0;Ti(1092856)|0;Ti(1092800)|0;Ti(1092744)|0;Ti(1092632)|0;Ti(1092576)|0;Ti(1092520)|0;Ti(1092464)|0;Ti(1092408)|0;Ti(1092352)|0;Ti(1092296)|0;Ti(1092240)|0;Ti(1092184)|0;Ti(1092128)|0;Ti(1092072)|0;Ti(1092016)|0;Ti(1091904)|0;Ti(1091960)|0;Ti(1091848)|0;Ti(1091792)|0;Ti(1091736)|0;Ti(1091680)|0;Ti(1091624)|0;Ti(1091568)|0;Ti(1091512)|0;Ti(1091456)|0;Ti(1091400)|0;Ti(1091344)|0;Ti(1091288)|0;Ti(1091232)|0;Ti(1091176)|0;Ti(1091120)|0;Ti(1091064)|0;Ti(1091008)|0;Ti(1090952)|0;Ti(1090896)|0;Ti(1090840)|0;Ti(1090784)|0;Ti(1090728)|0;Ti(1090672)|0;Ti(1090616)|0;Ti(1090560)|0;Ti(1090504)|0;Ti(1090448)|0;Ti(1090392)|0;Ti(1090336)|0;Ti(1090280)|0;Ti(1090224)|0;Ti(1090168)|0;Ti(1090112)|0;Ti(1090056)|0;Ti(109e4)|0;Ti(1089944)|0;Ti(1089888)|0;Ti(1084224)|0;Ti(1084168)|0;Ti(1084112)|0;Ti(1084056)|0;Ti(1084e3)|0;Ti(1083944)|0;Ti(1083888)|0;Ti(1083832)|0;Ti(1083776)|0;Ti(1083720)|0;Ti(1084336)|0;Ti(1259752)|0;Ti(1259696)|0;Ti(1259640)|0;Ti(1259584)|0;Ti(1258696)|0;Ti(1258640)|0;Ti(1084392)|0;Ti(1262656)|0;Ti(1262600)|0;Ti(1084280)|0;Ti(1262768)|0;Ti(1084448)|0;Ti(1268240)|0;Ti(1092688)|0;al();return}function Wh(a,b){a=a|0;b=b|0;var d=0;a=i;i=i+8|0;d=a|0;c[d>>2]=b;JCb(d);i=a;return 0}function Xh(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;d=a;a=Tk(b+20|0,c[b+16>>2]|0,d)|0;if((a|0)<0){e=a;return e|0}a=Uk(b+8|0,0,c[b+4>>2]|0,d)|0;e=(a|0)<0?a:0;return e|0}function Yh(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+24|0;d=b|0;e=b+16|0;f=c[a+44>>2]|0;g=d|0;h=f+8|0;j=c[h+4>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=j;j=d+8|0;c[j>>2]=-1;c[j+4>>2]=-1;j=e|0;c[j>>2]=c[f+20>>2];c[e+4>>2]=-1;Ok(a,Bk(1)|0);Mk(a,yk(g)|0);Nk(a,xk(j)|0);i=b;return 0}function Zh(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=c[(c[a>>2]|0)+44>>2]|0;f=e+24|0;g=fi(a,c[f>>2]|0)|0;c[d>>2]=g;if((g|0)==0){h=-12;i=b;return h|0}j=e+32|0;k=c[j+4>>2]|0;l=g+136|0;c[l>>2]=c[j>>2];c[l+4>>2]=k;k=e+8|0;e=c[k+4>>2]|0;l=g+352|0;c[l>>2]=c[k>>2];c[l+4>>2]=e;c[g+344>>2]=c[a+48>>2];e=cj(a,PCb(g)|0)|0;JCb(d);if((e|0)<0){h=e;i=b;return h|0}d=c[f>>2]|0;f=YGb(c[j>>2]|0,c[j+4>>2]|0,d,(d|0)<0|0?-1:0)|0;c[j>>2]=f;c[j+4>>2]=F;h=e;i=b;return h|0}function _h(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+128|0;d=a|0;a=c[(c[d>>2]|0)+44>>2]|0;e=b|0;f=a+8|0;iBb(e,128,0,c[f>>2]|0,c[f+4>>2]|0);f=c[a+24>>2]|0;yDb(c[d>>2]|0,40,2262136,(d=i,i=i+24|0,c[d>>2]=c[a+20>>2],c[d+8>>2]=e,c[d+16>>2]=f,d)|0);i=d;i=b;return 0}function $h(a){a=a|0;var d=0,e=0,f=0,g=0.0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0;d=c[a+44>>2]|0;a=WDb(65536)|0;e=d+40|0;c[e>>2]=a;if((a|0)==0){f=-12;return f|0}a=d+8|0;g=+sGb(+h[a>>3],32);i=d+28|0;j=c[i>>2]|0;c[d+60>>2]=~~(g/+(j|0)+.5);k=c[e>>2]|0;b[k>>1]=0;b[k+16384>>1]=32760;e=8192;while(1){l=e>>>1;m=65536;n=0;while(1){o=n+e|0;p=(b[k+(o<<1)>>1]|0)+(b[k+(n<<1)>>1]|0)|0;q=8192-n|0;r=(b[k+(q-e<<1)>>1]|0)+(b[k+(q<<1)>>1]|0)|0;s=(ba(r,r)|0)+(ba(p,p)|0)|0;t=0;u=m;while(1){v=u;w=0;x=gHb(v,w,s,t)|0;y=hHb(0,1073217600,x,F)|0;x=YGb(y,F,1,0)|0;y=YGb(x,F,v,w)|0;w=y>>>1|F<<31;if((u|0)==(w|0)){break}else{u=w}}b[k+(n+l<<1)>>1]=((ba(u,p)|0)+32767|0)>>>16;b[k+(q-l<<1)>>1]=((ba(u,r)|0)+32768|0)>>>16;if(o>>>0<4096>>>0){m=u;n=o}else{break}}if(e>>>0>3>>>0){e=l}else{z=0;break}}while(1){e=k+(z<<1)|0;b[e>>1]=((b[e>>1]|0)+4|0)>>>3;e=z+1|0;if(e>>>0<8193>>>0){z=e}else{A=0;break}}while(1){b[k+(16384-A<<1)>>1]=b[k+(A<<1)>>1]|0;z=A+1|0;if(z>>>0<8192>>>0){A=z}else{B=0;break}}do{b[k+(B+16384<<1)>>1]=-(b[k+(B<<1)>>1]|0);B=B+1|0;}while(B>>>0<16384>>>0);g=+h[d+16>>3];if(!(g!=0.0)){f=0;return f|0}c[d+64>>2]=j;c[d+72>>2]=(j>>>0)/25|0;C=+sGb(g*+h[a>>3],32);c[d+80>>2]=~~(C/+(c[i>>2]|0)+.5);f=0;return f|0}function ai(a){a=a|0;$Db((c[a+44>>2]|0)+40|0);return}function bi(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+8|0;d=b|0;e=d|0;c[e>>2]=c[(c[a+44>>2]|0)+28>>2];c[d+4>>2]=-1;Ok(a,xk(550056)|0);Mk(a,yk(552088)|0);Nk(a,xk(e)|0);i=b;return 0}function ci(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[(c[a>>2]|0)+44>>2]|0;e=c[d+24>>2]|0;f=d+32|0;g=c[f>>2]|0;h=c[f+4>>2]|0;do{if((g|0)==0&(h|0)==0){i=e}else{f=(e|0)<0|0?-1:0;j=d+48|0;k=ZGb(g,h,c[j>>2]|0,c[j+4>>2]|0)|0;j=F;l=(f|0)>(j|0)|(f|0)==(j|0)&e>>>0>k>>>0?k:e;if((l|0)==0){m=-541478725}else{i=l;break}return m|0}}while(0);e=fi(a,i)|0;if((e|0)==0){m=-12;return m|0}h=c[e>>2]|0;if((i|0)>0){g=d+56|0;l=c[d+40>>2]|0;k=c[d+60>>2]|0;j=d+68|0;f=c[d+72>>2]|0;n=d+76|0;o=d+80|0;p=c[d+64>>2]|0;q=c[g>>2]|0;r=ba(i,k)|0;s=0;t=q;u=c[j>>2]|0;while(1){v=b[l+(t>>>17<<1)>>1]|0;w=h+(s<<1)|0;b[w>>1]=v;if(u>>>0<f>>>0){x=c[n>>2]|0;b[w>>1]=v+(b[l+(x>>>17<<1)>>1]<<1);c[n>>2]=x+(c[o>>2]|0)}x=u+1|0;y=(x|0)==(p|0)?0:x;x=s+1|0;if((x|0)<(i|0)){s=x;t=t+k|0;u=y}else{break}}c[g>>2]=q+r;c[j>>2]=y}y=d+48|0;d=c[y+4>>2]|0;j=e+136|0;c[j>>2]=c[y>>2];c[j+4>>2]=d;d=YGb(c[y>>2]|0,c[y+4>>2]|0,i,(i|0)<0|0?-1:0)|0;c[y>>2]=d;c[y+4>>2]=F;m=cj(a,e)|0;return m|0}function di(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;a=b+32|0;d=c[b+28>>2]|0;b=IDb(c[a>>2]|0,c[a+4>>2]|0,d,(d|0)<0|0?-1:0,1e6,0)|0;c[a>>2]=b;c[a+4>>2]=F;return 0}function ei(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[c[(c[a+8>>2]|0)+32>>2]>>2]|0;a=c[(c[d+12>>2]|0)+24>>2]|0;do{if((a|0)!=0){e=Oe[a&1023](d,b)|0;if((e|0)==0){break}else{f=e}return f|0}}while(0);f=gi(d,b)|0;return f|0}function fi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[(c[a+12>>2]|0)+24>>2]|0;do{if((d|0)!=0){e=Oe[d&1023](a,b)|0;if((e|0)==0){break}else{f=e}return f|0}}while(0);f=gi(a,b)|0;return f|0}function gi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;f=ICb()|0;c[e>>2]=f;g=a+148|0;h=c[g>>2]|0;j=a+40|0;do{if((h|0)==(hBb(c[j>>2]|0,c[j+4>>2]|0)|0)){k=f}else{if((hBb(c[j>>2]|0,c[j+4>>2]|0)|0)==0){k=c[e>>2]|0;break}else{yDb(0,0,1904872,(l=i,i=i+24|0,c[l>>2]=2214136,c[l+8>>2]=2129392,c[l+16>>2]=47,l)|0);i=l;Cd();return 0}}}while(0);if((k|0)==0){m=0;i=d;return m|0}c[k+76>>2]=b;f=a+52|0;c[k+80>>2]=c[f>>2];wCb(k,c[g>>2]|0);g=c[j+4>>2]|0;l=k+352|0;c[l>>2]=c[j>>2];c[l+4>>2]=g;c[k+344>>2]=c[a+48>>2];if((LCb(k,0)|0)<0){JCb(e);m=0;i=d;return m|0}else{GFb(c[k+64>>2]|0,0,b,h,c[f>>2]|0)|0;m=c[e>>2]|0;i=d;return m|0}return 0}function hi(a){a=a|0;JCb((c[a+44>>2]|0)+4|0);return}function ii(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;c[d>>2]=0;e=c[c[a+16>>2]>>2]|0;f=c[c[a+32>>2]>>2]|0;a=xk(549704)|0;if((a|0)==0){g=-12;i=b;return g|0}Hk(a,e+68|0);Ak(d,3,0)|0;Gk(c[d>>2]|0,e+84|0);d=Dk()|0;if((d|0)==0){g=-12;i=b;return g|0}Hk(d,e+76|0);e=xk(551696)|0;if((e|0)==0){g=-12;i=b;return g|0}Hk(e,f+64|0);g=0;i=b;return g|0}function ji(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[(c[a>>2]|0)+44>>2]|0;d=b+8|0;c[a+20>>2]=c[d>>2];e=b+12|0;c[a+24>>2]=c[e>>2];c[a+28>>2]=1;c[a+32>>2]=1;f=b+64|0;g=a+116|0;a=c[f+4>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=a;c[b+16>>2]=(c[d>>2]|0)/2|0;c[b+20>>2]=(c[e>>2]|0)/2|0;return 0}function ki(e,f){e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0,S=0,T=0,U=0.0,V=0.0,W=0,X=0,Y=0;j=i;i=i+8|0;k=j|0;c[k>>2]=f;l=c[e+8>>2]|0;e=c[c[l+32>>2]>>2]|0;m=c[l+44>>2]|0;l=c[m+16>>2]|0;n=c[m+20>>2]|0;o=m+56|0;p=+h[o>>3];q=m+4|0;r=c[q>>2]|0;do{if((r|0)==0){s=e+20|0;t=5}else{u=e+20|0;if((c[r+68>>2]|0)!=(c[u>>2]|0)){s=u;t=5;break}if((c[r+72>>2]|0)==(c[e+24>>2]|0)){v=f;w=r}else{s=u;t=5}}}while(0);if((t|0)==5){JCb(q);r=e+24|0;f=Zr(e,c[s>>2]|0,c[r>>2]|0)|0;c[q>>2]=f;if((f|0)==0){JCb(k);x=-12;i=j;return x|0}if((c[r>>2]|0)>0){u=0;y=f;while(1){z=(c[y>>2]|0)+(ba(c[y+32>>2]|0,u)|0)|0;TGb(z|0,0,c[s>>2]<<2|0)|0;z=u+1|0;A=c[q>>2]|0;if((z|0)<(c[r>>2]|0)){u=z;y=A}else{B=A;break}}}else{B=f}v=c[k>>2]|0;w=B}B=v+136|0;f=c[B+4>>2]|0;y=w+136|0;c[y>>2]=c[B>>2];c[y+4>>2]=f;f=c[w+32>>2]|0;y=m+40|0;do{if((c[y>>2]|0)==0){if((c[m+44>>2]|0)!=0){t=13;break}if((c[m+48>>2]|0)==0){C=v}else{t=13}}else{t=13}}while(0);do{if((t|0)==13){B=m+12|0;u=c[B>>2]|0;if((u|0)<=0){C=v;break}r=m+8|0;s=m+44|0;A=m+48|0;z=0;D=c[w>>2]|0;E=c[r>>2]|0;F=u;while(1){if((E<<2|0)>0){u=0;do{G=D+u|0;H=(d[G]|0)-(c[y>>2]|0)|0;a[G]=(H|0)>0?H&255:0;H=D+(u|1)|0;G=(d[H]|0)-(c[s>>2]|0)|0;a[H]=(G|0)>0?G&255:0;G=D+(u|2)|0;H=(d[G]|0)-(c[A>>2]|0)|0;a[G]=(H|0)>0?H&255:0;u=u+4|0;I=c[r>>2]|0;}while((u|0)<(I<<2|0));J=I;K=c[B>>2]|0}else{J=E;K=F}u=z+1|0;if((u|0)<(K|0)){z=u;D=D+f|0;E=J;F=K}else{break}}C=c[k>>2]|0}}while(0);K=c[C+80>>2]|0;do{if((K|0)==3){if((c[C+76>>2]|0)<=0){break}J=m+24|0;L=+(l|0);M=+(n|0);f=m+12|0;I=m+8|0;y=m+28|0;w=m+32|0;v=m+36|0;F=0;E=C;while(1){D=c[E>>2]|0;z=F<<1;B=D+(z<<2)|0;N=+g[D+((z|1)<<2)>>2];if((c[J>>2]|0)==0){O=+g[B>>2];P=p*(N-O)*.5;Q=1.0-p*(N+O)*.5}else{P=p*N;Q=p*+g[B>>2]+1.0}B=~~(L*(P+1.0));z=~~(M*Q);D=c[q>>2]|0;r=c[D+32>>2]|0;A=c[f>>2]|0;do{if(+h[o>>3]>1.0){if(!(A>>>0>z>>>0)){R=E;break}if((c[I>>2]|0)>>>0>B>>>0){S=B;T=z;t=41}else{R=E}}else{s=A-1|0;u=(c[I>>2]|0)-1|0;S=u>>>0<B>>>0?u:B;T=s>>>0<z>>>0?s:z;t=41}}while(0);if((t|0)==41){t=0;z=(S<<2)+(ba(T,r)|0)|0;B=c[D>>2]|0;A=B+z|0;s=(d[A]|0)+(c[y>>2]|0)|0;a[A]=(s|0)>255?-1:s&255;s=B+(z+1)|0;A=(d[s]|0)+(c[w>>2]|0)|0;a[s]=(A|0)>255?-1:A&255;A=B+(z+2)|0;z=(d[A]|0)+(c[v>>2]|0)|0;a[A]=(z|0)>255?-1:z&255;R=c[k>>2]|0}z=F+1|0;if((z|0)<(c[R+76>>2]|0)){F=z;E=R}else{break}}}else if((K|0)==1){if((c[C+76>>2]|0)<=0){break}E=m+24|0;M=+(l|0);L=+(n|0);F=m+12|0;v=m+8|0;w=m+28|0;y=m+32|0;I=m+36|0;f=0;J=C;while(1){z=c[J>>2]|0;A=f<<1;B=z+(A<<1)|0;s=b[z+((A|1)<<1)>>1]|0;A=s<<16>>16;if((c[E>>2]|0)==0){z=b[B>>1]|0;U=p*+(A-z|0)/65535.0;V=1.0-p*+(z+A|0)/65535.0}else{U=p*+(s<<16>>16|0)/32767.0;V=p*+(b[B>>1]|0)/32767.0+1.0}B=~~(M*(U+1.0));s=~~(L*V);A=c[q>>2]|0;z=c[A+32>>2]|0;u=c[F>>2]|0;do{if(+h[o>>3]>1.0){if(!(u>>>0>s>>>0)){W=J;break}if((c[v>>2]|0)>>>0>B>>>0){X=B;Y=s;t=32}else{W=J}}else{H=u-1|0;G=(c[v>>2]|0)-1|0;X=G>>>0<B>>>0?G:B;Y=H>>>0<s>>>0?H:s;t=32}}while(0);if((t|0)==32){t=0;s=(X<<2)+(ba(Y,z)|0)|0;B=c[A>>2]|0;u=B+s|0;D=(d[u]|0)+(c[w>>2]|0)|0;a[u]=(D|0)>255?-1:D&255;D=B+(s+1)|0;u=(d[D]|0)+(c[y>>2]|0)|0;a[D]=(u|0)>255?-1:u&255;u=B+(s+2)|0;s=(d[u]|0)+(c[I>>2]|0)|0;a[u]=(s|0)>255?-1:s&255;W=c[k>>2]|0}s=f+1|0;if((s|0)<(c[W+76>>2]|0)){f=s;J=W}else{break}}}}while(0);JCb(k);x=cj(e,PCb(c[q>>2]|0)|0)|0;i=j;return x|0}function li(a){a=a|0;var b=0,d=0.0,e=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=+(c[a+48>>2]|0)/(+(c[b+64>>2]|0)/+(c[b+68>>2]|0))+.5;if(d<1024.0){e=1024}else{e=~~d}c[a+136>>2]=e;c[a+132>>2]=e;c[a+128>>2]=e;return 0}function mi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+128|0;d=b|0;e=b+64|0;f=c[a+44>>2]|0;g=f+12|0;h=f+4|0;if((c[g>>2]|0)==0){j=h}else{k=d|0;l=d+4|0;m=d+8|0;n=d+12|0;o=d+16|0;p=d+20|0;q=d+24|0;r=d+28|0;s=d+32|0;t=d+36|0;u=d+40|0;v=a+24|0;w=a+12|0;x=a+16|0;y=a+20|0;z=0;while(1){A=h;if((c[A>>2]|0)!=0){B=0;do{TGb(d|0,0,20)|0;c[p>>2]=68;c[q>>2]=614;c[r>>2]=0;c[s>>2]=0;c[t>>2]=42;TGb(u|0,0,20)|0;C=vAb(1976032,(D=i,i=i+24|0,c[D>>2]=z,c[D+8>>2]=118,c[D+16>>2]=B,D)|0)|0;i=D;c[k>>2]=C;Hi(c[v>>2]|0,v,12,w,x,d)|0;c[y>>2]=c[v>>2];B=B+1|0;}while(B>>>0<(c[A>>2]|0)>>>0)}B=f+8|0;if((c[B>>2]|0)!=0){C=0;do{c[k>>2]=0;c[l>>2]=1;c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;c[p>>2]=68;c[q>>2]=614;c[r>>2]=0;c[s>>2]=0;c[t>>2]=42;TGb(u|0,0,20)|0;E=vAb(1976032,(D=i,i=i+24|0,c[D>>2]=z,c[D+8>>2]=97,c[D+16>>2]=C,D)|0)|0;i=D;c[k>>2]=E;Hi(c[v>>2]|0,v,12,w,x,d)|0;c[y>>2]=c[v>>2];C=C+1|0;}while(C>>>0<(c[B>>2]|0)>>>0)}B=z+1|0;if(B>>>0<(c[g>>2]|0)>>>0){z=B}else{j=A;break}}}z=e;g=e+4|0;v=e+44|0;y=e+48|0;d=e|0;x=a+40|0;w=a+28|0;k=a+32|0;u=a+36|0;if((c[j>>2]|0)!=0){t=0;do{TGb(e|0,0,60)|0;c[v>>2]=816;c[y>>2]=2552;s=vAb(1921792,(D=i,i=i+16|0,c[D>>2]=118,c[D+8>>2]=t,D)|0)|0;i=D;c[d>>2]=s;Hi(c[x>>2]|0,x,4,w,k,e)|0;c[u>>2]=c[x>>2];t=t+1|0;}while(t>>>0<(c[j>>2]|0)>>>0)}j=f+8|0;if((c[j>>2]|0)!=0){t=0;do{TGb(z|0,0,60)|0;c[g>>2]=1;c[v>>2]=816;c[y>>2]=2552;s=vAb(1921792,(D=i,i=i+16|0,c[D>>2]=97,c[D+8>>2]=t,D)|0)|0;i=D;c[d>>2]=s;Hi(c[x>>2]|0,x,4,w,k,e)|0;c[u>>2]=c[x>>2];t=t+1|0;}while(t>>>0<(c[j>>2]|0)>>>0)}j=dEb(c[a+24>>2]|0,1048)|0;c[f+40>>2]=j;if((j|0)==0){F=-12;i=b;return F|0}c[f+32>>2]=c[x>>2];F=0;i=b;return F|0}function ni(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+8|0;f=d|0;g=c[a+44>>2]|0;h=a+24|0;if((c[h>>2]|0)!=0){j=a+12|0;k=g+40|0;l=0;do{$Db((c[j>>2]|0)+(l*60|0)|0);m=c[k>>2]|0;n=m+(l*1048|0)+1046|0;o=b[n>>1]|0;if(!(o<<16>>16==0)){p=m+(l*1048|0)+1044|0;q=o;do{o=m+(l*1048|0)+20+((e[p>>1]|0)<<2)|0;r=c[o>>2]|0;b[n>>1]=q-1;c[o>>2]=0;b[p>>1]=(b[p>>1]|0)+1&255;c[f>>2]=r;JCb(f);q=b[n>>1]|0;}while(!(q<<16>>16==0))}l=l+1|0;}while(l>>>0<(c[h>>2]|0)>>>0)}h=a+40|0;if((c[h>>2]|0)==0){s=g+40|0;t=s;u=c[t>>2]|0;v=u;ZDb(v);i=d;return}l=a+28|0;a=0;do{$Db((c[l>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[h>>2]|0)>>>0);s=g+40|0;t=s;u=c[t>>2]|0;v=u;ZDb(v);i=d;return}function oi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[a+44>>2]|0;d=b+4|0;e=a+32|0;f=b+12|0;b=a+16|0;g=a+40|0;a=0;h=0;i=0;j=0;a:while(1){k=c[d+(a<<2)>>2]|0;if((k|0)==0){l=h;m=i;n=j}else{o=(a|0)==1;p=h;q=0;r=i;s=j;while(1){t=Bk(a)|0;if((t|0)==0){u=-12;v=15;break a}Hk(t,(c[(c[e>>2]|0)+(p<<2)>>2]|0)+64|0);if(o){w=Dk()|0;if((w|0)==0){u=-12;v=15;break a}Hk(w,(c[(c[e>>2]|0)+(p<<2)>>2]|0)+72|0);x=Ek()|0;if((x|0)==0){u=-12;v=15;break a}Gk(x,(c[(c[e>>2]|0)+(p<<2)>>2]|0)+80|0);y=x;z=w}else{y=s;z=r}if((c[f>>2]|0)!=0){if(o){w=p;x=0;while(1){Hk(t,(c[(c[b>>2]|0)+(w<<2)>>2]|0)+68|0);Hk(z,(c[(c[b>>2]|0)+(w<<2)>>2]|0)+76|0);Gk(y,(c[(c[b>>2]|0)+(w<<2)>>2]|0)+84|0);A=x+1|0;if(A>>>0<(c[f>>2]|0)>>>0){w=(c[g>>2]|0)+w|0;x=A}else{break}}}else{x=p;w=0;while(1){Hk(t,(c[(c[b>>2]|0)+(x<<2)>>2]|0)+68|0);A=w+1|0;if(A>>>0<(c[f>>2]|0)>>>0){x=(c[g>>2]|0)+x|0;w=A}else{break}}}}w=p+1|0;x=q+1|0;if(x>>>0<k>>>0){p=w;q=x;r=z;s=y}else{l=w;m=z;n=y;break}}}s=a+1|0;if(s>>>0<2>>>0){a=s;h=l;i=m;j=n}else{u=0;v=15;break}}if((v|0)==15){return u|0}return 0}function pi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+8>>2]|0;return Zr(c[(c[e+32>>2]|0)+((((((c[a+12>>2]|0)-(c[e+12>>2]|0)|0)/60|0)>>>0)%((c[e+40>>2]|0)>>>0)|0)<<2)>>2]|0,b,d)|0}function qi(a,b){a=a|0;b=b|0;var d=0;d=c[a+8>>2]|0;return fi(c[(c[d+32>>2]|0)+((((((c[a+12>>2]|0)-(c[d+12>>2]|0)|0)/60|0)>>>0)%((c[d+40>>2]|0)>>>0)|0)<<2)>>2]|0,b)|0}function ri(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+8|0;g=f|0;h=c[a+8>>2]|0;j=c[a+12>>2]|0;c[g>>2]=d;a=c[h+44>>2]|0;k=c[h+12>>2]|0;l=(j-k|0)/60|0;j=c[a+16>>2]|0;if(l>>>0<j>>>0){yDb(h,16,2314160,(m=i,i=i+8|0,c[m>>2]=c[k+(l*60|0)>>2],m)|0);i=m;JCb(g);n=0;i=f;return n|0}if(l>>>0<((c[h+40>>2]|0)+j|0)>>>0){n=ui(h,l,d)|0;i=f;return n|0}j=c[a+40>>2]|0;a=j+(l*1048|0)+1046|0;g=b[a>>1]|0;if(g<<16>>16==256){yDb(h,24,2293432,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;m=j+(l*1048|0)+1044|0;h=e[m>>1]|0;k=(b[a>>1]|0)-1&65535;b[a>>1]=k;JCb(j+(l*1048|0)+20+(((k&65535)+h&255)<<2)|0);o=b[a>>1]|0;p=m}else{o=g;p=j+(l*1048|0)+1044|0}g=e[p>>1]|0;b[a>>1]=o+1;c[j+(l*1048|0)+20+((g+(o&65535)&255)<<2)>>2]=d;n=0;i=f;return n|0}function si(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;d=i;i=i+8|0;f=d|0;g=c[a>>2]|0;h=g+44|0;j=c[h>>2]|0;k=j+16|0;l=(c[k>>2]|0)+(((c[a+4>>2]|0)-(c[g+28>>2]|0)|0)/60|0)|0;a=g+24|0;if(!(l>>>0<(c[a>>2]|0)>>>0)){m=-541478725;i=d;return m|0}n=j+40|0;o=g+16|0;p=g;q=g+12|0;r=g+40|0;s=j+32|0;j=g+32|0;t=f|0;u=f+4|0;v=l;a:while(1){if((c[(c[n>>2]|0)+(v*1048|0)+16>>2]|0)==0){l=Ni(c[(c[o>>2]|0)+(v<<2)>>2]|0)|0;if(!((l|0)==-541478725)){m=l;w=35;break}l=c[h>>2]|0;c[(c[l+40>>2]|0)+(v*1048|0)+16>>2]=1;x=l+32|0;l=(c[x>>2]|0)-1|0;c[x>>2]=l;yDb(p,40,2338352,(y=i,i=i+16|0,c[y>>2]=c[(c[q>>2]|0)+(v*60|0)>>2],c[y+8>>2]=l,y)|0);i=y}l=c[k>>2]|0;x=c[r>>2]|0;z=l-1+x|0;if((c[s>>2]|0)==0){A=x}else{x=l;while(1){do{if((c[(c[n>>2]|0)+(x*1048|0)+16>>2]|0)==0){l=Ni(c[(c[o>>2]|0)+(x<<2)>>2]|0)|0;if((l|0)==-541478725){B=c[h>>2]|0;c[(c[B+40>>2]|0)+(x*1048|0)+16>>2]=1;C=B+32|0;B=(c[C>>2]|0)-1|0;c[C>>2]=B;yDb(p,40,2338352,(y=i,i=i+16|0,c[y>>2]=c[(c[q>>2]|0)+(x*60|0)>>2],c[y+8>>2]=B,y)|0);i=y;break}else{if((l|0)<0){m=l;w=35;break a}else{break}}}}while(0);if((x|0)==(z|0)){D=c[k>>2]|0}else{D=x+1|0}if((c[s>>2]|0)==0){break}else{x=D}}A=c[r>>2]|0}x=c[h>>2]|0;z=x+16|0;l=c[z>>2]|0;B=l+A|0;C=x+40|0;E=c[C>>2]|0;G=E+(l*1048|0)|0;H=c[G>>2]|0;I=c[G+4>>2]|0;G=l+1|0;if(G>>>0<B>>>0){l=I;J=H;K=G;while(1){G=E+(K*1048|0)|0;L=c[G>>2]|0;M=c[G+4>>2]|0;G=(l|0)>(M|0)|(l|0)==(M|0)&J>>>0>L>>>0;N=G?J:L;L=G?l:M;M=K+1|0;if(M>>>0<B>>>0){l=L;J=N;K=M}else{O=L;P=N;break}}}else{O=I;P=H}K=x+24|0;J=YGb(c[K>>2]|0,c[K+4>>2]|0,P,O)|0;l=F;c[K>>2]=J;c[K+4>>2]=l;c[z>>2]=B;c[x+32>>2]=c[r>>2];yDb(p,40,1880392,(y=i,i=i+16|0,c[y>>2]=J,c[y+8>>2]=l,y)|0);i=y;l=c[z>>2]|0;do{if(l>>>0<(c[a>>2]|0)>>>0){J=c[x+4>>2]|0;K=(c[x+8>>2]|0)+J|0;E=c[r>>2]|0;if(J>>>0<K>>>0){N=J;J=l;L=E;while(1){M=J-L+N|0;G=c[o>>2]|0;Q=c[h>>2]|0;R=c[(c[j>>2]|0)+(N<<2)>>2]|0;S=Q+40|0;T=(c[S>>2]|0)+(M*1048|0)|0;U=c[T>>2]|0;V=c[T+4>>2]|0;T=Q+24|0;Q=c[T>>2]|0;W=c[T+4>>2]|0;c[t>>2]=1;T=c[(c[G+(M<<2)>>2]|0)+48>>2]|0;c[u>>2]=T;G=R+40|0;X=hBb(c[G>>2]|0,c[G+4>>2]|0)|0;if((T|0)==0){m=-558323010;w=35;break a}T=(c[S>>2]|0)+(M*1048|0)|0;M=ZGb(P,O,c[T>>2]|0,c[T+4>>2]|0)|0;T=R+56|0;S=KDb(M,F,T,f)|0;M=F;G=c[u>>2]|0;if((G|0)<48e3){Y=9600}else{Y=(G|0)/5|0}if(!((S|0)==0&(M|0)==0)){G=R+52|0;Z=ZGb(U,V,P,O)|0;V=YGb(Z,F,Q,W)|0;W=F;Q=Y;Z=0;U=0;_=M;M=S;while(1){S=(Q|0)<0|0?-1:0;$=(S|0)>(_|0)|(S|0)==(_|0)&Q>>>0>M>>>0?M:Q;S=fi(R,$)|0;if((S|0)==0){m=-12;w=35;break a}GFb(c[S+64>>2]|0,0,$,X,c[G>>2]|0)|0;aa=KDb(U,Z,f,T)|0;ba=YGb(V,W,aa,F)|0;aa=S+136|0;c[aa>>2]=ba;c[aa+4>>2]=F;aa=cj(R,S)|0;if((aa|0)<0){m=aa;w=35;break a}aa=$;S=($|0)<0|0?-1:0;ba=YGb(aa,S,U,Z)|0;ca=F;da=ZGb(M,_,aa,S)|0;if((M|0)==(aa|0)&(_|0)==(S|0)){break}else{Q=$;Z=ca;U=ba;_=F;M=da}}}M=N+1|0;_=c[z>>2]|0;U=c[r>>2]|0;if(M>>>0<K>>>0){N=M;J=_;L=U}else{ea=_;fa=U;break}}}else{ea=l;fa=E}L=ea+fa|0;if(ea>>>0<L>>>0){ga=ea}else{break}do{while(1){J=c[C>>2]|0;N=J+(ga*1048|0)+1046|0;K=b[N>>1]|0;if(K<<16>>16==0){break}U=J+(ga*1048|0)+1044|0;_=J+(ga*1048|0)+20+((e[U>>1]|0)<<2)|0;J=c[_>>2]|0;b[N>>1]=K-1;c[_>>2]=0;b[U>>1]=(b[U>>1]|0)+1&255;U=ui(g,ga,J)|0;if((U|0)<0){m=U;w=35;break a}}ga=ga+1|0;}while(ga>>>0<L>>>0)}}while(0);C=(c[r>>2]|0)+v|0;if(C>>>0<(c[a>>2]|0)>>>0){v=C}else{m=-541478725;w=35;break}}if((w|0)==35){i=d;return m|0}return 0}function ti(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=((c[a+4>>2]|0)-(c[d+28>>2]|0)|0)/60|0;g=d+16|0;h=c[(c[g>>2]|0)+(f<<2)>>2]|0;c[a+56>>2]=1;c[a+60>>2]=1e6;j=a+20|0;c[j>>2]=c[h+20>>2];k=a+24|0;c[k>>2]=c[h+24>>2];l=a+28|0;m=h+28|0;n=l;o=c[m>>2]|0;p=c[m+4>>2]|0;c[n>>2]=o;c[n+4>>2]=p;c[a+52>>2]=c[h+52>>2];h=e+12|0;if(!((c[h>>2]|0)>>>0>1>>>0)){q=0;i=b;return q|0}p=d+40|0;m=l|0;l=a+32|0;a=d;r=d+12|0;d=e+36|0;e=2;s=f;t=o;while(1){o=(c[p>>2]|0)+s|0;u=c[(c[g>>2]|0)+(o<<2)>>2]|0;if((t|0)==0){v=u+28|0;w=c[v>>2]|0;x=c[v+4>>2]|0;c[n>>2]=w;c[n+4>>2]=x;y=w}else{y=t}w=c[j>>2]|0;x=c[u+20>>2]|0;do{if((w|0)==(x|0)){v=c[k>>2]|0;z=c[u+24>>2]|0;if((v|0)!=(z|0)){A=z;B=v;C=10;break}z=c[u+28>>2]|0;if(!((y|0)==(z|0)|(z|0)==0)){A=v;B=v;C=10;break}if((c[l>>2]|0)!=(c[u+32>>2]|0)){A=v;B=v;C=10}}else{A=c[u+24>>2]|0;B=c[k>>2]|0;C=10}}while(0);if((C|0)==10){C=0;v=c[r>>2]|0;z=c[u+28>>2]|0;D=c[u+32>>2]|0;E=c[v+(f*60|0)>>2]|0;F=c[l>>2]|0;yDb(a,16,1900440,(G=i,i=i+80|0,c[G>>2]=c[v+(o*60|0)>>2],c[G+8>>2]=x,c[G+16>>2]=A,c[G+24>>2]=z,c[G+32>>2]=D,c[G+40>>2]=E,c[G+48>>2]=w,c[G+56>>2]=B,c[G+64>>2]=y,c[G+72>>2]=F,G)|0);i=G;if((c[d>>2]|0)==0){q=-22;C=13;break}}if(!(e>>>0<(c[h>>2]|0)>>>0)){q=0;C=13;break}e=e+1|0;s=o;t=c[m>>2]|0}if((C|0)==13){i=b;return q|0}return 0}function ui(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=c[a+44>>2]|0;h=c[(c[a+16>>2]|0)+(b<<2)>>2]|0;j=c[(c[a+32>>2]|0)+(((b>>>0)%((c[a+40>>2]|0)>>>0)|0)<<2)>>2]|0;a=c[g+40>>2]|0;k=d+136|0;l=j+56|0;m=KDb(c[k>>2]|0,c[k+4>>2]|0,h+56|0,l)|0;n=F;c[k>>2]=m;c[k+4>>2]=n;o=a+(b*1048|0)|0;c[o>>2]=m;c[o+4>>2]=n;p=a+(b*1048|0)+8|0;b=c[p>>2]|0;a=c[p+4>>2]|0;q=YGb(b,a,1,0)|0;r=F;c[p>>2]=q;c[p+4>>2]=r;p=c[h+48>>2]|0;do{if((p|0)==0){h=0;if(!((a|0)>(h|0)|(a|0)==(h|0)&b>>>0>0>>>0)){break}h=IDb(m,n,q,r,b,a)|0;c[o>>2]=h;c[o+4>>2]=F}else{h=c[d+76>>2]|0;c[f>>2]=1;c[f+4>>2]=p;s=KDb(h,(h|0)<0|0?-1:0,f,l)|0;h=YGb(c[o>>2]|0,c[o+4>>2]|0,s,F)|0;c[o>>2]=h;c[o+4>>2]=F}}while(0);o=g+24|0;g=YGb(c[k>>2]|0,c[k+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;c[k>>2]=g;c[k+4>>2]=F;k=cj(j,d)|0;i=e;return k|0}function vi(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;$Db(b+80|0);rZ(c[b+52>>2]|0);a=b+20|0;d=b+60|0;if((c[a>>2]|0)>0){e=d;f=0;do{$Db((c[e>>2]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[a>>2]|0))}$Db(d);$Db(b+72|0);JCb(b+12|0);return}function wi(a){a=a|0;var b=0,d=0,e=0;b=c[c[a+16>>2]>>2]|0;d=c[c[a+32>>2]>>2]|0;a=xk(549696)|0;if((a|0)==0){e=-12;return e|0}Hk(a,b+68|0);a=Ek()|0;if((a|0)==0){e=-12;return e|0}Gk(a,b+84|0);a=Dk()|0;if((a|0)==0){e=-12;return e|0}Hk(a,b+76|0);b=xk(550104)|0;if((b|0)==0){e=-12;return e|0}Hk(b,d+64|0);e=0;return e|0}function xi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a|0;d=c[b>>2]|0;e=c[d+44>>2]|0;f=c[c[d+16>>2]>>2]|0;d=e+16|0;c[d>>2]=0;do{g=Ni(f)|0;}while((c[d>>2]|0)==0&(g|0)>-1);if(!((g|0)==-541478725)){return g|0}if((c[e+12>>2]|0)==0){return g|0}e=c[(c[b>>2]|0)+44>>2]|0;b=e+48|0;d=(c[b>>2]|0)+1|0;c[b>>2]=d;if((d|0)>=(c[a+20>>2]|0)){c[b>>2]=0}c[e+64>>2]=0;c[e+16>>2]=1;cj(a,PCb(c[e+12>>2]|0)|0)|0;return g|0}function yi(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0,B=0,C=0,D=0;b=i;d=c[a>>2]|0;e=c[c[d+16>>2]>>2]|0;f=c[d+44>>2]|0;h=f+4|0;j=a+20|0;c[j>>2]=c[h>>2];k=f+8|0;l=c[k>>2]|0;m=a+24|0;c[m>>2]=l;if((c[f+32>>2]|0)==0){n=l}else{n=(l|0)/(c[e+148>>2]|0)|0}c[f+24>>2]=n;l=n<<1;n=1;while(1){o=1<<n;if((o|0)<(l|0)){n=n+1|0}else{break}}l=f+56|0;do{if((n|0)!=(c[l>>2]|0)){p=f+52|0;rZ(c[p>>2]|0);c[p>>2]=pZ(n,0)|0;c[l>>2]=n;p=f+20|0;q=f+60|0;r=q;if((c[p>>2]|0)>0){s=0;do{$Db((c[r>>2]|0)+(s<<2)|0);s=s+1|0;}while((s|0)<(c[p>>2]|0))}$Db(q);s=c[e+148>>2]|0;c[p>>2]=s;if(!(s>>>0<65536>>>0|(s&1073741823|0)==(s|0))){t=-22;i=b;return t|0}if(!(o>>>0<65536>>>0|(o&1073741823|0)==(o|0))){t=-22;i=b;return t|0}u=o<<2;v=WDb(s<<2)|0;c[r>>2]=v;if((v|0)==0){t=-12;i=b;return t|0}else{w=0}while(1){if((w|0)>=(c[p>>2]|0)){break}v=WDb(u)|0;c[(c[r>>2]|0)+(w<<2)>>2]=v;if((c[(c[r>>2]|0)+(w<<2)>>2]|0)==0){t=-12;x=34;break}else{w=w+1|0}}if((x|0)==34){i=b;return t|0}c[f+64>>2]=0;r=f+72|0;u=YDb(c[r>>2]|0,o,4)|0;p=u;c[r>>2]=p;if((u|0)==0){t=-12;i=b;return t|0}u=c[f+76>>2]|0;do{if((u|0)==3){if((o|0)<=0){break}y=+(o-1|0);r=0;do{z=+(r|0);g[p+(r<<2)>>2]=.41999998688697815- +T(z*6.283185307179586/y)*.5+ +T(z*12.566370614359172/y)*.07999999821186066;r=r+1|0;}while((r|0)<(o|0))}else if((u|0)==0){if((o|0)>0){A=0}else{break}do{g[p+(A<<2)>>2]=1.0;A=A+1|0;}while((A|0)<(o|0))}else if((u|0)==2){if((o|0)<=0){break}y=+(o-1|0);r=0;do{g[p+(r<<2)>>2]=.5400000214576721- +T(+(r|0)*6.283185307179586/y)*.46000000834465027;r=r+1|0;}while((r|0)<(o|0))}else if((u|0)==1){if((o|0)<=0){break}y=+(o-1|0);r=0;do{g[p+(r<<2)>>2]=(1.0- +T(+(r|0)*6.283185307179586/y))*.5;r=r+1|0;}while((r|0)<(o|0))}else{yDb(0,0,2046800,(B=i,i=i+24|0,c[B>>2]=2040512,c[B+8>>2]=2037024,c[B+16>>2]=229,B)|0);i=B;Cd();return 0}}while(0);p=f+12|0;JCb(p);u=Zr(a,c[j>>2]|0,c[m>>2]|0)|0;c[p>>2]=u;if((u|0)==0){t=-12;i=b;return t|0}c[a+28>>2]=1;c[a+32>>2]=1;if((c[m>>2]|0)<=0){break}p=u|0;r=u+32|0;q=u+4|0;v=u+36|0;s=u+8|0;C=u+40|0;u=0;do{D=(c[p>>2]|0)+(ba(c[r>>2]|0,u)|0)|0;TGb(D|0,0,c[j>>2]|0)|0;D=(c[q>>2]|0)+(ba(c[v>>2]|0,u)|0)|0;TGb(D|0,-128|0,c[j>>2]|0)|0;D=(c[s>>2]|0)+(ba(c[C>>2]|0,u)|0)|0;TGb(D|0,-128|0,c[j>>2]|0)|0;u=u+1|0;}while((u|0)<(c[m>>2]|0))}}while(0);a=f+48|0;if((c[a>>2]|0)>=(c[j>>2]|0)){c[a>>2]=0}a=f+80|0;c[a>>2]=YDb(c[a>>2]|0,(c[m>>2]|0)*3|0,4)|0;m=c[k>>2]|0;yDb(d,40,2033464,(B=i,i=i+24|0,c[B>>2]=c[h>>2],c[B+8>>2]=m,c[B+16>>2]=o,B)|0);i=B;t=0;i=b;return t|0}function zi(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0.0,O=0,P=0.0,Q=0.0,S=0.0,V=0.0,W=0.0,X=0.0,Y=0,Z=0,_=0,aa=0,ca=0,da=0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0,la=0,ma=0,na=0,oa=0.0,pa=0,qa=0.0,ra=0,sa=0.0,ta=0;f=i;i=i+16|0;h=f|0;j=f+8|0;c[j>>2]=e;k=d+8|0;l=c[k>>2]|0;m=c[l+44>>2]|0;n=c[e+76>>2]|0;o=m+68|0;c[o>>2]=0;if((n|0)==0){JCb(j);i=f;return 0}p=h|0;q=h+4|0;r=d+48|0;d=n;n=e;e=l;l=m;a:while(1){m=c[c[e+32>>2]>>2]|0;s=c[l+12>>2]|0;t=1<<(c[l+56>>2]|0)-1;u=t<<1;v=1.0/(+R(+(t|0))*32768.0);t=l+64|0;w=c[t>>2]|0;x=u-w|0;y=(x|0)>(d|0)?d:x;x=l+20|0;z=c[x>>2]|0;A=(z|0)>0;do{if(A){B=c[n+64>>2]|0;C=c[l+68>>2]|0;if((y|0)<=0){break}D=c[l+72>>2]|0;E=c[l+60>>2]|0;G=0;do{H=c[B+(G<<2)>>2]|0;I=c[E+(G<<2)>>2]|0;J=0;do{K=J+w|0;g[I+(K<<2)>>2]=+(b[H+(J+C<<1)>>1]|0)*+g[D+(K<<2)>>2];J=J+1|0;}while((J|0)<(y|0));G=G+1|0;}while((G|0)<(z|0))}}while(0);G=y+w|0;c[t>>2]=G;if((G|0)==(u|0)){G=c[l+24>>2]|0;if(A){D=l+52|0;C=l+60|0;E=0;while(1){qZ(c[D>>2]|0,c[(c[C>>2]|0)+(E<<2)>>2]|0);B=E+1|0;J=c[x>>2]|0;if((B|0)<(J|0)){E=B}else{L=J;break}}}else{L=z}E=m+24|0;C=c[E>>2]|0;if((C|0)>0){D=c[l+80>>2]|0;A=0;do{u=A*3|0;g[D+(u<<2)>>2]=0.0;g[D+(u+1<<2)>>2]=127.5;g[D+(u+2<<2)>>2]=127.5;A=A+1|0;}while((A|0)<(C|0))}if((L|0)>0){C=l+32|0;A=l+36|0;D=l+44|0;z=(G|0)>0;u=l+80|0;t=l+60|0;w=l+40|0;J=0;B=L;while(1){H=c[C>>2]|0;do{if((H|0)==1){if((c[A>>2]|0)==0){M=256.0;N=256.0;O=24}else{P=256.0;Q=256.0;S=256.0}}else if((H|0)==0){V=256.0/+(B|0);I=c[A>>2]|0;if((I|0)==1){P=V;Q=V;S=V;break}else if((I|0)!=0){O=21;break a}M=V;N=V*3.141592653589793;O=24}else{O=22;break a}}while(0);do{if((O|0)==24){O=0;if((B|0)<=1){P=0.0;Q=0.0;S=M;break}V=+(J|0)*6.283185307179586/+(B|0);P=N*+T(V)*.5;Q=N*+U(V)*.5;S=M}}while(0);V=+g[D>>2];W=Q*V;X=P*V;if(z){I=ba(J,G)|0;K=0;Y=H;while(1){Z=(((Y|0)==0?0:I)+K|0)*3|0;_=c[u>>2]|0;aa=_+(Z<<2)|0;ca=K<<1;da=c[(c[t>>2]|0)+(J<<2)>>2]|0;V=v*+Rb(+(+g[da+(ca<<2)>>2]),+(+g[da+((ca|1)<<2)>>2]));ca=c[w>>2]|0;if((ca|0)==3){ea=V<1.0?V:1.0;fa=1.0- +$(ea>1.0e-6?ea:1.0e-6)/-13.815510557964274}else if((ca|0)==2){fa=+sb(+V)}else if((ca|0)==1){fa=+R(V)}else if((ca|0)==0){fa=V}else{O=32;break a}if((c[A>>2]|0)==1){ca=1;while(1){if(!(ca>>>0<7>>>0)){break}if(+g[911984+(ca<<4)>>2]<fa){ca=ca+1|0}else{break}}da=ca-1|0;V=+g[911984+(da<<4)>>2];do{if(fa>V){ea=+g[911984+(ca<<4)>>2];if(fa<ea){ga=(fa-V)/(ea-V);ea=1.0-ga;ha=ea*+g[911996+(da<<4)>>2]+ga*+g[911996+(ca<<4)>>2];ia=ea*+g[911992+(da<<4)>>2]+ga*+g[911992+(ca<<4)>>2];ja=+g[911988+(da<<4)>>2]*ea+ga*+g[911988+(ca<<4)>>2];break}else{ha=+g[911996+(ca<<4)>>2];ia=+g[911992+(ca<<4)>>2];ja=+g[911988+(ca<<4)>>2];break}}else{ha=+g[911996+(da<<4)>>2];ia=+g[911992+(da<<4)>>2];ja=+g[911988+(da<<4)>>2]}}while(0);g[aa>>2]=S*ja+ +g[aa>>2];da=_+(Z+1<<2)|0;g[da>>2]=W*ia+ +g[da>>2];da=_+(Z+2<<2)|0;g[da>>2]=X*ha+ +g[da>>2]}else{g[aa>>2]=S*fa+ +g[aa>>2];da=_+(Z+1<<2)|0;g[da>>2]=W*fa+ +g[da>>2];da=_+(Z+2<<2)|0;g[da>>2]=X*fa+ +g[da>>2]}da=K+1|0;if((da|0)>=(G|0)){break}K=da;Y=c[C>>2]|0}ka=c[x>>2]|0}else{ka=B}Y=J+1|0;if((Y|0)<(ka|0)){J=Y;B=ka}else{break}}}if((c[l+28>>2]|0)==0){la=l+48|0}else{B=m+20|0;do{if((c[E>>2]|0)>0){J=s|0;x=s+32|0;C=0;do{G=c[J>>2]|0;A=ba(c[x>>2]|0,C)|0;VGb(G+A|0,G+(A+1)|0,(c[B>>2]|0)-1|0)|0;C=C+1|0;ma=c[E>>2]|0;}while((C|0)<(ma|0));if((ma|0)<=0){break}C=s+4|0;x=s+36|0;J=0;do{A=c[C>>2]|0;G=ba(c[x>>2]|0,J)|0;VGb(A+G|0,A+(G+1)|0,(c[B>>2]|0)-1|0)|0;J=J+1|0;na=c[E>>2]|0;}while((J|0)<(na|0));if((na|0)<=0){break}J=s+8|0;x=s+40|0;C=0;do{G=c[J>>2]|0;A=ba(c[x>>2]|0,C)|0;VGb(G+A|0,G+(A+1)|0,(c[B>>2]|0)-1|0)|0;C=C+1|0;}while((C|0)<(c[E>>2]|0))}}while(0);C=l+48|0;c[C>>2]=(c[B>>2]|0)-1;la=C}C=l+80|0;x=c[E>>2]|0;J=s+32|0;b:do{if((x|0)>0){A=(ba(c[J>>2]|0,x-1|0)|0)+(c[la>>2]|0)|0;G=0;w=(c[s>>2]|0)+A|0;while(1){v=+g[(c[C>>2]|0)+((G*3|0)<<2)>>2];do{if(v<=255.0&v<0.0){oa=0.0}else{if(v>255.0){oa=255.0;break}oa=v}}while(0);a[w]=~~+Gc(+oa);Z=G+1|0;pa=c[E>>2]|0;if((Z|0)>=(pa|0)){break}G=Z;w=w+(-(c[J>>2]|0)|0)|0}w=s+36|0;if((pa|0)<=0){break}G=(ba(c[w>>2]|0,pa-1|0)|0)+(c[la>>2]|0)|0;Z=0;_=(c[s+4>>2]|0)+G|0;while(1){v=+g[(c[C>>2]|0)+((Z*3|0)+1<<2)>>2];do{if(v<=255.0&v<0.0){qa=0.0}else{if(v>255.0){qa=255.0;break}qa=v}}while(0);a[_]=~~+Gc(+qa);G=Z+1|0;ra=c[E>>2]|0;if((G|0)>=(ra|0)){break}Z=G;_=_+(-(c[w>>2]|0)|0)|0}w=s+40|0;if((ra|0)<=0){break}_=(ba(c[w>>2]|0,ra-1|0)|0)+(c[la>>2]|0)|0;Z=0;G=(c[s+8>>2]|0)+_|0;while(1){v=+g[(c[C>>2]|0)+((Z*3|0)+2<<2)>>2];do{if(v<=255.0&v<0.0){sa=0.0}else{if(v>255.0){sa=255.0;break}sa=v}}while(0);a[G]=~~+Gc(+sa);_=Z+1|0;if((_|0)>=(c[E>>2]|0)){break b}Z=_;G=G+(-(c[w>>2]|0)|0)|0}}}while(0);E=n+136|0;C=c[E>>2]|0;J=c[E+4>>2]|0;E=c[l+68>>2]|0;c[p>>2]=1;c[q>>2]=c[r>>2];x=KDb(E,(E|0)<0|0?-1:0,h,m+56|0)|0;E=YGb(x,F,C,J)|0;J=s+136|0;c[J>>2]=E;c[J+4>>2]=F;J=c[(c[m>>2]|0)+44>>2]|0;E=J+48|0;C=(c[E>>2]|0)+1|0;c[E>>2]=C;if((C|0)>=(c[m+20>>2]|0)){c[E>>2]=0}c[J+64>>2]=0;c[J+16>>2]=1;if((cj(m,PCb(c[J+12>>2]|0)|0)|0)<0){O=86;break}}if((y|0)<0){O=86;break}c[o>>2]=(c[o>>2]|0)+y;if((d|0)==(y|0)){O=86;break}J=c[k>>2]|0;d=d-y|0;n=c[j>>2]|0;e=J;l=c[J+44>>2]|0}if((O|0)==21){yDb(0,0,2046800,(ta=i,i=i+24|0,c[ta>>2]=2040512,c[ta+8>>2]=2037024,c[ta+16>>2]=357,ta)|0);i=ta;Cd();return 0}else if((O|0)==22){yDb(0,0,2046800,(ta=i,i=i+24|0,c[ta>>2]=2040512,c[ta+8>>2]=2037024,c[ta+16>>2]=367,ta)|0);i=ta;Cd();return 0}else if((O|0)==32){yDb(0,0,2046800,(ta=i,i=i+24|0,c[ta>>2]=2040512,c[ta+8>>2]=2037024,c[ta+16>>2]=404,ta)|0);i=ta;Cd();return 0}else if((O|0)==86){JCb(j);i=f;return 0}return 0}function Ai(a){a=a|0;JCb((c[a+44>>2]|0)+24|0);return}function Bi(a){a=a|0;var b=0,d=0,e=0;b=c[c[a+16>>2]>>2]|0;d=c[c[a+32>>2]>>2]|0;a=xk(549688)|0;if((a|0)==0){e=-12;return e|0}Hk(a,b+68|0);a=Ek()|0;if((a|0)==0){e=-12;return e|0}Gk(a,b+84|0);a=Dk()|0;if((a|0)==0){e=-12;return e|0}Hk(a,b+76|0);b=xk(550096)|0;if((b|0)==0){e=-12;return e|0}Hk(b,d+64|0);e=0;return e|0}function Ci(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a|0;d=c[b>>2]|0;e=c[d+44>>2]|0;f=c[c[d+16>>2]>>2]|0;d=e+28|0;c[d>>2]=0;do{g=Ni(f)|0;}while((c[d>>2]|0)==0&(g|0)>-1);if(!((g|0)==-541478725)){return g|0}if((c[e+24>>2]|0)==0){return g|0}e=c[(c[b>>2]|0)+44>>2]|0;b=e+24|0;if((cj(a,c[b>>2]|0)|0)>-1){c[e+28>>2]=1}c[b>>2]=0;c[e+20>>2]=0;return g|0}function Di(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=f;j=c[a>>2]|0;k=c[c[j+16>>2]>>2]|0;l=c[j+44>>2]|0;m=l+32|0;if((c[m>>2]|0)==0){n=k+48|0;o=c[l+4>>2]|0;p=+(c[n>>2]|0)/(+(o|0)*(+(c[l+12>>2]|0)/+(c[l+16>>2]|0)))+.5;if(p<1.0){q=1}else{q=~~p}c[m>>2]=q;r=o;s=n}else{r=c[l+4>>2]|0;s=k+48|0}c[l+20>>2]=0;k=l+4|0;c[a+20>>2]=r;r=l+8|0;c[a+24>>2]=c[r>>2];c[a+28>>2]=1;c[a+32>>2]=1;c[d>>2]=c[s>>2];c[d+4>>2]=c[m>>2];c[e>>2]=c[k>>2];c[e+4>>2]=1;kFb(g,d,e);e=a+116|0;a=c[f>>2]|0;d=c[f+4>>2]|0;c[e>>2]=a;c[e+4>>2]=d;e=c[r>>2]|0;r=c[m>>2]|0;yDb(j,40,2210848,(j=i,i=i+32|0,c[j>>2]=c[k>>2],c[j+8>>2]=e,h[j+16>>3]=+(a|0)/+(d|0),c[j+24>>2]=r,j)|0);i=j;i=b;return 0}function Ei(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;g=i;i=i+16|0;h=g|0;j=g+8|0;c[h>>2]=f;k=c[e+8>>2]|0;l=c[c[k+32>>2]>>2]|0;m=c[k+44>>2]|0;k=c[f+76>>2]|0;n=m+24|0;o=c[n>>2]|0;if((o|0)==0){p=0}else{p=c[o+32>>2]|0}q=c[e+148>>2]|0;r=c[m+32>>2]|0;s=255/(ba(r,q)|0)|0;a:do{if((k|0)>0){t=l+20|0;u=l+24|0;v=j|0;w=j+4|0;x=e+48|0;y=l+56|0;z=(q|0)>0;A=m+36|0;B=m+20|0;C=m+4|0;D=l|0;E=m+8|0;G=m+40|0;H=0;I=c[f>>2]|0;J=0;K=p;L=o;b:while(1){do{if((L|0)==0){M=Zr(l,c[t>>2]|0,c[u>>2]|0)|0;c[n>>2]=M;if((M|0)==0){N=-12;O=34;break b}c[M+68>>2]=c[t>>2];c[M+72>>2]=c[u>>2];P=c[h>>2]|0;Q=P+136|0;R=c[Q>>2]|0;S=c[Q+4>>2]|0;Q=(I-(c[P>>2]|0)>>1|0)/(q|0)|0;c[v>>2]=1;c[w>>2]=c[x>>2];P=KDb(Q,(Q|0)<0|0?-1:0,j,y)|0;Q=YGb(P,F,R,S)|0;S=M+136|0;c[S>>2]=Q;c[S+4>>2]=F;S=c[M+32>>2]|0;if((c[u>>2]|0)<=0){T=M;U=S;break}Q=M|0;R=0;while(1){P=(c[Q>>2]|0)+(ba(R,S)|0)|0;TGb(P|0,0,c[t>>2]|0)|0;P=R+1|0;if((P|0)<(c[u>>2]|0)){R=P}else{T=M;U=S;break}}}else{T=L;U=K}}while(0);if(z){S=T|0;M=1;R=I;while(1){Q=(c[E>>2]|0)/2|0;P=Q;V=(Q|0)<0|0?-1:0;W=R+2|0;X=b[R>>1]|0;Y=IDb(X<<16>>16,X<<16>>16<0|0?-1:0,P,V,32767,0)|0;X=ZGb(P,V,Y,F)|0;Y=X;X=c[G>>2]|0;do{if((X|0)==1){V=(c[u>>2]|0)-1|0;if((Y|0)<0){Z=0}else{Z=(Y|0)>(V|0)?V:Y}if((Q|0)>(Z|0)){_=Q;$=Z<<16>>16}else{_=Z;$=Q}if(($|0)<(_|0)){aa=$}else{break}do{V=(c[S>>2]|0)+((c[B>>2]|0)+(ba(aa,U)|0))|0;a[V]=(d[V]|0)+s;aa=aa+1|0;}while((aa|0)<(_|0))}else if((X|0)==0){if(!((Y|0)>-1)){break}if((Y|0)>=(c[u>>2]|0)){break}V=(c[S>>2]|0)+((c[B>>2]|0)+(ba(Y,U)|0))|0;a[V]=(d[V]|0)+s}}while(0);if((M|0)>=(q|0)){break}M=M+1|0;R=W}ca=I+(q<<1)|0}else{ca=I}R=(c[A>>2]|0)+1|0;c[A>>2]=R;if((R|0)==(r|0)){c[A>>2]=0;R=(c[B>>2]|0)+1|0;c[B>>2]=R;da=R}else{da=c[B>>2]|0}if((da|0)==(c[C>>2]|0)){ea=c[(c[D>>2]|0)+44>>2]|0;fa=ea+24|0;ga=cj(l,c[fa>>2]|0)|0;if(!((ga|0)>-1)){O=30;break}c[ea+28>>2]=1;c[fa>>2]=0;c[ea+20>>2]=0;ha=ga}else{ha=J}R=H+1|0;if((R|0)<(k|0)){H=R;I=ca;J=ha;K=U;L=c[n>>2]|0}else{ia=ha;break a}}if((O|0)==30){c[fa>>2]=0;c[ea+20>>2]=0;ia=ga;break}else if((O|0)==34){i=g;return N|0}}else{ia=0}}while(0);JCb(h);N=ia;i=g;return N|0}function Fi(){return 262756}function Gi(){return 2353960}function Hi(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c[b>>2]|0;i=h>>>0<a>>>0?h:a;a=aEb(c[e>>2]|0,h+1|0,60)|0;h=aEb(c[f>>2]|0,(c[b>>2]|0)+1|0,4)|0;j=(a|0)!=0;if(j){c[e>>2]=a}if((h|0)==0){k=-12;return k|0}c[f>>2]=h;if(!j){k=-12;return k|0}j=c[e>>2]|0;h=i+1|0;VGb(j+(h*60|0)|0,j+(i*60|0)|0,((c[b>>2]|0)-i|0)*60|0|0)|0;j=c[f>>2]|0;VGb(j+(h<<2)|0,j+(i<<2)|0,(c[b>>2]|0)-i<<2|0)|0;UGb((c[e>>2]|0)+(i*60|0)|0,g|0,60)|0;c[(c[f>>2]|0)+(i<<2)>>2]=0;i=(c[b>>2]|0)+1|0;c[b>>2]=i;if(!(h>>>0<i>>>0)){k=0;return k|0}g=c[f>>2]|0;f=h;h=i;while(1){i=c[g+(f<<2)>>2]|0;if((i|0)==0){l=h}else{e=i+d|0;c[e>>2]=(c[e>>2]|0)+1;l=c[b>>2]|0}e=f+1|0;if(e>>>0<l>>>0){f=e;h=l}else{k=0;break}}return k|0}function Ii(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;if(!((c[a+40>>2]|0)>>>0>b>>>0)){g=-1;i=f;return g|0}if(!((c[d+24>>2]|0)>>>0>e>>>0)){g=-1;i=f;return g|0}h=a+32|0;if((c[(c[h>>2]|0)+(b<<2)>>2]|0)!=0){g=-1;i=f;return g|0}j=d+16|0;if((c[(c[j>>2]|0)+(e<<2)>>2]|0)!=0){g=-1;i=f;return g|0}k=a+28|0;l=c[(c[k>>2]|0)+(b*60|0)+4>>2]|0;m=d+12|0;if((l|0)!=(c[(c[m>>2]|0)+(e*60|0)+4>>2]|0)){n=c[a+8>>2]|0;o=lGb(l)|0;l=c[d+8>>2]|0;p=lGb(c[(c[m>>2]|0)+(e*60|0)+4>>2]|0)|0;yDb(a,16,2194928,(q=i,i=i+48|0,c[q>>2]=n,c[q+8>>2]=b,c[q+16>>2]=(o|0)!=0?o:2116416,c[q+24>>2]=l,c[q+32>>2]=e,c[q+40>>2]=(p|0)!=0?p:2116416,q)|0);i=q;g=-22;i=f;return g|0}q=cEb(168)|0;p=q;if((q|0)==0){g=-12;i=f;return g|0}c[(c[j>>2]|0)+(e<<2)>>2]=p;c[(c[h>>2]|0)+(b<<2)>>2]=p;c[q>>2]=a;c[q+8>>2]=d;d=c[k>>2]|0;c[q+4>>2]=d+(b*60|0);c[q+12>>2]=(c[m>>2]|0)+(e*60|0);c[q+16>>2]=c[d+(b*60|0)+4>>2];c[q+52>>2]=-1;g=0;i=f;return g|0}function Ji(a){a=a|0;return c[a+148>>2]|0}function Ki(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=a+12|0;h=a+8|0;j=c[h>>2]|0;k=((c[g>>2]|0)-(c[j+12>>2]|0)|0)/60|0;l=c[(c[a>>2]|0)+8>>2]|0;m=c[j+8>>2]|0;yDb(j,40,2057280,(j=i,i=i+24|0,c[j>>2]=c[b+8>>2],c[j+8>>2]=l,c[j+16>>2]=m,j)|0);i=j;c[(c[(c[h>>2]|0)+16>>2]|0)+(k<<2)>>2]=0;j=Ii(b,e,c[h>>2]|0,k)|0;if((j|0)<0){c[(c[(c[h>>2]|0)+16>>2]|0)+(k<<2)>>2]=a;n=j;i=f;return n|0}c[h>>2]=b;c[g>>2]=(c[b+12>>2]|0)+(d*60|0);c[(c[b+16>>2]|0)+(d<<2)>>2]=a;d=a+68|0;if((c[d>>2]|0)!=0){Lk(d,(c[(c[b+32>>2]|0)+(e<<2)>>2]|0)+68|0)}d=a+76|0;if((c[d>>2]|0)!=0){Lk(d,(c[(c[b+32>>2]|0)+(e<<2)>>2]|0)+76|0)}d=a+84|0;if((c[d>>2]|0)==0){n=0;i=f;return n|0}Kk(d,(c[(c[b+32>>2]|0)+(e<<2)>>2]|0)+84|0);n=0;i=f;return n|0}function Li(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;d=a+24|0;e=c[d>>2]|0;if((e|0)==0){f=0;i=b;return f|0}g=a+16|0;h=0;j=e;a:while(1){k=c[(c[g>>2]|0)+(h<<2)>>2]|0;do{if((k|0)==0){l=j}else{m=k|0;e=c[m>>2]|0;if((c[e+24>>2]|0)==0){n=0}else{n=c[c[e+16>>2]>>2]|0}o=k+104|0;c[o>>2]=0;c[o+4>>2]=-2147483648;o=k+92|0;p=c[o>>2]|0;if((p|0)==1){q=7;break a}else if((p|0)!=0){l=j;break}c[o>>2]=1;p=Li(e)|0;if((p|0)<0){f=p;q=50;break a}p=c[(c[k+4>>2]|0)+48>>2]|0;if((p|0)==0){r=c[m>>2]|0;if((c[r+24>>2]|0)!=1){q=11;break a}}else{s=re[p&4095](k)|0;if((s|0)<0){q=13;break a}}p=c[k+16>>2]|0;b:do{if((p|0)==1){do{if((n|0)==0){t=c[k+56>>2]|0;q=42}else{e=k+56|0;if((c[e>>2]|0)!=0){break b}if((c[k+60>>2]|0)==0){u=n+56|0;v=e;e=c[u>>2]|0;w=c[u+4>>2]|0;c[v>>2]=e;c[v+4>>2]=w;t=e;q=42;break}else{break}}}while(0);if((q|0)==42){q=0;if((t|0)!=0){break}}e=k+60|0;if((c[e>>2]|0)!=0){break}w=c[k+48>>2]|0;c[k+56>>2]=1;c[e>>2]=w}else if((p|0)==0){w=k+56|0;do{if((c[w>>2]|0)==0){e=k+60|0;if((c[e>>2]|0)!=0){break}if((n|0)==0){c[k+56>>2]=1;c[e>>2]=1e6;break}else{e=n+56|0;v=w;u=c[e+4>>2]|0;c[v>>2]=c[e>>2];c[v+4>>2]=u;break}}}while(0);w=k+28|0;do{if((c[w>>2]|0)==0){u=k+32|0;if((c[u>>2]|0)!=0){q=25;break}if((n|0)==0){c[k+28>>2]=1;c[u>>2]=1;if((c[k+20>>2]|0)==0){q=35;break a}else{q=34;break}}else{u=n+28|0;v=w;e=c[u+4>>2]|0;c[v>>2]=c[u>>2];c[v+4>>2]=e;break}}else{q=25}}while(0);do{if((q|0)==25){q=0;if((n|0)!=0){break}if((c[k+20>>2]|0)==0){q=35;break a}else{q=34}}}while(0);if((q|0)==34){q=0;if((c[k+24>>2]|0)==0){q=35;break a}else{break}}w=k+116|0;do{if((c[w>>2]|0)==0){if((c[k+120>>2]|0)!=0){break}e=n+116|0;v=w;u=c[e+4>>2]|0;c[v>>2]=c[e>>2];c[v+4>>2]=u}}while(0);w=k+20|0;if((c[w>>2]|0)==0){c[w>>2]=c[n+20>>2]}w=k+24|0;if((c[w>>2]|0)!=0){break}c[w>>2]=c[n+24>>2]}}while(0);p=c[(c[k+12>>2]|0)+48>>2]|0;if((p|0)!=0){x=re[p&4095](k)|0;if((x|0)<0){q=47;break a}}c[o>>2]=2;l=c[d>>2]|0}}while(0);p=h+1|0;if(p>>>0<l>>>0){h=p;j=l}else{f=0;q=50;break}}if((q|0)==7){yDb(a,32,2011120,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;f=0;i=b;return f|0}else if((q|0)==11){yDb(r,16,1972152,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;f=-22;i=b;return f|0}else if((q|0)==13){r=c[m>>2]|0;yDb(r,16,1943360,(y=i,i=i+8|0,c[y>>2]=c[r+8>>2],y)|0);i=y;f=s;i=b;return f|0}else if((q|0)==35){yDb(c[m>>2]|0,16,1918592,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;f=-22;i=b;return f|0}else if((q|0)==47){yDb(c[m>>2]|0,16,1897840,(y=i,i=i+8|0,c[y>>2]=c[(c[k+8>>2]|0)+8>>2],y)|0);i=y;f=x;i=b;return f|0}else if((q|0)==50){i=b;return f|0}return 0}function Mi(a,b,d){a=a|0;b=b|0;d=d|0;d=i;i=i+128|0;if((c[b+16>>2]|0)==0){i=d;return}a=b+40|0;iBb(d|0,128,-1,c[a>>2]|0,c[a+4>>2]|0);i=d;return}function Ni(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+128|0;if((c[a+16>>2]|0)!=0){d=a+40|0;iBb(b|0,128,-1,c[d>>2]|0,c[d+4>>2]|0)}d=a+144|0;if((c[d>>2]|0)!=0){e=-541478725;i=b;return e|0}f=a+152|0;if((c[f>>2]|0)!=0){yDb(0,0,2355200,(g=i,i=i+24|0,c[g>>2]=2335120,c[g+8>>2]=2310088,c[g+16>>2]=342,g)|0);i=g;Cd();return 0}c[f>>2]=1;h=a+4|0;j=a|0;k=a+124|0;l=a+156|0;m=-1;while(1){n=c[(c[h>>2]|0)+44>>2]|0;do{if((n|0)==0){o=c[c[(c[j>>2]|0)+16>>2]>>2]|0;if((o|0)==0){p=m;break}p=Ni(o)|0}else{p=re[n&4095](a)|0}}while(0);if((p|0)==-541478725){n=c[k>>2]|0;if((n|0)==0){q=13;break}c[k>>2]=0;r=Oi(a,n)|0}else{r=p}if((r|0)<0){q=16;break}n=c[f>>2]|0;if((n|0)==0){e=r;q=22;break}if((c[l>>2]&1|0)==0){q=21;break}if((n|0)==0){e=r;q=22;break}else{m=r}}do{if((q|0)==13){c[f>>2]=0}else if((q|0)==16){c[f>>2]=0;if((r|0)==-541478725){break}else{e=r}i=b;return e|0}else if((q|0)==21){yDb(0,0,2355200,(g=i,i=i+24|0,c[g>>2]=2291144,c[g+8>>2]=2310088,c[g+16>>2]=360,g)|0);i=g;Cd();return 0}else if((q|0)==22){i=b;return e|0}}while(0);c[d>>2]=1;e=-541478725;i=b;return e|0}function Oi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,G=0.0,H=0.0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[f>>2]=b;j=a+8|0;k=c[j>>2]|0;l=c[a+12>>2]|0;c[g>>2]=0;m=c[k+60>>2]|0;if((c[a+144>>2]|0)!=0){JCb(f);n=-541478725;i=d;return n|0}o=c[l+36>>2]|0;p=(o|0)==0?826:o;a:do{if((c[l+56>>2]|0)==0){r=b;s=15}else{if((RCb(b)|0)!=0){r=c[f>>2]|0;s=15;break}yDb(c[j>>2]|0,48,2073808,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;o=a+16|0;u=c[o>>2]|0;if((u|0)==0){v=Zr(a,c[a+20>>2]|0,c[a+24>>2]|0)|0;s=9}else if((u|0)==1){v=fi(a,c[(c[f>>2]|0)+76>>2]|0)|0;s=9}else{w=-22}do{if((s|0)==9){c[g>>2]=v;if((v|0)==0){w=-12;break}u=NCb(v,c[f>>2]|0)|0;if((u|0)<0){w=u;break}u=c[o>>2]|0;if((u|0)==1){x=c[(c[g>>2]|0)+64>>2]|0;y=c[f>>2]|0;z=c[y+64>>2]|0;A=c[y+76>>2]|0;B=y+352|0;y=hBb(c[B>>2]|0,c[B+4>>2]|0)|0;IFb(x,z,0,0,A,y,c[(c[f>>2]|0)+80>>2]|0)|0}else if((u|0)==0){u=c[g>>2]|0;y=c[f>>2]|0;jDb(u|0,u+32|0,y|0,y+32|0,c[y+80>>2]|0,c[y+68>>2]|0,c[y+72>>2]|0)}else{w=-22;break}JCb(f);break a}}while(0);JCb(g);JCb(f);n=w;i=d;return n|0}}while(0);if((s|0)==15){c[g>>2]=r}b:do{if((m|0)!=0){r=a+56|0;s=a+60|0;w=m;do{C=+h[w>>3];f=(c[g>>2]|0)+136|0;if(C>(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0)*(+(c[r>>2]|0)/+(c[s>>2]|0))){break b}f=w+8|0;v=c[f>>2]|0;b=w+12|0;l=c[b>>2]|0;yDb(c[j>>2]|0,48,2069224,(t=i,i=i+24|0,h[t>>3]=C,c[t+8>>2]=v,c[t+16>>2]=l,t)|0);i=t;Pi(c[j>>2]|0,c[f>>2]|0,c[b>>2]|0,0,0,c[w+16>>2]|0)|0;b=(c[j>>2]|0)+60|0;f=c[b>>2]|0;$Db(f+12|0);$Db(f+8|0);c[b>>2]=c[f+20>>2];ZDb(f);w=c[(c[j>>2]|0)+60>>2]|0;}while((w|0)!=0)}}while(0);j=c[g>>2]|0;t=j+136|0;m=c[t>>2]|0;w=c[t+4>>2]|0;do{if((c[k+64>>2]|0)==0){D=p;E=a+160|0}else{t=sCb(j)|0;s=F;r=a+160|0;f=c[k+72>>2]|0;h[f+8>>3]=+((c[r>>2]|0)>>>0)+ +(c[r+4>>2]|0)*4294967296.0;if((m|0)==0&(w|0)==(-2147483648|0)){G=+q}else{G=(+(m>>>0)+ +(w|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}h[f>>3]=G;if((t|0)==(-1|0)&(s|0)==(-1|0)){H=+q}else{H=+(t>>>0)+ +(s|0)*4294967296.0}h[f+16>>3]=H;s=+Q(+(+MBb(c[k+68>>2]|0,f,0)))<.5;c[k+76>>2]=s&1;if(!s){D=p;E=r;break}D=(c[(c[k+4>>2]|0)+20>>2]&65536|0)==0?p:826;E=r}}while(0);p=Oe[D&1023](a,c[g>>2]|0)|0;g=YGb(c[E>>2]|0,c[E+4>>2]|0,1,0)|0;c[E>>2]=g;c[E+4>>2]=F;c[a+152>>2]=0;if((m|0)==0&(w|0)==(-2147483648|0)){n=p;i=d;return n|0}c[e>>2]=1;c[e+4>>2]=1e6;E=KDb(m,w,a+56|0,e)|0;e=a+104|0;c[e>>2]=E;c[e+4>>2]=F;e=c[a+100>>2]|0;if((e|0)==0){n=p;i=d;return n|0}if(!((c[a+112>>2]|0)>-1)){n=p;i=d;return n|0}rj(e,a);n=p;i=d;return n|0}function Pi(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;i=i+256|0;if((QGb(b,2275304)|0)==0){j=h|0;TGb(j|0,0,256)|0;k=(e|0)==0;l=k?j:e;j=c[a+8>>2]|0;uAb(l,k?256:f,2259520,(m=i,i=i+16|0,c[m>>2]=c[c[a+4>>2]>>2],c[m+8>>2]=j,m)|0)|0;i=m;if(!k){n=0;i=h;return n|0}yDb(a,32,2244920,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=0;i=h;return n|0}if((QGb(b,2232552)|0)==0){n=Qi(a,d)|0;i=h;return n|0}m=c[(c[a+4>>2]|0)+48>>2]|0;if((m|0)==0){n=-38;i=h;return n|0}n=oe[m&63](a,b,d,e,f,g)|0;i=h;return n|0}function Qi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=a+68|0;f=c[e>>2]|0;g=c[a+4>>2]|0;if((c[g+20>>2]&196608|0)==0){yDb(a,16,2014064,(h=i,i=i+8|0,c[h>>2]=c[g>>2],h)|0);i=h;j=-1163346256;i=d;return j|0}g=eEb(b)|0;if((g|0)==0){j=-12;i=d;return j|0}b=a+72|0;do{if((c[b>>2]|0)==0){k=dEb(3,8)|0;c[b>>2]=k;if((k|0)!=0){break}ZDb(g);j=-12;i=d;return j|0}}while(0);b=a+44|0;k=JBb(e,g,160768,0,0,0,0,0,c[b>>2]|0)|0;if((k|0)<0){yDb(c[b>>2]|0,16,2010304,(h=i,i=i+8|0,c[h>>2]=g,h)|0);i=h;ZDb(g);j=k;i=d;return j|0}else{IBb(f);f=a+64|0;ZDb(c[f>>2]|0);c[f>>2]=g;j=0;i=d;return j|0}return 0}function Ri(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){b=0;return b|0}else{d=0}while(1){e=c[((d|0)==0?5221496:d+44|0)>>2]|0;if((e|0)==0){b=0;f=4;break}if((QGb(c[e>>2]|0,a)|0)==0){b=e;f=4;break}else{d=e}}if((f|0)==4){return b|0}return 0}function Si(a){a=a|0;return c[((a|0)==0?5221496:a+44|0)>>2]|0}function Ti(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[214510]|0;if((c[a+20>>2]&196608|0)==196608){yDb(0,0,2355200,(e=i,i=i+24|0,c[e>>2]=2220016,c[e+8>>2]=2310088,c[e+16>>2]=484,e)|0);i=e;Cd();return 0}f=c[a+8>>2]|0;a:do{if((f|0)!=0){g=0;while(1){if((c[f+(g*60|0)>>2]|0)==0){break a}if((c[f+(g*60|0)+36>>2]|0)!=0){if((c[f+(g*60|0)+16>>2]|0)!=0){h=8;break}if((c[f+(g*60|0)+28>>2]|0)!=0){h=8;break}}g=g+1|0}if((h|0)==8){yDb(0,0,2355200,(e=i,i=i+24|0,c[e>>2]=2210720,c[e+8>>2]=2310088,c[e+16>>2]=489,e)|0);i=e;Cd();return 0}}}while(0);e=a+44|0;c[e>>2]=0;h=a;a=d;while(1){d=c[a>>2]|0;if((d|0)==0){f=a;if(((D=c[f>>2]|0,(c[f>>2]|0)==0?(c[f>>2]=h)|0:0,D)|0)==0){break}j=c[a>>2]|0}else{j=d}a=j+44|0}c[214510]=e;i=b;return 0}function Ui(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;do{if((a|0)==0){b=0}else{if((c[a>>2]|0)==0){b=0;break}else{d=a;e=0}while(1){f=d+60|0;g=e+1|0;if((c[f>>2]|0)==0){b=g;break}else{d=f;e=g}}}}while(0);return b|0}function Vi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a|0)==0){d=0;return d|0}e=cEb(80)|0;f=e;if((e|0)==0){d=0;return d|0}c[e>>2]=1755728;c[e+4>>2]=a;if((b|0)==0){g=0}else{g=eEb(b)|0}c[e+8>>2]=g;g=c[a+40>>2]|0;do{if((g|0)==0){h=8}else{b=cEb(g)|0;c[e+44>>2]=b;if((b|0)!=0){h=8;break}i=e+56|0}}while(0);a:do{if((h|0)==8){DEb(e);g=c[a+16>>2]|0;if((g|0)!=0){b=e+44|0;c[c[b>>2]>>2]=g;DEb(c[b>>2]|0)}b=cEb(4)|0;g=e+56|0;c[g>>2]=b;if((b|0)==0){i=g;break}c[b>>2]=190;b=a+8|0;j=c[b>>2]|0;do{if((j|0)==0){h=14}else{if((c[j>>2]|0)==0){h=14;break}else{k=j;l=0}do{k=k+60|0;l=l+1|0;}while((c[k>>2]|0)!=0);m=e+24|0;c[m>>2]=l;if((l|0)==0){n=m;break}o=WDb(l*60|0)|0;c[e+12>>2]=o;if((o|0)==0){i=g;break a}p=c[m>>2]|0;UGb(o|0,c[b>>2]|0,p*60|0)|0;o=cEb(p<<2)|0;c[e+16>>2]=o;if((o|0)==0){i=g;break a}else{n=m}}}while(0);if((h|0)==14){b=e+24|0;c[b>>2]=0;n=b}b=a+12|0;j=c[b>>2]|0;do{if((j|0)==0){h=21}else{if((c[j>>2]|0)==0){h=21;break}else{q=j;r=0}do{q=q+60|0;r=r+1|0;}while((c[q>>2]|0)!=0);m=e+40|0;c[m>>2]=r;if((r|0)==0){s=0;break}o=WDb(r*60|0)|0;c[e+28>>2]=o;if((o|0)==0){i=g;break a}p=c[m>>2]|0;UGb(o|0,c[b>>2]|0,p*60|0)|0;o=cEb(p<<2)|0;c[e+32>>2]=o;if((o|0)==0){i=g;break a}s=c[m>>2]|0}}while(0);if((h|0)==21){c[e+40>>2]=0;s=0}c[e+36>>2]=s;c[e+20>>2]=c[n>>2];d=f;return d|0}}while(0);$Db(e+16|0);$Db(e+12|0);c[e+24>>2]=0;$Db(e+32|0);$Db(e+28|0);c[e+40>>2]=0;$Db(e+44|0);$Db(i);ZDb(e);d=0;return d|0}function Wi(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((f|0)<=0){return 0}if((e|0)==0){g=0;do{_e[b&1023](a,d,g,f)|0;g=g+1|0;}while((g|0)<(f|0));return 0}else{g=0;do{c[e+(g<<2)>>2]=_e[b&1023](a,d,g,f)|0;g=g+1|0;}while((g|0)<(f|0));return 0}return 0}function Xi(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){return}b=c[a+48>>2]|0;if((b|0)!=0){jj(b,a)}b=a+4|0;d=c[(c[b>>2]|0)+32>>2]|0;if((d|0)!=0){me[d&511](a)}d=a+24|0;if((c[d>>2]|0)!=0){e=a+16|0;f=0;do{Yi(c[(c[e>>2]|0)+(f<<2)>>2]|0);f=f+1|0;}while(f>>>0<(c[d>>2]|0)>>>0)}d=a+40|0;if((c[d>>2]|0)!=0){f=a+32|0;e=0;do{Yi(c[(c[f>>2]|0)+(e<<2)>>2]|0);e=e+1|0;}while(e>>>0<(c[d>>2]|0)>>>0)}d=a+44|0;if((c[(c[b>>2]|0)+16>>2]|0)!=0){HEb(c[d>>2]|0)}$Db(a+8|0);$Db(a+12|0);$Db(a+28|0);$Db(a+16|0);$Db(a+32|0);$Db(d);d=a+60|0;b=c[d>>2]|0;if((b|0)!=0){e=b;do{$Db(e+12|0);$Db(e+8|0);c[d>>2]=c[e+20>>2];ZDb(e);e=c[d>>2]|0;}while((e|0)!=0)}e=a;HEb(e);d=a+68|0;IBb(c[d>>2]|0);c[d>>2]=0;$Db(a+72|0);$Db(a+56|0);ZDb(e);return}function Yi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;if((a|0)==0){i=b;return}e=c[a>>2]|0;if((e|0)==0){f=a}else{c[(c[e+32>>2]|0)+((((c[a+4>>2]|0)-(c[e+28>>2]|0)|0)/60|0)<<2)>>2]=0;f=c[d>>2]|0}e=c[f+8>>2]|0;if((e|0)==0){g=f}else{c[(c[e+16>>2]|0)+((((c[f+12>>2]|0)-(c[e+12>>2]|0)|0)/60|0)<<2)>>2]=0;g=c[d>>2]|0}Ik(g+64|0);Ik(g+68|0);Ik(g+72|0);Ik(g+76|0);Jk(g+80|0);Jk(g+84|0);if((g|0)==0){i=b;return}JCb(g+124|0);$Db(d);i=b;return}function Zi(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+16|0;f=e|0;g=e+8|0;c[f>>2]=0;a:do{if((d|0)==0){h=36}else{if((a[d]|0)==0){h=36;break}j=b+4|0;k=c[j>>2]|0;if((c[k+16>>2]|0)==0){yDb(b,16,2177208,(l=i,i=i+8|0,c[l>>2]=d,l)|0);i=l;m=-22;i=e;return m|0}n=c[k>>2]|0;do{if((QGb(n,2166312)|0)!=0){if((QGb(n,2159728)|0)==0){break}if((QGb(n,2152760)|0)==0){break}if((QGb(n,2145808)|0)==0){break}if((QGb(n,2139800)|0)==0){break}if((QGb(n,2133448)|0)==0){break}if((QGb(n,2127064)|0)==0){break}if((QGb(n,2121152)|0)==0){break}k=$i(b,f,d)|0;if((k|0)<0){o=k;break a}else{h=36;break a}}}while(0);n=eEb(d)|0;c[g>>2]=n;if((n|0)==0){o=-12;break}k=c[c[j>>2]>>2]|0;do{if((QGb(k,2152760)|0)==0){p=n;q=1}else{if((QGb(k,2139800)|0)==0){p=n;q=1;break}r=(QGb(k,2145808)|0)==0;p=n;q=r?3:0}}while(0);while(1){if((q|0)==0){s=p;break}j=Vb(p|0,58)|0;if((j|0)==0){h=19;break}else{p=j+1|0;q=q-1|0}}if((h|0)==19){s=n+(SGb(n|0)|0)|0}j=Vb(s|0,58)|0;r=(j|0)!=0|0;t=(j|0)==0;b:do{if((QGb(k,2121152)|0)==0){if(t){h=32;break}else{u=0;v=j}while(1){w=v+1|0;if((a[w]|0)==58){x=v;break}y=Vb(w|0,61)|0;z=Vb(w|0,58)|0;if((y|0)!=0){if((z|0)==0|y>>>0<z>>>0){h=27;break}}a[v]=124;z=Vb(w|0,58)|0;if((z|0)==0){h=33;break b}else{u=1;v=z}}if((h|0)==27){if((w|0)==0){A=u;h=31;break}else{x=w}}if((a[x]|0)!=58){A=u;h=31;break}VGb(x|0,x+1|0,SGb(x|0)|0)|0;h=33}else{if(t){A=r;h=31;break}else{B=j}while(1){a[B]=124;z=Vb(B+1|0,58)|0;if((z|0)==0){A=r;h=31;break}else{B=z}}}}while(0);if((h|0)==31){if((A|0)==0){h=32}else{h=33}}if((h|0)==32){C=b}else if((h|0)==33){r=b;yDb(r,24,2115632,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;C=r}r=c[g>>2]|0;yDb(C,48,2101120,(l=i,i=i+8|0,c[l>>2]=r,l)|0);i=l;j=$i(b,f,r)|0;$Db(g);if((j|0)<0){o=j}else{h=36}}}while(0);do{if((h|0)==36){g=_i(b,f)|0;if((g|0)<0){o=g;break}C=BBb(c[f>>2]|0,9203312,0,2)|0;if((C|0)==0){o=g;break}yDb(b,16,2088960,(l=i,i=i+8|0,c[l>>2]=c[C>>2],l)|0);i=l;o=-1414549496}}while(0);DBb(f);m=o;i=e;return m|0}function _i(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=a;f=IEb(e,b)|0;if((f|0)<0){yDb(e,16,2201936,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=f;i=d;return h|0}j=a+4|0;k=c[j>>2]|0;l=a+52|0;do{if((c[k+20>>2]&4|0)==0){m=7}else{n=c[a+48>>2]|0;if((c[l>>2]&1&c[n+24>>2]|0)==0){m=7;break}o=c[(c[n+32>>2]|0)+4>>2]|0;if((o|0)==0){m=7;break}c[l>>2]=1;c[c[a+56>>2]>>2]=o;p=c[j>>2]|0}}while(0);if((m|0)==7){c[l>>2]=0;p=k}do{if((c[p+16>>2]|0)==0){q=f;r=p}else{k=IEb(c[a+44>>2]|0,b)|0;if((k|0)>=0){q=k;r=c[j>>2]|0;break}yDb(e,16,2193936,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=k;i=d;return h|0}}while(0);g=c[r+52>>2]|0;if((g|0)!=0){h=Oe[g&1023](a,0)|0;i=d;return h|0}g=c[r+24>>2]|0;if((g|0)!=0){h=re[g&4095](a)|0;i=d;return h|0}g=c[r+28>>2]|0;if((g|0)==0){h=q;i=d;return h|0}h=Oe[g&1023](a,b)|0;i=d;return h|0}function $i(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+88|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;c[g>>2]=e;if((e|0)==0){l=0;i=f;return l|0}a:do{if((a[e]|0)==0){m=0}else{n=b+44|0;o=b;p=0;q=0;r=-1;s=e;b:while(1){t=p;while(1){u=pEb(c[n>>2]|0,t)|0;if((u|0)==0){v=0;w=r;x=0;break}if((c[u+12>>2]|0)!=128){y=c[u+8>>2]|0;if((y|0)!=(r|0)){z=9;break}}if((a[s]|0)==0){m=q;break a}else{t=u}}if((z|0)==9){z=0;v=c[u>>2]|0;w=y;x=u}A=GEb(g,2064632,2060672,(v|0)!=0|0,h,j)|0;if((A|0)<0){z=11;break}t=c[g>>2]|0;if((a[t]|0)!=0){c[g>>2]=t+1}t=c[h>>2]|0;if((t|0)==0){B=v;C=x}else{D=x;while(1){E=pEb(c[n>>2]|0,D)|0;if((E|0)==0){B=t;C=0;break}else{D=E}}}D=c[j>>2]|0;yDb(o,48,2040296,(F=i,i=i+16|0,c[F>>2]=B,c[F+8>>2]=D,F)|0);i=F;D=(qEb(o,B,0,0,0)|0)==0;t=c[j>>2]|0;do{if(D){CBb(d,B,t,0)|0;G=rEb(c[n>>2]|0,B,c[j>>2]|0,0)|0;if((G|0)>=0){break}if((qEb(c[n>>2]|0,B,0,0,3)|0)==0){z=23;break b}}else{H=rEb(o,B,t,0)|0;if((H|0)<0){z=20;break b}}}while(0);ZDb(c[j>>2]|0);ZDb(c[h>>2]|0);t=q+1|0;D=c[g>>2]|0;if((a[D]|0)==0){m=t;break a}else{p=C;q=t;r=w;s=D}}if((z|0)==11){s=c[g>>2]|0;if((A|0)==-22){yDb(o,16,2056384,(F=i,i=i+8|0,c[F>>2]=s,F)|0);i=F;l=-22;i=f;return l|0}else{r=k|0;TGb(r|0,0,64)|0;a[r]=0;GBb(A,r,64)|0;yDb(o,16,2045272,(F=i,i=i+16|0,c[F>>2]=s,c[F+8>>2]=r,F)|0);i=F;l=A;i=f;return l|0}}else if((z|0)==20){ZDb(c[j>>2]|0);ZDb(c[h>>2]|0);l=H;i=f;return l|0}else if((z|0)==23){if((G|0)==-1414549496){yDb(o,16,2036840,(F=i,i=i+8|0,c[F>>2]=B,F)|0);i=F}ZDb(c[j>>2]|0);ZDb(c[h>>2]|0);l=G;i=f;return l|0}}}while(0);G=c[b+64>>2]|0;do{if((G|0)!=0){h=Qi(b,G)|0;if((h|0)<0){l=h}else{break}i=f;return l|0}}while(0);l=m;i=f;return l|0}function aj(a,b){a=a|0;b=b|0;return c[a+(b*60|0)>>2]|0}function bj(a,b){a=a|0;b=b|0;return c[a+(b*60|0)+4>>2]|0}function cj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0;d=i;i=i+144|0;e=d|0;f=d+8|0;g=a+16|0;do{if((c[g>>2]|0)!=0){h=a+40|0;iBb(d+16|0,128,-1,c[h>>2]|0,c[h+4>>2]|0);if((c[g>>2]|0)!=1){break}h=a+132|0;j=c[h>>2]|0;if((j|0)==0){break}k=a+124|0;l=c[k>>2]|0;m=c[b+76>>2]|0;if(!((l|0)!=0|(m|0)<(j|0))){if((m|0)<=(c[a+136>>2]|0)){break}}c[e>>2]=b;j=vCb(b)|0;n=a+156|0;c[n>>2]=c[n>>2]|1;n=f|0;o=f+4|0;p=a+48|0;q=a+128|0;r=a+56|0;s=a+52|0;t=0;u=l;l=m;m=0;a:while(1){v=u;w=l;x=m;while(1){if((w|0)==0){y=18;break a}if((v|0)==0){c[n>>2]=1;c[o>>2]=c[p>>2];z=fi(a,c[q>>2]|0)|0;if((z|0)==0){y=12;break a}NCb(z,c[e>>2]|0)|0;A=(c[e>>2]|0)+136|0;B=c[A>>2]|0;C=c[A+4>>2]|0;A=z+136|0;c[A>>2]=B;c[A+4>>2]=C;if(!((B|0)==0&(C|0)==(-2147483648|0))){C=KDb(x,(x|0)<0|0?-1:0,f,r)|0;B=YGb(c[A>>2]|0,c[A+4>>2]|0,C,F)|0;c[A>>2]=B;c[A+4>>2]=F}c[z+76>>2]=0;D=z;E=0}else{D=v;E=c[v+76>>2]|0}z=D+76|0;A=(c[q>>2]|0)-E|0;B=(w|0)>(A|0)?A:w;IFb(c[D+64>>2]|0,c[(c[e>>2]|0)+64>>2]|0,E,x,B,j,c[s>>2]|0)|0;G=B+x|0;H=w-B|0;A=(c[z>>2]|0)+B|0;c[z>>2]=A;if((A|0)<(c[h>>2]|0)){v=D;w=H;x=G}else{break}}t=Oi(a,D)|0;u=0;l=H;m=G}if((y|0)==12){yDb(c[a+8>>2]|0,24,2078672,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;I=0;i=d;return I|0}else if((y|0)==18){JCb(e);c[k>>2]=v;I=t;i=d;return I|0}}}while(0);I=Oi(a,b)|0;i=d;return I|0}function dj(){return 1755728}function ej(a,b){a=a|0;b=b|0;return cj(c[c[(c[a+8>>2]|0)+32>>2]>>2]|0,b)|0}function fj(a){a=a|0;var b=0,d=0;b=c[a+8>>2]|0;if((b|0)!=0){d=b;return d|0}d=c[c[a+4>>2]>>2]|0;return d|0}function gj(a,b){a=a|0;b=b|0;var d=0,e=0;do{if((b|0)==0){d=c[a+4>>2]|0;if((d|0)==0){break}if((c[d+16>>2]|0)==0){break}d=c[a+44>>2]|0;if((d|0)==0){break}else{e=d}return e|0}}while(0);e=0;return e|0}function hj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;a:do{if((a|0)==0){b=0}else{d=0;while(1){e=c[((d|0)==0?5221496:d+44|0)>>2]|0;if((e|0)==0){f=0;break}if((c[e+16>>2]|0)==(a|0)){b=e;break a}else{d=e}}return f|0}}while(0);while(1){a=c[((b|0)==0?5221496:b+44|0)>>2]|0;if((a|0)==0){f=0;g=6;break}d=c[a+16>>2]|0;if((d|0)==0){b=a}else{f=d;g=6;break}}if((g|0)==6){return f|0}return 0}function ij(){var a=0,b=0,d=0,e=0,f=0;a=i;i=i+8|0;b=a|0;d=cEb(60)|0;c[b>>2]=d;if((d|0)==0){e=0;i=a;return e|0}f=cEb(8)|0;c[d+32>>2]=f;if((f|0)==0){$Db(b);e=0;i=a;return e|0}else{c[d>>2]=1059072;DEb(d);e=c[b>>2]|0;i=a;return e|0}return 0}function jj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+20|0;e=c[d>>2]|0;f=a+8|0;a=0;while(1){if(!(a>>>0<e>>>0)){g=5;break}h=c[f>>2]|0;if((c[h+(a<<2)>>2]|0)==(b|0)){break}else{a=a+1|0}}if((g|0)==5){return}g=e-1|0;e=h+(g<<2)|0;h=c[e>>2]|0;c[e>>2]=b;c[(c[f>>2]|0)+(a<<2)>>2]=h;c[d>>2]=g;return}function kj(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;if((b|0)==0){return}if((c[b+20>>2]|0)==0){d=b}else{e=b;while(1){Xi(c[c[e+8>>2]>>2]|0);b=c[a>>2]|0;if((c[b+20>>2]|0)==0){d=b;break}else{e=b}}}$Db(d+48|0);$Db((c[a>>2]|0)+12|0);$Db((c[a>>2]|0)+44|0);$Db((c[a>>2]|0)+16|0);$Db((c[a>>2]|0)+8|0);$Db((c[a>>2]|0)+32|0);$Db(a);return}function lj(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;f=g+24|0;do{if((c[f>>2]|0)!=0){h=(c[g+32>>2]|0)+4|0;if((c[h>>2]|0)!=0){break}i=c[g+40>>2]|0;if((i|0)==0){c[f>>2]=0;c[g+28>>2]=1;break}else{c[h>>2]=i;break}}}while(0);f=Vi(b,d)|0;do{if((f|0)!=0){d=g+8|0;b=g+20|0;i=XDb(c[d>>2]|0,(c[b>>2]<<2)+4|0)|0;if((i|0)==0){Xi(f);break}h=i;c[d>>2]=h;d=c[b>>2]|0;i=d+1|0;c[b>>2]=i;c[h+(d<<2)>>2]=f;c[g+4>>2]=i;c[f+48>>2]=g;c[a>>2]=f;i=Zi(f,e)|0;if((i|0)>=0){j=0;return j|0}d=c[a>>2]|0;if((d|0)!=0){Xi(d)}c[a>>2]=0;j=i;return j|0}}while(0);c[a>>2]=0;j=-12;return j|0}function mj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+24|0;do{if((c[e>>2]|0)!=0){f=(c[a+32>>2]|0)+4|0;if((c[f>>2]|0)!=0){break}g=c[a+40>>2]|0;if((g|0)==0){c[e>>2]=0;c[a+28>>2]=1;break}else{c[f>>2]=g;break}}}while(0);e=Vi(b,d)|0;if((e|0)==0){h=0;return h|0}d=a+8|0;b=a+20|0;g=XDb(c[d>>2]|0,(c[b>>2]<<2)+4|0)|0;if((g|0)==0){Xi(e);h=0;return h|0}else{f=g;c[d>>2]=f;d=c[b>>2]|0;g=d+1|0;c[b>>2]=g;c[f+(d<<2)>>2]=e;c[a+4>>2]=g;c[e+48>>2]=a;h=e;return h|0}return 0}function nj(a,b){a=a|0;b=b|0;c[a+56>>2]=b;return}function oj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0;e=i;i=i+1360|0;f=e|0;g=e+8|0;h=e+264|0;j=e+296|0;k=e+1320|0;l=e+1328|0;m=b+20|0;n=c[m>>2]|0;o=(n|0)==0;a:do{if(o){p=k;q=l|0;r=16}else{s=c[b+8>>2]|0;t=0;b:while(1){u=c[s+(t<<2)>>2]|0;v=c[u+24>>2]|0;w=u+16|0;x=0;while(1){if(!(x>>>0<v>>>0)){break}y=c[(c[w>>2]|0)+(x<<2)>>2]|0;if((y|0)==0){r=8;break b}if((c[y>>2]|0)==0){r=8;break b}else{x=x+1|0}}w=c[u+40>>2]|0;v=u+32|0;z=0;while(1){if(!(z>>>0<w>>>0)){break}y=c[(c[v>>2]|0)+(z<<2)>>2]|0;if((y|0)==0){r=13;break b}if((c[y+8>>2]|0)==0){r=13;break b}else{z=z+1|0}}v=t+1|0;if(v>>>0<n>>>0){t=v}else{r=15;break}}if((r|0)==8){t=c[u+12>>2]|0;s=c[t+(x*60|0)>>2]|0;v=lGb(c[t+(x*60|0)+4>>2]|0)|0;t=c[u+8>>2]|0;w=c[c[u+4>>2]>>2]|0;yDb(d,16,2100896,(A=i,i=i+32|0,c[A>>2]=s,c[A+8>>2]=v,c[A+16>>2]=t,c[A+24>>2]=w,A)|0);i=A;B=-22;i=e;return B|0}else if((r|0)==13){w=c[u+28>>2]|0;t=c[w+(z*60|0)>>2]|0;v=lGb(c[w+(z*60|0)+4>>2]|0)|0;w=c[u+8>>2]|0;s=c[c[u+4>>2]>>2]|0;yDb(d,16,2094128,(A=i,i=i+32|0,c[A>>2]=t,c[A+8>>2]=v,c[A+16>>2]=w,c[A+24>>2]=s,A)|0);i=A;B=-22;i=e;return B|0}else if((r|0)==15){s=k;w=l|0;if(o){p=s;q=w;r=16;break}v=b+8|0;t=0;y=0;C=n;c:while(1){D=c[(c[v>>2]|0)+(y<<2)>>2]|0;E=D+24|0;F=c[E>>2]|0;if((F|0)==0){G=t;H=C}else{I=D+16|0;D=0;J=t;K=F;while(1){F=c[(c[I>>2]|0)+(D<<2)>>2]|0;if((c[(c[F+12>>2]|0)+52>>2]|0)==0){L=J;M=K}else{if((c[F+16>>2]|0)==0){N=Ri(2127040)|0}else{N=Ri(2121136)|0}Lb(w|0,32,2115424,(A=i,i=i+8|0,c[A>>2]=J,A)|0)|0;i=A;O=lj(k,N,w,0,0,b)|0;if((O|0)<0){B=O;r=330;break c}O=Ki(F,c[k>>2]|0,0,0)|0;if((O|0)<0){B=O;r=330;break c}L=J+1|0;M=c[E>>2]|0}O=D+1|0;if(O>>>0<M>>>0){D=O;J=L;K=M}else{break}}G=L;H=c[m>>2]|0}K=y+1|0;if(K>>>0<H>>>0){t=G;y=K;C=H}else{P=H;Q=v;R=s;S=w;break a}}if((r|0)==330){i=e;return B|0}}}}while(0);if((r|0)==16){P=0;Q=b+8|0;R=p;S=q}q=g|0;g=h|0;h=b;S=b+12|0;p=b+44|0;R=j|0;H=j+4|0;G=P;while(1){d:do{if((G|0)==0){T=0;r=109}else{P=0;L=0;M=G;while(1){k=c[(c[Q>>2]|0)+(L<<2)>>2]|0;N=c[k+24>>2]|0;e:do{if((N|0)==0){r=35}else{n=c[k+16>>2]|0;o=0;while(1){l=c[n+(o<<2)>>2]|0;if((c[l+68>>2]|0)==0){r=47;break e}if((c[l+16>>2]|0)==1){if((c[l+76>>2]|0)==0){r=47;break e}if((c[l+84>>2]|0)==0){r=47;break e}}l=o+1|0;if(l>>>0<N>>>0){o=l}else{r=35;break}}}}while(0);f:do{if((r|0)==35){r=0;N=c[k+40>>2]|0;if((N|0)==0){U=P;V=M;break}o=c[k+32>>2]|0;n=0;while(1){l=c[o+(n<<2)>>2]|0;if((c[l+64>>2]|0)==0){r=47;break f}if((c[l+16>>2]|0)==1){if((c[l+72>>2]|0)==0){r=47;break f}if((c[l+80>>2]|0)==0){r=47;break f}}l=n+1|0;if(l>>>0<N>>>0){n=l}else{U=P;V=M;break}}}}while(0);if((r|0)==47){r=0;if((c[(c[k+4>>2]|0)+36>>2]|0)==0){W=Pk(k)|0}else{W=uj(k)|0}if((W|0)<0&(W|0)!=-11){X=W;break d}U=(W>>>31^1)+P|0;V=c[m>>2]|0}n=L+1|0;if(n>>>0<V>>>0){P=U;L=n;M=V}else{break}}if((V|0)==0){T=U;r=109;break}else{Y=0;Z=0;_=0;$=0;aa=0;ba=0;ca=V}g:while(1){M=c[(c[Q>>2]|0)+(ba<<2)>>2]|0;L=M+24|0;if((c[L>>2]|0)==0){da=Y;ea=Z;fa=_;ga=$;ha=aa;ia=ca}else{P=M+16|0;M=Y;n=Z;N=_;o=$;l=aa;u=0;while(1){ja=c[(c[P>>2]|0)+(u<<2)>>2]|0;do{if((ja|0)==0){ka=l;la=o;ma=N;na=n;oa=M}else{z=ja+64|0;x=c[z>>2]|0;w=ja+68|0;s=c[w>>2]|0;v=ja+16|0;if((x|0)==(s|0)|(x|0)==0|(s|0)==0){pa=0}else{pa=(vj(x,s,c[v>>2]|0,0)|0)==0|0}h:do{if((c[v>>2]|0)==1){s=ja+72|0;x=c[s>>2]|0;C=ja+76|0;y=c[C>>2]|0;if((x|0)==(y|0)|(x|0)==0|(y|0)==0){qa=pa}else{t=(vj(x,y,0,1)|0)==0;y=t?1:pa;if((c[v>>2]|0)==1){qa=y}else{ra=y;sa=o;ta=N;ua=n;break}}y=c[ja+80>>2]|0;do{if((y|0)==0){r=63}else{t=c[ja+84>>2]|0;if((t|0)==0){r=63;break}if((y|0)==(t|0)){va=qa;wa=o;xa=N+1|0;ya=n;break}if((qa|0)!=0){va=qa;wa=o;xa=N;ya=n;break}va=(vk(y,t)|0)==0|0;wa=o;xa=N;ya=n+1|0}}while(0);if((r|0)==63){r=0;va=qa;wa=o+1|0;xa=N;ya=n}y=c[s>>2]|0;do{if((y|0)!=0){t=c[C>>2]|0;if((t|0)==0){break}if((y|0)==(t|0)){ra=va;sa=wa;ta=xa+1|0;ua=ya;break h}if((va|0)!=0){ra=va;sa=wa;ta=xa;ua=ya;break h}ra=(uk(y,t)|0)==0|0;sa=wa;ta=xa;ua=ya+1|0;break h}}while(0);ra=va;sa=wa+1|0;ta=xa;ua=ya}else{ra=pa;sa=o;ta=N;ua=n}}while(0);y=c[z>>2]|0;do{if((y|0)==0){r=77}else{C=c[w>>2]|0;if((C|0)==0){r=77;break}if((y|0)==(C|0)){za=ra;Aa=sa;Ba=ta+1|0;Ca=ua;r=82;break}if((ra|0)!=0){Da=ua;Ea=ta;Fa=sa;break}za=(tk(y,C,c[v>>2]|0)|0)==0|0;Aa=sa;Ba=ta;Ca=ua+1|0;r=82}}while(0);if((r|0)==77){r=0;za=ra;Aa=sa+1|0;Ba=ta;Ca=ua;r=82}if((r|0)==82){r=0;if((za|0)==0){ka=l;la=Aa;ma=Ba;na=Ca;oa=M;break}else{Da=Ca;Ea=Ba;Fa=Aa}}y=c[v>>2]|0;if((y|0)==0){w=Ri(2290944)|0;if((w|0)==0){r=85;break g}Lb(g|0,30,2259280,(A=i,i=i+8|0,c[A>>2]=l,A)|0)|0;i=A;z=lj(f,w,g,c[S>>2]|0,0,b)|0;if((z|0)<0){X=z;break d}else{Ga=l+1|0;Ha=M}}else if((y|0)==1){y=Ri(2244704)|0;if((y|0)==0){r=88;break g}Lb(g|0,30,2219816,(A=i,i=i+8|0,c[A>>2]=M,A)|0)|0;i=A;a[q]=0;z=c[p>>2]|0;if((z|0)==0){Ia=0}else{Lb(q|0,256,2210592,(A=i,i=i+8|0,c[A>>2]=z,A)|0)|0;i=A;Ia=c[p>>2]|0}z=lj(f,y,g,Ia,0,b)|0;if((z|0)<0){X=z;break d}else{Ga=l;Ha=M+1|0}}else{X=-22;break d}z=c[f>>2]|0;y=Ki(ja,z,0,0)|0;if((y|0)<0){X=y;break d}uj(z)|0;w=c[c[z+16>>2]>>2]|0;C=c[c[z+32>>2]>>2]|0;z=w+16|0;if((tk(c[w+64>>2]|0,c[w+68>>2]|0,c[z>>2]|0)|0)==0){r=95}else{if((tk(c[C+64>>2]|0,c[C+68>>2]|0,c[C+16>>2]|0)|0)==0){r=95}else{Ja=y}}if((r|0)==95){r=0;Ja=y|-38}do{if((c[z>>2]|0)==1){if((uk(c[w+72>>2]|0,c[w+76>>2]|0)|0)!=0){if((vk(c[w+80>>2]|0,c[w+84>>2]|0)|0)!=0){Ka=Ja;break}}Ka=Ja|-38}else{Ka=Ja}}while(0);if((c[C+16>>2]|0)==1){if((uk(c[C+72>>2]|0,c[C+76>>2]|0)|0)==0){r=103;break g}if((vk(c[C+80>>2]|0,c[C+84>>2]|0)|0)==0){r=103;break g}}if((Ka|0)<0){La=Ka;break g}else{ka=Ga;la=Fa;ma=Ea;na=Da;oa=Ha}}}while(0);w=u+1|0;if(w>>>0<(c[L>>2]|0)>>>0){M=oa;n=na;N=ma;o=la;l=ka;u=w}else{break}}da=oa;ea=na;fa=ma;ga=la;ha=ka;ia=c[m>>2]|0}u=ba+1|0;if(u>>>0<ia>>>0){Y=da;Z=ea;_=fa;$=ga;aa=ha;ba=u;ca=ia}else{r=110;break}}if((r|0)==85){r=0;yDb(d,16,2274984,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;X=-22;break}else if((r|0)==88){r=0;yDb(d,16,2232320,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;X=-22;break}else if((r|0)==103){r=0;La=Ka|-38}else if((r|0)==110){r=0;yDb(h,48,2193656,(A=i,i=i+32|0,c[A>>2]=U,c[A+8>>2]=ea,c[A+16>>2]=fa,c[A+24>>2]=ga,A)|0);i=A;if((ga|0)==0){X=0;break}if((ea|U|0)!=0){X=-11;break}IAb(j,0,1);u=c[m>>2]|0;if((u|0)!=0){l=0;o=u;while(1){u=c[(c[Q>>2]|0)+(l<<2)>>2]|0;N=c[u+24>>2]|0;i:do{if((N|0)==0){r=115}else{n=c[u+16>>2]|0;M=0;while(1){L=c[n+(M<<2)>>2]|0;if((c[L+68>>2]|0)==0){r=127;break i}if((c[L+16>>2]|0)==1){if((c[L+76>>2]|0)==0){r=127;break i}if((c[L+84>>2]|0)==0){r=127;break i}}L=M+1|0;if(L>>>0<N>>>0){M=L}else{r=115;break}}}}while(0);j:do{if((r|0)==115){r=0;N=c[u+40>>2]|0;if((N|0)==0){Ma=o;break}M=c[u+32>>2]|0;n=0;while(1){L=c[M+(n<<2)>>2]|0;if((c[L+64>>2]|0)==0){r=127;break j}if((c[L+16>>2]|0)==1){if((c[L+72>>2]|0)==0){r=127;break j}if((c[L+80>>2]|0)==0){r=127;break j}}L=n+1|0;if(L>>>0<N>>>0){n=L}else{Ma=o;break}}}}while(0);if((r|0)==127){r=0;n=c[u+8>>2]|0;KAb(j,2177048,(A=i,i=i+16|0,c[A>>2]=(c[H>>2]|0)!=0?2166280:9203384,c[A+8>>2]=n,A)|0);i=A;Ma=c[m>>2]|0}n=l+1|0;if(n>>>0<Ma>>>0){l=n;o=Ma}else{break}}}yDb(h,16,2152576,(A=i,i=i+8|0,c[A>>2]=c[R>>2],A)|0);i=A;X=-5;break}o=c[(c[ja+8>>2]|0)+8>>2]|0;yDb(d,16,2201768,(A=i,i=i+16|0,c[A>>2]=c[(c[ja>>2]|0)+8>>2],c[A+8>>2]=o,A)|0);i=A;X=La}}while(0);if((r|0)==109){r=0;yDb(h,48,2193656,(A=i,i=i+32|0,c[A>>2]=T,c[A+8>>2]=0,c[A+16>>2]=0,c[A+24>>2]=0,A)|0);i=A;X=0}if(!((X|0)==-11)){break}yDb(h,48,1942880,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;G=c[m>>2]|0}if((X|0)<0){B=X;i=e;return B|0}else{Na=0;Oa=0}while(1){Pa=c[m>>2]|0;if(!(Oa>>>0<Pa>>>0)){if((Na|0)==0){break}else{Na=0;Oa=0;continue}}X=c[(c[Q>>2]|0)+(Oa<<2)>>2]|0;G=X+24|0;do{if((c[G>>2]|0)==0){Qa=0}else{h=X+16|0;T=X+40|0;La=X+32|0;ja=0;d=0;while(1){R=c[(c[h>>2]|0)+(d<<2)>>2]|0;Ma=c[R+68>>2]|0;k:do{if((Ma|0)==0){Ra=ja}else{if((c[Ma>>2]|0)!=1){Ra=ja;break}H=c[c[Ma+4>>2]>>2]|0;j=c[T>>2]|0;if((j|0)==0){Ra=ja;break}U=c[La>>2]|0;ea=c[R+16>>2]|0;ga=ja;fa=0;Ka=j;l:while(1){j=c[U+(fa<<2)>>2]|0;m:do{if((ea|0)==(c[j+16>>2]|0)){Sa=j+64|0;ia=c[Sa>>2]|0;ca=ia|0;ba=c[ca>>2]|0;if((ba|0)==0){break l}else if((ba|0)==1){Ta=ga;Ua=Ka;break}ha=ia+4|0;ia=0;while(1){if(!(ia>>>0<ba>>>0)){Ta=ga;Ua=Ka;break m}Va=c[ha>>2]|0;if((c[Va+(ia<<2)>>2]|0)==(H|0)){break}else{ia=ia+1|0}}c[Va>>2]=H;c[ca>>2]=1;Ta=1;Ua=c[T>>2]|0}else{Ta=ga;Ua=Ka}}while(0);j=fa+1|0;if(j>>>0<Ua>>>0){ga=Ta;fa=j;Ka=Ua}else{Ra=Ta;break k}}zk(Sa,H,(H|0)<0|0?-1:0)|0;Ra=1}}while(0);R=d+1|0;Wa=c[G>>2]|0;if(R>>>0<Wa>>>0){ja=Ra;d=R}else{break}}if((Wa|0)==0){Qa=Ra;break}else{Xa=Ra;Ya=0}while(1){d=c[(c[h>>2]|0)+(Ya<<2)>>2]|0;ja=c[d+76>>2]|0;n:do{if((ja|0)==0){Za=Xa}else{if((c[ja>>2]|0)!=1){Za=Xa;break}R=c[c[ja+4>>2]>>2]|0;Ma=c[T>>2]|0;if((Ma|0)==0){Za=Xa;break}u=c[La>>2]|0;Ka=c[d+16>>2]|0;fa=Xa;ga=0;ea=Ma;o:while(1){Ma=c[u+(ga<<2)>>2]|0;p:do{if((Ka|0)==(c[Ma+16>>2]|0)){_a=Ma+72|0;U=c[_a>>2]|0;j=U|0;C=c[j>>2]|0;if((C|0)==0){break o}else if((C|0)==1){$a=fa;ab=ea;break}ia=U+4|0;U=0;while(1){if(!(U>>>0<C>>>0)){$a=fa;ab=ea;break p}bb=c[ia>>2]|0;if((c[bb+(U<<2)>>2]|0)==(R|0)){break}else{U=U+1|0}}c[bb>>2]=R;c[j>>2]=1;$a=1;ab=c[T>>2]|0}else{$a=fa;ab=ea}}while(0);Ma=ga+1|0;if(Ma>>>0<ab>>>0){fa=$a;ga=Ma;ea=ab}else{Za=$a;break n}}zk(_a,R,(R|0)<0|0?-1:0)|0;Za=1}}while(0);d=Ya+1|0;cb=c[G>>2]|0;if(d>>>0<cb>>>0){Xa=Za;Ya=d}else{break}}if((cb|0)==0){Qa=Za;break}else{db=Za;eb=0}while(1){d=c[(c[h>>2]|0)+(eb<<2)>>2]|0;ja=c[d+84>>2]|0;q:do{if((ja|0)==0){fb=db}else{if((c[ja+4>>2]|0)!=1){fb=db;break}ea=c[ja>>2]|0;ga=c[ea>>2]|0;fa=c[ea+4>>2]|0;ea=c[T>>2]|0;if((ea|0)==0){fb=db;break}Ka=-1;u=c[La>>2]|0;H=c[d+16>>2]|0;r:do{if((fa|0)>(Ka|0)|(fa|0)==(Ka|0)&ga>>>0>-1>>>0|(ga&2147483647|0)==0&(fa&0|0)==0){Ma=db;U=0;ia=ea;while(1){C=c[u+(U<<2)>>2]|0;ca=C+80|0;ha=c[ca>>2]|0;s:do{if((H|0)==(c[C+16>>2]|0)){ba=ha+4|0;aa=c[ba>>2]|0;if((aa|0)==1){gb=Ma;hb=ia;break}$=ha+8|0;if((a[$]|0)!=0){ib=Ma;jb=ca;kb=ha;lb=$;break r}$=ha|0;_=0;while(1){if((_|0)>=(aa|0)){gb=Ma;hb=ia;break s}mb=c[$>>2]|0;Z=mb+(_<<3)|0;if((c[Z>>2]|0)==(ga|0)&(c[Z+4>>2]|0)==(fa|0)){break}else{_=_+1|0}}c[mb>>2]=ga;c[mb+4>>2]=fa;c[ba>>2]=1;gb=1;hb=c[T>>2]|0}else{gb=Ma;hb=ia}}while(0);ha=U+1|0;if(ha>>>0<hb>>>0){Ma=gb;U=ha;ia=hb}else{fb=gb;break q}}}else{ia=db;U=0;Ma=ea;while(1){ha=c[u+(U<<2)>>2]|0;ca=ha+80|0;C=c[ca>>2]|0;t:do{if((H|0)==(c[ha+16>>2]|0)){j=C+4|0;_=c[j>>2]|0;if((_|0)==1){nb=ia;ob=Ma;break}$=C+8|0;if((a[$]|0)!=0){if((a[C+9|0]|0)!=0){ib=ia;jb=ca;kb=C;lb=$;break r}}$=C|0;aa=0;while(1){if((aa|0)>=(_|0)){nb=ia;ob=Ma;break t}pb=c[$>>2]|0;Z=pb+(aa<<3)|0;if((c[Z>>2]|0)==(ga|0)&(c[Z+4>>2]|0)==(fa|0)){break}else{aa=aa+1|0}}c[pb>>2]=ga;c[pb+4>>2]=fa;c[j>>2]=1;nb=1;ob=c[T>>2]|0}else{nb=ia;ob=Ma}}while(0);C=U+1|0;if(C>>>0<ob>>>0){ia=nb;U=C;Ma=ob}else{fb=nb;break q}}}}while(0);a[kb+9|0]=0;a[lb]=0;Ak(jb,ga,fa)|0;fb=ib}}while(0);d=eb+1|0;if(d>>>0<(c[G>>2]|0)>>>0){db=fb;eb=d}else{Qa=fb;break}}}}while(0);Na=Qa|Na;Oa=Oa+1|0}u:do{if((Pa|0)==0){qb=0;rb=0;sb=0}else{Oa=0;v:do{Na=c[(c[Q>>2]|0)+(Oa<<2)>>2]|0;Qa=c[Na+24>>2]|0;do{if((Qa|0)!=0){fb=c[Na+16>>2]|0;eb=0;while(1){tb=c[fb+(eb<<2)>>2]|0;if((c[tb+16>>2]|0)==1){if((c[c[tb+68>>2]>>2]|0)==1){ub=eb;break}}db=eb+1|0;if(db>>>0<Qa>>>0){eb=db}else{ub=db;break}}if((ub|0)==(Qa|0)){break}eb=c[c[(c[tb+68>>2]|0)+4>>2]>>2]|0;fb=BFb(eb)|0;db=Na+40|0;ib=c[db>>2]|0;if((ib|0)==0){break}jb=Na+32|0;lb=(fb|0)==4;kb=0;nb=ib;while(1){ib=c[(c[jb>>2]|0)+(kb<<2)>>2]|0;do{if((c[ib+16>>2]|0)==1){ob=ib+64|0;pb=c[ob>>2]|0;if((c[pb>>2]|0)>>>0<2>>>0){vb=nb;break}w:do{if(lb){gb=-1;hb=-2147483648;mb=0;Za=pb;while(1){cb=c[(c[Za+4>>2]|0)+(mb<<2)>>2]|0;Ya=BFb(cb)|0;if((yFb(cb)|0)==(eb|0)){wb=mb;break w}if((zFb(cb)|0)==(eb|0)|(Ya|0)==8){wb=mb;break w}cb=Ya-4|0;Xa=((Ya|0)<4?0:1073741823)-((cb|0)>-1?cb:4-Ya|0)|0;Ya=(Xa|0)>(hb|0);cb=Ya?mb:gb;_a=mb+1|0;$a=c[ob>>2]|0;if(_a>>>0<(c[$a>>2]|0)>>>0){gb=cb;hb=Ya?Xa:hb;mb=_a;Za=$a}else{wb=cb;break}}}else{Za=-1;mb=-2147483648;hb=0;gb=pb;while(1){cb=c[(c[gb+4>>2]|0)+(hb<<2)>>2]|0;$a=BFb(cb)|0;if((yFb(cb)|0)==(eb|0)){wb=hb;break w}if((zFb(cb)|0)==(eb|0)){wb=hb;break w}cb=$a-fb|0;_a=(($a|0)<(fb|0)?0:1073741823)-((cb|0)>-1?cb:-cb|0)|0;cb=(_a|0)>(mb|0);$a=cb?hb:Za;Xa=hb+1|0;Ya=c[ob>>2]|0;if(Xa>>>0<(c[Ya>>2]|0)>>>0){Za=$a;mb=cb?_a:mb;hb=Xa;gb=Ya}else{wb=$a;break}}}}while(0);if(!((wb|0)>-1)){r=208;break v}pb=c[(c[ob>>2]|0)+4>>2]|0;gb=pb+(wb<<2)|0;hb=c[gb>>2]|0;c[gb>>2]=c[pb>>2];c[pb>>2]=hb;vb=c[db>>2]|0}else{vb=nb}}while(0);ib=kb+1|0;if(ib>>>0<vb>>>0){kb=ib;nb=vb}else{break}}}}while(0);Oa=Oa+1|0;xb=c[m>>2]|0;}while(Oa>>>0<xb>>>0);if((r|0)==208){yDb(0,0,2056584,(A=i,i=i+24|0,c[A>>2]=2309752,c[A+8>>2]=1971568,c[A+16>>2]=1010,A)|0);i=A;Cd();return 0}if((xb|0)==0){qb=0;rb=0;sb=0;break}Oa=c[Q>>2]|0;Na=0;Qa=xb;nb=xb;while(1){kb=c[Oa+(Na<<2)>>2]|0;db=c[kb+24>>2]|0;do{if((db|0)==0){yb=Qa;zb=nb}else{fb=c[kb+16>>2]|0;eb=0;while(1){Ab=c[fb+(eb<<2)>>2]|0;if((c[Ab+16>>2]|0)==1){if((c[c[Ab+76>>2]>>2]|0)==1){Bb=eb;break}}lb=eb+1|0;if(lb>>>0<db>>>0){eb=lb}else{Bb=lb;break}}if((Bb|0)==(db|0)){yb=Qa;zb=nb;break}eb=c[c[(c[Ab+76>>2]|0)+4>>2]>>2]|0;fb=kb+40|0;lb=c[fb>>2]|0;if((lb|0)==0){yb=Qa;zb=nb;break}jb=c[kb+32>>2]|0;ib=0;fa=0;ga=lb;while(1){lb=c[jb+(fa<<2)>>2]|0;do{if((c[lb+16>>2]|0)==1){hb=c[lb+72>>2]|0;pb=c[hb>>2]|0;if(pb>>>0<2>>>0){Cb=ib;Db=ga;break}gb=c[hb+4>>2]|0;hb=0;mb=ib;Za=2147483647;while(1){$a=eb-(c[gb+(hb<<2)>>2]|0)|0;Ya=($a|0)>-1?$a:-$a|0;$a=(Ya|0)<(Za|0);Eb=$a?hb:mb;Xa=hb+1|0;if(Xa>>>0<pb>>>0){hb=Xa;mb=Eb;Za=$a?Ya:Za}else{break}}Za=gb+(Eb<<2)|0;mb=c[Za>>2]|0;c[Za>>2]=c[gb>>2];c[gb>>2]=mb;Cb=Eb;Db=c[fb>>2]|0}else{Cb=ib;Db=ga}}while(0);lb=fa+1|0;if(lb>>>0<Db>>>0){ib=Cb;fa=lb;ga=Db}else{break}}ga=c[m>>2]|0;yb=ga;zb=ga}}while(0);kb=Na+1|0;if(kb>>>0<yb>>>0){Na=kb;Qa=yb;nb=zb}else{break}}if((zb|0)==0){qb=0;rb=0;sb=0;break}else{Fb=0;Gb=zb;Hb=Oa}x:while(1){nb=c[Hb+(Fb<<2)>>2]|0;Qa=c[nb+24>>2]|0;do{if((Qa|0)==0){Ib=Gb}else{Na=c[nb+16>>2]|0;kb=0;while(1){Jb=c[Na+(kb<<2)>>2]|0;if((c[Jb+16>>2]|0)==1){if((c[(c[Jb+84>>2]|0)+4>>2]|0)==1){Kb=kb;break}}db=kb+1|0;if(db>>>0<Qa>>>0){kb=db}else{Kb=db;break}}if((Kb|0)==(Qa|0)){Ib=Gb;break}kb=nb+40|0;Na=c[kb>>2]|0;if((Na|0)==0){Ib=Gb;break}db=nb+32|0;ga=Jb+84|0;fa=0;ib=Na;while(1){Na=c[(c[db>>2]|0)+(fa<<2)>>2]|0;do{if((c[Na+16>>2]|0)==1){fb=Na+80|0;eb=c[fb>>2]|0;if((c[eb+4>>2]|0)<2){Mb=ib;break}else{Nb=2147483647;Ob=-2147483648;Pb=-1;Qb=0;Rb=eb}while(1){eb=c[c[ga>>2]>>2]|0;jb=c[eb>>2]|0;lb=c[eb+4>>2]|0;eb=(c[Rb>>2]|0)+(Qb<<3)|0;mb=c[eb>>2]|0;Za=c[eb+4>>2]|0;eb=hBb(jb,lb)|0;hb=hBb(mb,Za)|0;pb=hb-eb|0;ob=0;Ya=(lb|0)<(ob|0)|(lb|0)==(ob|0)&jb>>>0<0>>>0;if((jb&2147483647|0)==0&(lb&0|0)==0|Ya^1){ob=-1;if((Za|0)>(ob|0)|(Za|0)==(ob|0)&mb>>>0>-1>>>0|(mb&2147483647|0)==0&(Za&0|0)==0){Sb=lb;Tb=jb;Ub=Za;Vb=mb;Wb=0;Xb=1e5}else{r=243}}else{r=243}if((r|0)==243){r=0;if(Ya){Ya=jb&2147483647;Yb=(Ya|0)==0?eb:Ya}else{Yb=eb}eb=0;if((Za|0)<(eb|0)|(Za|0)==(eb|0)&mb>>>0<0>>>0){eb=mb&2147483647;Zb=(eb|0)==0?hb:eb}else{Zb=hb}hb=Zb-Yb|0;Sb=0;Tb=0;Ub=0;Vb=0;Wb=0;Xb=((Yb|0)>(Zb|0)?8e4:9e4)-((hb|0)>-1?hb:-hb|0)|0}while(1){hb=1493424+(Wb<<4)|0;eb=c[hb>>2]|0;mb=c[hb+4>>2]|0;hb=1493432+(Wb<<4)|0;Za=c[hb>>2]|0;Ya=c[hb+4>>2]|0;do{if((eb&Tb|0)==0&(mb&Sb|0)==0){_b=Xb;$b=Ub;ac=Vb;bc=Sb;cc=Tb}else{if(!((eb&Vb|0)==0&(mb&Ub|0)==0)){_b=Xb;$b=Ub;ac=Vb;bc=Sb;cc=Tb;break}if((Za&Vb|0)==0&(Ya&Ub|0)==0){_b=Xb;$b=Ub;ac=Vb;bc=Sb;cc=Tb;break}if(!((Za&Tb|0)==0&(Ya&Sb|0)==0)){_b=Xb;$b=Ub;ac=Vb;bc=Sb;cc=Tb;break}_b=Xb-2+((hBb(Za,Ya)|0)*10|0)|0;$b=Ub&~Ya;ac=Vb&~Za;bc=Sb&~mb;cc=Tb&~eb}}while(0);eb=Wb+1|0;if(eb>>>0<21>>>0){Sb=bc;Tb=cc;Ub=$b;Vb=ac;Wb=eb;Xb=_b}else{break}}if((cc&8|0)==0&(bc&0|0)==0){dc=_b}else{dc=(ac&8|0)==0&($b&0|0)==0?_b:_b+10|0}eb=ac&-9;mb=$b|0;Za=hBb(eb&cc,mb&bc)|0;Ya=(Za*10|0)+dc+((hBb(eb&((cc|8)^-9),mb&~bc)|0)*-5|0)|0;if((Ya|0)>(Ob|0)){r=258}else{if((pb|0)<(Nb|0)&(Ya|0)==(Ob|0)){r=258}else{ec=Pb;fc=Ob;gc=Nb}}if((r|0)==258){r=0;ec=Qb;fc=Ya;gc=pb}Ya=Qb+1|0;hc=c[fb>>2]|0;if((Ya|0)<(c[hc+4>>2]|0)){Nb=gc;Ob=fc;Pb=ec;Qb=Ya;Rb=hc}else{break}}if(!((ec|0)>-1)){break x}fb=c[hc>>2]|0;gb=fb+(ec<<3)|0;Ya=c[gb>>2]|0;mb=c[gb+4>>2]|0;eb=c[fb+4>>2]|0;c[gb>>2]=c[fb>>2];c[gb+4>>2]=eb;c[fb>>2]=Ya;c[fb+4>>2]=mb;Mb=c[kb>>2]|0}else{Mb=ib}}while(0);Na=fa+1|0;if(Na>>>0<Mb>>>0){fa=Na;ib=Mb}else{break}}Ib=c[m>>2]|0}}while(0);nb=Fb+1|0;if(!(nb>>>0<Ib>>>0)){qb=0;rb=0;sb=Ib;break u}Fb=nb;Gb=Ib;Hb=c[Q>>2]|0}yDb(0,0,2056584,(A=i,i=i+24|0,c[A>>2]=2309752,c[A+8>>2]=1971568,c[A+16>>2]=941,A)|0);i=A;Cd();return 0}}while(0);y:while(1){Hb=qb;Ib=rb;while(1){if(Hb>>>0<sb>>>0){break}if((Ib|0)==0){r=291;break y}else{Hb=0;Ib=0}}Gb=c[(c[Q>>2]|0)+(Hb<<2)>>2]|0;Fb=Gb+24|0;Mb=c[Fb>>2]|0;if((Mb|0)==0){ic=Ib}else{ec=Gb+16|0;hc=0;Rb=Ib;Qb=Mb;while(1){Mb=c[(c[ec>>2]|0)+(hc<<2)>>2]|0;Pb=c[Mb+64>>2]|0;do{if((Pb|0)==0){jc=Rb;kc=Qb}else{if((c[Pb>>2]|0)!=1){jc=Rb;kc=Qb;break}fc=tj(Mb,0)|0;if((fc|0)<0){lc=fc;r=299;break y}jc=1;kc=c[Fb>>2]|0}}while(0);Mb=hc+1|0;if(Mb>>>0<kc>>>0){hc=Mb;Rb=jc;Qb=kc}else{ic=jc;break}}}Qb=Gb+40|0;Rb=c[Qb>>2]|0;do{if((Rb|0)==0){mc=ic}else{hc=Gb+32|0;ec=0;Ib=ic;Mb=Rb;while(1){Pb=c[(c[hc>>2]|0)+(ec<<2)>>2]|0;fc=c[Pb+64>>2]|0;do{if((fc|0)==0){nc=Ib;oc=Mb}else{if((c[fc>>2]|0)!=1){nc=Ib;oc=Mb;break}Ob=tj(Pb,0)|0;if((Ob|0)<0){lc=Ob;r=299;break y}nc=1;oc=c[Qb>>2]|0}}while(0);Pb=ec+1|0;if(Pb>>>0<oc>>>0){ec=Pb;Ib=nc;Mb=oc}else{break}}if((c[Fb>>2]|0)==0|(oc|0)==0){mc=nc;break}Mb=Gb+16|0;if((c[(c[c[Mb>>2]>>2]|0)+52>>2]|0)>-1){pc=0;qc=nc;rc=oc}else{mc=nc;break}while(1){Ib=c[(c[hc>>2]|0)+(pc<<2)>>2]|0;if((c[Ib+52>>2]|0)<0){ec=tj(Ib,c[c[Mb>>2]>>2]|0)|0;if((ec|0)<0){lc=ec;r=299;break y}sc=1;tc=c[Qb>>2]|0}else{sc=qc;tc=rc}ec=pc+1|0;if(ec>>>0<tc>>>0){pc=ec;qc=sc;rc=tc}else{mc=sc;break}}}}while(0);qb=Hb+1|0;rb=mc;sb=c[m>>2]|0}z:do{if((r|0)==291){if((sb|0)==0){uc=sb;break}else{vc=0}while(1){mc=c[(c[Q>>2]|0)+(vc<<2)>>2]|0;rb=mc+24|0;qb=mc+16|0;sc=0;while(1){if(!(sc>>>0<(c[rb>>2]|0)>>>0)){break}tc=tj(c[(c[qb>>2]|0)+(sc<<2)>>2]|0,0)|0;if((tc|0)<0){lc=tc;r=299;break z}else{sc=sc+1|0}}sc=mc+40|0;qb=mc+32|0;rb=0;while(1){if(!(rb>>>0<(c[sc>>2]|0)>>>0)){break}tc=tj(c[(c[qb>>2]|0)+(rb<<2)>>2]|0,0)|0;if((tc|0)<0){lc=tc;r=299;break z}else{rb=rb+1|0}}rb=vc+1|0;qb=c[m>>2]|0;if(rb>>>0<qb>>>0){vc=rb}else{uc=qb;break}}}}while(0);do{if((r|0)==299){vc=(lc|0)<0?lc:0;if((vc|0)==0){uc=c[m>>2]|0;break}else{B=vc;i=e;return B|0}}}while(0);A:do{if((uc|0)==0){wc=0}else{lc=0;vc=uc;sb=uc;while(1){Hb=c[(c[Q>>2]|0)+(lc<<2)>>2]|0;if((c[Hb+40>>2]|0)==0){qb=Li(Hb)|0;if((qb|0)!=0){B=qb;r=330;break}qb=c[m>>2]|0;xc=qb;yc=qb}else{xc=vc;yc=sb}qb=lc+1|0;if(qb>>>0<xc>>>0){lc=qb;vc=xc;sb=yc}else{break}}if((r|0)==330){i=e;return B|0}if((yc|0)==0){wc=0;break}else{zc=0;Ac=0}while(1){sb=c[(c[Q>>2]|0)+(zc<<2)>>2]|0;vc=sb+24|0;if((c[vc>>2]|0)==0){Bc=0}else{lc=sb+16|0;qb=0;Hb=c[lc>>2]|0;while(1){c[(c[Hb+(qb<<2)>>2]|0)+100>>2]=b;rb=c[lc>>2]|0;c[(c[rb+(qb<<2)>>2]|0)+112>>2]=-1;sc=qb+1|0;mc=c[vc>>2]|0;if(sc>>>0<mc>>>0){qb=sc;Hb=rb}else{Bc=mc;break}}}Hb=sb+40|0;do{if((c[Hb>>2]|0)==0){Cc=Bc;r=315}else{qb=sb+32|0;lc=0;mc=c[qb>>2]|0;do{c[(c[mc+(lc<<2)>>2]|0)+100>>2]=b;mc=c[qb>>2]|0;c[(c[mc+(lc<<2)>>2]|0)+112>>2]=-1;lc=lc+1|0;Dc=c[Hb>>2]|0;}while(lc>>>0<Dc>>>0);if((Dc|0)!=0){Ec=Ac;break}Cc=c[vc>>2]|0;r=315}}while(0);if((r|0)==315){r=0;if(Cc>>>0>(2147483647-Ac|0)>>>0){B=-22;break}Ec=Cc+Ac|0}vc=zc+1|0;if(vc>>>0<(c[m>>2]|0)>>>0){zc=vc;Ac=Ec}else{wc=Ec;break A}}i=e;return B|0}}while(0);Ec=dEb(wc,4)|0;Ac=Ec;if((Ec|0)==0){B=-12;i=e;return B|0}Ec=c[m>>2]|0;if((Ec|0)==0){Fc=0}else{zc=c[Q>>2]|0;Q=0;Cc=0;r=Ec;while(1){Ec=c[zc+(Q<<2)>>2]|0;do{if((c[Ec+40>>2]|0)==0){Dc=Ec+24|0;if((c[Dc>>2]|0)==0){Gc=Cc;Hc=r;break}Bc=Ec+16|0;yc=0;xc=Cc;uc=c[Bc>>2]|0;while(1){c[Ac+(xc<<2)>>2]=c[uc+(yc<<2)>>2];Ic=xc+1|0;vc=c[Bc>>2]|0;c[(c[vc+(yc<<2)>>2]|0)+112>>2]=xc;Hb=yc+1|0;if(Hb>>>0<(c[Dc>>2]|0)>>>0){yc=Hb;xc=Ic;uc=vc}else{break}}Gc=Ic;Hc=c[m>>2]|0}else{Gc=Cc;Hc=r}}while(0);Ec=Q+1|0;if(Ec>>>0<Hc>>>0){Q=Ec;Cc=Gc;r=Hc}else{Fc=Gc;break}}}if((Fc|0)!=(wc|0)){yDb(0,0,2056584,(A=i,i=i+24|0,c[A>>2]=2010456,c[A+8>>2]=1971568,c[A+16>>2]=1143,A)|0);i=A;Cd();return 0}c[b+48>>2]=Ac;c[b+52>>2]=wc;B=0;i=e;return B|0}function pj(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((b|0)==0){j=-38;return j|0}k=(i&1|0)==0;do{if((i&3|0)==1){l=pj(b,d,e,f,g,h,i|2)|0;if((l|0)==-38){break}else{j=l}return j|0}}while(0);if(!((h|0)==0|(g|0)==0)){a[g]=0}l=b+20|0;m=c[l>>2]|0;if((m|0)==0){j=-38;return j|0}n=b+8|0;if(k){k=0;b=-38;o=m;while(1){p=c[(c[n>>2]|0)+(k<<2)>>2]|0;do{if((QGb(d,2335328)|0)==0){q=19}else{r=c[p+8>>2]|0;if((r|0)!=0){if((QGb(d,r)|0)==0){q=19;break}}if((QGb(d,c[c[p+4>>2]>>2]|0)|0)==0){q=19}else{s=b;t=o}}}while(0);if((q|0)==19){q=0;r=Pi(p,e,f,g,h,i)|0;if((r|0)!=-38&(r|0)<0){j=r;q=22;break}s=r;t=c[l>>2]|0}r=k+1|0;if(r>>>0<t>>>0){k=r;b=s;o=t}else{j=s;q=22;break}}if((q|0)==22){return j|0}}else{s=0;t=m;while(1){m=c[(c[n>>2]|0)+(s<<2)>>2]|0;do{if((QGb(d,2335328)|0)==0){q=12}else{o=c[m+8>>2]|0;if((o|0)!=0){if((QGb(d,o)|0)==0){q=12;break}}if((QGb(d,c[c[m+4>>2]>>2]|0)|0)==0){q=12}else{u=t}}}while(0);if((q|0)==12){q=0;p=Pi(m,e,f,g,h,i)|0;if(!((p|0)==-38)){j=p;q=22;break}u=c[l>>2]|0}p=s+1|0;if(p>>>0<u>>>0){s=p;t=u}else{j=-38;q=22;break}}if((q|0)==22){return j|0}}return 0}function qj(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=+g;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a|0)==0){return 0}i=a+20|0;j=c[i>>2]|0;if((j|0)==0){return 0}k=a+8|0;a=(f&1|0)==0;l=0;m=j;a:while(1){j=c[(c[k>>2]|0)+(l<<2)>>2]|0;b:do{if((j|0)==0){n=m}else{do{if((QGb(b,2335328)|0)!=0){if((QGb(b,c[j+8>>2]|0)|0)==0){break}if((QGb(b,c[c[j+4>>2]>>2]|0)|0)!=0){n=m;break b}}}while(0);o=j+60|0;while(1){p=c[o>>2]|0;if((p|0)==0){q=0;break}if(+h[p>>3]>g){q=p;break}else{o=p+20|0}}c[o>>2]=cEb(24)|0;p=eEb(d)|0;c[(c[o>>2]|0)+8>>2]=p;p=eEb(e)|0;c[(c[o>>2]|0)+12>>2]=p;p=c[o>>2]|0;h[p>>3]=g;c[p+16>>2]=f;c[p+20>>2]=q;if(!a){r=14;break a}n=c[i>>2]|0}}while(0);j=l+1|0;if(j>>>0<n>>>0){l=j;m=n}else{r=14;break}}if((r|0)==14){return 0}return 0}function rj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b+112|0;e=c[d>>2]|0;f=a+48|0;g=c[f>>2]|0;a:do{if((e|0)==0){h=0}else{i=b+104|0;j=c[i>>2]|0;k=c[i+4>>2]|0;i=e;while(1){l=i-1>>1;m=c[g+(l<<2)>>2]|0;n=m+104|0;o=c[n+4>>2]|0;if(!((o|0)<(k|0)|(o|0)==(k|0)&(c[n>>2]|0)>>>0<j>>>0)){h=i;break a}c[g+(i<<2)>>2]=m;c[m+112>>2]=i;if((l|0)==0){h=0;break}else{i=l}}}}while(0);c[g+(h<<2)>>2]=b;c[d>>2]=h;g=c[f>>2]|0;f=h<<1|1;e=a+52|0;a=c[e>>2]|0;if((f|0)>=(a|0)){p=h;q=g+(p<<2)|0;c[q>>2]=b;c[d>>2]=p;return}i=b+104|0;j=c[i>>2]|0;k=c[i+4>>2]|0;i=h;h=f;f=a;while(1){a=h+1|0;if((a|0)<(f|0)){l=(c[g+(a<<2)>>2]|0)+104|0;m=c[l+4>>2]|0;n=(c[g+(h<<2)>>2]|0)+104|0;o=c[n+4>>2]|0;r=(m|0)<(o|0)|(m|0)==(o|0)&(c[l>>2]|0)>>>0<(c[n>>2]|0)>>>0?a:h}else{r=h}a=c[g+(r<<2)>>2]|0;n=a+104|0;l=c[n+4>>2]|0;if((k|0)<(l|0)|(k|0)==(l|0)&j>>>0<(c[n>>2]|0)>>>0){p=i;s=11;break}c[g+(i<<2)>>2]=a;c[a+112>>2]=i;a=r<<1|1;n=c[e>>2]|0;if((a|0)<(n|0)){i=r;h=a;f=n}else{p=r;s=11;break}}if((s|0)==11){q=g+(p<<2)|0;c[q>>2]=b;c[d>>2]=p;return}}function sj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=i;d=a+48|0;e=a+52|0;if((c[e>>2]|0)==0){f=-541478725;i=b;return f|0}while(1){a=c[c[d>>2]>>2]|0;g=Ni(a)|0;if(!((g|0)==-541478725)){f=g;h=16;break}g=c[a+8>>2]|0;if((g|0)==0){j=2115856}else{j=c[g+8>>2]|0}k=c[a+12>>2]|0;if((k|0)==0){l=2115856}else{l=c[k>>2]|0}yDb(g,48,2194128,(g=i,i=i+16|0,c[g>>2]=j,c[g+8>>2]=l,g)|0);i=g;g=a+112|0;a=c[g>>2]|0;k=(c[e>>2]|0)-1|0;c[e>>2]=k;if((a|0)<(k|0)){a=c[d>>2]|0;m=c[a+(k<<2)>>2]|0;n=c[g>>2]|0;o=n<<1|1;a:do{if((o|0)<(k|0)){p=m+104|0;q=c[p>>2]|0;r=c[p+4>>2]|0;p=n;s=o;t=k;while(1){u=s+1|0;if((u|0)<(t|0)){v=(c[a+(u<<2)>>2]|0)+104|0;w=c[v+4>>2]|0;x=(c[a+(s<<2)>>2]|0)+104|0;y=c[x+4>>2]|0;z=(w|0)<(y|0)|(w|0)==(y|0)&(c[v>>2]|0)>>>0<(c[x>>2]|0)>>>0?u:s}else{z=s}u=c[a+(z<<2)>>2]|0;x=u+104|0;v=c[x+4>>2]|0;if((r|0)<(v|0)|(r|0)==(v|0)&q>>>0<(c[x>>2]|0)>>>0){A=p;break a}c[a+(p<<2)>>2]=u;c[u+112>>2]=p;u=z<<1|1;x=c[e>>2]|0;if((u|0)<(x|0)){p=z;s=u;t=x}else{A=z;break}}}else{A=n}}while(0);c[a+(A<<2)>>2]=m;c[m+112>>2]=A}c[g>>2]=-1;if((c[e>>2]|0)==0){f=-541478725;h=16;break}}if((h|0)==16){i=b;return f|0}return 0}function tj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;if((b|0)==0){f=0;i=e;return f|0}g=b+64|0;h=c[g>>2]|0;if((h|0)==0){f=0;i=e;return f|0}j=b+16|0;k=c[j>>2]|0;do{if((k|0)!=0|(d|0)==0){l=h;m=k}else{if((c[d+16>>2]|0)!=0){l=h;m=0;break}n=d+52|0;o=(a[(bFb(c[n>>2]|0)|0)+4|0]&1^1)&255;p=c[g>>2]|0;if((c[p>>2]|0)==0){q=-1}else{r=-1;s=0;t=p;while(1){p=aHa(r,c[(c[t+4>>2]|0)+(s<<2)>>2]|0,c[n>>2]|0,o,0)|0;u=s+1|0;v=c[g>>2]|0;if(u>>>0<(c[v>>2]|0)>>>0){r=p;s=u;t=v}else{q=p;break}}}t=c[b>>2]|0;s=ZEb(q)|0;r=c[c[g>>2]>>2]|0;p=ZEb(c[n>>2]|0)|0;yDb(t,48,1918296,(w=i,i=i+32|0,c[w>>2]=s,c[w+8>>2]=r,c[w+16>>2]=p,c[w+24>>2]=o,w)|0);i=w;p=c[g>>2]|0;c[c[p+4>>2]>>2]=q;l=p;m=c[j>>2]|0}}while(0);c[l>>2]=1;c[b+52>>2]=c[c[l+4>>2]>>2];l=b+72|0;a:do{if((m|0)==1){j=c[l>>2]|0;q=j|0;if((c[q>>2]|0)==0){d=c[b>>2]|0;h=c[(c[b+8>>2]|0)+8>>2]|0;yDb(d,16,1897544,(w=i,i=i+16|0,c[w>>2]=c[d+8>>2],c[w+8>>2]=h,w)|0);i=w;f=-22;i=e;return f|0}c[q>>2]=1;c[b+48>>2]=c[c[j+4>>2]>>2];j=b+80|0;q=c[j>>2]|0;if((a[q+8|0]|0)!=0){h=b|0;d=c[h>>2]|0;k=c[(c[b+8>>2]|0)+8>>2]|0;yDb(d,16,2354896,(w=i,i=i+16|0,c[w>>2]=c[d+8>>2],c[w+8>>2]=k,w)|0);i=w;if((a[(c[j>>2]|0)+9|0]|0)!=0){f=-22;i=e;return f|0}yDb(c[h>>2]|0,16,2334616,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;f=-22;i=e;return f|0}c[q+4>>2]=1;h=c[q>>2]|0;q=c[h>>2]|0;k=c[h+4>>2]|0;h=b+40|0;c[h>>2]=q;c[h+4>>2]=k;d=0;do{if((k|0)<(d|0)|(k|0)==(d|0)&q>>>0<0>>>0){p=q&2147483647;r=b+148|0;c[r>>2]=p;if((p|0)==0){x=r;break}c[h>>2]=0;c[h+4>>2]=0;y=j;break a}else{r=b+148|0;c[r>>2]=0;x=r}}while(0);c[x>>2]=hBb(q,k)|0;y=j}else{y=b+80|0}}while(0);Ik(g);Ik(b+68|0);Ik(l);Ik(b+76|0);Jk(y);Jk(b+84|0);f=0;i=e;return f|0}function uj(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+64|0;e=d|0;f=b+16|0;g=c[f>>2]|0;do{if((g|0)==0){h=4}else{j=c[g>>2]|0;if((j|0)==0){h=4;break}k=c[j+16>>2]|0}}while(0);do{if((h|0)==4){g=c[b+32>>2]|0;if((g|0)==0){k=0;break}j=c[g>>2]|0;if((j|0)==0){k=0;break}k=c[j+16>>2]|0}}while(0);j=re[c[(c[b+4>>2]|0)+36>>2]&4095](b)|0;if((j|0)<0){if((j|0)==-11){l=-11;i=d;return l|0}g=c[b+8>>2]|0;m=e|0;TGb(m|0,0,64)|0;a[m]=0;GBb(j,m,64)|0;yDb(b,16,2145752,(n=i,i=i+16|0,c[n>>2]=g,c[n+8>>2]=m,n)|0);i=n;l=j;i=d;return l|0}j=b+24|0;if((c[j>>2]|0)!=0){m=b;g=0;do{e=c[(c[(c[f>>2]|0)+(g<<2)>>2]|0)+84>>2]|0;do{if((e|0)!=0){if((c[e+4>>2]|0)==0){o=e+8|0;do{if((a[e+9|0]|0)!=0){if((a[o]|0)!=0){break}yDb(m,24,2133408,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}}while(0);a[o]=1;break}else{p=e+8|0;q=e+9|0;if((a[p]|0)==0){if((a[q]|0)!=0){h=18}}else{h=18}if((h|0)==18){h=0;yDb(m,24,2139752,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}a[q]=0;a[p]=0;break}}}while(0);g=g+1|0;}while(g>>>0<(c[j>>2]|0)>>>0)}j=b+40|0;if((c[j>>2]|0)!=0){g=b;m=b+32|0;f=0;do{e=c[(c[(c[m>>2]|0)+(f<<2)>>2]|0)+80>>2]|0;do{if((e|0)!=0){if((c[e+4>>2]|0)==0){p=e+8|0;do{if((a[e+9|0]|0)!=0){if((a[p]|0)!=0){break}yDb(g,24,2133408,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}}while(0);a[p]=1;break}else{o=e+8|0;q=e+9|0;if((a[o]|0)==0){if((a[q]|0)!=0){h=29}}else{h=29}if((h|0)==29){h=0;yDb(g,24,2139752,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}a[q]=0;a[o]=0;break}}}while(0);f=f+1|0;}while(f>>>0<(c[j>>2]|0)>>>0)}j=Bk(k)|0;if((j|0)==0){l=-12;i=d;return l|0}Ok(b,j);if((k|0)!=1){l=0;i=d;return l|0}k=Dk()|0;if((k|0)==0){l=-12;i=d;return l|0}Nk(b,k);k=Ek()|0;if((k|0)==0){l=-12;i=d;return l|0}Mk(b,k);l=0;i=d;return l|0}function vj(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+40|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;if((a|0)==(b|0)){m=1;i=f;return m|0}n=h;o=fEb(a,16)|0;p=o;c[h>>2]=p;do{if((o|0)==0){q=p}else{c[o+8>>2]=0;c[o+12>>2]=0;r=c[h>>2]|0;s=r+4|0;c[s>>2]=fEb(c[s>>2]|0,c[r>>2]<<2)|0;r=c[h>>2]|0;if((c[r+4>>2]|0)!=0){q=r;break}if((c[a+4>>2]|0)==0){q=r;break}$Db(n);q=c[h>>2]|0}}while(0);c[j>>2]=q;q=g;h=fEb(b,16)|0;n=h;c[g>>2]=n;do{if((h|0)==0){t=n}else{c[h+8>>2]=0;c[h+12>>2]=0;a=c[g>>2]|0;o=a+4|0;c[o>>2]=fEb(c[o>>2]|0,c[a>>2]<<2)|0;a=c[g>>2]|0;if((c[a+4>>2]|0)!=0){t=a;break}if((c[b+4>>2]|0)==0){t=a;break}$Db(q);t=c[g>>2]|0}}while(0);c[k>>2]=t;g=c[j>>2]|0;q=(g|0)==0;if(q|(t|0)==0){if(q){u=t}else{$Db(g+4|0);u=c[k>>2]|0}if((u|0)!=0){$Db(u+4|0)}$Db(j);$Db(k);m=0;i=f;return m|0}if((e|0)==0){v=tk(g,t,d)|0}else{v=uk(g,t)|0}c[l>>2]=v;if((v|0)==0){$Db((c[j>>2]|0)+4|0);$Db((c[k>>2]|0)+4|0);$Db(j);$Db(k);m=0;i=f;return m|0}else{$Db(v+4|0);$Db(v+12|0);$Db(l);m=1;i=f;return m|0}return 0}function wj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;if((a|0)==0){i=b;return}d=c[a>>2]|0;e=d+88|0;f=c[e>>2]|0;if((f|0)==0){yDb(0,0,2319440,(g=i,i=i+24|0,c[g>>2]=2331136,c[g+8>>2]=2191784,c[g+16>>2]=102,g)|0);i=g;Cd()}g=f-1|0;c[e>>2]=g;if((g|0)==0){me[c[d+72>>2]&511](d)}d=a+36|0;if((c[d>>2]|0)!=(a+4|0)){$Db(d)}d=a+72|0;g=c[d>>2]|0;if((g|0)!=0){$Db(g+40|0)}$Db(d);$Db(a+76|0);DBb(a+108|0);ZDb(a);i=b;return}function xj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=c[c[a+16>>2]>>2]|0;h=(c[a+44>>2]|0)+4|0;do{if((WBb(c[h>>2]|0)|0)==0){if((d&2|0)!=0){j=-11;i=e;return j|0}a=Ni(g)|0;if((a|0)<0){j=a}else{break}i=e;return j|0}}while(0);if((WBb(c[h>>2]|0)|0)==0){j=-22;i=e;return j|0}g=c[h>>2]|0;do{if((d&1|0)==0){ZBb(g,f,4,0)|0;QCb(b,c[f>>2]|0);JCb(f)}else{h=c[g>>2]|0;a=c[g+4>>2]|0;k=c[g+12>>2]|0;do{if(a>>>0<k>>>0){if(!(a>>>0<h>>>0)){l=a;break}l=k+(a-h)|0}else{l=h+(a-k)|0}}while(0);k=c[l>>2]|0;c[f>>2]=k;a=MCb(b,k)|0;if((a|0)<0){j=a}else{break}i=e;return j|0}}while(0);j=0;i=e;return j|0}function yj(a,b){a=a|0;b=b|0;var d=0;d=c[c[a+16>>2]>>2]|0;c[d+128>>2]=b;c[d+136>>2]=b;c[d+132>>2]=b;return}function zj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=c[c[b+4>>2]>>2]|0;do{if((QGb(e,2318592)|0)!=0){if((QGb(e,2191712)|0)==0){break}yDb(0,0,2055192,(f=i,i=i+24|0,c[f>>2]=1942080,c[f+8>>2]=1970752,c[f+16>>2]=360,f)|0);i=f;Cd()}}while(0);e=(c[c[b+16>>2]>>2]|0)+116|0;b=a;a=c[e+4>>2]|0;c[b>>2]=c[e>>2];c[b+4>>2]=a;i=d;return}function Aj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;a=c[e+56>>2]|0;if((a|0)!=0){jAb(a)}a=e+4|0;e=c[a>>2]|0;if((e|0)==0){i=b;return}f=(WBb(e)|0)>>>0>3>>>0;e=c[a>>2]|0;if(f){f=d;g=e;while(1){ZBb(g,f,4,0)|0;JCb(d);h=(WBb(c[a>>2]|0)|0)>>>0>3>>>0;j=c[a>>2]|0;if(h){g=j}else{k=j;break}}}else{k=e}VBb(k);c[a>>2]=0;i=b;return}function Bj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=0;f=e+16|0;g=c[f>>2]|0;if((g&3|0)!=0){yDb(a,16,2115056,(h=i,i=i+16|0,c[h>>2]=g,c[h+8>>2]=4,h)|0);i=h;j=-22;i=b;return j|0}if((g|0)==0){Pk(a)|0;j=0;i=b;return j|0}h=e+12|0;e=0;k=g;while(1){if(!(e>>>0<k>>>2>>>0)){l=9;break}g=c[(c[h>>2]|0)+(e<<2)>>2]|0;m=zk(d,g,(g|0)<0|0?-1:0)|0;if((m|0)<0){l=8;break}e=e+1|0;k=c[f>>2]|0}if((l|0)==8){Ik(d);j=m;i=b;return j|0}else if((l|0)==9){Ok(a,c[d>>2]|0);j=0;i=b;return j|0}return 0}function Cj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a+44|0;f=c[e>>2]|0;do{if((b|0)==0){g=f}else{h=c[b>>2]|0;j=nGb(4,h,-1,-1)|0;if(j>>>0>536870911>>>0){k=-22;i=d;return k|0}l=wEb(f,2166168,h,j<<2,0)|0;if((l|0)<0){k=l;i=d;return k|0}else{g=c[e>>2]|0;break}}}while(0);e=UBb(32)|0;c[g+4>>2]=e;if((e|0)==0){yDb(a,16,2152480,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-12;i=d;return k|0}else{c[g+8>>2]=100;a=g+64|0;c[a>>2]=0;c[a+4>>2]=-2147483648;k=0;i=d;return k|0}return 0}function Dj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+44>>2]|0;c[d>>2]=0;c[e>>2]=0;g=f+24|0;h=c[g>>2]|0;if((h&3|0)!=0){yDb(a,16,2145600,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=4,j)|0);i=j;k=-22;i=b;return k|0}l=f+52|0;m=c[l>>2]|0;if((m&3|0)!=0){yDb(a,16,2139616,(j=i,i=i+16|0,c[j>>2]=m,c[j+8>>2]=4,j)|0);i=j;k=-22;i=b;return k|0}m=f+32|0;n=c[m>>2]|0;if((n&7|0)!=0){yDb(a,16,2133248,(j=i,i=i+16|0,c[j>>2]=n,c[j+8>>2]=8,j)|0);i=j;k=-22;i=b;return k|0}o=f+40|0;p=c[o>>2]|0;if((p&3|0)!=0){yDb(a,16,2126856,(j=i,i=i+16|0,c[j>>2]=p,c[j+8>>2]=4,j)|0);i=j;k=-22;i=b;return k|0}do{if((h|0)==0){q=n}else{p=f+20|0;r=0;s=h;while(1){if(!(r>>>0<s>>>2>>>0)){t=15;break}u=c[(c[p>>2]|0)+(r<<2)>>2]|0;v=zk(d,u,(u|0)<0|0?-1:0)|0;if((v|0)<0){break}r=r+1|0;s=c[g>>2]|0}if((t|0)==15){Ok(a,c[d>>2]|0);q=c[m>>2]|0;break}Ik(d);k=v;i=b;return k|0}}while(0);do{if((q|0)==0){if((c[o>>2]|0)!=0){t=19;break}if((c[f+44>>2]|0)!=0){t=19}}else{t=19}}while(0);if((t|0)==19){v=f+28|0;g=0;h=q;while(1){if(!(g>>>0<h>>>3>>>0)){break}q=(c[v>>2]|0)+(g<<3)|0;w=Ak(e,c[q>>2]|0,c[q+4>>2]|0)|0;if((w|0)<0){t=24;break}g=g+1|0;h=c[m>>2]|0}if((t|0)==24){Jk(e);k=w;i=b;return k|0}w=f+36|0;m=0;while(1){if(!(m>>>0<(c[o>>2]|0)>>>2>>>0)){break}h=c[(c[w>>2]|0)+(m<<2)>>2]|0;x=Ak(e,h|0,((h|0)<0|0?-1:0)|-2147483648)|0;if((x|0)<0){t=28;break}m=m+1|0}if((t|0)==28){Jk(e);k=x;i=b;return k|0}do{if((c[f+44>>2]|0)!=0){if((c[e>>2]|0)!=0){yDb(a,24,2120992,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;break}x=Fk()|0;c[e>>2]=x;if((x|0)==0){k=-12}else{break}i=b;return k|0}}while(0);Mk(a,c[e>>2]|0)}e=c[l>>2]|0;if((e|0)==0){k=0;i=b;return k|0}c[d>>2]=0;j=f+48|0;f=0;x=e;while(1){if(!(f>>>0<x>>>2>>>0)){t=40;break}e=c[(c[j>>2]|0)+(f<<2)>>2]|0;y=zk(d,e,(e|0)<0|0?-1:0)|0;if((y|0)<0){t=39;break}f=f+1|0;x=c[l>>2]|0}if((t|0)==39){Ik(d);k=y;i=b;return k|0}else if((t|0)==40){Nk(a,c[d>>2]|0);k=0;i=b;return k|0}return 0}function Ej(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a+44|0;f=c[e>>2]|0;do{if((b|0)==0){g=f}else{h=c[b>>2]|0;j=nGb(4,h,-1,-1)|0;if(j>>>0>536870911>>>0){k=-22;i=d;return k|0}l=wEb(f,2354512,h,j<<2,0)|0;if((l|0)<0){k=l;i=d;return k|0}l=c[b+16>>2]|0;j=nGb(4,l,-1,-1)|0;if(j>>>0>536870911>>>0){k=-22;i=d;return k|0}h=wEb(f,2309384,l,j<<2,0)|0;if((h|0)<0){k=h;i=d;return k|0}h=c[b+4>>2]|0;j=nGb(8,h,-1,-1)|0;if(j>>>0>268435455>>>0){k=-22;i=d;return k|0}l=wEb(f,2274672,h,j<<3,0)|0;if((l|0)<0){k=l;i=d;return k|0}l=c[b+8>>2]|0;j=nGb(4,l,-1,-1)|0;if(j>>>0>536870911>>>0){k=-22;i=d;return k|0}h=wEb(f,2244464,l,j<<2,0)|0;if((h|0)<0){k=h;i=d;return k|0}h=c[b+12>>2]|0;j=vEb(f,2219672,h,(h|0)<0|0?-1:0,0)|0;if((j|0)<0){k=j;i=d;return k|0}else{g=c[e>>2]|0;break}}}while(0);e=UBb(32)|0;c[g+4>>2]=e;if((e|0)==0){yDb(a,16,2152480,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-12;i=d;return k|0}else{c[g+8>>2]=100;a=g+64|0;c[a>>2]=0;c[a+4>>2]=-2147483648;k=0;i=d;return k|0}return 0}function Fj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=c[a+8>>2]|0;a=f+44|0;g=c[a>>2]|0;h=e;c[e>>2]=b;b=(c[a>>2]|0)+4|0;do{if((XBb(c[b>>2]|0)|0)>>>0<4>>>0){a=c[b>>2]|0;if((YBb(a,(WBb(a)|0)<<1)|0)>=0){break}yDb(f,16,2176832,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-12;i=d;return k|0}}while(0);_Bb(c[b>>2]|0,h,4,0)|0;h=g+8|0;if((c[h>>2]|0)==0){k=0;i=d;return k|0}b=(WBb(c[g+4>>2]|0)|0)>>>2;g=c[h>>2]|0;if(b>>>0<g>>>0){k=0;i=d;return k|0}b=c[f+8>>2]|0;a=(b|0)!=0?b:c[c[f+4>>2]>>2]|0;yDb(f,24,2193432,(j=i,i=i+16|0,c[j>>2]=g,c[j+8>>2]=a,j)|0);i=j;c[h>>2]=(c[h>>2]|0)*10|0;k=0;i=d;return k|0}function Gj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;do{if((b|0)!=0){g=b+352|0;h=c[g>>2]|0;j=c[g+4>>2]|0;do{if(!((h|0)==0&(j|0)==0)){g=hBb(h,j)|0;if((g|0)==(vCb(b)|0)){break}yDb(0,16,2307200,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;k=-22;i=e;return k|0}}while(0);if((d&8|0)==0){break}j=ICb()|0;c[f>>2]=j;if((j|0)==0){k=-12;i=e;return k|0}h=MCb(j,b)|0;if((h|0)>-1){l=Hj(a,j,d)|0}else{l=h}JCb(f);k=l;i=e;return k|0}}while(0);k=Hj(a,b,d)|0;i=e;return k|0}function Hj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=c[a+44>>2]|0;c[g+24>>2]=0;h=g+84|0;if((b|0)==0){c[h>>2]=1;j=0;i=e;return j|0}if((c[h>>2]|0)!=0){j=-22;i=e;return j|0}h=(c[b+360>>2]|0)!=0;a:do{if((d&1|0)==0){k=c[(c[c[a+32>>2]>>2]|0)+16>>2]|0;if((k|0)==0){do{if((c[g+32>>2]|0)==(c[b+68>>2]|0)){if((c[g+36>>2]|0)!=(c[b+72>>2]|0)){break}if((c[g+40>>2]|0)==(c[b+80>>2]|0)){break a}}}while(0);yDb(a,32,2093896,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}else if((k|0)==1){m=b+352|0;n=c[m>>2]|0;o=c[m+4>>2]|0;if((n|0)==0&(o|0)==0){p=g+72|0;q=c[p>>2]|0;r=c[p+4>>2]|0;c[m>>2]=q;c[m+4>>2]=r;s=r;t=q}else{s=o;t=n}do{if((c[g+60>>2]|0)==(c[b+80>>2]|0)){if((c[g+56>>2]|0)!=(c[b+344>>2]|0)){break}n=g+72|0;if(!((c[n>>2]|0)==(t|0)&(c[n+4>>2]|0)==(s|0))){break}n=c[g+64>>2]|0;if((n|0)==(vCb(b)|0)){break a}}}while(0);yDb(a,16,2088768,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=-22;i=e;return j|0}else{j=-22;i=e;return j|0}}}while(0);l=g+4|0;do{if((XBb(c[l>>2]|0)|0)==0){g=c[l>>2]|0;s=YBb(g,(WBb(g)|0)+4|0)|0;if((s|0)<0){j=s}else{break}i=e;return j|0}}while(0);s=ICb()|0;c[f>>2]=s;if((s|0)==0){j=-12;i=e;return j|0}do{if(h){QCb(s,b)}else{g=MCb(s,b)|0;if((g|0)>=0){break}JCb(f);j=g;i=e;return j|0}}while(0);s=_Bb(c[l>>2]|0,f,4,0)|0;if((s|0)<0){if(h){QCb(b,c[f>>2]|0)}JCb(f);j=s;i=e;return j|0}do{if((d&4|0)!=0){s=re[c[(c[a+28>>2]|0)+44>>2]&4095](c[c[a+32>>2]>>2]|0)|0;if((s|0)<0){j=s}else{break}i=e;return j|0}}while(0);j=0;i=e;return j|0}function Ij(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=c[a+44>>2]|0;c[g>>2]=0;c[h>>2]=0;k=j+84|0;if((b|0)==0){c[k>>2]=1;l=0;i=f;return l|0}if((c[k>>2]|0)!=0){l=-22;i=f;return l|0}k=ICb()|0;c[g>>2]=k;if((k|0)==0){l=-12;i=f;return l|0}k=b+100|0;j=SAb(0,0,38,b,(c[k>>2]|0)>>>1&1^1)|0;c[h>>2]=j;a:do{if((j|0)==0){m=-12}else{n=yw(c[g>>2]|0,b)|0;if((n|0)<0){m=n;break}n=c[(c[g>>2]|0)+80>>2]|0;b:do{if((c[(c[c[a+32>>2]>>2]|0)+16>>2]|0)==0){o=bFb(n)|0;p=fFb(c[(c[g>>2]|0)+80>>2]|0)|0;if((o|0)==0|(p|0)<1){m=-22;break a}q=o+6|0;o=0;while(1){if((o|0)>=(p|0)){break b}if((o-1|0)>>>0<2>>>0){r=d[q]|0}else{r=0}s=c[g>>2]|0;t=c[s+72>>2]|0;u=c[s+32+(o<<2)>>2]|0;s=WAb(c[h>>2]|0)|0;if((s|0)==0){m=-12;break a}v=ba(t>>r,u)|0;u=SAb(c[(c[g>>2]|0)+(o<<2)>>2]|0,v,210,s,(c[k>>2]|0)>>>1&1^1)|0;c[(c[g>>2]|0)+360+(o<<2)>>2]=u;w=c[g>>2]|0;if((c[w+360+(o<<2)>>2]|0)==0){break}else{o=o+1|0}}KCb(w);m=-12;break a}else{o=CFb(n)|0;q=(c[g>>2]|0)+352|0;p=hBb(c[q>>2]|0,c[q+4>>2]|0)|0;q=(o|0)!=0?p:1;p=q>>>0>8>>>0;if(p){o=q-8|0;c[(c[g>>2]|0)+396>>2]=o;u=cEb(o<<2)|0;c[(c[g>>2]|0)+392>>2]=u;if((c[(c[g>>2]|0)+392>>2]|0)==0){m=-12;break a}}u=p?8:q;p=0;while(1){if(!(p>>>0<u>>>0)){break}o=WAb(c[h>>2]|0)|0;if((o|0)==0){m=-12;break a}s=c[g>>2]|0;v=SAb(c[(c[s+64>>2]|0)+(p<<2)>>2]|0,c[s+32>>2]|0,210,o,(c[k>>2]|0)>>>1&1^1)|0;c[(c[g>>2]|0)+360+(p<<2)>>2]=v;x=c[g>>2]|0;if((c[x+360+(p<<2)>>2]|0)==0){y=23;break}else{p=p+1|0}}if((y|0)==23){KCb(x);m=-12;break a}p=q-8|0;u=0;while(1){if(!(u>>>0<p>>>0)){break b}v=WAb(c[h>>2]|0)|0;if((v|0)==0){m=-12;break a}o=c[g>>2]|0;s=SAb(c[(c[o+64>>2]|0)+(u+8<<2)>>2]|0,c[o+32>>2]|0,210,v,(c[k>>2]|0)>>>1&1^1)|0;c[(c[(c[g>>2]|0)+392>>2]|0)+(u<<2)>>2]=s;z=c[g>>2]|0;if((c[(c[z+392>>2]|0)+(u<<2)>>2]|0)==0){break}else{u=u+1|0}}KCb(z);m=-12;break a}}while(0);m=Gj(a,c[g>>2]|0,e)|0}}while(0);XAb(h);JCb(g);l=m;i=f;return l|0}function Jj(a,b){a=a|0;b=b|0;wj(a);return}function Kj(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;XAb(d);i=b;return}function Lj(a){a=a|0;return c[(c[a+44>>2]|0)+24>>2]|0}function Mj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;d=c[a+44>>2]|0;e=d+40|0;do{if(!((c[e>>2]|0)==-1)){f=d+32|0;if((c[f>>2]|0)==0){break}g=d+36|0;if((c[g>>2]|0)==0){break}h=d+8|0;j=d+12|0;if(!(+(c[h>>2]|0)/+(c[j>>2]|0)>0.0)){break}k=UBb(4)|0;c[d+4>>2]=k;if((k|0)==0){l=-12;i=b;return l|0}k=c[f>>2]|0;f=c[g>>2]|0;g=ZEb(c[e>>2]|0)|0;m=c[h>>2]|0;h=c[j>>2]|0;j=c[d+16>>2]|0;n=c[d+20>>2]|0;o=c[d+44>>2]|0;p=c[d+48>>2]|0;q=c[d+52>>2]|0;yDb(a,40,2231816,(r=i,i=i+80|0,c[r>>2]=k,c[r+8>>2]=f,c[r+16>>2]=g,c[r+24>>2]=m,c[r+32>>2]=h,c[r+40>>2]=j,c[r+48>>2]=n,c[r+56>>2]=o,c[r+64>>2]=p,c[r+72>>2]=(q|0)!=0?q:9203480,r)|0);i=r;c[d+28>>2]=100;l=0;i=b;return l|0}}while(0);yDb(a,16,2244304,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;l=-22;i=b;return l|0}function Nj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8|0;d=b|0;e=(c[a+44>>2]|0)+4|0;a=c[e>>2]|0;a:do{if((a|0)==0){f=0}else{g=d;h=a;while(1){j=(WBb(h)|0)==0;k=c[e>>2]|0;if(j){f=k;break a}ZBb(k,g,4,0)|0;JCb(d);k=c[e>>2]|0;if((k|0)==0){f=0;break}else{h=k}}}}while(0);VBb(f);c[e>>2]=0;i=b;return}function Oj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=c[a+44>>2]|0;c[d>>2]=0;c[e>>2]=0;c[f>>2]=0;h=c[(c[c[a+32>>2]>>2]|0)+16>>2]|0;if((h|0)==1){j=c[g+60>>2]|0;zk(e,j,(j|0)<0|0?-1:0)|0;Ok(a,c[e>>2]|0);j=c[g+56>>2]|0;zk(f,j,(j|0)<0|0?-1:0)|0;Nk(a,c[f>>2]|0);f=g+72|0;j=c[f>>2]|0;k=c[f+4>>2]|0;if((j|0)==0&(k|0)==0){f=c[g+64>>2]|0;l=((f|0)<0|0?-1:0)|-2147483648;m=f|0}else{l=k;m=j}Ak(d,m,l)|0;Mk(a,c[d>>2]|0);n=0;i=b;return n|0}else if((h|0)==0){h=c[g+40>>2]|0;zk(e,h,(h|0)<0|0?-1:0)|0;Ok(a,c[e>>2]|0);n=0;i=b;return n|0}else{n=-22;i=b;return n|0}return 0}function Pj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=c[a+44>>2]|0;e=d+60|0;if((c[e>>2]|0)==-1){yDb(a,16,2008344,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}h=d+80|0;j=c[h>>2]|0;do{if((j|0)==0){if((c[d+64>>2]|0)!=0){break}yDb(a,16,1917352,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else{k=fBb(j)|0;l=F;m=d+72|0;c[m>>2]=k;c[m+4>>2]=l;if((k|0)==0&(l|0)==0){yDb(a,16,1970168,(f=i,i=i+8|0,c[f>>2]=c[h>>2],f)|0);i=f;g=-22;i=b;return g|0}m=hBb(k,l)|0;l=d+64|0;k=c[l>>2]|0;if((k|0)==0|(m|0)==(k|0)){c[l>>2]=m;break}l=c[h>>2]|0;yDb(a,16,1941496,(f=i,i=i+24|0,c[f>>2]=k,c[f+8>>2]=l,c[f+16>>2]=m,f)|0);i=f;g=-22;i=b;return g|0}}while(0);j=UBb(4)|0;c[d+4>>2]=j;if((j|0)==0){g=-12;i=b;return g|0}j=d+8|0;m=c[j>>2]|0;if((m|0)==0){l=d+56|0;k=c[l>>2]|0;c[j>>2]=1;c[d+12>>2]=k;n=1;o=k;p=l}else{n=m;o=c[d+12>>2]|0;p=d+56|0}m=wFb(c[e>>2]|0)|0;e=c[p>>2]|0;p=c[h>>2]|0;yDb(a,40,1896472,(f=i,i=i+40|0,c[f>>2]=n,c[f+8>>2]=o,c[f+16>>2]=m,c[f+24>>2]=e,c[f+32>>2]=p,f)|0);i=f;c[d+28>>2]=100;g=0;i=b;return g|0}function Qj(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;a=WBb(c[b+4>>2]|0)|0;do{if((a|0)==0){if((c[b+84>>2]|0)==0){break}else{d=-541478725}return d|0}}while(0);d=a>>>2;return d|0}function Rj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;e=c[(c[a>>2]|0)+44>>2]|0;f=e+4|0;if((WBb(c[f>>2]|0)|0)!=0){ZBb(c[f>>2]|0,d,4,0)|0;g=cj(a,c[d>>2]|0)|0;i=b;return g|0}if((c[e+84>>2]|0)!=0){g=-541478725;i=b;return g|0}d=e+24|0;c[d>>2]=(c[d>>2]|0)+1;g=-11;i=b;return g|0}function Sj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[(c[a>>2]|0)+44>>2]|0;d=c[a+16>>2]|0;do{if((d|0)==1){e=b+72|0;if(!((c[e>>2]|0)==0&(c[e+4>>2]|0)==0)){break}f=a+40|0;g=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=g}else if((d|0)==0){c[a+20>>2]=c[b+32>>2];c[a+24>>2]=c[b+36>>2];g=b+44|0;e=a+28|0;f=c[g+4>>2]|0;c[e>>2]=c[g>>2];c[e+4>>2]=f}else{h=-22;return h|0}}while(0);d=b+8|0;f=a+56|0;e=c[d+4>>2]|0;c[f>>2]=c[d>>2];c[f+4>>2]=e;e=b+16|0;b=a+116|0;a=c[e+4>>2]|0;c[b>>2]=c[e>>2];c[b+4>>2]=a;h=0;return h|0}function Tj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=c[(c[a+4>>2]|0)+12>>2]|0;g=e+4|0;h=dEb(c[g>>2]|0,132)|0;c[e+8>>2]=h;if((h|0)==0){j=-12;i=b;return j|0}if((c[g>>2]|0)<=0){j=0;i=b;return j|0}h=d;e=d|0;k=f+4|0;f=d+4|0;l=d+36|0;m=d+20|0;n=a+24|0;o=a+12|0;p=a+16|0;q=a+20|0;a=d+24|0;r=0;while(1){TGb(h|0,0,60)|0;s=vAb(2290040,(t=i,i=i+8|0,c[t>>2]=r,t)|0)|0;i=t;c[e>>2]=s;if((s|0)==0){j=-12;u=10;break}c[f>>2]=c[k>>2];c[l>>2]=504;s=c[k>>2]|0;if((s|0)==0){c[m>>2]=140}else if((s|0)==1){c[a>>2]=860}else{u=8;break}Hi(r,n,12,o,p,d)|0;c[q>>2]=c[n>>2];s=r+1|0;if((s|0)<(c[g>>2]|0)){r=s}else{j=0;u=10;break}}if((u|0)==8){yDb(0,0,2353312,(t=i,i=i+24|0,c[t>>2]=2274144,c[t+8>>2]=2258448,c[t+16>>2]=130,t)|0);i=t;Cd();return 0}else if((u|0)==10){i=b;return j|0}return 0}function Uj(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+8|0;f=d|0;g=a+24|0;if((c[g>>2]|0)==0){i=d;return}h=(c[a+44>>2]|0)+8|0;j=a+12|0;a=0;do{k=c[h>>2]|0;l=k+(a*132|0)+130|0;m=b[l>>1]|0;if(!(m<<16>>16==0)){n=k+(a*132|0)+128|0;o=m;do{m=k+(a*132|0)+((e[n>>1]|0)<<2)|0;p=c[m>>2]|0;b[l>>1]=o-1;c[m>>2]=0;b[n>>1]=(b[n>>1]|0)+1&31;c[f>>2]=p;JCb(f);o=b[l>>1]|0;}while(!(o<<16>>16==0))}$Db((c[h>>2]|0)+(a*132|0)|0);$Db((c[j>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[g>>2]|0)>>>0);i=d;return}function Vj(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[a>>2]|0;a=d+24|0;e=c[a>>2]|0;a:do{if((e|0)!=0){f=(c[d+44>>2]|0)+8|0;g=d+16|0;h=0;i=e;b:while(1){do{if((b[(c[f>>2]|0)+(h*132|0)+130>>1]|0)==0){j=c[(c[g>>2]|0)+(h<<2)>>2]|0;if((c[j+144>>2]|0)!=0){k=i;break}l=Ni(j)|0;if(!((l|0)==-541478725)){m=l;break b}k=c[a>>2]|0}else{k=i}}while(0);l=h+1|0;if(l>>>0<k>>>0){h=l;i=k}else{break a}}return m|0}}while(0);m=Xj(d)|0;return m|0}function Wj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;d=c[a>>2]|0;e=d+16|0;f=c[c[e>>2]>>2]|0;a:do{if((c[a+16>>2]|0)==0){c[a+56>>2]=1;c[a+60>>2]=1e6;g=c[f+20>>2]|0;c[a+20>>2]=g;h=c[f+24>>2]|0;c[a+24>>2]=h;j=f+28|0;k=a+28|0;l=c[j>>2]|0;m=c[j+4>>2]|0;c[k>>2]=l;c[k+4>>2]=m;c[a+52>>2]=c[f+52>>2];c[a+116>>2]=1;c[a+120>>2]=0;k=c[d+24>>2]|0;j=l;l=m;m=1;while(1){if(!(m>>>0<k>>>0)){break a}n=c[(c[e>>2]|0)+(m<<2)>>2]|0;o=c[n+20>>2]|0;p=c[n+24>>2]|0;if(!((g|0)==(o|0)&(h|0)==(p|0))){q=p;break}if((j|0)!=(c[n+28>>2]|0)){q=h;break}if((l|0)==(c[n+32>>2]|0)){m=m+1|0}else{q=h;break}}k=c[n+28>>2]|0;p=c[n+32>>2]|0;yDb(d,16,1916608,(r=i,i=i+72|0,c[r>>2]=c[(c[d+12>>2]|0)+(m*60|0)>>2],c[r+8>>2]=o,c[r+16>>2]=q,c[r+24>>2]=k,c[r+32>>2]=p,c[r+40>>2]=g,c[r+48>>2]=h,c[r+56>>2]=j,c[r+64>>2]=l,r)|0);i=r;s=-22;i=b;return s|0}}while(0);q=a+156|0;c[q>>2]=c[q>>2]|1;s=0;i=b;return s|0}function Xj(a){a=a|0;var d=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0;d=i;f=c[a+44>>2]|0;g=c[a+24>>2]|0;if((g|0)==0){j=-541478725;i=d;return j|0}k=c[f+8>>2]|0;l=a+16|0;m=0;n=-1;o=2147483647;p=-1;while(1){if((b[k+(m*132|0)+130>>1]|0)==0){if((c[(c[(c[l>>2]|0)+(m<<2)>>2]|0)+144>>2]|0)==0){j=0;q=11;break}else{r=o;s=p;t=n}}else{u=(c[k+(m*132|0)+((b[k+(m*132|0)+128>>1]&31)<<2)>>2]|0)+136|0;v=c[u>>2]|0;w=c[u+4>>2]|0;u=(w|0)<(o|0)|(w|0)==(o|0)&v>>>0<p>>>0;r=u?w:o;s=u?v:p;t=u?m:n}u=m+1|0;if(u>>>0<g>>>0){m=u;n=t;o=r;p=s}else{break}}if((q|0)==11){i=d;return j|0}if((t|0)<0){j=-541478725;i=d;return j|0}q=c[f+8>>2]|0;f=q+(t*132|0)+128|0;s=q+(t*132|0)+130|0;p=b[s>>1]|0;if(p<<16>>16==0){yDb(0,0,2353312,(x=i,i=i+24|0,c[x>>2]=2333168,c[x+8>>2]=2308648,c[x+16>>2]=101,x)|0);i=x;Cd();return 0}r=q+(t*132|0)+(e[f>>1]<<2)|0;q=c[r>>2]|0;b[s>>1]=p-1;c[r>>2]=0;b[f>>1]=(b[f>>1]|0)+1&31;f=q+136|0;y=(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0)*1.0e-6;yDb(a,48,1896032,(x=i,i=i+16|0,c[x>>2]=t,h[x+8>>3]=y,x)|0);i=x;j=cj(c[c[a+32>>2]>>2]|0,q)|0;i=d;return j|0}function Yj(a,d){a=a|0;d=d|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;j=f+8|0;c[g>>2]=d;k=c[a+8>>2]|0;l=((c[a+12>>2]|0)-(c[k+12>>2]|0)|0)/60|0;m=d+136|0;d=c[m>>2]|0;n=c[m+4>>2]|0;if((d|0)==0&(n|0)==(-2147483648|0)){yDb(k,24,2244024,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;JCb(g);p=-1094995529;i=f;return p|0}m=c[k+44>>2]|0;c[j>>2]=1;c[j+4>>2]=1e6;q=KDb(d,n,a+56|0,j)|0;j=F;a=(c[g>>2]|0)+136|0;c[a>>2]=q;c[a+4>>2]=j;a=k;n=m+8|0;m=e[(c[n>>2]|0)+(l*132|0)+130>>1]|0;yDb(a,48,2231536,(o=i,i=i+24|0,h[o>>3]=(+(q>>>0)+ +(j|0)*4294967296.0)*1.0e-6,c[o+8>>2]=l,c[o+16>>2]=m,o)|0);i=o;m=c[n>>2]|0;n=c[g>>2]|0;g=m+(l*132|0)+130|0;j=b[g>>1]|0;if(j<<16>>16==32){yDb(a,24,2219392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;o=m+(l*132|0)+128|0;a=e[o>>1]|0;q=(b[g>>1]|0)-1&65535;b[g>>1]=q;JCb(m+(l*132|0)+(((q&65535)+a&31)<<2)|0);r=b[g>>1]|0;s=o}else{r=j;s=m+(l*132|0)+128|0}j=e[s>>1]|0;b[g>>1]=r+1;c[m+(l*132|0)+((j+(r&65535)&31)<<2)>>2]=n;p=Xj(k)|0;i=f;return p|0}function Zj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;if((c[d+272>>2]|0)!=4){i=b;return 0}e=d+264|0;f=c[e>>2]|0;if((f|0)==(-1|0)&(c[e+4>>2]|0)==(-1|0)){g=hFb()|0;c[e>>2]=g;c[e+4>>2]=0;h=g}else{h=f}yDb(a,32,2159152,(a=i,i=i+8|0,c[a>>2]=h,a)|0);i=a;oDb(d+4|0,h);i=b;return 0}function _j(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=(RCb(b)|0)!=0;h=g&1;j=c[a+272>>2]|0;if((j|0)==3){k=h^1}else if((j|0)==1){k=0}else if((j|0)==4){l=a+4|0;m=a+260|0;a=c[m>>2]|0;c[l+((a&63)<<2)>>2]=(c[l+((a+9&63)<<2)>>2]|0)+(c[l+((a+40&63)<<2)>>2]|0);a=c[m>>2]|0;c[m>>2]=a+1;k=c[l+((a&63)<<2)>>2]&1}else if((j|0)==2){k=1}else{k=h}j=c[589944+(k<<2)>>2]|0;yDb(f,40,2209928,(a=i,i=i+24|0,c[a>>2]=c[589944+(h<<2)>>2],c[a+8>>2]=j,c[a+16>>2]=(h|0)==(k|0)?2201240:9203424,a)|0);i=a;do{if((k|0)==1&(g^1)){a=SCb(b)|0;if((a|0)<0){n=a}else{o=b;break}i=d;return n|0}else{if(!(g&(k|0)==0)){o=b;break}a=PCb(b)|0;if((a|0)==0){n=-12}else{o=a;break}i=d;return n|0}}while(0);b=cj(c[c[f+32>>2]>>2]|0,o)|0;if(!(g&(k|0)==0)){n=b;i=d;return n|0}JCb(e);n=b;i=d;return n|0}function $j(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+44>>2]|0;e=dk(a)|0;if((e|0)<0){f=e;i=b;return f|0}if((c[d+312>>2]|0)==0){f=0;i=b;return f|0}yDb(a,16,1981232,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-22;i=b;return f|0}function ak(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;d=b+8|0;IBb(c[d>>2]|0);c[d>>2]=0;d=a+40|0;if((c[d>>2]|0)!=0){e=a+28|0;a=0;do{$Db((c[e>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0)}if((c[b+312>>2]|0)==0){return}JCb(b+1576|0);d=b+316|0;b=c[d>>2]|0;if((b|0)==0){return}E0a(b)|0;$Db(d);return}function bk(a){a=a|0;var b=0;b=dk(a)|0;return((b|0)<0?b:0)|0}function ck(a){a=a|0;var b=0;if((c[(c[a+44>>2]|0)+312>>2]|0)==0){b=Pk(a)|0;return b|0}else{Ok(a,xk(551680)|0);b=0;return b|0}return 0}function dk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=e+4|0;g=a;h=JBb(e+8|0,c[f>>2]|0,160616,0,0,0,0,0,g)|0;j=c[f>>2]|0;if((h|0)<0){yDb(g,16,2006680,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;l=h;i=b;return l|0}c[e+312>>2]=(yb(j|0,1968832)|0)!=0;j=d;h=e+1596|0;if((c[h>>2]|0)<=0){l=0;i=b;return l|0}e=d|0;g=a+4|0;f=d+4|0;m=d+44|0;n=a+40|0;o=a+28|0;p=a+32|0;q=a+36|0;a=0;while(1){TGb(j|0,0,60)|0;r=vAb(1940312,(k=i,i=i+8|0,c[k>>2]=a,k)|0)|0;i=k;c[e>>2]=r;if((r|0)==0){l=-12;s=7;break}c[f>>2]=c[(c[(c[g>>2]|0)+8>>2]|0)+4>>2];c[m>>2]=450;Hi(a,n,4,o,p,d)|0;c[q>>2]=c[n>>2];r=a+1|0;if((r|0)<(c[h>>2]|0)){a=r}else{l=0;s=7;break}}if((s|0)==7){i=b;return l|0}return 0}function ek(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;d=c[c[b+16>>2]>>2]|0;e=((c[a+4>>2]|0)-(c[b+28>>2]|0)|0)/60|0;a=(c[b+44>>2]|0)+1592|0;while(1){b=Ni(d)|0;if((b|0)<0){f=b;g=4;break}if((c[a>>2]|0)==(e|0)){f=0;g=4;break}}if((g|0)==4){return f|0}return 0}function fk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0.0,y=0,z=0.0,A=0.0,B=0,C=0.0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0.0,fa=0.0,ga=0,ha=0,ia=0,ja=0.0,ka=0.0,la=0;d=i;i=i+48|0;e=d|0;f=d+40|0;c[f>>2]=b;g=c[a+8>>2]|0;a=g+44|0;j=c[a>>2]|0;l=d+8|0;m=c[c[g+16>>2]>>2]|0;n=j+16|0;o=j+32|0;p=c[o+4>>2]&2147483647;r=2146435072;s=b+136|0;t=c[s>>2]|0;u=c[s+4>>2]|0;if(p>>>0>r>>>0|p>>>0==r>>>0&(c[o>>2]|0)>>>0>0>>>0){if((t|0)==0&(u|0)==(-2147483648|0)){v=+q}else{v=+(t>>>0)+ +(u|0)*4294967296.0}h[o>>3]=v}o=j+64|0;r=c[o+4>>2]&2147483647;p=2146435072;if(r>>>0>p>>>0|r>>>0==p>>>0&(c[o>>2]|0)>>>0>0>>>0){if((t|0)==0&(u|0)==(-2147483648|0)){w=+q}else{w=+(t>>>0)+ +(u|0)*4294967296.0}h[o>>3]=w*(+(c[m+56>>2]|0)/+(c[m+60>>2]|0))}o=m+160|0;p=j+264|0;h[p>>3]=+((c[o>>2]|0)>>>0)+ +(c[o+4>>2]|0)*4294967296.0;if((t|0)==0&(u|0)==(-2147483648|0)){o=j+24|0;h[o>>3]=+q;x=+q;y=o}else{w=+(t>>>0)+ +(u|0)*4294967296.0;u=j+24|0;h[u>>3]=w;x=w;y=u}u=j+56|0;h[u>>3]=x*(+(c[m+56>>2]|0)/+(c[m+60>>2]|0));t=sCb(b)|0;if((t|0)==(-1|0)&(F|0)==(-1|0)){z=+q}else{t=sCb(b)|0;z=+(t>>>0)+ +(F|0)*4294967296.0}h[j+296>>3]=z;t=m+16|0;o=c[t>>2]|0;do{if((o|0)==1){h[j+248>>3]=+(c[b+76>>2]|0)}else if((o|0)==0){if((c[b+296>>2]|0)==0){A=0.0}else{A=(c[b+300>>2]|0)!=0?1.0:2.0}h[j+208>>3]=A;h[j+88>>3]=+((c[b+88>>2]|0)>>>0>>>0);if((c[j+312>>2]|0)==0){break}r=c[a>>2]|0;s=r+1576|0;B=c[s>>2]|0;c[e>>2]=B;do{if((B|0)==0){C=0.0}else{D=b+72|0;E=c[D>>2]|0;if((E|0)!=(c[B+72>>2]|0)){C=0.0;break}G=b+68|0;H=c[G>>2]|0;if((H|0)!=(c[B+68>>2]|0)){C=0.0;break}I=c[b+32>>2]|0;if((I|0)!=(c[B+32>>2]|0)){C=0.0;break}do{if((E-8|0)>0){J=I<<3;K=r+376|0;L=0;M=0;N=0;O=0;P=c[b>>2]|0;R=c[B>>2]|0;S=H;T=E;while(1){if(((S*3|0)-8|0)>0){U=L;V=M;W=N;X=0;do{Y=Pe[c[K>>2]&255](r,P+X|0,R+X|0,I,8)|0;W=YGb(Y,(Y|0)<0|0?-1:0,W,V)|0;V=F;U=U+64|0;X=X+8|0;Z=c[G>>2]|0;}while((X|0)<((Z*3|0)-8|0));_=U;$=V;ba=W;ca=Z;da=c[D>>2]|0}else{_=L;$=M;ba=N;ca=S;da=T}X=O+8|0;if((X|0)<(da-8|0)){L=_;M=$;N=ba;O=X;P=P+J|0;R=R+J|0;S=ca;T=da}else{break}}if((_|0)==0){ea=0.0;break}T=eHb(ba,$,_,(_|0)<0|0?-1:0)|0;ea=+(T>>>0)+ +(F|0)*4294967296.0}else{ea=0.0}}while(0);D=r+1568|0;z=+Q(+(ea- +h[D>>3]));x=(ea>z?z:ea)/100.0;if(x<0.0){fa=0.0}else{fa=x>1.0?1.0:x}h[D>>3]=ea;JCb(e);C=fa}}while(0);c[s>>2]=PCb(b)|0;h[j+304>>3]=C;Lb(l|0,32,2009624,(ga=i,i=i+8|0,h[ga>>3]=C,ga)|0)|0;i=ga;CBb(FCb(b)|0,1999200,l,0)|0}}while(0);C=+MBb(c[j+8>>2]|0,n,0);n=j+1584|0;h[n>>3]=C;l=m+8|0;fa=+h[y>>3];ea=+h[u>>3];m=~~+h[j+288>>3];yDb(c[l>>2]|0,48,1995048,(ga=i,i=i+32|0,h[ga>>3]=+h[p>>3],h[ga+8>>3]=fa,h[ga+16>>3]=ea,c[ga+24>>2]=m,ga)|0);i=ga;m=c[t>>2]|0;if((m|0)==0){e=c[l>>2]|0;ea=+h[j+208>>3];do{if(ea==0.0){ha=80}else{if(ea==1.0){ha=84;break}ha=ea==2.0?66:63}}while(0);_=(mGb(~~+h[j+88>>3])|0)<<24>>24;ea=+h[j+304>>3];yDb(e,48,1991768,(ga=i,i=i+24|0,c[ga>>2]=ha,c[ga+8>>2]=_,h[ga+16>>3]=ea,ga)|0);i=ga}else if((m|0)==1){m=~~+h[j+240>>3];yDb(c[l>>2]|0,48,1988288,(ga=i,i=i+16|0,c[ga>>2]=~~+h[j+248>>3],c[ga+8>>2]=m,ga)|0);i=ga}do{if(C==0.0){c[j+1592>>2]=-1;ia=-1}else{h[k>>3]=C;m=c[k+4>>2]&2147483647;_=2146435072;if(m>>>0>_>>>0|m>>>0==_>>>0&(c[k>>2]|0)>>>0>0>>>0|C<0.0){c[j+1592>>2]=0;ia=0;break}else{ea=+aa(C)+-1.0;fa=+((c[j+1596>>2]|0)-1|0);_=~~(ea>fa?fa:ea);c[j+1592>>2]=_;ia=_;break}}}while(0);yDb(c[l>>2]|0,48,1983872,(ga=i,i=i+16|0,h[ga>>3]=C,c[ga+8>>2]=ia,ga)|0);i=ga;do{if(C!=0.0){h[j+280>>3]=+h[p>>3];ea=+h[y>>3];h[j+48>>3]=ea;fa=+h[u>>3];h[j+80>>3]=fa;ga=j+272|0;h[ga>>3]=+h[ga>>3]+1.0;if((c[t>>2]|0)!=1){ja=ea;ka=fa;break}ga=j+240|0;h[ga>>3]=+h[ga>>3]+ +(c[b+76>>2]|0);ja=ea;ka=fa}else{ja=+h[y>>3];ka=+h[u>>3]}}while(0);h[j+40>>3]=ja;h[j+72>>3]=ka;if(+h[n>>3]!=0.0){la=cj(c[(c[g+32>>2]|0)+(c[j+1592>>2]<<2)>>2]|0,c[f>>2]|0)|0;i=d;return la|0}else{JCb(f);la=0;i=d;return la|0}return 0}function gk(a){a=a|0;var b=0,d=0.0,e=0;b=c[(c[a+8>>2]|0)+44>>2]|0;TGb(b+264|0,0,16)|0;h[b+16>>3]=+(c[a+56>>2]|0)/+(c[a+60>>2]|0);h[b+40>>3]=+q;h[b+48>>3]=+q;h[b+80>>3]=+q;h[b+72>>3]=+q;h[b+32>>3]=+q;h[b+64>>3]=+q;h[b+96>>3]=1.0;h[b+104>>3]=2.0;h[b+112>>3]=3.0;h[b+128>>3]=5.0;h[b+136>>3]=6.0;h[b+144>>3]=7.0;h[b+152>>3]=1.0;h[b+160>>3]=2.0;h[b+168>>3]=3.0;h[b+184>>3]=5.0;h[b+192>>3]=6.0;h[b+200>>3]=7.0;h[b+216>>3]=0.0;h[b+224>>3]=1.0;h[b+232>>3]=2.0;h[b+88>>3]=+q;h[b+208>>3]=+q;h[b+304>>3]=+q;h[b+240>>3]=+q;h[b+248>>3]=+q;if((c[a+16>>2]|0)==1){d=+(c[a+48>>2]|0)}else{d=+q}h[b+256>>3]=d;if((c[b+312>>2]|0)==0){e=0;return e|0}a=ARa(0)|0;c[b+316>>2]=a;if((a|0)==0){e=-12;return e|0}x7(b+320|0,a);e=0;return e|0}function hk(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0.0,na=0;d=i;i=i+2200|0;e=d|0;f=d+64|0;g=d+1088|0;j=d+1112|0;k=d+1120|0;l=d+1128|0;m=d+1160|0;n=d+1168|0;o=d+1176|0;p=c[b+44>>2]|0;q=c[p+12>>2]|0;r=p+16|0;s=c[r>>2]|0;do{if((q|0)==0){t=s}else{u=b;if((s|0)!=0){yDb(u,16,2243320,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=d;return w|0}x=aCb(q,m,n,0,u)|0;if((x|0)<0){w=x;i=d;return w|0}x=WDb((c[n>>2]|0)+1|0)|0;u=c[m>>2]|0;y=c[n>>2]|0;if((x|0)!=0){UGb(x|0,u|0,y)|0;a[x+y|0]=0;bCb(u,y);c[r>>2]=x;t=x;break}bCb(u,y);w=-12;i=d;return w|0}}while(0);r=p+4|0;n=p+8|0;p=b;b=l;c[k>>2]=t;c[r>>2]=0;c[n>>2]=0;m=l+16|0;q=l|0;s=l+8|0;y=l+20|0;u=l+24|0;l=g;x=e|0;e=g+16|0;z=g|0;A=g+4|0;B=g+8|0;C=g+12|0;g=A;D=B;E=C;F=f|0;a:do{if((a[t]|0)!=0){G=t;H=0;I=0;while(1){J=G;while(1){K=qd(J|0,2200768)|0;L=J+K|0;c[k>>2]=L;M=a[L]|0;if((M<<24>>24|0)==0){break a}else if((M<<24>>24|0)!=35){break}M=K+1|0;N=J+M|0;c[k>>2]=N;O=hc(N|0,2064256)|0;N=J+(O+M)|0;c[k>>2]=N;if((a[N]|0)==0){break a}N=J+(K+2+O)|0;c[k>>2]=N;if((a[N]|0)==0){break a}else{J=N}}N=J+((qd(L|0,2200768)|0)+K)|0;c[k>>2]=N;if((a[N]|0)==0){P=N}else{TGb(b|0,0,32)|0;c[m>>2]=H;N=wAb(k,2165472)|0;b:do{if((N|0)==0){Q=24}else{if((a[N]|0)==0){Q=24;break}O=xAb(N,2158832,j)|0;M=VEb(q,O,1)|0;if((M|0)<0){yDb(p,16,2151752,(v=i,i=i+16|0,c[v>>2]=O,c[v+8>>2]=H,v)|0);i=v;R=M;break}M=c[j>>2]|0;do{if((M|0)==0){c[s>>2]=-1;c[s+4>>2]=2147483647}else{S=VEb(s,M,1)|0;if((S|0)<0){yDb(p,16,2144696,(v=i,i=i+16|0,c[v>>2]=c[j>>2],c[v+8>>2]=H,v)|0);i=v;R=S;break b}S=c[s+4>>2]|0;T=c[q+4>>2]|0;if(!((S|0)<(T|0)|(S|0)==(T|0)&(c[s>>2]|0)>>>0<(c[q>>2]|0)>>>0)){break}yDb(p,16,2139080,(v=i,i=i+24|0,c[v>>2]=c[j>>2],c[v+8>>2]=H,c[v+16>>2]=O,v)|0);i=v;R=-22;break b}}while(0);c[y>>2]=0;c[u>>2]=0;O=c[k>>2]|0;if((a[O]|0)==0){R=0;break}else{U=0;V=0;W=O}c:while(1){TGb(l|0,0,16)|0;c[e>>2]=U;O=qd(W|0,2200768)|0;M=W+O|0;c[k>>2]=M;if((a[M]|0)==91){T=W+(O+1)|0;c[k>>2]=T;if((a[T]|0)==0){Q=38;break}else{X=T;Y=0}while(1){Z=hc(X|0,2100320)|0;if((RGb(X,2289264,5)|0)==0){_=Y|1}else{if((RGb(X,2273192,5)|0)!=0){Q=32;break c}_=Y|2}c[z>>2]=_;T=X+Z|0;c[k>>2]=T;$=a[T]|0;if($<<24>>24==93){break}if((qd(T|0,2088472)|0)==0){Q=35;break c}if($<<24>>24==0){Q=38;break c}T=X+(Z+1)|0;c[k>>2]=T;if((a[T]|0)==0){Q=38;break c}else{X=T;Y=_}}T=X+(Z+1)|0;c[k>>2]=T;aa=T}else{c[z>>2]=1;aa=M}c[k>>2]=aa+(qd(aa|0,2200768)|0);T=wAb(k,2165472)|0;c[A>>2]=T;if((T|0)==0){Q=43;break}if((a[T]|0)==0){Q=43;break}T=c[k>>2]|0;c[k>>2]=T+(qd(T|0,2200768)|0);T=wAb(k,2165472)|0;c[B>>2]=T;if((T|0)==0){Q=46;break}if((a[T]|0)==0){Q=46;break}T=c[k>>2]|0;c[k>>2]=T+(qd(T|0,2200768)|0);c[C>>2]=wAb(k,2165472)|0;ba=U+1|0;T=c[u>>2]|0;if((T|0)==(V|0)){O=V<<1;S=(O|0)<16?16:O;O=YDb(c[y>>2]|0,S,40)|0;ca=O;c[y>>2]=ca;if((O|0)==0){Q=52;break}da=S;ea=c[u>>2]|0;fa=ca}else{da=V;ea=T;fa=c[y>>2]|0}c[u>>2]=ea+1;T=fa+(ea*20|0)|0;c[T>>2]=c[l>>2];c[T+4>>2]=c[l+4>>2];c[T+8>>2]=c[l+8>>2];c[T+12>>2]=c[l+12>>2];c[T+16>>2]=c[l+16>>2];T=c[k>>2]|0;ca=qd(T|0,2200768)|0;S=T+ca|0;c[k>>2]=S;O=a[S]|0;if((O<<24>>24|0)==59|(O<<24>>24|0)==0){R=0;break b}else if((O<<24>>24|0)!=44){Q=54;break}O=T+(ca+1)|0;c[k>>2]=O;if((a[O]|0)==0){R=0;break b}else{U=ba;V=da;W=O}}if((Q|0)==32){Q=0;sAb(x,X,64)|0;yDb(p,16,2093672,(v=i,i=i+24|0,c[v>>2]=x,c[v+8>>2]=H,c[v+16>>2]=U,v)|0);i=v;R=-22;break}else if((Q|0)==35){Q=0;yDb(p,16,2083696,(v=i,i=i+24|0,c[v>>2]=$<<24>>24,c[v+8>>2]=H,c[v+16>>2]=U,v)|0);i=v;R=-22;break}else if((Q|0)==38){Q=0;yDb(p,16,2078144,(v=i,i=i+16|0,c[v>>2]=H,c[v+8>>2]=U,v)|0);i=v;R=-22;break}else if((Q|0)==43){Q=0;yDb(p,16,2073232,(v=i,i=i+16|0,c[v>>2]=H,c[v+8>>2]=U,v)|0);i=v}else if((Q|0)==46){Q=0;yDb(p,16,2068736,(v=i,i=i+16|0,c[v>>2]=H,c[v+8>>2]=U,v)|0);i=v}else if((Q|0)==52){Q=0;yDb(p,16,2126408,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;R=-12;break}else if((Q|0)==54){Q=0;yDb(p,16,2120584,(v=i,i=i+16|0,c[v>>2]=H,c[v+8>>2]=ba,v)|0);i=v;O=c[z>>2]|0;IAb(f,0,1);if((O&1|0)==0){ga=1}else{KAb(f,2257568,(v=i,i=i+8|0,c[v>>2]=2289264,v)|0);i=v;ga=0}if((O&2|0)!=0){if((ga|0)==0){MAb(f,43,1)}KAb(f,2257568,(v=i,i=i+8|0,c[v>>2]=2273192,v)|0);i=v}O=c[A>>2]|0;ca=c[B>>2]|0;T=c[C>>2]|0;yDb(p,16,2114440,(v=i,i=i+32|0,c[v>>2]=c[F>>2],c[v+8>>2]=O,c[v+16>>2]=ca,c[v+24>>2]=T,v)|0);i=v;R=-22;break}$Db(g);$Db(D);$Db(E);R=-22}}while(0);if((Q|0)==24){Q=0;yDb(p,16,2132840,(v=i,i=i+8|0,c[v>>2]=H,v)|0);i=v;R=-22}ZDb(N);if((R|0)<0){w=R;Q=85;break}P=c[k>>2]|0}J=qd(P|0,2200768)|0;T=P+J|0;c[k>>2]=T;ca=a[T]|0;if((ca<<24>>24|0)==59){O=P+(J+1)|0;c[k>>2]=O;ha=O}else if((ca<<24>>24|0)==0){ha=T}else{Q=65;break}T=H+1|0;ca=c[n>>2]|0;if((ca|0)==(I|0)){O=I<<1;J=(O|0)<16?16:O;O=YDb(c[r>>2]|0,J,64)|0;S=O;c[r>>2]=S;if((O|0)==0){Q=71;break}ia=J;ja=c[n>>2]|0;ka=S;la=c[k>>2]|0}else{ia=I;ja=ca;ka=c[r>>2]|0;la=ha}c[n>>2]=ja+1;ca=ka+(ja<<5)|0;c[ca>>2]=c[b>>2];c[ca+4>>2]=c[b+4>>2];c[ca+8>>2]=c[b+8>>2];c[ca+12>>2]=c[b+12>>2];c[ca+16>>2]=c[b+16>>2];c[ca+20>>2]=c[b+20>>2];c[ca+24>>2]=c[b+24>>2];c[ca+28>>2]=c[b+28>>2];if((a[la]|0)==0){break a}else{G=la;H=T;I=ia}}if((Q|0)==65){yDb(p,16,2192272,(v=i,i=i+8|0,c[v>>2]=H,v)|0);i=v;w=-22;i=d;return w|0}else if((Q|0)==71){yDb(p,16,2176008,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-12;i=d;return w|0}else if((Q|0)==85){i=d;return w|0}}}while(0);Yc(c[r>>2]|0,c[n>>2]|0,32,412);yDb(p,48,2230800,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;if((c[n>>2]|0)<=0){w=0;i=d;return w|0}Q=o|0;ia=0;while(1){la=c[r>>2]|0;b=la+(ia<<5)|0;ja=la+(ia<<5)+8|0;ma=(+((c[ja>>2]|0)>>>0)+ +(c[ja+4>>2]|0)*4294967296.0)/1.0e6;ja=c[la+(ia<<5)+16>>2]|0;yDb(p,40,2218752,(v=i,i=i+24|0,h[v>>3]=(+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0)/1.0e6,h[v+8>>3]=ma,c[v+16>>2]=ja,v)|0);i=v;ja=la+(ia<<5)+24|0;if((c[ja>>2]|0)>0){b=la+(ia<<5)+20|0;la=0;do{ka=c[b>>2]|0;ha=c[ka+(la*20|0)>>2]|0;IAb(o,0,1);if((ha&1|0)==0){na=1}else{KAb(o,2257568,(v=i,i=i+8|0,c[v>>2]=2289264,v)|0);i=v;na=0}if((ha&2|0)!=0){if((na|0)==0){MAb(o,43,1)}KAb(o,2257568,(v=i,i=i+8|0,c[v>>2]=2273192,v)|0);i=v}ha=c[ka+(la*20|0)+4>>2]|0;k=c[ka+(la*20|0)+8>>2]|0;P=c[ka+(la*20|0)+12>>2]|0;R=c[ka+(la*20|0)+16>>2]|0;yDb(p,40,2209368,(v=i,i=i+40|0,c[v>>2]=c[Q>>2],c[v+8>>2]=ha,c[v+16>>2]=k,c[v+24>>2]=P,c[v+32>>2]=R,v)|0);i=v;la=la+1|0;}while((la|0)<(c[ja>>2]|0))}ja=ia+1|0;if((ja|0)<(c[n>>2]|0)){ia=ja}else{w=0;break}}i=d;return w|0}function ik(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+44>>2]|0;a=b+8|0;d=b+4|0;if((c[a>>2]|0)<=0){$Db(d);return}b=d;e=0;do{f=c[b>>2]|0;g=f+(e<<5)+24|0;h=f+(e<<5)+20|0;f=c[h>>2]|0;if((c[g>>2]|0)>0){i=0;j=f;while(1){ZDb(c[j+(i*20|0)+4>>2]|0);ZDb(c[j+(i*20|0)+8>>2]|0);ZDb(c[j+(i*20|0)+12>>2]|0);k=i+1|0;l=c[h>>2]|0;if((k|0)<(c[g>>2]|0)){i=k;j=l}else{m=l;break}}}else{m=f}ZDb(m);e=e+1|0;}while((e|0)<(c[a>>2]|0));$Db(d);return}function jk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,Q=0.0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+2120|0;f=e|0;g=e+8|0;j=e+1032|0;k=e+2056|0;l=b+8|0;m=c[l>>2]|0;n=c[m+44>>2]|0;o=d+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;do{if(!((p|0)==0&(q|0)==(-2147483648|0))){c[f>>2]=1;c[f+4>>2]=1e6;o=KDb(p,q,b+56|0,f)|0;r=F;s=n+8|0;if((c[s>>2]|0)<=0){break}t=n+4|0;u=m;v=g|0;w=(+(o>>>0)+ +(r|0)*4294967296.0)/1.0e6;x=b+100|0;y=j|0;z=k|0;A=0;do{B=c[t>>2]|0;C=B+(A<<5)|0;D=B+(A<<5)+28|0;E=C|0;G=c[E>>2]|0;H=c[E+4>>2]|0;do{if((c[D>>2]|0)==0){if((r|0)<(H|0)|(r|0)==(H|0)&o>>>0<G>>>0){break}E=B+(A<<5)+8|0;I=c[E+4>>2]|0;if(!((r|0)<(I|0)|(r|0)==(I|0)&o>>>0<(c[E>>2]|0)>>>0)){break}c[D>>2]=1;J=1;K=8}else{J=0;K=8}}while(0);a:do{if((K|0)==8){K=0;E=C|0;do{if((r|0)<(H|0)|(r|0)==(H|0)&o>>>0<G>>>0){K=10}else{I=B+(A<<5)+8|0;L=c[I+4>>2]|0;if(!((r|0)<(L|0)|(r|0)==(L|0)&o>>>0<(c[I>>2]|0)>>>0)){K=10;break}if((J|0)==0){break a}else{M=J}}}while(0);if((K|0)==10){K=0;c[D>>2]=0;M=J|2}IAb(g,0,1);if((M&1|0)==0){N=1}else{KAb(g,2257568,(O=i,i=i+8|0,c[O>>2]=2289264,O)|0);i=O;N=0}if((M&2|0)!=0){if((N|0)==0){MAb(g,43,1)}KAb(g,2257568,(O=i,i=i+8|0,c[O>>2]=2273192,O)|0);i=O}I=c[B+(A<<5)+16>>2]|0;P=(+((c[E>>2]|0)>>>0)+ +(c[E+4>>2]|0)*4294967296.0)/1.0e6;L=B+(A<<5)+8|0;Q=(+((c[L>>2]|0)>>>0)+ +(c[L+4>>2]|0)*4294967296.0)/1.0e6;yDb(u,40,2352176,(O=i,i=i+40|0,c[O>>2]=c[v>>2],c[O+8>>2]=I,h[O+16>>3]=P,h[O+24>>3]=Q,h[O+32>>3]=w,O)|0);i=O;I=B+(A<<5)+24|0;L=c[I>>2]|0;if((L|0)<=0){break}R=B+(A<<5)+20|0;S=0;T=L;while(1){L=c[R>>2]|0;if((c[L+(S*20|0)>>2]&M|0)==0){U=T}else{V=L+(S*20|0)+16|0;W=L+(S*20|0)+4|0;X=c[W>>2]|0;Y=L+(S*20|0)+8|0;Z=c[Y>>2]|0;_=L+(S*20|0)+12|0;L=c[_>>2]|0;yDb(u,40,2332032,(O=i,i=i+32|0,c[O>>2]=c[V>>2],c[O+8>>2]=X,c[O+16>>2]=Z,c[O+24>>2]=L,O)|0);i=O;L=pj(c[x>>2]|0,c[W>>2]|0,c[Y>>2]|0,c[_>>2]|0,y,1024,1)|0;_=c[V>>2]|0;TGb(z|0,0,64)|0;a[z]=0;GBb(L,z,64)|0;yDb(u,40,2307664,(O=i,i=i+24|0,c[O>>2]=_,c[O+8>>2]=z,c[O+16>>2]=y,O)|0);i=O;U=c[I>>2]|0}_=S+1|0;if((_|0)<(U|0)){S=_;T=U}else{break}}}}while(0);A=A+1|0;}while((A|0)<(c[s>>2]|0))}}while(0);if(!((c[b+16>>2]|0)>>>0<2>>>0)){$=-38;i=e;return $|0}$=cj(c[c[(c[l>>2]|0)+32>>2]>>2]|0,d)|0;i=e;return $|0}function kk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a;e=b;f=ZGb(c[d>>2]|0,c[d+4>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0;e=F;d=0;if((e|0)>(d|0)|(e|0)==(d|0)&f>>>0>0>>>0){g=1;return g|0}((e|0)<0|0?-1:0)>>31|((e|0)<0|0?-1:0)<<1;f=e>>31|((e|0)<0|0?-1:0)<<1;if((f|0)!=0){g=f;return g|0}g=(c[a+16>>2]|0)-(c[b+16>>2]|0)|0;return g|0}function lk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a|0;g=c[f>>2]|0;j=c[g+44>>2]|0;k=c[c[g+16>>2]>>2]|0;l=j+8|0;h[l>>3]=1.0e-6;m=k+56|0;n=k+60|0;h[j+16>>3]=+(c[m>>2]|0)/+(c[n>>2]|0);h[j+24>>3]=+(c[k+48>>2]|0);c[a+20>>2]=c[k+20>>2];c[a+24>>2]=c[k+24>>2];k=j+4|0;j=OBb(d,c[k>>2]|0,160600,l,0,0,0,0,0,0,0)|0;if((j|0)<0){yDb(g,16,1894800,(o=i,i=i+8|0,c[o>>2]=c[k>>2],o)|0);i=o;p=j;i=b;return p|0}lFb(e,+h[d>>3],2147483647);d=c[e>>2]|0;j=c[e+4>>2]|0;if((d|0)<1|(j|0)<1){yDb(g,16,2351808,(o=i,i=i+16|0,c[o>>2]=d,c[o+8>>2]=j,o)|0);i=o;p=-22;i=b;return p|0}else{c[a+56>>2]=d;c[a+60>>2]=j;a=c[n>>2]|0;yDb(c[f>>2]|0,40,2331784,(o=i,i=i+32|0,c[o>>2]=c[m>>2],c[o+8>>2]=a,c[o+16>>2]=d,c[o+24>>2]=j,o)|0);i=o;p=0;i=b;return p|0}return 0}function mk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=c[a+8>>2]|0;f=c[c[e+32>>2]>>2]|0;g=a+56|0;h=f+56|0;j=g|0;k=c[j>>2]|0;l=a+60|0;a=c[l>>2]|0;m=h|0;n=c[m>>2]|0;o=f+60|0;p=c[o>>2]|0;q=gHb(p,(p|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;r=F;s=gHb(n,(n|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;do{if((q|0)==(s|0)&(r|0)==(F|0)){if(!((p|0)==0|(a|0)==0)){t=cj(f,b)|0;i=d;return t|0}if((k|0)==0|(n|0)==0){break}if((k>>31|0)!=(n>>31|0)){break}t=cj(f,b)|0;i=d;return t|0}}while(0);n=b+136|0;k=c[n>>2]|0;a=c[n+4>>2]|0;p=KDb(k,a,g,h)|0;h=F;c[n>>2]=p;c[n+4>>2]=h;n=c[l>>2]|0;l=c[m>>2]|0;m=c[o>>2]|0;yDb(e,48,2272920,(e=i,i=i+64|0,c[e>>2]=c[j>>2],c[e+8>>2]=n,c[e+16>>2]=k,c[e+24>>2]=a,c[e+32>>2]=l,c[e+40>>2]=m,c[e+48>>2]=p,c[e+56>>2]=h,e)|0);i=e;t=cj(f,b)|0;i=d;return t|0}function nk(a){a=a|0;var b=0;b=c[a+44>>2]|0;c[b+8>>2]=b;return 0}function ok(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=c[b+4>>2]|0;if((a|0)==0){d=b+12|0;e=d;JCb(e);return}else{f=a}while(1){a=c[f+4>>2]|0;JCb(f|0);ZDb(f);if((a|0)==0){break}else{f=a}}d=b+12|0;e=d;JCb(e);return}function pk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a|0;e=c[d>>2]|0;f=c[e+44>>2]|0;g=f+4|0;h=g;j=c[h>>2]|0;do{if((j|0)==0){k=Ni(c[c[e+16>>2]>>2]|0)|0;if((k|0)>=0){l=c[h>>2]|0;if((l|0)!=0){m=l;break}yDb(0,0,2005456,(l=i,i=i+24|0,c[l>>2]=1967872,c[l+8>>2]=1939528,c[l+16>>2]=240,l)|0);i=l;Cd();return 0}if(!((k|0)==-541478725)){n=k;i=b;return n|0}if((c[a+88>>2]|0)==0){n=-541478725;i=b;return n|0}n=qk(c[d>>2]|0)|0;i=b;return n|0}else{m=j}}while(0);if((c[a+88>>2]|0)!=0){n=qk(c[d>>2]|0)|0;i=b;return n|0}d=cj(a,c[m>>2]|0)|0;m=c[h>>2]|0;a=c[m+4>>2]|0;j=f+8|0;if((c[j>>2]|0)==(m|0)){c[j>>2]=f}$Db(g);c[h>>2]=a;n=d;i=b;return n|0}function qk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+8|0;d=b|0;e=c[c[a+32>>2]>>2]|0;f=c[a+44>>2]|0;g=f+4|0;h=g;j=c[h>>2]|0;do{if((j|0)==0){c[d>>2]=0;k=4}else{l=c[j>>2]|0;c[d>>2]=l;if((l|0)==0){k=4;break}m=f+12|0;if((c[f+12>>2]|0)!=0){n=m;k=7;break}o=e+88|0;if((c[l+76>>2]|0)<(c[o>>2]|0)){p=o;q=m;k=22;break}if((CFb(c[l+80>>2]|0)|0)==0){r=1;k=11}else{s=l+352|0;t=hBb(c[s>>2]|0,c[s+4>>2]|0)|0;if((t|0)>0){r=t;k=11}}if((k|0)==11){t=c[l+64>>2]|0;l=128;s=0;do{u=c[t+(s<<2)>>2]|0;v=128;while(1){if(((u|0)%(v|0)|0|0)==0){break}else{v=v>>1}}l=(v|0)<(l|0)?v:l;s=s+1|0;}while((s|0)<(r|0));if((l|0)<=31){p=o;q=m;k=22;break}}s=c[d>>2]|0;if((c[s+76>>2]|0)==(c[o>>2]|0)){t=c[h>>2]|0;u=c[t+4>>2]|0;w=f+8|0;if((c[w>>2]|0)==(t|0)){c[w>>2]=f}$Db(g);c[h>>2]=u;x=s;break}else{u=PCb(s)|0;if((u|0)==0){y=-12;i=b;return y|0}else{c[u+76>>2]=c[o>>2];rk(e,c[d>>2]|0,c[o>>2]|0);x=u;break}}}}while(0);do{if((k|0)==4){if((c[f+12>>2]|0)==0){y=-541478725;i=b;return y|0}else{n=f+12|0;k=7;break}}}while(0);if((k|0)==7){p=e+88|0;q=n;k=22}if((k|0)==22){n=e+40|0;r=hBb(c[n>>2]|0,c[n+4>>2]|0)|0;n=c[q>>2]|0;j=c[p>>2]|0;do{if((n|0)==0){u=fi(e,j)|0;c[q>>2]=u;if((u|0)==0){y=-12;i=b;return y|0}else{c[u+76>>2]=0;s=(c[d>>2]|0)+136|0;w=c[s+4>>2]|0;t=u+136|0;c[t>>2]=c[s>>2];c[t+4>>2]=w;w=c[p>>2]|0;c[f+16>>2]=w;z=u;A=w;break}}else{if((j|0)==(c[f+16>>2]|0)){z=n;A=j;break}yDb(a,16,1915304,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;y=-22;i=b;return y|0}}while(0);j=f+16|0;a:do{if((c[z+76>>2]|0)<(A|0)){n=a+16|0;p=e+52|0;w=f+8|0;u=f;t=A;while(1){s=c[h>>2]|0;if((s|0)==0){C=Ni(c[c[n>>2]>>2]|0)|0;if((C|0)==-541478725){k=31;break}if((C|0)<0){y=C;k=44;break}C=c[h>>2]|0;if((C|0)==0){k=35;break}D=C;E=c[j>>2]|0}else{D=s;E=t}s=c[D>>2]|0;c[d>>2]=s;C=c[q>>2]|0;F=c[C+76>>2]|0;G=E-F|0;H=s+76|0;I=c[H>>2]|0;J=(G|0)>(I|0)?I:G;IFb(c[C+64>>2]|0,c[s+64>>2]|0,F,0,J,r,c[p>>2]|0)|0;F=(c[q>>2]|0)+76|0;c[F>>2]=(c[F>>2]|0)+J;if((J|0)==(c[H>>2]|0)){JCb(d);H=c[h>>2]|0;F=c[H+4>>2]|0;if((c[w>>2]|0)==(H|0)){c[w>>2]=u}$Db(g);c[h>>2]=F}else{rk(e,s,J)}J=c[q>>2]|0;s=c[j>>2]|0;if((c[J+76>>2]|0)<(s|0)){t=s}else{K=J;break a}}if((k|0)==31){t=c[q>>2]|0;u=c[t+76>>2]|0;GFb(c[t+64>>2]|0,u,(c[j>>2]|0)-u|0,r,c[p>>2]|0)|0;u=c[q>>2]|0;c[u+76>>2]=c[j>>2];K=u;break}else if((k|0)==35){yDb(0,0,2005456,(B=i,i=i+24|0,c[B>>2]=1894712,c[B+8>>2]=1939528,c[B+16>>2]=204,B)|0);i=B;Cd();return 0}else if((k|0)==44){i=b;return y|0}}else{K=z}}while(0);c[q>>2]=0;x=K}y=cj(e,x)|0;i=b;return y|0}function rk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+8|0;f=e|0;g=a+40|0;h=hBb(c[g>>2]|0,c[g+4>>2]|0)|0;g=a+52|0;j=(CFb(c[g>>2]|0)|0)!=0;k=j?h:1;l=BFb(c[g>>2]|0)|0;g=ba(l,j?1:h)|0;h=b+76|0;j=c[h>>2]|0;if((j|0)<=(d|0)){yDb(0,0,2005456,(l=i,i=i+24|0,c[l>>2]=2351760,c[l+8>>2]=1939528,c[l+16>>2]=113,l)|0);i=l;Cd()}if((k|0)>0){l=ba(g,d)|0;m=b+64|0;n=0;while(1){o=(c[m>>2]|0)+(n<<2)|0;c[o>>2]=(c[o>>2]|0)+l;o=n+1|0;if((o|0)<(k|0)){n=o}else{p=m;break}}}else{p=b+64|0}m=c[p>>2]|0;if((b|0)==(m|0)){q=j}else{UGb(b|0,m|0,k>>>0>8>>>0?32:k<<2)|0;q=c[h>>2]|0}k=ba(g,d)|0;g=b+32|0;c[g>>2]=(c[g>>2]|0)-k;c[h>>2]=q-d;q=b+136|0;if((c[q>>2]|0)==0&(c[q+4>>2]|0)==(-2147483648|0)){i=e;return}c[f>>2]=1;c[f+4>>2]=c[a+48>>2];b=KDb(d,(d|0)<0|0?-1:0,f,a+56|0)|0;a=YGb(c[q>>2]|0,c[q+4>>2]|0,b,F)|0;c[q>>2]=a;c[q+4>>2]=F;i=e;return}function sk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=c[(c[a+8>>2]|0)+44>>2]|0;a=cEb(8)|0;f=b+8|0;c[(c[f>>2]|0)+4>>2]=a;a=c[(c[f>>2]|0)+4>>2]|0;if((a|0)==0){JCb(e);g=-12;i=d;return g|0}else{c[f>>2]=a;c[a>>2]=c[e>>2];g=0;i=d;return g|0}return 0}function tk(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;c[h>>2]=b;c[j>>2]=e;c[k>>2]=0;if((b|0)==(e|0)){l=b;i=g;return l|0}do{if((f|0)==0){if((c[b>>2]|0)==0){m=0;n=0;o=0;p=0;q=b;r=e;break}else{s=0;t=0;u=0;v=0;w=0;x=e;y=b}while(1){if((c[x>>2]|0)==0){z=s;A=t;B=u;C=v;D=x;E=y}else{F=s;G=t;H=u;I=v;J=0;K=c[(c[y+4>>2]|0)+(w<<2)>>2]|0;while(1){L=bFb(K)|0;M=bFb(c[(c[(c[j>>2]|0)+4>>2]|0)+(J<<2)>>2]|0)|0;N=a[L+7|0]|0;O=a[M+7|0]&N&128|H;P=(d[L+4|0]|0)>>>0>1>>>0;if(P){Q=(d[M+4|0]|0)>>>0>1>>>0|0}else{Q=0}M=Q|G;L=c[h>>2]|0;R=c[(c[L+4>>2]|0)+(w<<2)>>2]|0;S=c[j>>2]|0;if((R|0)==(c[(c[S+4>>2]|0)+(J<<2)>>2]|0)){T=N&128|I;U=P&1|F}else{T=I;U=F}P=J+1|0;if(P>>>0<(c[S>>2]|0)>>>0){F=U;G=M;H=O;I=T;J=P;K=R}else{z=U;A=M;B=O;C=T;D=S;E=L;break}}}K=w+1|0;if(K>>>0<(c[E>>2]|0)>>>0){s=z;t=A;u=B;v=C;w=K;x=D;y=E}else{m=C;n=B;o=A;p=z;q=E;r=D;break}}}else{m=0;n=0;o=0;p=0;q=b;r=e}}while(0);if((n|0)>(m|0)|(o|0)>(p|0)){l=0;i=g;return l|0}p=c[q>>2]|0;q=c[r>>2]|0;r=p>>>0>q>>>0?q:p;p=cEb(16)|0;q=p;c[k>>2]=q;a:do{if((p|0)==0){V=q}else{b:do{if((r|0)==0){W=q}else{o=WDb(r<<2)|0;c[(c[k>>2]|0)+4>>2]=o;do{if((o|0)!=0){m=c[h>>2]|0;n=m|0;e=c[n>>2]|0;if((e|0)==0){W=c[k>>2]|0;break b}b=c[j>>2]|0;D=b|0;E=m+4|0;z=c[k>>2]|0;A=z+4|0;B=c[D>>2]|0;C=0;y=0;x=B;w=e;e=B;c:while(1){if((x|0)==0){X=y;Y=0;Z=w;_=e}else{B=(c[E>>2]|0)+(C<<2)|0;v=c[b+4>>2]|0;u=0;t=y;s=x;T=e;while(1){U=c[B>>2]|0;if((U|0)==(c[v+(u<<2)>>2]|0)){Q=c[n>>2]|0;if(!(t>>>0<(Q>>>0>s>>>0?s:Q)>>>0)){$=23;break c}c[(c[A>>2]|0)+(t<<2)>>2]=U;aa=t+1|0;ba=c[D>>2]|0}else{aa=t;ba=T}U=u+1|0;if(U>>>0<ba>>>0){u=U;t=aa;s=ba;T=ba}else{break}}X=aa;Y=ba;Z=c[n>>2]|0;_=ba}T=C+1|0;if(T>>>0<Z>>>0){C=T;y=X;x=Y;w=Z;e=_}else{break}}if(($|0)==23){yDb(0,16,2262328,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;ZDb(c[(c[k>>2]|0)+4>>2]|0);ZDb(c[k>>2]|0);l=0;i=g;return l|0}c[z>>2]=X;if((X|0)==0){V=z;break a}e=XDb(c[z+12>>2]|0,(c[m+8>>2]|0)+(c[z+8>>2]|0)<<2)|0;if((e|0)==0){break}c[(c[k>>2]|0)+12>>2]=e;e=c[h>>2]|0;w=e+12|0;if((c[e+8>>2]|0)==0){ca=w;da=e}else{e=0;x=w;while(1){w=c[k>>2]|0;c[(c[w+12>>2]|0)+(c[w+8>>2]<<2)>>2]=c[(c[x>>2]|0)+(e<<2)>>2];w=c[k>>2]|0;y=w+8|0;C=c[y>>2]|0;c[y>>2]=C+1;c[c[(c[w+12>>2]|0)+(C<<2)>>2]>>2]=w;w=e+1|0;C=c[h>>2]|0;y=C+12|0;if(w>>>0<(c[C+8>>2]|0)>>>0){e=w;x=y}else{ca=y;da=C;break}}}$Db(ca);$Db(da+4|0);$Db(h);x=c[k>>2]|0;e=XDb(c[x+12>>2]|0,(c[(c[j>>2]|0)+8>>2]|0)+(c[x+8>>2]|0)<<2)|0;if((e|0)==0){break}c[(c[k>>2]|0)+12>>2]=e;e=c[j>>2]|0;x=e+12|0;if((c[e+8>>2]|0)==0){ea=x;fa=e}else{e=0;z=x;while(1){x=c[k>>2]|0;c[(c[x+12>>2]|0)+(c[x+8>>2]<<2)>>2]=c[(c[z>>2]|0)+(e<<2)>>2];x=c[k>>2]|0;m=x+8|0;C=c[m>>2]|0;c[m>>2]=C+1;c[c[(c[x+12>>2]|0)+(C<<2)>>2]>>2]=x;x=e+1|0;C=c[j>>2]|0;m=C+12|0;if(x>>>0<(c[C+8>>2]|0)>>>0){e=x;z=m}else{ea=m;fa=C;break}}}$Db(ea);$Db(fa+4|0);$Db(j);l=c[k>>2]|0;i=g;return l|0}}while(0);V=c[k>>2]|0;break a}}while(0);c[W>>2]=0;V=W}}while(0);if((V|0)!=0){$Db(V+12|0);$Db((c[k>>2]|0)+4|0)}$Db(k);l=0;i=g;return l|0}function uk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[e>>2]=a;c[f>>2]=b;c[g>>2]=0;if((a|0)==(b|0)){h=a;i=d;return h|0}j=c[a>>2]|0;a:do{if((j|0)==0){k=XDb(c[b+12>>2]|0,(c[a+8>>2]|0)+(c[b+8>>2]|0)<<2)|0;if((k|0)==0){l=36;break}c[(c[f>>2]|0)+12>>2]=k;k=c[e>>2]|0;m=k+12|0;if((c[k+8>>2]|0)==0){n=m}else{k=0;o=m;while(1){m=c[f>>2]|0;c[(c[m+12>>2]|0)+(c[m+8>>2]<<2)>>2]=c[(c[o>>2]|0)+(k<<2)>>2];m=c[f>>2]|0;p=m+8|0;q=c[p>>2]|0;c[p>>2]=q+1;c[c[(c[m+12>>2]|0)+(q<<2)>>2]>>2]=m;m=k+1|0;q=c[e>>2]|0;p=q+12|0;if(m>>>0<(c[q+8>>2]|0)>>>0){k=m;o=p}else{n=p;break}}}$Db(n);$Db((c[e>>2]|0)+4|0);$Db(e);o=c[f>>2]|0;c[g>>2]=o;h=o;i=d;return h|0}else{o=c[b>>2]|0;if((o|0)==0){k=XDb(c[a+12>>2]|0,(c[b+8>>2]|0)+(c[a+8>>2]|0)<<2)|0;if((k|0)==0){l=36;break}c[(c[e>>2]|0)+12>>2]=k;k=c[f>>2]|0;p=k+12|0;if((c[k+8>>2]|0)==0){r=p}else{k=0;m=p;while(1){p=c[e>>2]|0;c[(c[p+12>>2]|0)+(c[p+8>>2]<<2)>>2]=c[(c[m>>2]|0)+(k<<2)>>2];p=c[e>>2]|0;q=p+8|0;s=c[q>>2]|0;c[q>>2]=s+1;c[c[(c[p+12>>2]|0)+(s<<2)>>2]>>2]=p;p=k+1|0;s=c[f>>2]|0;q=s+12|0;if(p>>>0<(c[s+8>>2]|0)>>>0){k=p;m=q}else{r=q;break}}}$Db(r);$Db((c[f>>2]|0)+4|0);$Db(f);m=c[e>>2]|0;c[g>>2]=m;h=m;i=d;return h|0}m=j>>>0>o>>>0?o:j;k=cEb(16)|0;q=k;c[g>>2]=q;if((k|0)==0){t=q;break}do{if((m|0)==0){u=q}else{k=WDb(m<<2)|0;c[(c[g>>2]|0)+4>>2]=k;if((k|0)==0){l=36;break a}k=c[e>>2]|0;p=k|0;s=c[p>>2]|0;if((s|0)==0){u=c[g>>2]|0;break}v=c[f>>2]|0;w=v|0;x=k+4|0;k=c[g>>2]|0;y=k+4|0;z=c[w>>2]|0;A=0;B=0;C=z;D=s;s=z;b:while(1){if((C|0)==0){E=A;F=0;G=D;H=s}else{z=(c[x>>2]|0)+(B<<2)|0;I=c[v+4>>2]|0;J=A;K=0;L=C;M=s;while(1){N=c[z>>2]|0;if((N|0)==(c[I+(K<<2)>>2]|0)){O=c[p>>2]|0;if(!(J>>>0<(O>>>0>L>>>0?L:O)>>>0)){l=14;break b}c[(c[y>>2]|0)+(J<<2)>>2]=N;P=J+1|0;Q=c[w>>2]|0}else{P=J;Q=M}N=K+1|0;if(N>>>0<Q>>>0){J=P;K=N;L=Q;M=Q}else{break}}E=P;F=Q;G=c[p>>2]|0;H=Q}M=B+1|0;if(M>>>0<G>>>0){A=E;B=M;C=F;D=G;s=H}else{break}}if((l|0)==14){yDb(0,16,2262328,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;ZDb(c[(c[g>>2]|0)+4>>2]|0);ZDb(c[g>>2]|0);h=0;i=d;return h|0}c[k>>2]=E;if((E|0)==0){t=k;break a}s=XDb(c[k+12>>2]|0,(c[(c[e>>2]|0)+8>>2]|0)+(c[k+8>>2]|0)<<2)|0;if((s|0)==0){l=36;break a}c[(c[g>>2]|0)+12>>2]=s;s=c[e>>2]|0;D=s+12|0;if((c[s+8>>2]|0)==0){R=D}else{s=0;C=D;while(1){D=c[g>>2]|0;c[(c[D+12>>2]|0)+(c[D+8>>2]<<2)>>2]=c[(c[C>>2]|0)+(s<<2)>>2];D=c[g>>2]|0;B=D+8|0;A=c[B>>2]|0;c[B>>2]=A+1;c[c[(c[D+12>>2]|0)+(A<<2)>>2]>>2]=D;D=s+1|0;A=c[e>>2]|0;B=A+12|0;if(D>>>0<(c[A+8>>2]|0)>>>0){s=D;C=B}else{R=B;break}}}$Db(R);$Db((c[e>>2]|0)+4|0);$Db(e);C=c[g>>2]|0;s=XDb(c[C+12>>2]|0,(c[(c[f>>2]|0)+8>>2]|0)+(c[C+8>>2]|0)<<2)|0;if((s|0)==0){l=36;break a}c[(c[g>>2]|0)+12>>2]=s;s=c[f>>2]|0;C=s+12|0;if((c[s+8>>2]|0)==0){S=C}else{s=0;k=C;while(1){C=c[g>>2]|0;c[(c[C+12>>2]|0)+(c[C+8>>2]<<2)>>2]=c[(c[k>>2]|0)+(s<<2)>>2];C=c[g>>2]|0;B=C+8|0;D=c[B>>2]|0;c[B>>2]=D+1;c[c[(c[C+12>>2]|0)+(D<<2)>>2]>>2]=C;C=s+1|0;D=c[f>>2]|0;B=D+12|0;if(C>>>0<(c[D+8>>2]|0)>>>0){s=C;k=B}else{S=B;break}}}$Db(S);$Db((c[f>>2]|0)+4|0);$Db(f);h=c[g>>2]|0;i=d;return h|0}}while(0);c[u>>2]=0;t=u}}while(0);if((l|0)==36){t=c[g>>2]|0}if((t|0)!=0){$Db(t+12|0);$Db((c[g>>2]|0)+4|0)}$Db(g);h=0;i=d;return h|0}function vk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;c[f>>2]=b;c[g>>2]=d;c[h>>2]=0;j=(a[b+9|0]|0)+(a[b+8|0]|0)|0;k=(a[d+9|0]|0)+(a[d+8|0]|0)|0;if((d|0)==(b|0)){l=b;i=e;return l|0}if(j>>>0<k>>>0){c[g>>2]=b;c[f>>2]=d;m=k;n=j;o=b;p=d}else{m=j;n=k;o=d;p=b}do{if((m|0)==0){b=c[p+4>>2]|0;d=c[o+4>>2]|0;k=cEb(20)|0;j=k;c[h>>2]=j;if((k|0)==0){q=j;break}j=WDb(d+b<<3)|0;c[c[h>>2]>>2]=j;if((j|0)==0){r=54;break}j=c[f>>2]|0;b=c[j+4>>2]|0;d=(b|0)>0;do{if(d){k=c[g>>2]|0;s=k+4|0;t=c[h>>2]|0;u=k|0;k=c[j>>2]|0;v=0;w=0;while(1){x=k+(v<<3)|0;y=c[x>>2]|0;z=c[x+4>>2]|0;A=-1;do{if((z|0)>(A|0)|(z|0)==(A|0)&y>>>0>-1>>>0|(y&2147483647|0)==0&(z&0|0)==0){B=c[s>>2]|0;if((B|0)<=0){C=w;break}D=c[u>>2]|0;E=0;F=w;G=z;H=y;while(1){I=D+(E<<3)|0;if((H|0)==(c[I>>2]|0)&(G|0)==(c[I+4>>2]|0)){J=(c[t>>2]|0)+(F<<3)|0;c[J>>2]=H;c[J+4>>2]=G;c[I>>2]=0;c[I+4>>2]=0;c[x>>2]=0;c[x+4>>2]=0;K=F+1|0;L=0;M=0}else{K=F;L=G;M=H}I=E+1|0;if((I|0)<(B|0)){E=I;F=K;G=L;H=M}else{C=K;break}}}else{C=w}}while(0);x=v+1|0;if((x|0)<(b|0)){v=x;w=C}else{break}}if(d){N=0;O=C;P=j}else{Q=C;R=j;break}while(1){w=(c[P>>2]|0)+(N<<3)|0;v=c[w>>2]|0;t=c[w+4>>2]|0;do{if((v|0)==0&(t|0)==0){S=O;T=P}else{w=-1;if(!((t|0)>(w|0)|(t|0)==(w|0)&v>>>0>-1>>>0|(v&2147483647|0)==0&(t&0|0)==0)){S=O;T=P;break}w=hBb(v,t)|0;u=w|0;s=((w|0)<0|0?-1:0)|-2147483648;w=c[g>>2]|0;k=c[w+4>>2]|0;x=c[f>>2]|0;if((k|0)<=0){S=O;T=x;break}y=x|0;z=c[h>>2]|0;A=c[w>>2]|0;w=0;H=O;while(1){G=A+(w<<3)|0;if((c[G>>2]|0)==(u|0)&(c[G+4>>2]|0)==(s|0)){G=(c[y>>2]|0)+(N<<3)|0;F=c[G+4>>2]|0;E=(c[z>>2]|0)+(H<<3)|0;c[E>>2]=c[G>>2];c[E+4>>2]=F;U=H+1|0}else{U=H}F=w+1|0;if((F|0)<(k|0)){w=F;H=U}else{S=U;T=x;break}}}}while(0);t=N+1|0;if((t|0)<(c[T+4>>2]|0)){N=t;O=S;P=T}else{Q=S;R=T;break}}}else{Q=0;R=j}}while(0);j=c[g>>2]|0;c[g>>2]=R;c[f>>2]=j;d=c[j+4>>2]|0;if((d|0)>0){b=0;t=Q;v=j;x=R;while(1){H=(c[v>>2]|0)+(b<<3)|0;w=c[H>>2]|0;k=c[H+4>>2]|0;do{if((w|0)==0&(k|0)==0){V=t;W=v;X=x}else{H=-1;if(!((k|0)>(H|0)|(k|0)==(H|0)&w>>>0>-1>>>0|(w&2147483647|0)==0&(k&0|0)==0)){V=t;W=v;X=x;break}H=hBb(w,k)|0;z=H|0;y=((H|0)<0|0?-1:0)|-2147483648;H=c[g>>2]|0;s=c[H+4>>2]|0;u=c[f>>2]|0;if((s|0)<=0){V=t;W=u;X=H;break}A=u|0;F=c[h>>2]|0;E=c[H>>2]|0;G=0;B=t;while(1){D=E+(G<<3)|0;if((c[D>>2]|0)==(z|0)&(c[D+4>>2]|0)==(y|0)){D=(c[A>>2]|0)+(b<<3)|0;I=c[D+4>>2]|0;J=(c[F>>2]|0)+(B<<3)|0;c[J>>2]=c[D>>2];c[J+4>>2]=I;Y=B+1|0}else{Y=B}I=G+1|0;if((I|0)<(s|0)){G=I;B=Y}else{V=Y;W=u;X=H;break}}}}while(0);k=b+1|0;w=c[W+4>>2]|0;if((k|0)<(w|0)){b=k;t=V;v=W;x=X}else{Z=V;_=W;$=X;aa=w;break}}}else{Z=Q;_=j;$=R;aa=d}c[g>>2]=_;c[f>>2]=$;x=c[$+4>>2]|0;if((x|0)>0){v=c[h>>2]|0;t=v|0;b=c[$>>2]|0;w=0;k=Z;while(1){H=b+(w<<3)|0;u=c[H>>2]|0;B=c[H+4>>2]|0;G=0;a:do{if(((u&2147483647|0)!=0|(B&0|0)!=0)&((B|0)<(G|0)|(B|0)==(G|0)&u>>>0<0>>>0)&(aa|0)>0){s=c[_>>2]|0;F=0;A=k;y=B;z=u;while(1){E=s+(F<<3)|0;if((z|0)==(c[E>>2]|0)&(y|0)==(c[E+4>>2]|0)){E=(c[t>>2]|0)+(A<<3)|0;c[E>>2]=z;c[E+4>>2]=y;ba=A+1|0}else{ba=A}E=F+1|0;if((E|0)>=(aa|0)){ca=ba;break a}F=E;A=ba;y=c[H+4>>2]|0;z=c[H>>2]|0}}else{ca=k}}while(0);H=w+1|0;if((H|0)<(x|0)){w=H;k=ca}else{da=ca;ea=v;break}}}else{da=Z;ea=c[h>>2]|0}c[ea+4>>2]=da;if((da|0)==0){q=ea;break}v=XDb(c[ea+16>>2]|0,(c[$+12>>2]|0)+(c[ea+12>>2]|0)<<2)|0;if((v|0)==0){r=54;break}c[(c[h>>2]|0)+16>>2]=v;v=c[f>>2]|0;k=v+16|0;if((c[v+12>>2]|0)==0){fa=k}else{v=0;w=k;while(1){k=c[h>>2]|0;c[(c[k+16>>2]|0)+(c[k+12>>2]<<2)>>2]=c[(c[w>>2]|0)+(v<<2)>>2];k=c[h>>2]|0;x=k+12|0;t=c[x>>2]|0;c[x>>2]=t+1;c[c[(c[k+16>>2]|0)+(t<<2)>>2]>>2]=k;k=v+1|0;t=c[f>>2]|0;x=t+16|0;if(k>>>0<(c[t+12>>2]|0)>>>0){v=k;w=x}else{fa=x;break}}}$Db(fa);$Db(c[f>>2]|0);$Db(f);w=c[h>>2]|0;v=XDb(c[w+16>>2]|0,(c[(c[g>>2]|0)+12>>2]|0)+(c[w+12>>2]|0)<<2)|0;if((v|0)==0){r=54;break}c[(c[h>>2]|0)+16>>2]=v;v=c[g>>2]|0;w=v+16|0;if((c[v+12>>2]|0)==0){ga=w;ha=v}else{v=0;x=w;while(1){w=c[h>>2]|0;c[(c[w+16>>2]|0)+(c[w+12>>2]<<2)>>2]=c[(c[x>>2]|0)+(v<<2)>>2];w=c[h>>2]|0;k=w+12|0;t=c[k>>2]|0;c[k>>2]=t+1;c[c[(c[w+16>>2]|0)+(t<<2)>>2]>>2]=w;w=v+1|0;t=c[g>>2]|0;k=t+16|0;if(w>>>0<(c[t+12>>2]|0)>>>0){v=w;x=k}else{ga=k;ha=t;break}}}$Db(ga);$Db(ha);$Db(g);l=c[h>>2]|0;i=e;return l|0}else if((m|0)==1){if((n|0)!=0){r=13;break}x=o+4|0;v=c[x>>2]|0;if((v|0)<=0){l=0;i=e;return l|0}t=c[o>>2]|0;k=0;w=0;while(1){b=t+(w<<3)|0;d=c[b>>2]|0;j=c[b+4>>2]|0;b=-1;if((j|0)>(b|0)|(j|0)==(b|0)&d>>>0>-1>>>0|(d&2147483647|0)==0&(j&0|0)==0){b=t+(k<<3)|0;c[b>>2]=d;c[b+4>>2]=j;ia=k+1|0}else{ia=k}j=w+1|0;if((j|0)<(v|0)){k=ia;w=j}else{break}}if((ia|0)==0){l=0;i=e;return l|0}else{c[x>>2]=ia;r=13;break}}else{r=13}}while(0);do{if((r|0)==13){ia=XDb(c[o+16>>2]|0,(c[p+12>>2]|0)+(c[o+12>>2]|0)<<2)|0;if((ia|0)==0){r=54;break}c[(c[g>>2]|0)+16>>2]=ia;ia=c[f>>2]|0;n=ia+16|0;if((c[ia+12>>2]|0)==0){ja=n}else{ia=0;m=n;while(1){n=c[g>>2]|0;c[(c[n+16>>2]|0)+(c[n+12>>2]<<2)>>2]=c[(c[m>>2]|0)+(ia<<2)>>2];n=c[g>>2]|0;ha=n+12|0;ga=c[ha>>2]|0;c[ha>>2]=ga+1;c[c[(c[n+16>>2]|0)+(ga<<2)>>2]>>2]=n;n=ia+1|0;ga=c[f>>2]|0;ha=ga+16|0;if(n>>>0<(c[ga+12>>2]|0)>>>0){ia=n;m=ha}else{ja=ha;break}}}$Db(ja);$Db(c[f>>2]|0);$Db(f);l=c[g>>2]|0;i=e;return l|0}}while(0);if((r|0)==54){q=c[h>>2]|0}if((q|0)!=0){$Db(q+16|0);$Db(c[h>>2]|0)}$Db(h);l=0;i=e;return l|0}function wk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=b;while(1){b=c[d>>2]|0;if((b|0)==-1){e=0;f=4;break}if((b|0)==(a|0)){e=1;f=4;break}else{d=d+4|0}}if((f|0)==4){return e|0}return 0}function xk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((a|0)==0){b=0}else{d=0;while(1){if((c[a+(d<<2)>>2]|0)==-1){b=d;break}else{d=d+1|0}}}d=cEb(16)|0;e=d;if((d|0)==0){f=0;return f|0}c[d>>2]=b;if((b|0)==0){f=e;return f|0}g=WDb(b<<2)|0;c[d+4>>2]=g;if((g|0)==0){ZDb(d);f=0;return f|0}if((b|0)==0){f=e;return f|0}g=c[d+4>>2]|0;d=b;while(1){b=d-1|0;c[g+(b<<2)>>2]=c[a+(b<<2)>>2];if((b|0)==0){f=e;break}else{d=b}}return f|0}function yk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((a|0)==0){b=0}else{d=0;while(1){e=a+(d<<3)|0;if((c[e>>2]|0)==(-1|0)&(c[e+4>>2]|0)==(-1|0)){b=d;break}else{d=d+1|0}}}d=cEb(20)|0;e=d;if((d|0)==0){f=0;return f|0}c[d+4>>2]=b;if((b|0)==0){f=e;return f|0}g=b<<3;b=WDb(g)|0;c[d>>2]=b;if((b|0)==0){ZDb(d);f=0;return f|0}else{UGb(b|0,a|0,g)|0;f=e;return f|0}return 0}function zk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;d=c[a>>2]|0;do{if((d|0)==0){e=cEb(16)|0;f=e;c[a>>2]=f;if((e|0)==0){g=-12}else{h=f;break}return g|0}else{h=d}}while(0);d=XDb(c[h+4>>2]|0,(c[h>>2]<<2)+4|0)|0;if((d|0)==0){g=-12;return g|0}c[(c[a>>2]|0)+4>>2]=d;d=c[a>>2]|0;a=d|0;h=c[a>>2]|0;c[a>>2]=h+1;c[(c[d+4>>2]|0)+(h<<2)>>2]=b;g=0;return g|0}function Ak(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[a>>2]|0;do{if((e|0)==0){f=cEb(20)|0;g=f;c[a>>2]=g;if((f|0)==0){h=-12}else{i=g;break}return h|0}else{i=e}}while(0);e=XDb(c[i>>2]|0,(c[i+4>>2]<<3)+8|0)|0;if((e|0)==0){h=-12;return h|0}c[c[a>>2]>>2]=e;e=c[a>>2]|0;a=e+4|0;i=c[a>>2]|0;c[a>>2]=i+1;a=(c[e>>2]|0)+(i<<3)|0;c[a>>2]=b;c[a+4>>2]=d;h=0;return h|0}function Bk(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((b|0)==0){d=0;e=0;while(1){do{if((a[(bFb(e)|0)+7|0]&8)==0){if((d|0)==0){f=cEb(16)|0;g=f;if((f|0)==0){h=g;break}else{i=g}}else{i=d}g=i+4|0;f=i|0;j=XDb(c[g>>2]|0,(c[f>>2]<<2)+4|0)|0;if((j|0)==0){h=i;break}k=j;c[g>>2]=k;g=c[f>>2]|0;c[f>>2]=g+1;c[k+(g<<2)>>2]=e;h=i}else{h=d}}while(0);g=e+1|0;if((g|0)<333){d=h;e=g}else{l=h;break}}return l|0}h=(b|0)==1;b=h?10:0;if(h){m=0;n=0}else{l=0;return l|0}while(1){bFb(n)|0;if((m|0)==0){h=cEb(16)|0;e=h;if((h|0)==0){o=e}else{p=e;q=11}}else{p=m;q=11}do{if((q|0)==11){q=0;e=p+4|0;h=p|0;d=XDb(c[e>>2]|0,(c[h>>2]<<2)+4|0)|0;if((d|0)==0){o=p;break}i=d;c[e>>2]=i;e=c[h>>2]|0;c[h>>2]=e+1;c[i+(e<<2)>>2]=n;o=p}}while(0);e=n+1|0;if((e|0)<(b|0)){m=o;n=e}else{l=o;break}}return l|0}function Ck(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=0;b=0;while(1){do{if((CFb(b)|0)==0){d=a}else{if((a|0)==0){e=cEb(16)|0;f=e;if((e|0)==0){d=f;break}else{g=f}}else{g=a}f=g+4|0;e=g|0;h=XDb(c[f>>2]|0,(c[e>>2]<<2)+4|0)|0;if((h|0)==0){d=g;break}i=h;c[f>>2]=i;f=c[e>>2]|0;c[e>>2]=f+1;c[i+(f<<2)>>2]=b;d=g}}while(0);f=b+1|0;if((f|0)<10){a=d;b=f}else{break}}return d|0}function Dk(){return cEb(16)|0}function Ek(){var b=0,c=0;b=cEb(20)|0;if((b|0)==0){c=0;return c|0}a[b+8|0]=1;c=b;return c|0}function Fk(){var b=0,c=0;b=cEb(20)|0;if((b|0)==0){c=0;return c|0}a[b+9|0]=1;a[b+8|0]=1;c=b;return c|0}function Gk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[b>>2]=a;d=a+16|0;e=c[d>>2]|0;f=a+12|0;a=(c[f>>2]|0)+1|0;c[f>>2]=a;g=XDb(e,a<<2)|0;c[d>>2]=g;c[g+((c[f>>2]|0)-1<<2)>>2]=b;return}function Hk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[b>>2]=a;d=a+12|0;e=c[d>>2]|0;f=a+8|0;a=(c[f>>2]|0)+1|0;c[f>>2]=a;g=XDb(e,a<<2)|0;c[d>>2]=g;c[g+((c[f>>2]|0)-1<<2)>>2]=b;return}function Ik(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a>>2]|0;if((b|0)==0){return}d=c[b+8>>2]|0;e=b+12|0;f=0;while(1){if(!(f>>>0<d>>>0)){g=b;h=d;break}i=c[e>>2]|0;j=i+(f<<2)|0;k=f+1|0;if((c[j>>2]|0)==(a|0)){l=5;break}else{f=k}}do{if((l|0)==5){if(!((f|0)>-1)){g=b;h=d;break}VGb(j|0,i+(k<<2)|0,(d-f<<2)-4|0)|0;e=c[a>>2]|0;g=e;h=c[e+8>>2]|0}}while(0);f=h-1|0;c[g+8>>2]=f;if((f|0)==0){ZDb(c[g+4>>2]|0);ZDb(c[(c[a>>2]|0)+12>>2]|0);ZDb(c[a>>2]|0)}c[a>>2]=0;return}function Jk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a>>2]|0;if((b|0)==0){return}d=c[b+12>>2]|0;e=b+16|0;f=0;while(1){if(!(f>>>0<d>>>0)){g=b;h=d;break}i=c[e>>2]|0;j=i+(f<<2)|0;k=f+1|0;if((c[j>>2]|0)==(a|0)){l=5;break}else{f=k}}do{if((l|0)==5){if(!((f|0)>-1)){g=b;h=d;break}VGb(j|0,i+(k<<2)|0,(d-f<<2)-4|0)|0;e=c[a>>2]|0;g=e;h=c[e+12>>2]|0}}while(0);f=h-1|0;c[g+12>>2]=f;if((f|0)==0){ZDb(c[g>>2]|0);ZDb(c[(c[a>>2]|0)+16>>2]|0);ZDb(c[a>>2]|0)}c[a>>2]=0;return}function Kk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a>>2]|0;e=c[d+12>>2]|0;f=d+16|0;d=0;while(1){if(!(d>>>0<e>>>0)){g=6;break}h=(c[f>>2]|0)+(d<<2)|0;if((c[h>>2]|0)==(a|0)){break}else{d=d+1|0}}if((g|0)==6){return}if(!((d|0)>-1)){return}c[h>>2]=b;c[b>>2]=c[a>>2];c[a>>2]=0;return}function Lk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a>>2]|0;e=c[d+8>>2]|0;f=d+12|0;d=0;while(1){if(!(d>>>0<e>>>0)){g=6;break}h=(c[f>>2]|0)+(d<<2)|0;if((c[h>>2]|0)==(a|0)){break}else{d=d+1|0}}if((g|0)==6){return}if(!((d|0)>-1)){return}c[h>>2]=b;c[b>>2]=c[a>>2];c[a>>2]=0;return}function Mk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=a+24|0;f=c[b>>2]|0;if((f|0)==0){g=0}else{h=a+16|0;j=0;k=0;l=f;while(1){f=c[(c[h>>2]|0)+(k<<2)>>2]|0;do{if((f|0)==0){m=j;n=l}else{o=f+84|0;if((c[o>>2]|0)!=0){m=j;n=l;break}p=c[e>>2]|0;c[o>>2]=p;q=p+16|0;r=c[q>>2]|0;s=p+12|0;p=(c[s>>2]|0)+1|0;c[s>>2]=p;t=XDb(r,p<<2)|0;c[q>>2]=t;c[t+((c[s>>2]|0)-1<<2)>>2]=o;m=j+1|0;n=c[b>>2]|0}}while(0);f=k+1|0;if(f>>>0<n>>>0){j=m;k=f;l=n}else{g=m;break}}}m=a+40|0;n=c[m>>2]|0;if((n|0)==0){u=g}else{l=a+32|0;a=g;g=0;k=n;while(1){n=c[(c[l>>2]|0)+(g<<2)>>2]|0;do{if((n|0)==0){v=a;w=k}else{j=n+80|0;if((c[j>>2]|0)!=0){v=a;w=k;break}b=c[e>>2]|0;c[j>>2]=b;h=b+16|0;f=c[h>>2]|0;o=b+12|0;b=(c[o>>2]|0)+1|0;c[o>>2]=b;s=XDb(f,b<<2)|0;c[h>>2]=s;c[s+((c[o>>2]|0)-1<<2)>>2]=j;v=a+1|0;w=c[m>>2]|0}}while(0);n=g+1|0;if(n>>>0<w>>>0){a=v;g=n;k=w}else{u=v;break}}}if((u|0)!=0){i=d;return}u=c[e>>2]|0;$Db(u);$Db(u+16|0);$Db(e);i=d;return}function Nk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=a+24|0;f=c[b>>2]|0;if((f|0)==0){g=0}else{h=a+16|0;j=0;k=0;l=f;while(1){f=c[(c[h>>2]|0)+(k<<2)>>2]|0;do{if((f|0)==0){m=j;n=l}else{o=f+76|0;if((c[o>>2]|0)!=0){m=j;n=l;break}p=c[e>>2]|0;c[o>>2]=p;q=p+12|0;r=c[q>>2]|0;s=p+8|0;p=(c[s>>2]|0)+1|0;c[s>>2]=p;t=XDb(r,p<<2)|0;c[q>>2]=t;c[t+((c[s>>2]|0)-1<<2)>>2]=o;m=j+1|0;n=c[b>>2]|0}}while(0);f=k+1|0;if(f>>>0<n>>>0){j=m;k=f;l=n}else{g=m;break}}}m=a+40|0;n=c[m>>2]|0;if((n|0)==0){u=g}else{l=a+32|0;a=g;g=0;k=n;while(1){n=c[(c[l>>2]|0)+(g<<2)>>2]|0;do{if((n|0)==0){v=a;w=k}else{j=n+72|0;if((c[j>>2]|0)!=0){v=a;w=k;break}b=c[e>>2]|0;c[j>>2]=b;h=b+12|0;f=c[h>>2]|0;o=b+8|0;b=(c[o>>2]|0)+1|0;c[o>>2]=b;s=XDb(f,b<<2)|0;c[h>>2]=s;c[s+((c[o>>2]|0)-1<<2)>>2]=j;v=a+1|0;w=c[m>>2]|0}}while(0);n=g+1|0;if(n>>>0<w>>>0){a=v;g=n;k=w}else{u=v;break}}}if((u|0)!=0){i=d;return}u=c[e>>2]|0;$Db(u+4|0);$Db(u+12|0);$Db(e);i=d;return}function Ok(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=a+24|0;f=c[b>>2]|0;if((f|0)==0){g=0}else{h=a+16|0;j=0;k=0;l=f;while(1){f=c[(c[h>>2]|0)+(k<<2)>>2]|0;do{if((f|0)==0){m=j;n=l}else{o=f+68|0;if((c[o>>2]|0)!=0){m=j;n=l;break}p=c[e>>2]|0;c[o>>2]=p;q=p+12|0;r=c[q>>2]|0;s=p+8|0;p=(c[s>>2]|0)+1|0;c[s>>2]=p;t=XDb(r,p<<2)|0;c[q>>2]=t;c[t+((c[s>>2]|0)-1<<2)>>2]=o;m=j+1|0;n=c[b>>2]|0}}while(0);f=k+1|0;if(f>>>0<n>>>0){j=m;k=f;l=n}else{g=m;break}}}m=a+40|0;n=c[m>>2]|0;if((n|0)==0){u=g}else{l=a+32|0;a=g;g=0;k=n;while(1){n=c[(c[l>>2]|0)+(g<<2)>>2]|0;do{if((n|0)==0){v=a;w=k}else{j=n+64|0;if((c[j>>2]|0)!=0){v=a;w=k;break}b=c[e>>2]|0;c[j>>2]=b;h=b+12|0;f=c[h>>2]|0;o=b+8|0;b=(c[o>>2]|0)+1|0;c[o>>2]=b;s=XDb(f,b<<2)|0;c[h>>2]=s;c[s+((c[o>>2]|0)-1<<2)>>2]=j;v=a+1|0;w=c[m>>2]|0}}while(0);n=g+1|0;if(n>>>0<w>>>0){a=v;g=n;k=w}else{u=v;break}}}if((u|0)!=0){i=d;return}u=c[e>>2]|0;$Db(u+4|0);$Db(u+12|0);$Db(e);i=d;return}function Pk(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[b+16>>2]|0;do{if((d|0)==0){e=4}else{f=c[d>>2]|0;if((f|0)==0){e=4;break}g=c[f+16>>2]|0}}while(0);do{if((e|0)==4){d=c[b+32>>2]|0;if((d|0)==0){g=0;break}f=c[d>>2]|0;if((f|0)==0){g=0;break}g=c[f+16>>2]|0}}while(0);Ok(b,Bk(g)|0);if((g|0)!=1){return 0}g=cEb(20)|0;if((g|0)==0){h=0}else{a[g+8|0]=1;h=g}Mk(b,h);Nk(b,cEb(16)|0);return 0}function Qk(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[b+16>>2]|0;do{if((d|0)==0){e=4}else{f=c[d>>2]|0;if((f|0)==0){e=4;break}g=c[f+16>>2]|0}}while(0);do{if((e|0)==4){d=c[b+32>>2]|0;if((d|0)==0){g=0;break}f=c[d>>2]|0;if((f|0)==0){g=0;break}g=c[f+16>>2]|0}}while(0);Ok(b,Bk(g)|0);if((g|0)!=1){return 0}g=cEb(20)|0;if((g|0)==0){h=0}else{a[g+9|0]=1;a[g+8|0]=1;h=g}Mk(b,h);Nk(b,cEb(16)|0);return 0}function Rk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+8|0;g=f|0;h=_Eb(d)|0;do{if((h|0)==-1){j=kb(d|0,g|0,0)|0;if(!((a[c[g>>2]|0]|0)!=0|j>>>0>332>>>0)){k=j;break}yDb(e,16,2321400,(j=i,i=i+8|0,c[j>>2]=d,j)|0);i=j;l=-22;i=f;return l|0}else{k=h}}while(0);c[b>>2]=k;l=0;i=f;return l|0}function Sk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+8|0;g=f|0;h=xFb(d)|0;do{if((h|0)==-1){j=kb(d|0,g|0,0)|0;if(!((a[c[g>>2]|0]|0)!=0|j>>>0>9>>>0)){k=j;break}yDb(e,16,2185696,(j=i,i=i+8|0,c[j>>2]=d,j)|0);i=j;l=-22;i=f;return l|0}else{k=h}}while(0);c[b>>2]=k;l=0;i=f;return l|0}function Tk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0;f=i;i=i+8|0;g=f|0;h=+HBb(d,g);do{if(!((a[c[g>>2]|0]|0)!=0|h<1.0)){j=~~h;if(+(j|0)!=h|h>2147483647.0){break}c[b>>2]=j;k=0;i=f;return k|0}}while(0);yDb(e,16,2050848,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;k=-22;i=f;return k|0}function Uk(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+8|0;h=g|0;j=(d|0)!=0;do{if(j){k=kb(e|0,h|0,10)|0;l=c[h>>2]|0;if((a[l]|0)!=99){break}if((a[l+1|0]|0)!=0){break}if(!((k-1|0)>>>0<62>>>0)){break}c[d>>2]=k;c[b>>2]=0;c[b+4>>2]=0;m=0;i=g;return m|0}}while(0);k=fBb(e)|0;l=F;do{if((k|0)==0&(l|0)==0){n=kb(e|0,h|0,10)|0;if((a[c[h>>2]|0]|0)==0){if((n|0)!=0){o=(n|0)<0|0?-1:0;p=n;break}}yDb(f,16,2005320,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;m=-22;i=g;return m|0}else{o=l;p=k}}while(0);c[b>>2]=p;c[b+4>>2]=o;if(!j){m=0;i=g;return m|0}c[d>>2]=hBb(p,o)|0;m=0;i=g;return m|0}function Vk(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;if((b|0)==0){return}d=a;e=b;while(1){b=c[e+12>>2]|0;$Db(e);$Db(d);c[a>>2]=b;if((b|0)==0){break}else{e=b}}return}function Wk(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+40|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;c[h>>2]=d;c[j>>2]=0;c[k>>2]=0;c[l>>2]=0;c[h>>2]=d+(qd(d|0,2252784)|0);d=Xk(h,b)|0;a:do{if((d|0)<0){n=d}else{o=c[h>>2]|0;c[h>>2]=o+(qd(o|0,2252784)|0);o=b;p=Yk(h,j,l,o)|0;if((p|0)<0){n=p;break}else{q=0}while(1){p=Zk(m,h,b,q,o)|0;if((p|0)<0){n=p;break a}p=_k(c[m>>2]|0,j,k,o)|0;if((p|0)<0){n=p;break a}p=$k(h,j,k,l,o)|0;if((p|0)<0){n=p;break a}p=c[h>>2]|0;r=qd(p|0,2252784)|0;c[h>>2]=p+(r+1);s=a[p+r|0]|0;do{if(s<<24>>24==59){r=c[j>>2]|0;if((r|0)==0){t=q+1|0;break}p=l;u=c[l>>2]|0;while(1){if((u|0)==0){v=12;break}w=u+12|0;x=c[w>>2]|0;if((x|0)==0){v=13;break}else{p=w;u=x}}if((v|0)==12){v=0;c[p>>2]=r}else if((v|0)==13){v=0;c[w>>2]=r}c[j>>2]=0;v=15}else{v=15}}while(0);if((v|0)==15){v=0;u=q+1|0;if((s<<24>>24|0)==0){break}else if((s<<24>>24|0)==59|(s<<24>>24|0)==44){t=u}else{v=17;break}}u=c[h>>2]|0;c[h>>2]=u+(qd(u|0,2252784)|0);u=Yk(h,j,l,o)|0;if((u|0)<0){n=u;break a}else{q=t}}if((v|0)==17){yDb(o,16,2320528,(u=i,i=i+8|0,c[u>>2]=(c[h>>2]|0)-1,u)|0);i=u;n=-22;break}u=l;x=c[l>>2]|0;while(1){if((x|0)==0){v=22;break}y=x+12|0;z=c[y>>2]|0;if((z|0)==0){v=23;break}else{u=y;x=z}}if((v|0)==22){c[u>>2]=c[j>>2]}else if((v|0)==23){c[y>>2]=c[j>>2]}c[j>>2]=0;c[e>>2]=c[k>>2];A=0;B=c[l>>2]|0;c[f>>2]=B;i=g;return A|0}}while(0);y=b+20|0;v=b+8|0;if((c[y>>2]|0)!=0){do{Xi(c[c[v>>2]>>2]|0);}while((c[y>>2]|0)!=0)}$Db(v);v=c[k>>2]|0;if((v|0)!=0){y=k;b=v;while(1){v=c[b+12>>2]|0;$Db(b);$Db(y);c[k>>2]=v;if((v|0)==0){break}else{b=v}}}b=c[l>>2]|0;if((b|0)!=0){k=l;y=b;while(1){b=c[y+12>>2]|0;$Db(y);$Db(k);c[l>>2]=b;if((b|0)==0){break}else{y=b}}}y=c[j>>2]|0;if((y|0)!=0){l=j;k=y;while(1){y=c[k+12>>2]|0;$Db(k);$Db(l);c[j>>2]=y;if((y|0)==0){break}else{k=y}}}c[e>>2]=0;A=n;B=0;c[f>>2]=B;i=g;return A|0}function Xk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[a>>2]|0;f=Vb(e|0,59)|0;if((RGb(e,2175504,10)|0)!=0){g=0;i=d;return g|0}if((f|0)==0){yDb(b,16,2165160,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-22;i=d;return g|0}c[a>>2]=e+4;e=b+12|0;$Db(e);b=f+1|0;h=cEb(b-(c[a>>2]|0)|0)|0;c[e>>2]=h;if((h|0)==0){g=-12;i=d;return g|0}e=c[a>>2]|0;sAb(h,e,b-e|0)|0;c[a>>2]=f+1;g=0;i=d;return g|0}function Yk(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+16|0;h=g|0;j=g+8|0;c[j>>2]=0;k=c[b>>2]|0;do{if((a[k]|0)==91){l=h;m=0;n=k;while(1){c[b>>2]=n+1;o=wAb(b,1939184)|0;c[h>>2]=o;do{if((a[o]|0)==0){yDb(f,16,1914912,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;q=7}else{r=c[b>>2]|0;c[b>>2]=r+1;if((a[r]|0)==93){s=o;break}yDb(f,16,1894448,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;q=7}}while(0);if((q|0)==7){q=0;$Db(l);s=c[h>>2]|0}if((s|0)==0){t=-22;q=31;break}o=c[e>>2]|0;a:do{if((o|0)==0){q=15}else{r=e;u=o;while(1){v=c[u>>2]|0;if((v|0)!=0){if((QGb(v,s)|0)==0){break}}v=u+12|0;w=c[v>>2]|0;if((w|0)==0){q=15;break a}else{r=v;u=w}}if((u|0)==0){q=15;break}w=u+12|0;c[r>>2]=c[w>>2];c[w>>2]=0;ZDb(s);x=u}}while(0);if((q|0)==15){q=0;o=cEb(16)|0;if((o|0)==0){q=16;break}c[o>>2]=s;c[o+8>>2]=m;x=o}o=j;w=c[j>>2]|0;while(1){if((w|0)==0){q=21;break}y=w+12|0;v=c[y>>2]|0;if((v|0)==0){q=22;break}else{o=y;w=v}}if((q|0)==21){q=0;c[o>>2]=x}else if((q|0)==22){q=0;c[y>>2]=x}w=c[b>>2]|0;v=w+(qd(w|0,2252784)|0)|0;c[b>>2]=v;z=m+1|0;if((a[v]|0)==91){m=z;n=v}else{q=24;break}}if((q|0)==16){ZDb(s);t=-12;i=g;return t|0}else if((q|0)==24){A=z;B=c[j>>2]|0;break}else if((q|0)==31){i=g;return t|0}}else{A=0;B=0}}while(0);z=j;s=B;while(1){if((s|0)==0){q=28;break}C=s+12|0;B=c[C>>2]|0;if((B|0)==0){q=29;break}else{z=C;s=B}}if((q|0)==28){c[z>>2]=c[d>>2]}else if((q|0)==29){c[C>>2]=c[d>>2]}c[d>>2]=c[j>>2];t=A;i=g;return t|0}function Zk(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+32|0;j=wAb(d,2331520)|0;k=c[d>>2]|0;if((a[k]|0)==61){c[d>>2]=k+1;l=wAb(d,2307104)|0}else{l=0}d=h|0;Lb(d|0,30,2288872,(k=i,i=i+16|0,c[k>>2]=j,c[k+8>>2]=f,k)|0)|0;i=k;f=Ri(j)|0;if((f|0)==0){yDb(g,16,2272584,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;m=-22;ZDb(j);ZDb(l);i=h;return m|0}n=mj(e,f,d)|0;c[b>>2]=n;if((n|0)==0){yDb(g,16,2257248,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;m=-12;ZDb(j);ZDb(l);i=h;return m|0}do{if((QGb(j,2242920)|0)!=0|(l|0)==0){o=0;p=l;q=n}else{if((yb(l|0,2230440)|0)!=0){o=0;p=l;q=n;break}d=c[e+12>>2]|0;if((d|0)==0){o=0;p=l;q=n;break}f=vAb(2218384,(k=i,i=i+16|0,c[k>>2]=l,c[k+8>>2]=d,k)|0)|0;i=k;if((f|0)==0){m=-12;ZDb(j);ZDb(l);i=h;return m|0}else{o=f;p=f;q=c[b>>2]|0;break}}}while(0);n=Zi(q,p)|0;if((n|0)<0){yDb(g,16,2209080,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;if((p|0)!=0){yDb(g,16,2200472,(k=i,i=i+8|0,c[k>>2]=p,k)|0);i=k}yDb(g,16,2191992,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;Xi(c[b>>2]|0);c[b>>2]=0}ZDb(o);m=n;ZDb(j);ZDb(l);i=h;return m|0}function _k(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;g=a+24|0;h=c[b>>2]|0;j=(h|0)==0;a:do{if((c[g>>2]|0)==0){k=j}else{l=a+4|0;m=0;n=h;o=j;b:while(1){if(o){p=cEb(16)|0;if((p|0)==0){q=-12;r=21;break}else{s=p}}else{p=n+12|0;c[b>>2]=c[p>>2];c[p>>2]=0;s=n}p=s+4|0;t=c[p>>2]|0;do{if((t|0)==0){c[p>>2]=a;c[s+8>>2]=m;u=d;v=c[d>>2]|0;while(1){if((v|0)==0){r=13;break}w=v+12|0;x=c[w>>2]|0;if((x|0)==0){r=14;break}else{u=w;v=x}}if((r|0)==13){r=0;c[u>>2]=s;break}else if((r|0)==14){r=0;c[w>>2]=s;break}}else{v=c[s+8>>2]|0;x=Ii(t,v,a,m)|0;if((x|0)==0){y=0}else{z=c[c[l>>2]>>2]|0;yDb(e,16,1967440,(A=i,i=i+32|0,c[A>>2]=c[c[t+4>>2]>>2],c[A+8>>2]=v,c[A+16>>2]=z,c[A+24>>2]=m,A)|0);i=A;y=x}ZDb(c[s>>2]|0);ZDb(s);if((y|0)<0){q=y;r=21;break b}}}while(0);t=m+1|0;p=c[b>>2]|0;x=(p|0)==0;if(t>>>0<(c[g>>2]|0)>>>0){m=t;n=p;o=x}else{k=x;break a}}if((r|0)==21){i=f;return q|0}}}while(0);if(!k){yDb(e,16,2351480,(A=i,i=i+8|0,c[A>>2]=c[c[a+4>>2]>>2],A)|0);i=A;q=-22;i=f;return q|0}A=c[a+40>>2]|0;if((A|0)==0){q=0;i=f;return q|0}else{B=A}while(1){A=B-1|0;e=cEb(16)|0;if((e|0)==0){q=-12;r=21;break}c[e+4>>2]=a;c[e+8>>2]=A;c[e+12>>2]=c[b>>2];c[b>>2]=e;if((A|0)==0){q=0;r=21;break}else{B=A}}if((r|0)==21){i=f;return q|0}return 0}function $k(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+8|0;j=h|0;k=c[b>>2]|0;if((a[k]|0)!=91){l=0;i=h;return l|0}m=j;n=0;o=k;a:while(1){c[b>>2]=o+1;k=wAb(b,1939184)|0;c[j>>2]=k;do{if((a[k]|0)==0){yDb(g,16,1914912,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=7}else{r=c[b>>2]|0;c[b>>2]=r+1;if((a[r]|0)==93){s=k;break}yDb(g,16,1894448,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=7}}while(0);if((q|0)==7){q=0;$Db(m);s=c[j>>2]|0}k=c[d>>2]|0;if((s|0)==0){l=-22;q=22;break}if((k|0)==0){q=10;break}r=k+12|0;c[d>>2]=c[r>>2];t=c[e>>2]|0;b:do{if((t|0)==0){q=20}else{u=e;v=t;while(1){w=v|0;x=c[w>>2]|0;if((x|0)!=0){if((QGb(x,s)|0)==0){break}}x=v+12|0;y=c[x>>2]|0;if((y|0)==0){q=20;break b}else{u=x;v=y}}if((v|0)==0){q=20;break}y=v+12|0;c[u>>2]=c[y>>2];c[y>>2]=0;y=c[k+4>>2]|0;x=c[k+8>>2]|0;z=c[v+4>>2]|0;A=c[v+8>>2]|0;B=Ii(y,x,z,A)|0;if((B|0)!=0){C=c[c[z+4>>2]>>2]|0;yDb(g,16,1967440,(p=i,i=i+32|0,c[p>>2]=c[c[y+4>>2]>>2],c[p+8>>2]=x,c[p+16>>2]=C,c[p+24>>2]=A,p)|0);i=p;if((B|0)<0){q=18;break a}}ZDb(c[w>>2]|0);ZDb(s);ZDb(v);ZDb(k)}}while(0);if((q|0)==20){q=0;c[k>>2]=s;c[r>>2]=c[f>>2];c[f>>2]=k}t=c[b>>2]|0;A=t+(qd(t|0,2252784)|0)|0;c[b>>2]=A;t=n+1|0;if((a[A]|0)==91){n=t;o=A}else{l=t;q=22;break}}if((q|0)==10){yDb(g,16,2004840,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;ZDb(s);l=-22;i=h;return l|0}else if((q|0)==18){ZDb(s);l=B;i=h;return l|0}else if((q|0)==22){i=h;return l|0}return 0}function al(){return}function bl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+44>>2]|0;e=d+4|0;f=a;a=JBb(d+8|0,c[e>>2]|0,160512,0,0,0,0,0,f)|0;if((a|0)<0){yDb(f,16,2257080,(f=i,i=i+8|0,c[f>>2]=c[e>>2],f)|0);i=f;g=a;i=b;return g|0}else{h[d+32>>3]=0.0;h[d+160>>3]=0.0;h[d+64>>3]=+q;h[d+72>>3]=+q;h[d+80>>3]=+q;h[d+88>>3]=+q;h[d+112>>3]=+q;h[d+120>>3]=+q;g=0;i=b;return g|0}return 0}function cl(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+8|0;IBb(c[b>>2]|0);c[b>>2]=0;return}function dl(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,R=0,S=0,T=0;e=i;i=i+192|0;f=e|0;g=e+64|0;j=e+128|0;l=b+8|0;m=c[(c[l>>2]|0)+44>>2]|0;n=d+136|0;o=c[n>>2]|0;p=c[n+4>>2]|0;r=m+16|0;s=m+112|0;t=c[s+4>>2]&2147483647;u=2146435072;if(t>>>0>u>>>0|t>>>0==u>>>0&(c[s>>2]|0)>>>0>0>>>0){if((o|0)==0&(p|0)==(-2147483648|0)){h[s>>3]=+q;v=+q}else{h[s>>3]=+(o>>>0)+ +(p|0)*4294967296.0;v=(+(o>>>0)+ +(p|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}h[m+120>>3]=v}s=(o|0)==0&(p|0)==(-2147483648|0);if(s){u=m+96|0;h[u>>3]=+q;w=+q;x=u}else{u=m+96|0;h[u>>3]=+(o>>>0)+ +(p|0)*4294967296.0;w=(+(o>>>0)+ +(p|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0));x=u}u=m+128|0;h[u>>3]=w;t=sCb(d)|0;if((t|0)==(-1|0)&(F|0)==(-1|0)){y=+q}else{t=sCb(d)|0;y=+(t>>>0)+ +(F|0)*4294967296.0}t=m+56|0;h[t>>3]=y;z=WFb()|0;h[m+144>>3]=+(z>>>0)+ +(F|0)*4294967296.0;z=b+16|0;A=c[z>>2]|0;if((A|0)==1){y=+(c[d+76>>2]|0);h[m+160>>3]=y;h[m+48>>3]=y}else if((A|0)==0){h[m+24>>3]=+(c[d+296>>2]|0)}y=+MBb(c[m+8>>2]|0,r,0);h[k>>3]=y;r=c[k+4>>2]&2147483647;A=2146435072;B=r>>>0>A>>>0|r>>>0==A>>>0&(c[k>>2]|0)>>>0>0>>>0;if(B){C=-2147483648;D=0}else{C=(E=+y,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);D=~~+y>>>0}c[n>>2]=D;c[n+4>>2]=C;C=c[l>>2]|0;D=m+32|0;w=+h[D>>3];A=(E=+w,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);r=f|0;TGb(r|0,0,64)|0;a[r]=0;v=+h[x>>3];f=c[x+4>>2]&2147483647;G=2146435072;if(f>>>0>G>>>0|f>>>0==G>>>0&(c[x>>2]|0)>>>0>0>>>0){Lb(r|0,64,2288752,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{x=(E=+v,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Lb(r|0,64,2272400,(H=i,i=i+16|0,c[H>>2]=~~+v>>>0,c[H+8>>2]=x,H)|0)|0;i=H}v=+h[u>>3];u=g|0;TGb(u|0,0,64)|0;a[u]=0;I=+h[t>>3];g=c[t+4>>2]&2147483647;x=2146435072;if(g>>>0>x>>>0|g>>>0==x>>>0&(c[t>>2]|0)>>>0>0>>>0){Lb(u|0,64,2288752,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{t=(E=+I,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Lb(u|0,64,2272400,(H=i,i=i+16|0,c[H>>2]=~~+I>>>0,c[H+8>>2]=t,H)|0)|0;i=H}yDb(C,48,1894208,(H=i,i=i+40|0,c[H>>2]=~~+w>>>0,c[H+8>>2]=A,c[H+16>>2]=r,h[H+24>>3]=v,c[H+32>>2]=u,H)|0);i=H;u=c[z>>2]|0;if((u|0)==1){v=+h[m+48>>3];r=(E=+v,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);w=+h[m+40>>3];A=(E=+w,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);yDb(c[l>>2]|0,48,2331416,(H=i,i=i+32|0,c[H>>2]=~~+v>>>0,c[H+8>>2]=r,c[H+16>>2]=~~+w>>>0,c[H+24>>2]=A,H)|0);i=H}else if((u|0)==0){w=+h[m+24>>3];u=(E=+w,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);yDb(c[l>>2]|0,48,2351408,(H=i,i=i+16|0,c[H>>2]=~~+w>>>0,c[H+8>>2]=u,H)|0);i=H}u=c[l>>2]|0;A=j|0;TGb(A|0,0,64)|0;a[A]=0;if(B){Lb(A|0,64,2288752,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{B=(E=+y,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Lb(A|0,64,2272400,(H=i,i=i+16|0,c[H>>2]=~~+y>>>0,c[H+8>>2]=B,H)|0)|0;i=H}if(y==-9223372036854776000.0){J=+q}else{J=y*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}yDb(u,48,2307e3,(H=i,i=i+16|0,c[H>>2]=A,h[H+8>>3]=J,H)|0);i=H;if((c[z>>2]|0)==0){K=+h[D>>3]+1.0}else{K=+h[D>>3]+ +(c[d+76>>2]|0)}h[D>>3]=K;if(s){h[m+64>>3]=+q;L=+q}else{K=+(o>>>0)+ +(p|0)*4294967296.0;h[m+64>>3]=K;L=K*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}h[m+72>>3]=L;p=c[n>>2]|0;o=c[n+4>>2]|0;if((p|0)==0&(o|0)==(-2147483648|0)){h[m+80>>3]=+q;M=+q}else{h[m+80>>3]=+(p>>>0)+ +(o|0)*4294967296.0;M=(+(p>>>0)+ +(o|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}h[m+88>>3]=M;if((c[m+176>>2]|0)!=1){N=c[l>>2]|0;O=N+32|0;R=c[O>>2]|0;S=c[R>>2]|0;T=cj(S,d)|0;i=e;return T|0}b=m+40|0;h[b>>3]=+h[b>>3]+ +(c[d+76>>2]|0);N=c[l>>2]|0;O=N+32|0;R=c[O>>2]|0;S=c[R>>2]|0;T=cj(S,d)|0;i=e;return T|0}function el(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0.0,l=0.0;b=i;d=c[(c[a+8>>2]|0)+44>>2]|0;e=d+176|0;c[e>>2]=c[a+16>>2];f=d+16|0;g=d+136|0;h[g>>3]=+(c[a+56>>2]|0)/+(c[a+60>>2]|0);j=WFb()|0;h[d+152>>3]=+(j>>>0)+ +(F|0)*4294967296.0;if((c[e>>2]|0)==1){k=+(c[a+48>>2]|0)}else{k=+q}h[d+104>>3]=k;h[d+168>>3]=k;d=c[a+116>>2]|0;do{if((d|0)==0){l=+q}else{e=c[a+120>>2]|0;if((e|0)==0){l=+q;break}l=+(d|0)/+(e|0)}}while(0);h[f>>3]=l;yDb(c[a>>2]|0,40,1914696,(a=i,i=i+24|0,h[a>>3]=+h[g>>3],h[a+8>>3]=l,h[a+16>>3]=k,a)|0);i=a;i=b;return 0}function fl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+96|0;d=b+32|0;e=(c[a+44>>2]|0)+4|0;if((c[e>>2]|0)<=0){i=b;return 0}f=d;g=b|0;h=a+4|0;j=d+4|0;k=d|0;l=a+40|0;m=a+28|0;n=a+32|0;o=a+36|0;a=0;do{TGb(f|0,0,60)|0;Lb(g|0,32,1938640,(p=i,i=i+8|0,c[p>>2]=a,p)|0)|0;i=p;c[j>>2]=c[(c[(c[h>>2]|0)+8>>2]|0)+4>>2];c[k>>2]=eEb(g)|0;Hi(a,l,4,m,n,d)|0;c[o>>2]=c[l>>2];a=a+1|0;}while((a|0)<(c[e>>2]|0));i=b;return 0}function gl(a){a=a|0;var b=0,d=0;b=a+40|0;if((c[b>>2]|0)==0){return}d=a+28|0;a=0;do{$Db((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function hl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=c[a+8>>2]|0;a=b+40|0;f=c[a>>2]|0;a:do{if((f|0)==0){g=-541478725}else{h=b+32|0;j=-541478725;k=0;l=f;while(1){if((c[(c[(c[h>>2]|0)+(k<<2)>>2]|0)+144>>2]|0)==0){m=PCb(c[e>>2]|0)|0;if((m|0)==0){g=-12;break a}n=cj(c[(c[h>>2]|0)+(k<<2)>>2]|0,m)|0;if((n|0)<0){g=n;break a}o=n;p=c[a>>2]|0}else{o=j;p=l}n=k+1|0;if(n>>>0<p>>>0){j=o;k=n;l=p}else{g=o;break}}}}while(0);JCb(e);i=d;return g|0}function il(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;d=i;i=i+384|0;e=d|0;f=d+256|0;g=d+264|0;j=d+272|0;k=d+296|0;l=d+304|0;m=d+320|0;n=c[b+44>>2]|0;o=n+28|0;if((c[o>>2]|0)==0){yDb(b,16,2208848,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=d;return q|0}r=+h[n+16>>3]*1.0e6+.5;s=(E=+r,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);t=n+8|0;c[t>>2]=~~+r>>>0;c[t+4>>2]=s;s=c[n+32>>2]|0;if((s|0)==0){u=d+280|0;v=(QGb(c[c[b+4>>2]>>2]|0,2184024)|0)==0;w=c[n+36>>2]|0;Lb(u|0,16,2200328,(p=i,i=i+16|0,c[p>>2]=v?97:118,c[p+8>>2]=w,p)|0)|0;i=p;x=u}else{x=s}s=1;u=x;while(1){c[k>>2]=u;w=a[u]|0;if((w<<24>>24|0)==43){y=s+1|0}else if((w<<24>>24|0)==0){break}else{y=s}s=y;u=u+1|0}if(!((c[n+40>>2]|0)==1|(s|0)==1)){yDb(b,16,2191728,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1163346256;i=d;return q|0}cx();u=n+24|0;y=c[u>>2]|0;if((y|0)==0){z=0}else{z=WC(y)|0}y=n+44|0;c[y>>2]=0;w=aT(y,c[o>>2]|0,z,0)|0;if((w|0)<0){yDb(b,16,2175192,(p=i,i=i+8|0,c[p>>2]=c[o>>2],p)|0);i=p;q=w;i=d;return q|0}if((AT(c[y>>2]|0,0)|0)<0){yDb(b,24,2164904,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}w=c[t>>2]|0;z=c[t+4>>2]|0;v=0;do{if((z|0)>(v|0)|(z|0)==(v|0)&w>>>0>0>>>0){A=c[y>>2]|0;B=A+1056|0;C=c[B>>2]|0;D=c[B+4>>2]|0;do{if((C|0)==0&(D|0)==(-2147483648|0)){G=z;H=w}else{B=ZGb(-1,2147483647,C,D)|0;I=F;if(!((z|0)>(I|0)|(z|0)==(I|0)&w>>>0>B>>>0)){B=YGb(C,D,w,z)|0;G=F;H=B;break}yDb(b,16,2158216,(p=i,i=i+40|0,c[p>>2]=c[o>>2],c[p+8>>2]=C,c[p+16>>2]=D,c[p+24>>2]=w,c[p+32>>2]=z,p)|0);i=p;q=-22;i=d;return q|0}}while(0);D=sT(A,-1,H,G,1)|0;if((D|0)>=0){break}yDb(b,16,2151216,(p=i,i=i+24|0,c[p>>2]=c[o>>2],c[p+8>>2]=H,c[p+16>>2]=G,p)|0);i=p;q=D;i=d;return q|0}}while(0);G=c[y>>2]|0;H=c[G+24>>2]|0;if((H|0)!=0){z=c[G+28>>2]|0;G=0;do{c[(c[z+(G<<2)>>2]|0)+76>>2]=48;G=G+1|0;}while(G>>>0<H>>>0)}H=dEb(s,8)|0;G=n+224|0;c[G>>2]=H;if((H|0)==0){q=-12;i=d;return q|0}H=(s|0)>0;a:do{if(H){z=b;w=g|0;v=n+220|0;D=0;C=x;while(1){B=xAb(C,2144288,k)|0;if((B|0)==0){q=-558323010;J=72;break}I=c[y>>2]|0;c[f>>2]=-1;K=xd(B|0,2077608,(p=i,i=i+24|0,c[p>>2]=w,c[p+8>>2]=f,c[p+16>>2]=j,p)|0)|0;i=p;b:do{if((K-1|0)>>>0<2>>>0){L=(a[w]|0)!=118|0;M=IT(I,L,c[f>>2]|0,-1,0,0)|0;if((M|0)<0){N=lGb(L)|0;L=c[f>>2]|0;yDb(z,16,2072840,(p=i,i=i+16|0,c[p>>2]=N,c[p+8>>2]=L,p)|0);i=p;O=0;break}else{O=c[(c[I+28>>2]|0)+(M<<2)>>2]|0;break}}else{M=I+24|0;do{if((c[M>>2]|0)==0){R=0}else{L=I+28|0;N=0;S=0;T=0;c:while(1){U=hU(I,c[(c[L>>2]|0)+(N<<2)>>2]|0,B)|0;if((U|0)<0){J=38;break}do{if((U|0)==0){V=T;W=S}else{X=c[(c[L>>2]|0)+(N<<2)>>2]|0;if((c[X+76>>2]|0)==48){if((T|0)==0){V=X;W=S;break}else{J=43;break c}}else{V=T;W=S+1|0;break}}}while(0);U=N+1|0;if(U>>>0<(c[M>>2]|0)>>>0){N=U;S=W;T=V}else{J=45;break}}if((J|0)==38){J=0;yDb(z,16,2068216,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;O=0;break b}else if((J|0)==43){J=0;yDb(z,24,2063896,(p=i,i=i+16|0,c[p>>2]=B,c[p+8>>2]=N,p)|0);i=p;Y=T}else if((J|0)==45){J=0;if((V|0)==0){R=W;break}else{Y=V}}S=c[(c[Y+8>>2]|0)+8>>2]|0;if(S>>>0<2>>>0){O=Y;break b}L=lGb(S)|0;yDb(z,16,2039312,(p=i,i=i+16|0,c[p>>2]=B,c[p+8>>2]=L,p)|0);i=p;O=0;break b}}while(0);yDb(z,24,2060024,(p=i,i=i+16|0,c[p>>2]=B,c[p+8>>2]=(R|0)!=0?2055224:2044320,p)|0);i=p;O=0}}while(0);if((O|0)==0){q=-22;J=72;break}c[O+76>>2]=0;c[(c[G>>2]|0)+(D<<3)>>2]=O;B=c[v>>2]|0;I=c[O>>2]|0;c[v>>2]=(B|0)>(I|0)?B:I;I=D+1|0;if((I|0)<(s|0)){D=I;C=0}else{break a}}if((J|0)==72){i=d;return q|0}}}while(0);if((xAb(0,2144288,k)|0)!=0){q=-558323010;i=d;return q|0}k=n+220|0;O=dEb((c[k>>2]|0)+1|0,4)|0;R=O;c[n+228>>2]=R;if((O|0)==0){q=-12;i=d;return q|0}if((c[k>>2]|0)>=0){O=0;do{c[R+(O<<2)>>2]=-1;O=O+1|0;}while((O|0)<=(c[k>>2]|0))}d:do{if(H){k=c[G>>2]|0;O=0;do{c[R+(c[c[k+(O<<3)>>2]>>2]<<2)>>2]=O;O=O+1|0;}while((O|0)<(s|0));if(!H){J=58;break}O=m;k=l|0;Y=m+4|0;V=m|0;W=m+48|0;f=m+44|0;j=b+40|0;y=b+28|0;x=b+32|0;g=b+36|0;C=b;D=e|0;v=0;e:while(1){TGb(O|0,0,60)|0;Lb(k|0,16,2138680,(p=i,i=i+8|0,c[p>>2]=v,p)|0)|0;i=p;c[Y>>2]=c[(c[(c[(c[G>>2]|0)+(v<<3)>>2]|0)+8>>2]|0)+8>>2];c[V>>2]=eEb(k)|0;c[W>>2]=1244;c[f>>2]=2806;Hi(v,j,4,y,x,m)|0;c[g>>2]=c[j>>2];z=(c[G>>2]|0)+(v<<3)|0;w=q0a(c[(c[(c[z>>2]|0)+8>>2]|0)+48>>2]|0)|0;if((w|0)==0){J=62;break}A=c[(c[z>>2]|0)+8>>2]|0;c[A+488>>2]=1;Z=m0a(A,w,0)|0;if((Z|0)<0){J=64;break}w=c[(c[(c[G>>2]|0)+(v<<3)>>2]|0)+8>>2]|0;do{if((c[(c[w+12>>2]|0)+8>>2]|0)==1){A=w+448|0;if(!((c[A>>2]|0)==0&(c[A+4>>2]|0)==0)){break}z=w+416|0;I=jBb(c[z>>2]|0)|0;B=F;_=c[z>>2]|0;if((I|0)==0&(B|0)==0){J=68;break e}iBb(D,256,_,I,B);yDb(C,24,2120040,(p=i,i=i+16|0,c[p>>2]=v,c[p+8>>2]=D,p)|0);i=p;c[A>>2]=I;c[A+4>>2]=B}}while(0);w=v+1|0;if((w|0)<(s|0)){v=w}else{$=C;break d}}if((J|0)==62){yDb(C,16,2113976,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=d;return q|0}else if((J|0)==64){yDb(C,16,2099640,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=Z;i=d;return q|0}else if((J|0)==68){yDb(C,16,2125856,(p=i,i=i+16|0,c[p>>2]=v,c[p+8>>2]=_,p)|0);i=p;q=-22;i=d;return q|0}}else{J=58}}while(0);if((J|0)==58){$=b}b=c[t+4>>2]|0;J=c[u>>2]|0;u=c[o>>2]|0;o=c[n+36>>2]|0;yDb($,40,2132048,(p=i,i=i+40|0,c[p>>2]=c[t>>2],c[p+8>>2]=b,c[p+16>>2]=J,c[p+24>>2]=u,c[p+32>>2]=o,p)|0);i=p;q=0;i=d;return q|0}function jl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+44>>2]|0;d=a+40|0;if((c[d>>2]|0)==0){e=b+224|0}else{f=a+28|0;a=b+224|0;g=a;h=0;while(1){$Db((c[f>>2]|0)+(h*60|0)|0);i=c[(c[g>>2]|0)+(h<<3)>>2]|0;if((i|0)!=0){E0a(c[i+8>>2]|0)|0}i=h+1|0;if(i>>>0<(c[d>>2]|0)>>>0){h=i}else{e=a;break}}}$Db(e);$Db(b+228|0);JCb(b+216|0);e=b+44|0;if((c[e>>2]|0)==0){return}KT(e);return}function kl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=c[a+44>>2]|0;c[d>>2]=0;c[d+4>>2]=-1;g=e;c[g>>2]=c[167786];c[g+4>>2]=c[167787];c[g+8>>2]=c[167788];c[g+12>>2]=c[167789];g=a+40|0;if((c[g>>2]|0)==0){i=b;return 0}h=f+224|0;f=a+32|0;a=d;d=e|0;e=0;do{j=c[(c[(c[h>>2]|0)+(e<<3)>>2]|0)+8>>2]|0;k=c[(c[f>>2]|0)+(e<<2)>>2]|0;l=c[j+8>>2]|0;if((l|0)==1){c[a>>2]=c[j+420>>2];Hk(xk(a)|0,k+64|0);c[a>>2]=c[j+412>>2];Hk(xk(a)|0,k+72|0);m=j+448|0;n=c[m+4>>2]|0;c[d>>2]=c[m>>2];c[d+4>>2]=n;Gk(yk(d)|0,k+80|0)}else if((l|0)==0){c[a>>2]=c[j+140>>2];Hk(xk(a)|0,k+64|0)}e=e+1|0;}while(e>>>0<(c[g>>2]|0)>>>0);i=b;return 0}function ll(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;d=(c[(c[b+44>>2]|0)+224>>2]|0)+((((c[a+4>>2]|0)-(c[b+28>>2]|0)|0)/60|0)<<3)|0;b=c[d>>2]|0;e=c[b+8>>2]|0;f=b+40|0;b=a+56|0;g=c[f+4>>2]|0;c[b>>2]=c[f>>2];c[b+4>>2]=g;if((c[e+8>>2]|0)!=0){return 0}c[a+20>>2]=c[e+120>>2];c[a+24>>2]=c[e+124>>2];e=(c[d>>2]|0)+412|0;d=a+116|0;a=c[e+4>>2]|0;c[d>>2]=c[e>>2];c[d+4>>2]=a;return 0}function ml(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;d=i;i=i+136|0;e=d+64|0;f=c[b>>2]|0;g=((c[b+4>>2]|0)-(c[f+28>>2]|0)|0)/60|0;b=d+72|0;h=f+44|0;j=d|0;k=f+40|0;l=f;m=f+32|0;a:while(1){f=c[h>>2]|0;n=f+56|0;o=n;c[e>>2]=0;p=f+84|0;do{if((c[p>>2]|0)==0){q=f+48|0;if((c[q>>2]|0)==0){r=f+136|0;s=r;t=gT(c[f+44>>2]|0,s)|0;if((t|0)>=0){UGb(n|0,r|0,80)|0;break}vZ(s);UGb(n|0,r|0,80)|0;if(!((t|0)==-541478725)){u=t;v=38;break a}c[q>>2]=1;continue a}t=f+224|0;r=c[t>>2]|0;if((c[r+(g<<3)+4>>2]|0)==0){c[f+88>>2]=c[c[r+(g<<3)>>2]>>2];break}w=f+40|0;if((c[w>>2]|0)==1){u=-541478725;v=38;break a}r=f+8|0;s=c[f+44>>2]|0;x=s+1056|0;y=c[x>>2]|0;z=c[x+4>>2]|0;x=(y|0)==0&(z|0)==(-2147483648|0);A=YGb(x?0:y,x?0:z,c[r>>2]|0,c[r+4>>2]|0)|0;B=sT(s,-1,A,F,1)|0;if((B|0)<0){v=9;break a}if((c[k>>2]|0)!=0){A=0;s=c[t>>2]|0;do{M0a(c[(c[s+(A<<3)>>2]|0)+8>>2]|0);s=c[t>>2]|0;c[s+(A<<3)+4>>2]=0;A=A+1|0;}while(A>>>0<(c[k>>2]|0)>>>0)}c[q>>2]=0;A=c[w>>2]|0;c[w>>2]=A-((A|0)>1);yDb(l,40,2093176,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;continue a}}while(0);n=c[f+88>>2]|0;do{if((n|0)<=(c[f+220>>2]|0)){A=c[(c[f+228>>2]|0)+(n<<2)>>2]|0;if((A|0)<0){break}s=c[f+224>>2]|0;t=c[(c[m>>2]|0)+(A<<2)>>2]|0;r=ICb()|0;z=f+216|0;c[z>>2]=r;if((r|0)==0){u=-12;v=38;break a}x=s+(A<<3)|0;y=c[(c[x>>2]|0)+8>>2]|0;D=c[y+8>>2]|0;if((D|0)==1){E=A0a(y,r,e,o)|0;v=24}else if((D|0)==0){E=x0a(y,r,e,o)|0;v=24}else{G=-38}do{if((v|0)==24){v=0;if((E|0)<0){G=E;break}do{if((E|0)==0){v=29}else{if((c[(c[(c[x>>2]|0)+8>>2]|0)+8>>2]|0)==0){v=29;break}H=E;I=c[p>>2]|0}}while(0);if((v|0)==29){v=0;r=c[p>>2]|0;H=r;I=r}r=f+80|0;c[r>>2]=(c[r>>2]|0)+H;y=I-H|0;c[p>>2]=y;if((y|0)<1){BZ(f+136|0);c[p>>2]=0;c[r>>2]=0}if((c[e>>2]|0)!=0){r=oCb(c[z>>2]|0)|0;y=c[z>>2]|0;D=y+136|0;c[D>>2]=r;c[D+4>>2]=F;D=cj(t,y)|0;c[z>>2]=0;if((D|0)<0){u=D;v=38;break a}D=(A|0)==(g|0);if(D){u=D&1;v=38;break a}else{continue a}}if((H|0)==0){c[s+(A<<3)+4>>2]=1}JCb(z);continue a}}while(0);TGb(b|0,0,64)|0;a[b]=0;GBb(G,b,64)|0;yDb(l,24,2087872,(C=i,i=i+8|0,c[C>>2]=b,C)|0);i=C;JCb(z);BZ(f+136|0);c[p>>2]=0;c[f+80>>2]=0;continue a}}while(0);BZ(f+136|0);c[p>>2]=0;c[f+80>>2]=0}if((v|0)==9){TGb(j|0,0,64)|0;a[j]=0;GBb(B,j,64)|0;yDb(l,16,2083280,(C=i,i=i+8|0,c[C>>2]=j,C)|0);i=C;c[w>>2]=1;u=B;J=(u|0)>0;K=J?0:u;i=d;return K|0}else if((v|0)==38){J=(u|0)>0;K=J?0:u;i=d;return K|0}return 0}function nl(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+120|0;c[b>>2]=0;c[b+4>>2]=-2147483648;return 0}function ol(a){a=a|0;var b=0;b=a+156|0;c[b>>2]=c[b>>2]|1;return 0}function pl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[e>>2]=b;h=c[a+8>>2]|0;j=c[h+44>>2]|0;k=j+144|0;if((c[k>>2]|0)!=0){JCb(e);l=0;i=d;return l|0}m=b+136|0;n=c[m>>2]|0;o=c[m+4>>2]|0;if((n|0)==0&(o|0)==(-2147483648|0)){m=j+136|0;p=c[m+4>>2]|0;q=c[m>>2]|0;r=b;s=m}else{c[f>>2]=1;c[f+4>>2]=c[a+48>>2];m=KDb(n,o,a+56|0,f)|0;p=F;q=m;r=c[e>>2]|0;s=j+136|0}m=r+76|0;f=c[m>>2]|0;o=f;n=(f|0)<0|0?-1:0;b=YGb(o,n,q,p)|0;t=F;c[s>>2]=b;c[s+4>>2]=t;s=j+88|0;u=c[s>>2]|0;v=c[s+4>>2]|0;s=0;do{if((v|0)<(s|0)|(v|0)==(s|0)&u>>>0<0>>>0){w=j+72|0;if((c[w>>2]|0)==0&(c[w+4>>2]|0)==(-2147483648|0)){x=0;y=0;z=13}else{A=1;B=n;C=o;z=10}}else{w=j+112|0;D=c[w>>2]|0;E=c[w+4>>2]|0;w=YGb(D,E,o,n)|0;G=F;if(!((G|0)>(v|0)|(G|0)==(v|0)&w>>>0>u>>>0)){A=1;B=n;C=o;z=10;break}w=ZGb(u,v,D,E)|0;E=F;D=(n|0)>(E|0)|(n|0)==(E|0)&o>>>0>w>>>0;A=0;B=D?E:n;C=D?w:o;z=10}}while(0);do{if((z|0)==10){v=j+72|0;u=c[v>>2]|0;s=c[v+4>>2]|0;if(((q|0)!=0|(p|0)!=(-2147483648|0))&((u|0)!=0|(s|0)!=(-2147483648|0))&((t|0)>(s|0)|(t|0)==(s|0)&b>>>0>u>>>0)){v=ZGb(u,s,q,p)|0;s=F;u=(B|0)>(s|0)|(B|0)==(s|0)&C>>>0>v>>>0;x=u?s:B;y=u?v:C;z=13;break}else{if((A|0)==0){x=B;y=C;z=13;break}else{H=f;break}}}}while(0);a:do{if((z|0)==13){C=j+120|0;B=c[C>>2]|0;A=c[C+4>>2]|0;if((B|0)==0&(A|0)==(-2147483648|0)){b=YGb(y,x,q,p)|0;t=F;c[C>>2]=b;c[C+4>>2]=t;I=t;J=b}else{I=A;J=B}B=j+96|0;A=c[B>>2]|0;b=c[B+4>>2]|0;do{if((A|0)==(-1|0)&(b|0)==2147483647){B=j+80|0;if(!((c[B>>2]|0)==0&(c[B+4>>2]|0)==(-2147483648|0))){K=1;L=0;M=0;z=20;break}B=j+128|0;if((c[B>>2]|0)==0&(c[B+4>>2]|0)==0){N=n;O=o}else{K=1;L=0;M=0;z=20}}else{B=j+112|0;t=c[B>>2]|0;C=c[B+4>>2]|0;if(!((C|0)<(b|0)|(C|0)==(b|0)&t>>>0<A>>>0)){K=1;L=0;M=0;z=20;break}B=ZGb(A,b,t,C)|0;C=F;t=0;v=(C|0)<(t|0)|(C|0)==(t|0)&B>>>0<0>>>0;K=0;L=v?0:C;M=v?0:B;z=20}}while(0);b:do{if((z|0)==20){b=j+80|0;A=c[b>>2]|0;B=c[b+4>>2]|0;if(((q|0)!=0|(p|0)!=(-2147483648|0))&((A|0)!=0|(B|0)!=(-2147483648|0))&((p|0)<(B|0)|(p|0)==(B|0)&q>>>0<A>>>0)){b=ZGb(A,B,q,p)|0;B=F;A=(L|0)>(B|0)|(L|0)==(B|0)&M>>>0>b>>>0;P=0;Q=A?L:B;R=A?M:b}else{P=K;Q=L;R=M}b=j+128|0;A=c[b>>2]|0;B=c[b+4>>2]|0;do{if(!((A|0)==0&(B|0)==0)){b=ZGb(q,p,J,I)|0;v=F;if(!((v|0)<(B|0)|(v|0)==(B|0)&b>>>0<A>>>0)){break}b=ZGb(A,B,q,p)|0;v=YGb(b,F,J,I)|0;b=F;C=(Q|0)>(b|0)|(Q|0)==(b|0)&R>>>0>v>>>0;N=C?Q:b;O=C?R:v;break b}}while(0);if((P|0)==0){N=Q;O=R;break}c[a+144>>2]=1;c[k>>2]=1;H=c[m>>2]|0;break a}}while(0);B=j+112|0;A=YGb(c[B>>2]|0,c[B+4>>2]|0,o,n)|0;c[B>>2]=A;c[B+4>>2]=F;B=0;A=(x|0)<(B|0)|(x|0)==(B|0)&y>>>0<0>>>0;B=A?0:y;v=A?0:x;A=(n|0)>(N|0)|(n|0)==(N|0)&o>>>0>O>>>0;C=A?O:o;b=A?N:n;do{if(!((v|0)<(b|0)|(v|0)==(b|0)&B>>>0<C>>>0)){if((B|0)==(C|0)&(v|0)==(b|0)&(f|0)==0){break}yDb(0,0,2164840,(A=i,i=i+24|0,c[A>>2]=2158128,c[A+8>>2]=2151192,c[A+16>>2]=323,A)|0);i=A;Cd();return 0}}while(0);if((B|0)==0&(v|0)==0){c[m>>2]=C;S=r;T=h+32|0}else{A=h+32|0;t=c[c[A>>2]>>2]|0;u=ZGb(C,b,B,v)|0;s=fi(t,u)|0;if((s|0)==0){JCb(e);l=-12;i=d;return l|0}NCb(s,c[e>>2]|0)|0;u=c[e>>2]|0;IFb(c[s+64>>2]|0,c[u+64>>2]|0,0,B,c[s+76>>2]|0,c[a+148>>2]|0,c[u+80>>2]|0)|0;u=s+136|0;if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==(-2147483648|0))){c[g>>2]=1;c[g+4>>2]=c[s+344>>2];t=KDb(B,v,g,a+56|0)|0;w=YGb(c[u>>2]|0,c[u+4>>2]|0,t,F)|0;c[u>>2]=w;c[u+4>>2]=F}JCb(e);c[e>>2]=s;S=s;T=A}l=cj(c[c[T>>2]>>2]|0,S)|0;i=d;return l|0}}while(0);S=j+112|0;j=YGb(c[S>>2]|0,c[S+4>>2]|0,H,(H|0)<0|0?-1:0)|0;c[S>>2]=j;c[S+4>>2]=F;JCb(e);l=0;i=d;return l|0}function ql(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0,q=0,r=0;b=i;i=i+8|0;d=b|0;e=d;f=i;i=i+8|0;g=i;i=i+8|0;j=i;i=i+8|0;k=c[(c[a+8>>2]|0)+44>>2]|0;if((c[a+16>>2]|0)==0){l=a+56|0;m=c[l+4>>2]|0;c[d>>2]=c[l>>2];c[d+4>>2]=m}else{m=c[a+48>>2]|0;c[d>>2]=1;c[e+4>>2]=m}n=+h[k+56>>3];if(n!=1.7976931348623157e+308){o=n*1.0e6;m=(E=+o,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);d=k+16|0;c[d>>2]=~~+o>>>0;c[d+4>>2]=m}o=+h[k+64>>3];if(o!=1.7976931348623157e+308){n=o*1.0e6;m=(E=+n,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);d=k+24|0;c[d>>2]=~~+n>>>0;c[d+4>>2]=m}n=+h[k+48>>3];if(n!=0.0){o=n*1.0e6;m=(E=+o,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);d=k+8|0;c[d>>2]=~~+o>>>0;c[d+4>>2]=m}m=k+16|0;d=c[m>>2]|0;a=c[m+4>>2]|0;do{if(!((d|0)==(-1|0)&(a|0)==2147483647)){c[f>>2]=1;c[f+4>>2]=1e6;m=KDb(d,a,f,e)|0;l=F;p=k+72|0;q=c[p>>2]|0;r=c[p+4>>2]|0;if(!((q|0)==0&(r|0)==(-2147483648|0)|((l|0)<(r|0)|(l|0)==(r|0)&m>>>0<q>>>0))){break}c[p>>2]=m;c[p+4>>2]=l}}while(0);f=k+24|0;a=c[f>>2]|0;d=c[f+4>>2]|0;do{if(!((a|0)==(-1|0)&(d|0)==2147483647)){c[g>>2]=1;c[g+4>>2]=1e6;f=KDb(a,d,g,e)|0;l=F;p=k+80|0;m=c[p>>2]|0;q=c[p+4>>2]|0;if(!((m|0)==0&(q|0)==(-2147483648|0)|((l|0)>(q|0)|(l|0)==(q|0)&f>>>0>m>>>0))){break}c[p>>2]=f;c[p+4>>2]=l}}while(0);g=k+8|0;d=c[g>>2]|0;a=c[g+4>>2]|0;if((d|0)==0&(a|0)==0){i=b;return 0}c[j>>2]=1;c[j+4>>2]=1e6;g=KDb(d,a,j,e)|0;e=k+128|0;c[e>>2]=g;c[e+4>>2]=F;i=b;return 0}function rl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=g+144|0;if((c[h>>2]|0)!=0){JCb(e);j=0;i=d;return j|0}k=g+32|0;l=c[k>>2]|0;m=c[k+4>>2]|0;k=-1;n=g+72|0;o=c[n>>2]|0;p=c[n+4>>2]|0;if((m|0)>(k|0)|(m|0)==(k|0)&l>>>0>-1>>>0){k=g+104|0;n=c[k+4>>2]|0;q=((n|0)<(m|0)|(n|0)==(m|0)&(c[k>>2]|0)>>>0<l>>>0)&1;if((o|0)==0&(p|0)==(-2147483648|0)){r=q;s=7}else{t=q;s=6}}else{if((o|0)==0&(p|0)==(-2147483648|0)){s=8}else{t=1;s=6}}if((s|0)==6){q=b+136|0;l=c[q>>2]|0;k=c[q+4>>2]|0;r=(l|0)==0&(k|0)==(-2147483648|0)|((k|0)<(p|0)|(k|0)==(p|0)&l>>>0<o>>>0)?t:0;s=7}if((s|0)==7){if((r|0)==0){s=8}}a:do{if((s|0)==8){r=g+120|0;t=c[r>>2]|0;o=c[r+4>>2]|0;do{if((t|0)==0&(o|0)==(-2147483648|0)){l=b+136|0;p=c[l>>2]|0;k=c[l+4>>2]|0;if((p|0)==0&(k|0)==(-2147483648|0)){u=-2147483648;v=0;break}c[r>>2]=p;c[r+4>>2]=k;u=k;v=p}else{u=o;v=t}}while(0);t=g+40|0;o=c[t>>2]|0;r=c[t+4>>2]|0;t=g+80|0;p=c[t>>2]|0;k=c[t+4>>2]|0;do{if((o|0)==(-1|0)&(r|0)==2147483647){if(!((p|0)==0&(k|0)==(-2147483648|0))){w=1;s=15;break}t=g+128|0;if(!((c[t>>2]|0)==0&(c[t+4>>2]|0)==0)){x=1;s=16}}else{t=g+104|0;l=c[t+4>>2]|0;q=(l|0)>=(r|0)&((l|0)>(r|0)|(c[t>>2]|0)>>>0>=o>>>0)&1;if((p|0)==0&(k|0)==(-2147483648|0)){x=q;s=16}else{w=q;s=15}}}while(0);if((s|0)==15){o=b+136|0;r=c[o>>2]|0;q=c[o+4>>2]|0;x=((r|0)!=0|(q|0)!=(-2147483648|0))&((q|0)<(k|0)|(q|0)==(k|0)&r>>>0<p>>>0)?0:w;s=16}do{if((s|0)==16){r=g+128|0;q=c[r>>2]|0;o=c[r+4>>2]|0;do{if((q|0)==0&(o|0)==0){y=x}else{r=b+136|0;t=c[r>>2]|0;l=c[r+4>>2]|0;if((t|0)==0&(l|0)==(-2147483648|0)){y=x;break}r=ZGb(t,l,v,u)|0;l=F;y=(l|0)<(o|0)|(l|0)==(o|0)&r>>>0<q>>>0?0:x}}while(0);if((y|0)==0){break}c[a+144>>2]=1;c[h>>2]=1;break a}}while(0);p=g+104|0;k=YGb(c[p>>2]|0,c[p+4>>2]|0,1,0)|0;c[p>>2]=k;c[p+4>>2]=F;j=cj(c[c[f+32>>2]>>2]|0,b)|0;i=d;return j|0}}while(0);b=g+104|0;g=YGb(c[b>>2]|0,c[b+4>>2]|0,1,0)|0;c[b>>2]=g;c[b+4>>2]=F;JCb(e);j=0;i=d;return j|0}function sl(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+16|0;f=d|0;g=d+8|0;h=c[a+44>>2]|0;a=h+12|0;j=h+142|0;k=b[j>>1]|0;if(!(k<<16>>16==0)){l=h+140|0;m=k;do{k=a+((e[l>>1]|0)<<2)|0;n=c[k>>2]|0;b[j>>1]=m-1;c[k>>2]=0;b[l>>1]=(b[l>>1]|0)+1&31;c[g>>2]=n;JCb(g);m=b[j>>1]|0;}while(!(m<<16>>16==0))}m=h+144|0;j=h+274|0;g=b[j>>1]|0;if(g<<16>>16==0){i=d;return}l=h+272|0;h=g;do{g=m+((e[l>>1]|0)<<2)|0;a=c[g>>2]|0;b[j>>1]=h-1;c[g>>2]=0;b[l>>1]=(b[l>>1]|0)+1&31;c[f>>2]=a;JCb(f);h=b[j>>1]|0;}while(!(h<<16>>16==0));i=d;return}function tl(a){a=a|0;var b=0,d=0,e=0;b=xk(551856)|0;d=xk(552104)|0;e=a+16|0;Hk(b,(c[c[e>>2]>>2]|0)+68|0);Hk(d,(c[(c[e>>2]|0)+4>>2]|0)+68|0);Hk(b,(c[c[a+32>>2]>>2]|0)+64|0);return 0}function ul(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a>>2]|0;a=c[d+44>>2]|0;e=a;c[e>>2]=1;f=a+142|0;g=d+16|0;d=a+12|0;h=a+140|0;while(1){if((b[f>>1]|0)==0){i=0}else{i=(c[d+((b[h>>1]&31)<<2)>>2]|0)!=0|0}a=Ni(c[(c[g>>2]|0)+(i<<2)>>2]|0)|0;if((a|0)<0){j=a;k=6;break}if((c[e>>2]|0)==0){j=0;k=6;break}}if((k|0)==6){return j|0}return 0}function vl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a>>2]|0;e=c[d+16>>2]|0;f=c[e>>2]|0;g=c[e+4>>2]|0;e=c[f+20>>2]|0;h=c[g+20>>2]|0;j=f+24|0;k=c[j>>2]|0;l=c[g+24>>2]|0;if((e|0)==(h|0)&(k|0)==(l|0)){c[a+20>>2]=e;c[a+24>>2]=c[j>>2];j=f+56|0;g=a+56|0;m=c[j+4>>2]|0;c[g>>2]=c[j>>2];c[g+4>>2]=m;m=f+28|0;g=a+28|0;j=c[m+4>>2]|0;c[g>>2]=c[m>>2];c[g+4>>2]=j;j=f+116|0;f=a+116|0;a=c[j+4>>2]|0;c[f>>2]=c[j>>2];c[f+4>>2]=a;n=0;i=b;return n|0}else{yDb(d,16,1966112,(d=i,i=i+32|0,c[d>>2]=e,c[d+8>>2]=k,c[d+16>>2]=h,c[d+24>>2]=l,d)|0);i=d;n=-22;i=b;return n|0}return 0}function wl(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+8|0;j=h|0;k=c[f+8>>2]|0;l=k+44|0;m=c[l>>2]|0;n=m+144|0;o=m+12|0;p=(c[(c[k+16>>2]|0)+4>>2]|0)==(f|0)?n:o;f=p+130|0;q=b[f>>1]|0;if(q<<16>>16==32){yDb(k,24,1893512,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=p+128|0;t=e[s>>1]|0;u=(b[f>>1]|0)-1&65535;b[f>>1]=u;JCb(p+(((u&65535)+t&31)<<2)|0);v=b[f>>1]|0;w=s}else{v=q;w=p+128|0}q=e[w>>1]|0;b[f>>1]=v+1;c[p+((q+(v&65535)&31)<<2)>>2]=g;g=m+142|0;v=m+140|0;q=m+274|0;p=m+272|0;f=m;m=k+32|0;k=0;while(1){w=b[g>>1]|0;if(w<<16>>16==0){x=k;y=23;break}s=e[v>>1]|0;if((c[o+((s&31)<<2)>>2]|0)==0){x=k;y=23;break}if((b[q>>1]|0)==0){x=k;y=23;break}if((c[n+((b[p>>1]&31)<<2)>>2]|0)==0){x=k;y=23;break}t=o+(s<<2)|0;s=c[t>>2]|0;b[g>>1]=w-1;c[t>>2]=0;b[v>>1]=(b[v>>1]|0)+1&31;t=b[q>>1]|0;if(t<<16>>16==0){y=10;break}w=n+(e[p>>1]<<2)|0;u=c[w>>2]|0;b[q>>1]=t-1;c[w>>2]=0;b[p>>1]=(b[p>>1]|0)+1&31;c[j>>2]=u;c[f>>2]=0;w=c[l>>2]|0;t=c[s+72>>2]|0;a:do{if((c[w+4>>2]|0)==0){z=c[s+44>>2]|0;A=c[u+32>>2]|0;B=u+72|0;if((t|0)<=0){break}C=s+12|0;D=u|0;E=(z|0)>(A|0)?A:z;F=0;do{if((F|0)>=(c[B>>2]|0)){break a}G=(c[C>>2]|0)+(ba(F,z)|0)|0;UGb(G|0,(c[D>>2]|0)+(ba(F,A)|0)|0,E)|0;F=F+1|0;}while((F|0)<(t|0))}else{if((t|0)<=0){break}F=u|0;E=u+32|0;A=s|0;D=s+32|0;z=w+11|0;C=s+68|0;B=0;G=c[C>>2]|0;while(1){if((G|0)>0){H=ba(c[D>>2]|0,B)|0;I=ba(c[E>>2]|0,B)|0;J=(c[F>>2]|0)+I|0;I=(c[A>>2]|0)+(H+(d[z]|0))|0;H=0;while(1){a[I]=a[J]|0;K=H+1|0;L=c[C>>2]|0;if((K|0)<(L|0)){J=J+1|0;I=I+4|0;H=K}else{M=L;break}}}else{M=G}H=B+1|0;if((H|0)<(t|0)){B=H;G=M}else{break}}}}while(0);t=cj(c[c[m>>2]>>2]|0,s)|0;JCb(j);if((t|0)>-1){k=t}else{x=t;y=23;break}}if((y|0)==10){yDb(0,0,2183528,(r=i,i=i+24|0,c[r>>2]=2106576,c[r+8>>2]=2049240,c[r+16>>2]=101,r)|0);i=r;Cd();return 0}else if((y|0)==23){i=h;return x|0}return 0}function xl(a){a=a|0;var b=0;b=c[(c[a+8>>2]|0)+44>>2]|0;c[b+4>>2]=(Aw(b+8|0,c[a+52>>2]|0)|0)>>>31^1;return 0}function yl(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+44>>2]|0;j=f+28|0;if((c[j>>2]|0)==0){k=0;i=b;return k|0}l=f+24|0;if(!(+g[l>>2]>0.0)){k=0;i=b;return k|0}m=a;yDb(m,24,2174992,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;if((OBb(d,c[j>>2]|0,0,0,0,0,0,0,0,0,m)|0)<0){yDb(m,16,2164768,(a=i,i=i+8|0,c[a>>2]=c[j>>2],a)|0);i=a;k=-22;i=b;return k|0}else{lFb(e,+h[d>>3]/+g[l>>2],c[f+20>>2]|0);l=f+4|0;d=c[e>>2]|0;a=c[e+4>>2]|0;c[l>>2]=d;c[l+4>>2]=a;l=f+12|0;c[l>>2]=d;c[l+4>>2]=a;k=0;i=b;return k|0}return 0}function zl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+8|0;a=(c[(c[d>>2]|0)+44>>2]|0)+12|0;e=b+124|0;f=c[a+4>>2]|0;c[e>>2]=c[a>>2];c[e+4>>2]=f;return cj(c[c[(c[d>>2]|0)+32>>2]>>2]|0,b)|0}function Al(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a+8|0;h=c[(c[f>>2]|0)+44>>2]|0;j=a+28|0;k=j;l=c[k>>2]|0;m=c[k+4>>2]|0;do{if((c[h+28>>2]|0)==0){n=4}else{if(!(+g[h+24>>2]>0.0)){n=4;break}o=h+12|0}}while(0);do{if((n|0)==4){p=h+12|0;q=Bl(a,p)|0;if((q|0)==0){o=p;break}else{r=q}i=b;return r|0}}while(0);n=o;q=c[n+4>>2]|0;c[k>>2]=c[n>>2];c[k+4>>2]=q;q=a+20|0;k=c[q>>2]|0;n=a+24|0;p=c[n>>2]|0;s=d|0;t=d+4|0;if((l|0)==0|(m|0)==0){iFb(s,t,k,(k|0)<0|0?-1:0,p,(p|0)<0|0?-1:0,2147483647,0)|0}else{d=ba(k,l)|0;k=ba(p,m)|0;iFb(s,t,d,(d|0)<0|0?-1:0,k,(k|0)<0|0?-1:0,2147483647,0)|0}k=c[q>>2]|0;d=c[n>>2]|0;p=c[o>>2]|0;o=c[h+16>>2]|0;h=e|0;u=e+4|0;if((p|0)==0|(o|0)==0){iFb(h,u,k,(k|0)<0|0?-1:0,d,(d|0)<0|0?-1:0,2147483647,0)|0}else{e=ba(p,k)|0;k=ba(o,d)|0;iFb(h,u,e,(e|0)<0|0?-1:0,k,(k|0)<0|0?-1:0,2147483647,0)|0}k=c[n>>2]|0;n=c[s>>2]|0;s=c[t>>2]|0;t=c[j>>2]|0;j=c[a+32>>2]|0;a=c[h>>2]|0;h=c[u>>2]|0;yDb(c[f>>2]|0,40,2288120,(f=i,i=i+80|0,c[f>>2]=c[q>>2],c[f+8>>2]=k,c[f+16>>2]=l,c[f+24>>2]=m,c[f+32>>2]=n,c[f+40>>2]=s,c[f+48>>2]=t,c[f+56>>2]=j,c[f+64>>2]=a,c[f+72>>2]=h,f)|0);i=f;r=0;i=b;return r|0}function Bl(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0,v=0,w=0;e=i;i=i+72|0;f=e|0;g=e+56|0;j=e+64|0;k=j;l=c[a+8>>2]|0;m=c[l+44>>2]|0;n=bFb(c[a+52>>2]|0)|0;o=+(c[a+20>>2]|0);p=f|0;h[p>>3]=o;q=+(c[a+24>>2]|0);h[f+8>>3]=q;r=o/q;h[f+16>>3]=r;s=c[a+28>>2]|0;if((s|0)==0){t=1.0}else{t=+(s|0)/+(c[a+32>>2]|0)}h[f+32>>3]=t;h[f+24>>3]=t*r;h[f+40>>3]=+(1<<(d[n+5|0]|0)|0);h[f+48>>3]=+(1<<(d[n+6|0]|0)|0);n=m+28|0;f=l;do{if((OBb(g,c[n>>2]|0,160480,p,0,0,0,0,0,0,f)|0)<0){l=NEb(b,c[n>>2]|0,c[m+20>>2]|0,0,f)|0;if((l|0)>=0){u=c[b>>2]|0;break}yDb(f,16,2271872,(v=i,i=i+8|0,c[v>>2]=c[n>>2],v)|0);i=v;w=l;i=e;return w|0}else{lFb(k,+h[g>>3],c[m+20>>2]|0);l=b;a=c[j>>2]|0;s=c[j+4>>2]|0;c[l>>2]=a;c[l+4>>2]=s;u=a}}while(0);do{if((u|0)>=0){if((c[b+4>>2]|0)<1){break}else{w=0}i=e;return w|0}}while(0);yDb(f,16,2256624,(v=i,i=i+8|0,c[v>>2]=c[n>>2],v)|0);i=v;w=-22;i=e;return w|0}function Cl(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+8|0;d=b|0;e=a+8|0;f=c[(c[e>>2]|0)+44>>2]|0;h=a+28|0;j=h;k=c[j>>2]|0;l=c[j+4>>2]|0;do{if((c[f+28>>2]|0)==0){m=4}else{if(!(+g[f+24>>2]>0.0)){m=4;break}n=f+4|0}}while(0);do{if((m|0)==4){o=f+4|0;p=Bl(a,o)|0;if((p|0)==0){n=o;break}else{q=p}i=b;return q|0}}while(0);p=n;n=c[p>>2]|0;do{if((n|0)==0){m=8}else{o=f+8|0;r=c[o>>2]|0;if((r|0)==0){m=8;break}s=f+12|0;t=ba(c[a+24>>2]|0,n)|0;u=ba(c[a+20>>2]|0,r)|0;iFb(s,f+16|0,t,(t|0)<0|0?-1:0,u,(u|0)<0|0?-1:0,2147483647,0)|0;u=s;s=c[u+4>>2]|0;c[j>>2]=c[u>>2];c[j+4>>2]=s;v=o;w=p}}while(0);if((m|0)==8){c[a+28>>2]=1;c[a+32>>2]=1;v=a+24|0;w=a+20|0}m=c[v>>2]|0;v=c[w>>2]|0;w=a+20|0;p=c[w>>2]|0;j=a+24|0;f=c[j>>2]|0;n=d|0;o=d+4|0;if((k|0)==0|(l|0)==0){iFb(n,o,p,(p|0)<0|0?-1:0,f,(f|0)<0|0?-1:0,2147483647,0)|0}else{d=ba(p,k)|0;p=ba(f,l)|0;iFb(n,o,d,(d|0)<0|0?-1:0,p,(p|0)<0|0?-1:0,2147483647,0)|0}p=c[j>>2]|0;j=c[n>>2]|0;n=c[o>>2]|0;o=c[h>>2]|0;h=c[a+32>>2]|0;yDb(c[e>>2]|0,40,2144056,(e=i,i=i+80|0,c[e>>2]=c[w>>2],c[e+8>>2]=p,c[e+16>>2]=j,c[e+24>>2]=n,c[e+32>>2]=k,c[e+40>>2]=l,c[e+48>>2]=v,c[e+56>>2]=m,c[e+64>>2]=o,c[e+72>>2]=h,e)|0);i=e;q=0;i=b;return q|0}function Dl(a){a=a|0;Ok(a,xk(551656)|0);return 0}function El(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+112|0;f=e|0;g=b+8|0;j=c[g>>2]|0;k=zw(f,c[d>>2]|0,c[d+32>>2]|0,c[b+20>>2]|0,c[b+24>>2]|0,c[(c[j+44>>2]|0)+4>>2]|0)|0;l=f+4|0;m=f|0;n=(c[l>>2]|0)-(c[m>>2]|0)+1|0;o=f+12|0;p=f+8|0;f=(c[o>>2]|0)-(c[p>>2]|0)+1|0;q=j;j=b+160|0;r=c[j>>2]|0;s=c[j+4>>2]|0;j=e+48|0;TGb(j|0,0,32)|0;a[j]=0;t=d+136|0;u=c[t>>2]|0;v=c[t+4>>2]|0;if((u|0)==0&(v|0)==(-2147483648|0)){Lb(j|0,32,2256488,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0)|0;i=w}else{Lb(j|0,32,2229728,(w=i,i=i+16|0,c[w>>2]=u,c[w+8>>2]=v,w)|0)|0;i=w}v=e+80|0;TGb(v|0,0,32)|0;a[v]=0;u=c[t>>2]|0;x=c[t+4>>2]|0;if((u|0)==0&(x|0)==(-2147483648|0)){Lb(v|0,32,2256488,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0)|0;i=w}else{Lb(v|0,32,2242120,(w=i,i=i+8|0,h[w>>3]=(+(u>>>0)+ +(x|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),w)|0)|0;i=w}yDb(q,32,2002952,(w=i,i=i+32|0,c[w>>2]=r,c[w+8>>2]=s,c[w+16>>2]=j,c[w+24>>2]=v,w)|0);i=w;if((k|0)==0){yDb(q,32,2271840,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=c[g>>2]|0;z=y+32|0;A=c[z>>2]|0;B=c[A>>2]|0;C=cj(B,d)|0;i=e;return C|0}k=FCb(d)|0;v=e+16|0;Lb(v|0,32,1965560,(w=i,i=i+8|0,c[w>>2]=c[m>>2],w)|0)|0;i=w;CBb(k,1937472,v,0)|0;Lb(v|0,32,1965560,(w=i,i=i+8|0,c[w>>2]=c[l>>2],w)|0)|0;i=w;CBb(k,1913592,v,0)|0;Lb(v|0,32,1965560,(w=i,i=i+8|0,c[w>>2]=c[p>>2],w)|0)|0;i=w;CBb(k,1893120,v,0)|0;Lb(v|0,32,1965560,(w=i,i=i+8|0,c[w>>2]=c[o>>2],w)|0)|0;i=w;CBb(k,2350736,v,0)|0;Lb(v|0,32,1965560,(w=i,i=i+8|0,c[w>>2]=n,w)|0)|0;i=w;CBb(k,2330400,v,0)|0;Lb(v|0,32,1965560,(w=i,i=i+8|0,c[w>>2]=f,w)|0)|0;i=w;CBb(k,2306200,v,0)|0;v=c[m>>2]|0;m=c[l>>2]|0;l=c[p>>2]|0;p=c[o>>2]|0;yDb(q,32,2287984,(w=i,i=i+112|0,c[w>>2]=v,c[w+8>>2]=m,c[w+16>>2]=l,c[w+24>>2]=p,c[w+32>>2]=n,c[w+40>>2]=f,c[w+48>>2]=n,c[w+56>>2]=f,c[w+64>>2]=v,c[w+72>>2]=l,c[w+80>>2]=v,c[w+88>>2]=l,c[w+96>>2]=n,c[w+104>>2]=f,w)|0);i=w;yDb(q,32,2271840,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=c[g>>2]|0;z=y+32|0;A=c[z>>2]|0;B=c[A>>2]|0;C=cj(B,d)|0;i=e;return C|0}function Fl(a){a=a|0;Ok(a,xk(551592)|0);return 0}function Gl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;a=c[b+44>>2]|0;d=Ni(c[c[b+16>>2]>>2]|0)|0;if(!((d|0)==-541478725)){return d|0}if((c[a+48>>2]|0)==0){return d|0}e=a+40|0;f=c[e+4>>2]|0;g=a+32|0;c[g>>2]=c[e>>2];c[g+4>>2]=f;Hl(b);return d|0}function Hl(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+96|0;e=c[b+44>>2]|0;f=e+32|0;g=e+24|0;j=ZGb(c[f>>2]|0,c[f+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;k=F;l=e+16|0;m=c[l+4>>2]|0;if((k|0)<(m|0)|(k|0)==(m|0)&j>>>0<(c[l>>2]|0)>>>0){i=d;return}l=c[c[b+16>>2]>>2]|0;b=d|0;TGb(b|0,0,32)|0;a[b]=0;j=c[g>>2]|0;m=c[g+4>>2]|0;k=l+56|0;if((j|0)==0&(m|0)==(-2147483648|0)){Lb(b|0,32,2287872,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0)|0;i=n}else{Lb(b|0,32,2271680,(n=i,i=i+8|0,h[n>>3]=(+(j>>>0)+ +(m|0)*4294967296.0)*(+(c[k>>2]|0)/+(c[l+60>>2]|0)),n)|0)|0;i=n}m=d+32|0;TGb(m|0,0,32)|0;a[m]=0;j=c[f>>2]|0;o=c[f+4>>2]|0;if((j|0)==0&(o|0)==(-2147483648|0)){Lb(m|0,32,2287872,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0)|0;i=n}else{Lb(m|0,32,2271680,(n=i,i=i+8|0,h[n>>3]=(+(j>>>0)+ +(o|0)*4294967296.0)*(+(c[k>>2]|0)/+(c[l+60>>2]|0)),n)|0)|0;i=n}o=d+64|0;TGb(o|0,0,32)|0;a[o]=0;j=ZGb(c[f>>2]|0,c[f+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;g=F;if((j|0)==0&(g|0)==(-2147483648|0)){Lb(o|0,32,2287872,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0)|0;i=n}else{Lb(o|0,32,2271680,(n=i,i=i+8|0,h[n>>3]=(+(j>>>0)+ +(g|0)*4294967296.0)*(+(c[k>>2]|0)/+(c[l+60>>2]|0)),n)|0)|0;i=n}yDb(e,32,2305928,(n=i,i=i+24|0,c[n>>2]=b,c[n+8>>2]=m,c[n+16>>2]=o,n)|0);i=n;i=d;return}function Il(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0;f=i;i=i+64|0;g=f|0;j=f+32|0;k=b+8|0;l=c[k>>2]|0;m=c[l+44>>2]|0;n=b+24|0;o=c[n>>2]|0;if((o|0)>0){p=b+20|0;q=e+32|0;r=m+72|0;s=m+76|0;t=c[e>>2]|0;u=0;v=c[p>>2]|0;w=o;while(1){if((v|0)>0){x=c[r>>2]|0;y=0;z=c[s>>2]|0;do{z=((d[t+y|0]|0)>>>0<=x>>>0)+z|0;c[s>>2]=z;y=y+1|0;A=c[p>>2]|0;}while((y|0)<(A|0));B=A;C=c[n>>2]|0}else{B=v;C=w}y=u+1|0;if((y|0)<(C|0)){t=t+(c[q>>2]|0)|0;u=y;v=B;w=C}else{D=C;E=B;F=s;break}}}else{D=o;E=c[b+20>>2]|0;F=m+76|0}G=+((c[F>>2]|0)>>>0>>>0)/+(ba(E,D)|0);D=b+160|0;E=c[D>>2]|0;o=c[D+4>>2]|0;D=g|0;TGb(D|0,0,32)|0;a[D]=0;g=e+136|0;s=c[g>>2]|0;B=c[g+4>>2]|0;if((s|0)==0&(B|0)==(-2147483648|0)){Lb(D|0,32,2287872,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Lb(D|0,32,2229584,(H=i,i=i+16|0,c[H>>2]=s,c[H+8>>2]=B,H)|0)|0;i=H}B=j|0;TGb(B|0,0,32)|0;a[B]=0;j=c[g>>2]|0;s=c[g+4>>2]|0;if((j|0)==0&(s|0)==(-2147483648|0)){Lb(B|0,32,2287872,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Lb(B|0,32,2271680,(H=i,i=i+8|0,h[H>>3]=(+(j>>>0)+ +(s|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),H)|0)|0;i=H}b=(mGb(c[e+88>>2]|0)|0)<<24>>24;yDb(l,48,2241920,(H=i,i=i+48|0,c[H>>2]=E,c[H+8>>2]=o,h[H+16>>3]=G,c[H+24>>2]=D,c[H+32>>2]=B,c[H+40>>2]=b,H)|0);i=H;H=m+48|0;b=(c[H>>2]|0)!=0;do{if(G<+h[m+56>>3]){if(!b){break}c[H>>2]=0;B=c[g+4>>2]|0;D=m+32|0;c[D>>2]=c[g>>2];c[D+4>>2]=B;Hl(l)}else{if(b){break}c[H>>2]=1;B=c[g+4>>2]|0;D=m+24|0;c[D>>2]=c[g>>2];c[D+4>>2]=B}}while(0);H=c[g+4>>2]|0;b=m+40|0;c[b>>2]=c[g>>2];c[b+4>>2]=H;c[F>>2]=0;F=cj(c[c[(c[k>>2]|0)+32>>2]>>2]|0,e)|0;i=f;return F|0}function Jl(b){b=b|0;var d=0,e=0,f=0,g=0,j=0.0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0.0;d=i;i=i+32|0;e=c[(c[b+8>>2]|0)+44>>2]|0;f=b+56|0;g=b+60|0;j=+h[e+8>>3]/(+(c[f>>2]|0)/+(c[g>>2]|0));k=(E=+j,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);l=e+16|0;c[l>>2]=~~+j>>>0;c[l+4>>2]=k;k=(wk(c[b+52>>2]|0,680)|0)==0;b=e+64|0;j=+h[b>>3];if(k){m=j*219.0+16.0}else{m=j*255.0}k=e+72|0;c[k>>2]=~~m;n=d|0;TGb(n|0,0,32)|0;a[n]=0;o=c[l>>2]|0;p=c[l+4>>2]|0;if((o|0)==0&(p|0)==(-2147483648|0)){Lb(n|0,32,2287872,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;r=+h[b>>3];s=c[k>>2]|0;t=e+56|0;u=t;v=+h[u>>3];yDb(e,40,2256312,(q=i,i=i+32|0,c[q>>2]=n,h[q+8>>3]=r,c[q+16>>2]=s,h[q+24>>3]=v,q)|0);i=q;i=d;return 0}else{Lb(n|0,32,2271680,(q=i,i=i+8|0,h[q>>3]=(+(o>>>0)+ +(p|0)*4294967296.0)*(+(c[f>>2]|0)/+(c[g>>2]|0)),q)|0)|0;i=q;r=+h[b>>3];s=c[k>>2]|0;t=e+56|0;u=t;v=+h[u>>3];yDb(e,40,2256312,(q=i,i=i+32|0,c[q>>2]=n,h[q+8>>3]=r,c[q+16>>2]=s,h[q+24>>3]=v,q)|0);i=q;i=d;return 0}return 0}function Kl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+44>>2]|0;d=b+480|0;e=b+464|0;f=b+472|0;g=b+460|0;i=a;a=0;a:while(1){j=d+(a<<5)|0;k=c[e>>2]|0;if((k|0)>-1){c[j>>2]=k}l=+h[f>>3];if(l<1.0){h[d+(a<<5)+8>>3]=l}switch(c[j>>2]|0){case 7:{c[d+(a<<5)+24>>2]=16;break};case 1:{c[d+(a<<5)+24>>2]=14;break};case 18:{c[d+(a<<5)+24>>2]=2;break};case 19:{c[d+(a<<5)+24>>2]=52;break};case 3:{c[d+(a<<5)+24>>2]=32;break};case 4:{c[d+(a<<5)+24>>2]=58;break};case 0:{c[d+(a<<5)+24>>2]=54;break};case 2:{c[d+(a<<5)+24>>2]=64;break};case 5:{c[d+(a<<5)+24>>2]=38;break};case 8:{c[d+(a<<5)+24>>2]=20;break};case 6:{c[d+(a<<5)+24>>2]=30;break};case 9:{c[d+(a<<5)+24>>2]=68;break};case 17:{c[d+(a<<5)+24>>2]=40;break};case 20:{c[d+(a<<5)+24>>2]=62;break};case 21:{c[d+(a<<5)+24>>2]=44;break};case 12:{c[d+(a<<5)+24>>2]=72;break};case 22:{c[d+(a<<5)+24>>2]=50;break};case 23:{c[d+(a<<5)+24>>2]=48;break};case 14:{c[d+(a<<5)+24>>2]=4;break};case 16:{c[d+(a<<5)+24>>2]=18;break};case 10:{c[d+(a<<5)+24>>2]=22;break};case 13:{c[d+(a<<5)+24>>2]=42;break};case 15:{c[d+(a<<5)+24>>2]=46;break};case 11:{c[d+(a<<5)+24>>2]=8;break};default:{}}j=c[g>>2]|0;k=d+(a<<5)+20|0;m=c[k>>2]|0;n=(m|0)==0;do{if((j|0)==0){if(!n){o=m;p=35}}else{if(!n){o=m;p=35;break}q=eEb(j)|0;c[k>>2]=q;if((q|0)==0){r=-12;p=39;break a}else{o=q;p=35}}}while(0);if((p|0)==35){p=0;k=JBb(d+(a<<5)+16|0,o,160424,0,0,0,0,0,i)|0;if((k|0)<0){r=k;p=39;break}c[d+(a<<5)+24>>2]=24}k=a+1|0;if(k>>>0<4>>>0){a=k}else{p=38;break}}if((p|0)==38){c[b+432>>2]=204;r=0;return r|0}else if((p|0)==39){return r|0}return 0}function Ll(a){a=a|0;var b=0;b=c[a+44>>2]|0;Lw(b+8|0);IBb(c[b+496>>2]|0);IBb(c[b+528>>2]|0);IBb(c[b+560>>2]|0);IBb(c[b+592>>2]|0);return}function Ml(a){a=a|0;Ok(a,xk(551520)|0);return 0}function Nl(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)<(l|0)&(j|0)>0){p=g;q=e;r=b;s=k}else{return}while(1){k=0;do{b=d[r+k|0]|0;e=(d[q+k|0]|0)+b|0;a[p+k|0]=~~(+(b|0)+o*+(((e|0)<255?e:255)-b|0));k=k+1|0;}while((k|0)<(j|0));k=s+1|0;if((k|0)<(l|0)){p=p+i|0;q=q+f|0;r=r+c|0;s=k}else{break}}return}function Ol(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0,r=0;n=+h[l+8>>3];if((j|0)<(k|0)&(i|0)>0){o=f;p=d;q=b;r=j}else{return}while(1){j=0;do{b=a[q+j|0]|0;d=b&255;a[o+j|0]=~~(+(d|0)+n*+((a[p+j|0]&b&255)-d|0));j=j+1|0;}while((j|0)<(i|0));j=r+1|0;if((j|0)<(k|0)){o=o+g|0;p=p+e|0;q=q+c|0;r=j}else{break}}return}function Pl(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)<(l|0)&(j|0)>0){p=g;q=e;r=b;s=k}else{return}while(1){k=0;do{b=d[r+k|0]|0;a[p+k|0]=~~(+(b|0)+o*+((((d[q+k|0]|0)+b|0)>>>1)-b|0));k=k+1|0;}while((k|0)<(j|0));k=s+1|0;if((k|0)<(l|0)){p=p+i|0;q=q+f|0;r=r+c|0;s=k}else{break}}return}function Ql(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=p&255;if(p<<24>>24==0){r=q}else{p=255-((((d[g+k|0]|0)<<8^65280)>>>0)/(q>>>0)|0)|0;r=(p|0)<0?0:p}a[n+k|0]=~~(+(q|0)+o*+(r-q|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function Rl(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0,r=0;n=+h[l+8>>3];if((j|0)<(k|0)&(i|0)>0){o=f;p=d;q=b;r=j}else{return}while(1){j=0;do{b=a[q+j|0]|0;d=b&255;f=a[p+j|0]|0;a[o+j|0]=~~(+(d|0)+n*+((((b&255)>>>0>(f&255)>>>0?f:b)&255)-d|0));j=j+1|0;}while((j|0)<(i|0));j=r+1|0;if((j|0)<(k|0)){o=o+g|0;p=p+e|0;q=q+c|0;r=j}else{break}}return}function Sl(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=p-(d[g+k|0]|0)|0;a[n+k|0]=~~(+(p|0)+o*+(((q|0)>-1?q:-q|0)-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function Tl(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=p&255;a[n+k|0]=~~(+(q|0)+o*(+((p&255)>>>0)/+((d[g+k|0]|0)>>>0)*255.0- +(q|0)));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function Ul(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=p&255;if(p<<24>>24==-1){r=q}else{p=((d[g+k|0]|0)<<8>>>0)/((q^255)>>>0)|0;r=p>>>0<255>>>0?p:255}a[n+k|0]=~~(+(q|0)+o*+(r-q|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function Vl(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=d[g+k|0]|0;a[n+k|0]=~~(+(p|0)+o*+(q-(((ba(p<<1,q)|0)>>>0)/255|0)|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function Wl(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=a[g+k|0]|0;r=q&255;if(q<<24>>24>-1){s=(((ba(r,p)|0)>>>0)/255|0)<<1}else{s=255-((((ba(r^255,p^255)|0)>>>0)/255|0)<<1)|0}a[n+k|0]=~~(+(p|0)+o*+(s-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function Xl(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;q=a[f+j|0]|0;a[m+j|0]=~~(+(p|0)+n*+((((o&255)>>>0>(q&255)>>>0?o:q)&255)-p|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function Yl(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;a[n+k|0]=~~(+(p|0)+o*+((((ba(d[g+k|0]|0,p)|0)>>>0)/255|0)-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function Zl(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=p^255;r=q-(d[g+k|0]|0)|0;a[n+k|0]=~~(+(p|0)+o*+(q-((r|0)>-1?r:-r|0)|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function _l(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;iDb(e,f,a,b,g,i-h|0);return}function $l(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;a[m+j|0]=~~(+(p|0)+n*+(((a[f+j|0]|o)&255)-p|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function am(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=p&255;if(p<<24>>24>-1){r=(((ba(d[g+k|0]|0,q)|0)>>>0)/255|0)<<1}else{r=255-((((ba((d[g+k|0]|0)^255,q^255)|0)>>>0)/255|0)<<1)|0}a[n+k|0]=~~(+(q|0)+o*+(r-q|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function bm(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0,r=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;q=a[f+j|0]|0;r=(o&255)>>>0>(q&255)>>>0;a[m+j|0]=~~(+(p|0)+n*+((p^255)-((r?o:q)&255)+((r?q:o)&255)|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function cm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=a[g+k|0]|0;r=(q&255)<<1;if(q<<24>>24>-1){s=p>>>0>r>>>0?r:p}else{q=r-256|0;s=(p|0)>(q|0)?p:q}a[n+k|0]=~~(+(p|0)+o*+(s-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function dm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=a[g+k|0]|0;r=q&255;if(q<<24>>24==-1){s=r}else{q=((ba(p,p)|0)>>>0)/((r^255)>>>0)|0;s=q>>>0<255>>>0?q:255}a[n+k|0]=~~(+(p|0)+o*+(s-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function em(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=p^255;a[n+k|0]=~~(+(p|0)+o*+(q-(((ba((d[g+k|0]|0)^255,q)|0)>>>0)/255|0)|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function fm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0.0,r=0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=+(p&255|0);r=d[g+k|0]|0;s=+(r|0);if(p<<24>>24<0){t=s+ -127.5;if(t<0.0){u=-0.0-t}else{u=t}v=s+(q+ -127.5)*+(r^255|0)/127.5*(.5-u/255.0)}else{t=s+ -127.5;if(t<0.0){w=-0.0-t}else{w=t}v=s-s*((127.5-q)/127.5)*(.5-w/255.0)}a[n+k|0]=~~(q+o*(v-q));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function gm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=p-(d[g+k|0]|0)|0;a[n+k|0]=~~(+(p|0)+o*+(((q|0)<0?0:q)-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function hm(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;q=+(p|0);r=a[f+j|0]|0;s=r&255;do{if(r<<24>>24>-1){if(o<<24>>24==0){t=p;break}u=255-((255-(s<<1)<<8|0)/(p|0)|0)|0;t=(u|0)<0?0:u}else{if(o<<24>>24==-1){t=p;break}u=((s<<9)-65536|0)/(p^255|0)|0;t=(u|0)<255?u:255}}while(0);a[m+j|0]=~~(q+n*+(t-p|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function im(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;a[m+j|0]=~~(+(p|0)+n*+(((a[f+j|0]^o)&255)-p|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function jm(b,e,f,g,i,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;p=c[n+16>>2]|0;if((l|0)>=(m|0)){return}n=o+8|0;q=(k|0)>0;r=o+64|0;s=o+80|0;t=o+72|0;u=o+88|0;v=i;i=f;f=b;b=l;while(1){h[n>>3]=+(b|0);if(q){l=0;do{h[o>>3]=+(l|0);w=+((d[f+l|0]|0)>>>0);h[r>>3]=w;h[s>>3]=w;w=+((d[i+l|0]|0)>>>0);h[t>>3]=w;h[u>>3]=w;a[v+l|0]=~~+MBb(p,o,0);l=l+1|0;}while((l|0)<(k|0))}l=b+1|0;if((l|0)<(m|0)){v=v+j|0;i=i+g|0;f=f+e|0;b=l}else{break}}return}function km(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+40|0;f=e|0;g=e+8|0;c[f>>2]=b;h=c[a+44>>2]|0;j=c[c[a+16>>2]>>2]|0;k=c[c[a+32>>2]>>2]|0;l=Zr(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((l|0)==0){m=b;i=e;return m|0}NCb(l,b)|0;b=h+456|0;if((c[b>>2]|0)>0){k=h+448|0;n=h+452|0;o=l+68|0;p=l+72|0;q=h+480|0;h=g|0;r=g+4|0;s=g+8|0;t=g+12|0;u=g+16|0;v=g+20|0;w=g+24|0;x=g+28|0;y=a+56|0;z=g;g=a+48|0;A=0;do{if((A-1|0)>>>0<2>>>0){B=c[n>>2]|0;C=c[k>>2]|0}else{B=0;C=0}D=-(-(c[o>>2]|0)>>C)|0;E=-(-(c[p>>2]|0)>>B)|0;c[h>>2]=c[f>>2];c[r>>2]=d;c[s>>2]=l;c[t>>2]=j;c[u>>2]=A;c[v>>2]=D;c[w>>2]=E;c[x>>2]=q+(A<<5);D=c[(c[g>>2]|0)+28>>2]|0;Pe[c[c[y>>2]>>2]&255](a,322,z,0,(D|0)<(E|0)?D:E)|0;A=A+1|0;}while((A|0)<(c[b>>2]|0))}JCb(f);m=l;i=e;return m|0}function lm(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0;a=i;i=i+96|0;f=a|0;g=c[b+24>>2]|0;j=(ba(g,d)|0)/(e|0)|0;k=(ba(g,d+1|0)|0)/(e|0)|0;e=c[b+16>>2]|0;d=c[b>>2]|0;l=c[d+(e<<2)>>2]|0;m=c[b+4>>2]|0;n=c[m+(e<<2)>>2]|0;o=c[b+8>>2]|0;p=c[o+(e<<2)>>2]|0;r=c[b+12>>2]|0;s=r+160|0;h[f+56>>3]=+((c[s>>2]|0)>>>0)+ +(c[s+4>>2]|0)*4294967296.0;s=o+136|0;t=c[s>>2]|0;u=c[s+4>>2]|0;if((t|0)==0&(u|0)==(-2147483648|0)){v=+q}else{v=(+(t>>>0)+ +(u|0)*4294967296.0)*(+(c[r+56>>2]|0)/+(c[r+60>>2]|0))}h[f+48>>3]=v;r=c[b+20>>2]|0;v=+(r|0);h[f+16>>3]=v;w=+(g|0);h[f+24>>3]=w;h[f+32>>3]=v/+(c[o+68>>2]|0);h[f+40>>3]=w/+(c[o+72>>2]|0);g=c[b+28>>2]|0;b=c[d+32+(e<<2)>>2]|0;d=l+(ba(b,j)|0)|0;l=c[m+32+(e<<2)>>2]|0;m=n+(ba(l,j)|0)|0;n=c[o+32+(e<<2)>>2]|0;e=p+(ba(n,j)|0)|0;se[c[g+24>>2]&127](d,b,m,l,e,n,r,j,k,g,f|0);i=a;return 0}function mm(a){a=a|0;return Kw((c[(c[a>>2]|0)+44>>2]|0)+8|0,a)|0}function nm(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;e=c[a>>2]|0;f=c[e+16>>2]|0;g=c[f>>2]|0;h=c[f+4>>2]|0;f=c[e+44>>2]|0;j=g+52|0;k=bFb(c[j>>2]|0)|0;if((c[j>>2]|0)!=(c[h+52>>2]|0)){yDb(e,16,1927904,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=b;return m|0}n=c[g+20>>2]|0;o=c[h+20>>2]|0;p=g+24|0;q=c[p>>2]|0;r=c[h+24>>2]|0;do{if((n|0)==(o|0)&(q|0)==(r|0)){s=g+28|0;if((c[s>>2]|0)!=(c[h+28>>2]|0)){t=q;break}if((c[g+32>>2]|0)!=(c[h+32>>2]|0)){t=q;break}c[a+20>>2]=n;c[a+24>>2]=c[p>>2];u=g+56|0;v=a+56|0;w=c[u+4>>2]|0;c[v>>2]=c[u>>2];c[v+4>>2]=w;w=s;s=a+28|0;v=c[w+4>>2]|0;c[s>>2]=c[w>>2];c[s+4>>2]=v;v=g+116|0;s=a+116|0;w=c[v+4>>2]|0;c[s>>2]=c[v>>2];c[s+4>>2]=w;c[f+448>>2]=d[k+5|0]|0;c[f+452>>2]=d[k+6|0]|0;c[f+456>>2]=fFb(c[j>>2]|0)|0;w=Hw(e,f+8|0)|0;m=(w|0)<0?w:0;i=b;return m|0}else{t=r}}while(0);r=c[e+12>>2]|0;f=c[g+28>>2]|0;j=c[g+32>>2]|0;g=c[r+60>>2]|0;k=c[h+28>>2]|0;a=c[h+32>>2]|0;yDb(e,16,1926208,(l=i,i=i+80|0,c[l>>2]=c[r>>2],c[l+8>>2]=n,c[l+16>>2]=q,c[l+24>>2]=f,c[l+32>>2]=j,c[l+40>>2]=g,c[l+48>>2]=o,c[l+56>>2]=t,c[l+64>>2]=k,c[l+72>>2]=a,l)|0);i=l;m=-22;i=b;return m|0}function om(a,b){a=a|0;b=b|0;return Jw((c[(c[a+8>>2]|0)+44>>2]|0)+8|0,a,b)|0}function pm(a){a=a|0;Ok(a,xk(551472)|0);return 0}function qm(b){b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=c[(c[b>>2]|0)+44>>2]|0;e=b+52|0;b=bFb(c[e>>2]|0)|0;f=WDb(6144)|0;g=f;if((f|0)==0){i=-12;return i|0}j=f+2048|0;k=f+4096|0;l=0;do{m=+(l|0);n=m+-85.0;o=n*-.015625+.5;if(o<0.0){p=0.0}else{p=o>1.0?178.5:o*178.5}o=n*.015625+.5;if(o<0.0){q=0.0}else{q=o>1.0?1.0:o}o=(m+85.0+-255.0)*-.015625+.5;if(o<0.0){r=0.0}else{r=o>1.0?1.0:o}h[g+(l<<3)>>3]=p;h[j+(l<<3)>>3]=q*r*178.5;h[k+(255-l<<3)>>3]=p;l=l+1|0;}while((l|0)<256);l=d+8|0;s=d+16|0;t=d+24|0;u=d+32|0;v=d+40|0;w=d+48|0;x=d+56|0;y=d+64|0;z=d+72|0;A=0;do{p=+(A|0);r=+h[g+(A<<3)>>3];B=~~(p+ +h[l>>3]*r);if(B>>>0>255>>>0){C=-B>>31&255}else{C=B&255}B=C&255;D=~~(+(B|0)+ +h[s>>3]*+h[j+(B<<3)>>3]);if(D>>>0>255>>>0){E=-D>>31&255}else{E=D&255}D=E&255;B=~~(+(D|0)+ +h[t>>3]*+h[k+(D<<3)>>3]);if(B>>>0>255>>>0){F=-B>>31&255}else{F=B&255}B=~~(p+r*+h[u>>3]);if(B>>>0>255>>>0){G=-B>>31&255}else{G=B&255}B=G&255;D=~~(+(B|0)+ +h[v>>3]*+h[j+(B<<3)>>3]);if(D>>>0>255>>>0){H=-D>>31&255}else{H=D&255}D=H&255;B=~~(+(D|0)+ +h[w>>3]*+h[k+(D<<3)>>3]);if(B>>>0>255>>>0){I=-B>>31&255}else{I=B&255}B=~~(p+r*+h[x>>3]);if(B>>>0>255>>>0){J=-B>>31&255}else{J=B&255}B=J&255;D=~~(+(B|0)+ +h[y>>3]*+h[j+(B<<3)>>3]);if(D>>>0>255>>>0){K=-D>>31&255}else{K=D&255}D=K&255;B=~~(+(D|0)+ +h[z>>3]*+h[k+(D<<3)>>3]);if(B>>>0>255>>>0){L=-B>>31&255}else{L=B&255}a[d+(A+80)|0]=F;a[d+(A+336)|0]=I;a[d+(A+592)|0]=L;A=A+1|0;}while((A|0)<256);ZDb(f);Aw(d+848|0,c[e>>2]|0)|0;c[d+852>>2]=(aFb(b)|0)>>3;i=0;return i|0}function rm(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=c[b+8>>2]|0;b=c[h+44>>2]|0;j=h+32|0;h=c[c[j>>2]>>2]|0;k=a[b+848|0]|0;l=a[b+849|0]|0;m=a[b+850|0]|0;n=a[b+851|0]|0;o=c[b+852>>2]|0;p=c[e>>2]|0;do{if((RCb(e)|0)==0){q=h+24|0;r=Zr(h,c[h+20>>2]|0,c[q>>2]|0)|0;if((r|0)!=0){NCb(r,c[g>>2]|0)|0;s=r;t=q;break}JCb(g);u=-12;i=f;return u|0}else{s=e;t=h+24|0}}while(0);e=c[s>>2]|0;q=c[t>>2]|0;a:do{if((q|0)>0){r=h+20|0;v=k&255;w=l&255;x=m&255;y=n&255;z=s+32|0;A=c[r>>2]|0;if((o|0)==4){B=e;C=0;D=p;E=A;F=q}else{G=e;H=0;I=p;J=A;A=q;while(1){if((ba(J,o)|0)>0){K=0;do{L=K+v|0;a[G+L|0]=a[b+((d[I+L|0]|0)+80)|0]|0;L=K+w|0;a[G+L|0]=a[b+((d[I+L|0]|0)+336)|0]|0;L=K+x|0;a[G+L|0]=a[b+((d[I+L|0]|0)+592)|0]|0;K=K+o|0;M=c[r>>2]|0;}while((K|0)<(ba(M,o)|0));N=M;O=c[t>>2]|0}else{N=J;O=A}K=c[g>>2]|0;L=H+1|0;if((L|0)<(O|0)){G=G+(c[z>>2]|0)|0;H=L;I=I+(c[K+32>>2]|0)|0;J=N;A=O}else{P=K;break a}}}while(1){if((E<<2|0)>0){A=0;do{J=A+v|0;a[B+J|0]=a[b+((d[D+J|0]|0)+80)|0]|0;J=A+w|0;a[B+J|0]=a[b+((d[D+J|0]|0)+336)|0]|0;J=A+x|0;a[B+J|0]=a[b+((d[D+J|0]|0)+592)|0]|0;if((c[g>>2]|0)!=(s|0)){J=A+y|0;a[B+J|0]=a[D+J|0]|0}A=A+4|0;Q=c[r>>2]|0;}while((A|0)<(Q<<2|0));R=Q;S=c[t>>2]|0}else{R=E;S=F}A=c[g>>2]|0;J=C+1|0;if((J|0)<(S|0)){B=B+(c[z>>2]|0)|0;C=J;D=D+(c[A+32>>2]|0)|0;E=R;F=S}else{P=A;break}}}else{P=c[g>>2]|0}}while(0);if((P|0)!=(s|0)){JCb(g)}u=cj(c[c[j>>2]>>2]|0,s)|0;i=f;return u|0}function sm(a){a=a|0;$Db((c[a+44>>2]|0)+200|0);return}function tm(a){a=a|0;Ok(a,xk(551408)|0);return 0}function um(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0;b=c[(c[a>>2]|0)+44>>2]|0;d=a+52|0;Aw(b+204|0,c[d>>2]|0)|0;a=c[d>>2]|0;if((a|0)==42|(a|0)==68|(a|0)==292|(a|0)==294){e=65536}else{e=256}a=WDb(e<<6)|0;d=a;c[b+200>>2]=d;if((a|0)==0){f=-12;return f|0}a=e<<2;c[b+136>>2]=d;c[b+140>>2]=d+(e<<2);g=e<<1;c[b+144>>2]=d+(g<<2);i=g|e;c[b+148>>2]=d+(i<<2);c[b+152>>2]=d+(a<<2);j=a|e;c[b+156>>2]=d+(j<<2);k=j+e|0;c[b+160>>2]=d+(k<<2);l=k+e|0;c[b+164>>2]=d+(l<<2);m=e<<3;c[b+168>>2]=d+(m<<2);n=m|e;c[b+172>>2]=d+(n<<2);o=n+e|0;c[b+176>>2]=d+(o<<2);p=o+e|0;c[b+180>>2]=d+(p<<2);q=m|a;c[b+184>>2]=d+(q<<2);r=q|e;c[b+188>>2]=d+(r<<2);s=r+e|0;c[b+192>>2]=d+(s<<2);t=s+e|0;c[b+196>>2]=d+(t<<2);u=+h[b+8>>3];v=+h[b+16>>3];w=+h[b+24>>3];x=+h[b+32>>3];y=+h[b+40>>3];z=+h[b+48>>3];A=+h[b+56>>3];B=+h[b+64>>3];C=+h[b+72>>3];D=+h[b+80>>3];E=+h[b+88>>3];F=+h[b+96>>3];G=+h[b+104>>3];H=+h[b+112>>3];I=+h[b+120>>3];J=+h[b+128>>3];b=0;while(1){K=+(b|0);c[d+(b<<2)>>2]=~~+Hb(+(K*u));c[d+(e+b<<2)>>2]=~~+Hb(+(K*v));c[d+(g+b<<2)>>2]=~~+Hb(+(K*w));c[d+(i+b<<2)>>2]=~~+Hb(+(K*x));c[d+(a+b<<2)>>2]=~~+Hb(+(K*y));c[d+(j+b<<2)>>2]=~~+Hb(+(K*z));c[d+(k+b<<2)>>2]=~~+Hb(+(K*A));c[d+(l+b<<2)>>2]=~~+Hb(+(K*B));c[d+(m+b<<2)>>2]=~~+Hb(+(K*C));c[d+(n+b<<2)>>2]=~~+Hb(+(K*D));c[d+(o+b<<2)>>2]=~~+Hb(+(K*E));c[d+(p+b<<2)>>2]=~~+Hb(+(K*F));c[d+(q+b<<2)>>2]=~~+Hb(+(K*G));c[d+(r+b<<2)>>2]=~~+Hb(+(K*H));c[d+(s+b<<2)>>2]=~~+Hb(+(K*I));c[d+(t+b<<2)>>2]=~~+Hb(+(K*J));L=b+1|0;if((L|0)<(e|0)){b=L}else{f=0;break}}return f|0}function vm(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;h=i;i=i+8|0;j=h|0;c[j>>2]=g;k=c[f+8>>2]|0;f=c[k+44>>2]|0;l=k+32|0;k=c[c[l>>2]>>2]|0;m=a[f+204|0]|0;n=a[f+205|0]|0;o=a[f+206|0]|0;p=a[f+207|0]|0;q=c[g>>2]|0;do{if((RCb(g)|0)==0){r=Zr(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((r|0)!=0){NCb(r,c[j>>2]|0)|0;s=r;break}JCb(j);t=-12;i=h;return t|0}else{s=g}}while(0);g=c[s>>2]|0;a:do{switch(c[k+52>>2]|0){case 29:case 27:case 30:case 28:{r=k+24|0;u=c[r>>2]|0;if((u|0)<=0){break a}v=k+20|0;w=s+32|0;x=m&255;y=n&255;z=o&255;A=p&255;B=f+136|0;C=f+140|0;D=f+144|0;E=f+148|0;F=f+152|0;G=f+156|0;H=f+160|0;I=f+164|0;J=f+168|0;K=f+172|0;L=f+176|0;M=f+180|0;N=f+184|0;O=f+188|0;P=f+192|0;Q=f+196|0;R=0;S=g;T=q;U=c[v>>2]|0;V=u;while(1){if((U<<2|0)>0){u=0;do{W=u+x|0;X=u+y|0;Y=u+z|0;Z=u+A|0;_=d[T+W|0]|0;$=d[T+X|0]|0;aa=d[T+Y|0]|0;ba=d[T+Z|0]|0;ca=(c[(c[C>>2]|0)+($<<2)>>2]|0)+(c[(c[B>>2]|0)+(_<<2)>>2]|0)+(c[(c[D>>2]|0)+(aa<<2)>>2]|0)+(c[(c[E>>2]|0)+(ba<<2)>>2]|0)|0;if(ca>>>0>255>>>0){da=-ca>>31&255}else{da=ca&255}a[S+W|0]=da;W=(c[(c[G>>2]|0)+($<<2)>>2]|0)+(c[(c[F>>2]|0)+(_<<2)>>2]|0)+(c[(c[H>>2]|0)+(aa<<2)>>2]|0)+(c[(c[I>>2]|0)+(ba<<2)>>2]|0)|0;if(W>>>0>255>>>0){ea=-W>>31&255}else{ea=W&255}a[S+X|0]=ea;X=(c[(c[K>>2]|0)+($<<2)>>2]|0)+(c[(c[J>>2]|0)+(_<<2)>>2]|0)+(c[(c[L>>2]|0)+(aa<<2)>>2]|0)+(c[(c[M>>2]|0)+(ba<<2)>>2]|0)|0;if(X>>>0>255>>>0){fa=-X>>31&255}else{fa=X&255}a[S+Y|0]=fa;Y=(c[(c[O>>2]|0)+($<<2)>>2]|0)+(c[(c[N>>2]|0)+(_<<2)>>2]|0)+(c[(c[P>>2]|0)+(aa<<2)>>2]|0)+(c[(c[Q>>2]|0)+(ba<<2)>>2]|0)|0;if(Y>>>0>255>>>0){ga=-Y>>31&255}else{ga=Y&255}a[S+Z|0]=ga;u=u+4|0;ha=c[v>>2]|0;}while((u|0)<(ha<<2|0));ia=ha;ja=c[r>>2]|0}else{ia=U;ja=V}u=R+1|0;if((u|0)<(ja|0)){R=u;S=S+(c[w>>2]|0)|0;T=T+(c[(c[j>>2]|0)+32>>2]|0)|0;U=ia;V=ja}else{break}}break};case 294:case 292:{V=c[k+24>>2]|0;if((V|0)<=0){break a}U=c[k+20>>2]<<2;T=(U|0)>0;w=c[(c[j>>2]|0)+32>>2]|0;S=c[s+32>>2]|0;R=m&255;r=n&255;v=o&255;Q=p&255;P=f+136|0;N=f+140|0;O=f+144|0;M=f+148|0;L=f+152|0;J=f+156|0;K=f+160|0;I=f+164|0;H=f+168|0;F=f+172|0;G=f+176|0;E=f+180|0;D=f+184|0;B=f+188|0;C=f+192|0;A=f+196|0;z=0;y=g;x=q;while(1){u=x;Z=y;if(T){Y=c[P>>2]|0;ba=c[N>>2]|0;aa=c[O>>2]|0;_=c[M>>2]|0;$=c[L>>2]|0;X=c[J>>2]|0;W=c[K>>2]|0;ca=c[I>>2]|0;ka=c[H>>2]|0;la=c[F>>2]|0;ma=c[G>>2]|0;na=c[E>>2]|0;oa=c[D>>2]|0;pa=c[B>>2]|0;qa=c[C>>2]|0;ra=c[A>>2]|0;sa=0;do{ta=sa+R|0;ua=sa+r|0;va=sa+v|0;wa=sa+Q|0;xa=e[u+(ta<<1)>>1]|0;ya=e[u+(ua<<1)>>1]|0;za=e[u+(va<<1)>>1]|0;Aa=e[u+(wa<<1)>>1]|0;Ba=(c[ba+(ya<<2)>>2]|0)+(c[Y+(xa<<2)>>2]|0)+(c[aa+(za<<2)>>2]|0)+(c[_+(Aa<<2)>>2]|0)|0;if(Ba>>>0>65535>>>0){Ca=-Ba>>31&65535}else{Ca=Ba&65535}b[Z+(ta<<1)>>1]=Ca;ta=(c[X+(ya<<2)>>2]|0)+(c[$+(xa<<2)>>2]|0)+(c[W+(za<<2)>>2]|0)+(c[ca+(Aa<<2)>>2]|0)|0;if(ta>>>0>65535>>>0){Da=-ta>>31&65535}else{Da=ta&65535}b[Z+(ua<<1)>>1]=Da;ua=(c[la+(ya<<2)>>2]|0)+(c[ka+(xa<<2)>>2]|0)+(c[ma+(za<<2)>>2]|0)+(c[na+(Aa<<2)>>2]|0)|0;if(ua>>>0>65535>>>0){Ea=-ua>>31&65535}else{Ea=ua&65535}b[Z+(va<<1)>>1]=Ea;va=(c[pa+(ya<<2)>>2]|0)+(c[oa+(xa<<2)>>2]|0)+(c[qa+(za<<2)>>2]|0)+(c[ra+(Aa<<2)>>2]|0)|0;if(va>>>0>65535>>>0){Fa=-va>>31&65535}else{Fa=va&65535}b[Z+(wa<<1)>>1]=Fa;sa=sa+4|0;}while((sa|0)<(U|0))}sa=z+1|0;if((sa|0)<(V|0)){z=sa;y=y+S|0;x=x+w|0}else{break}}break};case 3:case 2:{w=k+24|0;x=c[w>>2]|0;if((x|0)<=0){break a}S=k+20|0;y=s+32|0;z=m&255;V=n&255;U=o&255;Q=f+136|0;v=f+140|0;r=f+144|0;R=f+152|0;A=f+156|0;C=f+160|0;B=f+168|0;D=f+172|0;E=f+176|0;G=0;F=g;H=q;I=c[S>>2]|0;K=x;while(1){if((I*3|0|0)>0){x=0;do{J=x+z|0;L=x+V|0;M=x+U|0;O=d[H+J|0]|0;N=d[H+L|0]|0;P=d[H+M|0]|0;T=(c[(c[v>>2]|0)+(N<<2)>>2]|0)+(c[(c[Q>>2]|0)+(O<<2)>>2]|0)+(c[(c[r>>2]|0)+(P<<2)>>2]|0)|0;if(T>>>0>255>>>0){Ga=-T>>31&255}else{Ga=T&255}a[F+J|0]=Ga;J=(c[(c[A>>2]|0)+(N<<2)>>2]|0)+(c[(c[R>>2]|0)+(O<<2)>>2]|0)+(c[(c[C>>2]|0)+(P<<2)>>2]|0)|0;if(J>>>0>255>>>0){Ha=-J>>31&255}else{Ha=J&255}a[F+L|0]=Ha;L=(c[(c[D>>2]|0)+(N<<2)>>2]|0)+(c[(c[B>>2]|0)+(O<<2)>>2]|0)+(c[(c[E>>2]|0)+(P<<2)>>2]|0)|0;if(L>>>0>255>>>0){Ia=-L>>31&255}else{Ia=L&255}a[F+M|0]=Ia;x=x+3|0;Ja=c[S>>2]|0;}while((x|0)<(Ja*3|0|0));Ka=Ja;La=c[w>>2]|0}else{Ka=I;La=K}x=G+1|0;if((x|0)<(La|0)){G=x;F=F+(c[y>>2]|0)|0;H=H+(c[(c[j>>2]|0)+32>>2]|0)|0;I=Ka;K=La}else{break}}break};case 297:case 295:case 298:case 296:{K=k+24|0;I=c[K>>2]|0;if((I|0)<=0){break a}H=k+20|0;y=s+32|0;F=m&255;G=n&255;w=o&255;S=f+136|0;E=f+140|0;B=f+144|0;D=f+152|0;C=f+156|0;R=f+160|0;A=f+168|0;r=f+172|0;Q=f+176|0;v=p&255;U=0;V=g;z=q;x=c[H>>2]|0;M=I;while(1){if((x<<2|0)>0){I=0;do{L=I+F|0;P=I+G|0;O=I+w|0;N=d[z+L|0]|0;J=d[z+P|0]|0;T=d[z+O|0]|0;sa=(c[(c[E>>2]|0)+(J<<2)>>2]|0)+(c[(c[S>>2]|0)+(N<<2)>>2]|0)+(c[(c[B>>2]|0)+(T<<2)>>2]|0)|0;if(sa>>>0>255>>>0){Ma=-sa>>31&255}else{Ma=sa&255}a[V+L|0]=Ma;L=(c[(c[C>>2]|0)+(J<<2)>>2]|0)+(c[(c[D>>2]|0)+(N<<2)>>2]|0)+(c[(c[R>>2]|0)+(T<<2)>>2]|0)|0;if(L>>>0>255>>>0){Na=-L>>31&255}else{Na=L&255}a[V+P|0]=Na;P=(c[(c[r>>2]|0)+(J<<2)>>2]|0)+(c[(c[A>>2]|0)+(N<<2)>>2]|0)+(c[(c[Q>>2]|0)+(T<<2)>>2]|0)|0;if(P>>>0>255>>>0){Oa=-P>>31&255}else{Oa=P&255}a[V+O|0]=Oa;if((c[j>>2]|0)!=(s|0)){a[V+(I+v)|0]=0}I=I+4|0;Pa=c[H>>2]|0;}while((I|0)<(Pa<<2|0));Qa=Pa;Ra=c[K>>2]|0}else{Qa=x;Ra=M}I=U+1|0;if((I|0)<(Ra|0)){U=I;V=V+(c[y>>2]|0)|0;z=z+(c[(c[j>>2]|0)+32>>2]|0)|0;x=Qa;M=Ra}else{break}}break};case 68:case 42:{M=c[k+24>>2]|0;if((M|0)<=0){break a}x=(c[k+20>>2]|0)*3|0;z=c[(c[j>>2]|0)+32>>2]|0;y=c[s+32>>2]|0;V=m&255;U=n&255;K=o&255;H=f+136|0;v=f+140|0;Q=f+144|0;A=f+152|0;r=f+156|0;R=f+160|0;D=f+168|0;C=f+172|0;B=f+176|0;if((x|0)>0){Sa=0;Ta=g;Ua=q}else{break a}while(1){S=Ua;E=Ta;w=c[H>>2]|0;G=c[v>>2]|0;F=c[Q>>2]|0;I=c[A>>2]|0;O=c[r>>2]|0;P=c[R>>2]|0;T=c[D>>2]|0;N=c[C>>2]|0;J=c[B>>2]|0;L=0;do{sa=L+V|0;Z=L+U|0;ra=L+K|0;qa=e[S+(sa<<1)>>1]|0;oa=e[S+(Z<<1)>>1]|0;pa=e[S+(ra<<1)>>1]|0;na=(c[G+(oa<<2)>>2]|0)+(c[w+(qa<<2)>>2]|0)+(c[F+(pa<<2)>>2]|0)|0;if(na>>>0>65535>>>0){Va=-na>>31&65535}else{Va=na&65535}b[E+(sa<<1)>>1]=Va;sa=(c[O+(oa<<2)>>2]|0)+(c[I+(qa<<2)>>2]|0)+(c[P+(pa<<2)>>2]|0)|0;if(sa>>>0>65535>>>0){Wa=-sa>>31&65535}else{Wa=sa&65535}b[E+(Z<<1)>>1]=Wa;Z=(c[N+(oa<<2)>>2]|0)+(c[T+(qa<<2)>>2]|0)+(c[J+(pa<<2)>>2]|0)|0;if(Z>>>0>65535>>>0){Xa=-Z>>31&65535}else{Xa=Z&65535}b[E+(ra<<1)>>1]=Xa;L=L+3|0;}while((L|0)<(x|0));L=Sa+1|0;if((L|0)<(M|0)){Sa=L;Ta=Ta+y|0;Ua=Ua+z|0}else{break}}break};default:{}}}while(0);if((c[j>>2]|0)!=(s|0)){JCb(j)}t=cj(c[c[l>>2]>>2]|0,s)|0;i=h;return t|0}function wm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[c[(c[a+8>>2]|0)+32>>2]>>2]|0;a=Zr(f,c[b+68>>2]|0,c[b+72>>2]|0)|0;if((a|0)==0){JCb(e);g=-12;i=d;return g|0}else{NCb(a,b)|0;OCb(a,c[e>>2]|0)|0;JCb(e);g=cj(f,a)|0;i=d;return g|0}return 0}function xm(a){a=a|0;var b=0;b=c[a+44>>2]|0;a=b+72|0;IBb(c[a>>2]|0);c[a>>2]=0;a=b+76|0;IBb(c[a>>2]|0);c[a>>2]=0;return}function ym(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=0;do{g=bFb(f)|0;h=a[g+7|0]|0;do{if((h&12)==0){if((a[g+5|0]|0)==0){if((a[g+6|0]|0)!=0){j=5}}else{j=5}if((j|0)==5){j=0;if((h&16)==0){break}}zk(e,f,(f|0)<0|0?-1:0)|0}}while(0);f=f+1|0;}while((f|0)<333);Ok(b,c[e>>2]|0);i=d;return 0}function zm(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+12>>2];c[a+24>>2]=c[b+16>>2];d=b+20|0;b=a+28|0;a=c[d+4>>2]|0;c[b>>2]=c[d>>2];c[b+4>>2]=a;return 0}function Am(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,l=0,m=0,n=0,o=0.0,p=0.0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b+8|0;f=c[(c[e>>2]|0)+44>>2]|0;g=bFb(c[b+52>>2]|0)|0;i=f+12|0;c[d+68>>2]=c[i>>2];j=f+16|0;c[d+72>>2]=c[j>>2];l=b+160|0;h[f+200>>3]=+((c[l>>2]|0)>>>0)+ +(c[l+4>>2]|0)*4294967296.0;l=d+136|0;m=c[l>>2]|0;n=c[l+4>>2]|0;if((m|0)==0&(n|0)==(-2147483648|0)){o=+q}else{o=(+(m>>>0)+ +(n|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}h[f+216>>3]=o;n=sCb(d)|0;if((n|0)==(-1|0)&(F|0)==(-1|0)){p=+q}else{n=sCb(d)|0;p=+(n>>>0)+ +(F|0)*4294967296.0}h[f+208>>3]=p;n=f+72|0;m=f+80|0;l=f+184|0;h[l>>3]=+MBb(c[n>>2]|0,m,0);r=f+192|0;h[r>>3]=+MBb(c[f+76>>2]|0,m,0);p=+MBb(c[n>>2]|0,m,0);h[l>>3]=p;l=f+4|0;h[k>>3]=p;m=c[k+4>>2]&2147483647;n=2146435072;do{if(!(m>>>0>n>>>0|m>>>0==n>>>0&(c[k>>2]|0)>>>0>0>>>0)){s=p>2147483647.0;if(s|p<-2147483648.0){c[l>>2]=s?2147483647:-2147483648;break}else{c[l>>2]=~~+Hb(+p);break}}}while(0);n=f+8|0;p=+h[r>>3];m=c[r+4>>2]&2147483647;s=2146435072;do{if(!(m>>>0>s>>>0|m>>>0==s>>>0&(c[r>>2]|0)>>>0>0>>>0)){t=p>2147483647.0;if(t|p<-2147483648.0){c[n>>2]=t?2147483647:-2147483648;break}else{c[n>>2]=~~+Hb(+p);break}}}while(0);r=c[l>>2]|0;if((r|0)<0){c[l>>2]=0;u=0}else{u=r}r=c[n>>2]|0;if((r|0)<0){c[n>>2]=0;v=0}else{v=r}r=c[i>>2]|0;i=c[b+20>>2]|0;if((r+u|0)>>>0>i>>>0){s=i-r|0;c[l>>2]=s;w=s}else{w=u}u=c[j>>2]|0;j=c[b+24>>2]|0;if((u+v|0)>>>0>j>>>0){b=j-u|0;c[n>>2]=b;x=b}else{x=v}v=c[f+48>>2]|0;b=w&-1<<v;c[l>>2]=b;l=c[f+52>>2]|0;w=x&-1<<l;c[n>>2]=w;n=ba(w,c[d+32>>2]|0)|0;x=d|0;c[x>>2]=(c[x>>2]|0)+((ba(c[f+32>>2]|0,b)|0)+n);do{if((a[g+7|0]&66)==0){n=d+4|0;x=c[n>>2]|0;if((x|0)!=0){u=ba(w>>l,c[d+36>>2]|0)|0;c[n>>2]=x+(((ba(c[f+36>>2]|0,b)|0)>>v)+u)}u=d+8|0;x=c[u>>2]|0;if((x|0)==0){break}n=ba(w>>l,c[d+40>>2]|0)|0;c[u>>2]=x+(((ba(c[f+40>>2]|0,b)|0)>>v)+n)}}while(0);v=d+12|0;l=c[v>>2]|0;if((l|0)==0){y=c[e>>2]|0;z=y+32|0;A=c[z>>2]|0;B=c[A>>2]|0;C=cj(B,d)|0;return C|0}g=ba(c[d+44>>2]|0,w)|0;c[v>>2]=l+((ba(c[f+44>>2]|0,b)|0)+g);y=c[e>>2]|0;z=y+32|0;A=c[z>>2]|0;B=c[A>>2]|0;C=cj(B,d)|0;return C|0}function Bm(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,r=0,s=0,t=0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+24|0;e=b|0;f=b+8|0;g=b+16|0;j=c[a+8>>2]|0;k=c[j+44>>2]|0;l=bFb(c[a+52>>2]|0)|0;m=c[c[j+16>>2]>>2]|0;n=+(c[m+20>>2]|0);h[k+88>>3]=n;o=k+80|0;h[o>>3]=n;n=+(c[m+24>>2]|0);h[k+104>>3]=n;h[k+96>>3]=n;m=a+20|0;p=a+24|0;n=+(c[m>>2]|0)/+(c[p>>2]|0);h[k+144>>3]=n;r=a+28|0;s=r|0;t=c[s>>2]|0;if((t|0)==0){u=1.0}else{u=+(t|0)/+(c[a+32>>2]|0)}h[k+152>>3]=u;h[k+160>>3]=u*n;t=l+5|0;h[k+168>>3]=+(1<<(d[t]|0)|0);v=l+6|0;h[k+176>>3]=+(1<<(d[v]|0)|0);h[k+184>>3]=+q;h[k+192>>3]=+q;w=k+120|0;h[w>>3]=+q;x=k+112|0;h[x>>3]=+q;y=k+136|0;h[y>>3]=+q;z=k+128|0;h[z>>3]=+q;h[k+200>>3]=0.0;h[k+216>>3]=+q;h[k+208>>3]=+q;bDb(k+32|0,0,l);l=k+48|0;c[l>>2]=d[t]|0;t=k+52|0;c[t>>2]=d[v]|0;v=k+64|0;A=c[v>>2]|0;B=j;j=OBb(e,A,160344,o,0,0,0,0,0,0,B)|0;do{if((j|0)<0){C=A;D=j}else{n=+h[e>>3];h[w>>3]=n;h[x>>3]=n;E=k+68|0;F=c[E>>2]|0;G=OBb(e,F,160344,o,0,0,0,0,0,0,B)|0;if((G|0)<0){C=F;D=G;break}n=+h[e>>3];h[y>>3]=n;h[z>>3]=n;G=c[v>>2]|0;F=OBb(e,G,160344,o,0,0,0,0,0,0,B)|0;if((F|0)<0){C=G;D=F;break}n=+h[e>>3];F=c[e>>2]|0;G=c[e+4>>2]|0;h[w>>3]=n;h[x>>3]=n;H=k+12|0;I=G&2147483647;G=2146435072;do{if(!(I>>>0>G>>>0|I>>>0==G>>>0&(F|0)>>>0>0>>>0)){J=n>2147483647.0;if(J|n<-2147483648.0){c[H>>2]=J?2147483647:-2147483648;break}J=~~+Hb(+n);c[H>>2]=J;K=k+16|0;u=+h[z>>3];L=c[z+4>>2]&2147483647;M=2146435072;if(L>>>0>M>>>0|L>>>0==M>>>0&(c[z>>2]|0)>>>0>0>>>0){break}M=u>2147483647.0;if(M|u<-2147483648.0){c[K>>2]=M?2147483647:-2147483648;break}M=~~+Hb(+u);c[H>>2]=J&-1<<c[l>>2];c[K>>2]=M&-1<<c[t>>2];M=k+72|0;IBb(c[M>>2]|0);J=k+76|0;IBb(c[J>>2]|0);c[J>>2]=0;c[M>>2]=0;if((JBb(M,c[k+56>>2]|0,160344,0,0,0,0,0,B)|0)<0){N=-22;i=b;return N|0}if((JBb(J,c[k+60>>2]|0,160344,0,0,0,0,0,B)|0)<0){N=-22;i=b;return N|0}if((c[k+28>>2]|0)==0){J=r;M=k+20|0;L=c[J>>2]|0;O=c[J+4>>2]|0;c[M>>2]=L;c[M+4>>2]=O;P=L;Q=O}else{c[g>>2]=c[m>>2];c[g+4>>2]=c[p>>2];jFb(f,r,g);O=k+20|0;L=k+24|0;M=ba(c[K>>2]|0,c[f>>2]|0)|0;J=ba(c[H>>2]|0,c[f+4>>2]|0)|0;iFb(O,L,M,(M|0)<0|0?-1:0,J,(J|0)<0|0?-1:0,2147483647,0)|0;P=c[O>>2]|0;Q=c[L>>2]|0}L=c[p>>2]|0;O=c[s>>2]|0;J=c[a+32>>2]|0;M=c[H>>2]|0;R=c[K>>2]|0;yDb(B,40,2199656,(S=i,i=i+64|0,c[S>>2]=c[m>>2],c[S+8>>2]=L,c[S+16>>2]=O,c[S+24>>2]=J,c[S+32>>2]=M,c[S+40>>2]=R,c[S+48>>2]=P,c[S+56>>2]=Q,S)|0);i=S;R=c[H>>2]|0;M=c[K>>2]|0;do{if(!((R|0)<1|(M|0)<1)){K=c[m>>2]|0;if((R|0)>(K|0)){break}if((M|0)>(c[p>>2]|0)){break}J=(K-R|0)/2|0;K=k+4|0;c[K>>2]=J;O=((c[p>>2]|0)-M|0)/2|0;c[K>>2]=J&-1<<c[l>>2];c[k+8>>2]=O&-1<<c[t>>2];N=0;i=b;return N|0}}while(0);yDb(B,16,2191040,(S=i,i=i+16|0,c[S>>2]=R,c[S+8>>2]=M,S)|0);i=S;N=-22;i=b;return N|0}}while(0);H=c[E>>2]|0;yDb(B,16,2207960,(S=i,i=i+16|0,c[S>>2]=c[v>>2],c[S+8>>2]=H,S)|0);i=S;N=-22;i=b;return N|0}}while(0);yDb(0,16,2174408,(S=i,i=i+8|0,c[S>>2]=C,S)|0);i=S;N=D;i=b;return N|0}function Cm(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0.0,R=0,S=0.0,T=0.0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0.0,aa=0.0,ba=0.0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0,ka=0.0,la=0,ma=0,na=0,oa=0;e=i;i=i+1064|0;f=e|0;g=e+8|0;j=e+16|0;k=e+24|0;l=e+1048|0;m=b+44|0;n=c[m>>2]|0;TGb(l|0,0,16)|0;o=n+8|0;p=o;q=o;o=c[n+24>>2]|0;do{if((o|0)!=0){do{if((c[q>>2]|0)==0){r=eEb(o)|0;c[q>>2]=r;if((r|0)==0){s=-12}else{break}i=e;return s|0}}while(0);r=n+12|0;do{if((c[r>>2]|0)==0){t=eEb(o)|0;c[r>>2]=t;if((t|0)==0){s=-12}else{break}i=e;return s|0}}while(0);r=n+16|0;if((c[r>>2]|0)!=0){break}t=eEb(o)|0;c[r>>2]=t;if((t|0)==0){s=-12}else{break}i=e;return s|0}}while(0);o=c[n+1052>>2]|0;do{if((o|0)!=0){t=c[m>>2]|0;IAb(k,0,1);r=aCb(o,g,j,0,0)|0;a:do{if((r|0)<0){u=r}else{v=c[j>>2]|0;if(v>>>0<2>>>0){u=-1094995529;break}w=c[g>>2]|0;x=w+2|0;c[g>>2]=x;y=v-2|0;c[j>>2]=y;if(y>>>0<2>>>0){u=-1094995529;break}y=x;x=(de((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535;c[g>>2]=w+4;c[j>>2]=v-4;v=x>>>0>4>>>0?4:x;b:do{if((v|0)==0){z=r}else{x=k|0;w=t+8|0;y=b;A=0;while(1){PAb(k);B=c[j>>2]|0;if(B>>>0<2>>>0){u=-1094995529;break a}C=c[g>>2]|0;D=C;E=(d[D]|d[D+1|0]<<8)<<16>>16;D=(de(E|0)|0)&65535;F=C+2|0;c[g>>2]=F;C=B-2|0;c[j>>2]=C;c:do{if(!(E<<16>>16==0)){if(C>>>0<2>>>0){u=-1094995529;break a}else{G=C;H=1;I=F}while(1){B=I;J=(d[B]|d[B+1|0]<<8)<<16>>16;B=I+2|0;c[g>>2]=B;K=G-2|0;c[j>>2]=K;if(K>>>0<2>>>0){u=-1094995529;break a}K=(de(J|0)|0)&65535;J=B;B=(de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535;c[g>>2]=I+4;c[j>>2]=G-4;KAb(k,2113328,(L=i,i=i+16|0,h[L>>3]=+(B|0)/255.0,h[L+8>>3]=+(K|0)/255.0,L)|0);i=L;if((H|0)>=(D|0)){break c}K=c[j>>2]|0;if(K>>>0<2>>>0){u=-1094995529;break a}G=K;H=H+1|0;I=c[g>>2]|0}}}while(0);F=c[x>>2]|0;do{if((a[F]|0)!=0){C=c[592648+(A<<2)>>2]|0;E=w+(C<<2)|0;if((c[E>>2]|0)!=0){break}K=eEb(F)|0;c[E>>2]=K;yDb(y,48,2099080,(L=i,i=i+32|0,c[L>>2]=A,c[L+8>>2]=C,c[L+16>>2]=D,c[L+24>>2]=K,L)|0);i=L;if((c[E>>2]|0)==0){z=-12;break b}}}while(0);D=A+1|0;if(D>>>0<v>>>0){A=D}else{z=r;break}}}}while(0);QAb(k,0)|0;bCb(c[g>>2]|0,c[j>>2]|0);u=z}}while(0);if((u|0)<0){s=u}else{break}i=e;return s|0}}while(0);u=n+4|0;z=c[u>>2]|0;do{if((z|0)!=0){do{if((c[q>>2]|0)==0){if((1030>>>(z>>>0)&1|0)==0){break}j=eEb(c[1415768+(z<<4)>>2]|0)|0;c[q>>2]=j;if((j|0)==0){s=-12}else{break}i=e;return s|0}}while(0);j=n+12|0;do{if((c[j>>2]|0)==0){g=c[u>>2]|0;if((1030>>>(g>>>0)&1|0)==0){break}k=eEb(c[1415772+(g<<4)>>2]|0)|0;c[j>>2]=k;if((k|0)==0){s=-12}else{break}i=e;return s|0}}while(0);j=n+16|0;do{if((c[j>>2]|0)==0){k=c[u>>2]|0;if((1030>>>(k>>>0)&1|0)==0){break}g=eEb(c[1415776+(k<<4)>>2]|0)|0;c[j>>2]=g;if((g|0)==0){s=-12}else{break}i=e;return s|0}}while(0);j=n+20|0;if((c[j>>2]|0)!=0){break}g=c[u>>2]|0;if(!((g-3|0)>>>0<7>>>0)){break}k=eEb(c[1415780+(g<<4)>>2]|0)|0;c[j>>2]=k;if((k|0)==0){s=-12}else{break}i=e;return s|0}}while(0);u=n+28|0;q=b;b=0;d:while(1){if((b|0)>=4){M=101;break}z=l+(b<<2)|0;k=c[p+(b<<2)>>2]|0;c[f>>2]=k;e:do{if((k|0)==0){N=0}else{j=k;O=0;while(1){if((a[j]|0)==0){N=O;break e}g=cEb(24)|0;if((g|0)==0){s=-12;M=112;break d}I=g;H=g;G=g+8|0;TGb(g|0,0,20)|0;h[H>>3]=+HBb(j,f);g=c[f>>2]|0;do{if((g|0)==0){P=0}else{if((a[g]|0)==0){P=g;break}o=g+1|0;c[f>>2]=o;P=o}}while(0);Q=+HBb(P,f);h[G>>3]=Q;g=c[f>>2]|0;do{if((g|0)==0){R=0}else{if((a[g]|0)==0){R=g;break}o=g+1|0;c[f>>2]=o;R=o}}while(0);S=+h[H>>3];if(S<0.0|S>1.0){M=51;break d}if(Q<0.0|Q>1.0){M=51;break d}if((c[z>>2]|0)==0){c[z>>2]=I}if((O|0)!=0){T=+h[O>>3];if((~~(T*255.0)|0)>=(~~(S*255.0)|0)){M=56;break d}c[O+16>>2]=I}if((R|0)==0){N=I;break}else{j=R;O=I}}}}while(0);k=c[z>>2]|0;if((k|0)==0){j=cEb(24)|0;if((j|0)==0){s=-12;M=112;break}g=j;TGb(j|0,0,20)|0;h[j>>3]=0.0;c[z>>2]=g;U=g;V=g}else{if(+h[k>>3]!=0.0){g=cEb(24)|0;if((g|0)==0){s=-12;M=112;break}TGb(g|0,0,16)|0;c[g+16>>2]=k;j=g;c[z>>2]=j;W=j}else{W=k}if((N|0)==0){M=65;break}else{U=N;V=W}}if(+h[U>>3]!=1.0){k=cEb(24)|0;if((k|0)==0){s=-12;M=112;break}h[k>>3]=1.0;h[k+8>>3]=1.0;c[k+16>>2]=0;c[U+16>>2]=k;X=c[z>>2]|0}else{X=V}k=(X|0)==0;if(k){Y=0}else{j=X;g=0;while(1){G=g+1|0;o=c[j+16>>2]|0;if((o|0)==0){Y=G;break}else{j=o;g=G}}}g=dEb(Y,24)|0;j=g;z=Y-1|0;G=WDb(z<<3)|0;o=G;m=dEb(Y,8)|0;r=m;if((g|0)==0|(G|0)==0|(m|0)==0){Z=-12}else{if(!k){_=0.0;t=X;v=-1;while(1){A=t|0;if(!((v|0)==-1)){h[o+(v<<3)>>3]=+h[A>>3]-_}y=c[t+16>>2]|0;if((y|0)==0){break}else{_=+h[A>>3];t=y;v=v+1|0}}}if((z|0)>1){_=+h[o>>3];v=X;t=1;$=_;k=c[X+16>>2]|0;while(1){aa=+h[k+8>>3];y=c[k+16>>2]|0;ba=+h[o+(t<<3)>>3];h[r+(t<<3)>>3]=((+h[y+8>>3]-aa)/ba-(aa- +h[v+8>>3])/$)*6.0;A=t+1|0;if((A|0)<(z|0)){v=k;t=A;$=ba;k=y}else{break}}h[j+(z*24|0)+8>>3]=1.0;h[g+8>>3]=1.0;k=1;$=_;while(1){h[j+(k*24|0)>>3]=$;ba=+h[o+(k<<3)>>3];h[j+(k*24|0)+8>>3]=($+ba)*2.0;h[j+(k*24|0)+16>>3]=ba;t=k+1|0;if((t|0)<(z|0)){k=t;$=ba}else{break}}}else{h[j+(z*24|0)+8>>3]=1.0;h[g+8>>3]=1.0}if((Y|0)>1){k=1;$=+h[g+16>>3];do{_=+h[j+(k*24|0)>>3];ba=+h[j+(k*24|0)+8>>3]-$*_;if(ba!=0.0){ca=1.0/ba}else{ca=1.0}t=j+(k*24|0)+16|0;$=ca*+h[t>>3];h[t>>3]=$;t=r+(k<<3)|0;h[t>>3]=ca*(+h[t>>3]-_*+h[r+(k-1<<3)>>3]);k=k+1|0;}while((k|0)<(Y|0))}k=Y-2|0;if((k|0)>-1){t=k;$=+h[r+(z<<3)>>3];while(1){k=r+(t<<3)|0;_=+h[k>>3]-$*+h[j+(t*24|0)+16>>3];h[k>>3]=_;if((t|0)>0){t=t-1|0;$=_}else{break}}}t=X+16|0;j=c[t>>2]|0;if((j|0)==0){M=91;break}else{da=X;ea=0;fa=t;ga=j}while(1){$=+h[da+8>>3];_=+h[o+(ea<<3)>>3];ba=+h[r+(ea<<3)>>3];j=ea+1|0;aa=+h[r+(j<<3)>>3]-ba;ha=(+h[ga+8>>3]-$)/_-_*ba*.5-_*aa/6.0;ia=ba*.5;ba=aa/(_*6.0);t=~~(+h[da>>3]*255.0);z=~~(+h[ga>>3]*255.0);if(!((z|t)>>>0<256>>>0)){M=94;break d}if((t|0)>(z|0)){ja=ga}else{k=t;do{_=+(k-t|0)/255.0;aa=$+ha*_+_*ia*_+_*_*ba*_;ka=aa;if(ka<0.0){la=0}else{la=ka>1.0?-1:~~(ka*255.0)}a[u+(b<<8)+k|0]=la;yDb(q,48,2329032,(L=i,i=i+32|0,h[L>>3]=_,h[L+8>>3]=aa,c[L+16>>2]=k,c[L+24>>2]=la&255,L)|0);i=L;k=k+1|0;}while((k|0)<=(z|0));ja=c[fa>>2]|0}z=ja+16|0;k=c[z>>2]|0;if((k|0)==0){Z=0;break}else{da=ja;ea=j;fa=z;ga=k}}}ZDb(g);ZDb(G);ZDb(m);if((Z|0)<0){s=Z;M=112;break}else{b=b+1|0}}if((M|0)==51){yDb(q,16,2304624,(L=i,i=i+16|0,h[L>>3]=S,h[L+8>>3]=Q,L)|0);i=L;s=-22;i=e;return s|0}else if((M|0)==56){ca=+h[O+8>>3];yDb(q,16,2286752,(L=i,i=i+32|0,h[L>>3]=T,h[L+8>>3]=ca,h[L+16>>3]=S,h[L+24>>3]=Q,L)|0);i=L;s=-22;i=e;return s|0}else if((M|0)==65){yDb(0,0,1935536,(L=i,i=i+24|0,c[L>>2]=2270720,c[L+8>>2]=1891680,c[L+16>>2]=194,L)|0);i=L;Cd();return 0}else if((M|0)==91){yDb(0,0,1935536,(L=i,i=i+24|0,c[L>>2]=1912200,c[L+8>>2]=1891680,c[L+16>>2]=283,L)|0);i=L;Cd();return 0}else if((M|0)==94){yDb(0,0,1935536,(L=i,i=i+24|0,c[L>>2]=2349184,c[L+8>>2]=1891680,c[L+16>>2]=298,L)|0);i=L;Cd();return 0}else if((M|0)==101){if((c[n+20>>2]|0)!=0){O=0;while(1){b=u+O|0;a[b]=a[n+((d[b]|0)+796)|0]|0;b=O+1|0;if((b|0)<256){O=b}else{ma=0;break}}while(1){O=u+256+ma|0;a[O]=a[n+((d[O]|0)+796)|0]|0;O=ma+1|0;if((O|0)<256){ma=O}else{na=0;break}}do{ma=u+512+na|0;a[ma]=a[n+((d[ma]|0)+796)|0]|0;na=na+1|0;}while((na|0)<256)}na=l|0;if((zDb()|0)>39){n=c[na>>2]|0;yDb(q,40,2178704,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L;if((n|0)!=0){ma=n;do{Q=+h[ma+8>>3];yDb(q,40,2102416,(L=i,i=i+16|0,h[L>>3]=+h[ma>>3],h[L+8>>3]=Q,L)|0);i=L;ma=c[ma+16>>2]|0;}while((ma|0)!=0)}yDb(q,40,2046296,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;yDb(q,40,2000664,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L;ma=0;do{yDb(q,40,1963664,(L=i,i=i+8|0,c[L>>2]=d[u+ma|0]|0,L)|0);i=L;ma=ma+1|0;}while((ma|0)<256);yDb(q,40,2046296,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;ma=c[l+4>>2]|0;yDb(q,40,2178704,(L=i,i=i+8|0,c[L>>2]=1,L)|0);i=L;if((ma|0)!=0){n=ma;do{Q=+h[n+8>>3];yDb(q,40,2102416,(L=i,i=i+16|0,h[L>>3]=+h[n>>3],h[L+8>>3]=Q,L)|0);i=L;n=c[n+16>>2]|0;}while((n|0)!=0)}yDb(q,40,2046296,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;yDb(q,40,2000664,(L=i,i=i+8|0,c[L>>2]=1,L)|0);i=L;n=0;do{yDb(q,40,1963664,(L=i,i=i+8|0,c[L>>2]=d[u+256+n|0]|0,L)|0);i=L;n=n+1|0;}while((n|0)<256);yDb(q,40,2046296,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;n=c[l+8>>2]|0;yDb(q,40,2178704,(L=i,i=i+8|0,c[L>>2]=2,L)|0);i=L;if((n|0)!=0){ma=n;do{Q=+h[ma+8>>3];yDb(q,40,2102416,(L=i,i=i+16|0,h[L>>3]=+h[ma>>3],h[L+8>>3]=Q,L)|0);i=L;ma=c[ma+16>>2]|0;}while((ma|0)!=0)}yDb(q,40,2046296,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;yDb(q,40,2000664,(L=i,i=i+8|0,c[L>>2]=2,L)|0);i=L;ma=0;do{yDb(q,40,1963664,(L=i,i=i+8|0,c[L>>2]=d[u+512+ma|0]|0,L)|0);i=L;ma=ma+1|0;}while((ma|0)<256);yDb(q,40,2046296,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L}L=c[na>>2]|0;if((L|0)!=0){na=L;while(1){L=c[na+16>>2]|0;ZDb(na);if((L|0)==0){break}else{na=L}}}na=c[l+4>>2]|0;if((na|0)!=0){L=na;while(1){na=c[L+16>>2]|0;ZDb(L);if((na|0)==0){break}else{L=na}}}L=c[l+8>>2]|0;if((L|0)!=0){na=L;while(1){L=c[na+16>>2]|0;ZDb(na);if((L|0)==0){break}else{na=L}}}na=c[l+12>>2]|0;if((na|0)==0){s=0;i=e;return s|0}else{oa=na}while(1){na=c[oa+16>>2]|0;ZDb(oa);if((na|0)==0){s=0;break}else{oa=na}}i=e;return s|0}else if((M|0)==112){i=e;return s|0}return 0}function Dm(a){a=a|0;Ok(a,xk(551360)|0);return 0}function Em(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;a=c[c[g+32>>2]>>2]|0;do{if((RCb(b)|0)==0){h=a+24|0;j=Zr(a,c[a+20>>2]|0,c[h>>2]|0)|0;if((j|0)!=0){NCb(j,c[e>>2]|0)|0;k=j;l=c[e>>2]|0;m=h;break}JCb(e);n=-12;i=d;return n|0}else{k=b;l=b;m=a+24|0}}while(0);c[f>>2]=l;c[f+4>>2]=k;l=c[m>>2]|0;m=c[(c[g+48>>2]|0)+28>>2]|0;Pe[c[c[g+56>>2]>>2]&255](g,690,f,0,(l|0)>(m|0)?m:l)|0;if((k|0)!=(c[e>>2]|0)){JCb(e)}n=cj(a,k)|0;i=d;return n|0}function Fm(a){a=a|0;var b=0,d=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=a+52|0;a=bFb(c[d>>2]|0)|0;Aw(b+1056|0,c[d>>2]|0)|0;c[b+1060>>2]=(aFb(a)|0)>>3;return 0}function Gm(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=c[b+44>>2]|0;b=c[e>>2]|0;i=c[e+4>>2]|0;e=c[h+1060>>2]|0;j=c[b+72>>2]|0;k=(ba(j,f)|0)/(g|0)|0;l=(ba(j,f+1|0)|0)/(g|0)|0;g=i+32|0;f=c[g>>2]|0;j=(c[i>>2]|0)+(ba(f,k)|0)|0;m=b+32|0;n=c[m>>2]|0;o=(c[b>>2]|0)+(ba(n,k)|0)|0;if((k|0)>=(l|0)){return 0}p=b+68|0;q=d[h+1056|0]|0;r=d[h+1057|0]|0;s=d[h+1058|0]|0;t=d[h+1059|0]|0;u=c[p>>2]|0;if((i|0)!=(b|0)&(e|0)==4){b=k;i=j;v=o;w=u;x=f;y=n;while(1){if((w<<2|0)>0){z=0;do{A=z+q|0;a[i+A|0]=a[h+((d[v+A|0]|0)+28)|0]|0;A=z+r|0;a[i+A|0]=a[h+((d[v+A|0]|0)+284)|0]|0;A=z+s|0;a[i+A|0]=a[h+((d[v+A|0]|0)+540)|0]|0;A=z+t|0;a[i+A|0]=a[v+A|0]|0;z=z+4|0;B=c[p>>2]|0;}while((z|0)<(B<<2|0));C=B;D=c[g>>2]|0;E=c[m>>2]|0}else{C=w;D=x;E=y}z=b+1|0;if((z|0)<(l|0)){b=z;i=i+D|0;v=v+E|0;w=C;x=D;y=E}else{break}}return 0}else{E=k;k=j;j=o;o=u;u=f;f=n;while(1){if((ba(o,e)|0)>0){n=0;do{y=n+q|0;a[k+y|0]=a[h+((d[j+y|0]|0)+28)|0]|0;y=n+r|0;a[k+y|0]=a[h+((d[j+y|0]|0)+284)|0]|0;y=n+s|0;a[k+y|0]=a[h+((d[j+y|0]|0)+540)|0]|0;n=n+e|0;F=c[p>>2]|0;}while((n|0)<(ba(F,e)|0));G=F;H=c[g>>2]|0;I=c[m>>2]|0}else{G=o;H=u;I=f}n=E+1|0;if((n|0)<(l|0)){E=n;k=k+H|0;j=j+I|0;o=G;u=H;f=I}else{break}}return 0}return 0}function Hm(a){a=a|0;var b=0,d=0,e=0,f=0,h=0;b=c[a+44>>2]|0;d=c[b+4>>2]|0;do{if((d|0)!=0){e=JBb(b+8|0,d,160336,0,0,0,0,0,a)|0;if((e|0)<0){f=e}else{break}return f|0}}while(0);g[b+36>>2]=+g[b+32>>2]*3.0;c[b+112>>2]=16-(c[b+108>>2]|0);a=b+116|0;c[a>>2]=sZ(4,0)|0;d=b+120|0;c[d>>2]=sZ(4,1)|0;e=b+124|0;c[e>>2]=WDb(1024)|0;h=WDb(1024)|0;c[b+128>>2]=h;if((c[a>>2]|0)==0){f=-12;return f|0}if((c[d>>2]|0)==0|(h|0)==0){f=-12;return f|0}else{return((c[e>>2]|0)==0?-12:0)|0}return 0}function Im(a){a=a|0;var b=0;b=c[a+44>>2]|0;uZ(c[b+116>>2]|0);uZ(c[b+120>>2]|0);ZDb(c[b+124>>2]|0);ZDb(c[b+128>>2]|0);ZDb(c[b+100>>2]|0);ZDb(c[b+76>>2]|0);ZDb(c[b+80>>2]|0);ZDb(c[b+84>>2]|0);ZDb(c[b+88>>2]|0);ZDb(c[b+92>>2]|0);ZDb(c[b+96>>2]|0);IBb(c[b+8>>2]|0);return}function Jm(a){a=a|0;Ok(a,xk(551344)|0);return 0}function Km(b,e){b=b|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0.0,aa=0,ca=0,da=0,ea=0.0,fa=0,ga=0,ha=0,ia=0,ja=0;f=i;i=i+8|0;j=f|0;c[j>>2]=e;k=c[b+8>>2]|0;l=k+44|0;m=c[l>>2]|0;n=c[c[k+32>>2]>>2]|0;do{if((RCb(e)|0)==0){k=Zr(n,c[n+20>>2]|0,c[n+24>>2]|0)|0;if((k|0)!=0){NCb(k,c[j>>2]|0)|0;o=0;p=k;q=c[j>>2]|0;break}JCb(j);r=-12;i=f;return r|0}else{o=1;p=e;q=e}}while(0);e=m+40|0;k=m+76|0;s=k;t=m+104|0;u=c[t>>2]|0;v=c[q+32>>2]|0;w=m+24|0;x=c[w>>2]|0;y=m+28|0;z=c[y>>2]|0;do{if((z|0)>0){A=e;B=m+44|0;C=m+48|0;D=m+52|0;E=m+56|0;F=m+60|0;G=m+64|0;H=m+68|0;I=m+72|0;if((x|0)<=0){break}J=c[q>>2]|0;K=0;L=c[k>>2]|0;M=c[m+80>>2]|0;N=c[m+84>>2]|0;while(1){O=0;P=J;while(1){Q=P+1|0;R=P+2|0;g[L+(O<<2)>>2]=+g[A>>2]*+(d[P]|0|0)+ +g[B>>2]*+(d[Q]|0|0)+ +g[C>>2]*+(d[R]|0|0);g[M+(O<<2)>>2]=+g[D>>2]*+(d[P]|0|0)+ +g[E>>2]*+(d[Q]|0|0)+ +g[F>>2]*+(d[R]|0|0);g[N+(O<<2)>>2]=+g[G>>2]*+(d[P]|0|0)+ +g[H>>2]*+(d[Q]|0|0)+ +g[I>>2]*+(d[R]|0|0);R=O+1|0;if((R|0)<(x|0)){O=R;P=P+3|0}else{break}}P=K+1|0;if((P|0)<(z|0)){J=J+v|0;K=P;L=L+(u<<2)|0;M=M+(u<<2)|0;N=N+(u<<2)|0}else{break}}}}while(0);v=m+88|0;k=v;q=0;N=u;u=x;x=z;while(1){z=c[k+(q<<2)>>2]|0;M=c[s+(q<<2)>>2]|0;L=c[l>>2]|0;K=c[L+100>>2]|0;TGb(z|0,0,ba(N<<2,x)|0)|0;J=x-15|0;if((J|0)>0){I=u-15|0;H=(I|0)>0;G=L+112|0;F=L+124|0;E=L+116|0;D=L+128|0;C=L+8|0;B=L+120|0;A=L+16|0;P=L+36|0;O=0;R=M;M=z;while(1){if(H){Q=0;while(1){S=0;T=R+(Q<<2)|0;while(1){U=c[F>>2]|0;UGb(U|0,T|0,64)|0;tZ(c[E>>2]|0,U);V=c[D>>2]|0;g[V+(S<<2)>>2]=+g[U>>2]*.25;g[V+(S+16<<2)>>2]=+g[U+4>>2]*.3535533905932738;g[V+(S+32<<2)>>2]=+g[U+8>>2]*.3535533905932738;g[V+(S+48<<2)>>2]=+g[U+12>>2]*.3535533905932738;g[V+(S+64<<2)>>2]=+g[U+16>>2]*.3535533905932738;g[V+(S+80<<2)>>2]=+g[U+20>>2]*.3535533905932738;g[V+(S+96<<2)>>2]=+g[U+24>>2]*.3535533905932738;g[V+(S+112<<2)>>2]=+g[U+28>>2]*.3535533905932738;g[V+(S+128<<2)>>2]=+g[U+32>>2]*.3535533905932738;g[V+(S+144<<2)>>2]=+g[U+36>>2]*.3535533905932738;g[V+(S+160<<2)>>2]=+g[U+40>>2]*.3535533905932738;g[V+(S+176<<2)>>2]=+g[U+44>>2]*.3535533905932738;g[V+(S+192<<2)>>2]=+g[U+48>>2]*.3535533905932738;g[V+(S+208<<2)>>2]=+g[U+52>>2]*.3535533905932738;g[V+(S+224<<2)>>2]=+g[U+56>>2]*.3535533905932738;g[V+(S+240<<2)>>2]=+g[U+60>>2]*.3535533905932738;U=S+1|0;if((U|0)<16){S=U;T=T+(N<<2)|0}else{W=0;X=V;break}}while(1){tZ(c[E>>2]|0,X);g[X>>2]=+g[X>>2]*.25;T=X+4|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+8|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+12|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+16|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+20|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+24|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+28|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+32|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+36|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+40|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+44|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+48|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+52|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+56|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+60|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=W+1|0;if((T|0)<16){W=T;X=X+64|0}else{break}}T=c[D>>2]|0;S=c[F>>2]|0;V=0;do{U=V<<4;Y=0;do{g[S+(Y+U<<2)>>2]=+g[T+((Y<<4)+V<<2)>>2];Y=Y+1|0;}while((Y|0)<16);V=V+1|0;}while((V|0)<16);if((c[C>>2]|0)==0){V=0;Y=S;while(1){U=0;Z=Y;while(1){_=+g[Z>>2];if(_<0.0){$=-0.0-_}else{$=_}if($<+g[P>>2]){g[Z>>2]=0.0}aa=U+1|0;if((aa|0)<16){U=aa;Z=Z+4|0}else{break}}Z=V+1|0;if((Z|0)<16){V=Z;Y=Y+64|0}else{ca=S;da=T;break}}}else{T=0;Y=S;while(1){V=0;Z=Y;while(1){_=+g[Z>>2];if(_<0.0){ea=-0.0-_}else{ea=_}h[A>>3]=ea;_=+MBb(c[C>>2]|0,A,L);g[Z>>2]=_*+g[Z>>2];U=V+1|0;if((U|0)<16){V=U;Z=Z+4|0}else{break}}Z=T+1|0;if((Z|0)<16){T=Z;Y=Y+64|0}else{break}}ca=c[F>>2]|0;da=c[D>>2]|0}Y=0;T=ca;while(1){g[T>>2]=+g[T>>2]*4.0;S=T+4|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+8|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+12|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+16|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+20|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+24|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+28|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+32|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+36|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+40|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+44|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+48|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+52|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+56|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+60|0;g[S>>2]=+g[S>>2]*2.82842712474619;tZ(c[B>>2]|0,T);S=Y+1|0;if((S|0)<16){Y=S;T=T+64|0}else{break}}T=c[F>>2]|0;Y=0;do{g[da>>2]=+g[T+(Y<<2)>>2]*4.0;S=1;do{g[da+(S<<2)>>2]=+g[T+((S<<4)+Y<<2)>>2]*2.82842712474619;S=S+1|0;}while((S|0)<16);tZ(c[B>>2]|0,da);S=Y+Q|0;Z=0;do{V=M+(S+(ba(Z,N)|0)<<2)|0;g[V>>2]=+g[da+(Z<<2)>>2]+ +g[V>>2];Z=Z+1|0;}while((Z|0)<16);Y=Y+1|0;}while((Y|0)<16);Y=c[G>>2]|0;T=Y+Q|0;if((T|0)<(I|0)){Q=T}else{fa=Y;break}}}else{fa=c[G>>2]|0}Q=ba(fa,N)|0;Y=fa+O|0;if((Y|0)<(J|0)){O=Y;R=R+(Q<<2)|0;M=M+(Q<<2)|0}else{break}}}if((x|0)>0&(u|0)>0){M=0;R=z;O=K;while(1){J=0;do{G=R+(J<<2)|0;g[G>>2]=+g[O+(J<<2)>>2]*+g[G>>2];J=J+1|0;}while((J|0)<(u|0));J=M+1|0;if((J|0)<(x|0)){M=J;R=R+(N<<2)|0;O=O+(N<<2)|0}else{break}}}O=q+1|0;if((O|0)>=3){break}q=O;N=c[t>>2]|0;u=c[w>>2]|0;x=c[y>>2]|0}x=p|0;u=p+32|0;N=c[u>>2]|0;q=c[t>>2]|0;t=c[w>>2]|0;fa=c[y>>2]|0;do{if((fa|0)>0){da=e;ca=m+52|0;X=m+64|0;W=m+44|0;l=m+56|0;s=m+68|0;k=m+48|0;O=m+60|0;R=m+72|0;if((t|0)<=0){break}M=c[x>>2]|0;K=0;z=c[v>>2]|0;J=c[m+92>>2]|0;G=c[m+96>>2]|0;while(1){I=0;B=M;while(1){F=z+(I<<2)|0;D=J+(I<<2)|0;L=G+(I<<2)|0;A=~~(+g[F>>2]*+g[da>>2]+ +g[D>>2]*+g[ca>>2]+ +g[L>>2]*+g[X>>2]);if(A>>>0>255>>>0){ga=-A>>31&255}else{ga=A&255}a[B]=ga;A=~~(+g[F>>2]*+g[W>>2]+ +g[D>>2]*+g[l>>2]+ +g[L>>2]*+g[s>>2]);if(A>>>0>255>>>0){ha=-A>>31&255}else{ha=A&255}a[B+1|0]=ha;A=~~(+g[F>>2]*+g[k>>2]+ +g[D>>2]*+g[O>>2]+ +g[L>>2]*+g[R>>2]);if(A>>>0>255>>>0){ia=-A>>31&255}else{ia=A&255}a[B+2|0]=ia;A=I+1|0;if((A|0)<(t|0)){I=A;B=B+3|0}else{break}}B=K+1|0;if((B|0)<(fa|0)){M=M+N|0;K=B;z=z+(q<<2)|0;J=J+(q<<2)|0;G=G+(q<<2)|0}else{break}}}}while(0);if((o|0)==0){o=c[x>>2]|0;x=c[j>>2]|0;q=c[x>>2]|0;N=c[u>>2]|0;u=c[x+32>>2]|0;x=b+20|0;fa=c[w>>2]|0;w=((c[x>>2]|0)-fa|0)*3|0;t=c[b+24>>2]|0;b=c[y>>2]|0;ia=t-b|0;do{if((w|0)==0){ja=b}else{ha=fa*3|0;if((b|0)<=0){ja=b;break}ga=0;m=o+ha|0;v=q+ha|0;while(1){UGb(m|0,v|0,w)|0;ha=ga+1|0;e=c[y>>2]|0;if((ha|0)<(e|0)){ga=ha;m=m+N|0;v=v+u|0}else{ja=e;break}}}}while(0);a:do{if((t|0)!=(b|0)&(ia|0)>0){y=1;w=o+(ba(ja,N)|0)|0;fa=q+(ba(ja,u)|0)|0;while(1){UGb(w|0,fa|0,(c[x>>2]|0)*3|0)|0;if((y|0)>=(ia|0)){break a}y=y+1|0;w=w+N|0;fa=fa+u|0}}}while(0);JCb(j)}r=cj(n,p)|0;i=f;return r|0}function Lm(a){a=a|0;var b=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+48|0;e=b|0;f=b+40|0;h=c[a+8>>2]|0;j=c[h+44>>2]|0;g[e>>2]=.5773502588272095;g[e+4>>2]=.5773502588272095;g[e+8>>2]=.5773502588272095;g[e+12>>2]=.7071067690849304;g[e+16>>2]=0.0;g[e+20>>2]=-.7071067690849304;g[e+24>>2]=.40824830532073975;g[e+28>>2]=-.8164966106414795;g[e+32>>2]=.40824830532073975;k=f|0;Aw(k,c[a+52>>2]|0)|0;l=d[k]|0;g[j+40>>2]=+g[e+(l*12|0)+(l<<2)>>2];l=f+1|0;g[j+44>>2]=+g[e+((d[k]|0)*12|0)+((d[l]|0)<<2)>>2];m=f+2|0;g[j+48>>2]=+g[e+((d[k]|0)*12|0)+((d[m]|0)<<2)>>2];g[j+52>>2]=+g[e+((d[l]|0)*12|0)+((d[k]|0)<<2)>>2];f=d[l]|0;g[j+56>>2]=+g[e+(f*12|0)+(f<<2)>>2];g[j+60>>2]=+g[e+((d[l]|0)*12|0)+((d[m]|0)<<2)>>2];g[j+64>>2]=+g[e+((d[m]|0)*12|0)+((d[k]|0)<<2)>>2];g[j+68>>2]=+g[e+((d[m]|0)*12|0)+((d[l]|0)<<2)>>2];l=d[m]|0;g[j+72>>2]=+g[e+(l*12|0)+(l<<2)>>2];l=a+20|0;e=c[l>>2]|0;m=j+112|0;k=c[m>>2]|0;f=e-((e-16|0)%(k|0)|0)|0;e=j+24|0;c[e>>2]=f;n=a+24|0;a=c[n>>2]|0;o=a-((a-16|0)%(k|0)|0)|0;k=j+28|0;c[k>>2]=o;a=c[l>>2]|0;if((f|0)==(a|0)){p=o}else{yDb(h,24,2304040,(q=i,i=i+8|0,c[q>>2]=a-f,q)|0);i=q;p=c[k>>2]|0}f=c[n>>2]|0;if((p|0)!=(f|0)){yDb(h,24,2286144,(q=i,i=i+8|0,c[q>>2]=f-p,q)|0);i=q}q=(c[e>>2]|0)+31&-32;c[j+104>>2]=q;p=q<<2;f=j+76|0;h=0;while(1){r=WDb(ba(p,c[k>>2]|0)|0)|0;s=r;if((h|0)>=2){t=10;break}n=f+(h*12|0)|0;c[n>>2]=s;a=f+(h*12|0)+4|0;c[a>>2]=WDb(ba(p,c[k>>2]|0)|0)|0;o=WDb(ba(p,c[k>>2]|0)|0)|0;c[f+(h*12|0)+8>>2]=o;if((c[n>>2]|0)==0){u=-12;t=28;break}if((c[a>>2]|0)==0|(o|0)==0){u=-12;t=28;break}h=h+1|0}if((t|0)==10){h=j+100|0;c[h>>2]=s;if((r|0)==0){u=-12;i=b;return u|0}r=dEb(c[k>>2]|0,p)|0;p=r;if((r|0)==0){u=-12;i=b;return u|0}s=c[k>>2]|0;if((s-15|0)>0){j=0;f=c[e>>2]|0;o=s;while(1){if((f-15|0)>0){a=0;do{n=0;do{l=(ba(n+j|0,q)|0)+a|0;v=p+(l<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+1<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+2<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+3<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+4<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+5<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+6<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+7<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+8<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+9<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+10<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+11<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+12<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+13<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+14<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+15<<2)|0;c[v>>2]=(c[v>>2]|0)+1;n=n+1|0;}while((n|0)<16);w=c[m>>2]|0;a=w+a|0;x=c[e>>2]|0;}while((a|0)<(x-15|0));y=x;z=c[k>>2]|0;A=w}else{y=f;z=o;A=c[m>>2]|0}a=A+j|0;if((a|0)<(z-15|0)){j=a;f=y;o=z}else{B=z;break}}}else{B=s}if((B|0)>0){s=c[e>>2]|0;e=(s|0)>0;z=0;do{if(e){o=ba(z,q)|0;y=c[h>>2]|0;f=0;do{j=f+o|0;g[y+(j<<2)>>2]=1.0/+(c[p+(j<<2)>>2]|0);f=f+1|0;}while((f|0)<(s|0))}z=z+1|0;}while((z|0)<(B|0))}ZDb(r);u=0;i=b;return u|0}else if((t|0)==28){i=b;return u|0}return 0}function Mm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=d|0;g=eEb(2177e3)|0;c[f>>2]=g;TGb(d+4|0,0,32)|0;c[d+36>>2]=172;c[d+40>>2]=0;c[d+44>>2]=0;h=d+48|0;c[h>>2]=1466;c[d+52>>2]=0;c[d+56>>2]=0;if((g|0)==0){j=-12;i=b;return j|0}g=a+24|0;k=a+12|0;l=a+16|0;Hi(0,g,12,k,l,d)|0;m=a+20|0;c[m>>2]=c[g>>2];do{if((c[e+128>>2]|0)!=0){n=eEb(2100832)|0;c[f>>2]=n;c[h>>2]=0;if((n|0)==0){j=-12;i=b;return j|0}else{Hi(1,g,12,k,l,d)|0;c[m>>2]=c[g>>2];break}}}while(0);g=c[e+120>>2]|0;do{if((g-1&g|0)==0){m=c[e+124>>2]|0;if((m-1&m|0)!=0){break}m=e+40|0;c[m>>2]=0;c[m+4>>2]=-2147483648;j=0;i=b;return j|0}}while(0);yDb(a,16,2045096,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-22;i=b;return j|0}function Nm(a){a=a|0;var b=0,d=0;b=c[a+44>>2]|0;JCb(b+16|0);$Db(b+76|0);$Db(b+4|0);$Db(b+20|0);b=a+24|0;if((c[b>>2]|0)==0){return}d=a+12|0;a=0;do{$Db((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function Om(a){a=a|0;Ok(a,xk(551200)|0);return 0}function Pm(a,b){a=a|0;b=b|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0.0,Na=0.0;f=i;i=i+8|0;g=f|0;j=c[a+8>>2]|0;k=c[c[j+32>>2]>>2]|0;l=c[j+44>>2]|0;m=l+8|0;n=c[m>>2]|0;do{if((c[a+12>>2]|0)==(c[j+12>>2]|0)){c[(c[l+4>>2]|0)+(n*24|0)>>2]=b;c[l+24>>2]=1}else{c[(c[l+20>>2]|0)+(n<<2)>>2]=b;c[l+28>>2]=1;if((c[l+24>>2]|0)==0){o=0}else{break}i=f;return o|0}}while(0);a=l+24|0;p=l+128|0;q=l+28|0;do{if((c[p>>2]|0)!=0){if((c[q>>2]|0)==0){o=0}else{break}i=f;return o|0}}while(0);c[q>>2]=0;c[a>>2]=0;if((b|0)==0){r=-1;s=-1;t=0;u=-2147483648}else{if((n|0)==0){v=l+16|0;w=c[l+4>>2]|0}else{a=c[l+4>>2]|0;v=a+((n-1|0)*24|0)|0;w=a}a=c[v>>2]|0;v=(a|0)==0?b:a;a=l+4|0;q=c[l+76>>2]|0;x=l+72|0;TGb(q|0,0,c[x>>2]<<3|0)|0;y=v+68|0;z=v+72|0;A=l+120|0;B=l+124|0;C=l+60|0;D=l+64|0;G=l+52|0;H=l+56|0;I=v+8|0;J=(c[l+132>>2]|0)==0;K=0;while(1){if(J){L=1}else{L=(c[I>>2]|0)!=0?3:1}if((K|0)>=(L|0)){break}M=c[v+32+(K<<2)>>2]|0;N=c[b+32+(K<<2)>>2]|0;O=c[y>>2]|0;if((K|0)==0){R=(c[B>>2]|0)/2|0;S=(c[A>>2]|0)/2|0;T=O;U=c[z>>2]|0}else{V=c[G>>2]|0;W=c[H>>2]|0;R=((c[B>>2]|0)/2|0)>>W;S=((c[A>>2]|0)/2|0)>>V;T=-(-O>>V)|0;U=-(-(c[z>>2]|0)>>W)|0}a:do{if((U|0)>0){W=(T|0)>0;V=(c[C>>2]|0)==8;O=c[v+(K<<2)>>2]|0;X=c[b+(K<<2)>>2]|0;Y=0;while(1){Z=(Y|0)/(R|0)|0;do{if(V){if(W){_=0;$=0}else{break}while(1){ca=_+S|0;da=(T|0)>(ca|0);ea=da?ca:T;if((_|0)<(ea|0)){fa=_;ha=0;ia=0;while(1){ja=(d[O+fa|0]|0)-(d[X+fa|0]|0)|0;ka=(ja|0)>-1?ja:-ja|0;ja=YGb(ka,(ka|0)<0|0?-1:0,ia,ha)|0;ka=F;la=fa+1|0;if((la|0)<(ea|0)){fa=la;ha=ka;ia=ja}else{ma=ka;na=ja;break}}}else{ma=0;na=0}ia=q+((ba(c[D>>2]|0,Z)|0)+$<<3)|0;ha=YGb(c[ia>>2]|0,c[ia+4>>2]|0,na,ma)|0;c[ia>>2]=ha;c[ia+4>>2]=F;if(da){_=ca;$=$+1|0}else{break}}}else{if(!W){break}ia=ba(c[D>>2]|0,Z)|0;ha=O;fa=X;ea=0;ja=0;while(1){ka=ea+S|0;la=(T|0)>(ka|0);oa=la?ka:T;if((ea|0)<(oa|0)){pa=ea;qa=0;ra=0;while(1){sa=(e[ha+(pa<<1)>>1]|0)-(e[fa+(pa<<1)>>1]|0)|0;ta=(sa|0)>-1?sa:-sa|0;sa=YGb(ta,(ta|0)<0|0?-1:0,ra,qa)|0;ta=F;ua=pa+1|0;if((ua|0)<(oa|0)){pa=ua;qa=ta;ra=sa}else{va=ta;wa=sa;break}}}else{va=0;wa=0}ra=q+(ja+ia<<3)|0;qa=YGb(c[ra>>2]|0,c[ra+4>>2]|0,wa,va)|0;c[ra>>2]=qa;c[ra+4>>2]=F;if(la){ea=ka;ja=ja+1|0}else{break}}}}while(0);Z=Y+1|0;if((Z|0)>=(U|0)){break a}O=O+M|0;X=X+N|0;Y=Z}}}while(0);K=K+1|0}K=(c[l+68>>2]|0)-1|0;do{if((K|0)>0){U=c[D>>2]|0;va=U-1|0;if((va|0)>0){xa=0;ya=-1;za=-1}else{Aa=-1;Ba=-1;break}while(1){wa=xa+1|0;T=ba(xa,U)|0;S=ba(wa,U)|0;$=0;_=ya;ma=za;do{na=$+T|0;R=q+(na<<3)|0;v=q+(na+1<<3)|0;na=YGb(c[v>>2]|0,c[v+4>>2]|0,c[R>>2]|0,c[R+4>>2]|0)|0;R=$+S|0;v=q+(R<<3)|0;C=YGb(na,F,c[v>>2]|0,c[v+4>>2]|0)|0;v=q+(R+1<<3)|0;R=YGb(C,F,c[v>>2]|0,c[v+4>>2]|0)|0;v=F;C=(v|0)>(_|0)|(v|0)==(_|0)&R>>>0>ma>>>0;ma=C?R:ma;_=C?v:_;$=$+1|0;}while(($|0)<(va|0));if((wa|0)<(K|0)){xa=wa;ya=_;za=ma}else{Aa=_;Ba=ma;break}}}else{Aa=-1;Ba=-1}}while(0);za=w+(n*24|0)+16|0;c[za>>2]=0;c[za+4>>2]=0;ya=c[x>>2]|0;if((ya|0)>0){x=0;xa=0;K=0;do{D=q+(x<<3)|0;K=YGb(c[D>>2]|0,c[D+4>>2]|0,K,xa)|0;xa=F;c[za>>2]=K;c[za+4>>2]=xa;x=x+1|0;}while((x|0)<(ya|0))}ya=w+(n*24|0)+8|0;c[ya>>2]=Ba;c[ya+4>>2]=Aa;Aa=(c[m>>2]|0)+1|0;c[m>>2]=Aa;ya=l+80|0;if((Aa|0)!=(c[ya>>2]|0)){o=0;i=f;return o|0}Aa=l+16|0;JCb(Aa);c[Aa>>2]=PCb(b)|0;c[m>>2]=0;m=c[ya>>2]|0;ya=c[a>>2]|0;if((m|0)>0){a=l+112|0;b=c[a>>2]|0;Aa=c[a+4>>2]|0;a=0;Ba=0;n=-1;while(1){w=ya+(a*24|0)+16|0;x=c[w+4>>2]|0;xa=(x|0)>(Aa|0)|(x|0)==(Aa|0)&(c[w>>2]|0)>>>0>b>>>0?a:n;w=ya+(a*24|0)+8|0;x=c[w+4>>2]|0;za=ya+(Ba*24|0)+8|0;K=c[za+4>>2]|0;q=(x|0)<(K|0)|(x|0)==(K|0)&(c[w>>2]|0)>>>0<(c[za>>2]|0)>>>0?a:Ba;za=a+1|0;if((za|0)<(m|0)){a=za;Ba=q;n=xa}else{Ca=q;Da=xa;break}}}else{Ca=0;Da=-1}n=ya+(Ca*24|0)+8|0;ya=c[n+4>>2]|0;Ba=l+104|0;a=c[Ba+4>>2]|0;m=(ya|0)<(a|0)|(ya|0)==(a|0)&(c[n>>2]|0)>>>0<(c[Ba>>2]|0)>>>0?Ca:-1;r=Da;s=m;t=Ca;u=(Da|0)>-1&(m|0)<0?Da:Ca}b:do{if((zDb()|0)>47){Ca=j;Da=l+80|0;yDb(Ca,48,1999432,(m=i,i=i+8|0,c[m>>2]=c[Da>>2],m)|0);i=m;Ba=l+4|0;n=c[Da>>2]|0;if((n|0)>0){Ea=0;Fa=n}else{o=0;i=f;return o|0}while(1){n=c[Ba>>2]|0;if((c[n+(Ea*24|0)>>2]|0)==0){Ga=Fa;Ha=Ba;break b}a=Ea+1|0;ya=n+(Ea*24|0)+16|0;b=c[ya>>2]|0;Aa=c[ya+4>>2]|0;ya=n+(Ea*24|0)+8|0;n=c[ya>>2]|0;xa=c[ya+4>>2]|0;yDb(Ca,48,1962608,(m=i,i=i+72|0,c[m>>2]=a,c[m+8>>2]=b,c[m+16>>2]=Aa,c[m+24>>2]=n,c[m+32>>2]=xa,c[m+40>>2]=(Ea|0)==(r|0)?1934432:9203040,c[m+48>>2]=(Ea|0)==(s|0)?1890936:9203040,c[m+56>>2]=(Ea|0)==(t|0)?2348344:9203040,c[m+64>>2]=(Ea|0)==(u|0)?2328168:9203040,m)|0);i=m;xa=c[Da>>2]|0;if((a|0)<(xa|0)){Ea=a;Fa=xa}else{Ga=xa;Ha=Ba;break}}}else{Ga=c[l+80>>2]|0;Ha=l+4|0}}while(0);Fa=l+80|0;if((Ga|0)<=0){o=0;i=f;return o|0}Ga=l+20|0;Ea=k+160|0;t=l+32|0;s=l+40|0;l=0;r=0;while(1){j=c[Ha>>2]|0;Ba=c[j+(l*24|0)>>2]|0;if((Ba|0)==0){o=r;Ia=65;break}if((l|0)==(u|0)){if((c[p>>2]|0)==0){Ja=j}else{JCb((c[Ga>>2]|0)+(u<<2)|0);Ja=c[Ha>>2]|0}JCb(Ja+(u*24|0)|0);Ka=r}else{c[g>>2]=Ba;j=Ba+136|0;Da=c[j>>2]|0;m=c[j+4>>2]|0;do{if(!((Da|0)==0&(m|0)==(-2147483648|0))){if(!((c[s>>2]|0)==0&(c[s+4>>2]|0)==(-2147483648|0))){break}c[s>>2]=Da;c[s+4>>2]=m}}while(0);if((c[p>>2]|0)==0){La=Ba}else{JCb(g);m=c[(c[Ga>>2]|0)+(l<<2)>>2]|0;c[g>>2]=m;La=m}m=c[s>>2]|0;Da=c[s+4>>2]|0;if((m|0)==0&(Da|0)==(-2147483648|0)){Ma=0.0}else{Ma=+(m>>>0)+ +(Da|0)*4294967296.0}Na=(+((c[Ea>>2]|0)>>>0)+ +(c[Ea+4>>2]|0)*4294967296.0)*+h[t>>3]+Ma;Da=(E=+Na,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);m=La+136|0;c[m>>2]=~~+Na>>>0;c[m+4>>2]=Da;Da=cj(k,La)|0;if((Da|0)<0){o=Da;Ia=65;break}else{Ka=Da}}Da=l+1|0;if((Da|0)<(c[Fa>>2]|0)){l=Da;r=Ka}else{o=Ka;Ia=65;break}}if((Ia|0)==65){i=f;return o|0}return 0}function Qm(a){a=a|0;var b=0,f=0,g=0,i=0,j=0,k=0,l=0.0,m=0,n=0,o=0;b=c[(c[a+8>>2]|0)+44>>2]|0;f=bFb(c[a+52>>2]|0)|0;g=c[a+20>>2]|0;i=c[a+24>>2]|0;c[b+52>>2]=d[f+5|0]|0;c[b+56>>2]=d[f+6|0]|0;a=((e[f+8>>1]|0)>>>11&15)+1|0;c[b+60>>2]=a;f=(1<<a)-1|0;a=f;j=(f|0)<0|0?-1:0;f=gHb(i,(i|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;k=gHb(f,F,a,j)|0;l=+h[b+96>>3]*(+(k>>>0)+ +(F|0)*4294967296.0)/100.0;k=(E=+l,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);f=b+112|0;c[f>>2]=~~+l>>>0;c[f+4>>2]=k;k=c[b+120>>2]|0;f=c[b+124>>2]|0;m=gHb(f,(f|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;n=gHb(m,F,a,j)|0;l=+h[b+88>>3]*(+(n>>>0)+ +(F|0)*4294967296.0)/100.0;n=(E=+l,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);j=b+104|0;c[j>>2]=~~+l>>>0;c[j+4>>2]=n;n=(k|0)/2|0;k=(g-1+n|0)/(n|0)|0;c[b+64>>2]=k;n=(f|0)/2|0;f=(i-1+n|0)/(n|0)|0;c[b+68>>2]=f;n=ba(k,f)|0;c[b+72>>2]=n;f=b+76|0;c[f>>2]=WDb(n<<3)|0;n=b+80|0;k=dEb(c[n>>2]|0,24)|0;c[b+4>>2]=k;if((c[f>>2]|0)==0|(k|0)==0){o=-12;return o|0}do{if((c[b+128>>2]|0)!=0){k=dEb(c[n>>2]|0,4)|0;c[b+20>>2]=k;if((k|0)==0){o=-12}else{break}return o|0}}while(0);o=0;return o|0}function Rm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a>>2]|0;a=b+44|0;d=c[a>>2]|0;e=d+128|0;f=c[e>>2]|0;g=f<<1|1;h=d+48|0;if((g&c[h>>2]|0)==(g|0)){i=-541478725;return i|0}do{if((c[d+24>>2]|0)==0){g=c[c[b+16>>2]>>2]|0;j=Ni(g)|0;if((j|0)==-541478725){c[h>>2]=c[h>>2]|1;k=Pm(g,0)|0}else{k=j}if((k|0)<0){i=k;return i|0}else{l=c[e>>2]|0;break}}else{l=f}}while(0);do{if((l|0)!=0){f=c[a>>2]|0;if((c[f+28>>2]|0)!=0){break}e=c[(c[b+16>>2]|0)+4>>2]|0;k=Ni(e)|0;if((k|0)==-541478725){h=f+48|0;c[h>>2]=c[h>>2]|2;m=Pm(e,0)|0}else{m=k}if((m|0)<0){i=m}else{break}return i|0}}while(0);i=0;return i|0}function Sm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+8|0;d=b|0;e=d;f=i;i=i+8|0;g=i;i=i+8|0;j=g;k=i;i=i+8|0;l=c[a>>2]|0;m=c[l+44>>2]|0;n=c[(c[l+16>>2]|0)+(((c[m+128>>2]|0)!=0)<<2)>>2]|0;o=n+116|0;p=o;q=c[p>>2]|0;r=c[p+4>>2]|0;c[d>>2]=q;c[d+4>>2]=r;p=q;q=r;do{if((p|0)==0){s=q}else{if((q|0)==0){s=0;break}r=m+80|0;c[f>>2]=(c[r>>2]|0)-1;c[f+4>>2]=c[r>>2];jFb(j,e,f);r=c[g>>2]|0;t=c[g+4>>2]|0;c[d>>2]=r;c[d+4>>2]=t;u=c[n+120>>2]|0;yDb(l,40,2131104,(v=i,i=i+32|0,c[v>>2]=c[o>>2],c[v+8>>2]=u,c[v+16>>2]=r,c[v+24>>2]=t,v)|0);i=v;t=a+156|0;c[t>>2]=c[t>>2]|1;t=a+56|0;r=n+56|0;u=t;w=c[r+4>>2]|0;c[u>>2]=c[r>>2];c[u+4>>2]=w;w=a+116|0;u=c[d+4>>2]|0;c[w>>2]=c[d>>2];c[w+4>>2]=u;u=n+28|0;w=a+28|0;r=c[u+4>>2]|0;c[w>>2]=c[u>>2];c[w+4>>2]=r;c[a+20>>2]=c[n+20>>2];c[a+24>>2]=c[n+24>>2];jFb(k,e,t);h[m+32>>3]=+(c[k+4>>2]|0)/+(c[k>>2]|0);x=0;i=b;return x|0}}while(0);yDb(l,16,2137736,(v=i,i=i+16|0,c[v>>2]=p,c[v+8>>2]=s,v)|0);i=v;x=-22;i=b;return x|0}function Tm(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;a=b+36|0;d=cEb((c[a>>2]<<3)+16|0)|0;c[b+4>>2]=d;if((d|0)==0){e=-12;return e|0}d=b+24|0;c[d>>2]=0;c[d+4>>2]=0;c[b+8>>2]=0;c[b+12>>2]=1;c[b+16>>2]=2;c[b+20>>2]=3;c[b+32>>2]=(c[a>>2]|0)+2;e=0;return e|0}function Um(a){a=a|0;$Db((c[a+44>>2]|0)+4|0);return}function Vm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=i;i=i+8|0;g=i;i=i+8|0;h=c[a>>2]|0;j=c[c[h+16>>2]>>2]|0;k=(c[h+44>>2]|0)+36|0;l=c[k>>2]<<1;c[d>>2]=1;c[d+4>>2]=l;jFb(e,j+56|0,d);d=a+56|0;l=c[e+4>>2]|0;c[d>>2]=c[e>>2];c[d+4>>2]=l;c[f>>2]=c[k>>2]<<1;c[f+4>>2]=1;jFb(g,j+116|0,f);f=a+116|0;a=c[g+4>>2]|0;c[f>>2]=c[g>>2];c[f+4>>2]=a;yDb(h,40,1999088,(h=i,i=i+8|0,c[h>>2]=c[k>>2],h)|0);i=h;i=b;return 0}function Wm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;e=c[a+8>>2]|0;a=c[c[e+32>>2]>>2]|0;f=c[e+44>>2]|0;g=c[f+4>>2]|0;h=b+136|0;j=c[h>>2]|0;k=c[h+4>>2]|0;if((j|0)==0&(k|0)==(-2147483648|0)){l=cj(a,b)|0;i=d;return l|0}m=f+32|0;n=c[m>>2]|0;if((n|0)==0){o=c[f+12>>2]|0;p=g+(o<<3)|0;q=c[p+4>>2]|0;do{if((k|0)<(q|0)|(k|0)==(q|0)&j>>>0<(c[p>>2]|0)>>>0){r=c[f+16>>2]|0;s=g+(r<<3)|0;t=YGb(c[s>>2]|0,c[s+4>>2]|0,j,k)|0;s=c[f+20>>2]|0;u=g+(s<<3)|0;v=ZGb(t,F,c[u>>2]|0,c[u+4>>2]|0)|0;u=c[f+8>>2]|0;t=g+(u<<3)|0;w=ZGb(v,F,c[t>>2]|0,c[t+4>>2]|0)|0;t=F;v=c[f+36>>2]|0;x=v+2|0;if((x|0)>0){y=0}else{z=v;A=r;B=u;C=s;break}while(1){D=g+(y<<3)|0;E=YGb(w,t,c[D>>2]|0,c[D+4>>2]|0)|0;c[D>>2]=E;c[D+4>>2]=F;D=y+1|0;if((D|0)<(x|0)){y=D}else{z=v;A=r;B=u;C=s;break}}}else{z=c[f+36>>2]|0;A=c[f+16>>2]|0;B=c[f+8>>2]|0;C=c[f+20>>2]|0}}while(0);y=z-1|0;p=g+(A<<3)|0;q=g+(B<<3)|0;B=ZGb(c[p>>2]|0,c[p+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;q=gHb(B,F,y,(y|0)<0|0?-1:0)|0;y=F;B=z+1|0;p=g+(C<<3)|0;s=ZGb(j,k,c[p>>2]|0,c[p+4>>2]|0)|0;p=gHb(s,F,B,(B|0)<0|0?-1:0)|0;B=F;s=f+24|0;u=YGb(c[s>>2]|0,c[s+4>>2]|0,q,y)|0;y=YGb(u,F,p,B)|0;c[s>>2]=y;c[s+4>>2]=F;G=o;H=A;I=C;J=z}else{c[m>>2]=n-1;n=c[f+36>>2]|0;m=gHb(j<<1|0>>>31,k<<1|j>>>31,n,(n|0)<0|0?-1:0)|0;z=f+24|0;c[z>>2]=m;c[z+4>>2]=F;G=c[f+12>>2]|0;H=c[f+16>>2]|0;I=c[f+20>>2]|0;J=n}n=g+(G<<3)|0;c[n>>2]=j;c[n+4>>2]=k;c[f+8>>2]=G;c[f+12>>2]=H;c[f+16>>2]=I;H=f+36|0;G=J+2|0;c[f+20>>2]=(I+1|0)%(G|0)|0;I=f+24|0;f=c[I>>2]|0;J=c[I+4>>2]|0;c[h>>2]=f;c[h+4>>2]=J;I=e;if((G|0)>0){G=0;do{e=g+(G<<3)|0;n=c[e+4>>2]|0;yDb(I,48,1962272,(K=i,i=i+16|0,c[K>>2]=c[e>>2],c[K+8>>2]=n,K)|0);i=K;G=G+1|0;}while((G|0)<((c[H>>2]|0)+2|0));L=c[h+4>>2]|0;M=c[h>>2]|0}else{L=J;M=f}yDb(I,48,1934128,(K=i,i=i+32|0,c[K>>2]=j,c[K+8>>2]=k,c[K+16>>2]=M,c[K+24>>2]=L,K)|0);i=K;l=cj(a,b)|0;i=d;return l|0}function Xm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=c[a+44>>2]|0;c[d+1312>>2]=20;e=d+20|0;f=c[e>>2]|0;g=(f|0)/2|0;if((f|0)<8){h=4}else{h=(g|0)>128?128:g}c[e>>2]=h;h=d+8|0;if((c[h>>2]&15|0)!=0){yDb(a,16,2175232,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1163346256;i=b;return k|0}g=c[d+1368>>2]|0;if((g|0)==0){l=c[d+1316>>2]|0}else{f=Kc(g|0,2099664)|0;c[d+1316>>2]=f;l=f}if((l|0)!=0){nb(2044352,1,104,l|0)|0}l=d+1360|0;f=c[l>>2]|0;if((f|0)>0){g=d+1352|0;c[g>>2]=(c[g>>2]|0)+(f&15);g=f&-16;c[l>>2]=g;m=g}else{m=f}c[d+1376>>2]=2;f=a;if((c[d+1372>>2]|0)==0){a=c[d+1364>>2]|0;g=c[d+1352>>2]|0;l=c[d+1356>>2]|0;n=c[h>>2]|0;h=c[d+12>>2]|0;o=c[d+16>>2]|0;p=c[e>>2]<<1;e=c[d+24>>2]|0;q=c[d+28>>2]|0;yDb(f,40,1961992,(j=i,i=i+80|0,c[j>>2]=m,c[j+8>>2]=a,c[j+16>>2]=g,c[j+24>>2]=l,c[j+32>>2]=n,c[j+40>>2]=h,c[j+48>>2]=o,c[j+56>>2]=p,c[j+64>>2]=e,c[j+72>>2]=q,j)|0);i=j;k=0;i=b;return k|0}else{yDb(f,16,1998848,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=b;return k|0}return 0}function Ym(a){a=a|0;var b=0;b=c[a+44>>2]|0;JCb(b+4|0);a=c[b+1316>>2]|0;if((a|0)!=0){fb(a|0)|0}a=b+32|0;b=c[a>>2]|0;if((b|0)==0){$Db(a);return}E0a(b)|0;$Db(a);return}function Zm(a){a=a|0;Ok(a,xk(551152)|0);return 0}function _m(a,b,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0;a=i;i=i+48|0;n=a|0;o=a+16|0;p=a+32|0;c[n>>2]=g;c[n+8>>2]=h;c[n+4>>2]=h;c[o>>2]=b;c[o+8>>2]=e;c[o+4>>2]=e;c[p>>2]=d;c[p+8>>2]=f;c[p+4>>2]=f;f=0;d=0;while(1){if((d|0)>=3){q=f;r=4;break}e=_w(c[l+(d<<2)>>2]|0,c[m+(d<<2)>>2]|0,c[l+32+(d<<2)>>2]|0,c[m+32+(d<<2)>>2]|0,c[o+(d<<2)>>2]|0,c[p+(d<<2)>>2]|0,c[n+(d<<2)>>2]|0,j,k)|0;if((e|0)<0){q=e;r=4;break}else{f=e;d=d+1|0}}if((r|0)==4){i=a;return q|0}return 0}function $m(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0.0,U=0.0,V=0.0;e=i;i=i+376|0;f=e|0;g=e+8|0;j=e+40|0;k=e+80|0;l=e+120|0;c[f>>2]=b;m=a+8|0;n=c[m>>2]|0;o=c[n+44>>2]|0;p=o;q=c[c[n+32>>2]>>2]|0;TGb(g|0,0,32)|0;r=2.0/+(c[o+1312>>2]|0);n=Zr(q,c[q+20>>2]|0,c[q+24>>2]|0)|0;if((n|0)==0){JCb(f);s=-12;i=e;return s|0}NCb(n,b)|0;b=o+1360|0;t=c[b>>2]|0;do{if((t|0)<0){u=7}else{v=o+1364|0;w=c[v>>2]|0;if((w|0)<0){u=7;break}x=o+1352|0;y=c[x>>2]|0;if((y|0)<0){u=7;break}z=o+1356|0;A=c[z>>2]|0;if((A|0)<0){u=7;break}B=c[o+4>>2]|0;C=c[f>>2]|0;D=c[((B|0)==0?C:B)>>2]|0;B=c[C>>2]|0;E=a+20|0;F=c[E>>2]|0;G=(t|0)>(F|0)?F:t;c[b>>2]=G;F=a+24|0;H=c[F>>2]|0;I=(w|0)>(H|0)?H:w;c[v>>2]=I;v=c[E>>2]|0;if((y+G|0)>>>0>v>>>0){E=v-G|0;c[x>>2]=E;J=E}else{J=y}y=c[F>>2]|0;if((A+I|0)>>>0>y>>>0){F=y-I|0;c[z>>2]=F;K=F}else{K=A}A=J&-16;c[x>>2]=A;x=c[C+32>>2]|0;C=(ba(x,I)|0)+G|0;bn(p,D+C|0,B+C|0,A,K,x,g)}}while(0);if((u|0)==7){u=c[o+4>>2]|0;K=c[f>>2]|0;bn(p,c[((u|0)==0?K:u)>>2]|0,c[K>>2]|0,c[a+20>>2]|0,c[a+24>>2]|0,c[K+32>>2]|0,g)}K=g|0;L=+h[K>>3];u=g+8|0;M=+h[u>>3];p=g+16|0;N=+h[p>>3];J=g+24|0;O=+h[J>>3];P=r;r=1.0-P;g=o+1320|0;Q=P*L+r*+h[g>>3];h[g>>3]=Q;g=o+1328|0;R=P*M+r*+h[g>>3];h[g>>3]=R;g=o+1336|0;S=P*N+r*+h[g>>3];h[g>>3]=S;g=o+1344|0;T=P*O+r*+h[g>>3];h[g>>3]=T;r=O-T;h[J>>3]=r;P=(L-Q)*-1.0;h[K>>3]=P;U=(M-R)*-1.0;h[u>>3]=U;V=(N-S)*-1.0;h[p>>3]=V;g=o+1316|0;if((c[g>>2]|0)!=0){b=l|0;Lb(b|0,256,2043456,(l=i,i=i+96|0,h[l>>3]=L,h[l+8>>3]=Q,h[l+16>>3]=P,h[l+24>>3]=M,h[l+32>>3]=R,h[l+40>>3]=U,h[l+48>>3]=N,h[l+56>>3]=S,h[l+64>>3]=V,h[l+72>>3]=O,h[l+80>>3]=T,h[l+88>>3]=r,l)|0)|0;i=l;l=SGb(b|0)|0;nb(b|0,1,l|0,c[g>>2]|0)|0}g=o+1280|0;T=+h[g>>3]+P;l=o+1288|0;P=+h[l>>3]+U;b=o+1296|0;U=+h[b>>3]+V;t=o+1304|0;V=+h[t>>3]+r;h[J>>3]=V;r=T*.9;h[K>>3]=r;T=P*.9;h[u>>3]=T;P=U*.9;h[p>>3]=P;h[g>>3]=r;h[l>>3]=T;h[b>>3]=P;h[t>>3]=V;U=P;P=V/100.0+1.0;t=j|0;Zw(r,T,U,P,t);j=a+20|0;b=c[j>>2]|0;l=a+52|0;V=r/+((b|0)/(-(-b>>(d[(bFb(c[l>>2]|0)|0)+5|0]|0))|0)|0|0);b=a+24|0;a=c[b>>2]|0;g=k|0;Zw(V,T/+((a|0)/(-(-a>>(d[(bFb(c[l>>2]|0)|0)+6|0]|0))|0)|0|0),U,P,g);a=c[o+1376>>2]|0;k=c[m>>2]|0;m=c[j>>2]|0;j=c[b>>2]|0;p=-(-m>>(d[(bFb(c[l>>2]|0)|0)+5|0]|0))|0;u=-(c[b>>2]|0)|0;b=-(u>>(d[(bFb(c[l>>2]|0)|0)+6|0]|0))|0;l=xe[a&3](k,m,j,p,b,t,g,1,c[o+16>>2]|0,c[f>>2]|0,n)|0;g=o+4|0;JCb(g);if((l|0)<0){s=l;i=e;return s|0}c[g>>2]=c[f>>2];s=cj(q,n)|0;i=e;return s|0}function an(a){a=a|0;var b=0;b=c[(c[a+8>>2]|0)+44>>2]|0;c[b+4>>2]=0;TGb(b+1280|0,0,32)|0;a=ARa(0)|0;c[b+32>>2]=a;x7(b+36|0,a);return 0}function bn(a,b,e,f,g,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,V=0,W=0,X=0,Y=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0.0,fb=0.0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0.0,vb=0,wb=0,xb=0.0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0.0,Eb=0.0,Fb=0.0,Gb=0.0,Hb=0.0;l=i;i=i+66568|0;m=l|0;n=ba(f<<3,g)|0;o=a+20|0;p=WDb((n>>>0)/(c[o>>2]<<4>>>0)|0)|0;n=p;q=a+8|0;r=c[q>>2]|0;s=r<<1|1;t=c[a+12>>2]|0;do{if((s|0)>0){if((t<<1|1|0)>0){u=0}else{break}do{v=t<<1|1;TGb(m+(u*516|0)|0,0,((v|0)>1?v<<2:4)|0)|0;u=u+1|0;}while((u|0)<(s|0))}}while(0);s=a+12|0;u=c[o>>2]|0;do{if((t|0)<(g-t-(u<<1)|0)){v=f-16|0;w=a+24|0;x=a+28|0;y=a+88|0;z=a;A=0;B=0;C=0;D=t;E=r;F=u;G=0;H=0;I=0;J=0;while(1){K=F<<1;if((E|0)<(v-E|0)){L=ba(D,j)|0;M=+(D|0);N=A;O=B;P=C;Q=E;R=K;S=E;V=G;W=H;X=I;Y=J;while(1){if((R|0)<0){_=255;$=0}else{aa=255;ca=0;da=0;while(1){ea=(ba(D-ca|0,j)|0)+Q|0;fa=aa;ga=0;ha=da;while(1){ia=d[e+(ea-ga)|0]|0;if((ia|0)<(fa|0)){ja=ha;ka=ia}else{ja=(ia|0)>(ha|0)?ia:ha;ka=fa}ia=ga+1|0;if((ia|0)<16){fa=ka;ga=ia;ha=ja}else{break}}ha=ca+1|0;if((ha|0)>(R|0)){_=ka;$=ja;break}else{aa=ka;ca=ha;da=ja}}}do{if(($-_|0)>(c[w>>2]|0)){da=c[x>>2]|0;if((da|0)==0){ca=c[s>>2]|0;aa=-ca|0;if((ca|0)<(aa|0)){la=P;ma=O;na=N;oa=-1;pa=-1;qa=-1;ra=-1;break}ha=b+(Q+L)|0;ga=2147483647;fa=aa;aa=S;ea=ca;ca=V;ia=W;sa=X;ta=Y;while(1){ua=-aa|0;if((aa|0)<(ua|0)){va=ga;wa=aa;xa=ea;ya=ca;za=ia;Aa=sa;Ba=ta}else{Ca=(ba(D-fa|0,j)|0)+Q|0;Da=ga;Ea=ua;ua=ca;Fa=ia;Ga=sa;Ha=ta;do{Ia=Pe[c[y>>2]&255](z,ha,e+(Ca-Ea)|0,j,c[o>>2]|0)|0;Ja=(Ia|0)<(Da|0);Ha=Ja?fa:Ha;Ga=Ja?Ea:Ga;Fa=Ja?fa:Fa;ua=Ja?Ea:ua;Da=Ja?Ia:Da;Ea=Ea+1|0;Ka=c[q>>2]|0;}while((Ea|0)<=(Ka|0));va=Da;wa=Ka;xa=c[s>>2]|0;ya=ua;za=Fa;Aa=Ga;Ba=Ha}Ea=fa+1|0;if((Ea|0)>(xa|0)){La=va;Ma=ya;Na=za;Oa=Aa;Pa=Ba;break}else{ga=va;fa=Ea;aa=wa;ea=xa;ca=ya;ia=za;sa=Aa;ta=Ba}}}else if((da|0)==1){ta=c[s>>2]|0;sa=1-ta|0;ia=b+(Q+L)|0;if((sa|0)<(ta|0)){ca=2147483647;ea=sa;sa=S;aa=ta;ta=X;fa=Y;while(1){ga=1-sa|0;if((ga|0)<(sa|0)){ha=(ba(D-ea|0,j)|0)+Q|0;Ea=ca;Ca=ga;ga=ta;Ia=fa;do{Ja=Pe[c[y>>2]&255](z,ia,e+(ha-Ca)|0,j,c[o>>2]|0)|0;Qa=(Ja|0)<(Ea|0);Ia=Qa?ea:Ia;ga=Qa?Ca:ga;Ea=Qa?Ja:Ea;Ca=Ca+2|0;Ra=c[q>>2]|0;}while((Ca|0)<(Ra|0));Sa=Ea;Ta=Ra;Ua=c[s>>2]|0;Va=ga;Wa=Ia}else{Sa=ca;Ta=sa;Ua=aa;Va=ta;Wa=fa}Ca=ea+2|0;if((Ca|0)<(Ua|0)){ca=Sa;ea=Ca;sa=Ta;aa=Ua;ta=Va;fa=Wa}else{Xa=Sa;Ya=Va;Za=Wa;break}}}else{Xa=2147483647;Ya=X;Za=Y}fa=Za+1|0;ta=Ya-1|0;aa=Ya+1|0;sa=Xa;ea=Za-1|0;ca=Ya;da=Za;while(1){Ca=(ba(D-ea|0,j)|0)+Q|0;if((ea|0)==(Za|0)){ha=sa;Ha=ta;Ga=ca;Fa=da;while(1){if((Ha|0)==(Ya|0)){_a=ha;$a=Ga;ab=Fa}else{ua=Pe[c[y>>2]&255](z,ia,e+(Ca-Ha)|0,j,c[o>>2]|0)|0;Da=(ua|0)<(ha|0);_a=Da?ua:ha;$a=Da?Ha:Ga;ab=Da?Za:Fa}Da=Ha+1|0;if((Da|0)>(aa|0)){bb=_a;cb=$a;db=ab;break}else{ha=_a;Ha=Da;Ga=$a;Fa=ab}}}else{Fa=sa;Ga=ta;Ha=ca;ha=da;while(1){Ia=Pe[c[y>>2]&255](z,ia,e+(Ca-Ga)|0,j,c[o>>2]|0)|0;ga=(Ia|0)<(Fa|0);Ea=ga?ea:ha;Da=ga?Ga:Ha;ua=ga?Ia:Fa;Ia=Ga+1|0;if((Ia|0)>(aa|0)){bb=ua;cb=Da;db=Ea;break}else{Fa=ua;Ga=Ia;Ha=Da;ha=Ea}}}ha=ea+1|0;if((ha|0)>(fa|0)){La=bb;Ma=cb;Na=db;Oa=cb;Pa=db;break}else{sa=bb;ea=ha;ca=cb;da=db}}}else{la=P;ma=O;na=N;oa=-1;pa=-1;qa=-1;ra=-1;break}if((La|0)>512){la=P;ma=O;na=N;oa=-1;pa=-1;qa=-1;ra=-1;break}if((Ma|0)==-1){la=P;ma=O;na=N;oa=-1;pa=Na;qa=Oa;ra=Pa;break}if((Na|0)==-1){la=P;ma=O;na=N;oa=Ma;pa=-1;qa=Oa;ra=Pa;break}da=c[s>>2]|0;ca=c[q>>2]|0;ea=m+((ca+Ma|0)*516|0)+(da+Na<<2)|0;c[ea>>2]=(c[ea>>2]|0)+1;if((Q|0)>(ca|0)&(D|0)>(da|0)){eb=+Z(+(+(Pa+D|0)),+(+(Oa+Q|0)))- +Z(+M,+(+(Q|0)));do{if(eb>3.141592653589793){fb=eb+ -6.283185307179586}else{if(!(eb<-3.141592653589793)){fb=eb;break}fb=eb+6.283185307179586}}while(0);h[n+(N<<3)>>3]=fb;gb=N+1|0}else{gb=N}la=Pa+P|0;ma=Oa+O|0;na=gb;oa=Oa;pa=Pa;qa=Oa;ra=Pa}else{la=P;ma=O;na=N;oa=V;pa=W;qa=X;ra=Y}}while(0);da=Q+16|0;ca=c[q>>2]|0;ea=c[o>>2]|0;sa=ea<<1;if((da|0)<(v-ca|0)){N=na;O=ma;P=la;Q=da;R=sa;S=ca;V=oa;W=pa;X=qa;Y=ra}else{hb=na;ib=ma;jb=la;kb=sa;lb=ca;mb=oa;nb=pa;ob=qa;pb=ra;qb=ea;break}}}else{hb=A;ib=B;jb=C;kb=K;lb=E;mb=G;nb=H;ob=I;pb=J;qb=F}Y=kb+D|0;if((Y|0)<(g-(c[s>>2]|0)-(qb<<1)|0)){A=hb;B=ib;C=jb;D=Y;E=lb;F=qb;G=mb;H=nb;I=ob;J=pb}else{break}}if((hb|0)==0){rb=jb;sb=ib;tb=53;break}J=(ib|0)/(hb|0)|0;I=(jb|0)/(hb|0)|0;H=(hb|0)/5|0;Yc(p|0,hb|0,8,394);G=hb-H|0;if((H|0)<(G|0)){M=0.0;F=H;while(1){eb=M+ +h[n+(F<<3)>>3];E=F+1|0;if((E|0)<(G|0)){M=eb;F=E}else{ub=eb;break}}}else{ub=0.0}M=ub/+(hb-(H<<1)|0);F=k+16|0;h[F>>3]=M;if(!(M<.001)){vb=I;wb=J;xb=M;break}h[F>>3]=0.0;vb=I;wb=J;xb=0.0}else{rb=0;sb=0;tb=53}}while(0);if((tb|0)==53){h[k+16>>3]=0.0;vb=rb;wb=sb;xb=0.0}sb=c[s>>2]|0;s=sb<<1;rb=c[q>>2]|0;do{if((s|0)>-1){q=rb<<1|1;tb=k|0;hb=k+8|0;if((q|0)>0){yb=0;zb=s}else{Ab=tb;Bb=hb;break}while(1){n=yb;jb=0;while(1){ib=c[m+(jb*516|0)+(zb<<2)>>2]|0;if((ib|0)>(n|0)){h[tb>>3]=+(jb-rb|0);h[hb>>3]=+(zb-sb|0);Cb=ib}else{Cb=n}ib=jb+1|0;if((ib|0)<(q|0)){n=Cb;jb=ib}else{break}}if((zb|0)>0){yb=Cb;zb=zb-1|0}else{Ab=tb;Bb=hb;break}}}else{Ab=k|0;Bb=k+8|0}}while(0);ub=+(wb-((f|0)/2|0)|0);fb=+(vb-((g|0)/2|0)|0);g=k+16|0;M=+T(xb)+-1.0;eb=+U(xb);Db=+h[Ab>>3]+(ub*M-fb*eb);h[Ab>>3]=Db;Eb=+h[Bb>>3]+(ub*eb+fb*M);h[Bb>>3]=Eb;M=Db;Db=+(-rb<<1|0);fb=+(rb<<1|0);if(M<Db){Fb=Db}else{Fb=M>fb?fb:M}h[Ab>>3]=Fb;Fb=Eb;Eb=+(-sb<<1|0);M=+(s|0);if(Fb<Eb){Gb=Eb}else{Gb=Fb>M?M:Fb}h[Bb>>3]=Gb;Gb=xb;if(Gb<-.10000000149011612){Hb=-.10000000149011612;h[g>>3]=Hb;ZDb(p);i=l;return}Hb=Gb>.10000000149011612?.10000000149011612:Gb;h[g>>3]=Hb;ZDb(p);i=l;return}function cn(a,b){a=a|0;b=b|0;var c=0.0,d=0.0,e=0;c=+h[a>>3];d=+h[b>>3];if(c<d){e=-1;return e|0}e=c>d|0;return e|0}function dn(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+8|0;f=e|0;g=c[b+44>>2]|0;h=c[g+24>>2]|0;if((QGb(h,2082520)|0)==0){c[g+32>>2]=1;j=0;i=e;return j|0}if((QEb(f|0,h,-1,b)|0)<0){j=-22;i=e;return j|0}if((c[g+32>>2]|0)!=0){j=0;i=e;return j|0}b=f|0;h=f+1|0;k=f+2|0;a[g+28|0]=(((d[b]|0)*263|0)+16896+((d[h]|0)*516|0)+((d[k]|0)*100|0)|0)>>>10;a[g+29|0]=((((d[b]|0)*-152|0)+511+((d[h]|0)*-298|0)+((d[k]|0)*450|0)|0)>>>10)+128;a[g+30|0]=((((d[b]|0)*450|0)+511+((d[h]|0)*-377|0)+((d[k]|0)*-73|0)|0)>>>10)+128;a[g+31|0]=a[f+3|0]|0;j=0;i=e;return j|0}function en(a){a=a|0;Ok(a,xk(551104)|0);return 0}function fn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0.0,U=0,V=0,W=0;f=b+8|0;b=c[f>>2]|0;g=c[b+44>>2]|0;h=e+72|0;if((c[h>>2]|0)<=0){i=b;j=i+32|0;k=c[j>>2]|0;l=c[k>>2]|0;m=cj(l,e)|0;return m|0}b=e|0;n=e+32|0;o=g+36|0;p=g+32|0;q=e+68|0;r=g+4|0;s=g+8|0;t=g+12|0;u=g+16|0;v=g+20|0;w=g+31|0;x=g+28|0;y=g+40|0;z=g+29|0;A=g+30|0;g=0;do{B=c[b>>2]|0;C=ba(c[n>>2]|0,g)|0;D=g>>c[o>>2];E=c[e+4>>2]|0;F=ba(D,c[e+36>>2]|0)|0;G=c[e+8>>2]|0;H=ba(D,c[e+40>>2]|0)|0;D=c[q>>2]|0;I=(D|0)>0;do{if((c[p>>2]|0)==0){if(I){J=0;K=D}else{break}while(1){L=+((d[w]|0)>>>0)/255.0;M=c[t>>2]|0;N=(J-(c[r>>2]|0)|0)%(M|0)|0;O=c[u>>2]|0;P=(g-(c[s>>2]|0)|0)%(O|0)|0;Q=c[v>>2]|0;if((((N|0)<0?M:0)+N|0)<(Q|0)){R=12}else{if((((P|0)<0?O:0)+P|0)<(Q|0)){R=12}else{S=K}}if((R|0)==12){R=0;T=1.0-L;Q=B+(C+J)|0;a[Q]=~~(T*+(d[Q]|0|0)+L*+(d[x]|0|0));Q=E+(F+(J>>c[y>>2]))|0;a[Q]=~~(T*+(d[Q]|0|0)+L*+(d[z]|0|0));Q=G+(H+(J>>c[y>>2]))|0;a[Q]=~~(T*+(d[Q]|0|0)+L*+(d[A]|0|0));S=c[q>>2]|0}Q=J+1|0;if((Q|0)<(S|0)){J=Q;K=S}else{break}}}else{if(I){U=0;V=D}else{break}while(1){Q=c[t>>2]|0;P=(U-(c[r>>2]|0)|0)%(Q|0)|0;O=c[u>>2]|0;N=(g-(c[s>>2]|0)|0)%(O|0)|0;M=c[v>>2]|0;if((((P|0)<0?Q:0)+P|0)<(M|0)){R=8}else{if((((N|0)<0?O:0)+N|0)<(M|0)){R=8}else{W=V}}if((R|0)==8){R=0;M=B+(C+U)|0;a[M]=~a[M];W=c[q>>2]|0}M=U+1|0;if((M|0)<(W|0)){U=M;V=W}else{break}}}}while(0);g=g+1|0;}while((g|0)<(c[h>>2]|0));i=c[f>>2]|0;j=i+32|0;k=c[j>>2]|0;l=c[k>>2]|0;m=cj(l,e)|0;return m|0}function gn(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0.0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;b=i;i=i+112|0;e=b|0;f=b+104|0;g=c[a+8>>2]|0;j=c[g+44>>2]|0;k=bFb(c[a+52>>2]|0)|0;l=d[k+5|0]|0;c[j+40>>2]=l;m=d[k+6|0]|0;c[j+36>>2]=m;k=a+24|0;n=+(c[k>>2]|0);h[e+32>>3]=n;h[e+24>>3]=n;o=a+20|0;p=+(c[o>>2]|0);h[e+48>>3]=p;h[e+40>>3]=p;r=c[a+28>>2]|0;if((r|0)==0){s=1.0}else{s=+(r|0)/+(c[a+32>>2]|0)}h[e+56>>3]=s;a=e|0;h[a>>3]=s*(p/n);h[e+8>>3]=+(l|0);h[e+16>>3]=+(m|0);m=e+64|0;h[m>>3]=+q;l=e+72|0;h[l>>3]=+q;r=e+80|0;h[r>>3]=+q;t=e+88|0;h[t>>3]=+q;u=e+96|0;h[u>>3]=+q;e=j+44|0;v=g;g=j+4|0;w=j+48|0;x=j+8|0;y=j+52|0;z=j+12|0;A=j+56|0;B=j+16|0;C=j+60|0;D=j+20|0;E=0;do{F=c[e>>2]|0;G=OBb(f,F,160280,a,0,0,0,0,0,0,v)|0;H=(E|0)==5;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[m>>3]=n;c[g>>2]=~~n;F=c[w>>2]|0;G=OBb(f,F,160280,a,0,0,0,0,0,0,v)|0;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[l>>3]=n;c[x>>2]=~~n;F=c[y>>2]|0;G=OBb(f,F,160280,a,0,0,0,0,0,0,v)|0;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[t>>3]=n;c[z>>2]=~~n;F=c[A>>2]|0;G=OBb(f,F,160280,a,0,0,0,0,0,0,v)|0;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[r>>3]=n;c[B>>2]=~~n;F=c[C>>2]|0;G=OBb(f,F,160280,a,0,0,0,0,0,0,v)|0;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[u>>3]=n;c[D>>2]=~~n;E=E+1|0;}while((E|0)<6);if((K|0)==17){yDb(v,16,2143064,(L=i,i=i+8|0,c[L>>2]=J,L)|0);i=L;M=I;i=b;return M|0}I=c[z>>2]|0;if((I|0)>0){N=I}else{N=c[o>>2]|0}c[z>>2]=N;z=c[B>>2]|0;if((z|0)>0){O=z}else{O=c[k>>2]|0}c[B>>2]=O;if((N|O|0)<0){yDb(v,16,2156736,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;M=-22;i=b;return M|0}else{B=c[x>>2]|0;x=d[j+28|0]|0;k=d[j+29|0]|0;z=d[j+30|0]|0;o=d[j+31|0]|0;yDb(v,40,2149952,(L=i,i=i+64|0,c[L>>2]=c[g>>2],c[L+8>>2]=B,c[L+16>>2]=N,c[L+24>>2]=O,c[L+32>>2]=x,c[L+40>>2]=k,c[L+48>>2]=z,c[L+56>>2]=o,L)|0);i=L;M=0;i=b;return M|0}return 0}function hn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0,U=0,V=0.0,W=0,X=0;f=b+8|0;b=c[(c[f>>2]|0)+44>>2]|0;g=c[b+4>>2]|0;h=c[b+8>>2]|0;i=(h|0)>0?h:0;j=b+16|0;k=e+72|0;if((i|0)>=(c[k>>2]|0)){l=c[f>>2]|0;m=l+32|0;n=c[m>>2]|0;o=c[n>>2]|0;p=cj(o,e)|0;return p|0}q=e|0;r=e+32|0;s=b+36|0;t=b+32|0;u=(g|0)>0?g:0;v=e+68|0;w=b+12|0;x=b+20|0;y=h-1|0;z=b+28|0;A=b+31|0;B=b+40|0;C=b+29|0;D=b+30|0;b=i;while(1){if((b|0)>=((c[j>>2]|0)+h|0)){E=24;break}i=c[q>>2]|0;F=ba(c[r>>2]|0,b)|0;G=b>>c[s>>2];H=c[e+4>>2]|0;I=ba(G,c[e+36>>2]|0)|0;J=c[e+8>>2]|0;K=ba(G,c[e+40>>2]|0)|0;G=c[w>>2]|0;L=G+g|0;M=(u|0)<(L|0);a:do{if((c[t>>2]|0)==0){if(!M){break}N=b-h|0;O=y-b|0;P=u;Q=L;R=G;while(1){if((P|0)>=(c[v>>2]|0)){break a}S=+((d[A]|0)>>>0)/255.0;T=c[x>>2]|0;do{if((N|0)<(T|0)){E=21}else{if((O+(c[j>>2]|0)|0)<(T|0)){E=21;break}if((P-g|0)<(T|0)){E=21;break}if((Q+~P|0)<(T|0)){E=21}else{U=R}}}while(0);if((E|0)==21){E=0;V=1.0-S;T=i+(F+P)|0;a[T]=~~(V*+(d[T]|0|0)+S*+(d[z]|0|0));T=H+(I+(P>>c[B>>2]))|0;a[T]=~~(V*+(d[T]|0|0)+S*+(d[C]|0|0));T=J+(K+(P>>c[B>>2]))|0;a[T]=~~(V*+(d[T]|0|0)+S*+(d[D]|0|0));U=c[w>>2]|0}T=P+1|0;W=U+g|0;if((T|0)<(W|0)){P=T;Q=W;R=U}else{break}}}else{if(!M){break}R=b-h|0;Q=y-b|0;P=u;O=L;N=G;while(1){if((P|0)>=(c[v>>2]|0)){break a}W=c[x>>2]|0;do{if((R|0)<(W|0)){E=14}else{if((Q+(c[j>>2]|0)|0)<(W|0)){E=14;break}if((P-g|0)<(W|0)){E=14;break}if((O+~P|0)<(W|0)){E=14}else{X=N}}}while(0);if((E|0)==14){E=0;W=i+(F+P)|0;a[W]=~a[W];X=c[w>>2]|0}W=P+1|0;T=X+g|0;if((W|0)<(T|0)){P=W;O=T;N=X}else{break}}}}while(0);F=b+1|0;if((F|0)<(c[k>>2]|0)){b=F}else{E=24;break}}if((E|0)==24){l=c[f>>2]|0;m=l+32|0;n=c[m>>2]|0;o=c[n>>2]|0;p=cj(o,e)|0;return p|0}return 0}function jn(b){b=b|0;var d=0;d=c[b+44>>2]|0;a[d+32|0]=~~(+h[d+16>>3]*255.0+.5);a[d+33|0]=~~(+h[d+24>>3]*255.0+.5);return 0}function kn(a){a=a|0;var b=0;b=c[a+44>>2]|0;$Db(b+4|0);$Db(b+8|0);$Db(b+12|0);return}function ln(a){a=a|0;Ok(a,xk(551096)|0);return 0}function mn(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+8|0;j=h|0;c[j>>2]=g;k=c[f+8>>2]|0;l=k+44|0;m=c[l>>2]|0;n=c[c[k+32>>2]>>2]|0;k=c[m+4>>2]|0;o=c[m+8>>2]|0;do{if((RCb(g)|0)==0){m=Zr(n,c[n+20>>2]|0,c[n+24>>2]|0)|0;if((m|0)!=0){NCb(m,c[j>>2]|0)|0;p=m;q=0;r=c[j>>2]|0;break}JCb(j);s=-12;i=h;return s|0}else{p=g;q=1;r=g}}while(0);g=f+20|0;m=c[g>>2]|0;t=f+24|0;f=c[t>>2]|0;u=c[r>>2]|0;v=c[r+32>>2]|0;UGb(k|0,u|0,m)|0;UGb(k+m|0,u+v|0,m)|0;r=k+(m<<1)|0;w=v<<1;x=u+w|0;y=f-2|0;if((y|0)>2){f=m-2|0;z=v*-2|0;if((f|0)>2){A=m-1|0;B=x;C=r;D=2;while(1){a[C]=a[B]|0;a[C+1|0]=a[B+1|0]|0;E=2;while(1){F=E+z|0;G=E+w|0;H=E-v|0;I=E+v|0;J=E+1|0;a[C+E|0]=((((d[B+(I-1)|0]|0)+(d[B+(H-1)|0]|0)+(d[B+(H+1)|0]|0)+(d[B+(I+1)|0]|0)|0)*9|0)+((d[B+(G-2)|0]|0)+(d[B+(F-2)|0]|0)+(d[B+(F+2)|0]|0)+(d[B+(G+2)|0]|0)<<1)+((d[B+(G-1)|0]|0)+(d[B+(F-1)|0]|0)+(d[B+(F+1)|0]|0)+(d[B+(G+1)|0]|0)+(d[B+(H-2)|0]|0)+(d[B+(I-2)|0]|0)+(d[B+(H+2)|0]|0)+(d[B+(I+2)|0]|0)<<2)+((d[B+E|0]|0)*15|0)+(((d[B+I|0]|0)+(d[B+H|0]|0)+(d[B+(E-1)|0]|0)+(d[B+J|0]|0)|0)*12|0)+(((d[B+G|0]|0)+(d[B+F|0]|0)+(d[B+(E-2)|0]|0)+(d[B+(E+2)|0]|0)|0)*5|0)|0)/159|0;if((J|0)<(f|0)){E=J}else{break}}a[C+f|0]=a[B+f|0]|0;a[C+A|0]=a[B+A|0]|0;E=D+1|0;if((E|0)<(y|0)){B=B+v|0;C=C+m|0;D=E}else{break}}}else{D=x;C=r;B=2;while(1){a[C]=a[D]|0;a[C+1|0]=a[D+1|0]|0;a[C+2|0]=a[D+2|0]|0;a[C+3|0]=a[D+3|0]|0;A=B+1|0;if((A|0)<(y|0)){D=D+v|0;C=C+m|0;B=A}else{break}}}K=u+(ba(v,y)|0)|0;L=k+(ba(y,m)|0)|0}else{K=x;L=r}UGb(L|0,K|0,m)|0;UGb(L+m|0,K+v|0,m)|0;m=c[g>>2]|0;v=c[t>>2]|0;K=v-1|0;do{if((K|0)>1){L=m-1|0;r=m+1|0;x=(c[l>>2]|0)+12|0;if((L|0)>1){M=1;N=k;O=o}else{P=m;Q=v;break}while(1){y=O+(m<<1)|0;u=ba(M,m)|0;B=1;while(1){C=d[N+(B-1)|0]|0;D=B+1|0;A=d[N+D|0]|0;f=B+m|0;w=d[N+(f+L)|0]|0;z=d[N+(r+f)|0]|0;E=A-C-(d[N+(B+L)|0]<<1)+(d[N+(D+m)|0]<<1)-w+z|0;J=w-(A+C)+z-(d[N+B|0]<<1)+(d[N+(f+m)|0]<<1)|0;z=-E|0;C=-J|0;b[O+(f<<1)>>1]=((J|0)>-1?J:C)+((E|0)>-1?E:z);do{if((E|0)==0){R=20}else{f=(E|0)<0;A=f?z:E;w=(f?C:J)<<16;f=A*27146|0;F=A*158218|0;A=-f|0;if((w|0)>(-F|0)&(w|0)<(A|0)){S=0;break}if((w|0)>(A|0)&(w|0)<(f|0)){S=2;break}if((w|0)>(f|0)&(w|0)<(F|0)){S=1}else{R=20}}}while(0);if((R|0)==20){R=0;S=3}a[(c[x>>2]|0)+(B+u)|0]=S;if((D|0)<(L|0)){B=D}else{break}}B=M+1|0;if((B|0)<(K|0)){M=B;N=N+m|0;O=y}else{break}}P=c[g>>2]|0;Q=c[t>>2]|0}else{P=m;Q=v}}while(0);TGb(k|0,0,ba(Q,P)|0)|0;P=c[g>>2]|0;Q=c[t>>2]|0;v=Q-1|0;if((v|0)>1){m=P-1|0;O=(m|0)>1;N=(c[l>>2]|0)+12|0;M=P<<1;K=P+1|0;S=M-1|0;L=M|1;x=o;o=1;r=k;while(1){B=r+P|0;u=x+(P<<1)|0;if(O){J=ba(o,P)|0;C=1;do{E=a[(c[N>>2]|0)+(C+J)|0]|0;do{if((E|0)==1){z=C+P|0;F=b[x+(z<<1)>>1]|0;if(!((F&65535)>>>0>(e[x+(C-1<<1)>>1]|0)>>>0)){break}if(!((F&65535)>>>0>(e[x+(L+C<<1)>>1]|0)>>>0)){break}if((F&65535)>>>0>255>>>0){T=-(F&65535)>>31&255}else{T=F&255}a[r+z|0]=T}else if((E|0)==3){z=C+P|0;F=b[x+(z<<1)>>1]|0;if(!((F&65535)>>>0>(e[x+(C<<1)>>1]|0)>>>0)){break}if(!((F&65535)>>>0>(e[x+(C+M<<1)>>1]|0)>>>0)){break}if((F&65535)>>>0>255>>>0){U=-(F&65535)>>31&255}else{U=F&255}a[r+z|0]=U}else if((E|0)==0){z=C+P|0;F=b[x+(z<<1)>>1]|0;if(!((F&65535)>>>0>(e[x+(S+C<<1)>>1]|0)>>>0)){break}if(!((F&65535)>>>0>(e[x+(C+1<<1)>>1]|0)>>>0)){break}if((F&65535)>>>0>255>>>0){V=-(F&65535)>>31&255}else{V=F&255}a[r+z|0]=V}else if((E|0)==2){z=C+P|0;F=b[x+(z<<1)>>1]|0;if(!((F&65535)>>>0>(e[x+(m+C<<1)>>1]|0)>>>0)){break}if(!((F&65535)>>>0>(e[x+(K+C<<1)>>1]|0)>>>0)){break}if((F&65535)>>>0>255>>>0){W=-(F&65535)>>31&255}else{W=F&255}a[r+z|0]=W}}while(0);C=C+1|0;}while((C|0)<(m|0))}C=o+1|0;if((C|0)<(v|0)){x=u;o=C;r=B}else{break}}X=c[t>>2]|0;Y=c[g>>2]|0}else{X=Q;Y=P}P=c[p+32>>2]|0;Q=c[l>>2]|0;l=a[Q+32|0]|0;g=a[Q+33|0]|0;if((X|0)>0){Q=(Y|0)>0;t=Y-1|0;r=X-1|0;o=0;x=k;k=c[p>>2]|0;while(1){if(Q){v=(o|0)==0;m=(o|0)==(r|0);W=0;do{K=a[x+W|0]|0;a:do{if((K&255)>>>0>(g&255)>>>0){a[k+W|0]=K}else{if((W|0)==0){if((K&255)>>>0>(l&255)>>>0){R=61}}else{if(((W|0)==(t|0)|v|m)&(K&255)>>>0>(l&255)>>>0){R=61}}b:do{if((R|0)==61){R=0;V=W-Y|0;do{if(!((d[x+(V-1)|0]|0)>>>0>(g&255)>>>0)){if((d[x+V|0]|0)>>>0>(g&255)>>>0){break}if((d[x+(V+1)|0]|0)>>>0>(g&255)>>>0){break}if((d[x+(W-1)|0]|0)>>>0>(g&255)>>>0){break}if((d[x+(W+1)|0]|0)>>>0>(g&255)>>>0){break}S=W+Y|0;if((d[x+(S-1)|0]|0)>>>0>(g&255)>>>0){break}if((d[x+S|0]|0)>>>0>(g&255)>>>0){break}if(!((d[x+(S+1)|0]|0)>>>0>(g&255)>>>0)){break b}}}while(0);a[k+W|0]=K;break a}}while(0);a[k+W|0]=0}}while(0);W=W+1|0;}while((W|0)<(Y|0))}W=o+1|0;if((W|0)<(X|0)){o=W;x=x+Y|0;k=k+P|0}else{break}}}if(!q){JCb(j)}s=cj(n,p)|0;i=h;return s|0}function nn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=a+20|0;e=a+24|0;a=b+4|0;c[a>>2]=WDb(ba(c[e>>2]|0,c[d>>2]|0)|0)|0;f=b+8|0;c[f>>2]=dEb(ba(c[e>>2]|0,c[d>>2]|0)|0,2)|0;g=WDb(ba(c[e>>2]|0,c[d>>2]|0)|0)|0;c[b+12>>2]=g;if((c[a>>2]|0)==0){return-12|0}else{return((c[f>>2]|0)==0|(g|0)==0?-12:0)|0}return 0}function on(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=b+264|0;d=c[a>>2]|0;if((d|0)==-1){e=hFb()|0;c[a>>2]=e;f=e}else{f=d}oDb(b+4|0,f);return 0}function pn(a){a=a|0;var b=0;b=c[a+44>>2]|0;$Db(b+284|0);$Db(b+272|0);$Db(b+280|0);return}function qn(a){a=a|0;Ok(a,xk(551064)|0);return 0}function rn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=b+8|0;g=c[(c[f>>2]|0)+44>>2]|0;h=a[g+296|0]|0;i=a[g+297|0]|0;j=a[g+298|0]|0;k=e|0;l=b+24|0;m=c[l>>2]|0;if((m|0)>0){n=b+20|0;o=e+32|0;p=h&255;q=g+272|0;r=i&255;s=j&255;t=g+292|0;u=c[k>>2]|0;v=0;w=0;x=c[n>>2]|0;y=m;while(1){if((x|0)>0){m=c[q>>2]|0;z=c[t>>2]|0;A=u;B=v;C=0;while(1){c[m+(B<<2)>>2]=d[A+p|0]|0;c[m+(B+1<<2)>>2]=d[A+r|0]|0;D=B+3|0;c[m+(B+2<<2)>>2]=d[A+s|0]|0;E=C+1|0;F=c[n>>2]|0;if((E|0)<(F|0)){A=A+(d[z+4|0]|0)|0;B=D;C=E}else{break}}G=D;H=F;I=c[l>>2]|0}else{G=v;H=x;I=y}C=w+1|0;if((C|0)<(I|0)){u=u+(c[o>>2]|0)|0;v=G;w=C;x=H;y=I}else{J=q;break}}}else{J=g+272|0}q=g+276|0;I=g+284|0;y=g+288|0;H=g+268|0;x=g+280|0;w=g+4|0;D8(c[J>>2]|0,3,c[q>>2]|0,c[I>>2]|0,c[y>>2]|0,c[H>>2]|0,c[x>>2]|0,w);E8(c[J>>2]|0,3,c[q>>2]|0,c[I>>2]|0,c[y>>2]|0,c[H>>2]|0,c[x>>2]|0,w);w=c[l>>2]|0;if((w|0)<=0){K=c[f>>2]|0;L=K+32|0;M=c[L>>2]|0;N=c[M>>2]|0;O=cj(N,e)|0;return O|0}H=b+20|0;b=e+32|0;y=h&255;h=i&255;i=j&255;j=g+292|0;g=c[k>>2]|0;k=0;q=0;J=c[H>>2]|0;G=w;while(1){if((J|0)>0){w=g;v=k;o=0;while(1){P=v+1|0;u=(c[(c[x>>2]|0)+(v<<2)>>2]|0)*3|0;a[w+y|0]=c[(c[I>>2]|0)+(u<<2)>>2];a[w+h|0]=c[(c[I>>2]|0)+(u+1<<2)>>2];a[w+i|0]=c[(c[I>>2]|0)+(u+2<<2)>>2];u=o+1|0;Q=c[H>>2]|0;if((u|0)<(Q|0)){w=w+(d[(c[j>>2]|0)+4|0]|0)|0;v=P;o=u}else{break}}R=P;S=Q;T=c[l>>2]|0}else{R=k;S=J;T=G}o=q+1|0;if((o|0)<(T|0)){g=g+(c[b>>2]|0)|0;k=R;q=o;J=S;G=T}else{break}}K=c[f>>2]|0;L=K+32|0;M=c[L>>2]|0;N=c[M>>2]|0;O=cj(N,e)|0;return O|0}function sn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=a+52|0;c[b+292>>2]=bFb(c[d>>2]|0)|0;e=ba(c[a+24>>2]|0,c[a+20>>2]|0)|0;a=b+276|0;c[a>>2]=e;f=b+272|0;g=YDb(c[f>>2]|0,e,12)|0;c[f>>2]=g;if((g|0)==0){h=-12;return h|0}g=b+280|0;f=YDb(c[g>>2]|0,c[a>>2]|0,4)|0;c[g>>2]=f;if((f|0)==0){h=-12;return h|0}f=b+284|0;g=YDb(c[f>>2]|0,c[b+288>>2]|0,12)|0;c[f>>2]=g;if((g|0)==0){h=-12;return h|0}Aw(b+296|0,c[d>>2]|0)|0;h=0;return h|0}function tn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=c[e+4>>2]|0;g=f&15|f>>4;f=a+40|0;h=d;j=e+8|0;e=d|0;k=d+4|0;l=d+48|0;m=a+28|0;n=a+32|0;o=a+36|0;TGb(h|0,0,60)|0;do{if((g&1|0)!=0){a=vAb(2042528,(p=i,i=i+8|0,c[p>>2]=c[f>>2],p)|0)|0;i=p;if((a|0)==0){q=-12;i=b;return q|0}else{c[j+(c[f>>2]<<2)>>2]=0;c[e>>2]=a;c[k>>2]=0;c[l>>2]=2164;Hi(c[f>>2]|0,f,4,m,n,d)|0;c[o>>2]=c[f>>2];break}}}while(0);TGb(h|0,0,60)|0;do{if((g&2|0)!=0){a=vAb(2042528,(p=i,i=i+8|0,c[p>>2]=c[f>>2],p)|0)|0;i=p;if((a|0)==0){q=-12;i=b;return q|0}else{c[j+(c[f>>2]<<2)>>2]=1;c[e>>2]=a;c[k>>2]=0;c[l>>2]=2164;Hi(c[f>>2]|0,f,4,m,n,d)|0;c[o>>2]=c[f>>2];break}}}while(0);TGb(h|0,0,60)|0;do{if((g&4|0)!=0){a=vAb(2042528,(p=i,i=i+8|0,c[p>>2]=c[f>>2],p)|0)|0;i=p;if((a|0)==0){q=-12;i=b;return q|0}else{c[j+(c[f>>2]<<2)>>2]=2;c[e>>2]=a;c[k>>2]=0;c[l>>2]=2164;Hi(c[f>>2]|0,f,4,m,n,d)|0;c[o>>2]=c[f>>2];break}}}while(0);TGb(h|0,0,60)|0;if((g&8|0)==0){q=0;i=b;return q|0}g=vAb(2042528,(p=i,i=i+8|0,c[p>>2]=c[f>>2],p)|0)|0;i=p;if((g|0)==0){q=-12;i=b;return q|0}c[j+(c[f>>2]<<2)>>2]=3;c[e>>2]=g;c[k>>2]=0;c[l>>2]=2164;Hi(c[f>>2]|0,f,4,m,n,d)|0;c[o>>2]=c[f>>2];q=0;i=b;return q|0}function un(a){a=a|0;var b=0,d=0;b=a+40|0;if((c[b>>2]|0)==0){return}d=a+28|0;a=0;do{$Db((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function vn(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b+16|0;f=c[c[d>>2]>>2]|0;g=c[f+64>>2]|0;if((g|0)==0){h=-11;return h|0}if((c[g>>2]|0)==0){h=-11;return h|0}if((c[f+68>>2]|0)==0){f=xk(551888)|0;Hk(f,(c[c[d>>2]>>2]|0)+68|0);i=c[(c[c[d>>2]>>2]|0)+64>>2]|0}else{i=g}g=i+4|0;d=bFb(c[c[g>>2]>>2]|0)|0;f=(e[d+8>>1]|0)>>>11&15;j=a[d+7|0]&1;d=i|0;i=1;while(1){if(!(i>>>0<(c[d>>2]|0)>>>0)){k=9;break}l=bFb(c[(c[g>>2]|0)+(i<<2)>>2]|0)|0;if(!(f<<16>>16==((e[l+8>>1]|0)>>>11&15))){h=-11;k=14;break}if((j|0)==(a[l+7|0]&1|0)){i=i+1|0}else{h=-11;k=14;break}}if((k|0)==9){if(f<<16>>16==7){m=551752}else{m=(j|0)==0?551760:551768}j=b+40|0;if((c[j>>2]|0)==0){h=0;return h|0}f=b+32|0;b=0;while(1){i=xk(m)|0;Hk(i,(c[(c[f>>2]|0)+(b<<2)>>2]|0)+64|0);i=b+1|0;if(i>>>0<(c[j>>2]|0)>>>0){b=i}else{h=0;break}}return h|0}else if((k|0)==14){return h|0}return 0}function wn(a){a=a|0;c[(c[a+44>>2]|0)+4>>2]=8;return tn(a)|0}function xn(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a>>2]|0;e=c[c[b+16>>2]>>2]|0;f=c[b+44>>2]|0;g=bFb(c[e+52>>2]|0)|0;if(!(((c[f+8+((((c[a+4>>2]|0)-(c[b+28>>2]|0)|0)/60|0)<<2)>>2]|0)-1|0)>>>0<2>>>0)){return 0}c[a+24>>2]=-(-(c[e+24>>2]|0)>>(d[g+6|0]|0));c[a+20>>2]=-(-(c[e+20>>2]|0)>>(d[g+5|0]|0));return 0}function yn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=i;i=i+8|0;f=e|0;c[f>>2]=d;d=c[b+8>>2]|0;b=c[d+44>>2]|0;g=d+40|0;a:do{if((c[g>>2]|0)==0){h=0;j=0}else{k=d+32|0;l=b+8|0;m=b+40|0;n=b+24|0;o=b+48|0;p=b+44|0;q=0;r=0;s=0;while(1){t=c[(c[k>>2]|0)+(s<<2)>>2]|0;u=c[l+(s<<2)>>2]|0;do{if((c[t+144>>2]|0)==0){v=t+20|0;w=t+24|0;x=Zr(t,c[v>>2]|0,c[w>>2]|0)|0;if((x|0)==0){h=-12;j=r;break a}NCb(x,c[f>>2]|0)|0;y=c[x>>2]|0;z=c[x+32>>2]|0;A=c[f>>2]|0;b:do{if((c[m>>2]|0)==0){iDb(y,z,c[A+(u<<2)>>2]|0,c[A+32+(u<<2)>>2]|0,c[n+(u<<2)>>2]|0,c[w>>2]|0)}else{B=c[A>>2]|0;C=c[A+32>>2]|0;D=c[v>>2]|0;E=c[w>>2]|0;F=c[o>>2]|0;if((E|0)<=0){break}G=c[p>>2]|0;H=(D|0)>0;I=u<<1;if((G|0)==2){J=B;K=y;L=0;while(1){if(H){M=0;do{N=(ba(M,F)|0)+I|0;O=M<<1;a[K+O|0]=a[J+N|0]|0;a[K+(O|1)|0]=a[J+(N+1)|0]|0;M=M+1|0;}while((M|0)<(D|0))}M=L+1|0;if((M|0)<(E|0)){J=J+C|0;K=K+z|0;L=M}else{break b}}}else if((G|0)!=1){break}if(H){P=B;Q=y;R=0}else{break}while(1){L=0;do{a[Q+L|0]=a[P+((ba(L,F)|0)+u)|0]|0;L=L+1|0;}while((L|0)<(D|0));L=R+1|0;if((L|0)<(E|0)){P=P+C|0;Q=Q+z|0;R=L}else{break}}}}while(0);z=cj(t,x)|0;if((z|0)==-541478725){S=r+1|0;T=-541478725;break}else{if((z|0)<0){h=z;j=r;break a}else{S=r;T=z;break}}}else{S=r;T=q}}while(0);t=s+1|0;if(t>>>0<(c[g>>2]|0)>>>0){q=T;r=S;s=t}else{h=T;j=S;break}}}}while(0);JCb(f);if((j|0)==(c[g>>2]|0)){i=e;return-541478725|0}else{i=e;return((h|0)==-541478725?0:h)|0}return 0}function zn(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+8|0;g=f|0;h=c[b+8>>2]|0;j=c[h+44>>2]|0;k=b+52|0;l=bFb(c[k>>2]|0)|0;m=l+7|0;n=a[m]|0;if((n&32)==0){o=(d[l+4|0]|0)>>>0>2>>>0?112:16}else{o=7}if((c[j+4>>2]&~((n<<24>>24<0?8:0)|o)|0)!=0){yDb(h,16,2163520,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-22;i=f;return p|0}h=dDb(j+24|0,c[k>>2]|0,c[b+20>>2]|0)|0;if((h|0)<0){p=h;i=f;return p|0}c[j+44>>2]=(((e[l+8>>1]|0)>>>11&15)+1|0)>>>3;c[j+48>>2]=(aFb(l)|0)>>3;c[j+40>>2]=((d[m]|0)>>>4&1^1)&255;if((a[m]&32)==0){p=0;i=f;return p|0}Aw(g|0,c[k>>2]|0)|0;k=j+8|0;c[k>>2]=d[g+(c[k>>2]|0)|0]|0;k=j+12|0;c[k>>2]=d[g+(c[k>>2]|0)|0]|0;k=j+16|0;c[k>>2]=d[g+(c[k>>2]|0)|0]|0;k=j+20|0;c[k>>2]=d[g+(c[k>>2]|0)|0]|0;p=0;i=f;return p|0}function An(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;d=c[a+44>>2]|0;e=d+20|0;f=c[e>>2]|0;c[d+12>>2]=65536/(f|0)|0;c[d+72>>2]=0;g=d+64|0;if((c[g>>2]|0)==0&(c[g+4>>2]|0)==0){j=f}else{c[e>>2]=0;j=0}e=c[d+16>>2]|0;if((e|j|0)!=0){f=c[d+52>>2]|0;yDb(a,40,2171816,(k=i,i=i+32|0,c[k>>2]=(c[d+4>>2]|0)==0?2097536:2042264,c[k+8>>2]=e,c[k+16>>2]=j,c[k+24>>2]=f,k)|0);i=k}f=d+56|0;j=c[f>>2]|0;e=c[f+4>>2]|0;f=c[g>>2]|0;l=c[g+4>>2]|0;if((j|f|0)==0&(e|l|0)==0){m=d+76|0;n=PGb(m,1960984,4)|0;o=(n|0)==0;p=o&1;q=d+80|0;r=q;c[r>>2]=p;i=b;return 0}g=c[d+52>>2]|0;yDb(a,40,1997432,(k=i,i=i+32|0,c[k>>2]=(c[d+4>>2]|0)==0?2097536:2042264,h[k+8>>3]=(+(j>>>0)+ +(e>>>0)*4294967296.0)/1.0e6,h[k+16>>3]=(+(f>>>0)+ +(l>>>0)*4294967296.0)/1.0e6,c[k+24>>2]=g,k)|0);i=k;m=d+76|0;n=PGb(m,1960984,4)|0;o=(n|0)==0;p=o&1;q=d+80|0;r=q;c[r>>2]=p;i=b;return 0}function Bn(a){a=a|0;if((c[(c[a+44>>2]|0)+80>>2]|0)==0){Ok(a,xk(550064)|0);return 0}else{Ok(a,xk(550984)|0);return 0}return 0}function Cn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0;e=b+8|0;f=c[e>>2]|0;g=c[f+44>>2]|0;h=d+136|0;i=c[h>>2]|0;j=c[h+4>>2]|0;if((i|0)==0&(j|0)==(-2147483648|0)){k=-1.0}else{k=(+(i>>>0)+ +(j|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}j=g+72|0;i=c[j>>2]|0;do{if((i|0)==1){l=11}else if((i|0)==0){c[g+8>>2]=0;h=g+56|0;m=c[h>>2]|0;n=c[h+4>>2]|0;if(k<(+(m>>>0)+ +(n>>>0)*4294967296.0)/1.0e6){l=19;break}o=b+160|0;p=c[o+4>>2]|0;q=g+16|0;r=c[q>>2]|0;s=(r|0)<0|0?-1:0;if((p|0)<(s|0)|(p|0)==(s|0)&(c[o>>2]|0)>>>0<r>>>0){l=19;break}c[j>>2]=1;s=(r|0)==0;if((m|0)==0&(n|0)==0){if(s){l=11;break}t=k*1.0e6;n=~~+t>>>0;m=(E=+t,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[h>>2]=n;c[h+4>>2]=m;if(!(((n|0)!=0|(m|0)!=0)&(r|0)==0)){l=11;break}}else{if(!s){l=11;break}}c[q>>2]=c[o>>2];l=11}else{u=i;l=16}}while(0);do{if((l|0)==11){i=g+64|0;o=c[i>>2]|0;q=c[i+4>>2]|0;if((o|0)==0&(q|0)==0){i=b+160|0;s=c[i>>2]|0;r=c[i+4>>2]|0;i=c[g+16>>2]|0;m=ZGb(s,r,i,(i|0)<0|0?-1:0)|0;n=c[g+12>>2]|0;h=gHb(m,F,n,(n|0)<0|0?-1:0)|0;n=g+8|0;c[n>>2]=h;h=(c[g+20>>2]|0)+i|0;i=(h|0)<0|0?-1:0;if(!((r|0)>(i|0)|(r|0)==(i|0)&s>>>0>h>>>0)){u=1;l=16;break}c[j>>2]=2;v=n;l=18;break}else{n=g+56|0;t=(+((c[n>>2]|0)>>>0)+ +((c[n+4>>2]|0)>>>0)*4294967296.0)/1.0e6;w=(+(o>>>0)+ +(q>>>0)*4294967296.0)/1.0e6;q=g+8|0;c[q>>2]=~~((k-t)*65535.0/w);if(!(k>t+w)){l=19;break}c[j>>2]=2;v=q;l=18;break}}}while(0);do{if((l|0)==16){if((u|0)!=2){l=19;break}v=g+8|0;l=18}}while(0);do{if((l|0)==18){c[v>>2]=65535;x=-1;y=g+8|0}else if((l|0)==19){u=c[g+8>>2]|0;j=g+8|0;if(!(u>>>0>65535>>>0)){x=u&65535;y=j;break}x=-u>>31&65535;y=j}}while(0);l=x&65535;c[y>>2]=l;if((c[g+4>>2]|0)==1){x=l^65535;c[y>>2]=x;z=x}else{z=l}if((z|0)>=65535){A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;G=cj(D,d)|0;return G|0}if((c[g+52>>2]|0)!=0){z=c[d+72>>2]|0;l=c[(c[f+48>>2]|0)+28>>2]|0;Pe[c[c[f+56>>2]>>2]&255](f,378,d,0,(z|0)>(l|0)?l:z)|0;A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;G=cj(D,d)|0;return G|0}do{if((a[g+44|0]|0)!=0){if((c[g+80>>2]|0)!=0){break}z=c[d+72>>2]|0;l=c[(c[f+48>>2]|0)+28>>2]|0;Pe[c[c[f+56>>2]>>2]&255](f,120,d,0,(z|0)>(l|0)?l:z)|0;A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;G=cj(D,d)|0;return G|0}}while(0);g=f+56|0;z=d;l=d+72|0;x=c[l>>2]|0;y=f+48|0;v=c[(c[y>>2]|0)+28>>2]|0;Pe[c[c[g>>2]>>2]&255](f,532,z,0,(x|0)>(v|0)?v:x)|0;if((c[d+4>>2]|0)==0){A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;G=cj(D,d)|0;return G|0}if((c[d+8>>2]|0)==0){A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;G=cj(D,d)|0;return G|0}x=c[l>>2]|0;l=c[(c[y>>2]|0)+28>>2]|0;Pe[c[c[g>>2]>>2]&255](f,728,z,0,(x|0)>(l|0)?l:x)|0;A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;G=cj(D,d)|0;return G|0}function Dn(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[(c[b+8>>2]|0)+44>>2]|0;f=b+52|0;b=bFb(c[f>>2]|0)|0;c[e+24>>2]=d[b+5|0]|0;c[e+28>>2]=d[b+6|0]|0;c[e+32>>2]=($Eb(b)|0)>>3;g=e+52|0;c[g>>2]=(d[b+7|0]|0)>>>7&255&c[g>>2];a[e+44|0]=(Aw(e+45|0,c[f>>2]|0)|0)>>>31&255^1;if((wk(c[f>>2]|0,429784)|0)==0){h=0;i=e+36|0;j=i;c[j>>2]=h;k=h<<16;l=k|32768;m=e+40|0;n=m;c[n>>2]=l;return 0}h=(c[g>>2]|0)!=0?0:16;i=e+36|0;j=i;c[j>>2]=h;k=h<<16;l=k|32768;m=e+40|0;n=m;c[n>>2]=l;return 0}function En(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=c[b+44>>2]|0;b=h+44|0;i=a[b]|0;j=i<<24>>24!=0?0:3;k=c[e+72>>2]|0;l=(ba(k,f)|0)/(g|0)|0;m=(ba(k,f+1|0)|0)/(g|0)|0;if((l|0)>=(m|0)){return 0}g=e+(j<<2)|0;f=e+32+(j<<2)|0;j=h+48|0;k=e+68|0;e=h+36|0;n=h+8|0;o=h+40|0;h=l;l=c[k>>2]|0;p=i;while(1){i=p<<24>>24!=0?4:1;if((l|0)>0){q=(ba(d[j]|0,p&255)|0)+(ba(c[f>>2]|0,h)|0)|0;r=0;s=(c[g>>2]|0)+q|0;while(1){q=ba((d[s]|0)-(c[e>>2]|0)|0,c[n>>2]|0)|0;a[s]=(q+(c[o>>2]|0)|0)>>>16;q=r+1|0;t=c[k>>2]|0;if((q|0)<(t|0)){r=q;s=s+i|0}else{u=t;break}}}else{u=l}i=h+1|0;if((i|0)>=(m|0)){break}h=i;l=u;p=a[b]|0}return 0}function Fn(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;j=c[b+44>>2]|0;b=c[e+72>>2]|0;k=(ba(b,f)|0)/(g|0)|0;l=(ba(b,f+1|0)|0)/(g|0)|0;if((c[j+52>>2]|0)!=0){g=j+76|0;if((k|0)>=(l|0)){i=h;return 0}f=e;b=e+32|0;m=e+68|0;n=d[j+45|0]|0;o=j+8|0;p=j+77|0;q=d[j+46|0]|0;r=j+78|0;s=d[j+47|0]|0;t=j+79|0;u=d[j+48|0]|0;v=k;w=c[m>>2]|0;while(1){if((w|0)>0){x=ba(c[b>>2]|0,v)|0;y=0;z=(c[f>>2]|0)+x|0;while(1){x=d[g]|0;A=z+n|0;B=(ba((d[A]|0)-x|0,c[o>>2]|0)|0)+(x<<16|32768)>>16;if(B>>>0>255>>>0){C=-B>>31&255}else{C=B&255}a[A]=C;A=d[p]|0;B=z+q|0;x=(ba((d[B]|0)-A|0,c[o>>2]|0)|0)+(A<<16|32768)>>16;if(x>>>0>255>>>0){D=-x>>31&255}else{D=x&255}a[B]=D;B=d[r]|0;x=z+s|0;A=(ba((d[x]|0)-B|0,c[o>>2]|0)|0)+(B<<16|32768)>>16;if(A>>>0>255>>>0){E=-A>>31&255}else{E=A&255}a[x]=E;x=d[t]|0;A=z+u|0;B=(ba((d[A]|0)-x|0,c[o>>2]|0)|0)+(x<<16|32768)>>16;if(B>>>0>255>>>0){F=-B>>31&255}else{F=B&255}a[A]=F;A=y+1|0;B=c[m>>2]|0;if((A|0)<(B|0)){y=A;z=z+4|0}else{G=B;break}}}else{G=w}z=v+1|0;if((z|0)<(l|0)){v=z;w=G}else{break}}i=h;return 0}G=c[j+32>>2]|0;if((G|0)==4){w=j+76|0;if((k|0)>=(l|0)){i=h;return 0}v=e;m=e+32|0;F=e+68|0;o=d[j+45|0]|0;u=j+8|0;t=j+77|0;E=d[j+46|0]|0;s=j+78|0;r=d[j+47|0]|0;D=k;q=c[F>>2]|0;while(1){if((q|0)>0){p=ba(c[m>>2]|0,D)|0;C=0;n=(c[v>>2]|0)+p|0;while(1){p=d[w]|0;g=n+o|0;f=(ba((d[g]|0)-p|0,c[u>>2]|0)|0)+(p<<16|32768)>>16;if(f>>>0>255>>>0){H=-f>>31&255}else{H=f&255}a[g]=H;g=d[t]|0;f=n+E|0;p=(ba((d[f]|0)-g|0,c[u>>2]|0)|0)+(g<<16|32768)>>16;if(p>>>0>255>>>0){I=-p>>31&255}else{I=p&255}a[f]=I;f=d[s]|0;p=n+r|0;g=(ba((d[p]|0)-f|0,c[u>>2]|0)|0)+(f<<16|32768)>>16;if(g>>>0>255>>>0){J=-g>>31&255}else{J=g&255}a[p]=J;p=C+1|0;g=c[F>>2]|0;if((p|0)<(g|0)){C=p;n=n+4|0}else{K=g;break}}}else{K=q}n=D+1|0;if((n|0)<(l|0)){D=n;q=K}else{break}}i=h;return 0}else if((G|0)==3){G=j+76|0;if((k|0)>=(l|0)){i=h;return 0}K=e;q=e+32|0;D=e+68|0;e=d[j+45|0]|0;F=j+8|0;J=j+77|0;u=d[j+46|0]|0;r=j+78|0;s=d[j+47|0]|0;j=k;k=c[D>>2]|0;while(1){if((k|0)>0){I=ba(c[q>>2]|0,j)|0;E=0;t=(c[K>>2]|0)+I|0;while(1){I=d[G]|0;H=t+e|0;o=(ba((d[H]|0)-I|0,c[F>>2]|0)|0)+(I<<16|32768)>>16;if(o>>>0>255>>>0){L=-o>>31&255}else{L=o&255}a[H]=L;H=d[J]|0;o=t+u|0;I=(ba((d[o]|0)-H|0,c[F>>2]|0)|0)+(H<<16|32768)>>16;if(I>>>0>255>>>0){M=-I>>31&255}else{M=I&255}a[o]=M;o=d[r]|0;I=t+s|0;H=(ba((d[I]|0)-o|0,c[F>>2]|0)|0)+(o<<16|32768)>>16;if(H>>>0>255>>>0){N=-H>>31&255}else{N=H&255}a[I]=N;I=E+1|0;H=c[D>>2]|0;if((I|0)<(H|0)){E=I;t=t+3|0}else{O=H;break}}}else{O=k}t=j+1|0;if((t|0)<(l|0)){j=t;k=O}else{break}}i=h;return 0}else{yDb(0,0,2112368,(h=i,i=i+24|0,c[h>>2]=2098440,c[h+8>>2]=2092280,c[h+16>>2]=190,h)|0);i=h;Cd();return 0}return 0}function Gn(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=c[b+44>>2]|0;b=c[e+72>>2]|0;i=(ba(b,f)|0)/(g|0)|0;j=(ba(b,f+1|0)|0)/(g|0)|0;if((i|0)>=(j|0)){return 0}g=e;f=e+32|0;b=e+68|0;e=h+32|0;k=h+36|0;l=h+8|0;m=h+40|0;h=i;i=c[b>>2]|0;n=c[e>>2]|0;while(1){if((ba(n,i)|0)>0){o=ba(c[f>>2]|0,h)|0;p=0;q=(c[g>>2]|0)+o|0;while(1){o=ba((d[q]|0)-(c[k>>2]|0)|0,c[l>>2]|0)|0;a[q]=(o+(c[m>>2]|0)|0)>>>16;o=p+1|0;r=c[b>>2]|0;s=c[e>>2]|0;if((o|0)<(ba(s,r)|0)){p=o;q=q+1|0}else{t=r;u=s;break}}}else{t=i;u=n}q=h+1|0;if((q|0)<(j|0)){h=q;i=t;n=u}else{break}}return 0}function Hn(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=c[b+44>>2]|0;b=-(c[e+68>>2]|0)>>c[h+24>>2];i=-b|0;j=-(-(c[e+72>>2]|0)>>c[h+28>>2])|0;k=(ba(j,f)|0)/(g|0)|0;l=(ba(f+1|0,j)|0)/(g|0)|0;g=(k|0)<(l|0);j=(b|0)<0;b=h+8|0;if(!g){return 0}h=e+4|0;f=e+36|0;if(j){m=k}else{return 0}do{n=ba(c[f>>2]|0,m)|0;o=0;p=(c[h>>2]|0)+n|0;while(1){a[p]=((ba((d[p]|0)-128|0,c[b>>2]|0)|0)+8421367|0)>>>16;n=o+1|0;if((n|0)<(i|0)){o=n;p=p+1|0}else{break}}m=m+1|0;}while((m|0)<(l|0));if(!g){return 0}g=e+8|0;m=e+40|0;if(j){q=k}else{return 0}do{k=ba(c[m>>2]|0,q)|0;j=0;e=(c[g>>2]|0)+k|0;while(1){a[e]=((ba((d[e]|0)-128|0,c[b>>2]|0)|0)+8421367|0)>>>16;k=j+1|0;if((k|0)<(i|0)){j=k;e=e+1|0}else{break}}q=q+1|0;}while((q|0)<(l|0));return 0}function In(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=c[c[d+16>>2]>>2]|0;c[e+8>>2]=fFb(c[a+52>>2]|0)|0;g=f+20|0;h=c[g>>2]|0;c[a+20>>2]=h;j=f+24|0;f=c[e+4>>2]|0;e=(((f|0)==0)+(c[j>>2]|0)|0)/2|0;c[a+24>>2]=e;a=c[j>>2]|0;yDb(d,40,2347152,(d=i,i=i+40|0,c[d>>2]=c[g>>2],c[d+8>>2]=a,c[d+16>>2]=(f|0)==1?1933096:1997344,c[d+24>>2]=h,c[d+32>>2]=e,d)|0);i=d;i=b;return 0}function Jn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+8>>2]|0;a=c[d+44>>2]|0;e=c[c[d+32>>2]>>2]|0;c[b+72>>2]=c[e+24>>2];c[b+296>>2]=0;d=a+8|0;if((c[d>>2]|0)<=0){f=cj(e,b)|0;return f|0}if((c[a+4>>2]|0)==1){a=0;do{g=b+(a<<2)|0;h=c[b+32+(a<<2)>>2]|0;c[g>>2]=(c[g>>2]|0)+h;c[b+32+(a<<2)>>2]=h<<1;a=a+1|0;}while((a|0)<(c[d>>2]|0));f=cj(e,b)|0;return f|0}else{a=0;do{h=b+32+(a<<2)|0;c[h>>2]=c[h>>2]<<1;a=a+1|0;}while((a|0)<(c[d>>2]|0));f=cj(e,b)|0;return f|0}return 0}function Kn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=d|0;g=eEb(2171400)|0;c[f>>2]=g;TGb(d+4|0,0,32)|0;c[d+36>>2]=350;c[d+40>>2]=0;c[d+44>>2]=0;h=d+48|0;c[h>>2]=1074;c[d+52>>2]=0;c[d+56>>2]=0;if((g|0)==0){j=-12;i=b;return j|0}g=a+24|0;k=a+12|0;l=a+16|0;Hi(0,g,12,k,l,d)|0;m=a+20|0;c[m>>2]=c[g>>2];do{if((c[e+68>>2]|0)!=0){n=eEb(2097040)|0;c[f>>2]=n;c[h>>2]=0;if((n|0)==0){j=-12;i=b;return j|0}else{Hi(1,g,12,k,l,d)|0;c[m>>2]=c[g>>2];break}}}while(0);g=c[e+128>>2]|0;do{if((g-1&g|0)==0){m=c[e+132>>2]|0;if((m-1&m|0)!=0){break}if((c[e+136>>2]|0)<=(ba(m,g)|0)){j=0;i=b;return j|0}yDb(a,16,1997240,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;j=-22;i=b;return j|0}}while(0);yDb(a,16,2041920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;j=-22;i=b;return j|0}function Ln(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+44>>2]|0;d=b+4|0;e=c[d>>2]|0;f=b+8|0;if((e|0)==(c[f>>2]|0)){g=e}else{JCb(d);g=c[f>>2]|0}d=b+12|0;if((c[d>>2]|0)!=(g|0)){JCb(d)}JCb(f);$Db(b+140|0);$Db(b+172|0);$Db(b+216|0);$Db(b+204|0);b=a+24|0;if((c[b>>2]|0)==0){return}f=a+12|0;a=0;do{$Db((c[f>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function Mn(a){a=a|0;Ok(a,xk(550960)|0);return 0}function Nn(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;f=i;i=i+80|0;g=f|0;j=f+24|0;k=f+48|0;l=c[b+8>>2]|0;m=c[c[l+32>>2]>>2]|0;n=c[l+44>>2]|0;o=n;TGb(g|0,-1|0,20)|0;TGb(j|0,0,20)|0;do{if((c[b+12>>2]|0)==(c[l+12>>2]|0)){p=n+4|0;q=c[p>>2]|0;r=n+8|0;if((q|0)==(c[r>>2]|0)){s=q}else{JCb(p);s=c[r>>2]|0}c[p>>2]=s;q=n+12|0;t=c[q>>2]|0;c[r>>2]=t;if((e|0)==0){u=t}else{c[q>>2]=e;u=e}do{if((s|0)==0){c[p>>2]=t;if((t|0)==0){v=0;i=f;return v|0}if((u|0)!=0){break}yDb(0,0,1960848,(w=i,i=i+24|0,c[w>>2]=1933016,c[w+8>>2]=1910096,c[w+16>>2]=697,w)|0);i=w;Cd();return 0}else{if(!((t|0)==0|(u|0)==0)){break}yDb(0,0,1960848,(w=i,i=i+24|0,c[w>>2]=1933016,c[w+8>>2]=1910096,c[w+16>>2]=697,w)|0);i=w;Cd();return 0}}while(0);c[n+28>>2]=1}else{t=n+16|0;p=c[t>>2]|0;q=n+20|0;if((p|0)==(c[q>>2]|0)){x=p}else{JCb(t);x=c[q>>2]|0}c[t>>2]=x;p=n+24|0;r=c[p>>2]|0;c[q>>2]=r;if((e|0)==0){y=r}else{c[p>>2]=e;y=e}do{if((x|0)==0){c[t>>2]=r;if((r|0)==0){v=0;i=f;return v|0}if((y|0)!=0){break}yDb(0,0,1960848,(w=i,i=i+24|0,c[w>>2]=1889832,c[w+8>>2]=1910096,c[w+16>>2]=700,w)|0);i=w;Cd();return 0}else{if(!((r|0)==0|(y|0)==0)){break}yDb(0,0,1960848,(w=i,i=i+24|0,c[w>>2]=1889832,c[w+8>>2]=1910096,c[w+16>>2]=700,w)|0);i=w;Cd();return 0}}while(0);c[n+32>>2]=1;if((c[n+28>>2]|0)==0){v=0}else{break}i=f;return v|0}}while(0);y=n+28|0;x=n+68|0;e=n+32|0;do{if((c[x>>2]|0)!=0){if((c[e>>2]|0)==0){v=0}else{break}i=f;return v|0}}while(0);c[e>>2]=0;c[y>>2]=0;y=n+8|0;e=c[y>>2]|0;u=c[n+64>>2]|0;do{if((u|0)==-1){if((c[e+296>>2]|0)==0){z=1;break}z=c[e+300>>2]|0}else{z=u}}while(0);u=c[n+76>>2]|0;s=(u|0)==-1?z:u;if(!(z>>>0<2>>>0|s>>>0<2>>>0)){yDb(0,0,1960848,(w=i,i=i+24|0,c[w>>2]=2347072,c[w+8>>2]=1910096,c[w+16>>2]=711,w)|0);i=w;Cd();return 0}u=(s|0)!=(z|0)?1040768:1040792;z=n+116|0;do{if((c[z>>2]|0)==0){r=PCb(e)|0;c[j+4>>2]=r;if((r|0)==0){v=-12}else{break}i=f;return v|0}else{r=n+4|0;t=n+12|0;p=Pn(l,0,s,c[r>>2]|0,e,c[t>>2]|0)|0;c[j>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}q=g|0;c[q>>2]=Qn(o,p)|0;p=Pn(l,1,s,c[r>>2]|0,c[y>>2]|0,c[t>>2]|0)|0;c[j+4>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}c[g+4>>2]=Qn(o,p)|0;p=Pn(l,2,s,c[r>>2]|0,c[y>>2]|0,c[t>>2]|0)|0;c[j+8>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}c[g+8>>2]=Qn(o,p)|0;do{if((c[z>>2]|0)!=1){p=Pn(l,3,s,c[r>>2]|0,c[y>>2]|0,c[t>>2]|0)|0;c[j+12>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}c[g+12>>2]=Qn(o,p)|0;if((c[z>>2]|0)==1){break}p=Pn(l,4,s,c[r>>2]|0,c[y>>2]|0,c[t>>2]|0)|0;c[j+16>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}else{c[g+16>>2]=Qn(o,p)|0;break}}}while(0);t=c[g+4>>2]|0;r=c[g+8>>2]|0;p=c[g+12>>2]|0;A=c[g+16>>2]|0;yDb(l,32,2326632,(w=i,i=i+40|0,c[w>>2]=c[q>>2],c[w+8>>2]=t,c[w+16>>2]=r,c[w+24>>2]=p,c[w+32>>2]=A,w)|0);i=w}}while(0);z=c[u+4>>2]|0;A=c[u>>2]|0;p=Rn(o,z,A,s)|0;r=n+72|0;if(((c[r>>2]|0)-4|0)>>>0<2>>>0){B=Rn(o,p,c[u+8>>2]|0,s)|0}else{B=p}p=c[n+112>>2]|0;do{if((p|0)==1){o=n+56|0;t=c[o>>2]|0;C=c[o+4>>2]|0;D=m+160|0;E=c[D>>2]|0;G=c[D+4>>2]|0;D=YGb(E,G,-1,-1)|0;if((t|0)==(D|0)&(C|0)==(F|0)){C=n+48|0;D=c[C+4>>2]|0;t=n+96|0;H=c[t>>2]|0;I=c[t+4>>2]|0;if((D|0)>(I|0)|(D|0)==(I|0)&(c[C>>2]|0)>>>0>H>>>0){J=1;break}else{K=I;L=H}}else{H=c[n+4>>2]|0;I=c[y>>2]|0;C=c[I+32>>2]|0;D=c[H+32>>2]|0;t=c[H+68>>2]|0;M=c[H+72>>2]|0;if((M|0)>0){N=(t|0)>0;O=c[I>>2]|0;I=c[H>>2]|0;H=0;P=0;Q=0;while(1){if(N){R=0;S=P;T=Q;while(1){U=(d[I+R|0]|0)-(d[O+R|0]|0)|0;V=(U|0)>-1?U:-U|0;U=YGb(V,(V|0)<0|0?-1:0,T,S)|0;V=F;W=R+1|0;if((W|0)<(t|0)){R=W;S=V;T=U}else{X=V;Y=U;break}}}else{X=P;Y=Q}T=H+1|0;if((T|0)<(M|0)){O=O+C|0;I=I+D|0;H=T;P=X;Q=Y}else{Z=X;_=Y;break}}}else{Z=0;_=0}Q=n+96|0;P=c[Q>>2]|0;H=c[Q+4>>2]|0;if((Z|0)>(H|0)|(Z|0)==(H|0)&_>>>0>P>>>0){J=1;break}else{K=H;L=P}}c[o>>2]=E;c[o+4>>2]=G;P=c[y>>2]|0;H=c[n+12>>2]|0;Q=c[H+32>>2]|0;D=c[P+32>>2]|0;I=c[P+68>>2]|0;C=c[P+72>>2]|0;if((C|0)>0){O=(I|0)>0;M=c[H>>2]|0;H=c[P>>2]|0;P=0;t=0;N=0;while(1){if(O){q=0;T=t;S=N;while(1){R=(d[H+q|0]|0)-(d[M+q|0]|0)|0;U=(R|0)>-1?R:-R|0;R=YGb(U,(U|0)<0|0?-1:0,S,T)|0;U=F;V=q+1|0;if((V|0)<(I|0)){q=V;T=U;S=R}else{$=U;aa=R;break}}}else{$=t;aa=N}S=P+1|0;if((S|0)<(C|0)){M=M+Q|0;H=H+D|0;P=S;t=$;N=aa}else{ba=$;ca=aa;break}}}else{ba=0;ca=0}N=n+48|0;c[N>>2]=ca;c[N+4>>2]=ba;J=((ba|0)>(K|0)|(ba|0)==(K|0)&ca>>>0>L>>>0)&1}else{J=0}}while(0);if((p|0)==1){if((J|0)==0){da=B}else{ea=52}}else if((p|0)==2){ea=52}else{da=B}a:do{if((ea|0)==52){switch(c[r>>2]|0){case 3:{p=g|0;L=j|0;da=Sn(l,p,Sn(l,p,Sn(l,p,B,c[u+8>>2]|0,L,s)|0,c[u+16>>2]|0,L,s)|0,c[u+12>>2]|0,L,s)|0;break a;break};case 4:{da=Sn(l,g|0,B,(B|0)==(A|0)?z:A,j|0,s)|0;break a;break};case 5:{L=g|0;p=j|0;da=Sn(l,L,Sn(l,L,B,c[u+16>>2]|0,p,s)|0,c[u+12>>2]|0,p,s)|0;break a;break};case 0:{da=Sn(l,g|0,B,(B|0)==(A|0)?z:A,j|0,s)|0;break a;break};case 1:{da=Sn(l,g|0,B,c[u+8>>2]|0,j|0,s)|0;break a;break};case 2:{da=Sn(l,g|0,B,c[u+16>>2]|0,j|0,s)|0;break a;break};default:{yDb(0,0,1960848,(w=i,i=i+24|0,c[w>>2]=2302856,c[w+8>>2]=1910096,c[w+16>>2]=780,w)|0);i=w;Cd();return 0}}}}while(0);do{if((c[x>>2]|0)==0){u=j+(da<<2)|0;B=c[u>>2]|0;if((B|0)==0){fa=Pn(l,da,s,c[n+4>>2]|0,c[y>>2]|0,c[n+12>>2]|0)|0;ea=65;break}else{c[u>>2]=0;ga=B;break}}else{fa=Pn(l,da,s,c[n+16>>2]|0,c[n+20>>2]|0,c[n+24>>2]|0)|0;ea=65}}while(0);do{if((ea|0)==65){if((fa|0)==0){v=-12}else{ga=fa;break}i=f;return v|0}}while(0);JCb(j|0);JCb(j+4|0);JCb(j+8|0);JCb(j+12|0);JCb(j+16|0);j=n+136|0;n=(c[g+(da<<2)>>2]|0)>=(c[j>>2]|0);fa=n&1;ea=ga+296|0;c[ea>>2]=fa;y=l;if(n){n=m+160|0;l=c[n>>2]|0;x=c[n+4>>2]|0;n=k|0;TGb(n|0,0,32)|0;a[n]=0;k=e+136|0;e=c[k>>2]|0;B=c[k+4>>2]|0;if((e|0)==0&(B|0)==(-2147483648|0)){Lb(n|0,32,2227792,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0)|0;i=w}else{Lb(n|0,32,2216240,(w=i,i=i+8|0,h[w>>3]=(+(e>>>0)+ +(B|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),w)|0)|0;i=w}yDb(y,24,2284840,(w=i,i=i+24|0,c[w>>2]=l,c[w+8>>2]=x,c[w+16>>2]=n,w)|0);i=w;c[ga+300>>2]=s;ha=c[ea>>2]|0}else{ha=fa}fa=c[g>>2]|0;ea=c[g+4>>2]|0;s=c[g+8>>2]|0;n=c[g+12>>2]|0;x=c[g+16>>2]|0;g=c[j>>2]|0;yDb(y,48,2269376,(w=i,i=i+72|0,c[w>>2]=J,c[w+8>>2]=fa,c[w+16>>2]=ea,c[w+24>>2]=s,c[w+32>>2]=n,c[w+40>>2]=x,c[w+48>>2]=g,c[w+56>>2]=da,c[w+64>>2]=(ha|0)!=0?2253976:2239816,w)|0);i=w;v=cj(m,ga)|0;i=f;return v|0}function On(a){a=a|0;var b=0,e=0,f=0,g=0,i=0,j=0.0,k=0.0,l=0,m=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=bFb(c[e>>2]|0)|0;g=c[a+20>>2]|0;i=c[a+24>>2]|0;j=+(ba(i,g)|0)*255.0;k=+h[b+104>>3]*j/100.0;a=(E=+k,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);l=b+96|0;c[l>>2]=~~+k>>>0;c[l+4>>2]=a;a=gDb(b+140|0,b+156|0,g,i,c[e>>2]|0,32)|0;if((a|0)<0){m=a;return m|0}a=gDb(b+172|0,b+188|0,g,i,c[e>>2]|0,32)|0;if((a|0)<0){m=a;return m|0}else{c[b+36>>2]=d[f+5|0]|0;c[b+40>>2]=d[f+6|0]|0;f=g+15&-16;c[b+208>>2]=f;c[b+212>>2]=(g>>1)+15&-16;m=b+216|0;c[m>>2]=WDb(ba(f,(i|0)/2|0)|0)|0;f=c[b+128>>2]|0;a=c[b+132>>2]|0;e=WDb(ba((((((f|0)/2|0)+g|0)/(f|0)|0)<<4)+16|0,((((a|0)/2|0)+i|0)/(a|0)|0)+1|0)|0)|0;c[b+204>>2]=e;return((c[m>>2]|0)==0|(e|0)==0?-12:0)|0}return 0}function Pn(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;j=c[a+44>>2]|0;if((b|0)==1){k=PCb(f)|0;i=h;return k|0}l=c[c[a+32>>2]>>2]|0;a=Zr(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;if((a|0)==0){k=0;i=h;return k|0}NCb(a,f)|0;if((b|0)==4){l=f+68|0;m=f+72|0;n=j+36|0;o=j+40|0;p=0;do{q=c[f+(p<<2)>>2]|0;if((q|0)==0){break}r=c[f+32+(p<<2)>>2]|0;if((r|0)==0){break}s=c[a+32+(p<<2)>>2]|0;t=(c[a+(p<<2)>>2]|0)+(ba(s,d)|0)|0;u=q+(ba(r,d)|0)|0;q=c[l>>2]|0;if((p|0)==0){v=c[m>>2]|0;w=q}else{v=-(-(c[m>>2]|0)>>c[o>>2])|0;w=-(-q>>c[n>>2])|0}iDb(t,s<<1,u,r<<1,w,(v|0)/2|0);p=p+1|0;}while((p|0)<4);p=1-d|0;v=g+68|0;w=g+72|0;m=0;while(1){l=c[g+(m<<2)>>2]|0;if((l|0)==0){k=a;x=62;break}r=c[g+32+(m<<2)>>2]|0;if((r|0)==0){k=a;x=62;break}u=c[a+32+(m<<2)>>2]|0;s=(c[a+(m<<2)>>2]|0)+(ba(u,p)|0)|0;t=l+(ba(r,p)|0)|0;l=c[v>>2]|0;if((m|0)==0){y=c[w>>2]|0;z=l}else{y=-(-(c[w>>2]|0)>>c[o>>2])|0;z=-(-l>>c[n>>2])|0}iDb(s,u<<1,t,r<<1,z,(y|0)/2|0);r=m+1|0;if((r|0)<4){m=r}else{k=a;x=62;break}}if((x|0)==62){i=h;return k|0}}else if((b|0)==0){m=1-d|0;y=f+68|0;z=f+72|0;n=j+36|0;o=j+40|0;w=0;do{v=c[f+(w<<2)>>2]|0;if((v|0)==0){break}p=c[f+32+(w<<2)>>2]|0;if((p|0)==0){break}r=c[a+32+(w<<2)>>2]|0;t=(c[a+(w<<2)>>2]|0)+(ba(r,m)|0)|0;u=v+(ba(p,m)|0)|0;v=c[y>>2]|0;if((w|0)==0){A=c[z>>2]|0;B=v}else{A=-(-(c[z>>2]|0)>>c[o>>2])|0;B=-(-v>>c[n>>2])|0}iDb(t,r<<1,u,p<<1,B,(A|0)/2|0);w=w+1|0;}while((w|0)<4);w=e+68|0;A=e+72|0;B=0;while(1){z=c[e+(B<<2)>>2]|0;if((z|0)==0){k=a;x=62;break}y=c[e+32+(B<<2)>>2]|0;if((y|0)==0){k=a;x=62;break}m=c[a+32+(B<<2)>>2]|0;p=(c[a+(B<<2)>>2]|0)+(ba(m,d)|0)|0;u=z+(ba(y,d)|0)|0;z=c[w>>2]|0;if((B|0)==0){C=c[A>>2]|0;D=z}else{C=-(-(c[A>>2]|0)>>c[o>>2])|0;D=-(-z>>c[n>>2])|0}iDb(p,m<<1,u,y<<1,D,(C|0)/2|0);y=B+1|0;if((y|0)<4){B=y}else{k=a;x=62;break}}if((x|0)==62){i=h;return k|0}}else if((b|0)==2){B=1-d|0;C=f+68|0;D=f+72|0;n=j+36|0;o=j+40|0;A=0;do{w=c[f+(A<<2)>>2]|0;if((w|0)==0){break}y=c[f+32+(A<<2)>>2]|0;if((y|0)==0){break}u=c[a+32+(A<<2)>>2]|0;m=(c[a+(A<<2)>>2]|0)+(ba(u,B)|0)|0;p=w+(ba(y,B)|0)|0;w=c[C>>2]|0;if((A|0)==0){E=c[D>>2]|0;F=w}else{E=-(-(c[D>>2]|0)>>c[o>>2])|0;F=-(-w>>c[n>>2])|0}iDb(m,u<<1,p,y<<1,F,(E|0)/2|0);A=A+1|0;}while((A|0)<4);A=g+68|0;E=g+72|0;F=0;while(1){D=c[g+(F<<2)>>2]|0;if((D|0)==0){k=a;x=62;break}C=c[g+32+(F<<2)>>2]|0;if((C|0)==0){k=a;x=62;break}B=c[a+32+(F<<2)>>2]|0;y=(c[a+(F<<2)>>2]|0)+(ba(B,d)|0)|0;p=D+(ba(C,d)|0)|0;D=c[A>>2]|0;if((F|0)==0){G=c[E>>2]|0;H=D}else{G=-(-(c[E>>2]|0)>>c[o>>2])|0;H=-(-D>>c[n>>2])|0}iDb(y,B<<1,p,C<<1,H,(G|0)/2|0);C=F+1|0;if((C|0)<4){F=C}else{k=a;x=62;break}}if((x|0)==62){i=h;return k|0}}else if((b|0)==3){b=f+68|0;F=f+72|0;G=j+36|0;H=j+40|0;j=0;do{n=c[f+(j<<2)>>2]|0;if((n|0)==0){break}o=c[f+32+(j<<2)>>2]|0;if((o|0)==0){break}E=c[a+32+(j<<2)>>2]|0;A=(c[a+(j<<2)>>2]|0)+(ba(E,d)|0)|0;g=n+(ba(o,d)|0)|0;n=c[b>>2]|0;if((j|0)==0){I=c[F>>2]|0;J=n}else{I=-(-(c[F>>2]|0)>>c[H>>2])|0;J=-(-n>>c[G>>2])|0}iDb(A,E<<1,g,o<<1,J,(I|0)/2|0);j=j+1|0;}while((j|0)<4);j=1-d|0;d=e+68|0;I=e+72|0;J=0;while(1){F=c[e+(J<<2)>>2]|0;if((F|0)==0){k=a;x=62;break}b=c[e+32+(J<<2)>>2]|0;if((b|0)==0){k=a;x=62;break}f=c[a+32+(J<<2)>>2]|0;o=(c[a+(J<<2)>>2]|0)+(ba(f,j)|0)|0;g=F+(ba(b,j)|0)|0;F=c[d>>2]|0;if((J|0)==0){K=c[I>>2]|0;L=F}else{K=-(-(c[I>>2]|0)>>c[H>>2])|0;L=-(-F>>c[G>>2])|0}iDb(o,f<<1,g,b<<1,L,(K|0)/2|0);b=J+1|0;if((b|0)<4){J=b}else{k=a;x=62;break}}if((x|0)==62){i=h;return k|0}}else{yDb(0,0,1960848,(k=i,i=i+24|0,c[k>>2]=2302856,c[k+8>>2]=1910096,c[k+16>>2]=638,k)|0);i=k;Cd();return 0}return 0}function Qn(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;g=c[e+120>>2]|0;h=g*6|0;i=e+124|0;j=f+68|0;k=f+72|0;l=(g|0)<0;m=e+36|0;n=e+40|0;o=0;do{p=c[f+(o<<2)>>2]|0;q=c[f+32+(o<<2)>>2]|0;r=c[j>>2]|0;if((o|0)==0){s=c[k>>2]|0;t=r}else{s=-(-(c[k>>2]|0)>>c[n>>2])|0;t=-(-r>>c[m>>2])|0}r=c[e+172+(o<<2)>>2]|0;u=c[e+188+(o<<2)>>2]|0;v=(s|0)>0;do{if(l){if(v){w=r;x=0}else{break}while(1){TGb(w|0,-1|0,t|0)|0;y=x+1|0;if((y|0)<(s|0)){w=w+u|0;x=y}else{break}}}else{if(v){y=r;z=0;while(1){TGb(y|0,0,t|0)|0;A=z+1|0;if((A|0)<(s|0)){y=y+u|0;z=A}else{break}}}z=(t|0)>0;do{if(z){y=q<<1;A=0;do{B=d[p+A|0]|0;C=d[p+(A+q)|0]|0;D=B-C|0;do{if((((D|0)>-1?D:-D|0)|0)>(g|0)){E=(C*-6|0)+(B<<2)+(d[p+(A+y)|0]<<1)|0;if((((E|0)>-1?E:-E|0)|0)<=(h|0)){break}a[r+A|0]=-1}}while(0);A=A+1|0;}while((A|0)<(t|0));if(!z){F=17;break}A=q<<1;y=q*3|0;B=0;while(1){C=d[p+(B+q)|0]|0;D=d[p+B|0]|0;E=C-D|0;G=d[p+(A+B)|0]|0;H=C-G|0;do{if((((E|0)>-1?E:-E|0)|0)>(g|0)&(((H|0)>-1?H:-H|0)|0)>(g|0)){I=((G+D|0)*-3|0)+(C<<2)+(d[p+(y+B)|0]<<1)|0;if((((I|0)>-1?I:-I|0)|0)<=(h|0)){break}a[r+(B+u)|0]=-1}}while(0);C=B+1|0;if((C|0)<(t|0)){B=C}else{J=A;break}}}else{F=17}}while(0);if((F|0)==17){F=0;J=q<<1}A=p+J|0;B=r+(u<<1)|0;y=s-2|0;if((y|0)>2){C=q*-2|0;D=ba(u,y)|0;G=ba(q,y)|0;H=B;E=A;I=2;while(1){if(z){K=0;do{L=d[E+K|0]|0;M=d[E+(K-q)|0]|0;N=L-M|0;O=d[E+(K+q)|0]|0;P=L-O|0;do{if((((N|0)>-1?N:-N|0)|0)>(g|0)&(((P|0)>-1?P:-P|0)|0)>(g|0)){Q=(d[E+(K+C)|0]|0)+(L<<2)+((O+M|0)*-3|0)+(d[E+(K+J)|0]|0)|0;if((((Q|0)>-1?Q:-Q|0)|0)<=(h|0)){break}a[H+K|0]=-1}}while(0);K=K+1|0;}while((K|0)<(t|0))}K=I+1|0;if((K|0)<(y|0)){H=H+u|0;E=E+q|0;I=K}else{break}}R=r+D|0;S=p+G|0}else{R=B;S=A}if(!z){break}I=q*-2|0;E=0;do{H=d[S+E|0]|0;y=d[S+(E-q)|0]|0;C=H-y|0;K=d[S+(E+q)|0]|0;M=H-K|0;do{if((((C|0)>-1?C:-C|0)|0)>(g|0)&(((M|0)>-1?M:-M|0)|0)>(g|0)){O=((K+y|0)*-3|0)+(H<<2)+(d[S+(E+I)|0]<<1)|0;if((((O|0)>-1?O:-O|0)|0)<=(h|0)){break}a[R+E|0]=-1}}while(0);E=E+1|0;}while((E|0)<(t|0));if(z){T=0}else{break}do{E=d[S+(T+q)|0]|0;I=d[S+T|0]|0;A=E-I|0;do{if((((A|0)>-1?A:-A|0)|0)>(g|0)){B=(I*-6|0)+(E<<2)+(d[S+(T-q)|0]<<1)|0;if((((B|0)>-1?B:-B|0)|0)<=(h|0)){break}a[R+(T+u)|0]=-1}}while(0);T=T+1|0;}while((T|0)<(t|0))}}while(0);o=o+1|0;U=(c[i>>2]|0)!=0;}while((o|0)<((U?3:1)|0));do{if(U){o=e+172|0;i=c[o>>2]|0;t=c[k>>2]|0;T=-t>>c[n>>2];R=e+188|0;h=c[R>>2]<<1;S=c[e+196>>2]|0;g=h>>1;J=~T;if(!((T|0)<-2)){V=t;W=R;X=o;break}T=-(c[j>>2]|0)>>c[m>>2];s=~T;x=(T|0)<-2;T=S<<1;w=i+h|0;l=i+g|0;f=i+(-g|0)|0;g=c[e+180>>2]|0;u=c[e+176>>2]|0;q=i;i=1;while(1){p=f+h|0;r=q+h|0;v=l+h|0;z=w+h|0;E=g+S|0;I=u+S|0;if(x){A=r;B=v;G=(i&1|0)==0;D=z;H=p;y=1;do{K=y+S|0;do{if((a[g+K|0]|0)==-1){M=y-1|0;if((a[g+M|0]|0)==-1){F=68;break}if((a[g+y|0]|0)==-1){F=68;break}C=y+1|0;if((a[g+C|0]|0)==-1){F=68;break}if((a[g+(M+S)|0]|0)==-1){F=68;break}if((a[g+(C+S)|0]|0)==-1){F=68;break}if((a[g+(T+M)|0]|0)==-1){F=68;break}if((a[g+(T+y)|0]|0)==-1){F=68;break}if((a[g+(T+C)|0]|0)==-1){F=68}else{F=59}}else{F=59}}while(0);do{if((F|0)==59){F=0;if(!((a[u+K|0]|0)==-1)){break}C=y-1|0;if((a[u+C|0]|0)==-1){F=68;break}if((a[u+y|0]|0)==-1){F=68;break}M=y+1|0;if((a[u+M|0]|0)==-1){F=68;break}if((a[u+(C+S)|0]|0)==-1){F=68;break}if((a[u+(M+S)|0]|0)==-1){F=68;break}if((a[u+(T+C)|0]|0)==-1){F=68;break}if((a[u+(T+y)|0]|0)==-1){F=68;break}if((a[u+(T+M)|0]|0)==-1){F=68}}}while(0);do{if((F|0)==68){F=0;b[A+(y<<1)>>1]=-1;b[B+(y<<1)>>1]=-1;if(G){b[D+(y<<1)>>1]=-1;break}else{b[H+(y<<1)>>1]=-1;break}}}while(0);y=y+1|0;}while((y|0)<(s|0))}y=i+1|0;if((y|0)<(J|0)){w=z;l=v;f=p;g=E;u=I;q=r;i=y}else{V=t;W=R;X=o;break}}}else{V=c[k>>2]|0;W=e+188|0;X=e+172|0}}while(0);k=c[e+128>>2]|0;m=c[e+132>>2]|0;n=(k|0)/2|0;U=(m|0)/2|0;o=c[W>>2]|0;W=c[X>>2]|0;X=c[j>>2]|0;j=((X+n|0)/(k|0)|0)+1|0;R=j<<2;t=c[e+204>>2]|0;e=ba(((V+U|0)/(m|0)|0)+1|0,j)|0;j=e<<2;i=(V|0)%(U|0)|0;q=X-((X|0)%(n|0)|0)|0;u=V-((i|0)==0?U:i)|0;TGb(t|0,0,e<<4|0)|0;e=W+o|0;if((m|0)>3){i=(X|0)>0;g=o<<1;f=ba(o,(U|0)>2?U:2)|0;l=W;w=1;J=e;while(1){s=ba((w|0)/(m|0)|0,R)|0;T=ba((w+U|0)/(m|0)|0,R)|0;if(i){S=0;do{do{if((a[l+S|0]|0)==-1){if(!((a[l+(S+o)|0]|0)==-1)){break}if(!((a[l+(g+S)|0]|0)==-1)){break}x=((S|0)/(k|0)|0)<<2;h=((S+n|0)/(k|0)|0)<<2;y=t+(x+s<<2)|0;c[y>>2]=(c[y>>2]|0)+1;y=t+((h+s|1)<<2)|0;c[y>>2]=(c[y>>2]|0)+1;y=t+((x+T|2)<<2)|0;c[y>>2]=(c[y>>2]|0)+1;y=t+((h+T|3)<<2)|0;c[y>>2]=(c[y>>2]|0)+1}}while(0);S=S+1|0;}while((S|0)<(X|0))}S=w+1|0;if((S|0)<(U|0)){l=J;w=S;J=J+o|0}else{break}}Y=W+f|0}else{Y=e}if((U|0)<(u|0)){e=(q|0)>0;f=(q|0)<(X|0);W=ba(o,U)|0;J=(m|0)>1;w=-o|0;l=Y;g=U;while(1){i=ba((g|0)/(m|0)|0,R)|0;S=g+U|0;T=ba((S|0)/(m|0)|0,R)|0;if(e){s=0;while(1){do{if((k|0)<2|J^1){F=102}else{r=l+s|0;I=0;E=0;while(1){p=0;v=E;while(1){do{if((a[r+(p-o)|0]|0)==-1){if(!((a[r+p|0]|0)==-1)){Z=v;break}Z=((a[r+(p+o)|0]|0)==-1)+v|0}else{Z=v}}while(0);z=p+1|0;if((z|0)<(n|0)){p=z;v=Z}else{break}}v=I+1|0;if((v|0)<(U|0)){r=r+o|0;I=v;E=Z}else{break}}if((Z|0)==0){F=102;break}E=((s|0)/(k|0)|0)<<2;I=s+n|0;r=((I|0)/(k|0)|0)<<2;v=t+(E+i<<2)|0;c[v>>2]=(c[v>>2]|0)+Z;v=t+((r+i|1)<<2)|0;c[v>>2]=(c[v>>2]|0)+Z;v=t+((E+T|2)<<2)|0;c[v>>2]=(c[v>>2]|0)+Z;v=t+((r+T|3)<<2)|0;c[v>>2]=(c[v>>2]|0)+Z;_=I}}while(0);if((F|0)==102){F=0;_=s+n|0}if((_|0)<(q|0)){s=_}else{break}}}if(f){s=q;do{do{if(J){I=l+s|0;v=0;r=0;while(1){do{if((a[I+w|0]|0)==-1){if(!((a[I]|0)==-1)){$=r;break}$=((a[I+o|0]|0)==-1)+r|0}else{$=r}}while(0);E=v+1|0;if((E|0)<(U|0)){I=I+o|0;v=E;r=$}else{break}}if(($|0)==0){break}r=((s|0)/(k|0)|0)<<2;v=((s+n|0)/(k|0)|0)<<2;I=t+(r+i<<2)|0;c[I>>2]=(c[I>>2]|0)+$;I=t+((v+i|1)<<2)|0;c[I>>2]=(c[I>>2]|0)+$;I=t+((r+T|2)<<2)|0;c[I>>2]=(c[I>>2]|0)+$;I=t+((v+T|3)<<2)|0;c[I>>2]=(c[I>>2]|0)+$}}while(0);s=s+1|0;}while((s|0)<(X|0))}s=l+W|0;if((S|0)<(u|0)){l=s;g=S}else{aa=s;break}}}else{aa=Y}Y=V-1|0;if((u|0)<(Y|0)&(X|0)>0){V=aa;aa=u;while(1){u=ba((aa|0)/(m|0)|0,R)|0;g=ba((aa+U|0)/(m|0)|0,R)|0;l=0;do{do{if((a[V+(l-o)|0]|0)==-1){if(!((a[V+l|0]|0)==-1)){break}if(!((a[V+(l+o)|0]|0)==-1)){break}W=((l|0)/(k|0)|0)<<2;$=((l+n|0)/(k|0)|0)<<2;w=t+(W+u<<2)|0;c[w>>2]=(c[w>>2]|0)+1;w=t+(($+u|1)<<2)|0;c[w>>2]=(c[w>>2]|0)+1;w=t+((W+g|2)<<2)|0;c[w>>2]=(c[w>>2]|0)+1;w=t+(($+g|3)<<2)|0;c[w>>2]=(c[w>>2]|0)+1}}while(0);l=l+1|0;}while((l|0)<(X|0));l=aa+1|0;if((l|0)<(Y|0)){V=V+o|0;aa=l}else{break}}}if((j|0)>0){ca=0;da=0}else{ea=0;return ea|0}while(1){aa=c[t+(da<<2)>>2]|0;o=(aa|0)>(ca|0)?aa:ca;aa=da+1|0;if((aa|0)<(j|0)){ca=o;da=aa}else{ea=o;break}}return ea|0}function Rn(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0.0,Pb=0.0,Qb=0.0,Rb=0.0,Sb=0.0,Tb=0;h=b+8|0;i=c[h>>2]|0;j=b+80|0;k=i+68|0;l=i+72|0;m=b+84|0;n=b+88|0;o=2-g|0;p=g+1|0;q=(e|0)<3?o:p;r=q+1|0;s=(f|0)<3?o:p;p=(e|0)>2^(g|0)==1;g=b+4|0;o=b+12|0;t=b+36|0;u=b+40|0;v=0;w=0;x=0;y=0;z=0;A=0;B=0;C=0;D=0;E=0;G=0;H=0;I=0;while(1){J=c[b+140+(I<<2)>>2]|0;K=c[b+156+(I<<2)>>2]|0;L=c[i+(I<<2)>>2]|0;M=c[i+32+(I<<2)>>2]|0;N=M<<1;O=c[k>>2]|0;P=(I|0)==0;if(P){Q=c[l>>2]|0;R=O}else{Q=-(-(c[l>>2]|0)>>c[u>>2])|0;R=-(-O>>c[t>>2])|0}O=(I|0)!=0|0;S=c[m>>2]>>O;T=c[n>>2]>>O;O=P?8:4;P=R-O|0;if((Q|0)>0){U=J;V=0;while(1){TGb(U|0,0,R|0)|0;W=V+1|0;if((W|0)<(Q|0)){U=U+K|0;V=W}else{break}}}V=ba(M,r)|0;U=L+V|0;W=L+(V-N)|0;X=L+(V+N)|0;V=ba(K,q)|0;Y=J+V|0;if((e|0)==3|(e|0)==0){Z=g}else if((e|0)==4|(e|0)==2){Z=o}else{Z=h}_=c[Z>>2]|0;$=c[_+32+(I<<2)>>2]|0;aa=$<<1;ca=c[_+(I<<2)>>2]|0;_=ba($,q)|0;$=ca+_|0;da=ca+(_+aa)|0;if((f|0)==3|(f|0)==0){ea=g}else if((f|0)==4|(f|0)==2){ea=o}else{ea=h}_=c[ea>>2]|0;ca=c[_+32+(I<<2)>>2]|0;fa=ca<<1;ga=c[_+(I<<2)>>2]|0;_=ba(ca,s)|0;ca=ga+_|0;ha=ga+(_+fa)|0;_=K<<1;if(p){Tn(b,da,aa,ha,fa,J+(V+_)|0,_,Q,R,I)}else{Tn(b,$,aa,ca,fa,Y,_,Q,R,I)}V=Q-2|0;if((V|0)>2){ga=(S|0)==(T|0);ia=(O|0)<(P|0);ja=Y;Y=2;ka=v;la=w;ma=x;na=y;oa=z;pa=A;qa=B;ra=C;sa=D;ta=E;ua=G;va=H;wa=W;W=U;U=X;X=$;$=da;da=ca;ca=ha;while(1){do{if(ga|(Y|0)<(S|0)|(Y|0)>(T|0)){if(ia){xa=O;ya=ka;za=la;Aa=ma;Ba=na;Ca=oa;Da=pa;Ea=qa;Fa=ra;Ga=sa;Ha=ta;Ia=ua;Ja=va}else{Ka=ua;La=va;Ma=sa;Na=ta;Oa=qa;Pa=ra;Qa=oa;Ra=pa;Sa=ma;Ta=na;Ua=ka;Va=la;break}while(1){ha=a[ja+xa|0]|0;if(ha<<24>>24==0){if((a[ja+(xa+_)|0]|0)==0){Wa=Ia;Xa=Ja;Ya=Ga;Za=Ha;_a=Ea;$a=Fa;ab=Ca;bb=Da;cb=Aa;db=Ba;eb=ya;fb=za}else{gb=22}}else{gb=22}do{if((gb|0)==22){gb=0;hb=(d[W+xa|0]<<2)+(d[wa+xa|0]|0)+(d[U+xa|0]|0)|0;ib=(((d[$+xa|0]|0)+(d[X+xa|0]|0)|0)*3|0)-hb|0;jb=(ib|0)>-1?ib:-ib|0;do{if((jb|0)>23){if((ha&1)==0){if((a[ja+(xa+_)|0]&1)==0){kb=Ia;lb=Ja}else{gb=25}}else{gb=25}if((gb|0)==25){gb=0;ib=YGb(jb,(jb|0)<0|0?-1:0,Ja,Ia)|0;kb=F;lb=ib}if((jb|0)<=42){mb=Ga;nb=Ha;ob=Ea;pb=Fa;qb=kb;rb=lb;break}if((ha&2)==0){if((a[ja+(xa+_)|0]&2)==0){sb=Ga;tb=Ha}else{gb=29}}else{gb=29}if((gb|0)==29){gb=0;ib=YGb(jb,(jb|0)<0|0?-1:0,Ha,Ga)|0;sb=F;tb=ib}if((ha&4)==0){if((a[ja+(xa+_)|0]&4)==0){mb=sb;nb=tb;ob=Ea;pb=Fa;qb=kb;rb=lb;break}}ib=YGb(jb,(jb|0)<0|0?-1:0,Fa,Ea)|0;mb=sb;nb=tb;ob=F;pb=ib;qb=kb;rb=lb}else{mb=Ga;nb=Ha;ob=Ea;pb=Fa;qb=Ia;rb=Ja}}while(0);jb=(((d[ca+xa|0]|0)+(d[da+xa|0]|0)|0)*3|0)-hb|0;ib=(jb|0)>-1?jb:-jb|0;if((ib|0)<=23){Wa=qb;Xa=rb;Ya=mb;Za=nb;_a=ob;$a=pb;ab=Ca;bb=Da;cb=Aa;db=Ba;eb=ya;fb=za;break}if((ha&1)==0){if((a[ja+(xa+_)|0]&1)==0){ub=Ca;vb=Da}else{gb=36}}else{gb=36}if((gb|0)==36){gb=0;jb=YGb(ib,(ib|0)<0|0?-1:0,Da,Ca)|0;ub=F;vb=jb}if((ib|0)<=42){Wa=qb;Xa=rb;Ya=mb;Za=nb;_a=ob;$a=pb;ab=ub;bb=vb;cb=Aa;db=Ba;eb=ya;fb=za;break}if((ha&2)==0){if((a[ja+(xa+_)|0]&2)==0){wb=Aa;xb=Ba}else{gb=40}}else{gb=40}if((gb|0)==40){gb=0;jb=YGb(ib,(ib|0)<0|0?-1:0,Ba,Aa)|0;wb=F;xb=jb}if((ha&4)==0){if((a[ja+(xa+_)|0]&4)==0){Wa=qb;Xa=rb;Ya=mb;Za=nb;_a=ob;$a=pb;ab=ub;bb=vb;cb=wb;db=xb;eb=ya;fb=za;break}}jb=YGb(ib,(ib|0)<0|0?-1:0,za,ya)|0;Wa=qb;Xa=rb;Ya=mb;Za=nb;_a=ob;$a=pb;ab=ub;bb=vb;cb=wb;db=xb;eb=F;fb=jb}}while(0);ha=xa+1|0;if((ha|0)<(P|0)){xa=ha;ya=eb;za=fb;Aa=cb;Ba=db;Ca=ab;Da=bb;Ea=_a;Fa=$a;Ga=Ya;Ha=Za;Ia=Wa;Ja=Xa}else{Ka=Wa;La=Xa;Ma=Ya;Na=Za;Oa=_a;Pa=$a;Qa=ab;Ra=bb;Sa=cb;Ta=db;Ua=eb;Va=fb;break}}}else{Ka=ua;La=va;Ma=sa;Na=ta;Oa=qa;Pa=ra;Qa=oa;Ra=pa;Sa=ma;Ta=na;Ua=ka;Va=la}}while(0);ha=Y+2|0;if((ha|0)<(V|0)){ja=ja+_|0;Y=ha;ka=Ua;la=Va;ma=Sa;na=Ta;oa=Qa;pa=Ra;qa=Oa;ra=Pa;sa=Ma;ta=Na;ua=Ka;va=La;wa=wa+N|0;W=W+N|0;U=U+N|0;X=X+aa|0;$=$+aa|0;da=da+fa|0;ca=ca+fa|0}else{yb=Ua;zb=Va;Ab=Sa;Bb=Ta;Cb=Qa;Db=Ra;Eb=Oa;Fb=Pa;Gb=Ma;Hb=Na;Ib=Ka;Jb=La;break}}}else{yb=v;zb=w;Ab=x;Bb=y;Cb=z;Db=A;Eb=B;Fb=C;Gb=D;Hb=E;Ib=G;Jb=H}fa=I+1|0;if((fa|0)<(((c[j>>2]|0)!=0?3:1)|0)){v=yb;w=zb;x=Ab;y=Bb;z=Cb;A=Db;B=Eb;C=Fb;D=Gb;E=Hb;G=Ib;H=Jb;I=fa}else{break}}I=0;H=0;do{if((Gb>>>0<I>>>0|Gb>>>0==I>>>0&Hb>>>0<500>>>0)&(Ab>>>0<H>>>0|Ab>>>0==H>>>0&Bb>>>0<500>>>0)){G=0;E=0;if(!(Eb>>>0>G>>>0|Eb>>>0==G>>>0&Fb>>>0>499>>>0|(yb>>>0>E>>>0|yb>>>0==E>>>0&zb>>>0>499>>>0))){Kb=Gb;Lb=Hb;Mb=Ab;Nb=Bb;break}E=Eb>>>0>yb>>>0|Eb>>>0==yb>>>0&Fb>>>0>zb>>>0;G=E?Eb:yb;D=gHb(E?zb:Fb,E?yb:Eb,3,0)|0;C=F;B=G>>>0>C>>>0|G>>>0==C>>>0&(E?Fb:zb)>>>0>D>>>0;Kb=B?Eb:Gb;Lb=B?Fb:Hb;Mb=B?yb:Ab;Nb=B?zb:Bb}else{Kb=Gb;Lb=Hb;Mb=Ab;Nb=Bb}}while(0);Bb=~~((+(Jb>>>0)+ +(Ib>>>0)*4294967296.0)/6.0+.5);Ib=~~((+(Db>>>0)+ +(Cb>>>0)*4294967296.0)/6.0+.5);Cb=~~((+(Lb>>>0)+ +(Kb>>>0)*4294967296.0)/6.0+.5);Kb=~~((+(Nb>>>0)+ +(Mb>>>0)*4294967296.0)/6.0+.5);Mb=(Bb|0)>(Ib|0);Nb=Mb?Bb:Ib;Ob=+(Nb|0);Lb=Mb?Ib:Bb;if((Lb|0)>1){Pb=+(Lb|0)}else{Pb=1.0}Qb=Ob/Pb;Lb=(Cb|0)>(Kb|0);Bb=Lb?Cb:Kb;Pb=+(Bb|0);Ib=Lb?Kb:Cb;if((Ib|0)>1){Rb=+(Ib|0)}else{Rb=1.0}Sb=Pb/Rb;Rb=Pb/((Nb|0)>1?Ob:1.0);if((Cb|0)>499|(Kb|0)>499){if(!((Cb<<1|0)<(Kb|0)|(Kb<<1|0)<(Cb|0))){gb=56}}else{gb=56}do{if((gb|0)==56){if((Cb|0)>999|(Kb|0)>999){if((Cb*3|0|0)<(Kb<<1|0)){break}if((Kb*3|0|0)<(Cb<<1|0)){break}}if((Cb|0)>1999|(Kb|0)>1999){if((Cb*5|0|0)<(Kb<<2|0)){break}if((Kb*5|0|0)<(Cb<<2|0)){break}}if(((Cb|0)>3999|(Kb|0)>3999)&Sb>Qb){break}do{if(Rb>.005&(Bb|0)>150){if(!((Cb<<1|0)<(Kb|0)|(Kb<<1|0)<(Cb|0))){break}Tb=Lb?f:e;return Tb|0}}while(0);Tb=Mb?f:e;return Tb|0}}while(0);Tb=Lb?f:e;return Tb|0}function Sn(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=c[a+44>>2]|0;i=h;j=b+(d<<2)|0;k=c[j>>2]|0;if((k|0)<0){l=f+(d<<2)|0;m=c[l>>2]|0;if((m|0)==0){n=Pn(a,d,g,c[h+4>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0)|0;c[l>>2]=n;o=n}else{o=m}m=Qn(i,o)|0;c[j>>2]=m;p=m}else{p=k}k=b+(e<<2)|0;b=c[k>>2]|0;if((b|0)<0){m=f+(e<<2)|0;f=c[m>>2]|0;if((f|0)==0){o=Pn(a,e,g,c[h+4>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0)|0;c[m>>2]=o;q=o}else{q=f}f=Qn(i,q)|0;c[k>>2]=f;r=f;s=c[j>>2]|0}else{r=b;s=p}do{if((r*3|0|0)<(s|0)){t=12}else{if((r<<1|0)>=(s|0)){break}if((s|0)>(c[h+136>>2]|0)){t=12}}}while(0);do{if((t|0)==12){p=r-s|0;if((((p|0)>-1?p:-p|0)|0)<=29){break}if((r|0)<(c[h+136>>2]|0)){u=e}else{break}return u|0}}while(0);u=d;return u|0}function Tn(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;n=c[((m|0)==0?b+208|0:b+212|0)>>2]|0;m=c[b+216>>2]|0;b=k>>1;if((b|0)>0&(l|0)>0){o=m;p=g+(-h|0)|0;g=e+(-f|0)|0;e=0;while(1){q=0;do{r=(d[g+q|0]|0)-(d[p+q|0]|0)|0;a[o+q|0]=(r|0)>-1?r:-r|0;q=q+1|0;}while((q|0)<(l|0));q=e+1|0;if((q|0)<(b|0)){o=o+n|0;p=p+h|0;g=g+f|0;e=q}else{break}}}e=k-2|0;if((e|0)<=2){return}f=l-1|0;g=(f|0)>1;h=n<<1;p=k-4|0;k=n*3|0;o=2;b=i;i=m;while(1){m=i+n|0;if(g){q=(o|0)==2;r=(o|0)==(p|0);s=1;do{t=a[i+(s+n)|0]|0;a:do{if((t&255)>>>0>3>>>0){u=s-1|0;v=s+2|0;w=u;x=0;do{x=((d[i+w|0]|0)>>>0>3>>>0)+x+((d[i+(w+n)|0]|0)>>>0>3>>>0)+((d[i+(h+w)|0]|0)>>>0>3>>>0)|0;w=w+1|0;}while((w|0)<(v|0)&(x|0)<2);if((x|0)<=1){break}w=b+s|0;a[w]=1;if((t&255)>>>0>19>>>0){y=u;z=0;A=0;B=0}else{break}do{C=(d[i+y|0]|0)>>>0>19>>>0;A=C?1:A;D=(d[i+(h+y)|0]|0)>>>0>19>>>0;z=(C&1)+z+((d[i+(y+n)|0]|0)>>>0>19>>>0)+(D&1)|0;B=D?1:B;y=y+1|0;}while((y|0)<(v|0)&(z|0)<6);if((z|0)<=3){break}if(!((A|0)==0|(B|0)==0)){a[w]=3;break}v=s-4|0;u=(v|0)>0?v:0;v=s+5|0;x=(v|0)>(l|0)?l:v;if((u|0)<(x|0)){v=u;u=A;D=B;C=0;E=0;while(1){if(q){F=C}else{F=(d[i+(v-n)|0]|0)>>>0>19>>>0?1:C}G=(d[i+v|0]|0)>>>0>19>>>0?1:u;H=(d[i+(h+v)|0]|0)>>>0>19>>>0?1:D;if(r){I=E}else{I=(d[i+(k+v)|0]|0)>>>0>19>>>0?1:E}J=v+1|0;if((J|0)<(x|0)){v=J;u=G;D=H;C=F;E=I}else{K=G;L=H;M=F;N=I;break}}}else{K=A;L=B;M=0;N=0}E=(K|0)!=0;if(E){if((M|L|0)==0){O=27}}else{O=27}do{if((O|0)==27){O=0;if((L|0)!=0){if(!((N|0)==0&(E^1))){break}}if((z|0)<=5){break a}a[w]=5;break a}}while(0);a[w]=3}}while(0);s=s+1|0;}while((s|0)<(f|0))}s=o+2|0;if((s|0)<(e|0)){o=s;b=b+j|0;i=m}else{break}}return}function Un(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a>>2]|0;a=b+44|0;d=c[a>>2]|0;e=d+68|0;f=c[e>>2]|0;g=f<<1|1;h=d+44|0;if((g&c[h>>2]|0)==(g|0)){i=-541478725;return i|0}do{if((c[d+28>>2]|0)==0){g=c[c[b+16>>2]>>2]|0;j=Ni(g)|0;if((j|0)==-541478725){c[h>>2]=c[h>>2]|1;k=Nn(g,0)|0}else{k=j}if((k|0)<0){i=k;return i|0}else{l=c[e>>2]|0;break}}else{l=f}}while(0);do{if((l|0)!=0){f=c[a>>2]|0;if((c[f+32>>2]|0)!=0){break}e=c[(c[b+16>>2]|0)+4>>2]|0;k=Ni(e)|0;if((k|0)==-541478725){h=f+44|0;c[h>>2]=c[h>>2]|2;m=Nn(e,0)|0}else{m=k}if((m|0)<0){i=m}else{break}return i|0}}while(0);i=0;return i|0}function Vn(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a>>2]|0;d=c[(c[b+16>>2]|0)+(((c[(c[b+44>>2]|0)+68>>2]|0)!=0)<<2)>>2]|0;b=a+156|0;c[b>>2]=c[b>>2]|1;b=d+56|0;e=a+56|0;f=c[b+4>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=f;f=d+28|0;e=a+28|0;b=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=b;b=d+116|0;e=a+116|0;f=c[b+4>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=f;c[a+20>>2]=c[d+20>>2];c[a+24>>2]=c[d+24>>2];return 0}function Wn(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=b+16|0;if((c[c[f>>2]>>2]|0)==0){g=0;i=d;return g|0}c[e>>2]=0;h=0;a:while(1){j=bFb(h)|0;do{if((a[j+7|0]&14)==0){if((a[j+4|0]|0)==0){break}if((a[j+6|0]|0)!=0){break}k=zk(e,h,(h|0)<0|0?-1:0)|0;if((k|0)<0){l=7;break a}}}while(0);j=h+1|0;if((j|0)<333){h=j}else{l=9;break}}if((l|0)==7){Ik(e);g=k;i=d;return g|0}else if((l|0)==9){Hk(c[e>>2]|0,(c[c[f>>2]>>2]|0)+68|0);Hk(c[e>>2]|0,(c[c[b+32>>2]>>2]|0)+64|0);g=0;i=d;return g|0}return 0}function Xn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=c[c[f+32>>2]>>2]|0;h=c[b+296>>2]|0;do{if((h|0)!=0){j=a+4|0;if((c[b+300>>2]|0)==(c[j>>2]|0)){break}do{if((RCb(b)|0)==0){k=Zr(g,c[g+20>>2]|0,c[g+24>>2]|0)|0;if((k|0)!=0){NCb(k,c[e>>2]|0)|0;l=k;m=c[e>>2]|0;break}JCb(e);n=-12;i=d;return n|0}else{l=b;m=b}}while(0);k=c[m+72>>2]|0;o=a+8|0;p=k-1|0;a:do{if((k|0)>0){q=0;r=m;while(1){s=c[r+(q<<2)>>2]|0;if((s|0)==0){break a}t=c[r+32+(q<<2)>>2]|0;if((t|0)==0){break a}u=c[l+32+(q<<2)>>2]|0;v=c[o+(q<<2)>>2]|0;w=c[l+(q<<2)>>2]|0;b:do{if((c[j>>2]|0)==0){x=-t|0;y=-u|0;z=t<<1;A=p;B=w+(ba(u,p)|0)|0;C=s+(ba(t,p)|0)|0;while(1){if((A|0)<=0){break}D=C+x|0;UGb(B|0,D|0,v)|0;A=A-1|0;B=B+y|0;C=D}UGb(B|0,C+z|0,v)|0}else{y=-(t<<1)|0;A=1;x=w;D=s;E=r;while(1){if((A|0)<(c[E+72>>2]|0)){F=D+t|0;UGb(x|0,F|0,v)|0;G=F}else{UGb(x|0,D+y|0,v)|0;G=D+t|0}if((A|0)>=(k|0)){break b}A=A+1|0;x=x+u|0;D=G;E=c[e>>2]|0}}}while(0);u=q+1|0;if((u|0)>=4){break a}q=u;r=c[e>>2]|0}}else{r=0;q=m;while(1){if((c[q+(r<<2)>>2]|0)==0){break a}if((c[q+32+(r<<2)>>2]|0)==0){break a}u=r+1|0;if((u|0)>=4){break a}r=u;q=c[e>>2]|0}}}while(0);c[l+300>>2]=c[j>>2];if((c[e>>2]|0)!=(l|0)){JCb(e)}n=cj(g,l)|0;i=d;return n|0}}while(0);yDb(f,40,1889744,(f=i,i=i+8|0,c[f>>2]=(h|0)!=0?2347008:2326472,f)|0);i=f;n=cj(g,c[e>>2]|0)|0;i=d;return n|0}function Yn(a){a=a|0;return dDb((c[(c[a+8>>2]|0)+44>>2]|0)+8|0,c[a+52>>2]|0,c[a+20>>2]|0)|0}function Zn(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+40|0;e=d|0;f=d+32|0;g=c[b+44>>2]|0;h=c[g+4>>2]|0;if((h|0)==0){j=-22;i=d;return j|0}k=e|0;l=b;b=g+8|0;g=h;while(1){h=Vb(g|0,124)|0;m=(h|0)!=0;if(m){n=h-g|0}else{n=SGb(g|0)|0}if((n|0)>31){o=7;break}UGb(k|0,g|0,n)|0;a[e+n|0]=0;p=Rk(f,k,l)|0;if((p|0)<0){j=p;o=10;break}c[b+(c[f>>2]<<2)>>2]=1;p=m?h+1|0:0;if((p|0)==0){j=0;o=10;break}else{g=p}}if((o|0)==7){yDb(l,16,1932824,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=-1;i=d;return j|0}else if((o|0)==10){i=d;return j|0}return 0}function _n(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=0;f=0;while(1){if((c[e+8+(f<<2)>>2]|0)==1){if((zk(d,f,(f|0)<0|0?-1:0)|0)<0){g=4;break}}h=f+1|0;if((h|0)<333){f=h}else{g=6;break}}if((g|0)==4){Ik(d);j=0;Ok(a,j);i=b;return 0}else if((g|0)==6){j=c[d>>2]|0;Ok(a,j);i=b;return 0}return 0}function $n(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=0;f=0;while(1){if((c[e+8+(f<<2)>>2]|0)==0){if((zk(d,f,(f|0)<0|0?-1:0)|0)<0){g=4;break}}h=f+1|0;if((h|0)<333){f=h}else{g=6;break}}if((g|0)==4){Ik(d);j=0;Ok(a,j);i=b;return 0}else if((g|0)==6){j=c[d>>2]|0;Ok(a,j);i=b;return 0}return 0}function ao(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+44>>2]|0;e=UBb(8)|0;c[d+4>>2]=e;if((e|0)==0){f=-12;i=b;return f|0}e=d+8|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=c[d+28>>2]|0;yDb(a,40,2096552,(a=i,i=i+16|0,c[a>>2]=c[d+24>>2],c[a+8>>2]=e,a)|0);i=a;f=0;i=b;return f|0}function bo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;f=e+4|0;g=c[f>>2]|0;if((g|0)==0){h=e+48|0}else{j=(WBb(g)|0)>>>2;g=e+48|0;c[g>>2]=(c[g>>2]|0)+j;j=c[f>>2]|0;k=d;if((WBb(j)|0)!=0){do{ZBb(j,k,4,0)|0;JCb(d);}while((WBb(j)|0)!=0)}VBb(c[f>>2]|0);h=g}g=c[e+40>>2]|0;f=c[h>>2]|0;h=c[e+44>>2]|0;yDb(a,40,2170064,(a=i,i=i+32|0,c[a>>2]=c[e+36>>2],c[a+8>>2]=g,c[a+16>>2]=f,c[a+24>>2]=h,a)|0);i=a;i=b;return}function co(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=f+40|0;h=c[g>>2]|0;j=e+16|0;e=0;k=h;while(1){if((k|0)!=(h|0)){l=e;m=11;break}n=Ni(c[c[j>>2]>>2]|0)|0;if(!((n|0)>-1)){break}e=n;k=c[g>>2]|0}if((m|0)==11){i=b;return l|0}if(!((n|0)==-541478725)){l=n;i=b;return l|0}n=f+4|0;if((WBb(c[n>>2]|0)|0)==0){l=-541478725;i=b;return l|0}if((WBb(c[n>>2]|0)|0)==0){l=0;i=b;return l|0}k=d;e=f+8|0;f=a+56|0;while(1){ZBb(c[n>>2]|0,k,4,0)|0;h=KDb(c[e>>2]|0,c[e+4>>2]|0,(c[c[j>>2]>>2]|0)+56|0,f)|0;o=c[g>>2]|0;p=YGb(o,(o|0)<0|0?-1:0,h,F)|0;h=c[d>>2]|0;o=h+136|0;c[o>>2]=p;c[o+4>>2]=F;o=cj(a,h)|0;if((o|0)<0){l=o;m=11;break}c[g>>2]=(c[g>>2]|0)+1;if((WBb(c[n>>2]|0)|0)==0){l=0;m=11;break}}if((m|0)==11){i=b;return l|0}return 0}function eo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=d+24|0;f=a+56|0;g=c[e>>2]|0;c[f>>2]=c[d+28>>2];c[f+4>>2]=g;g=e;e=a+116|0;f=c[g+4>>2]|0;c[e>>2]=c[g>>2];c[e+4>>2]=f;f=c[c[b+16>>2]>>2]|0;c[a+20>>2]=c[f+20>>2];c[a+24>>2]=c[f+24>>2];return 0}function fo(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,G=0.0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0;d=i;i=i+96|0;e=d|0;f=d+8|0;g=d+16|0;j=d+24|0;k=d+32|0;l=d+40|0;m=d+48|0;n=d+56|0;o=d+64|0;p=d+72|0;q=d+80|0;r=d+88|0;c[n>>2]=b;s=c[a+8>>2]|0;t=c[s+44>>2]|0;u=c[c[s+32>>2]>>2]|0;v=t+36|0;c[v>>2]=(c[v>>2]|0)+1;v=t+8|0;w=b+136|0;x=(c[w>>2]|0)==0&(c[w+4>>2]|0)==(-2147483648|0);if((c[v>>2]|0)==0&(c[v+4>>2]|0)==(-2147483648|0)){if(x){yDb(s,24,2172808,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;JCb(n);w=t+48|0;c[w>>2]=(c[w>>2]|0)+1;z=0;i=d;return z|0}w=c[t+4>>2]|0;A=m;c[m>>2]=b;do{if((XBb(w)|0)==0){B=YBb(w,(WBb(w)|0)<<1)|0;if((B|0)==0){C=5;break}JCb(m);if((B|0)<0){z=B}else{break}i=d;return z|0}else{C=5}}while(0);if((C|0)==5){_Bb(w,A,4,0)|0}D=+h[t+16>>3];if(!(D!=1.7976931348623157e+308&D!=-9223372036854776000.0)){A=(c[n>>2]|0)+136|0;w=c[A+4>>2]|0;c[v>>2]=c[A>>2];c[v+4>>2]=w;z=0;i=d;return z|0}G=D*1.0e6;D=G>-9223372036854776000.0?G:-9223372036854776000.0;if(D>9223372036854776000.0){H=2147483647;I=-1}else{H=(E=+D,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);I=~~+D>>>0}c[o>>2]=1;c[o+4>>2]=1e6;w=KDb(I,H,o,a+56|0)|0;o=F;c[v>>2]=w;c[v+4>>2]=o;c[p>>2]=1;c[p+4>>2]=1e6;A=KDb(I,H,p,u+56|0)|0;p=F;yDb(s,40,2189344,(y=i,i=i+32|0,c[y>>2]=w,c[y+8>>2]=o,c[y+16>>2]=A,c[y+24>>2]=p,y)|0);i=y;z=0;i=d;return z|0}p=t+4|0;do{if(x){J=b}else{A=(WBb(c[p>>2]|0)|0)<1;o=c[n>>2]|0;if(A){J=o;break}A=o+136|0;o=ZGb(c[A>>2]|0,c[A+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;A=a+56|0;w=u+56|0;H=JDb(o,F,A,w,c[t+32>>2]|0)|0;o=t+40|0;I=c[o>>2]|0;m=ZGb(H,F,I,(I|0)<0|0?-1:0)|0;I=F;H=0;B=c[p>>2]|0;if((I|0)<(H|0)|(I|0)==(H|0)&m>>>0<1>>>0){H=(WBb(B)|0)>>>2;yDb(s,48,2163376,(y=i,i=i+8|0,c[y>>2]=H,y)|0);i=y;K=t+48|0;c[K>>2]=(c[K>>2]|0)+H;ZBb(c[p>>2]|0,q,4,0)|0;H=c[p>>2]|0;K=k;if((WBb(H)|0)!=0){do{ZBb(H,K,4,0)|0;JCb(k);}while((WBb(H)|0)!=0)}H=c[p>>2]|0;K=j;c[j>>2]=c[q>>2];do{if((XBb(H)|0)==0){L=YBb(H,(WBb(H)|0)<<1)|0;if((L|0)==0){C=26;break}JCb(j);M=L}else{C=26}}while(0);if((C|0)==26){_Bb(H,K,4,0)|0;M=0}JCb(n);z=M;i=d;return z|0}L=r;N=YGb(m,I,-1,-1)|0;O=F;R=s;S=g;T=t+44|0;U=0;V=0;W=0;X=B;a:while(1){ZBb(X,L,4,0)|0;if((WBb(c[p>>2]|0)|0)==0&((V|0)<(O|0)|(V|0)==(O|0)&W>>>0<N>>>0)){Y=PCb(c[r>>2]|0)|0;yDb(R,48,2156464,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;if((Y|0)==0){Z=-12;C=34;break}_=c[p>>2]|0;c[g>>2]=Y;do{if((XBb(_)|0)==0){Y=YBb(_,(WBb(_)|0)<<1)|0;if((Y|0)==0){C=32;break}JCb(g);if((Y|0)<0){Z=Y;C=34;break a}}else{C=32}}while(0);if((C|0)==32){C=0;_Bb(_,S,4,0)|0}c[T>>2]=(c[T>>2]|0)+1}Y=KDb(c[v>>2]|0,c[v+4>>2]|0,A,w)|0;$=c[o>>2]|0;ba=YGb($,($|0)<0|0?-1:0,Y,F)|0;Y=c[r>>2]|0;$=Y+136|0;c[$>>2]=ba;c[$+4>>2]=F;ca=cj(u,Y)|0;if((ca|0)<0){C=37;break}c[o>>2]=(c[o>>2]|0)+1;Y=U+1|0;$=Y;ba=(Y|0)<0|0?-1:0;da=c[p>>2]|0;if((ba|0)<(I|0)|(ba|0)==(I|0)&$>>>0<m>>>0){U=Y;V=ba;W=$;X=da}else{C=39;break}}if((C|0)==34){JCb(r);JCb(n);z=Z;i=d;return z|0}else if((C|0)==37){JCb(n);z=ca;i=d;return z|0}else if((C|0)==39){X=f;if((WBb(da)|0)!=0){do{ZBb(da,X,4,0)|0;JCb(f);}while((WBb(da)|0)!=0)}X=c[p>>2]|0;W=e;c[e>>2]=c[n>>2];do{if((XBb(X)|0)==0){V=YBb(X,(WBb(X)|0)<<1)|0;if((V|0)==0){break}JCb(e);z=V;i=d;return z|0}}while(0);_Bb(X,W,4,0)|0;z=0;i=d;return z|0}}}while(0);e=c[p>>2]|0;p=l;c[l>>2]=J;do{if((XBb(e)|0)==0){J=YBb(e,(WBb(e)|0)<<1)|0;if((J|0)==0){break}JCb(l);z=J;i=d;return z|0}}while(0);_Bb(e,p,4,0)|0;z=0;i=d;return z|0}function go(a){a=a|0;var b=0;b=c[a+44>>2]|0;JCb(b+12|0);JCb(b+16|0);return}function ho(a){a=a|0;Ok(a,xk(1048e3)|0);return 0}function io(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=f;h=f+12|0;j=h;k=e+16|0;e=h;do{if((c[e>>2]|0)==0){l=Ni(c[c[k>>2]>>2]|0)|0;if((l|0)<0){m=l}else{n=l;break}i=b;return m|0}else{n=0}}while(0);l=f+16|0;do{if((c[l>>2]|0)==0){o=Ni(c[(c[k>>2]|0)+4>>2]|0)|0;if((o|0)<0){m=o}else{p=o;break}i=b;return m|0}else{p=n}}while(0);n=f+8|0;if((c[n>>2]|0)==3){k=f+24|0;if((c[k>>2]|0)==0&(c[k+4>>2]|0)==(-2147483648|0)){f=(c[h>>2]|0)+136|0;o=c[f+4>>2]|0;c[k>>2]=c[f>>2];c[k+4>>2]=o;q=0;r=p}else{q=0;r=p}while(1){if((q|0)>=2){m=r;s=20;break}p=c[k>>2]|0;o=c[k+4>>2]|0;f=YGb(p,o,1,0)|0;c[k>>2]=f;c[k+4>>2]=F;f=j+(q<<2)|0;t=c[f>>2]|0;u=t+136|0;c[u>>2]=p;c[u+4>>2]=o;o=VFb(t)|0;if((o|0)==0){m=-12;s=20;break}c[o>>2]=c[n>>2];o=cj(a,c[f>>2]|0)|0;c[f>>2]=0;if((o|0)<0){m=o;s=20;break}else{q=q+1|0;r=o}}if((s|0)==20){i=b;return m|0}}s=Zr(a,c[a+20>>2]|0,c[a+24>>2]|0)|0;c[d>>2]=s;if((s|0)==0){m=-12;i=b;return m|0}r=c[n>>2]|0;if((r|0)==2){lo(g,s,0)}else if((r|0)==7){ko(g,s,1)}else if((r|0)==1){ko(g,s,0)}else if((r|0)==6){lo(g,s,1)}s=NCb(c[d>>2]|0,c[h>>2]|0)|0;if((s|0)<0){JCb(d);m=s;i=b;return m|0}JCb(e);JCb(l);l=VFb(c[d>>2]|0)|0;if((l|0)==0){JCb(d);m=-12;i=b;return m|0}else{c[l>>2]=c[n>>2];m=cj(a,c[d>>2]|0)|0;i=b;return m|0}return 0}function jo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=c[d+16>>2]|0;g=c[f>>2]|0;h=c[g+20>>2]|0;j=c[g+24>>2]|0;k=g+56|0;g=c[k>>2]|0;l=c[k+4>>2]|0;k=g;m=l;n=m;o=c[f+4>>2]|0;f=c[o+20>>2]|0;p=c[o+24>>2]|0;if(!((h|0)==(f|0)&(j|0)==(p|0))){yDb(d,16,2253784,(q=i,i=i+32|0,c[q>>2]=h,c[q+8>>2]=j,c[q+16>>2]=f,c[q+24>>2]=p,q)|0);i=q;r=-1094995529;i=b;return r|0}p=c[o+56>>2]|0;f=c[o+60>>2]|0;o=gHb(f,(f|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;s=F;t=gHb(p,(p|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;do{if((o|0)==(t|0)&(s|0)==(F|0)){if((f|0)==0|(n|0)==0){if((k|0)==0|(p|0)==0){break}if((k>>31|0)!=(p>>31|0)){break}}u=bFb(c[a+52>>2]|0)|0;c[e+4>>2]=u;if((u|0)==0){r=-558323010;i=b;return r|0}switch(c[e+8>>2]|0){case 7:case 1:{v=j;w=h<<1;x=n;break};case 6:case 2:{v=j<<1;w=h;x=n;break};case 3:{u=e+24|0;c[u>>2]=0;c[u+4>>2]=-2147483648;v=j;w=h;x=m<<1|0>>>31;break};default:{yDb(d,16,2227656,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=b;return r|0}}c[a+20>>2]=w;c[a+24>>2]=v;u=a+56|0;c[u>>2]=g|0;c[u+4>>2]=x|l&0;r=0;i=b;return r|0}}while(0);yDb(d,16,2239648,(q=i,i=i+32|0,c[q>>2]=k,c[q+8>>2]=n,c[q+16>>2]=p,c[q+24>>2]=f,q)|0);i=q;r=-1094995529;i=b;return r|0}function ko(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=e+68|0;h=e+72|0;i=b+4|0;j=c[i>>2]|0;if((a[j+4|0]|0)==0){return}k=b+12|0;l=b+16|0;b=(f|0)==0;f=0;m=(c[g>>2]|0)/2|0;n=c[h>>2]|0;o=j;while(1){j=c[k>>2]|0;p=c[j+(f<<2)>>2]|0;q=c[(c[l>>2]|0)+(f<<2)>>2]|0;r=e+(f<<2)|0;s=c[r>>2]|0;if((f-1|0)>>>0<2>>>0){t=-(-(c[h>>2]|0)>>d[o+6|0])|0;u=-(((c[g>>2]|0)/-2|0)>>d[o+5|0])|0}else{t=n;u=m}do{if(b){v=e+32+(f<<2)|0;iDb(s,c[v>>2]|0,p,c[j+32+(f<<2)>>2]|0,u,t);iDb((c[r>>2]|0)+u|0,c[v>>2]|0,q,c[(c[l>>2]|0)+32+(f<<2)>>2]|0,u,t)}else{if((t|0)<=0){break}v=e+32+(f<<2)|0;if((u|0)>0){w=0;x=p;y=q;z=s}else{break}while(1){A=0;B=0;while(1){a[z+B|0]=a[x+A|0]|0;a[z+(B|1)|0]=a[y+A|0]|0;C=A+1|0;if((C|0)<(u|0)){A=C;B=B+2|0}else{break}}B=w+1|0;if((B|0)<(t|0)){w=B;x=x+(c[(c[k>>2]|0)+32+(f<<2)>>2]|0)|0;y=y+(c[(c[l>>2]|0)+32+(f<<2)>>2]|0)|0;z=z+(c[v>>2]|0)|0}else{break}}}}while(0);s=f+1|0;q=c[i>>2]|0;if((s|0)<(d[q+4|0]|0)){f=s;m=u;n=t;o=q}else{break}}return}function lo(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=e+68|0;h=c[g>>2]|0;i=e+72|0;j=(c[i>>2]|0)/2|0;k=b+4|0;l=c[k>>2]|0;if((a[l+4|0]|0)==0){return}m=b+12|0;n=b+16|0;if((f|0)==0){b=0;o=h;p=j;q=l;while(1){if((b-1|0)>>>0<2>>>0){r=-(((c[i>>2]|0)/-2|0)>>d[q+6|0])|0;s=-(-(c[g>>2]|0)>>d[q+5|0])|0}else{r=p;s=o}t=e+32+(b<<2)|0;u=c[t>>2]|0;v=ba(u,r)|0;w=e+(b<<2)|0;x=c[m>>2]|0;iDb(c[w>>2]|0,u,c[x+(b<<2)>>2]|0,c[x+32+(b<<2)>>2]|0,s,r);x=c[n>>2]|0;iDb((c[w>>2]|0)+v|0,c[t>>2]|0,c[x+(b<<2)>>2]|0,c[x+32+(b<<2)>>2]|0,s,r);x=b+1|0;t=c[k>>2]|0;if((x|0)<(d[t+4|0]|0)){b=x;o=s;p=r;q=t}else{break}}return}else{q=0;r=h;h=j;j=l;while(1){if((q-1|0)>>>0<2>>>0){y=-(((c[i>>2]|0)/-2|0)>>d[j+6|0])|0;z=-(-(c[g>>2]|0)>>d[j+5|0])|0}else{y=h;z=r}l=e+32+(q<<2)|0;p=c[l>>2]|0;s=e+(q<<2)|0;o=c[m>>2]|0;iDb(c[s>>2]|0,p<<f,c[o+(q<<2)>>2]|0,c[o+32+(q<<2)>>2]|0,z,y);o=c[n>>2]|0;iDb((c[s>>2]|0)+p|0,c[l>>2]<<f,c[o+(q<<2)>>2]|0,c[o+32+(q<<2)>>2]|0,z,y);o=q+1|0;l=c[k>>2]|0;if((o|0)<(d[l+4|0]|0)){q=o;r=z;h=y;j=l}else{break}}return}}function mo(a,b){a=a|0;b=b|0;c[(c[(c[a+8>>2]|0)+44>>2]|0)+12>>2]=b;return 0}function no(a,b){a=a|0;b=b|0;c[(c[(c[a+8>>2]|0)+44>>2]|0)+16>>2]=b;return 0}function oo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a>>2]|0;g=c[f+44>>2]|0;j=c[c[f+16>>2]>>2]|0;k=a+156|0;c[k>>2]=c[k>>2]|1;k=j+116|0;l=g+4|0;c[d>>2]=c[l>>2];c[d+4>>2]=1;kFb(e,k,d);d=a+116|0;a=c[e>>2]|0;g=c[e+4>>2]|0;c[d>>2]=a;c[d+4>>2]=g;d=c[k>>2]|0;k=c[j+120>>2]|0;j=a;a=g;yDb(f,40,1996728,(f=i,i=i+56|0,c[f>>2]=c[l>>2],c[f+8>>2]=d,c[f+16>>2]=k,h[f+24>>3]=+(d|0)/+(k|0),c[f+32>>2]=j,c[f+40>>2]=a,h[f+48>>3]=+(j|0)/+(a|0),f)|0);i=f;i=b;return 0}function po(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=a+160|0;a=c[(c[f+44>>2]|0)+4>>2]|0;h=fHb(c[g>>2]|0,c[g+4>>2]|0,a,(a|0)<0|0?-1:0)|0;if((h|0)==0&(F|0)==0){j=cj(c[c[f+32>>2]>>2]|0,b)|0;i=d;return j|0}else{JCb(e);j=0;i=d;return j|0}return 0}function qo(b,c,f,g,h,i){b=b|0;c=c|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;if((g|0)>0){j=0;k=f}else{return}do{f=(d[c+j|0]|0)<<7;l=(e[k>>1]|0)-f|0;m=127-((ba((l|0)>-1?l:-l|0,h)|0)>>16)|0;n=(m|0)<0?0:m;m=(ba(ba(n,l)|0,n)|0)>>14;n=(e[i+((j&7)<<1)>>1]|0)+f+m>>7;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[b+j|0]=o;k=k+((j&1)<<1)|0;j=j+1|0;}while((j|0)<(g|0));return}function ro(a,c,f,g,h,i){a=a|0;c=c|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((i|0)>0){j=0}else{return}do{k=j<<1;l=k|1;m=(d[g+k|0]|0)+(e[f+(j<<1)>>1]|0)+(d[g+l|0]|0)+(d[g+(k+h)|0]|0)+(d[g+(l+h)|0]|0)|0;l=c+(j<<1)|0;k=e[l>>1]|0;b[l>>1]=m;b[a+(j<<1)>>1]=m-k;j=j+1|0;}while((j|0)<(i|0));return}function so(a){a=a|0;var b=0,d=0,e=0.0,f=0,j=0,k=0;b=i;d=c[a+44>>2]|0;e=+g[d+4>>2];c[d+8>>2]=~~(32768.0/e);f=d+12|0;j=(c[f>>2]|0)+1&-2;if((j|0)<4){k=4}else{k=(j|0)>32?32:j}c[f>>2]=k;c[d+36>>2]=268;c[d+32>>2]=18;yDb(a,40,2169720,(a=i,i=i+16|0,h[a>>3]=e,c[a+8>>2]=k,a)|0);i=a;i=b;return 0}function to(a){a=a|0;$Db((c[a+44>>2]|0)+28|0);return}function uo(a){a=a|0;Ok(a,xk(550920)|0);return 0}function vo(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=i;i=i+8|0;g=f|0;c[g>>2]=d;h=c[a+8>>2]|0;j=c[h+44>>2]|0;k=c[c[h+32>>2]>>2]|0;do{if((RCb(d)|0)==0){h=Zr(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((h|0)!=0){NCb(h,c[g>>2]|0)|0;l=0;m=h;break}JCb(g);n=-12;i=f;return n|0}else{l=1;m=d}}while(0);d=a+20|0;h=a+24|0;a=j+12|0;o=j+28|0;p=j+8|0;q=j+36|0;r=j+32|0;s=j+16|0;t=j+20|0;u=j+24|0;j=0;do{v=c[g>>2]|0;w=c[v+(j<<2)>>2]|0;if((w|0)==0){break}x=c[v+32+(j<<2)>>2]|0;if((x|0)==0){break}v=(j|0)==0;y=c[(v?a:u)>>2]|0;z=c[(v?h:t)>>2]|0;A=c[(v?d:s)>>2]|0;v=c[m+(j<<2)>>2]|0;a:do{if((((A|0)>(z|0)?z:A)|0)>(y<<1|0)){B=c[m+32+(j<<2)>>2]|0;C=(A+15&-16|0)/2|0;D=2097152/((ba(y,y)|0)>>>0)|0;E=c[o>>2]|0;F=E+32|0;G=C+32|0;H=c[p>>2]|0;TGb(F|0,0,(C<<1)+32|0)|0;I=(y|0)>0;if(I){J=x<<1;K=(A|0)/2|0;L=0;while(1){M=E+((ba(L,C)|0)+G<<1)|0;N=E+((ba(L-1|0,C)|0)+G<<1)|0;O=w+(ba(J,L)|0)|0;Se[c[q>>2]&511](F,M,N,O,x,K);O=L+1|0;if((O|0)<(y|0)){L=O}else{P=y;Q=K;break}}}else{P=0;Q=(A|0)/2|0}K=z-y|0;L=(y+1+A|0)/2|0;J=(y|0)/-2|0;O=(y|0)>1;N=16-y|0;M=E+(J+16<<1)|0;R=I^1;S=P;do{do{if((S|0)<(K|0)){T=S+y|0;U=((T|0)/2|0|0)%(y|0)|0;V=E+((ba(U,C)|0)+G<<1)|0;W=E+((ba(((U|0)!=0?U:y)-1|0,C)|0)+G<<1)|0;U=w+(ba(T,x)|0)|0;Se[c[q>>2]&511](F,V,W,U,x,Q);if(I){U=0;W=0;while(1){V=(e[E+(U+16<<1)>>1]|0)+W|0;T=U+1|0;if((T|0)<(y|0)){U=T;W=V}else{X=y;Y=V;break}}}else{X=0;Y=0}if((X|0)<(Q|0)){W=X;U=Y;while(1){V=E+(W+N<<1)|0;T=(e[E+(W+16<<1)>>1]|0)-(e[V>>1]|0)+U|0;b[V>>1]=(ba(T,D)|0)>>>16;V=W+1|0;if((V|0)<(Q|0)){W=V;U=T}else{Z=Q;_=T;break}}}else{Z=X;_=Y}if((Z|0)<(L|0)){U=(ba(_,D)|0)>>>16&65535;W=Z;do{b[E+(W+N<<1)>>1]=U;W=W+1|0;}while((W|0)<(L|0))}if(O){$=J}else{break}do{b[E+($+16<<1)>>1]=b[F>>1]|0;$=$+1|0;}while(($|0)<0)}}while(0);W=(S|0)!=(y|0);if(W|R){aa=W?S:0}else{W=0;while(1){U=v+(ba(W,B)|0)|0;T=w+(ba(W,x)|0)|0;Se[c[r>>2]&511](U,T,M,A,H,1361560+((W&7)<<4)|0);T=W+1|0;if((T|0)<(y|0)){W=T}else{aa=y;break}}}W=v+(ba(aa,B)|0)|0;T=w+(ba(aa,x)|0)|0;Se[c[r>>2]&511](W,T,M,A,H,1361560+((aa&7)<<4)|0);T=aa+1|0;if((T|0)>=(z|0)){break a}W=v+(ba(T,B)|0)|0;U=w+(ba(T,x)|0)|0;Se[c[r>>2]&511](W,U,M,A,H,1361560+((T&7)<<4)|0);S=aa+2|0;}while((S|0)<(z|0))}else{if((v|0)==(w|0)){break}iDb(v,c[m+32+(j<<2)>>2]|0,w,x,A,z)}}while(0);j=j+1|0;}while((j|0)<4);if((l|0)==0){JCb(g)}n=cj(k,m)|0;i=f;return n|0}function wo(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=bFb(c[a+52>>2]|0)|0;f=d[e+5|0]|0;g=d[e+6|0]|0;e=b+28|0;$Db(e);h=a+20|0;i=b+12|0;j=dEb(((ba((c[h>>2]|0)+15&-16,(c[i>>2]|0)+1|0)|0)/2|0)+32|0,2)|0;c[e>>2]=j;if((j|0)==0){k=-12;return k|0}c[b+16>>2]=-(-(c[h>>2]|0)>>f);c[b+20>>2]=-(-(c[a+24>>2]|0)>>g);a=c[i>>2]|0;i=(((a>>f)+(a>>g)|0)/2|0)+1&-2;if((i|0)<4){l=4}else{l=(i|0)>32?32:i}c[b+24>>2]=l;k=0;return k|0}function xo(d){d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;g=0;do{h=bFb(g)|0;do{if((a[h+7|0]&12)==0){if((a[h+5|0]|0)!=(a[h+6|0]|0)){if(((b[h+10>>1]^b[h+8>>1])&3)==0){break}}zk(f,g,(g|0)<0|0?-1:0)|0}}while(0);g=g+1|0;}while((g|0)<333);Ok(d,c[f>>2]|0);i=e;return 0}function yo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e|0;g=e+8|0;c[f>>2]=d;h=c[b+8>>2]|0;j=c[c[h+32>>2]>>2]|0;k=j+24|0;l=Zr(j,c[j+20>>2]|0,c[k>>2]|0)|0;if((l|0)==0){JCb(f);m=-12;i=e;return m|0}NCb(l,d)|0;if((a[(bFb(c[b+52>>2]|0)|0)+7|0]&2)==0){n=c[f>>2]|0}else{b=c[f>>2]|0;UGb(c[l+4>>2]|0,c[b+4>>2]|0,1024)|0;n=b}c[g>>2]=n;c[g+4>>2]=l;n=c[k>>2]|0;k=c[(c[h+48>>2]|0)+28>>2]|0;Pe[c[c[h+56>>2]>>2]&255](h,452,g,0,(n|0)>(k|0)?k:n)|0;JCb(f);m=cj(j,l)|0;i=e;return m|0}function zo(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=bFb(c[a+52>>2]|0)|0;f=d[e+5|0]|0;g=d[e+6|0]|0;bDb(b,0,e);e=a+20|0;h=c[e>>2]|0;c[b+28>>2]=h;c[b+16>>2]=h;h=-(-(c[e>>2]|0)>>f)|0;c[b+24>>2]=h;c[b+20>>2]=h;h=a+24|0;a=c[h>>2]|0;c[b+44>>2]=a;c[b+32>>2]=a;a=-(-(c[h>>2]|0)>>g)|0;c[b+40>>2]=a;c[b+36>>2]=a;return 0}function Ao(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=c[d+44>>2]|0;d=c[e>>2]|0;i=c[e+4>>2]|0;e=h+16|0;j=h+32|0;k=f+1|0;l=h;h=0;while(1){m=c[d+(h<<2)>>2]|0;if((m|0)==0){n=20;break}o=d+32+(h<<2)|0;p=c[o>>2]|0;if((p|0)==0){n=20;break}q=c[e+(h<<2)>>2]|0;r=c[j+(h<<2)>>2]|0;s=(ba(r,f)|0)/(g|0)|0;t=(ba(r,k)|0)/(g|0)|0;r=c[l+(h<<2)>>2]|0;u=i+32+(h<<2)|0;v=(c[i+(h<<2)>>2]|0)+(ba(c[u>>2]|0,s)|0)|0;w=m+((ba(r,q-1|0)|0)+(ba(s,p)|0))|0;a:do{if((s|0)<(t|0)){p=(q|0)>0;if((r|0)==1){m=s;x=v;y=w;while(1){if(p){z=0;do{a[x+z|0]=a[y+(-z|0)|0]|0;z=z+1|0;}while((z|0)<(q|0))}z=m+1|0;if((z|0)<(t|0)){m=z;x=x+(c[u>>2]|0)|0;y=y+(c[o>>2]|0)|0}else{break a}}}else{A=s;B=v;C=w}while(1){do{if((r|0)==3){if(p){D=0;E=C;F=B}else{break}while(1){y=a[E]|0;x=a[E+1|0]|0;a[F+2|0]=a[E+2|0]|0;a[F+1|0]=x;a[F]=y;y=D+1|0;if((y|0)<(q|0)){D=y;E=E-3|0;F=F+3|0}else{break}}}else if((r|0)==2){y=B;x=C;if(p){G=0}else{break}do{b[y+(G<<1)>>1]=b[x+(-G<<1)>>1]|0;G=G+1|0;}while((G|0)<(q|0))}else if((r|0)==4){x=B;y=C;if(p){H=0}else{break}do{c[x+(H<<2)>>2]=c[y+(-H<<2)>>2];H=H+1|0;}while((H|0)<(q|0))}else{if(p){I=0}else{break}do{y=ba(I,r)|0;UGb(B+y|0,C+(-y|0)|0,r)|0;I=I+1|0;}while((I|0)<(q|0))}}while(0);y=A+1|0;if((y|0)<(t|0)){A=y;B=B+(c[u>>2]|0)|0;C=C+(c[o>>2]|0)|0}else{break}}}}while(0);o=h+1|0;if((o|0)<4){h=o}else{n=20;break}}if((n|0)==20){return 0}return 0}function Bo(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[(c[a+44>>2]|0)+4>>2]|0;if((d|0)==0){e=855104}else if((d|0)==1){e=58048}else if((d|0)==2|(d|0)==3){e=1425504}else{yDb(0,0,2169160,(d=i,i=i+24|0,c[d>>2]=2096288,c[d+8>>2]=2041296,c[d+16>>2]=121,d)|0);i=d;Cd();return 0}Ok(a,xk(e)|0);i=b;return 0}function Co(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[(c[a>>2]|0)+44>>2]|0;e=c[d+4>>2]|0;do{if((e|0)==1){f=ba(c[d+1064>>2]|0,c[d+1032>>2]|0)|0;g=(f|0)>1?f<<8:256;if((c[d+1056>>2]|0)==0){c[a+20>>2]=g;break}else{c[a+24>>2]=g;break}}else if((e|0)==0){c[a+20>>2]=256;g=ba(c[d+1064>>2]|0,c[d+1032>>2]|0)|0;c[a+24>>2]=ba((g|0)>1?g:1,(c[d+1048>>2]|0)+(c[d+1044>>2]|0)|0)|0}else if((e|0)==2|(e|0)==3){c[a+20>>2]=256;c[a+24>>2]=256}else{yDb(0,0,2169160,(g=i,i=i+24|0,c[g>>2]=2096288,c[g+8>>2]=2041296,c[g+16>>2]=176,g)|0);i=g;Cd();return 0}}while(0);c[a+28>>2]=1;c[a+32>>2]=1;i=b;return 0}function Do(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0.0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;g=i;i=i+8|0;h=g|0;c[h>>2]=f;j=c[e+8>>2]|0;k=c[j+44>>2]|0;l=c[c[j+32>>2]>>2]|0;j=l+20|0;m=l+24|0;n=Zr(l,c[j>>2]|0,c[m>>2]|0)|0;if((n|0)==0){JCb(h);o=-12;i=g;return o|0}p=f+136|0;f=c[p+4>>2]|0;q=n+136|0;c[q>>2]=c[p>>2];c[q+4>>2]=f;f=k+1032|0;q=c[f>>2]|0;if((q|0)>0){p=k+1072|0;r=k+1036|0;s=0;t=q;while(1){u=c[m>>2]|0;if((s-1|0)>>>0<2>>>0){v=c[p>>2]|0;w=d[v+5|0]|0;x=-(-u>>d[v+6|0])|0}else{w=0;x=u}u=-(-(c[j>>2]|0)>>w)|0;if((x|0)>0){v=0;do{y=b[(c[p>>2]|0)+8+(s<<1)>>1]&3;z=(c[n+(y<<2)>>2]|0)+(ba(c[n+32+(y<<2)>>2]|0,v)|0)|0;TGb(z|0,a[(c[r>>2]|0)+s|0]|0,u|0)|0;v=v+1|0;}while((v|0)<(x|0));A=c[f>>2]|0}else{A=t}v=s+1|0;if((v|0)<(A|0)){s=v;t=A}else{B=A;break}}}else{B=q}q=c[k+4>>2]|0;do{if((q|0)==1){if((B|0)<=0){break}A=k+1064|0;t=k+1052|0;s=k+1056|0;x=k+1060|0;r=k+1072|0;p=0;w=B;while(1){m=ba(c[A>>2]|0,p<<8)|0;v=c[h>>2]|0;u=c[t>>2]|0;z=c[x>>2]|0;y=c[r>>2]|0;C=b[y+8+(p<<1)>>1]&3;if((p-1|0)>>>0<2>>>0){D=d[y+6|0]|0;E=d[y+5|0]|0}else{D=0;E=0}y=c[v+32+(C<<2)>>2]|0;G=c[n+32+(C<<2)>>2]|0;H=ba(G,(z|0)==1?-1:1)|0;I=c[n+(C<<2)>>2]|0;J=(c[s>>2]|0)!=0;if(J){K=ba(G,m>>D)|0}else{K=m>>E}m=I+K|0;L=I+(K+(ba(G,(256>>>(D>>>0))-1|0)|0))|0;M=(z|0)!=0;z=M?L:m;L=-(c[v+72>>2]|0)>>D;N=-L|0;O=-(c[v+68>>2]|0)>>E;P=-O|0;if(J|M^1){Q=m}else{Q=I+(K+(256>>>(E>>>0)))|0}if((L|0)<0){L=255-u&255;I=(O|0)<0;O=Q;m=0;R=c[v+(C<<2)>>2]|0;while(1){C=R+P|0;if(I){if(J){if(M){v=z;S=R;while(1){T=v+(ba((d[S]|0)>>>(D>>>0),H)|0)|0;U=d[T]|0;if(U>>>0>L>>>0){V=-1}else{V=U+u&255}a[T]=V;T=S+1|0;if(T>>>0<C>>>0){v=v+1|0;S=T}else{break}}}else{S=z;v=R;while(1){T=S+(ba((d[v]|0)>>>(D>>>0),H)|0)|0;U=d[T]|0;if(U>>>0>L>>>0){W=-1}else{W=U+u&255}a[T]=W;T=v+1|0;if(T>>>0<C>>>0){S=S+1|0;v=T}else{break}}}}else{if(M){v=R;do{S=O+(-((d[v]|0)>>>(E>>>0))|0)|0;T=d[S]|0;if(T>>>0>L>>>0){X=-1}else{X=T+u&255}a[S]=X;v=v+1|0;}while(v>>>0<C>>>0)}else{v=R;do{S=O+((d[v]|0)>>>(E>>>0))|0;T=d[S]|0;if(T>>>0>L>>>0){Y=-1}else{Y=T+u&255}a[S]=Y;v=v+1|0;}while(v>>>0<C>>>0)}}}C=m+1|0;if((C|0)<(N|0)){O=O+G|0;m=C;R=R+y|0}else{break}}Z=c[f>>2]|0}else{Z=w}y=p+1|0;if((y|0)<(Z|0)){p=y;w=Z}else{break}}}else if((q|0)==0){if((B|0)<=0){break}w=k+1072|0;p=k+1044|0;s=k+1048|0;r=k+1064|0;x=k+8|0;t=x;A=k+1068|0;y=k+1040|0;R=0;do{m=b[(c[w>>2]|0)+8+(R<<1)>>1]&3;G=ba((c[s>>2]|0)+(c[p>>2]|0)|0,R)|0;O=ba(G,c[r>>2]|0)|0;G=c[h>>2]|0;N=G+72|0;u=c[N>>2]|0;if((u|0)>0){L=c[G+(m<<2)>>2]|0;M=G+68|0;H=0;z=u;u=c[M>>2]|0;while(1){J=ba(c[G+32+(m<<2)>>2]|0,H)|0;if((u|0)>0){I=0;do{P=t+(d[L+(I+J)|0]<<2)|0;c[P>>2]=(c[P>>2]|0)+1;I=I+1|0;_=c[M>>2]|0;}while((I|0)<(_|0));$=c[N>>2]|0;aa=_}else{$=z;aa=u}I=H+1|0;if((I|0)<($|0)){H=I;z=$;u=aa}else{ca=0;da=0;break}}}else{ca=0;da=0}do{u=c[t+(da<<2)>>2]|0;ca=ca>>>0>u>>>0?ca:u;da=da+1|0;}while((da|0)<256);ea=+gc(+(+((ca+1|0)>>>0>>>0)));if((c[j>>2]|0)>0){u=ca;z=0;H=YGb(u,z,-1,-1)|0;N=F;M=n+32+(m<<2)|0;L=n+(m<<2)|0;G=0;I=c[p>>2]|0;while(1){if((c[A>>2]|0)==0){J=I;P=(I|0)<0|0?-1:0;C=gHb(c[t+(G<<2)>>2]|0,0,J,P)|0;v=YGb(H,N,C,F)|0;C=eHb(v,F,u,z)|0;v=ZGb(J,P,C,F)|0;fa=v}else{fa=~~+Hb(+(+(I|0)*(1.0- +gc(+(+(((c[t+(G<<2)>>2]|0)+1|0)>>>0>>>0)))/ea)))}v=I-1|0;if((v|0)<(fa|0)){ga=I}else{C=v;do{do{if((c[r>>2]|0)==0){v=(ba(c[M>>2]|0,C+O|0)|0)+G|0;a[(c[L>>2]|0)+v|0]=-1}else{if((c[f>>2]|0)<=0){break}v=C+O|0;P=0;do{J=(ba(c[n+32+(P<<2)>>2]|0,v)|0)+G|0;a[(c[n+(P<<2)>>2]|0)+J|0]=a[(c[y>>2]|0)+P|0]|0;P=P+1|0;}while((P|0)<(c[f>>2]|0))}}while(0);C=C-1|0;}while((C|0)>=(fa|0));ga=c[p>>2]|0}C=(c[s>>2]|0)+ga-1|0;if((C|0)<(ga|0)){ha=ga}else{P=G&255;v=C;while(1){C=(ba(c[M>>2]|0,v+O|0)|0)+G|0;a[(c[L>>2]|0)+C|0]=P;C=v-1|0;J=c[p>>2]|0;if((C|0)<(J|0)){ha=J;break}else{v=C}}}v=G+1|0;if((v|0)<(c[j>>2]|0)){G=v;I=ha}else{break}}}TGb(x|0,0,1024)|0;R=R+1|0;}while((R|0)<(c[f>>2]|0))}else if((q|0)==3){R=e+24|0;x=c[R>>2]|0;if((x|0)<=0){break}p=e+20|0;s=n+32|0;y=n|0;r=n+4|0;t=n+8|0;A=0;w=c[p>>2]|0;I=x;while(1){x=c[h>>2]|0;G=ba(c[x+36>>2]|0,A)|0;L=ba(c[x+40>>2]|0,A)|0;if((w|0)>0){O=0;M=x;while(1){x=a[(c[M+4>>2]|0)+(O+G)|0]|0;z=x&255;u=a[(c[M+8>>2]|0)+(O+L)|0]|0;N=u&255;H=(ba(c[s>>2]|0,z)|0)+N|0;m=(c[y>>2]|0)+H|0;if((a[m]|0)==0){v=128-z|0;z=128-N|0;a[m]=((z|0)>-1?z:-z|0)+((v|0)>-1?v:-v|0)}a[(c[r>>2]|0)+H|0]=x;a[(c[t>>2]|0)+H|0]=u;u=O+1|0;ia=c[p>>2]|0;if((u|0)>=(ia|0)){break}O=u;M=c[h>>2]|0}ja=ia;ka=c[R>>2]|0}else{ja=w;ka=I}M=A+1|0;if((M|0)<(ka|0)){A=M;w=ja;I=ka}else{break}}}else if((q|0)==2){I=e+24|0;w=c[I>>2]|0;if((w|0)>0){A=e+20|0;R=n+32|0;p=n|0;t=0;r=c[A>>2]|0;y=w;while(1){w=c[h>>2]|0;s=ba(c[w+36>>2]|0,t)|0;M=ba(c[w+40>>2]|0,t)|0;if((r|0)>0){O=0;L=r;G=w;while(1){w=ba(d[(c[G+4>>2]|0)+(O+s)|0]|0,c[R>>2]|0)|0;u=(c[p>>2]|0)+((d[(c[G+8>>2]|0)+(O+M)|0]|0)+w)|0;w=a[u]|0;if(w<<24>>24==-1){la=L}else{a[u]=w+1;la=c[A>>2]|0}w=O+1|0;if((w|0)>=(la|0)){break}O=w;L=la;G=c[h>>2]|0}ma=la;na=c[I>>2]|0}else{ma=r;na=y}G=t+1|0;if((G|0)<(na|0)){t=G;r=ma;y=na}else{oa=p;pa=R;break}}}else{oa=n|0;pa=n+32|0}R=n+4|0;p=n+8|0;y=0;do{r=c[oa>>2]|0;t=ba(c[pa>>2]|0,y)|0;I=y&255;A=0;do{if((a[r+(A+t)|0]|0)==0){G=(ba(c[pa>>2]|0,y)|0)+A|0;a[(c[R>>2]|0)+G|0]=I;G=(ba(c[pa>>2]|0,y)|0)+A|0;a[(c[p>>2]|0)+G|0]=A}A=A+1|0;}while((A|0)<256);y=y+1|0;}while((y|0)<256)}else{yDb(0,0,2169160,(y=i,i=i+24|0,c[y>>2]=2096288,c[y+8>>2]=2041296,c[y+16>>2]=342,y)|0);i=y;Cd();return 0}}while(0);JCb(h);o=cj(l,n)|0;i=g;return o|0}function Eo(a){a=a|0;var b=0,e=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;a=bFb(c[e>>2]|0)|0;c[b+1072>>2]=a;c[b+1032>>2]=d[a+4|0]|0;a=c[e>>2]|0;if((a|0)==317|(a|0)==82){c[b+1036>>2]=1683776;c[b+1040>>2]=57824;return 0}else{c[b+1036>>2]=1683768;c[b+1040>>2]=57816;return 0}return 0}function Fo(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0;b=i;d=c[a+44>>2]|0;e=d+16|0;do{if((c[e>>2]|0)!=0){if((c[d+12>>2]|0)==0){break}yDb(a,16,2302400,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;h=-22;i=b;return h|0}}while(0);j=d+44|0;k=c[j>>2]|0;do{if((k|0)!=0){l=Jo(d+48|0,j,k,1996472,a)|0;if((l|0)<0){h=l}else{break}i=b;return h|0}}while(0);k=d+32|0;l=c[k>>2]|0;do{if((l|0)!=0){m=Jo(d+36|0,k,l,2041160,a)|0;if((m|0)<0){h=m}else{break}i=b;return h|0}}while(0);l=d+12|0;m=c[l>>2]|0;do{if((m|0)!=0){n=Jo(d+20|0,l,m,2168896,a)|0;if((n|0)<0){h=n}else{break}i=b;return h|0}}while(0);m=c[e>>2]|0;do{if((m|0)==0){o=0;p=a}else{n=a;q=Jo(d+24|0,e,m,2095984,n)|0;if((q|0)<0){h=q;i=b;return h|0}else{o=c[e>>2]|0;p=n;break}}}while(0);e=c[l>>2]|0;l=c[k>>2]|0;k=c[j>>2]|0;yDb(p,40,2284568,(f=i,i=i+32|0,c[f>>2]=o,c[f+8>>2]=e,c[f+16>>2]=l,c[f+24>>2]=k,f)|0);i=f;r=+g[d+8>>2];s=+U(r)*65536.0;t=+g[d+28>>2];c[d+64>>2]=~~+Gc(+(s*t));c[d+68>>2]=~~+Gc(+(t*+T(r)*65536.0));c[d+60>>2]=1;h=0;i=b;return h|0}function Go(a){a=a|0;var b=0;b=c[a+44>>2]|0;IBb(c[b+48>>2]|0);IBb(c[b+20>>2]|0);IBb(c[b+24>>2]|0);IBb(c[b+36>>2]|0);return}function Ho(a){a=a|0;Ok(a,xk(550880)|0);return 0}function Io(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=c[a+44>>2]|0;do{if((QGb(b,2168896)|0)==0){f=Jo(g+20|0,g+12|0,d,2168896,a)|0;if((f|0)<0){h=f;return h|0}else{$Db(g+16|0);break}}else{if((QGb(b,2095984)|0)==0){f=Jo(g+24|0,g+16|0,d,2095984,a)|0;if((f|0)<0){h=f;return h|0}else{$Db(g+12|0);break}}if((QGb(b,2041160)|0)==0){f=Jo(g+36|0,g+32|0,d,2041160,a)|0;if((f|0)<0){h=f}else{break}return h|0}if((QGb(b,1996472)|0)!=0){h=-38;return h|0}f=Jo(g+48|0,g+44|0,d,1996472,a)|0;if((f|0)<0){h=f}else{break}return h|0}}while(0);h=0;return h|0}function Jo(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;j=eEb(d)|0;if((j|0)==0){k=-12;i=g;return k|0}l=JBb(h,d,160256,0,0,0,0,0,f)|0;if((l|0)<0){yDb(f,16,1960392,(f=i,i=i+16|0,c[f>>2]=d,c[f+8>>2]=e,f)|0);i=f;ZDb(j);k=l;i=g;return k|0}l=c[a>>2]|0;if((l|0)!=0){IBb(l)}c[a>>2]=c[h>>2];$Db(b);c[b>>2]=j;k=0;i=g;return k|0}function Ko(b,e){b=b|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0.0,E=0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0,L=0,M=0.0,N=0;f=i;i=i+8|0;j=f|0;c[j>>2]=e;k=b+8|0;l=c[k>>2]|0;m=c[l+44>>2]|0;n=m;o=c[c[l+32>>2]>>2]|0;l=m+64|0;p=c[l>>2]|0;r=m+68|0;s=c[r>>2]|0;t=m+40|0;u=+g[t>>2];do{if((RCb(e)|0)==0){v=Zr(o,c[o+20>>2]|0,c[o+24>>2]|0)|0;if((v|0)!=0){NCb(v,c[j>>2]|0)|0;w=0;x=v;y=c[j>>2]|0;break}JCb(j);z=-12;i=f;return z|0}else{w=1;x=e;y=e}}while(0);e=b+160|0;v=m+72|0;h[v>>3]=+((c[e>>2]|0)>>>0)+ +(c[e+4>>2]|0)*4294967296.0;e=y+136|0;y=c[e>>2]|0;A=c[e+4>>2]|0;if((y|0)==0&(A|0)==(-2147483648|0)){e=m+96|0;h[e>>3]=+q;B=+q;C=e}else{e=m+96|0;h[e>>3]=(+(y>>>0)+ +(A|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0));B=+(y>>>0)+ +(A|0)*4294967296.0;C=e}h[m+80>>3]=B;do{if((c[m+32>>2]|0)!=0){B=+MBb(c[m+36>>2]|0,v,0);e=m+28|0;g[e>>2]=B;if(!(B<-10.0|B>10.0)){break}A=~~B;if((A|0)<-10){D=-10.0}else{D=(A|0)>10?10.0:+(A|0)}g[e>>2]=D;yDb(c[k>>2]|0,24,2189080,(E=i,i=i+24|0,c[E>>2]=-10,c[E+8>>2]=10,h[E+16>>3]=D,E)|0);i=E}}while(0);do{if((c[m+44>>2]|0)!=0){D=+MBb(c[m+48>>2]|0,v,0);g[t>>2]=D;e=D<-10.0;A=D>10.0;if(!(e|A)){break}if(e){F=-10.0}else{F=A?10.0:D}g[t>>2]=F;yDb(c[k>>2]|0,24,2172616,(E=i,i=i+24|0,c[E>>2]=-10,c[E+8>>2]=10,h[E+16>>3]=F,E)|0);i=E}}while(0);do{if((c[m+12>>2]|0)==0){if((c[m+16>>2]|0)==0){G=+g[m+8>>2];H=+g[m+4>>2];break}else{F=+MBb(c[m+24>>2]|0,v,0);g[m+8>>2]=F;D=F*180.0/3.141592653589793;g[m+4>>2]=D;G=F;H=D;break}}else{D=+MBb(c[m+20>>2]|0,v,0);g[m+4>>2]=D;F=D*3.141592653589793/180.0;g[m+8>>2]=F;G=F;H=D}}while(0);A=m+28|0;D=+g[A>>2];F=+g[t>>2];B=+h[C>>3];C=~~+h[v>>3];yDb(c[k>>2]|0,48,2163312,(E=i,i=i+48|0,h[E>>3]=G/3.141592653589793,h[E+8>>3]=H,h[E+16>>3]=D,h[E+24>>3]=F,h[E+32>>3]=B,c[E+40>>2]=C,E)|0);i=E;B=+g[m+8>>2];F=+U(B)*65536.0;D=+g[A>>2];A=~~+Gc(+(F*D));c[l>>2]=A;l=~~+Gc(+(D*+T(B)*65536.0));c[r>>2]=l;r=m+60|0;do{if((c[r>>2]|0)==0&(p|0)==(A|0)&(s|0)==(l|0)){I=33}else{E=0;do{C=E-128|0;k=(ba(C,l)|0)+8421376|0;v=(ba(C,A)|0)+8421376|0;C=0;do{e=C-128|0;y=k-(ba(e,A)|0)>>16;J=v+(ba(e,l)|0)>>16;if(y>>>0>255>>>0){K=-y>>31&255}else{K=y&255}a[n+368+(E<<8)+C|0]=K;if(J>>>0>255>>>0){L=-J>>31&255}else{L=J&255}a[n+65904+(E<<8)+C|0]=L;C=C+1|0;}while((C|0)<256);E=E+1|0;}while((E|0)<256);if((c[r>>2]|0)==0){I=33;break}M=+g[t>>2];I=34}}while(0);if((I|0)==33){B=+g[t>>2];if(u!=B&B!=0.0){M=B;I=34}}if((I|0)==34){B=M*25.5;I=0;do{L=~~(B+ +(I|0));if(L>>>0>255>>>0){N=-L>>31&255}else{N=L&255}a[n+112+I|0]=N;I=I+1|0;}while((I|0)<256)}I=(w|0)!=0;do{if(!I){if(!(+g[t>>2]!=0.0)){w=c[j>>2]|0;iDb(c[x>>2]|0,c[x+32>>2]|0,c[w>>2]|0,c[w+32>>2]|0,c[b+20>>2]|0,c[b+24>>2]|0)}w=c[j>>2]|0;N=c[w+12>>2]|0;if((N|0)==0){break}iDb(c[x+12>>2]|0,c[x+44>>2]|0,N,c[w+44>>2]|0,c[b+20>>2]|0,c[b+24>>2]|0)}}while(0);w=c[x+36>>2]|0;N=c[j>>2]|0;L=c[N+36>>2]|0;K=b+20|0;l=-(c[K>>2]|0)>>c[m+52>>2];A=-l|0;s=b+24|0;b=-(c[s>>2]|0)>>c[m+56>>2];if((b|0)!=0&(l|0)<0){l=c[N+8>>2]|0;m=c[N+4>>2]|0;N=c[x+8>>2]|0;p=c[x+4>>2]|0;E=-b|0;while(1){b=0;do{C=d[m+b|0]|0;v=d[l+b|0]|0;a[p+b|0]=a[n+368+(C<<8)+v|0]|0;a[N+b|0]=a[n+65904+(C<<8)+v|0]|0;b=b+1|0;}while((b|0)<(A|0));b=E-1|0;if((b|0)==0){break}else{l=l+L|0;m=m+L|0;N=N+w|0;p=p+w|0;E=b}}}do{if(+g[t>>2]!=0.0){E=c[x+32>>2]|0;w=c[j>>2]|0;p=c[w+32>>2]|0;N=c[K>>2]|0;L=c[s>>2]|0;if(!((L|0)!=0&(N|0)>0)){break}m=c[w>>2]|0;w=c[x>>2]|0;l=L;while(1){L=0;do{a[w+L|0]=a[(d[m+L|0]|0)+(n+112)|0]|0;L=L+1|0;}while((L|0)<(N|0));L=l-1|0;if((L|0)==0){break}else{m=m+p|0;w=w+E|0;l=L}}}}while(0);if(!I){JCb(j)}c[r>>2]=0;z=cj(o,x)|0;i=f;return z|0}function Lo(a){a=a|0;var b=0,e=0,f=0.0,g=0,i=0,j=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=bFb(c[a+52>>2]|0)|0;c[b+52>>2]=d[e+5|0]|0;c[b+56>>2]=d[e+6|0]|0;h[b+72>>3]=0.0;h[b+104>>3]=+(c[a+56>>2]|0)/+(c[a+60>>2]|0);e=c[a+116>>2]|0;if((e|0)==0){f=+q;g=b+88|0;i=g;h[i>>3]=f;return 0}j=c[a+120>>2]|0;if((j|0)==0){f=+q;g=b+88|0;i=g;h[i>>3]=f;return 0}f=+(e|0)/+(j|0);g=b+88|0;i=g;h[i>>3]=f;return 0}function Mo(b){b=b|0;var d=0;d=c[b+44>>2]|0;c[d+12>>2]=3;b=d+48|0;x=50529027;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[d+64>>2]=388;return 0}function No(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;e=a;a=c[d+20>>2]|0;f=c[d+24>>2]|0;g=c[d+28>>2]|0;yDb(e,32,2168784,(h=i,i=i+32|0,c[h>>2]=c[d+16>>2],c[h+8>>2]=a,c[h+16>>2]=f,c[h+24>>2]=g,h)|0);i=h;g=c[d+36>>2]|0;f=c[d+40>>2]|0;a=c[d+44>>2]|0;yDb(e,32,2095888,(h=i,i=i+32|0,c[h>>2]=c[d+32>>2],c[h+8>>2]=g,c[h+16>>2]=f,c[h+24>>2]=a,h)|0);i=h;JCb(d+60|0);JCb(d+52|0);JCb(d+56|0);i=b;return}function Oo(a){a=a|0;Ok(a,xk(550800)|0);return 0}function Po(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)>0){f=c;g=b;h=0;i=0;j=a}else{k=0;return k|0}while(1){a=(d[f]|0)+(d[j]|0)-((d[g]|0)<<1)|0;b=((a|0)>-1?a:-a|0)+i|0;a=h+1|0;if((a|0)<(e|0)){f=f+1|0;g=g+1|0;h=a;i=b;j=j+1|0}else{k=b;break}}return k|0}function Qo(a){a=a|0;var b=0;b=a+156|0;c[b>>2]=c[b>>2]|1;return 0}function Ro(e,f){e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;h=i;i=i+16|0;j=h|0;k=c[e+8>>2]|0;l=k+44|0;m=c[l>>2]|0;n=m+60|0;if((c[n>>2]|0)!=0){JCb(n)}o=m+52|0;p=c[o>>2]|0;c[n>>2]=p;q=m+56|0;r=c[q>>2]|0;c[o>>2]=r;c[q>>2]=f;if((r|0)==0){s=0;i=h;return s|0}if((p|0)==0){c[n>>2]=PCb(r)|0}r=m+68|0;n=c[r>>2]|0;if((n|0)==0){p=bFb(c[e+52>>2]|0)|0;c[r>>2]=p;t=p}else{t=n}if(!((b[t+8>>1]&16384)==0)){c[m+64>>2]=224}m=c[l>>2]|0;TGb(j|0,0,16)|0;l=m+68|0;t=c[l>>2]|0;if((a[t+4|0]|0)==0){u=0;v=0;w=0.0;x=0.0}else{n=m+52|0;p=m+60|0;r=m+56|0;e=m+64|0;f=0;q=0;y=0;z=t;while(1){t=c[n>>2]|0;A=c[t+68>>2]|0;B=c[t+72>>2]|0;C=c[t+32+(y<<2)>>2]|0;if((y|0)!=0&(y|0)<3){D=-(-B>>d[z+6|0])|0;E=-(-A>>d[z+5|0])|0}else{D=B;E=A}A=D-2|0;if((A|0)>2){B=f;G=q;H=2;I=t;while(1){t=ba(H,C)|0;J=c[I+(y<<2)>>2]|0;K=(c[(c[r>>2]|0)+(y<<2)>>2]|0)+t|0;L=J+(t-C)|0;M=J+(t+C)|0;N=_e[c[e>>2]&1023](L,(c[(c[p>>2]|0)+(y<<2)>>2]|0)+t|0,M,E)|0;O=H&1;P=j+(O<<3)|0;Q=YGb(c[P>>2]|0,c[P+4>>2]|0,N,(N|0)<0|0?-1:0)|0;c[P>>2]=Q;c[P+4>>2]=F;P=_e[c[e>>2]&1023](L,K,M,E)|0;K=j+((O^1)<<3)|0;O=YGb(c[K>>2]|0,c[K+4>>2]|0,P,(P|0)<0|0?-1:0)|0;c[K>>2]=O;c[K+4>>2]=F;K=_e[c[e>>2]&1023](L,J+t|0,M,E)|0;R=YGb(K,(K|0)<0|0?-1:0,G,B)|0;S=F;K=H+1|0;if((K|0)>=(A|0)){break}B=S;G=R;H=K;I=c[n>>2]|0}T=S;U=R;V=c[l>>2]|0}else{T=f;U=q;V=z}I=y+1|0;if((I|0)<(d[V+4|0]|0)){f=T;q=U;y=I;z=V}else{break}}V=j|0;z=j+8|0;u=T;v=U;w=+((c[V>>2]|0)>>>0)+ +(c[V+4>>2]|0)*4294967296.0;x=+((c[z>>2]|0)>>>0)+ +(c[z+4>>2]|0)*4294967296.0}W=+g[m+4>>2];do{if(w>x*W){X=0}else{if(x>w*W){X=1;break}X=x>(+(v>>>0)+ +(u|0)*4294967296.0)*+g[m+8>>2]?2:3}}while(0);u=m+48|0;v=m+49|0;VGb(v|0,u|0,3)|0;z=X&255;a[u]=z;u=z<<24>>24==3;z=u?3:X;V=u&1^1;u=a[v]|0;v=u&255;do{if(u<<24>>24==3){Y=V;Z=z;_=45}else{U=(z|0)==3?v:z;if((v|0)!=(U|0)){$=0;aa=U;break}Y=V+1|0;Z=v;_=45}}while(0);do{if((_|0)==45){v=a[m+50|0]|0;V=v&255;if(v<<24>>24==3){ca=Y;da=Z}else{v=(Z|0)==3?V:Z;if((V|0)!=(v|0)){$=0;aa=v;break}ca=Y+1|0;da=V}V=a[m+51|0]|0;v=V&255;if(V<<24>>24==3){$=ca;aa=da;break}V=(da|0)==3?v:da;$=(v|0)==(V|0)?ca+1|0:0;aa=V}}while(0);ca=m+12|0;da=c[ca>>2]|0;do{if((da|0)==3){if(($|0)==0){break}c[ca>>2]=aa;ea=aa;_=29}else{if(($|0)<=2){ea=da;_=29;break}c[ca>>2]=aa;ea=aa;_=29}}while(0);do{if((_|0)==29){if((ea|0)==2){c[(c[m+52>>2]|0)+296>>2]=0;break}else if((ea|0)==0){aa=c[m+52>>2]|0;c[aa+300>>2]=1;c[aa+296>>2]=1;break}else if((ea|0)==1){aa=c[m+52>>2]|0;c[aa+300>>2]=0;c[aa+296>>2]=1;break}else{break}}}while(0);ea=m+16+(X<<2)|0;c[ea>>2]=(c[ea>>2]|0)+1;ea=m+32+(c[ca>>2]<<2)|0;c[ea>>2]=(c[ea>>2]|0)+1;ea=k;if((X|0)==1){fa=2325960}else if((X|0)==2){fa=2302368}else if((X|0)==3){fa=2284536}else if((X|0)==0){fa=2346832}else{fa=0}X=c[ca>>2]|0;if((X|0)==0){ga=2346832}else if((X|0)==3){ga=2284536}else if((X|0)==2){ga=2302368}else if((X|0)==1){ga=2325960}else{ga=0}yDb(ea,48,1889488,(ea=i,i=i+16|0,c[ea>>2]=fa,c[ea+8>>2]=ga,ea)|0);i=ea;ea=c[c[k+32>>2]>>2]|0;s=cj(ea,PCb(c[o>>2]|0)|0)|0;i=h;return s|0}function So(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)>0){f=c;g=b;h=0;i=0;j=a}else{k=0;return k|0}while(1){a=(e[f>>1]|0)+(e[j>>1]|0)-((e[g>>1]|0)<<1)|0;b=((a|0)>-1?a:-a|0)+i|0;a=h+1|0;if((a|0)<(d|0)){f=f+2|0;g=g+2|0;h=a;i=b;j=j+2|0}else{k=b;break}}return k|0}function To(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=0;do{if((a[(bFb(f)|0)+7|0]&10)==0){zk(e,f,(f|0)<0|0?-1:0)|0}f=f+1|0;}while((f|0)<333);Ok(b,c[e>>2]|0);i=d;return 0}function Uo(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=c[c[f+32>>2]>>2]|0;f=Zr(h,c[h+20>>2]|0,c[h+24>>2]|0)|0;if((f|0)==0){JCb(e);j=-12;i=d;return j|0}NCb(f,b)|0;b=c[f>>2]|0;k=c[e>>2]|0;l=c[k>>2]|0;m=g+32|0;n=m;o=c[m>>2]|0;m=a+24|0;a=c[f+32>>2]|0;p=c[k+32>>2]|0;k=c[g+4>>2]|0;q=c[g+16>>2]|0;r=1-q|0;s=c[m>>2]>>1;do{if((k|0)==2){if((s|0)>0){t=0}else{break}do{u=t<<1;UGb(b+(ba(t,a)|0)|0,l+(ba(u+q|0,p)|0)|0,o)|0;UGb(b+(ba(t+s|0,a)|0)|0,l+(ba(u+r|0,p)|0)|0,o)|0;t=t+1|0;}while((t|0)<(s|0))}else if((k|0)==0){if((s|0)<=0){break}u=a<<1;v=0;do{w=v<<1;UGb(b+(ba(u,v)|0)|0,l+(ba(w+q|0,p)|0)|0,o)|0;UGb(b+(ba(w|1,a)|0)|0,l+(ba(w+r|0,p)|0)|0,o)|0;v=v+1|0;}while((v|0)<(s|0))}else if((k|0)==1){if((s|0)>0){x=0}else{break}do{v=x<<1;UGb(b+(ba(v+q|0,a)|0)|0,l+(ba(x,p)|0)|0,o)|0;UGb(b+(ba(v+r|0,a)|0)|0,l+(ba(x+s|0,p)|0)|0,o)|0;x=x+1|0;}while((x|0)<(s|0))}}while(0);s=g+28|0;x=c[s>>2]|0;o=g+52|0;p=c[o>>2]|0;if((x-p|0)>1){l=g+48|0;a=g+8|0;r=g+20|0;b=1;while(1){q=c[f+(b<<2)>>2]|0;k=c[e>>2]|0;t=c[k+(b<<2)>>2]|0;v=c[n+(b<<2)>>2]|0;u=c[f+32+(b<<2)>>2]|0;w=c[k+32+(b<<2)>>2]|0;k=c[a>>2]|0;y=c[r>>2]|0;z=1-y|0;A=c[l>>2]>>1;do{if((k|0)==2){if((A|0)>0){B=0}else{break}do{C=B<<1;UGb(q+(ba(B,u)|0)|0,t+(ba(C+y|0,w)|0)|0,v)|0;UGb(q+(ba(B+A|0,u)|0)|0,t+(ba(C+z|0,w)|0)|0,v)|0;B=B+1|0;}while((B|0)<(A|0))}else if((k|0)==1){if((A|0)>0){D=0}else{break}do{C=D<<1;UGb(q+(ba(C+y|0,u)|0)|0,t+(ba(D,w)|0)|0,v)|0;UGb(q+(ba(C+z|0,u)|0)|0,t+(ba(D+A|0,w)|0)|0,v)|0;D=D+1|0;}while((D|0)<(A|0))}else if((k|0)==0){if((A|0)<=0){break}C=u<<1;E=0;do{F=E<<1;UGb(q+(ba(C,E)|0)|0,t+(ba(F+y|0,w)|0)|0,v)|0;UGb(q+(ba(F|1,u)|0)|0,t+(ba(F+z|0,w)|0)|0,v)|0;E=E+1|0;}while((E|0)<(A|0))}}while(0);A=b+1|0;v=c[s>>2]|0;w=c[o>>2]|0;if((A|0)<(v-w|0)){b=A}else{G=v;H=w;break}}}else{G=x;H=p}do{if((H|0)!=0){p=G-1|0;x=c[f+(p<<2)>>2]|0;b=c[e>>2]|0;o=c[b+(p<<2)>>2]|0;s=c[n+(p<<2)>>2]|0;D=c[f+32+(p<<2)>>2]|0;B=c[b+32+(p<<2)>>2]|0;p=c[g+12>>2]|0;b=c[g+24>>2]|0;l=1-b|0;r=c[m>>2]>>1;if((p|0)==0){if((r|0)<=0){break}a=D<<1;w=0;do{v=w<<1;UGb(x+(ba(a,w)|0)|0,o+(ba(v+b|0,B)|0)|0,s)|0;UGb(x+(ba(v|1,D)|0)|0,o+(ba(v+l|0,B)|0)|0,s)|0;w=w+1|0;}while((w|0)<(r|0))}else if((p|0)==2){if((r|0)>0){I=0}else{break}do{w=I<<1;UGb(x+(ba(I,D)|0)|0,o+(ba(w+b|0,B)|0)|0,s)|0;UGb(x+(ba(I+r|0,D)|0)|0,o+(ba(w+l|0,B)|0)|0,s)|0;I=I+1|0;}while((I|0)<(r|0))}else if((p|0)==1){if((r|0)>0){J=0}else{break}do{w=J<<1;UGb(x+(ba(w+b|0,D)|0)|0,o+(ba(J,B)|0)|0,s)|0;UGb(x+(ba(w+l|0,D)|0)|0,o+(ba(J+r|0,B)|0)|0,s)|0;J=J+1|0;}while((J|0)<(r|0))}else{break}}}while(0);JCb(e);j=cj(h,f)|0;i=d;return j|0}function Vo(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=bFb(c[e>>2]|0)|0;c[b+28>>2]=fFb(c[e>>2]|0)|0;c[b+52>>2]=(d[f+7|0]|0)>>>7&255;g=dDb(b+32|0,c[e>>2]|0,c[a+20>>2]|0)|0;if((g|0)<0){h=g;return h|0}c[b+48>>2]=-(-(c[a+24>>2]|0)>>(d[f+6|0]|0));h=0;return h|0}function Wo(a){a=a|0;return 0}function Xo(a){a=a|0;var b=0;b=c[a+44>>2]|0;a=b+1044|0;IBb(c[a>>2]|0);c[a>>2]=0;$Db(b+1028|0);a=b+1048|0;IBb(c[a>>2]|0);c[a>>2]=0;$Db(b+1032|0);a=b+1052|0;IBb(c[a>>2]|0);c[a>>2]=0;$Db(b+1036|0);a=b+1056|0;IBb(c[a>>2]|0);c[a>>2]=0;$Db(b+1040|0);return}function Yo(a){a=a|0;var b=0,d=0;b=c[a+44>>2]|0;if((c[b+1128>>2]|0)==0){d=(c[b+1132>>2]|0)!=0?840:1798608}else{d=547800}Ok(a,xk(d)|0);return 0}function Zo(a){a=a|0;c[(c[a+44>>2]|0)+1132>>2]=1;return 0}function _o(a){a=a|0;c[(c[a+44>>2]|0)+1128>>2]=1;return 0}function $o(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+44|0;e=c[d>>2]|0;f=e+1140|0;yDb(a,48,1909656,(a=i,i=i+8|0,c[a>>2]=c[f>>2],a)|0);i=a;a=e+1028|0;e=0;while(1){if((e|0)>=4){g=0;h=7;break}if((e|0)==3){j=(c[f>>2]|0)!=0?2346736:1889392}else{j=2346736}k=eEb(j)|0;c[a+(e<<2)>>2]=k;if((k|0)==0){break}else{e=e+1|0}}if((h|0)==7){i=b;return g|0}h=c[d>>2]|0;d=h+1044|0;IBb(c[d>>2]|0);c[d>>2]=0;$Db(h+1028|0);d=h+1048|0;IBb(c[d>>2]|0);c[d>>2]=0;$Db(h+1032|0);d=h+1052|0;IBb(c[d>>2]|0);c[d>>2]=0;$Db(h+1036|0);d=h+1056|0;IBb(c[d>>2]|0);c[d>>2]=0;$Db(h+1040|0);g=-12;i=b;return g|0}function ap(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=c[b+8>>2]|0;j=c[h+44>>2]|0;k=c[c[h+32>>2]>>2]|0;do{if((RCb(e)|0)==0){h=Zr(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((h|0)!=0){NCb(h,c[g>>2]|0)|0;l=h;m=0;break}JCb(g);n=-12;i=f;return n|0}else{l=e;m=1}}while(0);a:do{if((c[j+1128>>2]|0)==0){e=j+1064|0;h=j+1060|0;o=b+24|0;p=b+20|0;q=j+4|0;r=0;s=c[g>>2]|0;while(1){t=c[s+(r<<2)>>2]|0;if((t|0)==0){break a}if((c[s+32+(r<<2)>>2]|0)==0){break a}if((r-1|0)>>>0<2>>>0){u=c[h>>2]|0;v=c[e>>2]|0}else{u=0;v=0}w=-(c[o>>2]|0)>>v;x=-w|0;y=-(c[p>>2]|0)>>u;z=-y|0;do{if((w|0)<0){A=l+32+(r<<2)|0;if((y|0)<0){B=0;C=c[l+(r<<2)>>2]|0;D=t}else{E=s;break}while(1){F=0;do{a[C+F|0]=a[(d[D+F|0]|0)+(q+(r<<8))|0]|0;F=F+1|0;}while((F|0)<(z|0));F=c[g>>2]|0;G=B+1|0;if((G|0)<(x|0)){B=G;C=C+(c[A>>2]|0)|0;D=D+(c[F+32+(r<<2)>>2]|0)|0}else{E=F;break}}}else{E=s}}while(0);x=r+1|0;if((x|0)<4){r=x;s=E}else{break}}}else{s=c[g>>2]|0;if((c[s+72>>2]|0)<=0){break}r=b+20|0;q=l+32|0;p=j+1136|0;o=1;e=c[l>>2]|0;h=c[s>>2]|0;x=s;while(1){s=c[r>>2]|0;if((s|0)>0){z=0;t=e;y=h;w=c[p>>2]|0;while(1){if((w|0)==4){a[t+3|0]=a[j+((d[y+3|0]|0)+772)|0]|0;H=13}else if((w|0)==3){H=13}else if((w|0)==2){H=14}if((H|0)==13){H=0;a[t+2|0]=a[j+((d[y+2|0]|0)+516)|0]|0;H=14}if((H|0)==14){H=0;a[t+1|0]=a[j+((d[y+1|0]|0)+260)|0]|0}a[t]=a[j+((d[y]|0)+4)|0]|0;A=c[p>>2]|0;F=z+1|0;if((F|0)<(s|0)){z=F;t=t+A|0;y=y+A|0;w=A}else{break}}I=c[g>>2]|0}else{I=x}if((o|0)>=(c[I+72>>2]|0)){break a}o=o+1|0;e=e+(c[q>>2]|0)|0;h=h+(c[I+32>>2]|0)|0;x=I}}}while(0);if((m|0)==0){JCb(g)}n=cj(k,l)|0;i=f;return n|0}function bp(b){b=b|0;var e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0.0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+40|0;f=e|0;g=e+8|0;j=e+24|0;l=c[b+8>>2]|0;m=c[l+44>>2]|0;n=b+52|0;o=bFb(c[n>>2]|0)|0;c[m+1060>>2]=d[o+5|0]|0;c[m+1064>>2]=d[o+6|0]|0;p=m+1072|0;h[p>>3]=+(c[b+20>>2]|0);h[m+1080>>3]=+(c[b+24>>2]|0);switch(c[n>>2]|0){case 6:case 7:case 0:case 4:case 33:case 5:case 35:case 300:case 299:{c[g+8>>2]=16;c[g+4>>2]=16;c[g>>2]=16;c[j>>2]=235;c[j+8>>2]=240;c[j+4>>2]=240;c[g+12>>2]=0;c[j+12>>2]=255;break};default:{TGb(g|0,0,16)|0;c[j+12>>2]=255;c[j+8>>2]=255;c[j+4>>2]=255;c[j>>2]=255}}b=m+1128|0;c[b>>2]=0;q=m+1132|0;c[q>>2]=0;do{if((wk(c[n>>2]|0,840)|0)==0){if((wk(c[n>>2]|0,547800)|0)==0){r=8;break}c[b>>2]=1;r=9}else{c[q>>2]=1;r=8}}while(0);if((r|0)==8){if((c[b>>2]|0)!=0){r=9}}if((r|0)==9){Aw(f|0,c[n>>2]|0)|0;c[m+1136>>2]=($Eb(o)|0)>>3}n=o+4|0;if((a[n]|0)==0){s=0;i=e;return s|0}o=m+1044|0;q=m+1028|0;t=l;l=m+1096|0;u=m+1104|0;v=m+1088|0;w=m+1120|0;x=m+1112|0;y=m+4|0;z=0;a:while(1){if((c[b>>2]|0)==0){A=z}else{A=d[f+z|0]|0}B=o+(z<<2)|0;IBb(c[B>>2]|0);c[B>>2]=0;C=q+(z<<2)|0;if((JBb(B,c[C>>2]|0,160224,1040888,1040904,0,0,0,t)|0)<0){r=15;break}D=c[j+(z<<2)>>2]|0;h[l>>3]=+(D|0);E=c[g+(z<<2)>>2]|0;h[u>>3]=+(E|0);F=+(D+E|0);G=0;while(1){H=+(G|0);h[v>>3]=H;if((G|0)<(E|0)){I=E}else{I=(G|0)>(D|0)?D:G}h[w>>3]=+(I|0);J=~~(F-H);if((J|0)<(E|0)){K=E}else{K=(J|0)>(D|0)?D:J}h[x>>3]=+(K|0);H=+MBb(c[B>>2]|0,p,m);h[k>>3]=H;J=c[k+4>>2]&2147483647;L=2146435072;if(J>>>0>L>>>0|J>>>0==L>>>0&(c[k>>2]|0)>>>0>0>>>0){r=22;break a}L=~~H;if((L|0)<(E|0)){M=E}else{M=(L|0)>(D|0)?D:L}a[y+(A<<8)+G|0]=M;yDb(t,48,2071856,(N=i,i=i+24|0,c[N>>2]=A,c[N+8>>2]=G,c[N+16>>2]=M&255,N)|0);i=N;L=G+1|0;if((L|0)<256){G=L}else{break}}D=z+1|0;if((D|0)<(d[n]|0)){z=D}else{s=0;r=27;break}}if((r|0)==15){yDb(t,16,2082160,(N=i,i=i+24|0,c[N>>2]=c[q+(A<<2)>>2],c[N+8>>2]=A,c[N+16>>2]=z,N)|0);i=N;s=-22;i=e;return s|0}else if((r|0)==22){yDb(t,16,2076240,(N=i,i=i+24|0,c[N>>2]=c[C>>2],c[N+8>>2]=G,c[N+16>>2]=A,N)|0);i=N;s=-22;i=e;return s|0}else if((r|0)==27){i=e;return s|0}return 0}function cp(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0.0;c=~~b;d=~~+h[a+1104>>3];e=~~+h[a+1096>>3];if((c|0)<(d|0)){f=d;g=+(f|0);return+g}f=(c|0)>(e|0)?e:c;g=+(f|0);return+g}function dp(a,b){a=a|0;b=+b;var c=0.0,d=0.0;c=+h[a+1104>>3];d=+h[a+1096>>3]-c;return+(c+d*+S(+((+h[a+1120>>3]-c)/d),+b))}function ep(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0.0,U=0.0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;d=i;i=i+632|0;e=d|0;f=d+16|0;j=d+24|0;k=d+32|0;l=d+40|0;m=d+552|0;n=d+568|0;o=b+44|0;p=c[o>>2]|0;q=p+8|0;r=c[q>>2]|0;if((r|0)==0){s=p;c[p+3145752>>2]=32;t=0;while(1){u=+(t|0)*.032258063554763794;v=0;do{w=+(v|0)*.032258063554763794;x=0;do{g[s+24+(t*49152|0)+(v*768|0)+(x*12|0)>>2]=u;g[s+24+(t*49152|0)+(v*768|0)+(x*12|0)+4>>2]=w;g[s+24+(t*49152|0)+(v*768|0)+(x*12|0)+8>>2]=+(x|0)*.032258063554763794;x=x+1|0;}while((x|0)<32);v=v+1|0;}while((v|0)<32);v=t+1|0;if((v|0)<32){t=v}else{y=0;break}}i=d;return y|0}t=Kc(r|0,2130688)|0;if((t|0)==0){r=-(c[(ld()|0)>>2]|0)|0;s=c[q>>2]|0;v=n|0;TGb(v|0,0,64)|0;a[v]=0;GBb(r,v,64)|0;yDb(b,16,2124248,(z=i,i=i+16|0,c[z>>2]=s,c[z+8>>2]=v,z)|0);i=z;y=r;i=d;return y|0}r=cc(c[q>>2]|0,46)|0;a:do{if((r|0)==0){yDb(b,16,2118784,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529}else{q=r+1|0;b:do{if((yAb(q,2111712)|0)==0){c[p+3145752>>2]=33;v=l|0;s=c[o>>2]|0;n=c[s+3145752>>2]|0;if((n|0)<=0){break}x=s+24|0;s=0;c:while(1){B=0;do{C=0;do{if((Tb(v|0,512,t|0)|0)==0){break c}else{D=v}while(1){E=a[D]|0;if(!(E<<24>>24==0)){if((EAb(E<<24>>24)|0)!=0){D=D+1|0;continue}E=a[D]|0;if(!((E<<24>>24|0)==0|(E<<24>>24|0)==35)){break}}if((Tb(v|0,512,t|0)|0)==0){break c}else{D=v}}xd(v|0,2038680,(z=i,i=i+24|0,c[z>>2]=x+(s*49152|0)+(B*768|0)+(C*12|0),c[z+8>>2]=x+(s*49152|0)+(B*768|0)+(C*12|0)+4,c[z+16>>2]=x+(s*49152|0)+(B*768|0)+(C*12|0)+8,z)|0)|0;i=z;C=C+1|0;}while((C|0)<(n|0));B=B+1|0;}while((B|0)<(n|0));s=s+1|0;if((s|0)>=(n|0)){break b}}yDb(b,16,2042752,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}else{if((yAb(q,2098040)|0)==0){n=l|0;s=c[o>>2]|0;c[s+3145752>>2]=17;d:do{if((Tb(n|0,512,t|0)|0)!=0){x=n;while(1){v=a[x]|0;if(!(v<<24>>24==0)){if((EAb(v<<24>>24)|0)!=0){x=x+1|0;continue}v=a[x]|0;if(!((v<<24>>24|0)==0|(v<<24>>24|0)==35)){break}}if((Tb(n|0,512,t|0)|0)==0){break d}else{x=n}}x=s+24|0;v=0;e:while(1){B=0;do{C=0;do{if((Tb(n|0,512,t|0)|0)==0){break e}else{F=n}while(1){E=a[F]|0;if(!(E<<24>>24==0)){if((EAb(E<<24>>24)|0)!=0){F=F+1|0;continue}E=a[F]|0;if(!((E<<24>>24|0)==0|(E<<24>>24|0)==35)){break}}if((Tb(n|0,512,t|0)|0)==0){break e}else{F=n}}E=xd(n|0,2012816,(z=i,i=i+24|0,c[z>>2]=f,c[z+8>>2]=j,c[z+16>>2]=k,z)|0)|0;i=z;if((E|0)!=3){A=-1094995529;break a}g[x+(v*49152|0)+(B*768|0)+(C*12|0)>>2]=+(c[f>>2]|0)*.000244140625;g[x+(v*49152|0)+(B*768|0)+(C*12|0)+4>>2]=+(c[j>>2]|0)*.000244140625;g[x+(v*49152|0)+(B*768|0)+(C*12|0)+8>>2]=+(c[k>>2]|0)*.000244140625;C=C+1|0;}while((C|0)<17);B=B+1|0;}while((B|0)<17);v=v+1|0;if((v|0)>=17){break b}}yDb(b,16,2042752,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}}while(0);yDb(b,16,2042752,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}if((yAb(q,2091968)|0)==0){n=l|0;s=e;v=c[o>>2]|0;TGb(m|0,0,12)|0;c[s>>2]=c[148170];c[s+4>>2]=c[148171];c[s+8>>2]=c[148172];do{if((Tb(n|0,512,t|0)|0)==0){break b}}while((RGb(n,2035464,12)|0)!=0);s=kb(l+12|0,0,0)|0;if((s-2|0)>>>0>62>>>0){yDb(b,16,2031536,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-22;break a}c[v+3145752>>2]=s;if((s|0)<=0){break}x=v+24|0;B=l+7|0;C=m|0;E=l+11|0;G=b;H=m+4|0;I=m+8|0;J=e|0;K=e+4|0;L=e+8|0;M=0;f:while(1){N=0;do{O=0;do{if((Tb(n|0,512,t|0)|0)==0){break f}while(1){if((RGb(n,2027392,7)|0)==0){if((RGb(B,2023936,4)|0)==0){P=C}else{Q=(RGb(B,2020568,4)|0)==0;R=Q?J:0;if((R|0)==0){A=-1094995529;break a}else{P=R}}xd(E|0,2038680,(z=i,i=i+24|0,c[z>>2]=P,c[z+8>>2]=P+4,c[z+16>>2]=P+8,z)|0)|0;i=z;u=+g[H>>2];w=+g[I>>2];S=+g[J>>2];T=+g[K>>2];U=+g[L>>2];yDb(G,48,2016680,(z=i,i=i+48|0,h[z>>3]=+g[C>>2],h[z+8>>3]=u,h[z+16>>3]=w,h[z+24>>3]=S,h[z+32>>3]=T,h[z+40>>3]=U,z)|0);i=z;V=n}else{V=n}while(1){R=a[V]|0;if(R<<24>>24==0){break}if((EAb(R<<24>>24)|0)==0){W=64;break}else{V=V+1|0}}if((W|0)==64){W=0;R=a[V]|0;if(!((R<<24>>24|0)==0|(R<<24>>24|0)==35)){break}}if((Tb(n|0,512,t|0)|0)==0){break f}}R=x+(O*49152|0)+(N*768|0)+(M*12|0)|0;Q=x+(O*49152|0)+(N*768|0)+(M*12|0)+4|0;X=x+(O*49152|0)+(N*768|0)+(M*12|0)+8|0;Y=xd(n|0,2038680,(z=i,i=i+24|0,c[z>>2]=R,c[z+8>>2]=Q,c[z+16>>2]=X,z)|0)|0;i=z;if((Y|0)!=3){A=-1094995529;break a}g[R>>2]=+g[R>>2]*(+g[J>>2]- +g[C>>2]);g[Q>>2]=+g[Q>>2]*(+g[K>>2]- +g[H>>2]);g[X>>2]=+g[X>>2]*(+g[L>>2]- +g[I>>2]);O=O+1|0;}while((O|0)<(s|0));N=N+1|0;}while((N|0)<(s|0));M=M+1|0;if((M|0)>=(s|0)){break b}}yDb(G,16,2042752,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}if((yAb(q,2086848)|0)!=0){yDb(b,16,2082120,(z=i,i=i+8|0,c[z>>2]=q,z)|0);i=z;A=-22;break a}s=l|0;M=c[o>>2]|0;I=l+3|0;L=l+2|0;H=-1;K=-1;g:while(1){Z=H;h:while(1){while(1){if((Tb(s|0,512,t|0)|0)==0){_=0;$=1;aa=2;break g}if((RGb(s,2071840,2)|0)==0){break h}if((RGb(s,2067128,3)|0)==0){break}if((RGb(s,2062864,6)|0)==0){W=80;break g}}Z=kb(I|0,0,0)|0}H=Z;K=kb(L|0,0,0)|0}i:do{if((W|0)==80){L=l+6|0;while(1){if((EAb(a[L]|0)|0)==0){break}else{L=L+1|0}}H=a[L]|0;I=H<<24>>24;if((I|0)==103){ca=1}else if((I|0)==98){ca=2}else{ca=0}j:do{if(H<<24>>24==0){da=L}else{I=H;G=L;while(1){C=G+1|0;if((EAb(I<<24>>24)|0)!=0){da=G;break j}J=a[C]|0;if(J<<24>>24==0){da=C;break}else{I=J;G=C}}}}while(0);while(1){if((EAb(a[da]|0)|0)==0){break}da=da+1|0}L=a[da]|0;H=L<<24>>24;if((H|0)==114){ea=0}else if((H|0)==98){ea=2}else{ea=1}k:do{if(L<<24>>24==0){fa=da}else{H=L;G=da;while(1){I=G+1|0;if((EAb(H<<24>>24)|0)!=0){fa=G;break k}C=a[I]|0;if(C<<24>>24==0){fa=I;break}else{H=C;G=I}}}}while(0);while(1){if((EAb(a[fa]|0)|0)==0){break}fa=fa+1|0}L=a[fa]|0;G=L<<24>>24;if((G|0)==114){ga=0}else if((G|0)==103){ga=1}else{ga=2}if(L<<24>>24==0){_=ca;$=ea;aa=ga;break}else{ha=L;ia=fa}while(1){L=ia+1|0;if((EAb(ha<<24>>24)|0)!=0){_=ca;$=ea;aa=ga;break i}G=a[L]|0;if(G<<24>>24==0){_=ca;$=ea;aa=ga;break}else{ha=G;ia=L}}}}while(0);if((K|0)==-1|(Z|0)==-1){yDb(b,16,2059128,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}if((K|0)<2|(Z|0)<2|(K|0)>262144|(Z|0)>262144){yDb(b,16,2053192,(z=i,i=i+16|0,c[z>>2]=K,c[z+8>>2]=Z,z)|0);i=z;A=-1094995529;break a}else{ja=1}while(1){if((ba(ba(ja,ja)|0,ja)|0)<(K|0)){ja=ja+1|0}else{break}}c[M+3145752>>2]=ja;U=1.0/+(Z-1|0);if((ja|0)<=0){break}K=M+24|0;L=m|0;G=m+4|0;H=m+8|0;I=m+((_&255)<<2)|0;C=m+(($&255)<<2)|0;J=m+((aa&255)<<2)|0;n=0;l:while(1){x=0;do{E=0;do{if((Tb(s|0,512,t|0)|0)==0){break l}B=xd(s|0,2038680,(z=i,i=i+24|0,c[z>>2]=L,c[z+8>>2]=G,c[z+16>>2]=H,z)|0)|0;i=z;if((B|0)!=3){A=-1094995529;break a}g[K+(n*49152|0)+(x*768|0)+(E*12|0)>>2]=U*+g[I>>2];g[K+(n*49152|0)+(x*768|0)+(E*12|0)+4>>2]=U*+g[C>>2];g[K+(n*49152|0)+(x*768|0)+(E*12|0)+8>>2]=U*+g[J>>2];E=E+1|0;}while((E|0)<(ja|0));x=x+1|0;}while((x|0)<(ja|0));n=n+1|0;if((n|0)>=(ja|0)){break b}}yDb(b,16,2042752,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}}while(0);if((c[p+3145752>>2]|0)!=0){A=0;break}yDb(b,16,2076216,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529}}while(0);fb(t|0)|0;y=A;i=d;return y|0}function fp(a){a=a|0;Ok(a,xk(550736)|0);return 0}function gp(a){a=a|0;c[(c[a+44>>2]|0)+3146200>>2]=120;return 0}function hp(a){a=a|0;Lw((c[a+44>>2]|0)+3145776|0);return}function ip(a,b,f){a=a|0;b=b|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=c[c[a+16>>2]>>2]|0;i=c[a+44>>2]|0;a=i;j=c[f>>2]|0;k=c[f+32>>2]|0;f=c[i+3145768>>2]|0;l=c[i+3145760>>2]|0;m=i+3145756|0;n=c[i+3145752>>2]|0;o=(n|0)>0;if((c[i+3145764>>2]|0)==0){if(!o){p=h+8|0;q=c[p>>2]|0;r=jp(q,b)|0;return r|0}s=i+3145757|0;t=i+3145758|0;u=0;v=0;w=0;while(1){x=u;y=v;z=0;while(1){A=x;B=y;C=0;do{D=(ba(A,k)|0)+(ba(B,l)|0)|0;g[a+24+(w*49152|0)+(z*768|0)+(C*12|0)>>2]=+(d[j+((d[m]|0)+D)|0]|0|0)/255.0;g[a+24+(w*49152|0)+(z*768|0)+(C*12|0)+4>>2]=+(d[j+((d[s]|0)+D)|0]|0|0)/255.0;g[a+24+(w*49152|0)+(z*768|0)+(C*12|0)+8>>2]=+(d[j+((d[t]|0)+D)|0]|0|0)/255.0;D=B+1|0;E=(D|0)==(f|0);A=(E&1)+A|0;B=E?0:D;C=C+1|0;}while((C|0)<(n|0));C=z+1|0;if((C|0)<(n|0)){x=A;y=B;z=C}else{break}}z=w+1|0;if((z|0)<(n|0)){u=A;v=B;w=z}else{break}}p=h+8|0;q=c[p>>2]|0;r=jp(q,b)|0;return r|0}else{if(!o){p=h+8|0;q=c[p>>2]|0;r=jp(q,b)|0;return r|0}o=i+3145757|0;w=i+3145758|0;i=0;B=0;v=0;while(1){A=0;u=B;t=v;while(1){s=0;F=u;G=t;do{z=j+((ba(F,l)|0)+(ba(G,k)|0))|0;g[a+24+(i*49152|0)+(A*768|0)+(s*12|0)>>2]=+(e[z+((d[m]|0)<<1)>>1]|0|0)/65535.0;g[a+24+(i*49152|0)+(A*768|0)+(s*12|0)+4>>2]=+(e[z+((d[o]|0)<<1)>>1]|0|0)/65535.0;g[a+24+(i*49152|0)+(A*768|0)+(s*12|0)+8>>2]=+(e[z+((d[w]|0)<<1)>>1]|0|0)/65535.0;z=F+1|0;y=(z|0)==(f|0);F=y?0:z;G=(y&1)+G|0;s=s+1|0;}while((s|0)<(n|0));s=A+1|0;if((s|0)<(n|0)){A=s;u=F;t=G}else{break}}t=i+1|0;if((t|0)<(n|0)){i=t;B=F;v=G}else{break}}p=h+8|0;q=c[p>>2]|0;r=jp(q,b)|0;return r|0}return 0}function jp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+44>>2]|0;h=c[c[a+32>>2]>>2]|0;do{if((RCb(b)|0)==0){j=h+24|0;k=Zr(h,c[h+20>>2]|0,c[j>>2]|0)|0;if((k|0)!=0){NCb(k,c[e>>2]|0)|0;l=k;m=c[e>>2]|0;n=j;break}JCb(e);o=0;i=d;return o|0}else{l=b;m=b;n=h+24|0}}while(0);c[f>>2]=m;c[f+4>>2]=l;m=c[n>>2]|0;n=c[(c[a+48>>2]|0)+28>>2]|0;Pe[c[c[a+56>>2]>>2]&255](a,c[g+20>>2]|0,f,0,(m|0)>(n|0)?n:m)|0;if((l|0)==(c[e>>2]|0)){o=l;i=d;return o|0}JCb(e);o=l;i=d;return o|0}function kp(a){a=a|0;return Kw((c[(c[a>>2]|0)+44>>2]|0)+3145776|0,a)|0}function lp(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=c[c[b+16>>2]>>2]|0;c[a+20>>2]=c[e+20>>2];c[a+24>>2]=c[e+24>>2];f=e+56|0;e=a+56|0;a=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=a;a=Hw(b,d+3145776|0)|0;return((a|0)<0?a:0)|0}function mp(a,b){a=a|0;b=b|0;return Jw((c[(c[a+8>>2]|0)+44>>2]|0)+3145776|0,a,b)|0}function np(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;a=bFb(c[e>>2]|0)|0;f=c[e>>2]|0;if((f|0)==42|(f|0)==68|(f|0)==292|(f|0)==294){g=1}else{g=0}Aw(d+12|0,f)|0;c[d+16>>2]=(aFb(a)|0)>>g+3;a=c[d+4>>2]|0;if((a|0)==1){f=d+20|0;if((g|0)==0){c[f>>2]=178;i=b;return 0}else{c[f>>2]=660;i=b;return 0}}else if((a|0)==2){f=d+20|0;if((g|0)==0){c[f>>2]=182;i=b;return 0}else{c[f>>2]=436;i=b;return 0}}else if((a|0)==0){a=d+20|0;if((g|0)==0){c[a>>2]=394;i=b;return 0}else{c[a>>2]=266;i=b;return 0}}else{yDb(0,0,2163224,(b=i,i=i+24|0,c[b>>2]=2137192,c[b+8>>2]=2149456,c[b+16>>2]=492,b)|0);i=b;Cd();return 0}return 0}function op(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=a+52|0;g=bFb(c[f>>2]|0)|0;h=e+3145764|0;c[h>>2]=0;j=c[f>>2]|0;if((j|0)==42|(j|0)==68|(j|0)==292|(j|0)==294){c[h>>2]=1}c[e+3145760>>2]=(aFb(g)|0)>>3;Aw(e+3145756|0,c[f>>2]|0)|0;f=a+20|0;g=c[f>>2]|0;h=a+24|0;a=c[h>>2]|0;do{if((g|0)>(a|0)){yDb(d,32,2198448,(k=i,i=i+8|0,c[k>>2]=g-a,k)|0);i=k}else{if((g|0)>=(a|0)){break}yDb(d,32,2188776,(k=i,i=i+8|0,c[k>>2]=a-g,k)|0);i=k}}while(0);g=c[f>>2]|0;f=c[h>>2]|0;h=(g|0)>(f|0)?f:g;c[e+3145768>>2]=h;g=1;while(1){l=ba(g,g)|0;m=ba(l,g)|0;if((m|0)<(h|0)){g=g+1|0}else{break}}if((m|0)!=(h|0)){yDb(d,24,2172480,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;n=-1094995529;i=b;return n|0}if(l>>>0>64>>>0){yDb(d,16,2142688,(k=i,i=i+24|0,c[k>>2]=8,c[k+8>>2]=512,c[k+16>>2]=512,k)|0);i=k;n=-22;i=b;return n|0}else{c[e+3145752>>2]=l;n=0;i=b;return n|0}return 0}function pp(a,f,h,i){a=a|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0;j=c[a+44>>2]|0;a=j;k=c[f>>2]|0;l=c[f+4>>2]|0;f=c[j+16>>2]|0;m=c[k+72>>2]|0;n=(ba(m,h)|0)/(i|0)|0;o=(ba(m,h+1|0)|0)/(i|0)|0;if((n|0)>=(o|0)){return 0}i=c[k+32>>2]|0;h=c[l+32>>2]|0;m=ba(i,n)|0;p=ba(h,n)|0;q=j+3145752|0;r=d[j+12|0]|0;s=d[j+13|0]|0;t=d[j+14|0]|0;u=(l|0)!=(k|0)&(f|0)==4;v=d[j+15|0]|0;j=c[k+68>>2]|0;w=(c[k>>2]|0)+m|0;m=(c[l>>2]|0)+p|0;p=n;while(1){n=m;l=w;k=ba(j,f)|0;if((k|0)>0){x=c[q>>2]|0;y=0;do{z=+(x-1|0)*15259021896696422.0e-21;A=y+r|0;B=y+s|0;C=y+t|0;D=~~(z*+(e[l+(C<<1)>>1]|0|0)+.5);E=~~(+(e[l+(B<<1)>>1]|0|0)*z+.5);F=~~(+(e[l+(A<<1)>>1]|0|0)*z+.5);z=+g[a+24+(F*49152|0)+(E*768|0)+(D*12|0)+4>>2];G=+g[a+24+(F*49152|0)+(E*768|0)+(D*12|0)+8>>2];H=~~(+g[a+24+(F*49152|0)+(E*768|0)+(D*12|0)>>2]*65535.0);if(H>>>0>65535>>>0){I=-H>>31&65535}else{I=H&65535}b[n+(A<<1)>>1]=I;A=~~(z*65535.0);if(A>>>0>65535>>>0){J=-A>>31&65535}else{J=A&65535}b[n+(B<<1)>>1]=J;B=~~(G*65535.0);if(B>>>0>65535>>>0){K=-B>>31&65535}else{K=B&65535}b[n+(C<<1)>>1]=K;if(u){C=y+v|0;b[n+(C<<1)>>1]=b[l+(C<<1)>>1]|0}y=y+f|0;}while((y|0)<(k|0))}k=p+1|0;if((k|0)<(o|0)){w=w+i|0;m=m+h|0;p=k}else{break}}return 0}function qp(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;i=c[b+44>>2]|0;b=i;j=c[e>>2]|0;k=c[e+4>>2]|0;e=c[i+16>>2]|0;l=c[j+72>>2]|0;m=(ba(l,f)|0)/(h|0)|0;n=(ba(l,f+1|0)|0)/(h|0)|0;h=k+32|0;f=j+32|0;if((m|0)>=(n|0)){return 0}l=c[f>>2]|0;o=c[h>>2]|0;p=ba(l,m)|0;q=ba(o,m)|0;r=j+68|0;s=i+3145752|0;t=d[i+12|0]|0;u=d[i+13|0]|0;v=d[i+14|0]|0;w=(k|0)!=(j|0)&(e|0)==4;x=d[i+15|0]|0;i=(c[j>>2]|0)+p|0;p=(c[k>>2]|0)+q|0;q=m;m=c[r>>2]|0;k=o;o=l;while(1){if((ba(m,e)|0)>0){l=0;do{y=+((c[s>>2]|0)-1|0)*.00392156862745098;j=l+t|0;z=l+u|0;A=l+v|0;B=~~(y*+(d[i+A|0]|0|0)+.5);C=~~(+(d[i+z|0]|0|0)*y+.5);D=~~(+(d[i+j|0]|0|0)*y+.5);y=+g[b+24+(D*49152|0)+(C*768|0)+(B*12|0)+4>>2];E=+g[b+24+(D*49152|0)+(C*768|0)+(B*12|0)+8>>2];F=~~(+g[b+24+(D*49152|0)+(C*768|0)+(B*12|0)>>2]*255.0);if(F>>>0>255>>>0){G=-F>>31&255}else{G=F&255}a[p+j|0]=G;j=~~(y*255.0);if(j>>>0>255>>>0){H=-j>>31&255}else{H=j&255}a[p+z|0]=H;z=~~(E*255.0);if(z>>>0>255>>>0){I=-z>>31&255}else{I=z&255}a[p+A|0]=I;if(w){A=l+x|0;a[p+A|0]=a[i+A|0]|0}l=l+e|0;J=c[r>>2]|0;}while((l|0)<(ba(J,e)|0));K=J;L=c[h>>2]|0;M=c[f>>2]|0}else{K=m;L=k;M=o}l=q+1|0;if((l|0)<(n|0)){i=i+M|0;p=p+L|0;q=l;m=K;k=L;o=M}else{break}}return 0}function rp(a,f,h,j){a=a|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=i;i=i+16|0;l=k|0;m=c[a+44>>2]|0;a=m;n=c[f>>2]|0;o=c[f+4>>2]|0;f=c[m+16>>2]|0;p=c[n+72>>2]|0;q=(ba(p,h)|0)/(j|0)|0;r=(ba(p,h+1|0)|0)/(j|0)|0;j=o+32|0;h=n+32|0;if((q|0)>=(r|0)){i=k;return 0}p=c[h>>2]|0;s=c[j>>2]|0;t=ba(p,q)|0;u=ba(s,q)|0;v=n+68|0;w=m+3145752|0;x=d[m+12|0]|0;y=d[m+13|0]|0;z=d[m+14|0]|0;A=l|0;B=l+4|0;C=l+8|0;D=(o|0)!=(n|0)&(f|0)==4;E=d[m+15|0]|0;m=(c[n>>2]|0)+t|0;t=(c[o>>2]|0)+u|0;u=q;q=c[v>>2]|0;o=s;s=p;while(1){p=t;n=m;if((ba(q,f)|0)>0){F=0;do{G=+((c[w>>2]|0)-1|0)*15259021896696422.0e-21;H=F+x|0;I=F+y|0;J=F+z|0;wp(l,a,+(e[n+(H<<1)>>1]|0|0)*G,+(e[n+(I<<1)>>1]|0|0)*G,G*+(e[n+(J<<1)>>1]|0|0));K=~~(+g[A>>2]*65535.0);if(K>>>0>65535>>>0){L=-K>>31&65535}else{L=K&65535}b[p+(H<<1)>>1]=L;H=~~(+g[B>>2]*65535.0);if(H>>>0>65535>>>0){M=-H>>31&65535}else{M=H&65535}b[p+(I<<1)>>1]=M;I=~~(+g[C>>2]*65535.0);if(I>>>0>65535>>>0){N=-I>>31&65535}else{N=I&65535}b[p+(J<<1)>>1]=N;if(D){J=F+E|0;b[p+(J<<1)>>1]=b[n+(J<<1)>>1]|0}F=F+f|0;O=c[v>>2]|0;}while((F|0)<(ba(O,f)|0));P=O;Q=c[j>>2]|0;R=c[h>>2]|0}else{P=q;Q=o;R=s}F=u+1|0;if((F|0)<(r|0)){m=m+R|0;t=t+Q|0;u=F;q=P;o=Q;s=R}else{break}}i=k;return 0}function sp(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=i;i=i+16|0;k=j|0;l=c[b+44>>2]|0;b=l;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[l+16>>2]|0;o=c[m+72>>2]|0;p=(ba(o,f)|0)/(h|0)|0;q=(ba(o,f+1|0)|0)/(h|0)|0;h=n+32|0;f=m+32|0;if((p|0)>=(q|0)){i=j;return 0}o=c[f>>2]|0;r=c[h>>2]|0;s=ba(o,p)|0;t=ba(r,p)|0;u=m+68|0;v=l+3145752|0;w=d[l+12|0]|0;x=d[l+13|0]|0;y=d[l+14|0]|0;z=k|0;A=k+4|0;B=k+8|0;C=(n|0)!=(m|0)&(e|0)==4;D=d[l+15|0]|0;l=(c[m>>2]|0)+s|0;s=(c[n>>2]|0)+t|0;t=p;p=c[u>>2]|0;n=r;r=o;while(1){if((ba(p,e)|0)>0){o=0;do{E=+((c[v>>2]|0)-1|0)*.00392156862745098;m=o+w|0;F=o+x|0;G=o+y|0;wp(k,b,+(d[l+m|0]|0|0)*E,+(d[l+F|0]|0|0)*E,E*+(d[l+G|0]|0|0));H=~~(+g[z>>2]*255.0);if(H>>>0>255>>>0){I=-H>>31&255}else{I=H&255}a[s+m|0]=I;m=~~(+g[A>>2]*255.0);if(m>>>0>255>>>0){J=-m>>31&255}else{J=m&255}a[s+F|0]=J;F=~~(+g[B>>2]*255.0);if(F>>>0>255>>>0){K=-F>>31&255}else{K=F&255}a[s+G|0]=K;if(C){G=o+D|0;a[s+G|0]=a[l+G|0]|0}o=o+e|0;L=c[u>>2]|0;}while((o|0)<(ba(L,e)|0));M=L;N=c[h>>2]|0;O=c[f>>2]|0}else{M=p;N=n;O=r}o=t+1|0;if((o|0)<(q|0)){l=l+O|0;s=s+N|0;t=o;p=M;n=N;r=O}else{break}}i=j;return 0}function tp(a,f,h,j){a=a|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=i;i=i+16|0;l=k|0;m=c[a+44>>2]|0;a=m;n=c[f>>2]|0;o=c[f+4>>2]|0;f=c[m+16>>2]|0;p=c[n+72>>2]|0;q=(ba(p,h)|0)/(j|0)|0;r=(ba(p,h+1|0)|0)/(j|0)|0;j=o+32|0;h=n+32|0;if((q|0)>=(r|0)){i=k;return 0}p=c[h>>2]|0;s=c[j>>2]|0;t=ba(p,q)|0;u=ba(s,q)|0;v=n+68|0;w=m+3145752|0;x=d[m+12|0]|0;y=d[m+13|0]|0;z=d[m+14|0]|0;A=l|0;B=l+4|0;C=l+8|0;D=(o|0)!=(n|0)&(f|0)==4;E=d[m+15|0]|0;m=(c[n>>2]|0)+t|0;t=(c[o>>2]|0)+u|0;u=q;q=c[v>>2]|0;o=s;s=p;while(1){p=t;n=m;if((ba(q,f)|0)>0){F=0;do{G=+((c[w>>2]|0)-1|0)*15259021896696422.0e-21;H=F+x|0;I=F+y|0;J=F+z|0;vp(l,a,+(e[n+(H<<1)>>1]|0|0)*G,+(e[n+(I<<1)>>1]|0|0)*G,G*+(e[n+(J<<1)>>1]|0|0));K=~~(+g[A>>2]*65535.0);if(K>>>0>65535>>>0){L=-K>>31&65535}else{L=K&65535}b[p+(H<<1)>>1]=L;H=~~(+g[B>>2]*65535.0);if(H>>>0>65535>>>0){M=-H>>31&65535}else{M=H&65535}b[p+(I<<1)>>1]=M;I=~~(+g[C>>2]*65535.0);if(I>>>0>65535>>>0){N=-I>>31&65535}else{N=I&65535}b[p+(J<<1)>>1]=N;if(D){J=F+E|0;b[p+(J<<1)>>1]=b[n+(J<<1)>>1]|0}F=F+f|0;O=c[v>>2]|0;}while((F|0)<(ba(O,f)|0));P=O;Q=c[j>>2]|0;R=c[h>>2]|0}else{P=q;Q=o;R=s}F=u+1|0;if((F|0)<(r|0)){m=m+R|0;t=t+Q|0;u=F;q=P;o=Q;s=R}else{break}}i=k;return 0}function up(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=i;i=i+16|0;k=j|0;l=c[b+44>>2]|0;b=l;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[l+16>>2]|0;o=c[m+72>>2]|0;p=(ba(o,f)|0)/(h|0)|0;q=(ba(o,f+1|0)|0)/(h|0)|0;h=n+32|0;f=m+32|0;if((p|0)>=(q|0)){i=j;return 0}o=c[f>>2]|0;r=c[h>>2]|0;s=ba(o,p)|0;t=ba(r,p)|0;u=m+68|0;v=l+3145752|0;w=d[l+12|0]|0;x=d[l+13|0]|0;y=d[l+14|0]|0;z=k|0;A=k+4|0;B=k+8|0;C=(n|0)!=(m|0)&(e|0)==4;D=d[l+15|0]|0;l=(c[m>>2]|0)+s|0;s=(c[n>>2]|0)+t|0;t=p;p=c[u>>2]|0;n=r;r=o;while(1){if((ba(p,e)|0)>0){o=0;do{E=+((c[v>>2]|0)-1|0)*.00392156862745098;m=o+w|0;F=o+x|0;G=o+y|0;vp(k,b,+(d[l+m|0]|0|0)*E,+(d[l+F|0]|0|0)*E,E*+(d[l+G|0]|0|0));H=~~(+g[z>>2]*255.0);if(H>>>0>255>>>0){I=-H>>31&255}else{I=H&255}a[s+m|0]=I;m=~~(+g[A>>2]*255.0);if(m>>>0>255>>>0){J=-m>>31&255}else{J=m&255}a[s+F|0]=J;F=~~(+g[B>>2]*255.0);if(F>>>0>255>>>0){K=-F>>31&255}else{K=F&255}a[s+G|0]=K;if(C){G=o+D|0;a[s+G|0]=a[l+G|0]|0}o=o+e|0;L=c[u>>2]|0;}while((o|0)<(ba(L,e)|0));M=L;N=c[h>>2]|0;O=c[f>>2]|0}else{M=p;N=n;O=r}o=t+1|0;if((o|0)<(q|0)){l=l+O|0;s=s+N|0;t=o;p=M;n=N;r=O}else{break}}i=j;return 0}function vp(a,b,d,e,f){a=a|0;b=b|0;d=+d;e=+e;f=+f;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0,C=0,D=0,E=0.0,F=0.0,G=0.0;h=~~d;i=~~e;j=~~f;k=h+1|0;l=(c[b+3145752>>2]|0)-1|0;m=(k|0)>(l|0)?l:k;k=i+1|0;n=(k|0)>(l|0)?l:k;k=j+1|0;o=(k|0)>(l|0)?l:k;p=d- +(h|0);d=e- +(i|0);e=f- +(j|0);f=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)>>2];q=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)+4>>2];r=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)+8>>2];s=+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)>>2];t=+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)+4>>2];u=+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)+8>>2];if(p>d){if(d>e){v=1.0-p;w=p-d;x=d-e;y=e*u+(v*r+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+8>>2]+x*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+8>>2]);z=e*t+(v*q+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+4>>2]+x*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+4>>2]);A=e*s+(v*f+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)>>2]+x*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}if(p>e){x=1.0-p;w=p-e;v=e-d;y=d*u+(x*r+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+8>>2]+v*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+8>>2]);z=d*t+(x*q+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+4>>2]+v*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+4>>2]);A=d*s+(x*f+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)>>2]+v*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}else{v=1.0-e;w=e-p;x=p-d;y=d*u+(v*r+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+8>>2]+x*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+8>>2]);z=d*t+(v*q+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+4>>2]+x*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+4>>2]);A=d*s+(v*f+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)>>2]+x*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}}else{if(e>d){x=1.0-e;w=e-d;v=d-p;y=p*u+(x*r+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+8>>2]+v*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+8>>2]);z=p*t+(x*q+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+4>>2]+v*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+4>>2]);A=p*s+(x*f+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)>>2]+v*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}v=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)>>2];w=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)+4>>2];x=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)+8>>2];if(e>p){E=1.0-d;F=d-e;G=e-p;y=p*u+(E*r+F*x+G*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+8>>2]);z=p*t+(E*q+F*w+G*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+4>>2]);A=p*s+(E*f+F*v+G*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}else{G=1.0-d;F=d-p;d=p-e;y=e*u+(G*r+F*x+d*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+8>>2]);z=e*t+(G*q+F*w+d*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+4>>2]);A=e*s+(G*f+F*v+d*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}}}function wp(a,b,d,e,f){a=a|0;b=b|0;d=+d;e=+e;f=+f;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0;h=~~d;i=~~e;j=~~f;k=h+1|0;l=(c[b+3145752>>2]|0)-1|0;m=(k|0)>(l|0)?l:k;k=i+1|0;n=(k|0)>(l|0)?l:k;k=j+1|0;o=(k|0)>(l|0)?l:k;p=d- +(h|0);d=e- +(i|0);e=f- +(j|0);f=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)>>2];q=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)+4>>2];r=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)+8>>2];s=+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)>>2];t=+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+4>>2];u=+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+8>>2];v=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)>>2];w=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)+4>>2];x=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)+8>>2];y=+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)>>2];z=+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+4>>2];A=+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+8>>2];B=f+p*(+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)>>2]-f);f=q+p*(+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+4>>2]-q);q=r+p*(+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+8>>2]-r);r=s+p*(+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)>>2]-s);s=t+p*(+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+4>>2]-t);t=u+p*(+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+8>>2]-u);u=B+d*(v+p*(+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)>>2]-v)-B);B=f+d*(w+p*(+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+4>>2]-w)-f);f=q+d*(x+p*(+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+8>>2]-x)-q);q=B+e*(s+d*(z+p*(+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)+4>>2]-z)-s)-B);B=f+e*(t+d*(A+p*(+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)+8>>2]-A)-t)-f);g[a>>2]=u+e*(r+d*(y+p*(+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)>>2]-y)-r)-u);g[a+4>>2]=q;g[a+8>>2]=B;return}function xp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+8>>2]|0;a=c[c[d+32>>2]>>2]|0;e=jp(d,b)|0;if((e|0)==0){f=-12;return f|0}f=cj(a,e)|0;return f|0}function yp(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+64|0;f=e|0;g=c[b+44>>2]|0;h=g+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;h=g+16|0;l=bFb(c[h>>2]|0)|0;c[g+92>>2]=l;do{if(!((a[l+7|0]&16)==0)){if((d[l+4|0]|0)>>>0<2>>>0){break}m=fFb(c[h>>2]|0)|0;c[g+24>>2]=m;a:do{if((m|0)>0){n=g+60|0;o=g+20|0;p=k;q=j;r=m;while(1){s=r-1|0;t=q&15;c[n+(s<<3)>>2]=t;u=(q>>>4|p<<28)&15;c[n+(s<<3)+4>>2]=u;if(t>>>0>3>>>0|u>>>0>3>>>0){break}t=q>>>8|p<<24;v=c[o>>2]|0;w=u+1|0;u=(v|0)>(w|0)?v:w;c[o>>2]=u;if((s|0)>0){p=p>>8|((p|0)<0|0?-1:0)<<24;q=t;r=s}else{x=u;break a}}yDb(b,16,2095112,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;z=-22;i=e;return z|0}else{x=c[g+20>>2]|0}}while(0);m=g+20|0;if(!((x|0)!=0&(x|0)<5)){yDb(0,0,2040776,(y=i,i=i+24|0,c[y>>2]=1995752,c[y+8>>2]=1960048,c[y+16>>2]=96,y)|0);i=y;Cd();return 0}r=f;q=f|0;p=f+36|0;o=b+24|0;n=b+12|0;u=b+16|0;s=b+20|0;t=0;while(1){if((t|0)>=(c[m>>2]|0)){z=0;A=18;break}TGb(f|0,0,60)|0;w=vAb(1932176,(y=i,i=i+8|0,c[y>>2]=t,y)|0)|0;i=y;c[q>>2]=w;if((w|0)==0){z=-12;A=18;break}c[p>>2]=776;B=Hi(t,o,12,n,u,f)|0;c[s>>2]=c[o>>2];if((B|0)<0){A=17;break}t=t+1|0}if((A|0)==17){$Db(r);z=B;i=e;return z|0}else if((A|0)==18){i=e;return z|0}}}while(0);yDb(b,16,2167824,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;z=-22;i=e;return z|0}function zp(a){a=a|0;var b=0,d=0;Tw((c[a+44>>2]|0)+96|0);b=a+24|0;if((c[b>>2]|0)==0){return}d=a+12|0;a=0;do{$Db((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function Ap(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+8|0;f=e|0;g=c[a+44>>2]|0;c[f>>2]=0;h=g+16|0;j=g+92|0;c[j>>2]=bFb(c[h>>2]|0)|0;k=0;do{l=bFb(k)|0;do{if(((b[(c[j>>2]|0)+8>>1]^b[l+8>>1])&30720)==0){m=fFb(k)|0;if((m|0)!=(d[l+4|0]|0|0)){break}zk(f,k,(k|0)<0|0?-1:0)|0}}while(0);k=k+1|0;}while((k|0)<333);k=g+20|0;if((c[k>>2]|0)>0){g=a+16|0;j=0;do{Hk(c[f>>2]|0,(c[(c[g>>2]|0)+(j<<2)>>2]|0)+68|0);j=j+1|0;}while((j|0)<(c[k>>2]|0))}c[f>>2]=0;k=c[h>>2]|0;zk(f,k,(k|0)<0|0?-1:0)|0;Hk(c[f>>2]|0,(c[c[a+32>>2]>>2]|0)+64|0);i=e;return 0}function Bp(a,b){a=a|0;b=b|0;return Uw((c[(c[a+8>>2]|0)+44>>2]|0)+96|0,a,b)|0}function Cp(a){a=a|0;return Vw((c[(c[a>>2]|0)+44>>2]|0)+96|0,a)|0}function Dp(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;b=i;i=i+208|0;f=b|0;g=c[a>>2]|0;h=c[g+44>>2]|0;j=h+96|0;k=g;l=h+20|0;Mw(j,k,c[l>>2]|0);m=h+152|0;c[h+132>>2]=h;c[h+128>>2]=2276;n=g+16|0;o=c[c[n>>2]>>2]|0;p=c[o+20>>2]|0;q=a+20|0;c[q>>2]=p;r=a+24|0;c[r>>2]=c[o+24>>2];s=o+56|0;o=a+56|0;t=c[s+4>>2]|0;c[o>>2]=c[s>>2];c[o+4>>2]=t;t=(c[c[n>>2]>>2]|0)+116|0;o=a+116|0;s=c[t+4>>2]|0;c[o>>2]=c[t>>2];c[o+4>>2]=s;s=a+28|0;o=(c[c[n>>2]>>2]|0)+28|0;t=s;u=c[o+4>>2]|0;c[t>>2]=c[o>>2];c[t+4>>2]=u;u=h+92|0;t=c[u>>2]|0;o=-(-p>>(d[t+5|0]|0))|0;p=h+28|0;v=p;c[h+36>>2]=o;c[h+32>>2]=o;o=c[q>>2]|0;c[h+40>>2]=o;c[p>>2]=o;o=-(-(c[r>>2]|0)>>(d[t+6|0]|0))|0;t=h+44|0;p=t;c[h+52>>2]=o;c[h+48>>2]=o;o=c[r>>2]|0;c[h+56>>2]=o;c[t>>2]=o;a:do{if((c[l>>2]|0)>0){o=s|0;t=a+32|0;r=0;while(1){w=c[(c[n>>2]|0)+(r<<2)>>2]|0;q=w+52|0;x=bFb(c[q>>2]|0)|0;y=c[o>>2]|0;z=c[w+28>>2]|0;if((y|0)!=(z|0)){A=5;break}B=c[t>>2]|0;C=c[w+32>>2]|0;if((B|0)!=(C|0)){D=C;E=B;break}B=c[w+20>>2]|0;C=-(-B>>(d[x+5|0]|0))|0;c[f+(r*52|0)+28>>2]=C;c[f+(r*52|0)+24>>2]=C;c[f+(r*52|0)+32>>2]=B;c[f+(r*52|0)+20>>2]=B;B=c[w+24>>2]|0;C=-(-B>>(d[x+6|0]|0))|0;c[f+(r*52|0)+44>>2]=C;c[f+(r*52|0)+40>>2]=C;c[f+(r*52|0)+48>>2]=B;c[f+(r*52|0)+36>>2]=B;B=fFb(c[q>>2]|0)|0;q=f+(r*52|0)+16|0;c[q>>2]=B;if((B|0)>0){B=0;do{c[f+(r*52|0)+(B<<2)>>2]=((e[x+8+(B<<1)>>1]|0)>>>11&15)+1;B=B+1|0;}while((B|0)<(c[q>>2]|0))}q=w+56|0;B=m+(r*184|0)+140|0;x=c[q+4>>2]|0;c[B>>2]=c[q>>2];c[B+4>>2]=x;c[m+(r*184|0)+180>>2]=1;c[m+(r*184|0)+132>>2]=0;c[m+(r*184|0)+136>>2]=0;x=r+1|0;if((x|0)<(c[l>>2]|0)){r=x}else{break a}}if((A|0)==5){D=c[w+32>>2]|0;E=c[t>>2]|0}o=c[(c[g+12>>2]|0)+(r*60|0)>>2]|0;x=c[c[g+28>>2]>>2]|0;yDb(k,16,2284264,(F=i,i=i+56|0,c[F>>2]=r,c[F+8>>2]=o,c[F+16>>2]=z,c[F+24>>2]=D,c[F+32>>2]=x,c[F+40>>2]=y,c[F+48>>2]=E,F)|0);i=F;G=-22;i=b;return G|0}}while(0);E=c[h+24>>2]|0;y=h+60|0;h=0;while(1){if((h|0)>=(E|0)){A=20;break}H=c[y+(h<<3)+4>>2]|0;I=c[y+(h<<3)>>2]|0;if((I+1|0)>(c[f+(H*52|0)+16>>2]|0)){A=13;break}J=((e[(c[u>>2]|0)+8+(h<<1)>>1]|0)>>>11&15)+1|0;K=c[f+(H*52|0)+(I<<2)>>2]|0;if((J|0)!=(K|0)){A=15;break}L=c[v+(h<<2)>>2]|0;M=c[f+(H*52|0)+20+(I<<2)>>2]|0;if((L|0)!=(M|0)){A=17;break}N=c[p+(h<<2)>>2]|0;O=c[f+(H*52|0)+36+(I<<2)>>2]|0;if((N|0)==(O|0)){h=h+1|0}else{A=19;break}}if((A|0)==13){yDb(k,16,2268912,(F=i,i=i+16|0,c[F>>2]=H,c[F+8>>2]=I,F)|0);i=F;G=-22;i=b;return G|0}else if((A|0)==15){yDb(k,16,2253368,(F=i,i=i+40|0,c[F>>2]=h,c[F+8>>2]=J,c[F+16>>2]=H,c[F+24>>2]=I,c[F+32>>2]=K,F)|0);i=F;G=-22;i=b;return G|0}else if((A|0)==17){yDb(k,16,2239160,(F=i,i=i+40|0,c[F>>2]=h,c[F+8>>2]=L,c[F+16>>2]=H,c[F+24>>2]=I,c[F+32>>2]=M,F)|0);i=F;G=-22;i=b;return G|0}else if((A|0)==19){yDb(k,16,2227240,(F=i,i=i+40|0,c[F>>2]=h,c[F+8>>2]=N,c[F+16>>2]=H,c[F+24>>2]=I,c[F+32>>2]=O,F)|0);i=F;G=-22;i=b;return G|0}else if((A|0)==20){G=Nw(j)|0;i=b;return G|0}return 0}function Ep(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=c[c[(c[a+4>>2]|0)+32>>2]>>2]|0;f=c[a+36>>2]|0;TGb(d|0,0,16)|0;a=f+20|0;g=f+96|0;h=0;while(1){if((h|0)>=(c[a>>2]|0)){break}j=Sw(g,h,d+(h<<2)|0,0)|0;if((j|0)<0){k=j;l=9;break}else{h=h+1|0}}if((l|0)==9){i=b;return k|0}l=Zr(e,c[e+20>>2]|0,c[e+24>>2]|0)|0;if((l|0)==0){k=-12;i=b;return k|0}h=f+120|0;g=KDb(c[h>>2]|0,c[h+4>>2]|0,f+108|0,e+56|0)|0;h=l+136|0;c[h>>2]=g;c[h+4>>2]=F;h=f+24|0;if((c[h>>2]|0)>0){g=f+60|0;a=f+28|0;j=f+44|0;f=0;do{m=c[g+(f<<3)>>2]|0;n=c[d+(c[g+(f<<3)+4>>2]<<2)>>2]|0;iDb(c[l+(f<<2)>>2]|0,c[l+32+(f<<2)>>2]|0,c[n+(m<<2)>>2]|0,c[n+32+(m<<2)>>2]|0,c[a+(f<<2)>>2]|0,c[j+(f<<2)>>2]|0);f=f+1|0;}while((f|0)<(c[h>>2]|0))}k=cj(e,l)|0;i=b;return k|0}function Fp(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0,H=0;d=c[b+44>>2]|0;qBb()|0;b=d+49468|0;e=b;f=c[d+308>>2]|0;g=(f|0)>-1?f:123457;c[d+49736>>2]=g;f=c[d+40>>2]|0;h=(f|0)==0;if(!h){c[b>>2]=f}b=c[d+44>>2]|0;i=(b|0)==0;if(!i){c[d+49472>>2]=b}c[d+99164>>2]=g;if(!h){c[d+98896>>2]=f}if(!i){c[d+98900>>2]=b}c[d+148592>>2]=g;if(!h){c[d+148324>>2]=f}if(!i){c[d+148328>>2]=b}c[d+198020>>2]=g;if(!h){c[d+197752>>2]=f}if(!i){c[d+197756>>2]=b}b=d;i=d+263564|0;f=0;do{if((c[e+(f*49428|0)>>2]|0)!=0){h=WDb(5120)|0;g=c[b+49468+(f*49428|0)>>2]|0;j=c[b+49468+(f*49428|0)+4>>2]|0;if((h|0)==0){k=-12;l=34;break}oDb(b+49468+(f*49428|0)+8|0,c[b+49468+(f*49428|0)+268>>2]|0);m=b+49468+(f*49428|0)+264|0;n=(j&8|0)==0;o=j&16;p=(o|0)!=0;q=+(g|0);r=(g|0)/2|0;s=q/1.7320508075688772;t=(o|0)==0;o=c[m>>2]|0;if((j&1|0)==0){j=0;u=0;v=o;while(1){w=v;do{c[b+49468+(f*49428|0)+8+((w&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((w+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((w+40&63)<<2)>>2]|0);x=c[m>>2]|0;y=x+1|0;c[m>>2]=y;z=+((c[b+49468+(f*49428|0)+8+((x&63)<<2)>>2]|0)>>>0>>>0)*2.0*2.3283064365386963e-10+-1.0;c[b+49468+(f*49428|0)+8+((y&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((x+10&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((x+41&63)<<2)>>2]|0);x=c[m>>2]|0;w=x+1|0;c[m>>2]=w;A=+((c[b+49468+(f*49428|0)+8+((x&63)<<2)>>2]|0)>>>0>>>0)*2.0*2.3283064365386963e-10+-1.0;B=z*z+A*A;}while(!(B<1.0));A=s*z*+R(+$(B)*-2.0/B);if(t){C=A}else{C=A*.5+ +(ba(a[592608+((j|0)%4|0)|0]|0,g)|0)*.35}A=C;if(A<-128.0){D=-128.0}else{D=A>127.0?127.0:A}if(n){E=D}else{E=D/3.0}a[h+u|0]=~~E;w=c[m>>2]|0;c[b+49468+(f*49428|0)+8+((w&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((w+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((w+40&63)<<2)>>2]|0);w=c[m>>2]|0;x=w+1|0;c[m>>2]=x;y=u+1|0;if((y|0)<5120){j=j+1+(((~~(+((c[b+49468+(f*49428|0)+8+((w&63)<<2)>>2]|0)>>>0>>>0)*6.0*2.3283064365386963e-10)|0)==0)<<31>>31)|0;u=y;v=x}else{F=0;G=x;break}}}else{v=0;u=0;j=o;while(1){c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((j+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((j+40&63)<<2)>>2]|0);t=c[m>>2]|0;x=t+1|0;c[m>>2]=x;y=~~(q*+((c[b+49468+(f*49428|0)+8+((t&63)<<2)>>2]|0)>>>0>>>0)*2.3283064365386963e-10)-r|0;do{if(n){if(p){a[h+u|0]=~~(+((y|0)/2|0|0)+ +(ba(a[592608+((v|0)%4|0)|0]|0,g)|0)*.25);break}else{a[h+u|0]=y;break}}else{if(p){a[h+u|0]=~~(+((y|0)/6|0|0)+ +(ba(a[592608+((v|0)%4|0)|0]|0,g)|0)*.25/3.0);break}else{a[h+u|0]=(y|0)/3|0;break}}}while(0);c[b+49468+(f*49428|0)+8+((x&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((t+10&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((t+41&63)<<2)>>2]|0);y=c[m>>2]|0;w=y+1|0;c[m>>2]=w;H=u+1|0;if((H|0)<5120){v=v+1+(((~~(+((c[b+49468+(f*49428|0)+8+((y&63)<<2)>>2]|0)>>>0>>>0)*6.0*2.3283064365386963e-10)|0)==0)<<31>>31)|0;u=H;j=w}else{F=0;G=w;break}}}while(1){c[b+49468+(f*49428|0)+8+((G&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((G+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((G+40&63)<<2)>>2]|0);j=c[m>>2]|0;c[m>>2]=j+1;c[b+49468+(f*49428|0)+276+(F*12|0)>>2]=h+(c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]&1023);j=c[m>>2]|0;c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((j+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((j+40&63)<<2)>>2]|0);j=c[m>>2]|0;c[m>>2]=j+1;c[b+49468+(f*49428|0)+276+(F*12|0)+4>>2]=h+(c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]&1023);j=c[m>>2]|0;c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((j+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((j+40&63)<<2)>>2]|0);j=c[m>>2]|0;c[m>>2]=j+1;c[b+49468+(f*49428|0)+276+(F*12|0)+8>>2]=h+(c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]&1023);j=F+1|0;if((j|0)>=4096){break}F=j;G=c[m>>2]|0}if((c[i>>2]|0)==0){j=0;do{u=c[m>>2]|0;c[b+49468+(f*49428|0)+8+((u&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((u+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((u+40&63)<<2)>>2]|0);u=c[m>>2]|0;c[m>>2]=u+1;c[b+247180+(j<<2)>>2]=c[b+49468+(f*49428|0)+8+((u&63)<<2)>>2]&1023;j=j+1|0;}while((j|0)<4096);c[i>>2]=1}c[b+49468+(f*49428|0)+272>>2]=h}f=f+1|0;}while((f|0)<4);if((l|0)==34){return k|0}c[d+263568>>2]=166;c[d+263572>>2]=550;k=0;return k|0}function Gp(a){a=a|0;var b=0;b=c[a+44>>2]|0;$Db(b+49740|0);$Db(b+99168|0);$Db(b+148596|0);$Db(b+198024|0);return}function Hp(b){b=b|0;var d=0,f=0,g=0,h=0;d=i;i=i+8|0;f=d|0;c[f>>2]=0;g=0;do{h=bFb(g)|0;do{if(!((a[h+7|0]&16)==0)){if((((e[h+8>>1]|0)>>>11&65535)+1&7|0)!=0){break}zk(f,g,(g|0)<0|0?-1:0)|0}}while(0);g=g+1|0;}while((g|0)<333);Ok(b,c[f>>2]|0);i=d;return 0}function Ip(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)>0){h=0}else{return}do{i=(a[e+(h+g)|0]|0)+(d[c+h|0]|0)|0;if(i>>>0>255>>>0){j=-i>>31&255}else{j=i&255}a[b+h|0]=j;h=h+1|0;}while((h|0)<(f|0));return}function Jp(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)<=0){return}g=f+4|0;h=f+8|0;i=0;do{j=a[d+i|0]|0;a[b+i|0]=((ba((a[(c[g>>2]|0)+i|0]|0)+(a[(c[f>>2]|0)+i|0]|0)+(a[(c[h>>2]|0)+i|0]|0)|0,j)|0)>>>7)+j;i=i+1|0;}while((i|0)<(e|0));return}function Kp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;a=c[c[g+32>>2]>>2]|0;h=c[g+44>>2]|0;do{if((RCb(b)|0)==0){j=Zr(a,c[a+20>>2]|0,c[a+24>>2]|0)|0;if((j|0)!=0){NCb(j,c[e>>2]|0)|0;k=j;l=c[e>>2]|0;break}JCb(e);m=-12;i=d;return m|0}else{k=b;l=b}}while(0);c[f>>2]=l;c[f+4>>2]=k;l=c[h+24>>2]|0;h=c[(c[g+48>>2]|0)+28>>2]|0;Pe[c[c[g+56>>2]>>2]&255](g,558,f,0,(l|0)>(h|0)?h:l)|0;if((c[e>>2]|0)!=(k|0)){JCb(e)}m=cj(a,k)|0;i=d;return m|0}function Lp(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=bFb(c[e>>2]|0)|0;c[b+4>>2]=fFb(c[e>>2]|0)|0;g=dDb(b+8|0,c[e>>2]|0,c[a+20>>2]|0)|0;if((g|0)<0){h=g;return h|0}g=a+24|0;a=-(-(c[g>>2]|0)>>(d[f+6|0]|0))|0;c[b+32>>2]=a;c[b+28>>2]=a;a=c[g>>2]|0;c[b+36>>2]=a;c[b+24>>2]=a;h=0;return h|0}function Mp(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=c[a+44>>2]|0;a=f;g=f+4|0;if((c[g>>2]|0)<=0){return 0}h=f+24|0;i=d+1|0;j=b+4|0;k=b;b=f+8|0;l=f+263568|0;m=f+263572|0;f=0;do{n=c[h+(f<<2)>>2]|0;o=(ba(n,d)|0)/(e|0)|0;p=(ba(n,i)|0)/(e|0)|0;n=c[j>>2]|0;q=c[n+32+(f<<2)>>2]|0;r=(c[n+(f<<2)>>2]|0)+(ba(q,o)|0)|0;n=c[k>>2]|0;s=c[n+32+(f<<2)>>2]|0;t=(c[n+(f<<2)>>2]|0)+(ba(s,o)|0)|0;n=c[b+(f<<2)>>2]|0;u=c[a+49468+(f*49428|0)+272>>2]|0;v=c[a+49468+(f*49428|0)+4>>2]|0;do{if((u|0)==0){if((r|0)==(t|0)){break}iDb(r,q,t,s,n,p-o|0)}else{if((o|0)>=(p|0)){break}w=(v&2|0)==0;x=(v&8|0)==0;y=a+49468+(f*49428|0)+264|0;z=t;A=o;B=r;while(1){C=A&4095;if(w){D=c[a+247180+(C<<2)>>2]|0}else{E=c[y>>2]|0;c[a+49468+(f*49428|0)+8+((E&63)<<2)>>2]=(c[a+49468+(f*49428|0)+8+((E+9&63)<<2)>>2]|0)+(c[a+49468+(f*49428|0)+8+((E+40&63)<<2)>>2]|0);E=c[y>>2]|0;c[y>>2]=E+1;D=c[a+49468+(f*49428|0)+8+((E&63)<<2)>>2]&1023}if(x){le[c[l>>2]&1023](B,z,u,n,D)}else{cf[c[m>>2]&1023](B,z,n,a+49468+(f*49428|0)+276+(C*12|0)|0);c[a+49468+(f*49428|0)+276+(C*12|0)+((D&3)<<2)>>2]=u+D}C=A+1|0;if((C|0)<(p|0)){z=z+s|0;A=C;B=B+q|0}else{break}}}}while(0);f=f+1|0;}while((f|0)<(c[g>>2]|0));return 0}function Np(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+44>>2]|0;if((c[d+12>>2]|0)!=0){yDb(a,24,2172296,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;c[d+28>>2]=3}a=d+472|0;e=d+648|0;if((c[a>>2]|0)==0){f=5}else{g=c[e>>2]|0;if((g|0)==2){f=5}else{h=g}}if((f|0)==5){c[a>>2]=0;c[e>>2]=2;h=2}e=d+468|0;if(!((c[e>>2]|0)!=0|(h|0)==1)){j=d+464|0;k=j;c[k>>2]=90;i=b;return 0}c[e>>2]=1;c[d+648>>2]=1;j=d+464|0;k=j;c[k>>2]=90;i=b;return 0}function Op(a){a=a|0;var b=0;b=c[a+44>>2]|0;Lw(b+40|0);a=b+652|0;IBb(c[a>>2]|0);c[a>>2]=0;a=b+656|0;IBb(c[a>>2]|0);c[a>>2]=0;return}function Pp(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[(c[a+44>>2]|0)+28>>2]|0;if((d|0)==1){e=xk(551792)|0;f=xk(551712)|0;g=e}else if((d|0)==3){e=xk(551824)|0;f=xk(551728)|0;g=e}else if((d|0)==2){e=xk(551776)|0;f=xk(551704)|0;g=e}else if((d|0)==0){d=xk(551808)|0;f=xk(551720)|0;g=d}else{yDb(0,0,2206064,(d=i,i=i+24|0,c[d>>2]=2198424,c[d+8>>2]=2188536,c[d+16>>2]=254,d)|0);i=d;Cd();return 0}d=a+16|0;Hk(g,(c[c[d>>2]>>2]|0)+68|0);Hk(f,(c[(c[d>>2]|0)+4>>2]|0)+68|0);Hk(g,(c[c[a+32>>2]>>2]|0)+64|0);i=b;return 0}function Qp(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var j=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0;g=i;f=a+44|0;e=c[f>>2]|0;do{if((QGb(b,2166880)|0)==0){j=e+652|0;l=a;m=c[j>>2]|0;n=JBb(j,d,160160,0,0,0,0,0,l)|0;if((n|0)>=0){IBb(m);break}yDb(l,16,1995488,(o=i,i=i+16|0,c[o>>2]=d,c[o+8>>2]=b,o)|0);i=o;c[j>>2]=m;p=n;i=g;return p|0}else{if((QGb(b,2094728)|0)!=0){p=-38;i=g;return p|0}n=e+656|0;m=a;j=c[n>>2]|0;l=JBb(n,d,160160,0,0,0,0,0,m)|0;if((l|0)>=0){IBb(j);break}yDb(m,16,1995488,(o=i,i=i+16|0,c[o>>2]=d,c[o+8>>2]=b,o)|0);i=o;c[n>>2]=j;p=l;i=g;return p|0}}while(0);if((c[e+32>>2]|0)!=0){p=0;i=g;return p|0}b=c[f>>2]|0;f=b+652|0;d=b+520|0;l=b+600|0;h[l>>3]=+MBb(c[f>>2]|0,d,0);j=b+608|0;h[j>>3]=+MBb(c[b+656>>2]|0,d,0);q=+MBb(c[f>>2]|0,d,0);h[l>>3]=q;h[k>>3]=q;l=c[k+4>>2]&2147483647;d=2146435072;if(l>>>0>d>>>0|l>>>0==d>>>0&(c[k>>2]|0)>>>0>0>>>0){r=2147483647}else{r=-1<<c[b+512>>2]&~~q}c[b+4>>2]=r;r=c[j+4>>2]&2147483647;d=2146435072;if(r>>>0>d>>>0|r>>>0==d>>>0&(c[j>>2]|0)>>>0>0>>>0){s=2147483647}else{s=-1<<c[b+516>>2]&~~+h[j>>3]}c[b+8>>2]=s;s=c[e+4>>2]|0;q=+h[e+608>>3];b=c[e+8>>2]|0;yDb(a,40,2040528,(o=i,i=i+32|0,h[o>>3]=+h[e+600>>3],c[o+8>>2]=s,h[o+16>>3]=q,c[o+24>>2]=b,o)|0);i=o;p=0;i=g;return p|0}function Rp(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,j=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;g=i;j=b+44|0;l=c[j>>2]|0;m=c[c[b+16>>2]>>2]|0;if((c[l+32>>2]|0)==1){n=sCb(e)|0;o=F;p=m+160|0;r=l+616|0;h[r>>3]=+((c[p>>2]|0)>>>0)+ +(c[p+4>>2]|0)*4294967296.0;p=e+136|0;s=c[p>>2]|0;t=c[p+4>>2]|0;if((s|0)==0&(t|0)==(-2147483648|0)){u=+q}else{u=(+(s>>>0)+ +(t|0)*4294967296.0)*(+(c[m+56>>2]|0)/+(c[m+60>>2]|0))}m=l+632|0;h[m>>3]=u;if((n|0)==(-1|0)&(o|0)==(-1|0)){v=+q}else{v=+(n>>>0)+ +(o|0)*4294967296.0}o=l+624|0;h[o>>3]=v;n=c[j>>2]|0;t=n+652|0;s=n+520|0;p=n+600|0;h[p>>3]=+MBb(c[t>>2]|0,s,0);w=n+608|0;h[w>>3]=+MBb(c[n+656>>2]|0,s,0);v=+MBb(c[t>>2]|0,s,0);h[p>>3]=v;h[k>>3]=v;p=c[k+4>>2]&2147483647;s=2146435072;if(p>>>0>s>>>0|p>>>0==s>>>0&(c[k>>2]|0)>>>0>0>>>0){x=2147483647}else{x=-1<<c[n+512>>2]&~~v}c[n+4>>2]=x;x=c[w+4>>2]&2147483647;s=2146435072;if(x>>>0>s>>>0|x>>>0==s>>>0&(c[w>>2]|0)>>>0>0>>>0){y=2147483647}else{y=-1<<c[n+516>>2]&~~+h[w>>3]}c[n+8>>2]=y;v=+h[m>>3];u=+h[o>>3];z=+h[l+600>>3];o=l+4|0;m=c[o>>2]|0;A=+h[l+608>>3];y=l+8|0;n=c[y>>2]|0;yDb(b,48,2163112,(b=i,i=i+56|0,h[b>>3]=+h[r>>3],h[b+8>>3]=v,h[b+16>>3]=u,h[b+24>>3]=z,c[b+32>>2]=m,h[b+40>>3]=A,c[b+48>>2]=n,b)|0);i=b;B=c[j>>2]|0;C=o;D=y}else{B=l;C=l+4|0;D=l+8|0}l=c[C>>2]|0;C=c[D>>2]|0;D=c[f+68>>2]|0;y=c[f+72>>2]|0;o=c[e+68>>2]|0;j=c[e+72>>2]|0;if((o|0)<=(l|0)){i=g;return e|0}if(!((D+l|0)>-1&(j|0)>(C|0))){i=g;return e|0}if((y+C|0)<0){i=g;return e|0}if((a[B+16|0]|0)!=0){b=d[B+17|0]|0;n=d[B+18|0]|0;m=d[B+19|0]|0;r=d[B+20|0]|0;w=c[B+480>>2]|0;s=d[B+23|0]|0;x=d[B+24|0]|0;p=d[B+25|0]|0;t=d[B+26|0]|0;E=c[B+496>>2]|0;G=(C|0)<0?-C|0:0;H=f+32|0;I=e+32|0;J=j-C|0;K=(J|0)>(y|0)?y:J;if((G|0)>=(K|0)){i=g;return e|0}J=c[I>>2]|0;L=c[H>>2]|0;M=ba(J,G+C|0)|0;N=ba(L,G)|0;O=(l|0)<0?-l|0:0;P=ba(E,O)|0;Q=ba(w,O+l|0)|0;R=o-l|0;S=(R|0)>(D|0)?D:R;R=(O|0)<(S|0);T=(a[B+21|0]|0)!=0;U=(c[e>>2]|0)+M|0;M=(c[f>>2]|0)+N|0;N=G;G=J;J=L;while(1){if(R){L=U+Q|0;V=M+P|0;W=O;while(1){X=V+t|0;Y=a[X]|0;do{if(T){Z=Y&255;if((Y<<24>>24|0)==0|(Y<<24>>24|0)==(-1|0)){_=Y;break}$=d[L+r|0]|0;_=((Z*65025|0|0)/((($+Z|0)*255|0)-(ba($,Z)|0)|0)|0)&255}else{_=Y}}while(0);Y=_&255;if((Y|0)==255){a[L+b|0]=a[V+s|0]|0;a[L+n|0]=a[V+x|0]|0;a[L+m|0]=a[V+p|0]|0}else if((Y|0)!=0){Z=L+b|0;$=Y^255;aa=ba(d[Z]|0,$)|0;a[Z]=((((ba(d[V+s|0]|0,Y)|0)+aa|0)*257|0)+32896|0)>>>16;aa=L+n|0;Z=ba(d[aa]|0,$)|0;a[aa]=((((ba(d[V+x|0]|0,Y)|0)+Z|0)*257|0)+32896|0)>>>16;Z=L+m|0;aa=ba(d[Z]|0,$)|0;a[Z]=((((ba(d[V+p|0]|0,Y)|0)+aa|0)*257|0)+32896|0)>>>16}do{if(T){if((Y|0)==255){a[L+r|0]=a[X]|0;break}else if((Y|0)==0){break}else{aa=L+r|0;Z=d[aa]|0;a[aa]=(((ba((d[X]|0)*257|0,Z^255)|0)+32896|0)>>>16)+Z;break}}}while(0);X=W+1|0;if((X|0)<(S|0)){L=L+w|0;V=V+E|0;W=X}else{break}}ca=c[I>>2]|0;da=c[H>>2]|0}else{ca=G;da=J}W=N+1|0;if((W|0)<(K|0)){U=U+ca|0;M=M+da|0;N=W;G=ca;J=da}else{break}}i=g;return e|0}da=(a[B+21|0]|0)!=0;do{if(da){J=(C|0)<0?-C|0:0;ca=f+12|0;G=f+44|0;N=e+44|0;M=j-C|0;U=(M|0)>(y|0)?y:M;if((J|0)>=(U|0)){ea=ca;fa=G;break}M=(l|0)<0?-l|0:0;K=M+l|0;H=o-l|0;I=(H|0)>(D|0)?D:H;if((M|0)>=(I|0)){ea=ca;fa=G;break}H=ba(c[G>>2]|0,J)|0;E=(c[ca>>2]|0)+H|0;H=(c[e+12>>2]|0)+(ba(c[N>>2]|0,J+C|0)|0)|0;w=J;while(1){J=E+M|0;S=H+K|0;r=M;while(1){T=a[J]|0;p=T&255;if((T<<24>>24|0)==0|(T<<24>>24|0)==(-1|0)){ga=T}else{m=d[S]|0;ga=((p*65025|0|0)/(((m+p|0)*255|0)-(ba(m,p)|0)|0)|0)&255}m=ga&255;if((m|0)==255){a[S]=T}else if((m|0)!=0){m=d[S]|0;a[S]=(((ba(p*257|0,m^255)|0)+32896|0)>>>16)+m}m=r+1|0;if((m|0)<(I|0)){J=J+1|0;S=S+1|0;r=m}else{break}}r=w+1|0;if((r|0)<(U|0)){E=E+(c[G>>2]|0)|0;H=H+(c[N>>2]|0)|0;w=r}else{ea=ca;fa=G;break}}}else{ea=f+12|0;fa=f+44|0}}while(0);ga=-D|0;D=-y|0;y=-o|0;o=-j|0;j=B+512|0;G=B+516|0;B=0;do{if((B|0)==0){ha=0;ia=0}else{ha=c[G>>2]|0;ia=c[j>>2]|0}ca=-(ga>>ia)|0;w=-(D>>ha)|0;N=C>>ha;H=l>>ia;E=(N|0)<0?-N|0:0;U=f+32+(B<<2)|0;I=e+32+(B<<2)|0;M=-(N+(o>>ha)|0)|0;K=(M|0)>(w|0)?w:M;if((E|0)<(K|0)){M=c[fa>>2]|0;r=c[I>>2]|0;S=c[U>>2]|0;J=ba(M,E<<ha)|0;m=ba(r,E+N|0)|0;N=ba(S,E)|0;p=(H|0)<0?-H|0:0;T=p+H|0;x=p<<ia;n=-(H+(y>>ia)|0)|0;H=(n|0)>(ca|0)?ca:n;n=(p|0)<(H|0);s=(ia|0)!=0;b=s^1;_=(ha|0)==0;t=_|b;O=_&b;b=1<<ia;P=E;E=(c[f+(B<<2)>>2]|0)+N|0;N=(c[e+(B<<2)>>2]|0)+m|0;m=(c[ea>>2]|0)+J|0;J=r;r=S;S=M;while(1){if(n){M=P+1|0;Q=(M|0)>=(w|0);R=t|Q;W=_|Q;Q=p;V=E+p|0;L=N+T|0;X=m+x|0;while(1){do{if(R){ja=57}else{if((Q+1|0)>=(ca|0)){ja=57;break}Y=c[fa>>2]|0;ka=((d[X+Y|0]|0)+(d[X]|0)+(d[X+1|0]|0)+(d[X+(Y+1)|0]|0)|0)>>>2}}while(0);do{if((ja|0)==57){ja=0;if(O){ka=d[X]|0;break}do{if(s){if((Q+1|0)>=(ca|0)){ja=61;break}Y=a[X]|0;la=((d[X+1|0]|0)+(Y&255)|0)>>>1;ma=Y}else{ja=61}}while(0);if((ja|0)==61){ja=0;Y=a[X]|0;la=Y&255;ma=Y}Y=ma&255;if(W){na=Y}else{na=((d[X+(c[fa>>2]|0)|0]|0)+Y|0)>>>1}ka=(na+la|0)>>>1}}while(0);do{if(da){if((ka|0)==0){oa=0;break}else if((ka|0)==255){oa=255;break}do{if(R){ja=72}else{if((Q+1|0)>=(ca|0)){ja=72;break}Y=c[fa>>2]|0;pa=((d[L+Y|0]|0)+(d[L]|0)+(d[L+1|0]|0)+(d[L+(Y+1)|0]|0)|0)>>>2&255}}while(0);do{if((ja|0)==72){ja=0;if(O){pa=a[L]|0;break}do{if(s){if((Q+1|0)>=(ca|0)){ja=76;break}Y=a[L]|0;qa=((d[L+1|0]|0)+(Y&255)|0)>>>1;ra=Y}else{ja=76}}while(0);if((ja|0)==76){ja=0;Y=a[L]|0;qa=Y&255;ra=Y}Y=ra&255;if(W){sa=Y}else{sa=((d[L+(c[fa>>2]|0)|0]|0)+Y|0)>>>1}pa=(sa+qa|0)>>>1&255}}while(0);Y=pa&255;oa=(ka*65025|0|0)/(((Y+ka|0)*255|0)-(ba(Y,ka)|0)|0)|0}else{oa=ka}}while(0);Y=ba(d[L]|0,255-oa|0)|0;a[L]=((((ba(d[V]|0,oa)|0)+Y|0)*257|0)+32896|0)>>>16;Y=Q+1|0;if((Y|0)<(H|0)){Q=Y;V=V+1|0;L=L+1|0;X=X+b|0}else{break}}ta=c[I>>2]|0;ua=c[U>>2]|0;va=c[fa>>2]|0;wa=M}else{ta=J;ua=r;va=S;wa=P+1|0}if((wa|0)<(K|0)){P=wa;E=E+ua|0;N=N+ta|0;m=m+(va<<ha)|0;J=ta;r=ua;S=va}else{break}}}B=B+1|0;}while((B|0)<3);i=g;return e|0}function Sp(a){a=a|0;return Kw((c[(c[a>>2]|0)+44>>2]|0)+40|0,a)|0}function Tp(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;d=Hw(b,(c[b+44>>2]|0)+40|0)|0;if((d|0)<0){e=d;return e|0}d=c[c[b+16>>2]>>2]|0;c[a+20>>2]=c[d+20>>2];c[a+24>>2]=c[d+24>>2];b=d+56|0;d=a+56|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;e=0;return e|0}function Up(a,b){a=a|0;b=b|0;return Jw((c[(c[a+8>>2]|0)+44>>2]|0)+40|0,a,b)|0}function Vp(b){b=b|0;var e=0,f=0;e=c[(c[b+8>>2]|0)+44>>2]|0;f=b+52|0;b=bFb(c[f>>2]|0)|0;bDb(e+480|0,0,b);c[e+512>>2]=d[b+5|0]|0;c[e+516>>2]=d[b+6|0]|0;a[e+16|0]=(Aw(e+17|0,c[f>>2]|0)|0)>>>31&255^1;a[e+21|0]=wk(c[f>>2]|0,1797264)|0;return 0}function Wp(b){b=b|0;var e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0.0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=c[b+8>>2]|0;g=f+44|0;j=c[g>>2]|0;l=b+52|0;b=bFb(c[l>>2]|0)|0;bDb(j+496|0,0,b);m=f+16|0;n=c[m>>2]|0;o=c[n>>2]|0;p=+(c[o+20>>2]|0);h[j+528>>3]=p;h[j+520>>3]=p;p=+(c[o+24>>2]|0);h[j+544>>3]=p;h[j+536>>3]=p;o=c[n+4>>2]|0;p=+(c[o+20>>2]|0);h[j+560>>3]=p;h[j+552>>3]=p;p=+(c[o+24>>2]|0);h[j+576>>3]=p;h[j+568>>3]=p;h[j+584>>3]=+(1<<(d[b+5|0]|0)|0);h[j+592>>3]=+(1<<(d[b+6|0]|0)|0);b=j+600|0;h[b>>3]=+q;o=j+608|0;h[o>>3]=+q;h[j+616>>3]=0.0;h[j+632>>3]=+q;h[j+624>>3]=+q;n=j+652|0;r=c[j+640>>2]|0;s=f;f=c[n>>2]|0;t=JBb(n,r,160160,0,0,0,0,0,s)|0;if((t|0)<0){yDb(s,16,1995488,(u=i,i=i+16|0,c[u>>2]=r,c[u+8>>2]=2166880,u)|0);i=u;c[n>>2]=f;v=t;i=e;return v|0}IBb(f);f=j+656|0;t=c[j+644>>2]|0;n=c[f>>2]|0;r=JBb(f,t,160160,0,0,0,0,0,s)|0;if((r|0)<0){yDb(s,16,1995488,(u=i,i=i+16|0,c[u>>2]=t,c[u+8>>2]=2094728,u)|0);i=u;c[f>>2]=n;v=r;i=e;return v|0}IBb(n);a[j+22|0]=(Aw(j+23|0,c[l>>2]|0)|0)>>>31&255^1;a[j+27|0]=wk(c[l>>2]|0,1797264)|0;if((c[j+32>>2]|0)==0){l=c[g>>2]|0;g=l+652|0;n=l+520|0;r=l+600|0;h[r>>3]=+MBb(c[g>>2]|0,n,0);f=l+608|0;h[f>>3]=+MBb(c[l+656>>2]|0,n,0);p=+MBb(c[g>>2]|0,n,0);h[r>>3]=p;h[k>>3]=p;r=c[k+4>>2]&2147483647;n=2146435072;if(r>>>0>n>>>0|r>>>0==n>>>0&(c[k>>2]|0)>>>0>0>>>0){w=2147483647}else{w=-1<<c[l+512>>2]&~~p}c[l+4>>2]=w;w=c[f+4>>2]&2147483647;n=2146435072;if(w>>>0>n>>>0|w>>>0==n>>>0&(c[f>>2]|0)>>>0>0>>>0){x=2147483647}else{x=-1<<c[l+516>>2]&~~+h[f>>3]}c[l+8>>2]=x;x=c[j+4>>2]|0;p=+h[o>>3];o=c[j+8>>2]|0;yDb(s,40,2040528,(u=i,i=i+32|0,h[u>>3]=+h[b>>3],c[u+8>>2]=x,h[u+16>>3]=p,c[u+24>>2]=o,u)|0);i=u}o=c[c[m>>2]>>2]|0;x=c[o+20>>2]|0;b=c[o+24>>2]|0;l=ZEb(c[o+52>>2]|0)|0;o=c[(c[m>>2]|0)+4>>2]|0;m=c[o+20>>2]|0;f=c[o+24>>2]|0;n=ZEb(c[o+52>>2]|0)|0;o=c[1341800+(c[j+648>>2]<<2)>>2]|0;yDb(s,40,1990808,(u=i,i=i+56|0,c[u>>2]=x,c[u+8>>2]=b,c[u+16>>2]=l,c[u+24>>2]=m,c[u+32>>2]=f,c[u+40>>2]=n,c[u+48>>2]=o,u)|0);i=u;v=0;i=e;return v|0}function Xp(a){a=a|0;Ok(a,Gw(0)|0);return 0}function Yp(a){a=a|0;var b=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+4>>2];c[a+24>>2]=c[b+8>>2];return 0}function Zp(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=Zr(c[c[f+32>>2]>>2]|0,(c[a+4>>2]|0)+b-(c[a+20>>2]|0)|0,(c[a+8>>2]|0)+e-(c[a+24>>2]|0)|0)|0;if((g|0)==0){h=0;return h|0}c[g+68>>2]=b;c[g+72>>2]=e;e=g|0;b=c[e>>2]|0;if((b|0)==0){h=g;return h|0}f=c[g+32>>2]|0;if((f|0)==0){h=g;return h|0}i=c[a+12>>2]|0;j=ba(i>>(d[a+80|0]|0),c[a+60>>2]|0)|0;k=c[a+16>>2]|0;c[e>>2]=b+((ba(k>>(d[a+84|0]|0),f)|0)+j);j=g+4|0;f=c[j>>2]|0;if((f|0)==0){h=g;return h|0}b=c[g+36>>2]|0;if((b|0)==0){h=g;return h|0}c[j>>2]=f+((ba(k>>(d[a+85|0]|0),b)|0)+(ba(i>>(d[a+81|0]|0),c[a+64>>2]|0)|0));b=g+8|0;f=c[b>>2]|0;if((f|0)==0){h=g;return h|0}j=c[g+40>>2]|0;if((j|0)==0){h=g;return h|0}c[b>>2]=f+((ba(k>>(d[a+86|0]|0),j)|0)+(ba(i>>(d[a+82|0]|0),c[a+68>>2]|0)|0));j=g+12|0;f=c[j>>2]|0;if((f|0)==0){h=g;return h|0}b=c[g+44>>2]|0;if((b|0)==0){h=g;return h|0}c[j>>2]=f+((ba(k>>(d[a+87|0]|0),b)|0)+(ba(i>>(d[a+83|0]|0),c[a+72>>2]|0)|0));h=g;return h|0}function _p(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;e=i;i=i+24|0;f=e|0;g=e+16|0;c[g>>2]=b;h=a+8|0;j=c[(c[h>>2]|0)+44>>2]|0;k=j;a:do{if((RCb(b)|0)==0){l=j+4|0;m=j+8|0;n=41}else{o=f;p=f|0;q=b|0;r=b+72|0;s=j+12|0;t=j+16|0;u=j+4|0;v=b+68|0;w=j+8|0;x=f+4|0;y=b+4|0;z=b+8|0;A=b+12|0;B=f+8|0;C=f+12|0;D=0;do{E=c[b+360+(D<<2)>>2]|0;if((E|0)==0){break}TGb(o|0,-1|0,16)|0;do{if((c[q>>2]|0)!=0){if((UCb(b,0)|0)==(E|0)){c[p>>2]=0;F=x}else{F=p}if((c[y>>2]|0)==0){break}if((UCb(b,1)|0)==(E|0)){c[F>>2]=1;G=F+4|0}else{G=F}if((c[z>>2]|0)==0){break}if((UCb(b,2)|0)==(E|0)){c[G>>2]=2;H=G+4|0}else{H=G}if((c[A>>2]|0)==0){break}if((UCb(b,3)|0)!=(E|0)){break}c[H>>2]=3}}while(0);I=E+4|0;J=E+8|0;K=c[p>>2]|0;L=(K|0)>-1;M=b+(K<<2)|0;N=c[x>>2]|0;O=(N|0)>-1;P=b+(N<<2)|0;Q=c[B>>2]|0;R=(Q|0)>-1;S=b+(Q<<2)|0;T=c[C>>2]|0;U=(T|0)>-1;V=b+(T<<2)|0;W=k+84+T|0;X=b+32+(T<<2)|0;T=k+84+Q|0;Y=b+32+(Q<<2)|0;Q=k+84+N|0;Z=b+32+(N<<2)|0;N=k+84+K|0;_=b+32+(K<<2)|0;$=0;aa=K;b:while(1){if(!((aa|0)>-1)){break}K=d[k+80+aa|0]|0;ca=d[k+84+aa|0]|0;da=c[b+(aa<<2)>>2]|0;ea=c[r>>2]|0;fa=c[b+32+(aa<<2)>>2]|0;ga=da+(ba(ea>>ca,fa)|0)|0;ha=c[s>>2]|0;ia=c[k+60+(aa<<2)>>2]|0;ja=ba(ha>>K,ia)|0;ka=c[t>>2]|0;la=(ba(ka>>ca,fa)|0)+ja|0;ja=c[u>>2]|0;ma=ba(ja-ha-(c[v>>2]|0)>>K,ia)|0;ha=(ba((c[w>>2]|0)-(ka+ea)>>ca,fa)|0)+ma|0;if((fa|0)<(ba(ja>>K,ia)|0)){l=u;m=w;n=41;break a}ia=c[I>>2]|0;K=da;if((K-ia|0)<(la|0)){l=u;m=w;n=41;break a}da=ga;if((ia+(c[J>>2]|0)-da|0)<(ha|0)){l=u;m=w;n=41;break a}do{if(L){ia=c[M>>2]|0;if(($|0)!=0){ga=K-(ia+(ba(ea>>(d[N]|0),c[_>>2]|0)|0))|0;if((((ga|0)>0?1:-1)|0)!=(((ga-la|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}ga=da-ia|0;if((((ga|0)>0?1:-1)|0)!=(((ga+ha|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}}if(!O){break}ga=c[P>>2]|0;if(($|0)!=1){ia=K-(ga+(ba(ea>>(d[Q]|0),c[Z>>2]|0)|0))|0;if((((ia|0)>0?1:-1)|0)!=(((ia-la|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}ia=da-ga|0;if((((ia|0)>0?1:-1)|0)!=(((ia+ha|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}}if(!R){break}ia=c[S>>2]|0;if(($|0)!=2){ga=K-(ia+(ba(ea>>(d[T]|0),c[Y>>2]|0)|0))|0;if((((ga|0)>0?1:-1)|0)!=(((ga-la|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}ga=da-ia|0;if((((ga|0)>0?1:-1)|0)!=(((ga+ha|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}}if(!U){break}ga=c[V>>2]|0;if(($|0)==3){break b}ia=K-(ga+(ba(ea>>(d[W]|0),c[X>>2]|0)|0))|0;if((((ia|0)>0?1:-1)|0)!=(((ia-la|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}ia=da-ga|0;if((((ia|0)>0?1:-1)|0)!=(((ia+ha|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}}}while(0);ha=$+1|0;if(!(ha>>>0<4>>>0)){break}$=ha;aa=c[f+(ha<<2)>>2]|0}D=D+1|0;}while((D|0)<4);D=c[g>>2]|0;w=D|0;u=c[w>>2]|0;if((u|0)==0){na=D;oa=0;pa=t;break}v=c[D+32>>2]|0;if((v|0)==0){na=D;oa=0;pa=t;break}r=c[s>>2]|0;C=ba(r>>(d[j+80|0]|0),c[j+60>>2]|0)|0;B=c[t>>2]|0;c[w>>2]=u+(-(C+(ba(B>>(d[j+84|0]|0),v)|0)|0)|0);v=D+4|0;C=c[v>>2]|0;if((C|0)==0){na=D;oa=0;pa=t;break}u=c[D+36>>2]|0;if((u|0)==0){na=D;oa=0;pa=t;break}c[v>>2]=C+(-((ba(r>>(d[j+81|0]|0),c[j+64>>2]|0)|0)+(ba(B>>(d[j+85|0]|0),u)|0)|0)|0);u=D+8|0;C=c[u>>2]|0;if((C|0)==0){na=D;oa=0;pa=t;break}v=c[D+40>>2]|0;if((v|0)==0){na=D;oa=0;pa=t;break}c[u>>2]=C+(-((ba(r>>(d[j+82|0]|0),c[j+68>>2]|0)|0)+(ba(B>>(d[j+86|0]|0),v)|0)|0)|0);v=D+12|0;C=c[v>>2]|0;if((C|0)==0){na=D;oa=0;pa=t;break}u=c[D+44>>2]|0;if((u|0)==0){na=D;oa=0;pa=t;break}c[v>>2]=C+(-((ba(r>>(d[j+83|0]|0),c[j+72>>2]|0)|0)+(ba(B>>(d[j+87|0]|0),u)|0)|0)|0);na=D;oa=0;pa=t}}while(0);do{if((n|0)==41){yDb(c[h>>2]|0,48,2086744,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;f=c[a+20>>2]|0;k=c[l>>2]|0;b=c[a+24>>2]|0;H=c[m>>2]|0;G=Zr(c[c[(c[h>>2]|0)+32>>2]>>2]|0,(f|0)>(k|0)?f:k,(b|0)>(H|0)?b:H)|0;if((G|0)!=0){NCb(G,c[g>>2]|0)|0;na=G;oa=1;pa=j+16|0;break}JCb(g);qa=-12;i=e;return qa|0}}while(0);m=c[pa>>2]|0;if((m|0)==0){ra=0}else{Ew(j+48|0,j+92|0,na|0,na+32|0,0,0,c[j+4>>2]|0,m);ra=c[pa>>2]|0}m=j+8|0;a=c[m>>2]|0;l=c[j+24>>2]|0;n=l+ra|0;G=j+48|0;H=j+92|0;b=na|0;k=na+32|0;if((a|0)>(n|0)){Ew(G,H,b,k,0,n,c[j+4>>2]|0,a-ra-l|0);sa=c[pa>>2]|0}else{sa=ra}ra=j+12|0;Ew(G,H,b,k,0,sa,c[ra>>2]|0,c[(c[g>>2]|0)+72>>2]|0);if(oa){oa=c[g>>2]|0;Dw(G,b,k,oa|0,oa+32|0,c[ra>>2]|0,c[pa>>2]|0,0,0,c[oa+68>>2]|0,c[oa+72>>2]|0)}oa=(c[j+20>>2]|0)+(c[ra>>2]|0)|0;ra=j+4|0;Ew(G,H,b,k,oa,c[pa>>2]|0,(c[ra>>2]|0)-oa|0,c[(c[g>>2]|0)+72>>2]|0);c[na+68>>2]=c[ra>>2];c[na+72>>2]=c[m>>2];if((c[g>>2]|0)!=(na|0)){JCb(g)}qa=cj(c[c[(c[h>>2]|0)+32>>2]>>2]|0,na)|0;i=e;return qa|0}function $p(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,r=0.0,s=0,t=0,u=0,v=0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;b=i;i=i+128|0;e=b|0;f=b+120|0;g=c[a+8>>2]|0;j=c[g+44>>2]|0;k=j+48|0;Bw(k,c[a+52>>2]|0,0)|0;l=j+44|0;Cw(k,j+92|0,l);m=a+20|0;n=+(c[m>>2]|0);h[e+8>>3]=n;o=e|0;h[o>>3]=n;p=a+24|0;r=+(c[p>>2]|0);h[e+24>>3]=r;h[e+16>>3]=r;s=e+40|0;h[s>>3]=+q;t=e+32|0;h[t>>3]=+q;u=e+56|0;h[u>>3]=+q;v=e+48|0;h[v>>3]=+q;w=n/r;h[e+80>>3]=w;x=c[a+28>>2]|0;if((x|0)==0){y=1.0}else{y=+(x|0)/+(c[a+32>>2]|0)}h[e+88>>3]=y;h[e+96>>3]=y*w;h[e+104>>3]=+(1<<(d[j+88|0]|0)|0);h[e+112>>3]=+(1<<(d[j+89|0]|0)|0);a=j+28|0;x=g;OBb(f,c[a>>2]|0,160096,o,0,0,0,0,0,0,x)|0;w=+h[f>>3];h[s>>3]=w;h[t>>3]=w;g=j+4|0;c[g>>2]=~~w;z=c[j+32>>2]|0;A=OBb(f,z,160096,o,0,0,0,0,0,0,x)|0;do{if((A|0)<0){B=z;C=A}else{w=+h[f>>3];h[u>>3]=w;h[v>>3]=w;D=j+8|0;c[D>>2]=~~w;E=c[a>>2]|0;F=OBb(f,E,160096,o,0,0,0,0,0,0,x)|0;if((F|0)<0){B=E;C=F;break}w=+h[f>>3];h[s>>3]=w;h[t>>3]=w;c[g>>2]=~~w;F=j+36|0;OBb(f,c[F>>2]|0,160096,o,0,0,0,0,0,0,x)|0;w=+h[f>>3];E=e+64|0;h[E>>3]=w;G=j+12|0;c[G>>2]=~~w;H=c[j+40>>2]|0;I=OBb(f,H,160096,o,0,0,0,0,0,0,x)|0;if((I|0)<0){B=H;C=I;break}w=+h[f>>3];h[e+72>>3]=w;I=j+16|0;c[I>>2]=~~w;H=c[F>>2]|0;F=OBb(f,H,160096,o,0,0,0,0,0,0,x)|0;if((F|0)<0){B=H;C=F;break}w=+h[f>>3];h[E>>3]=w;E=~~w;c[G>>2]=E;F=c[g>>2]|0;do{if((F|0)>=0){H=c[D>>2]|0;if((H|E|0)<0){break}if((c[I>>2]|0)<0){break}if((F|0)==0){J=c[m>>2]|0;c[g>>2]=J;K=J}else{K=F}if((H|0)==0){c[D>>2]=c[p>>2]}c[g>>2]=Fw(k,0,-1,K)|0;c[D>>2]=Fw(k,1,-1,c[D>>2]|0)|0;c[G>>2]=Fw(k,0,-1,c[G>>2]|0)|0;c[I>>2]=Fw(k,1,-1,c[I>>2]|0)|0;c[j+20>>2]=Fw(k,0,-1,c[m>>2]|0)|0;c[j+24>>2]=Fw(k,1,-1,c[p>>2]|0)|0;H=c[p>>2]|0;J=c[g>>2]|0;L=c[D>>2]|0;M=c[G>>2]|0;N=c[I>>2]|0;O=d[l]|0;P=d[j+45|0]|0;Q=d[j+46|0]|0;R=d[j+47|0]|0;yDb(x,40,2198296,(S=i,i=i+80|0,c[S>>2]=c[m>>2],c[S+8>>2]=H,c[S+16>>2]=J,c[S+24>>2]=L,c[S+32>>2]=M,c[S+40>>2]=N,c[S+48>>2]=O,c[S+56>>2]=P,c[S+64>>2]=Q,c[S+72>>2]=R,S)|0);i=S;R=c[G>>2]|0;Q=c[I>>2]|0;do{if((R|Q|0)>=0){P=c[g>>2]|0;if((P|0)<1){break}O=c[D>>2]|0;if((O|0)<1){break}if(((c[m>>2]|0)+R|0)>>>0>P>>>0){break}if(((c[p>>2]|0)+Q|0)>>>0>O>>>0){break}else{T=0}i=b;return T|0}}while(0);O=(c[m>>2]|0)+R|0;P=(c[p>>2]|0)+Q|0;N=c[g>>2]|0;M=c[D>>2]|0;yDb(x,16,2188312,(S=i,i=i+48|0,c[S>>2]=R,c[S+8>>2]=Q,c[S+16>>2]=O,c[S+24>>2]=P,c[S+32>>2]=N,c[S+40>>2]=M,S)|0);i=S;T=-22;i=b;return T|0}}while(0);yDb(x,16,2205912,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;T=-22;i=b;return T|0}}while(0);yDb(0,16,2172128,(S=i,i=i+8|0,c[S>>2]=B,S)|0);i=S;T=C;i=b;return T|0}function aq(a){a=a|0;$Db((c[a+44>>2]|0)+4|0);return}function bq(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=c[b+8>>2]|0;j=c[h+44>>2]|0;k=c[c[h+32>>2]>>2]|0;h=c[b+20>>2]|0;l=c[b+24>>2]|0;b=j;m=c[b>>2]|0;n=-(-h>>d[m+5|0])|0;o=-l>>d[m+6|0];m=-o|0;p=Zr(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((p|0)==0){JCb(g);q=-12;i=f;return q|0}NCb(p,e)|0;e=p|0;r=c[e>>2]|0;if((r|0)!=0){s=c[p+32>>2]|0;if((s|0)>0){t=0}else{t=ba(s,l-1|0)|0}TGb(r+t|0,0,ba((s|0)>-1?s:-s|0,l)|0)|0}s=p+4|0;t=c[s>>2]|0;if((t|0)!=0){r=c[p+36>>2]|0;if((r|0)>0){u=0}else{u=ba(r,~o)|0}TGb(t+u|0,0,ba((r|0)>-1?r:-r|0,m)|0)|0}r=c[p+8>>2]|0;if((r|0)!=0){u=c[p+40>>2]|0;if((u|0)>0){v=0}else{v=ba(u,~o)|0}TGb(r+v|0,0,ba((u|0)>-1?u:-u|0,m)|0)|0}u=c[p+12>>2]|0;if((u|0)!=0){v=c[p+44>>2]|0;if((v|0)>0){w=0}else{w=ba(v,l-1|0)|0}TGb(u+w|0,0,ba((v|0)>-1?v:-v|0,l)|0)|0}v=c[b>>2]|0;if((a[v+7|0]&66)==0){x=v}else{UGb(c[s>>2]|0,c[(c[g>>2]|0)+4>>2]|0,1024)|0;x=c[b>>2]|0}if((a[x+4|0]|0)!=0){s=j+4|0;j=p+32|0;v=0;w=x;while(1){x=(v-1|0)>>>0<2>>>0;u=x?n:h;r=x?m:l;if((r|0)>0){x=0;o=w;while(1){t=c[g>>2]|0;XEb(c[s>>2]|0,t|0,t+32|0,o,0,x,v,u,0);YEb(c[s>>2]|0,e,j,c[b>>2]|0,0,x,v,u);t=x+1|0;y=c[b>>2]|0;if((t|0)<(r|0)){x=t;o=y}else{z=y;break}}}else{z=w}o=v+1|0;if((o|0)<(d[z+4|0]|0)){v=o;w=z}else{break}}}JCb(g);q=cj(k,p)|0;i=f;return q|0}function cq(a){a=a|0;var b=0,d=0;b=c[(c[a+8>>2]|0)+44>>2]|0;c[b>>2]=bFb(c[a+52>>2]|0)|0;d=b+4|0;$Db(d);b=WDb(c[a+20>>2]<<1)|0;c[d>>2]=b;return((b|0)==0?-12:0)|0}function dq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0;b=i;i=i+128|0;d=b|0;e=c[a+44>>2]|0;h[e+456>>3]=r;h[e+464>>3]=-r;f=e+484|0;g=c[f>>2]|0;do{if((g|0)!=0){j=Kc(g|0,2094416)|0;c[e+480>>2]=j;if((j|0)!=0){break}j=-(c[(ld()|0)>>2]|0)|0;k=d|0;GBb(j,k,128)|0;yDb(a,16,2040400,(l=i,i=i+16|0,c[l>>2]=c[f>>2],c[l+8>>2]=k,l)|0);i=l;m=j;i=b;return m|0}}while(0);c[e+432>>2]=232;m=0;i=b;return m|0}function eq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0.0,k=0.0,l=0.0,m=0.0;b=i;d=c[a+44>>2]|0;e=d+472|0;f=c[e>>2]|0;g=c[e+4>>2]|0;if(!((f|0)==0&(g|0)==0)){e=c[d+504>>2]|0;j=+((ba(e,e)|0)>>>0>>>0);k=+$(j/(+h[d+448>>3]/(+(f>>>0)+ +(g>>>0)*4294967296.0)))*10.0/2.302585092994046;l=+$(j/+h[d+464>>3])*10.0/2.302585092994046;m=+$(j/+h[d+456>>3])*10.0/2.302585092994046;yDb(a,32,2166416,(a=i,i=i+24|0,h[a>>3]=k,h[a+8>>3]=l,h[a+16>>3]=m,a)|0);i=a}Lw(d+8|0);a=c[d+480>>2]|0;if((a|0)==0){i=b;return}fb(a|0)|0;i=b;return}function fq(a){a=a|0;Ok(a,xk(550536)|0);return 0}function gq(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+288|0;j=g|0;k=g+128|0;l=g+256|0;m=c[b+44>>2]|0;b=FCb(e)|0;Be[c[m+556>>2]&127](m,e|0,e+32|0,f|0,f+32|0,c[e+68>>2]|0,c[e+72>>2]|0,l|0);f=m+520|0;n=c[f>>2]|0;o=(n|0)>0;if(o){p=0;q=0.0;while(1){r=q+ +h[l+(p<<3)>>3];s=p+1|0;if((s|0)<(n|0)){p=s;q=r}else{t=r;break}}}else{t=0.0}q=t/+(n|0);n=m+456|0;t=+h[n>>3];h[n>>3]=t>q?q:t;n=m+464|0;t=+h[n>>3];h[n>>3]=t>q?t:q;n=m+448|0;h[n>>3]=q+ +h[n>>3];n=m+472|0;p=YGb(c[n>>2]|0,c[n+4>>2]|0,1,0)|0;c[n>>2]=p;c[n+4>>2]=F;if(o){o=m+508|0;p=j|0;j=k|0;t=q;k=m+488|0;s=m+504|0;u=0;do{if((c[o>>2]|0)==0){v=u}else{v=d[m+(u+512)|0]|0}w=m+(u+516)|0;x=a[w]|0;y=l+(v<<3)|0;Lb(p|0,128,2284104,(z=i,i=i+8|0,h[z>>3]=+h[y>>3],z)|0)|0;i=z;if(x<<24>>24==0){CBb(b,1995352,p,0)|0}else{Lb(j|0,128,2268656,(z=i,i=i+16|0,c[z>>2]=1995352,c[z+8>>2]=x<<24>>24,z)|0)|0;i=z;CBb(b,j,p,0)|0}Lb(p|0,128,2284104,(z=i,i=i+8|0,h[z>>3]=t,z)|0)|0;i=z;CBb(b,1959856,p,0)|0;x=a[w]|0;w=c[k+(v<<2)>>2]|0;r=+$(+((ba(w,w)|0)>>>0>>>0)/+h[y>>3])*10.0/2.302585092994046;Lb(p|0,128,2284104,(z=i,i=i+8|0,h[z>>3]=r,z)|0)|0;i=z;if(x<<24>>24==0){CBb(b,1931880,p,0)|0}else{Lb(j|0,128,2268656,(z=i,i=i+16|0,c[z>>2]=1931880,c[z+8>>2]=x<<24>>24,z)|0)|0;i=z;CBb(b,j,p,0)|0}x=c[s>>2]|0;r=+$(+((ba(x,x)|0)>>>0>>>0)/q)*10.0/2.302585092994046;Lb(p|0,128,2284104,(z=i,i=i+8|0,h[z>>3]=r,z)|0)|0;i=z;CBb(b,1909400,p,0)|0;u=u+1|0;}while((u|0)<(c[f>>2]|0))}u=m+480|0;p=c[u>>2]|0;if((p|0)==0){i=g;return e|0}b=c[n+4>>2]|0;Dd(p|0,1888960,(z=i,i=i+24|0,c[z>>2]=c[n>>2],c[z+8>>2]=b,h[z+16>>3]=q,z)|0)|0;i=z;do{if((c[f>>2]|0)>0){b=m+508|0;n=0;do{if((c[b>>2]|0)==0){A=n}else{A=d[m+(n+512)|0]|0}q=+h[l+(A<<3)>>3];Dd(c[u>>2]|0,2346456,(z=i,i=i+16|0,c[z>>2]=a[m+(n+516)|0]|0,h[z+8>>3]=q,z)|0)|0;i=z;n=n+1|0;B=c[f>>2]|0;}while((n|0)<(B|0));if((B|0)<=0){break}n=m+508|0;b=m+488|0;p=0;do{if((c[n>>2]|0)==0){C=p}else{C=d[m+(p+512)|0]|0}s=c[b+(C<<2)>>2]|0;q=+$(+((ba(s,s)|0)>>>0>>>0)/+h[l+(C<<3)>>3])*10.0/2.302585092994046;Dd(c[u>>2]|0,2325040,(z=i,i=i+16|0,c[z>>2]=a[m+(p+516)|0]|0,h[z+8>>3]=q,z)|0)|0;i=z;p=p+1|0;}while((p|0)<(c[f>>2]|0))}}while(0);lb(10,c[u>>2]|0)|0;i=g;return e|0}function hq(a){a=a|0;return Kw((c[(c[a>>2]|0)+44>>2]|0)+8|0,a)|0}function iq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=c[c[b+16>>2]>>2]|0;c[a+20>>2]=c[e+20>>2];c[a+24>>2]=c[e+24>>2];f=e+56|0;g=a+56|0;h=c[f+4>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;h=e+28|0;g=a+28|0;f=c[h+4>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=f;f=e+116|0;e=a+116|0;a=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=a;a=Hw(b,d+8|0)|0;return((a|0)<0?a:0)|0}function jq(a,b){a=a|0;b=b|0;return Jw((c[(c[a+8>>2]|0)+44>>2]|0)+8|0,a,b)|0}function kq(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=f+52|0;j=bFb(c[h>>2]|0)|0;k=c[f+8>>2]|0;l=c[k+44>>2]|0;m=l+520|0;c[m>>2]=d[j+4|0]|0;n=c[k+16>>2]|0;o=c[n>>2]|0;p=c[n+4>>2]|0;do{if((c[o+20>>2]|0)==(c[p+20>>2]|0)){if((c[o+24>>2]|0)!=(c[p+24>>2]|0)){break}if((c[o+52>>2]|0)!=(c[p+52>>2]|0)){yDb(k,16,2172088,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-22;i=g;return r|0}switch(c[h>>2]|0){case 8:case 32:case 82:case 84:case 86:case 314:case 316:case 88:case 317:case 319:case 320:case 12:case 13:case 34:case 14:{c[l+488>>2]=(1<<((e[j+8>>1]|0)>>>11&15)+1)-1;c[l+492>>2]=(1<<((e[j+10>>1]|0)>>>11&15)+1)-1;c[l+496>>2]=(1<<((e[j+12>>1]|0)>>>11&15)+1)-1;c[l+500>>2]=(1<<((e[j+14>>1]|0)>>>11&15)+1)-1;break};default:{c[l+488>>2]=235<<((e[j+8>>1]|0)>>>11&15)-7;c[l+492>>2]=240<<((e[j+10>>1]|0)>>>11&15)-7;c[l+496>>2]=240<<((e[j+12>>1]|0)>>>11&15)-7;c[l+500>>2]=(1<<((e[j+14>>1]|0)>>>11&15)+1)-1}}n=Aw(l+512|0,c[h>>2]|0)|0;s=n>>>31;c[l+508>>2]=s^1;a[l+516|0]=(n>>31&7)+114;n=(s|0)!=1;a[l+517|0]=n?103:117;a[l+518|0]=n?98:118;a[l+519|0]=97;n=c[m>>2]|0;if((n|0)>0){s=l+488|0;t=l+504|0;u=0;v=c[t>>2]|0;while(1){w=v+(c[s+(u<<2)>>2]|0)|0;c[t>>2]=w;x=u+1|0;if((x|0)<(n|0)){u=x;v=w}else{y=w;break}}}else{y=c[l+504>>2]|0}c[l+504>>2]=(y|0)/(n|0)|0;v=f+24|0;u=-(-(c[v>>2]|0)>>(d[j+6|0]|0))|0;c[l+548>>2]=u;c[l+544>>2]=u;u=c[v>>2]|0;c[l+552>>2]=u;c[l+540>>2]=u;u=f+20|0;v=-(-(c[u>>2]|0)>>(d[j+5|0]|0))|0;c[l+532>>2]=v;c[l+528>>2]=v;v=c[u>>2]|0;c[l+536>>2]=v;c[l+524>>2]=v;c[l+556>>2]=(b[j+8>>1]&16384)>>>0>14336>>>0?10:2;r=0;i=g;return r|0}}while(0);yDb(k,16,2188192,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-22;i=g;return r|0}function lq(a,b,d,f,g,i,j,k){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=c[a+520>>2]|0;if((j|0)>0){l=0}else{return}do{i=c[a+524+(l<<2)>>2]|0;m=c[a+540+(l<<2)>>2]|0;n=(c[g+(l<<2)>>2]|0)/2|0;o=(c[d+(l<<2)>>2]|0)/2|0;if((m|0)>0&(i|0)>0){p=c[b+(l<<2)>>2]|0;q=c[f+(l<<2)>>2]|0;r=0;s=0;t=0;while(1){u=0;v=s;w=t;do{x=(e[p+(u<<1)>>1]|0)-(e[q+(u<<1)>>1]|0)|0;w=YGb(ba(x,x)|0,0,w,v)|0;v=F;u=u+1|0;}while((u|0)<(i|0));u=r+1|0;if((u|0)<(m|0)){p=p+(o<<1)|0;q=q+(n<<1)|0;r=u;s=v;t=w}else{y=v;z=w;break}}}else{y=0;z=0}h[k+(l<<3)>>3]=(+(z>>>0)+ +(y>>>0)*4294967296.0)/+(ba(m,i)|0);l=l+1|0;}while((l|0)<(j|0));return}function mq(a,b,e,f,g,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=c[a+520>>2]|0;if((j|0)>0){l=0}else{return}do{i=c[a+524+(l<<2)>>2]|0;m=c[a+540+(l<<2)>>2]|0;n=c[g+(l<<2)>>2]|0;o=c[e+(l<<2)>>2]|0;if((m|0)>0&(i|0)>0){p=c[b+(l<<2)>>2]|0;q=c[f+(l<<2)>>2]|0;r=0;s=0;t=0;while(1){u=0;v=0;do{w=(d[p+u|0]|0)-(d[q+u|0]|0)|0;v=(ba(w,w)|0)+v|0;u=u+1|0;}while((u|0)<(i|0));u=YGb(v,(v|0)<0|0?-1:0,t,s)|0;w=F;x=r+1|0;if((x|0)<(m|0)){p=p+o|0;q=q+n|0;r=x;s=w;t=u}else{y=w;z=u;break}}}else{y=0;z=0}h[k+(l<<3)>>3]=(+(z>>>0)+ +(y>>>0)*4294967296.0)/+(ba(m,i)|0);l=l+1|0;}while((l|0)<(j|0));return}function nq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=i;i=i+104|0;e=d|0;f=d+8|0;g=d+24|0;h=d+72|0;j=d+80|0;k=d+88|0;l=d+96|0;m=c[b+44>>2]|0;n=c[m+4>>2]|0;if((n|0)==0){yDb(b,16,2166376,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=d;return p|0}q=m+24|0;r=b;b=f;s=g;t=f|0;f=d+40|0;u=Xw(t,f,h,j,e,n,r)|0;if((u|0)<0){v=u}else{u=g|0;g=d+56|0;n=c[h>>2]|0;w=c[j>>2]|0;x=Yw(u,g,n,w,8,t,f,n,w,c[e>>2]|0,r)|0;if((x|0)<0){y=x}else{e=WDb(ba(c[j>>2]|0,c[h>>2]|0)|0)|0;c[q>>2]=e;w=c[h>>2]|0;iDb(e,w,c[u>>2]|0,c[g>>2]|0,w,c[j>>2]|0);y=(e|0)==0?-12:x}$Db(b);$Db(s);v=y}if((v|0)<0){p=v;i=d;return p|0}c[m+16>>2]=c[h>>2];c[m+20>>2]=c[j>>2];v=c[h>>2]|0;qq(c[q>>2]|0,v,v,c[j>>2]|0,16,k);v=cEb((ba(c[j>>2]|0,(c[h>>2]|0)/2|0)|0)/2|0)|0;y=m+44|0;c[y>>2]=v;if((v|0)==0){p=-12;i=d;return p|0}s=c[q>>2]|0;b=c[h>>2]|0;x=(b|0)/2|0;e=c[j>>2]|0;w=(e|0)/2|0;if((e|0)>1){e=(b|0)>1;g=0;do{if(e){u=g<<1;n=ba(u,b)|0;f=ba(u|1,b)|0;u=ba(g,x)|0;t=0;do{z=t<<1;A=z+n|0;do{if((a[s+A|0]|0)==0){if((a[s+(A|1)|0]|0)!=0){B=1;break}C=z+f|0;if((a[s+C|0]|0)!=0){B=1;break}B=(a[s+(C+1)|0]|0)!=0|0}else{B=1}}while(0);a[v+(t+u)|0]=B;t=t+1|0;}while((t|0)<(x|0))}g=g+1|0;}while((g|0)<(w|0))}qq(v,x,x,w,0,l);w=c[k>>2]|0;k=c[l>>2]|0;l=(w|0)>(k|0)?w:k;x=m+12|0;c[x>>2]=l;v=WDb((l<<2)+4|0)|0;l=v;if((v|0)==0){p=-12;i=d;return p|0}a:do{if((c[x>>2]|0)>=0){v=0;b:while(1){g=v<<3|4;B=WDb(g)|0;s=l+(v<<2)|0;c[s>>2]=B;if((B|0)==0){p=-12;D=31;break}B=-v|0;if((v|0)>=(B|0)){b=ba(v,v)|0;e=B;do{t=WDb(g)|0;u=e+v|0;c[(c[s>>2]|0)+(u<<2)>>2]=t;t=c[(c[s>>2]|0)+(u<<2)>>2]|0;if((t|0)==0){p=-12;D=31;break b}f=ba(e,e)|0;n=B;z=t;while(1){c[z+(n+v<<2)>>2]=((ba(n,n)|0)+f|0)<=(b|0);t=n+1|0;if((t|0)>(v|0)){break}n=t;z=c[(c[s>>2]|0)+(u<<2)>>2]|0}e=e+1|0;}while((e|0)<=(v|0))}v=v+1|0;if((v|0)>(c[x>>2]|0)){break a}}if((D|0)==31){i=d;return p|0}}}while(0);c[m+8>>2]=l;l=m+28|0;D=c[h>>2]|0;zw(l,c[q>>2]|0,D,D,c[j>>2]|0,0)|0;D=m+48|0;q=(c[h>>2]|0)/2|0;zw(D,c[y>>2]|0,q,q,(c[j>>2]|0)/2|0,0)|0;j=c[m+32>>2]|0;q=c[m+36>>2]|0;y=c[m+40>>2]|0;yDb(r,40,2094320,(o=i,i=i+40|0,c[o>>2]=c[l>>2],c[o+8>>2]=j,c[o+16>>2]=q,c[o+24>>2]=y,c[o+32>>2]=w,o)|0);i=o;w=c[m+52>>2]|0;y=c[m+56>>2]|0;q=c[m+60>>2]|0;yDb(r,40,2040352,(o=i,i=i+40|0,c[o>>2]=c[D>>2],c[o+8>>2]=w,c[o+16>>2]=y,c[o+24>>2]=q,c[o+32>>2]=k,o)|0);i=o;p=0;i=d;return p|0}function oq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+44>>2]|0;$Db(b+24|0);$Db(b+44|0);a=b+8|0;d=a;if((c[d>>2]|0)==0){return}e=b+12|0;if((c[e>>2]|0)>=0){b=0;do{f=-b|0;if((b|0)>=(f|0)){g=f;do{$Db((c[(c[d>>2]|0)+(b<<2)>>2]|0)+(g+b<<2)|0);g=g+1|0;}while((g|0)<=(b|0))}$Db((c[d>>2]|0)+(b<<2)|0);b=b+1|0;}while((b|0)<=(c[e>>2]|0))}$Db(a);return}function pq(a){a=a|0;Ok(a,xk(550528)|0);return 0}function qq(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((g|0)>0&(f|0)>0){j=0;do{k=ba(j,e)|0;l=0;do{m=b+(l+k)|0;a[m]=(d[m]|0|0)>(h|0)|0;l=l+1|0;}while((l|0)<(f|0));j=j+1|0;}while((j|0)<(g|0))}j=b+(e+1)|0;h=g-1|0;g=(h|0)>1;l=f-1|0;f=(l|0)>1;k=-e|0;m=0;while(1){n=m+1|0;if(g&f){o=1;p=0;q=j}else{r=22;break}while(1){s=2;t=p;u=q;while(1){v=a[u]|0;w=u+1|0;do{if((v&255|0)<(n|0)){x=t}else{if((d[w]|0|0)<(n|0)){x=t;break}if((d[u-1|0]|0|0)<(n|0)){x=t;break}if((d[u+e|0]|0|0)<(n|0)){x=t;break}if((d[u+k|0]|0|0)<(n|0)){x=t;break}a[u]=v+1;x=1}}while(0);if((s|0)>=(l|0)){break}s=s+1|0;t=x;u=w}u=o+1|0;if((u|0)<(h|0)){o=u;p=x;q=q+e|0}else{break}}if((x|0)==0){break}else{m=n}}if((r|0)==22){y=m+2|0;z=y>>2;A=y+z|0;c[i>>2]=A;return}if(g&f){B=1}else{y=m+2|0;z=y>>2;A=y+z|0;c[i>>2]=A;return}do{f=ba(B,e)|0;g=1;do{r=b+(g+f)|0;x=a[r]|0;a[r]=((x&255)>>>2)+x;g=g+1|0;}while((g|0)<(l|0));B=B+1|0;}while((B|0)<(h|0));y=m+2|0;z=y>>2;A=y+z|0;c[i>>2]=A;return}function rq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=c[c[f+32>>2]>>2]|0;do{if((RCb(b)|0)==0){f=Zr(h,c[h+20>>2]|0,c[h+24>>2]|0)|0;if((f|0)!=0){NCb(f,c[e>>2]|0)|0;j=0;k=f;l=c[e>>2]|0;break}JCb(e);m=-12;i=d;return m|0}else{j=1;k=b;l=b}}while(0);b=g+8|0;f=a+20|0;n=c[f>>2]|0;o=a+24|0;tq(c[b>>2]|0,c[l>>2]|0,c[l+32>>2]|0,c[k>>2]|0,c[k+32>>2]|0,c[g+24>>2]|0,n,n,c[o>>2]|0,j,g+28|0);n=c[e>>2]|0;l=g+44|0;a=(c[f>>2]|0)/2|0;p=g+48|0;tq(c[b>>2]|0,c[n+4>>2]|0,c[n+36>>2]|0,c[k+4>>2]|0,c[k+36>>2]|0,c[l>>2]|0,a,a,(c[o>>2]|0)/2|0,j,p);a=c[e>>2]|0;n=(c[f>>2]|0)/2|0;tq(c[b>>2]|0,c[a+8>>2]|0,c[a+40>>2]|0,c[k+8>>2]|0,c[k+40>>2]|0,c[l>>2]|0,n,n,(c[o>>2]|0)/2|0,j,p);if((j|0)==0){JCb(e)}m=cj(h,k)|0;i=d;return m|0}function sq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=c[a+20>>2]|0;g=c[e+16>>2]|0;do{if((f|0)==(g|0)){h=c[a+24>>2]|0;j=c[e+20>>2]|0;if((h|0)==(j|0)){k=0}else{l=j;m=h;break}i=b;return k|0}else{l=c[e+20>>2]|0;m=c[a+24>>2]|0}}while(0);yDb(d,32,1888856,(d=i,i=i+32|0,c[d>>2]=g,c[d+8>>2]=l,c[d+16>>2]=f,c[d+24>>2]=m,d)|0);i=d;k=-22;i=b;return k|0}function tq(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;o=(m|0)!=0;if(!o){iDb(g,h,e,f,k,l)}m=c[n+8>>2]|0;p=n+12|0;q=c[p>>2]|0;if((m|0)>(q|0)){return}r=n|0;s=n+4|0;n=k-1|0;k=l-1|0;l=m;m=c[s>>2]|0;t=q;while(1){q=ba(l,f)|0;u=ba(l,h)|0;v=c[r>>2]|0;if((v|0)>(m|0)){w=m;x=t}else{y=ba(l,j)|0;z=v;do{v=a[i+(z+y)|0]|0;do{if(v<<24>>24==0){if(o){break}a[g+(z+u)|0]=a[e+(z+q)|0]|0}else{A=v&255;B=z-A|0;C=(B|0)<0?0:B;B=l-A|0;D=(B|0)<0?0:B;B=A+z|0;E=(n|0)>(B|0)?B:n;B=A+l|0;F=(k|0)>(B|0)?B:k;do{if((D|0)>(F|0)){G=-1}else{B=(C|0)>(E|0);H=E+1-C|0;I=h-H|0;J=j-H|0;H=b+(A<<2)|0;K=D;L=0;M=0;N=g+((ba(D,h)|0)+C)|0;O=i+((ba(D,j)|0)+C)|0;while(1){if(B){P=L;Q=M;R=N;S=O}else{T=K-D|0;U=C;V=L;W=M;X=N;Y=O;while(1){do{if((a[Y]|0)==0){if((c[(c[(c[H>>2]|0)+(U-C<<2)>>2]|0)+(T<<2)>>2]|0)==0){Z=W;_=V;break}Z=W+1|0;_=(d[X]|0)+V|0}else{Z=W;_=V}}while(0);$=X+1|0;aa=Y+1|0;ca=U+1|0;if((ca|0)>(E|0)){P=_;Q=Z;R=$;S=aa;break}else{U=ca;V=_;W=Z;X=$;Y=aa}}}Y=K+1|0;if((Y|0)>(F|0)){break}else{K=Y;L=P;M=Q;N=R+I|0;O=S+J|0}}if((Q|0)==0){G=-1;break}G=((((Q>>>1)+P|0)>>>0)/(Q>>>0)|0)&255}}while(0);a[g+(z+u)|0]=G}}while(0);z=z+1|0;da=c[s>>2]|0;}while((z|0)<=(da|0));w=da;x=c[p>>2]|0}z=l+1|0;if((z|0)>(x|0)){break}else{l=z;m=w;t=x}}return}function uq(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;d=c[b+44>>2]|0;if((QGb(d,2226568)|0)==0){c[b+48>>2]=0;e=0;return e|0}if(!((QEb(b+40|0,d,-1,a)|0)>-1)){e=-22;return e|0}c[b+48>>2]=1;e=0;return e|0}function vq(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+20|0;IBb(c[b>>2]|0);c[b>>2]=0;return}function wq(a){a=a|0;Ok(a,xk(550440)|0);return 0}function xq(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=i;f=c[a+44>>2]|0;do{if((QGb(b,2166272)|0)!=0){if((QGb(b,2094072)|0)==0){break}else{h=-38}i=g;return h|0}}while(0);b=f+20|0;f=c[b>>2]|0;e=a;a=JBb(b,d,160040,0,0,0,0,0,e)|0;if((a|0)<0){yDb(e,16,2040096,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;c[b>>2]=f;h=a;i=g;return h|0}else{IBb(f);h=a;i=g;return h|0}return 0}function yq(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0;b=i;i=i+8|0;e=b|0;f=c[a>>2]|0;g=c[f+44>>2]|0;j=c[c[f+16>>2]>>2]|0;k=j+52|0;l=bFb(c[k>>2]|0)|0;m=g+176|0;Bw(m,c[k>>2]|0,0)|0;Cw(m,g+220|0,g+40|0);m=d[l+5|0]|0;c[g+52>>2]=m;n=d[l+6|0]|0;c[g+56>>2]=n;o=+(c[j+20>>2]|0);h[g+88>>3]=o;l=g+80|0;h[l>>3]=o;o=+(c[j+24>>2]|0);h[g+104>>3]=o;h[g+96>>3]=o;h[g+144>>3]=+(1<<m|0);h[g+152>>3]=+(1<<n|0);h[g+160>>3]=+q;h[g+168>>3]=+q;n=g+120|0;h[n>>3]=+q;m=g+112|0;h[m>>3]=+q;j=g+136|0;h[j>>3]=+q;p=g+128|0;h[p>>3]=+q;r=g+20|0;IBb(c[r>>2]|0);c[r>>2]=0;s=g+16|0;t=f;f=JBb(r,c[s>>2]|0,160040,1040920,1040936,0,0,0,t)|0;if((f|0)<0){yDb(t,16,2124072,(u=i,i=i+8|0,c[u>>2]=c[s>>2],u)|0);i=u;v=f;i=b;return v|0}f=g+24|0;OBb(e,c[f>>2]|0,160040,l,1040920,1040936,0,0,g,0,t)|0;o=+h[e>>3];h[n>>3]=o;h[m>>3]=o;s=g+36|0;c[s>>2]=~~(+h[e>>3]+.5);r=c[g+28>>2]|0;w=OBb(e,r,160040,l,1040920,1040936,0,0,g,0,t)|0;o=+h[e>>3];do{if((w|0)>=0){x=c[e+4>>2]&2146435072;y=2146435072;if(!((x>>>0<y>>>0|x>>>0==y>>>0&(c[e>>2]&0)>>>0<0>>>0)&o>0.0)){break}h[j>>3]=o;h[p>>3]=o;y=g+32|0;c[y>>2]=~~(+h[e>>3]+.5);x=c[f>>2]|0;z=OBb(e,x,160040,l,1040920,1040936,0,0,g,0,t)|0;A=+h[e>>3];do{if((z|0)>=0){B=c[e+4>>2]&2146435072;C=2146435072;if(!((B>>>0<C>>>0|B>>>0==C>>>0&(c[e>>2]&0)>>>0<0>>>0)&A>0.0)){break}h[n>>3]=A;h[m>>3]=A;c[s>>2]=~~(+h[e>>3]+.5);c[g+60>>2]=fFb(c[k>>2]|0)|0;c[a+20>>2]=c[s>>2];c[a+24>>2]=c[y>>2];v=0;i=b;return v|0}}while(0);yDb(t,16,2118584,(u=i,i=i+24|0,c[u>>2]=2324888,c[u+8>>2]=x,h[u+16>>3]=A,u)|0);i=u;v=z;i=b;return v|0}}while(0);yDb(t,16,2118584,(u=i,i=i+24|0,c[u>>2]=1888800,c[u+8>>2]=r,h[u+16>>3]=o,u)|0);i=u;v=w;i=b;return v|0}function zq(a,b){a=a|0;b=+b;var c=0.0,d=0.0,e=0.0,f=0.0,g=0.0,i=0.0;c=+h[a+80>>3];d=+h[a+96>>3];e=+T(b);f=+U(b);b=d*f;g=e;e=g*(-0.0-c);i=c*g;g=f*(-0.0-d);return+((g<0.0?0.0:g)+((i<0.0?0.0:i)+((b<0.0?0.0:b)+(e<0.0?0.0:e))))}function Aq(a,b){a=a|0;b=+b;var c=0.0,d=0.0,e=0.0,f=0.0,g=0.0,i=0.0;c=+h[a+80>>3];d=+h[a+96>>3];e=+U(b);f=+T(b);b=f*(-0.0-d);g=e;e=g*(-0.0-c);i=d*f;f=c*g;return+((f<0.0?0.0:f)+((i<0.0?0.0:i)+((e<0.0?0.0:e)+(b<0.0?0.0:b))))}function Bq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0.0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=i;i=i+64|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;j=c[c[g+32>>2]>>2]|0;k=c[g+44>>2]|0;l=j+20|0;m=j+24|0;n=Zr(j,c[l>>2]|0,c[m>>2]|0)|0;if((n|0)==0){JCb(e);o=-12;i=d;return o|0}NCb(n,b)|0;b=a+160|0;p=k+160|0;h[p>>3]=+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0;b=(c[e>>2]|0)+136|0;r=c[b>>2]|0;s=c[b+4>>2]|0;if((r|0)==0&(s|0)==(-2147483648|0)){t=+q}else{t=(+(r>>>0)+ +(s|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}s=k+168|0;h[s>>3]=t;t=+MBb(c[k+20>>2]|0,k+80|0,k);h[k+8>>3]=t;u=+h[s>>3];yDb(g,48,2091776,(s=i,i=i+24|0,h[s>>3]=+h[p>>3],h[s+8>>3]=u,h[s+16>>3]=t/3.141592653589793,s)|0);i=s;s=~~(t*65536.0);p=s;r=(s|0)<0|0?-1:0;b=(s|0)<0;v=ZGb(205887,0,p,r)|0;w=fHb(b?v:p,b?F:r,411774,0)|0;r=F;b=0;p=(r|0)>(b|0)|(r|0)==(b|0)&w>>>0>308829>>>0;b=YGb(w,r,-411774,-1)|0;v=p?b:w;w=p?F:r;r=0;p=(w|0)>(r|0)|(w|0)==(r|0)&v>>>0>102942>>>0;r=ZGb(205887,0,v,w)|0;b=p?r:v;v=p?F:w;w=gHb(b,v,b,v)|0;p=F;r=ZGb(0,0,w>>>16|p<<16,p>>>16|0<<16)|0;p=F;w=gHb(b,v,r,p)|0;x=eHb(w,F,393216,0)|0;w=F;y=gHb(x,w,r,p)|0;p=eHb(y,F,1310720,0)|0;y=YGb(p,F,x,w)|0;w=YGb(y,F,b,v)|0;v=w;w=s+102943|0;s=w;b=(w|0)<0|0?-1:0;y=(w|0)<0;w=ZGb(205887,0,s,b)|0;x=fHb(y?w:s,y?F:b,411774,0)|0;b=F;y=0;s=(b|0)>(y|0)|(b|0)==(y|0)&x>>>0>308829>>>0;y=YGb(x,b,-411774,-1)|0;w=s?y:x;x=s?F:b;b=0;s=(x|0)>(b|0)|(x|0)==(b|0)&w>>>0>102942>>>0;b=ZGb(205887,0,w,x)|0;y=s?b:w;w=s?F:x;x=gHb(y,w,y,w)|0;s=F;b=ZGb(0,0,x>>>16|s<<16,s>>>16|0<<16)|0;s=F;x=gHb(y,w,b,s)|0;p=eHb(x,F,393216,0)|0;x=F;r=gHb(p,x,b,s)|0;s=eHb(r,F,1310720,0)|0;r=YGb(s,F,p,x)|0;x=YGb(r,F,y,w)|0;w=x;if((c[k+48>>2]|0)!=0){Ew(k+176|0,k+220|0,n|0,n+32|0,0,0,c[l>>2]|0,c[m>>2]|0)}x=k+60|0;if((c[x>>2]|0)>0){y=k+52|0;r=k+56|0;k=f|0;p=f+4|0;s=f+8|0;b=a+20|0;z=f+12|0;A=a+24|0;a=f+16|0;B=f+20|0;C=f+24|0;D=f+28|0;E=f+32|0;G=f+36|0;H=f+40|0;I=f+44|0;J=f+48|0;K=g+56|0;L=f;f=g+48|0;M=0;do{if((M-1|0)>>>0<2>>>0){N=c[r>>2]|0;O=c[y>>2]|0}else{N=0;O=0}P=-(c[l>>2]|0)>>O;Q=-(c[m>>2]|0)>>N;R=-Q|0;c[k>>2]=c[e>>2];c[p>>2]=n;c[s>>2]=-(-(c[b>>2]|0)>>O);c[z>>2]=-(-(c[A>>2]|0)>>N);c[a>>2]=-P;c[B>>2]=R;c[C>>2]=M;c[D>>2]=ba((P|0)/2|0,w)|0;c[E>>2]=ba((P|0)/-2|0,v)|0;P=(Q|0)/2|0;c[G>>2]=ba(P,v)|0;c[H>>2]=ba(P,w)|0;c[I>>2]=w;c[J>>2]=v;P=c[(c[f>>2]|0)+28>>2]|0;Pe[c[c[K>>2]>>2]&255](g,78,L,0,(P|0)<(R|0)?P:R)|0;M=M+1|0;}while((M|0)<(c[x>>2]|0))}JCb(e);o=cj(j,n)|0;i=d;return o|0}function Cq(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;j=i;i=i+8|0;k=j|0;l=c[f>>2]|0;m=c[f+4>>2]|0;n=c[e+44>>2]|0;e=c[f+16>>2]|0;o=c[f+20>>2]|0;p=c[f+8>>2]|0;q=c[f+12>>2]|0;r=c[f+24>>2]|0;s=c[f+28>>2]|0;t=c[f+32>>2]|0;u=c[f+44>>2]|0;v=c[f+48>>2]|0;w=(ba(o,g)|0)/(h|0)|0;x=(ba(o,g+1|0)|0)/(h|0)|0;if((w|0)>=(x|0)){i=j;return 0}h=ba(w,u)|0;g=ba(w,v)|0;o=(p<<16|0)/2|0;y=(q<<16|0)/2|0;z=(e|0)>0;A=m+(r<<2)|0;B=m+32+(r<<2)|0;m=n+188+(r<<2)|0;C=n+64|0;n=p-1|0;D=q-1|0;E=l+(r<<2)|0;G=l+32+(r<<2)|0;r=k|0;l=w;w=(c[f+40>>2]|0)+h|0;h=(c[f+36>>2]|0)+g|0;while(1){if(z){g=w+t+y|0;f=h+s+o|0;H=0;do{f=f+u|0;g=g-v|0;I=f>>16;J=g>>16;do{if(!((J|0)>(q|0)|(I|0)<=(p|0)&(I|0)>-2&(J|0)>-2^1)){K=c[A>>2]|0;L=ba(c[B>>2]|0,l)|0;M=c[m>>2]|0;N=(ba(M,H)|0)+L|0;L=K+N|0;do{if((c[C>>2]|0)==0){if((I|0)<0){O=0}else{O=(I|0)>(n|0)?n:I}if((J|0)<0){P=0}else{P=(J|0)>(D|0)?D:J}Q=(c[E>>2]|0)+((ba(c[G>>2]|0,P)|0)+(ba(O,M)|0))|0}else{R=c[E>>2]|0;S=c[G>>2]|0;if((I|0)<0){T=0}else{T=(I|0)>(n|0)?n:I}if((J|0)<0){U=0}else{U=(J|0)>(D|0)?D:J}V=f&65535;W=g&65535;X=T+1|0;Y=U+1|0;if((M|0)<=0){Q=r;break}Z=ba(T,M)|0;_=ba(U,S)|0;$=ba((X|0)>(n|0)?n:X,M)|0;X=ba((Y|0)>(D|0)?D:Y,S)|0;S=65536-V|0;Y=65536-W|0;aa=0;ca=W;W=0;da=0;while(1){ea=da+Z|0;fa=da+$|0;ga=(ba(d[R+(fa+_)|0]|0,V)|0)+(ba(d[R+(ea+_)|0]|0,S)|0)|0;ha=(ba(d[R+(fa+X)|0]|0,V)|0)+(ba(d[R+(ea+X)|0]|0,S)|0)|0;ea=gHb(ga,(ga|0)<0|0?-1:0,Y,aa)|0;ga=F;fa=gHb(ha,(ha|0)<0|0?-1:0,ca,W)|0;YGb(fa,F,ea,ga)|0;a[k+da|0]=F;ga=da+1|0;if((ga|0)<(M|0)){da=ga}else{Q=r;break}}}}while(0);if((M|0)==2){b[L>>1]=b[Q>>1]|0;break}else if((M|0)==1){a[L]=a[Q]|0;break}else if((M|0)==4){c[L>>2]=c[Q>>2];break}else if((M|0)==3){da=a[Q]|0;W=a[Q+1|0]|0;a[K+(N+2)|0]=a[Q+2|0]|0;a[K+(N+1)|0]=W;a[L]=da;break}else{UGb(L|0,Q|0,M)|0;break}}}while(0);H=H+1|0;}while((H|0)<(e|0))}H=l+1|0;if((H|0)<(x|0)){l=H;w=w+u|0;h=h+v|0}else{break}}i=j;return 0}function Dq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+40|0;e=d|0;f=d+32|0;g=c[a+44>>2]|0;h=g+28|0;j=c[h>>2]|0;k=c[g+60>>2]|0;a:do{if((j|0)==0){l=g+60|0;if((k|0)==0){m=l;n=14;break}if((c[g+64>>2]|0)!=0){o=j;p=k;q=l;n=9;break}c[h>>2]=k;c[l>>2]=j;o=k;p=j;q=l;n=9}else{do{if((k|0)==0){if((c[g+64>>2]|0)!=0){break}o=j;p=0;q=g+60|0;n=9;break a}}while(0);yDb(a,16,2165024,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=d;return s|0}}while(0);if((n|0)==9){do{if((o|0)==0){t=p}else{j=g+20|0;k=g+24|0;l=OEb(j,k,o)|0;if((l|0)>=0){u=e|0;Lb(u|0,31,2039456,(r=i,i=i+8|0,c[r>>2]=c[j>>2],r)|0)|0;i=r;rEb(g,1994776,u,0)|0;Lb(u|0,31,2039456,(r=i,i=i+8|0,c[r>>2]=c[k>>2],r)|0)|0;i=r;rEb(g,1959456,u,0)|0;t=c[q>>2]|0;break}yDb(a,16,2093280,(r=i,i=i+8|0,c[r>>2]=c[h>>2],r)|0);i=r;s=l;i=d;return s|0}}while(0);if((t|0)==0){m=q;n=14}else{v=q}}if((n|0)==14){rEb(g,1994776,1931592,0)|0;v=m}m=g+64|0;n=c[m>>2]|0;if((n|0)==0){rEb(g,1959456,1909e3,0)|0;w=c[m>>2]|0}else{w=n}n=g+68|0;m=c[n>>2]|0;q=c[g+56>>2]|0;yDb(a,40,1888656,(r=i,i=i+32|0,c[r>>2]=c[v>>2],c[r+8>>2]=w,c[r+16>>2]=(m|0)!=0?m:9203648,c[r+24>>2]=q,r)|0);i=r;r=g+32|0;c[r>>2]=0;do{if((c[n>>2]|0)!=0){c[f>>2]=_rb()|0;q=f;m=qEb(q,2324776,0,0,2)|0;w=uEb(q,m,c[n>>2]|0,r)|0;if((w|0)<0){s=w}else{break}i=d;return s|0}}while(0);c[g+16>>2]=c[b>>2];c[b>>2]=0;s=0;i=d;return s|0}function Eq(a){a=a|0;var b=0;b=c[a+44>>2]|0;a=b+4|0;Dsb(c[a>>2]|0);Dsb(c[b+8>>2]|0);Dsb(c[b+12>>2]|0);c[a>>2]=0;DBb(b+16|0);return}function Fq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=a+16|0;do{if((c[c[e>>2]>>2]|0)!=0){c[d>>2]=0;f=0;while(1){if((tsb(f)|0)==0){if((vsb(f)|0)!=0){g=5}}else{g=5}if((g|0)==5){g=0;h=zk(d,f,(f|0)<0|0?-1:0)|0;if((h|0)<0){break}}j=f+1|0;if((j|0)<333){f=j}else{g=8;break}}if((g|0)==8){Hk(c[d>>2]|0,(c[c[e>>2]>>2]|0)+68|0);break}Ik(d);k=h;i=b;return k|0}}while(0);h=a+32|0;if((c[c[h>>2]>>2]|0)==0){k=0;i=b;return k|0}c[d>>2]=0;a=0;while(1){if((usb(a)|0)!=0|(a|0)==11){g=13}else{if((vsb(a)|0)!=0){g=13}}if((g|0)==13){g=0;l=zk(d,a,(a|0)<0|0?-1:0)|0;if((l|0)<0){g=14;break}}e=a+1|0;if((e|0)<333){a=e}else{g=16;break}}if((g|0)==14){Ik(d);k=l;i=b;return k|0}else if((g|0)==16){Hk(c[d>>2]|0,(c[c[h>>2]>>2]|0)+64|0);k=0;i=b;return k|0}return 0}function Gq(a){a=a|0;var b=0;if((a|0)==0){b=_rb()|0}else{b=0}return b|0}function Hq(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0,G=0.0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;e=i;i=i+160|0;f=e|0;g=e+120|0;j=e+128|0;k=e+144|0;l=e+152|0;m=l;n=c[b>>2]|0;o=c[c[n+16>>2]>>2]|0;p=b+52|0;r=c[p>>2]|0;s=c[n+44>>2]|0;t=o+52|0;u=bFb(c[t>>2]|0)|0;v=bFb(c[p>>2]|0)|0;w=o+20|0;x=+(c[w>>2]|0);h[f+8>>3]=x;y=f|0;h[y>>3]=x;z=o+24|0;A=+(c[z>>2]|0);h[f+24>>3]=A;h[f+16>>3]=A;B=f+40|0;h[B>>3]=+q;C=f+32|0;h[C>>3]=+q;D=f+56|0;h[D>>3]=+q;E=f+48|0;h[E>>3]=+q;G=x/A;h[f+64>>3]=G;H=o+28|0;I=H|0;J=c[I>>2]|0;if((J|0)==0){K=1.0}else{K=+(J|0)/+(c[o+32>>2]|0)}h[f+72>>3]=K;h[f+80>>3]=K*G;h[f+88>>3]=+(1<<(d[u+5|0]|0)|0);h[f+96>>3]=+(1<<(d[u+6|0]|0)|0);h[f+104>>3]=+(1<<(d[v+5|0]|0)|0);h[f+112>>3]=+(1<<(d[v+6|0]|0)|0);v=s+60|0;f=n;OBb(g,c[v>>2]|0,159976,y,0,0,0,0,0,0,f)|0;G=+h[g>>3];h[B>>3]=G;h[C>>3]=G;C=s+20|0;c[C>>2]=~~G;B=s+64|0;n=c[B>>2]|0;J=OBb(g,n,159976,y,0,0,0,0,0,0,f)|0;do{if((J|0)<0){L=J;M=n}else{G=+h[g>>3];h[D>>3]=G;h[E>>3]=G;N=s+24|0;c[N>>2]=~~G;O=c[v>>2]|0;P=OBb(g,O,159976,y,0,0,0,0,0,0,f)|0;if((P|0)<0){L=P;M=O;break}O=~~+h[g>>3];c[C>>2]=O;P=c[N>>2]|0;Q=(O|0)<-1?-O|0:1;R=(P|0)<-1?-P|0:1;if((O&P|0)<0){c[N>>2]=0;c[C>>2]=0;S=0;T=8}else{if((O|0)==0){S=P;T=8}else{U=O;V=P}}if((T|0)==8){U=c[w>>2]|0;V=S}if((V|0)==0){W=c[z>>2]|0}else{W=V}P=W;O=(W|0)<0|0?-1:0;if((U|0)<0){N=c[w>>2]|0;X=ba(c[z>>2]|0,Q)|0;Y=IDb(P,O,N,(N|0)<0|0?-1:0,X,(X|0)<0|0?-1:0)|0;X=gHb(Y,F,Q,(Q|0)<0|0?-1:0)|0;Z=F;_=X}else{Z=(U|0)<0|0?-1:0;_=U}if((W|0)<0){X=c[z>>2]|0;Q=ba(c[w>>2]|0,R)|0;Y=IDb(_,Z,X,(X|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;Q=gHb(Y,F,R,(R|0)<0|0?-1:0)|0;$=F;aa=Q}else{$=O;aa=P}P=c[s+104>>2]|0;do{if((P|0)==0){ca=Z;da=_;ea=$;fa=aa}else{O=c[w>>2]|0;Q=O;R=(O|0)<0|0?-1:0;O=c[z>>2]|0;Y=O;X=(O|0)<0|0?-1:0;O=IDb(aa,$,Q,R,Y,X)|0;N=IDb(_,Z,Y,X,Q,R)|0;R=N;N=O;O=N;Q=(N|0)<0|0?-1:0;N=(Q|0)>(Z|0)|(Q|0)==(Z|0)&O>>>0>_>>>0;if((P|0)==1){X=R;Y=(R|0)<0|0?-1:0;ga=(Y|0)>($|0)|(Y|0)==($|0)&X>>>0>aa>>>0;ca=N?Z:Q;da=N?_:O;ea=ga?$:Y;fa=ga?aa:X;break}else{X=R;ga=(R|0)<0|0?-1:0;R=(ga|0)>($|0)|(ga|0)==($|0)&X>>>0>aa>>>0;ca=N?Q:Z;da=N?O:_;ea=R?ga:$;fa=R?X:aa;break}}}while(0);P=0;X=0;do{if((ca|0)>(P|0)|(ca|0)==(P|0)&da>>>0>2147483647>>>0|((ea|0)>(X|0)|(ea|0)==(X|0)&fa>>>0>2147483647>>>0)){T=22}else{R=c[w>>2]|0;ga=gHb(R,(R|0)<0|0?-1:0,fa,ea)|0;R=F;O=0;if((R|0)>(O|0)|(R|0)==(O|0)&ga>>>0>2147483647>>>0){T=22;break}ga=c[z>>2]|0;O=gHb(ga,(ga|0)<0|0?-1:0,da,ca)|0;ga=F;R=0;if((ga|0)>(R|0)|(ga|0)==(R|0)&O>>>0>2147483647>>>0){T=22}}}while(0);if((T|0)==22){yDb(f,16,1990680,(ha=i,i=i+1|0,i=i+7&-8,c[ha>>2]=0,ha)|0);i=ha}X=b+20|0;c[X>>2]=da;P=b+24|0;c[P>>2]=fa;O=d[u+7|0]|0;if((O&2|0)==0){ia=O>>>6&1}else{ia=1}c[s+48>>2]=ia;O=(r|0)==11?19:r;if((a[(bFb(O)|0)+7|0]&2)==0){ja=(d[(bFb(O)|0)+7|0]|0)>>>6&1}else{ja=1}c[s+52>>2]=ja;R=s+4|0;ga=c[R>>2]|0;if((ga|0)!=0){Dsb(ga)}ga=s+8|0;N=c[ga>>2]|0;if((N|0)!=0){Dsb(N)}N=s+12|0;Q=c[N>>2]|0;if((Q|0)!=0){Dsb(Q)}c[R>>2]=0;c[N>>2]=0;c[ga>>2]=0;do{if((c[w>>2]|0)==(c[X>>2]|0)){if((c[z>>2]|0)!=(c[P>>2]|0)){T=36;break}if((c[t>>2]|0)!=(c[p>>2]|0)){T=36}}else{T=36}}while(0);a:do{if((T|0)==36){c[j>>2]=R;c[j+4>>2]=ga;c[j+8>>2]=N;Q=s+16|0;Y=O;ka=(O|0)<0|0?-1:0;la=s+32|0;ma=s+96|0;na=s+100|0;oa=s+88|0;pa=s+92|0;qa=s+56|0;ra=0;b:while(1){if((ra|0)>=3){break a}sa=c[j+(ra<<2)>>2]|0;ta=zsb()|0;c[sa>>2]=ta;if((ta|0)==0){ua=-12;T=50;break}va=c[Q>>2]|0;c:do{if((va|0)==0){wa=ta}else{xa=0;ya=va;while(1){za=BBb(ya,9203648,xa,2)|0;Aa=c[sa>>2]|0;if((za|0)==0){wa=Aa;break c}Ba=rEb(Aa,c[za>>2]|0,c[za+4>>2]|0,0)|0;if((Ba|0)<0){ua=Ba;T=50;break b}xa=za;ya=c[Q>>2]|0}}}while(0);va=c[w>>2]|0;vEb(wa,1987056,va,(va|0)<0|0?-1:0,0)|0;va=(ra|0)!=0|0;ta=c[z>>2]>>va;vEb(c[sa>>2]|0,1983008,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[t>>2]|0;vEb(c[sa>>2]|0,1980120,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[X>>2]|0;vEb(c[sa>>2]|0,1977432,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[P>>2]>>va;vEb(c[sa>>2]|0,1974864,ta,(ta|0)<0|0?-1:0,0)|0;vEb(c[sa>>2]|0,1973096,Y,ka,0)|0;vEb(c[sa>>2]|0,2324776,c[la>>2]|0,0,0)|0;ta=c[ma>>2]|0;vEb(c[sa>>2]|0,1968880,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[na>>2]|0;vEb(c[sa>>2]|0,1961024,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[oa>>2]|0;vEb(c[sa>>2]|0,1958880,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[pa>>2]|0;vEb(c[sa>>2]|0,1956840,ta,(ta|0)<0|0?-1:0,0)|0;ta=Asb(c[sa>>2]|0,0,0)|0;if((ta|0)<0){ua=ta;T=50;break}if((c[qa>>2]|0)==0){break a}else{ra=ra+1|0}}if((T|0)==50){i=e;return ua|0}}}while(0);O=b+28|0;if((c[I>>2]|0)==0){N=H;ga=O;R=c[N+4>>2]|0;c[ga>>2]=c[N>>2];c[ga+4>>2]=R}else{c[k>>2]=ba(c[w>>2]|0,c[P>>2]|0)|0;c[k+4>>2]=ba(c[z>>2]|0,c[X>>2]|0)|0;jFb(m,k,H);R=O;ga=c[l+4>>2]|0;c[R>>2]=c[l>>2];c[R+4>>2]=ga}ga=c[w>>2]|0;R=c[z>>2]|0;N=ZEb(c[t>>2]|0)|0;ra=c[I>>2]|0;qa=c[o+32>>2]|0;pa=c[X>>2]|0;oa=c[P>>2]|0;na=ZEb(c[p>>2]|0)|0;ma=c[O>>2]|0;O=c[b+32>>2]|0;la=c[s+32>>2]|0;yDb(f,40,1954416,(ha=i,i=i+88|0,c[ha>>2]=ga,c[ha+8>>2]=R,c[ha+16>>2]=N,c[ha+24>>2]=ra,c[ha+32>>2]=qa,c[ha+40>>2]=pa,c[ha+48>>2]=oa,c[ha+56>>2]=na,c[ha+64>>2]=ma,c[ha+72>>2]=O,c[ha+80>>2]=la,ha)|0);i=ha;ua=0;i=e;return ua|0}}while(0);f=c[v>>2]|0;v=c[B>>2]|0;yDb(0,16,1952160,(ha=i,i=i+24|0,c[ha>>2]=M,c[ha+8>>2]=f,c[ha+16>>2]=v,ha)|0);i=ha;ua=L;i=e;return ua|0}function Iq(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+96|0;f=e|0;g=e+8|0;h=e+40|0;j=e+48|0;k=e+56|0;l=e+64|0;m=e+72|0;n=e+80|0;o=e+88|0;c[f>>2]=b;p=a+8|0;q=c[p>>2]|0;r=c[q+44>>2]|0;s=c[c[q+32>>2]>>2]|0;q=a+52|0;t=bFb(c[q>>2]|0)|0;u=a+20|0;do{if((c[b+68>>2]|0)==(c[u>>2]|0)){if((c[b+72>>2]|0)!=(c[a+24>>2]|0)){v=4;break}if((c[b+80>>2]|0)!=(c[q>>2]|0)){v=4}}else{v=4}}while(0);do{if((v|0)==4){q=g|0;Lb(q|0,31,2039456,(b=i,i=i+8|0,c[b>>2]=c[s+20>>2],b)|0)|0;i=b;rEb(r,1994776,q,0)|0;Lb(q|0,31,2039456,(b=i,i=i+8|0,c[b>>2]=c[s+24>>2],b)|0)|0;i=b;rEb(r,1959456,q,0)|0;q=c[f>>2]|0;b=c[c[(c[p>>2]|0)+16>>2]>>2]|0;c[b+52>>2]=c[q+80>>2];c[b+20>>2]=c[q+68>>2];c[b+24>>2]=c[q+72>>2];q=Hq(s)|0;if((q|0)<0){w=q}else{break}i=e;return w|0}}while(0);g=r+4|0;if((c[g>>2]|0)==0){w=cj(s,c[f>>2]|0)|0;i=e;return w|0}c[r+36>>2]=d[t+5|0]|0;c[r+40>>2]=d[t+6|0]|0;t=s+20|0;q=s+24|0;b=Zr(s,c[t>>2]|0,c[q>>2]|0)|0;if((b|0)==0){JCb(f);w=-12;i=e;return w|0}NCb(b,c[f>>2]|0)|0;c[b+68>>2]=c[t>>2];c[b+72>>2]=c[q>>2];if((c[r+52>>2]|0)!=0){x=c[s+52>>2]|0;fDb(c[b+4>>2]|0,(x|0)==11?19:x)|0}x=DCb(c[f>>2]|0)|0;y=r+72|0;do{if((c[y>>2]|0)==0){if((c[r+76>>2]|0)!=0){v=15;break}if((c[r+80>>2]|x|0)!=0){v=15;break}if((c[r+84>>2]|0)!=0){v=15}}else{v=15}}while(0);do{if((v|0)==15){ysb(c[g>>2]|0,n,h,o,j,k,l,m)|0;z=c[y>>2]|0;if((z|0)!=0){c[n>>2]=Jq(z,BCb(c[f>>2]|0)|0)|0}z=c[r+76>>2]|0;if((z|0)!=0){c[o>>2]=Jq(z,2)|0}z=c[r+80>>2]|0;do{if((z|0)==0){if((x|0)==0){break}c[h>>2]=(x|0)==2}else{c[h>>2]=(z|0)==2}}while(0);z=c[r+84>>2]|0;if((z|0)==0){A=c[j>>2]|0}else{B=(z|0)==2|0;c[j>>2]=B;A=B}wsb(c[g>>2]|0,c[n>>2]|0,c[h>>2]|0,c[o>>2]|0,A,c[k>>2]|0,c[l>>2]|0,c[m>>2]|0)|0;B=c[r+8>>2]|0;if((B|0)!=0){wsb(B,c[n>>2]|0,c[h>>2]|0,c[o>>2]|0,c[j>>2]|0,c[k>>2]|0,c[l>>2]|0,c[m>>2]|0)|0}B=c[r+12>>2]|0;if((B|0)==0){break}wsb(B,c[n>>2]|0,c[h>>2]|0,c[o>>2]|0,c[j>>2]|0,c[k>>2]|0,c[l>>2]|0,c[m>>2]|0)|0}}while(0);m=c[f>>2]|0;l=c[m+124>>2]|0;k=c[q>>2]|0;q=gHb(k,(k|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=c[u>>2]|0;u=gHb(q,F,l,(l|0)<0|0?-1:0)|0;l=F;q=c[m+128>>2]|0;m=c[t>>2]|0;t=gHb(m,(m|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;q=a+24|0;a=c[q>>2]|0;m=gHb(t,F,a,(a|0)<0|0?-1:0)|0;iFb(b+124|0,b+128|0,u,l,m,F,2147483647,0)|0;m=c[r+56>>2]|0;do{if((m|0)>0){C=c[f>>2]|0;v=34}else{l=c[f>>2]|0;if((m|0)<0){if((c[l+296>>2]|0)!=0){C=l;v=34;break}}Kq(c[(c[p>>2]|0)+44>>2]|0,b,l,c[g>>2]|0,c[q>>2]|0,1,0)}}while(0);if((v|0)==34){Kq(c[(c[p>>2]|0)+44>>2]|0,b,C,c[r+8>>2]|0,((c[q>>2]|0)+1|0)/2|0,2,0);Kq(c[(c[p>>2]|0)+44>>2]|0,b,c[f>>2]|0,c[r+12>>2]|0,(c[q>>2]|0)/2|0,2,1)}JCb(f);w=cj(s,b)|0;i=e;return w|0}function Jq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=(a|0)==0?1919320:a;a=(yb(c|0,1916136)|0)!=0;a:do{if(a){d=a?1:b}else{e=(yb(c|0,1910272)|0)!=0;if(e){d=e?4:b;break}e=(yb(c|0,1908768)|0)!=0;if(e){d=e?7:b;break}do{if((yb(c|0,1919320)|0)==0){if((yb(c|0,1907232)|0)!=0){break}if((yb(c|0,1905648)|0)==0){d=b;break a}}}while(0);d=5}}while(0);return Esb((d|0)==0|d>>>0>7>>>0?5:d)|0}function Kq(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+64|0;k=j|0;l=j+16|0;m=j+32|0;n=j+48|0;o=c[d+32>>2]|0;p=m|0;c[p>>2]=ba(o,g)|0;q=c[b+32>>2]|0;r=n|0;c[r>>2]=ba(q,g)|0;s=k|0;c[s>>2]=(c[d>>2]|0)+(ba(o,h)|0);o=l|0;c[o>>2]=(c[b>>2]|0)+(ba(q,h)|0);q=c[d+36>>2]|0;c[m+4>>2]=ba(q,g)|0;t=c[b+36>>2]|0;c[n+4>>2]=ba(t,g)|0;u=c[d+4>>2]|0;v=k+4|0;c[v>>2]=u+(ba(q,h)|0);q=c[b+4>>2]|0;w=l+4|0;c[w>>2]=q+(ba(t,h)|0);t=c[d+40>>2]|0;c[m+8>>2]=ba(t,g)|0;x=c[b+40>>2]|0;c[n+8>>2]=ba(x,g)|0;c[k+8>>2]=(c[d+8>>2]|0)+(ba(t,h)|0);c[l+8>>2]=(c[b+8>>2]|0)+(ba(x,h)|0);x=c[d+44>>2]|0;c[m+12>>2]=ba(x,g)|0;m=c[b+44>>2]|0;c[n+12>>2]=ba(m,g)|0;c[k+12>>2]=(c[d+12>>2]|0)+(ba(x,h)|0);c[l+12>>2]=(c[b+12>>2]|0)+(ba(m,h)|0);if((c[a+48>>2]|0)!=0){c[v>>2]=u}if((c[a+52>>2]|0)==0){y=bsb(e,s,p,0,f,o,r)|0;i=j;return}c[w>>2]=q;y=bsb(e,s,p,0,f,o,r)|0;i=j;return}function Lq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=Ni(c[c[b+16>>2]>>2]|0)|0;if(!((e|0)==-541478725)){f=e;return f|0}e=d+4|0;b=c[e>>2]|0;if((b|0)==0){f=-541478725;return f|0}g=b+136|0;h=c[g>>2]|0;i=c[g+4>>2]<<1|h>>>31;c[g>>2]=h<<1|0>>>31;c[g+4>>2]=i;i=c[d>>2]|0;a:do{if((i|0)>0){if((c[b+300>>2]|0)==0){d=0;while(1){g=b+32+(d<<2)|0;c[g>>2]=c[g>>2]<<1;g=d+1|0;if((g|0)<(i|0)){d=g}else{j=b;break a}}}else{k=0}do{d=b+(k<<2)|0;g=b+32+(k<<2)|0;h=c[g>>2]|0;c[d>>2]=(c[d>>2]|0)+h;c[g>>2]=h<<1;k=k+1|0;}while((k|0)<(i|0));j=c[e>>2]|0}else{j=b}}while(0);b=cj(a,j)|0;c[e>>2]=0;f=b;return f|0}function Mq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=c[c[d+16>>2]>>2]|0;c[e>>2]=fFb(c[f+52>>2]|0)|0;e=f+24|0;if((c[e>>2]&1|0)==0){c[a+56>>2]=c[f+56>>2];c[a+60>>2]=c[f+60>>2]<<1;c[a+116>>2]=c[f+116>>2]<<1;c[a+120>>2]=c[f+120>>2];c[a+20>>2]=c[f+20>>2];c[a+24>>2]=(c[e>>2]|0)/2|0;g=0;i=b;return g|0}else{yDb(d,16,2092224,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;g=-1094995529;i=b;return g|0}return 0}function Nq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[a+8>>2]|0;a=c[d+44>>2]|0;e=c[c[d+32>>2]>>2]|0;c[b+72>>2]=c[e+24>>2];c[b+296>>2]=0;d=a+4|0;f=c[d>>2]|0;do{if((f|0)!=0){g=c[a>>2]|0;if((g|0)>0){if((c[f+300>>2]|0)==0){h=0;do{i=f+32+(h<<2)|0;c[i>>2]=c[i>>2]<<1;h=h+1|0;}while((h|0)<(g|0))}else{h=0;do{i=f+(h<<2)|0;j=f+32+(h<<2)|0;k=c[j>>2]|0;c[i>>2]=(c[i>>2]|0)+k;c[j>>2]=k<<1;h=h+1|0;}while((h|0)<(g|0))}}g=f+136|0;h=c[g>>2]|0;k=c[g+4>>2]|0;if((h|0)==0&(k|0)==(-2147483648|0)){l=-2147483648;m=0}else{j=b+136|0;i=c[j>>2]|0;n=c[j+4>>2]|0;j=(i|0)==0&(n|0)==(-2147483648|0);o=YGb(i,n,h,k)|0;l=j?-2147483648:F;m=j?0:o}c[g>>2]=m;c[g+4>>2]=l;g=cj(e,f)|0;if((g|0)<0){p=g}else{break}return p|0}}while(0);f=PCb(b)|0;c[d>>2]=f;if((f|0)==0){p=-12;return p|0}f=c[a>>2]|0;if((f|0)>0){if((c[b+300>>2]|0)==0){a=0;do{d=b+(a<<2)|0;l=b+32+(a<<2)|0;m=c[l>>2]|0;c[d>>2]=(c[d>>2]|0)+m;c[l>>2]=m<<1;a=a+1|0;}while((a|0)<(f|0))}else{a=0;do{m=b+32+(a<<2)|0;c[m>>2]=c[m>>2]<<1;a=a+1|0;}while((a|0)<(f|0))}}f=b+136|0;a=c[f>>2]|0;m=c[f+4>>2]|0;if(!((a|0)==0&(m|0)==(-2147483648|0))){c[f>>2]=a<<1|0>>>31;c[f+4>>2]=m<<1|a>>>31}p=cj(e,b)|0;return p|0}function Oq(a,b){a=a|0;b=b|0;var d=0;d=c[a+8>>2]|0;a=c[(c[d+44>>2]|0)+4>>2]|0;if((a|0)==2){c[b+296>>2]=0}else if((a|0)!=(-1|0)){c[b+296>>2]=1;c[b+300>>2]=a}return cj(c[c[d+32>>2]>>2]|0,b)|0}function Pq(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;f=i;i=i+80|0;g=f|0;j=f+16|0;k=f+48|0;l=b+8|0;m=c[l>>2]|0;n=bFb(c[b+52>>2]|0)|0;TGb(g|0,0,16)|0;o=d[n+6|0]|0;p=e+80|0;q=e+68|0;r=b+24|0;s=0;t=0;while(1){u=e+(s<<2)|0;if((c[u>>2]|0)==0){v=t;break}w=e+32+(s<<2)|0;if((c[w>>2]|0)==0){v=t;break}x=cDb(c[p>>2]|0,c[q>>2]|0,s)|0;y=c[r>>2]|0;if((s-1|0)>>>0<2>>>0){z=-(-y>>o)|0}else{z=y}if((x|0)<0){A=x;B=24;break}if((z|0)>0){y=g+(s<<2)|0;C=c[w>>2]|0;w=0;D=t;E=c[u>>2]|0;u=c[y>>2]|0;while(1){G=eAb(u,E,x)|0;H=eAb(D,E,x)|0;I=w+1|0;if((I|0)<(z|0)){w=I;D=H;E=E+C|0;u=G}else{break}}c[y>>2]=G;J=H}else{J=t}u=s+1|0;if((u|0)<4){s=u;t=J}else{v=J;break}}if((B|0)==24){i=f;return A|0}B=m;m=b+160|0;J=c[m>>2]|0;t=c[m+4>>2]|0;m=j|0;TGb(m|0,0,32)|0;a[m]=0;j=e+136|0;s=c[j>>2]|0;H=c[j+4>>2]|0;if((s|0)==0&(H|0)==(-2147483648|0)){Lb(m|0,32,1958952,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}else{Lb(m|0,32,1908816,(K=i,i=i+16|0,c[K>>2]=s,c[K+8>>2]=H,K)|0)|0;i=K}H=k|0;TGb(H|0,0,32)|0;a[H]=0;k=c[j>>2]|0;s=c[j+4>>2]|0;if((k|0)==0&(s|0)==(-2147483648|0)){Lb(H|0,32,1958952,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}else{Lb(H|0,32,1931320,(K=i,i=i+8|0,h[K>>3]=(+(k>>>0)+ +(s|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),K)|0)|0;i=K}b=sCb(e)|0;s=F;k=c[n>>2]|0;n=c[e+124>>2]|0;j=c[e+128>>2]|0;G=c[q>>2]|0;q=c[e+72>>2]|0;if((c[e+296>>2]|0)==0){L=80}else{L=(c[e+300>>2]|0)!=0?84:66}z=c[e+84>>2]|0;o=(mGb(c[e+88>>2]|0)|0)<<24>>24;r=c[g>>2]|0;yDb(B,32,2092e3,(K=i,i=i+128|0,c[K>>2]=J,c[K+8>>2]=t,c[K+16>>2]=m,c[K+24>>2]=H,c[K+32>>2]=b,c[K+40>>2]=s,c[K+48>>2]=k,c[K+56>>2]=n,c[K+64>>2]=j,c[K+72>>2]=G,c[K+80>>2]=q,c[K+88>>2]=L,c[K+96>>2]=z,c[K+104>>2]=o,c[K+112>>2]=v,c[K+120>>2]=r,K)|0);i=K;do{if((c[e+4>>2]|0)!=0){if((c[e+36>>2]|0)==0){break}yDb(B,32,2038704,(K=i,i=i+8|0,c[K>>2]=c[g+4>>2],K)|0);i=K;if((c[e+8>>2]|0)==0){break}if((c[e+40>>2]|0)==0){break}yDb(B,32,2038704,(K=i,i=i+8|0,c[K>>2]=c[g+8>>2],K)|0);i=K;if((c[e+12>>2]|0)==0){break}if((c[e+44>>2]|0)==0){break}yDb(B,32,2038704,(K=i,i=i+8|0,c[K>>2]=c[g+12>>2],K)|0);i=K}}while(0);yDb(B,32,1994096,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;A=cj(c[c[(c[l>>2]|0)+32>>2]>>2]|0,e)|0;i=f;return A|0}function Qq(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;g=0;do{h=bFb(g)|0;a:do{if((a[h+7|0]&110)==0){j=a[h+4|0]|0;if((j&255)>>>0<3>>>0){break}if(!(((b[h+12>>1]^b[h+10>>1])&30720)==0)){break}k=j&255;j=0;while(1){if((j|0)>=(k|0)){break}l=b[h+8+(j<<1)>>1]|0;if(!((l&2016)==32)){break a}if((l&3|0)==(j|0)){j=j+1|0}else{break a}}zk(f,g,(g|0)<0|0?-1:0)|0}}while(0);g=g+1|0;}while((g|0)<333);Ok(d,c[f>>2]|0);i=e;return 0}function Rq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=_r(a,b,d)|0;d=e+8|0;b=c[d>>2]|0;a=e+4|0;c[d>>2]=c[a>>2];c[a>>2]=b;b=e+40|0;a=c[b>>2]|0;d=e+36|0;c[b>>2]=c[d>>2];c[d>>2]=a;a=e+240|0;d=c[a>>2]|0;b=c[a+4>>2]|0;f=e+232|0;g=c[f+4>>2]|0;c[a>>2]=c[f>>2];c[a+4>>2]=g;c[f>>2]=d;c[f+4>>2]=b;b=e+368|0;f=c[b>>2]|0;d=e+364|0;c[b>>2]=c[d>>2];c[d>>2]=f;return e|0}function Sq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+8|0;e=c[d>>2]|0;f=b+4|0;c[d>>2]=c[f>>2];c[f>>2]=e;e=b+40|0;f=c[e>>2]|0;d=b+36|0;c[e>>2]=c[d>>2];c[d>>2]=f;f=b+240|0;d=c[f>>2]|0;e=c[f+4>>2]|0;g=b+232|0;h=c[g+4>>2]|0;c[f>>2]=c[g>>2];c[f+4>>2]=h;c[g>>2]=d;c[g+4>>2]=e;e=b+368|0;g=c[e>>2]|0;d=b+364|0;c[e>>2]=c[d>>2];c[d>>2]=g;return cj(c[c[(c[a+8>>2]|0)+32>>2]>>2]|0,b)|0}function Tq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=c[b+44>>2]|0;f=e+8|0;g=c[f>>2]|0;h=a[g]|0;if(h<<24>>24==0){yDb(b,16,2163152,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=d;return k|0}l=e+16|0;m=e+20|0;n=g;g=0;o=h;while(1){if((CAb(o<<24>>24)|0)==0){p=5;break}h=(a[n]|0)-48|0;q=(h|0)>(g|0)?h:g;r=(c[l>>2]|0)+2|0;c[l>>2]=r;s=(a[n]|0)-48+(c[m>>2]|0)|0;c[m>>2]=s;h=n+1|0;t=a[h]|0;if(t<<24>>24==0){p=7;break}else{n=h;g=q;o=t}}if((p|0)==5){yDb(b,16,2091896,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=d;return k|0}else if((p|0)==7){p=(q+1|0)/2|0;q=c[f>>2]|0;c[e+32>>2]=p;yDb(b,32,2038584,(j=i,i=i+32|0,c[j>>2]=q,c[j+8>>2]=p,c[j+16>>2]=r,c[j+24>>2]=s,j)|0);i=j;k=0;i=d;return k|0}return 0}function Uq(a){a=a|0;var b=0,d=0;b=c[a+44>>2]|0;JCb(b+96|0);a=b+32|0;if((c[a>>2]|0)<=0){return}d=b+76|0;b=0;do{JCb(d+(b<<2)|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return}function Vq(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=0;do{if((a[(bFb(f)|0)+7|0]&14)==0){zk(e,f,(f|0)<0|0?-1:0)|0}f=f+1|0;}while((f|0)<333);Ok(b,c[e>>2]|0);i=d;return 0}function Wq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+8|0;d=b|0;e=d;f=i;i=i+8|0;g=i;i=i+8|0;j=g;k=i;i=i+8|0;l=k;m=i;i=i+8|0;n=c[a>>2]|0;o=c[n+44>>2]|0;p=c[c[n+16>>2]>>2]|0;q=p+116|0;r=q;s=c[r>>2]|0;t=c[r+4>>2]|0;c[d>>2]=s;c[d+4>>2]=t;r=s;s=t;do{if((r|0)==0){u=s}else{if((s|0)==0){u=0;break}t=o+16|0;v=c[t>>2]|0;c[f>>2]=c[o+20>>2];c[f+4>>2]=v;jFb(j,e,f);v=c[g>>2]|0;w=c[g+4>>2]|0;c[d>>2]=v;c[d+4>>2]=w;x=n;y=c[p+120>>2]|0;yDb(x,40,2205752,(z=i,i=i+32|0,c[z>>2]=c[q>>2],c[z+8>>2]=y,c[z+16>>2]=v,c[z+24>>2]=w,z)|0);i=z;w=a+156|0;c[w>>2]=c[w>>2]|1;w=a+116|0;v=c[d+4>>2]|0;c[w>>2]=c[d>>2];c[w+4>>2]=v;v=a+56|0;w=p+56|0;jFb(l,w,t);t=v;y=c[k>>2]|0;A=c[k+4>>2]|0;c[t>>2]=y;c[t+4>>2]=A;t=c[p+60>>2]|0;yDb(x,40,2198120,(z=i,i=i+32|0,c[z>>2]=c[w>>2],c[z+8>>2]=t,c[z+16>>2]=y,c[z+24>>2]=A,z)|0);i=z;jFb(m,e,v);h[o+24>>3]=+(c[m+4>>2]|0)/+(c[m>>2]|0);B=0;i=b;return B|0}}while(0);yDb(n,16,2215784,(z=i,i=i+16|0,c[z>>2]=r,c[z+8>>2]=u,z)|0);i=z;B=-22;i=b;return B|0}function Xq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0.0,H=0;e=i;i=i+8|0;f=e|0;c[f>>2]=d;d=c[b+8>>2]|0;b=c[c[d+32>>2]>>2]|0;g=c[d+44>>2]|0;d=g+12|0;j=c[d>>2]|0;k=c[g+8>>2]|0;l=a[k+j|0]|0;m=l-48|0;n=j+1|0;c[d>>2]=n;if((a[k+n|0]|0)==0){c[d>>2]=0}if((m|0)==0){JCb(f);o=0;i=e;return o|0}d=g+36|0;if((c[d>>2]|0)==0){p=0;q=m}else{m=g+40|0;if((c[m>>2]|0)>0){n=g+76|0;k=g+4|0;j=g+96|0;r=g+60|0;s=g+44|0;t=0;do{u=c[n>>2]|0;v=c[u+32+(t<<2)>>2]|0;w=c[k>>2]|0;x=(c[u+(t<<2)>>2]|0)+(ba(w,v)|0)|0;u=c[j>>2]|0;y=c[u+32+(t<<2)>>2]|0;z=(c[u+(t<<2)>>2]|0)+(ba(y,w)|0)|0;u=r+(t<<2)|0;A=s+(t<<2)|0;iDb(x,v<<1,z,y<<1,c[u>>2]|0,(1-w+(c[A>>2]|0)|0)/2|0);w=c[n>>2]|0;y=c[w+32+(t<<2)>>2]|0;z=(c[k>>2]|0)==0|0;v=-z|0;x=c[f>>2]|0;B=c[x+32+(t<<2)>>2]|0;iDb((c[w+(t<<2)>>2]|0)+(y&v)|0,y<<1,(c[x+(t<<2)>>2]|0)+(B&v)|0,B<<1,c[u>>2]|0,((z^1)+(c[A>>2]|0)|0)/2|0);t=t+1|0;}while((t|0)<(c[m>>2]|0))}c[d>>2]=0;p=1;q=l-49|0}if((q|0)>1){l=g+40|0;m=g+76|0;t=g+60|0;k=g+44|0;n=q-2|0;s=n>>>1;r=s<<1;j=p+s|0;s=q;A=p;z=c[l>>2]|0;while(1){if((z|0)>0){u=m+(A<<2)|0;B=0;while(1){v=c[u>>2]|0;x=c[f>>2]|0;iDb(c[v+(B<<2)>>2]|0,c[v+32+(B<<2)>>2]|0,c[x+(B<<2)>>2]|0,c[x+32+(B<<2)>>2]|0,c[t+(B<<2)>>2]|0,c[k+(B<<2)>>2]|0);x=B+1|0;v=c[l>>2]|0;if((x|0)<(v|0)){B=x}else{C=v;break}}}else{C=z}B=s-2|0;if((B|0)>1){s=B;A=A+1|0;z=C}else{break}}D=n-r|0;F=j+1|0}else{D=q;F=p}if((D|0)>0){D=g+40|0;if((c[D>>2]|0)>0){p=g+96|0;q=g+60|0;j=g+44|0;r=0;do{n=c[p>>2]|0;C=c[f>>2]|0;iDb(c[n+(r<<2)>>2]|0,c[n+32+(r<<2)>>2]|0,c[C+(r<<2)>>2]|0,c[C+32+(r<<2)>>2]|0,c[q+(r<<2)>>2]|0,c[j+(r<<2)>>2]|0);r=r+1|0;}while((r|0)<(c[D>>2]|0))}c[d>>2]=1}a:do{if((F|0)>0){d=g+76|0;D=b+160|0;r=g+24|0;j=0;while(1){q=PCb(c[d+(j<<2)>>2]|0)|0;if((q|0)==0){break}G=(+((c[D>>2]|0)>>>0)+ +(c[D+4>>2]|0)*4294967296.0)*+h[r>>3];p=(E=+G,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);C=q+136|0;c[C>>2]=~~+G>>>0;c[C+4>>2]=p;p=cj(b,q)|0;q=j+1|0;if((q|0)<(F|0)){j=q}else{H=p;break a}}JCb(f);o=-12;i=e;return o|0}else{H=0}}while(0);JCb(f);o=H;i=e;return o|0}function Yq(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=bFb(c[e>>2]|0)|0;g=a+20|0;h=a+24|0;i=Zr(a,c[g>>2]|0,c[h>>2]|0)|0;c[b+96>>2]=i;if((i|0)==0){j=-12;return j|0}i=b+32|0;k=b+76|0;l=0;while(1){if((l|0)>=(c[i>>2]|0)){break}m=Zr(a,c[g>>2]|0,c[h>>2]|0)|0;c[k+(l<<2)>>2]=m;if((m|0)==0){j=-12;n=7;break}else{l=l+1|0}}if((n|0)==7){return j|0}n=dDb(b+60|0,c[e>>2]|0,c[g>>2]|0)|0;if((n|0)<0){j=n;return j|0}n=-(-(c[h>>2]|0)>>(d[f+6|0]|0))|0;c[b+52>>2]=n;c[b+48>>2]=n;n=c[h>>2]|0;c[b+56>>2]=n;c[b+44>>2]=n;c[b+40>>2]=fFb(c[e>>2]|0)|0;j=0;return j|0}function Zq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;e=d+8|0;f=dEb(c[e>>2]|0,3076)|0;c[d+12>>2]=f;d=a;if((f|0)==0){yDb(d,16,2162848,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-12;i=b;return h|0}else{yDb(d,40,2091688,(g=i,i=i+8|0,c[g>>2]=c[e>>2],g)|0);i=g;h=0;i=b;return h|0}return 0}function _q(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+44>>2]|0;a=b+12|0;d=a;e=b+8|0;if((c[e>>2]|0)>0){f=0}else{$Db(a);return}while(1){b=(c[d>>2]|0)+(f*3076|0)|0;if((c[b>>2]|0)==0){g=4;break}JCb(b);b=f+1|0;if((b|0)<(c[e>>2]|0)){f=b}else{g=4;break}}if((g|0)==4){$Db(a);return}}function $q(a){a=a|0;Ok(a,xk(550424)|0);return 0}function ar(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a>>2]|0;d=b+16|0;e=(c[b+44>>2]|0)+4|0;while(1){f=Ni(c[c[d>>2]>>2]|0)|0;if((f|0)==-541478725){g=3;break}if((f|0)<0){h=f;g=8;break}if((c[e>>2]|0)==0){h=0;g=8;break}}if((g|0)==3){do{if((c[e>>2]|0)!=0){d=cj(a,br(b)|0)|0;if((d|0)<0){h=d}else{break}return h|0}}while(0);h=-541478725;return h|0}else if((g|0)==8){return h|0}return 0}function br(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0.0,s=0.0,t=0,u=0,v=0,w=0;b=i;i=i+6144|0;d=b|0;e=c[a+44>>2]|0;f=e+4|0;g=c[f>>2]|0;TGb(d|0,0,6144)|0;j=(g|0)>0;k=+(g|0);l=e+12|0;if(j){m=0;do{n=c[l>>2]|0;o=0;p=+h[d+(m<<3)>>3];do{p=p+ +(c[n+(o*3076|0)+4+(m<<2)>>2]|0);o=o+1|0;}while((o|0)<(g|0));h[d+(m<<3)>>3]=p/k;m=m+1|0;}while(m>>>0<768>>>0)}else{m=0;do{o=d+(m<<3)|0;h[o>>3]=+h[o>>3]/k;m=m+1|0;}while(m>>>0<768>>>0)}do{if(j){m=c[l>>2]|0;o=0;n=0;k=-1.0;while(1){q=0;r=0.0;do{s=+h[d+(q<<3)>>3]- +(c[m+(n*3076|0)+4+(q<<2)>>2]|0);r=r+s*s;q=q+1|0;}while((q|0)<768);q=(n|0)==0|r<k;t=q?n:o;u=n+1|0;if((u|0)<(g|0)){o=t;n=u;k=q?r:k}else{break}}if(j){v=0}else{w=t;break}while(1){TGb((c[l>>2]|0)+(v*3076|0)+4|0,0,3072)|0;if((v|0)!=(t|0)){JCb((c[l>>2]|0)+(v*3076|0)|0)}n=v+1|0;if((n|0)<(g|0)){v=n}else{w=t;break}}}else{w=0}}while(0);c[f>>2]=0;f=c[(c[l>>2]|0)+(w*3076|0)>>2]|0;t=f+136|0;k=(+((c[t>>2]|0)>>>0)+ +(c[t+4>>2]|0)*4294967296.0)*(+(c[e+16>>2]|0)/+(c[e+20>>2]|0));yDb(a,32,1931168,(a=i,i=i+24|0,c[a>>2]=w,h[a+8>>3]=k,c[a+16>>2]=g,a)|0);i=a;c[(c[l>>2]|0)+(w*3076|0)>>2]=0;i=b;return f|0}function cr(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[a+8>>2]|0;f=c[e+44>>2]|0;g=c[c[e+32>>2]>>2]|0;h=f+4|0;i=c[h>>2]|0;j=c[f+12>>2]|0;k=c[b>>2]|0;c[j+(i*3076|0)>>2]=b;l=a+24|0;m=c[l>>2]|0;if((m|0)>0){n=a+20|0;a=b+32|0;b=0;o=k;k=c[n>>2]|0;p=m;while(1){if((k|0)>0){m=0;do{q=m*3|0;r=j+(i*3076|0)+4+((d[o+q|0]|0)<<2)|0;c[r>>2]=(c[r>>2]|0)+1;r=j+(i*3076|0)+4+((d[o+(q+1)|0]|0|256)<<2)|0;c[r>>2]=(c[r>>2]|0)+1;r=j+(i*3076|0)+4+((d[o+(q+2)|0]|0|512)<<2)|0;c[r>>2]=(c[r>>2]|0)+1;m=m+1|0;s=c[n>>2]|0;}while((m|0)<(s|0));t=s;u=c[l>>2]|0}else{t=k;u=p}m=b+1|0;if((m|0)<(u|0)){b=m;o=o+(c[a>>2]|0)|0;k=t;p=u}else{break}}v=c[h>>2]|0}else{v=i}i=v+1|0;c[h>>2]=i;if((i|0)<(c[f+8>>2]|0)){w=0;return w|0}w=cj(g,br(e)|0)|0;return w|0}function dr(a){a=a|0;var b=0,d=0;b=a+56|0;d=(c[(c[a+8>>2]|0)+44>>2]|0)+16|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;return 0}function er(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+44>>2]|0;e=c[d+4>>2]|0;f=c[d+8>>2]|0;if(e>>>0>1024>>>0|f>>>0>1024>>>0){yDb(a,16,2162752,(g=i,i=i+16|0,c[g>>2]=e,c[g+8>>2]=f,g)|0);i=g;h=-22;i=b;return h|0}j=d+24|0;d=c[j>>2]|0;k=ba(f,e)|0;if((d|0)==0){c[j>>2]=k;h=0;i=b;return h|0}if(!(d>>>0>k>>>0)){h=0;i=b;return h|0}yDb(a,16,2091632,(g=i,i=i+24|0,c[g>>2]=e,c[g+8>>2]=f,c[g+16>>2]=k,g)|0);i=g;h=-22;i=b;return h|0}function fr(a){a=a|0;Ok(a,Gw(0)|0);return 0}function gr(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;a=c[b+44>>2]|0;d=Ni(c[c[b+16>>2]>>2]|0)|0;if(!((d|0)==-541478725)){e=d;return e|0}if((c[a+20>>2]|0)==0){e=-541478725;return e|0}e=ir(b)|0;return e|0}function hr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a>>2]|0;g=c[f+44>>2]|0;h=c[c[f+16>>2]>>2]|0;j=c[g+4>>2]|0;k=c[g+16>>2]|0;l=ba(j-1|0,k)|0;m=c[g+12>>2]<<1;n=m+l|0;l=g+8|0;o=c[l>>2]|0;p=(ba(o-1|0,k)|0)+m|0;m=c[h+20>>2]|0;if(m>>>0>(((2147483647-n|0)>>>0)/(j>>>0)|0)>>>0){yDb(f,16,2226344,(q=i,i=i+16|0,c[q>>2]=j,c[q+8>>2]=m,q)|0);i=q;r=-22;i=b;return r|0}k=h+24|0;s=c[k>>2]|0;if(s>>>0>(((2147483647-p|0)>>>0)/(o>>>0)|0)>>>0){yDb(f,16,2215744,(q=i,i=i+16|0,c[q>>2]=o,c[q+8>>2]=s,q)|0);i=q;r=-22;i=b;return r|0}else{c[a+20>>2]=(ba(m,j)|0)+n;c[a+24>>2]=(ba(c[k>>2]|0,c[l>>2]|0)|0)+p;p=h+28|0;l=a+28|0;k=c[p+4>>2]|0;c[l>>2]=c[p>>2];c[l+4>>2]=k;k=c[g+24>>2]|0;c[d>>2]=1;c[d+4>>2]=k;jFb(e,h+116|0,d);d=a+116|0;k=c[e+4>>2]|0;c[d>>2]=c[e>>2];c[d+4>>2]=k;k=g+28|0;Bw(k,c[h+52>>2]|0,0)|0;Cw(k,g+72|0,g+96|0);g=a+156|0;c[g>>2]=c[g>>2]|1;r=0;i=b;return r|0}return 0}function ir(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a+44|0;d=c[b>>2]|0;e=c[c[a+32>>2]>>2]|0;f=c[d+92>>2]|0;g=d+20|0;h=c[g>>2]|0;i=d+24|0;if(!(h>>>0<(c[i>>2]|0)>>>0)){j=cj(e,f)|0;c[g>>2]=0;return j|0}k=a+16|0;a=f|0;l=f+32|0;m=d;d=h;while(1){h=c[c[k>>2]>>2]|0;n=c[h+20>>2]|0;o=c[h+24>>2]|0;h=m+20|0;p=c[m+4>>2]|0;q=c[m+12>>2]|0;r=c[m+16>>2]|0;Ew(m+28|0,m+72|0,a,l,(ba(r+n|0,(d>>>0)%(p>>>0)|0)|0)+q|0,(ba(r+o|0,(d>>>0)/(p>>>0)|0)|0)+q|0,n,o);c[h>>2]=(c[h>>2]|0)+1;if(!((c[g>>2]|0)>>>0<(c[i>>2]|0)>>>0)){break}h=c[b>>2]|0;m=h;d=c[h+20>>2]|0}j=cj(e,f)|0;c[g>>2]=0;return j|0}function jr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=c[a+8>>2]|0;f=b+44|0;g=c[f>>2]|0;h=c[c[b+32>>2]>>2]|0;j=g+20|0;do{if((c[j>>2]|0)==0){k=h+20|0;l=h+24|0;m=Zr(h,c[k>>2]|0,c[l>>2]|0)|0;n=g+92|0;c[n>>2]=m;if((m|0)==0){JCb(e);o=-12;i=d;return o|0}NCb(m,c[e>>2]|0)|0;m=c[n>>2]|0;c[m+68>>2]=c[k>>2];c[m+72>>2]=c[l>>2];if((c[g+12>>2]|0)==0){if((c[g+16>>2]|0)==0){p=n;break}}Ew(g+28|0,g+72|0,m|0,m+32|0,0,0,c[k>>2]|0,c[l>>2]|0);p=n}else{p=g+92|0}}while(0);h=c[f>>2]|0;f=c[c[b+16>>2]>>2]|0;n=c[h+20>>2]|0;l=c[h+4>>2]|0;k=c[h+12>>2]|0;m=c[h+16>>2]|0;h=(ba(m+(c[f+20>>2]|0)|0,(n>>>0)%(l>>>0)|0)|0)+k|0;q=(ba((c[f+24>>2]|0)+m|0,(n>>>0)/(l>>>0)|0)|0)+k|0;k=c[p>>2]|0;p=c[e>>2]|0;Dw(g+28|0,k|0,k+32|0,p|0,p+32|0,h,q,0,0,c[a+20>>2]|0,c[a+24>>2]|0);JCb(e);e=(c[j>>2]|0)+1|0;c[j>>2]=e;if((e|0)!=(c[g+24>>2]|0)){o=0;i=d;return o|0}o=ir(b)|0;i=d;return o|0}function kr(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=0;do{g=bFb(f)|0;do{if((a[g+7|0]&14)==0){if((a[g+5|0]|0)!=(a[g+6|0]|0)){break}zk(e,f,(f|0)<0|0?-1:0)|0}}while(0);f=f+1|0;}while((f|0)<333);Ok(b,c[e>>2]|0);i=d;return 0}function lr(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;b=i;i=i+16|0;e=b|0;f=b+8|0;g=f;h=c[a>>2]|0;j=c[h+44>>2]|0;k=c[c[h+16>>2]>>2]|0;l=bFb(c[a+52>>2]|0)|0;m=bFb(c[k+52>>2]|0)|0;n=j+32|0;if((c[n>>2]&4|0)!=0){yDb(h,24,2187648,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[n>>2]=c[n>>2]&3;c[j+28>>2]=1}p=k+20|0;q=c[p>>2]|0;r=k+24|0;s=c[r>>2]|0;if((q|0)<(s|0)){t=5}else{if((c[j+28>>2]|0)!=1){t=5}}do{if((t|0)==5){u=j+28|0;if((q|0)<=(s|0)){if((c[u>>2]|0)==2){break}}c[u>>2]=0;c[j+4>>2]=d[m+5|0]|0;c[j+8>>2]=d[m+6|0]|0;bDb(j+12|0,0,l);u=c[r>>2]|0;v=a+20|0;c[v>>2]=u;w=c[p>>2]|0;x=a+24|0;c[x>>2]=w;y=k+28|0;z=a+28|0;if((c[y>>2]|0)==0){A=y;B=z;C=c[A+4>>2]|0;c[B>>2]=c[A>>2];c[B+4>>2]=C;D=u;E=w}else{c[e>>2]=1;c[e+4>>2]=1;kFb(g,e,y);y=z;z=c[f+4>>2]|0;c[y>>2]=c[f>>2];c[y+4>>2]=z;D=c[v>>2]|0;E=c[x>>2]|0}x=h;v=c[p>>2]|0;z=c[r>>2]|0;y=c[n>>2]|0;if((y|0)==1){F=1;G=2156080;t=13}else{w=(y|0)==3?2156080:2149128;if((y|0)==0){H=1;I=w}else{F=y;G=w;t=13}}if((t|0)==13){H=(F|0)==3|0;I=G}yDb(x,40,2162784,(o=i,i=i+56|0,c[o>>2]=v,c[o+8>>2]=z,c[o+16>>2]=y,c[o+24>>2]=D,c[o+32>>2]=E,c[o+40>>2]=I,c[o+48>>2]=H,o)|0);i=o;i=b;return 0}}while(0);yDb(h,40,2171768,(o=i,i=i+32|0,c[o>>2]=q,c[o+8>>2]=s,c[o+16>>2]=q,c[o+24>>2]=s,o)|0);i=o;i=b;return 0}function mr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((c[(c[(c[a+8>>2]|0)+44>>2]|0)+28>>2]|0)==0){e=_r(a,b,d)|0;return e|0}else{e=Yr(a,b,d)|0;return e|0}return 0}function nr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;a=c[c[g+32>>2]>>2]|0;if((c[(c[g+44>>2]|0)+28>>2]|0)!=0){h=cj(a,b)|0;i=d;return h|0}j=a+24|0;k=Zr(a,c[a+20>>2]|0,c[j>>2]|0)|0;if((k|0)==0){JCb(e);h=-12;i=d;return h|0}NCb(k,b)|0;b=c[e>>2]|0;l=b+124|0;if((c[l>>2]|0)==0){m=l;l=k+124|0;n=c[m+4>>2]|0;c[l>>2]=c[m>>2];c[l+4>>2]=n}else{c[k+124>>2]=c[b+128>>2];c[k+128>>2]=c[b+124>>2]}c[f>>2]=b;c[f+4>>2]=k;b=c[j>>2]|0;j=c[(c[g+48>>2]|0)+28>>2]|0;Pe[c[c[g+56>>2]>>2]&255](g,634,f,0,(b|0)>(j|0)?j:b)|0;JCb(e);h=cj(a,k)|0;i=d;return h|0}function or(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;h=c[d+44>>2]|0;d=c[e+4>>2]|0;i=c[e>>2]|0;e=c[d>>2]|0;if((e|0)==0){return 0}j=h+4|0;k=h+8|0;l=h+12|0;m=d+68|0;n=d+72|0;o=f+1|0;p=h+32|0;h=i+72|0;q=0;r=e;do{if((q-1|0)>>>0<2>>>0){s=c[k>>2]|0;t=c[j>>2]|0}else{s=0;t=0}e=-(c[m>>2]|0)>>t;u=-e|0;v=-(c[n>>2]|0)>>s;w=-v|0;x=(ba(w,f)|0)/(g|0)|0;y=(ba(o,w)|0)/(g|0)|0;w=c[d+32+(q<<2)>>2]|0;z=c[i+(q<<2)>>2]|0;A=c[i+32+(q<<2)>>2]|0;B=c[p>>2]|0;if((B&1|0)==0){C=z;D=A}else{C=z+(ba((c[h>>2]>>s)-1|0,A)|0)|0;D=-A|0}if((B&2|0)==0){E=x;F=w}else{E=~x-v|0;F=-w|0}v=r+(ba(w,E)|0)|0;a:do{switch(c[l+(q<<2)>>2]|0){case 3:{if((x|0)>=(y|0)){break a}w=(e|0)<0;B=x;A=v;while(1){if(w){z=B*3|0;G=0;do{H=(ba(G,D)|0)+z|0;I=a[C+H|0]|0;J=a[C+(H+1)|0]|0;K=G*3|0;a[A+(K+2)|0]=a[C+(H+2)|0]|0;a[A+(K+1)|0]=J;a[A+K|0]=I;G=G+1|0;}while((G|0)<(u|0))}G=B+1|0;if((G|0)<(y|0)){B=G;A=A+F|0}else{break}}break};case 8:{if((x|0)<(y|0)&(e|0)<0){L=x;M=v}else{break a}while(1){A=L<<3;B=0;do{w=C+((ba(B,D)|0)+A)|0;G=c[w+4>>2]|0;z=M+(B<<3)|0;c[z>>2]=c[w>>2];c[z+4>>2]=G;B=B+1|0;}while((B|0)<(u|0));B=L+1|0;if((B|0)<(y|0)){L=B;M=M+F|0}else{break}}break};case 1:{if((x|0)>=(y|0)){break a}B=(e|0)<0;A=x;G=v;while(1){if(B){z=0;do{a[G+z|0]=a[C+((ba(z,D)|0)+A)|0]|0;z=z+1|0;}while((z|0)<(u|0))}z=A+1|0;if((z|0)<(y|0)){A=z;G=G+F|0}else{break}}break};case 4:{if((x|0)<(y|0)&(e|0)<0){N=x;O=v}else{break a}while(1){G=N<<2;A=0;do{c[O+(A<<2)>>2]=c[C+((ba(A,D)|0)+G)>>2];A=A+1|0;}while((A|0)<(u|0));A=N+1|0;if((A|0)<(y|0)){N=A;O=O+F|0}else{break}}break};case 6:{if((x|0)<(y|0)&(e|0)<0){P=x;Q=v}else{break a}while(1){A=P*6|0;G=0;do{B=(ba(G,D)|0)+A|0;z=a[C+B|0]|0;w=a[C+(B+1)|0]|0;I=a[C+(B+2)|0]|0;K=a[C+(B+3)|0]|0;J=a[C+(B+4)|0]|0;H=G*6|0;a[Q+(H+5)|0]=a[C+(B+5)|0]|0;a[Q+(H+4)|0]=J;a[Q+(H+3)|0]=K;a[Q+(H+2)|0]=I;a[Q+(H|1)|0]=w;a[Q+H|0]=z;G=G+1|0;}while((G|0)<(u|0));G=P+1|0;if((G|0)<(y|0)){P=G;Q=Q+F|0}else{break}}break};case 2:{if((x|0)>=(y|0)){break a}G=(e|0)<0;A=x;z=v;while(1){if(G){H=A<<1;w=0;do{b[z+(w<<1)>>1]=b[C+((ba(w,D)|0)+H)>>1]|0;w=w+1|0;}while((w|0)<(u|0))}w=A+1|0;if((w|0)<(y|0)){A=w;z=z+F|0}else{break}}break};default:{}}}while(0);q=q+1|0;r=c[d+(q<<2)>>2]|0;}while((r|0)!=0);return 0}function pr(a){a=a|0;var b=0,d=0,e=0,f=0,h=0.0,j=0,k=0;b=i;d=c[a+44>>2]|0;e=c[d+4>>2]|0;f=c[d+8>>2]|0;h=+g[d+20>>2];c[d+28>>2]=e;c[d+32>>2]=f;c[d+36>>2]=~~(h*65536.0);j=(e|0)/2|0;c[d+40>>2]=j;e=(f|0)/2|0;c[d+44>>2]=e;f=e+j<<1;c[d+48>>2]=f;c[d+52>>2]=1<<f-1;f=c[d+12>>2]|0;j=c[d+16>>2]|0;h=+g[d+24>>2];c[d+304>>2]=f;c[d+308>>2]=j;c[d+312>>2]=~~(h*65536.0);e=(f|0)/2|0;c[d+316>>2]=e;f=(j|0)/2|0;c[d+320>>2]=f;j=f+e<<1;c[d+324>>2]=j;c[d+328>>2]=1<<j-1;c[d+592>>2]=196;if((c[d+588>>2]|0)==0){k=0;i=b;return k|0}yDb(a,16,2162472,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-22;i=b;return k|0}function qr(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=b+28|0;d=b+44|0;if((c[d>>2]<<1|0)>0){e=0;do{ZDb(c[a+28+(e<<2)>>2]|0);e=e+1|0;}while((e|0)<(c[d>>2]<<1|0))}d=b+304|0;e=b+320|0;if((c[e>>2]<<1|0)>0){f=0}else{return}do{ZDb(c[d+28+(f<<2)>>2]|0);f=f+1|0;}while((f|0)<(c[e>>2]<<1|0));return}function rr(a){a=a|0;Ok(a,xk(550376)|0);return 0}function sr(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;g=i;i=i+296|0;h=g|0;j=g+248|0;k=g+264|0;l=g+280|0;m=c[c[b+16>>2]>>2]|0;n=c[b+44>>2]|0;b=c[m+20>>2]|0;c[j>>2]=b;o=-(-b>>c[n+580>>2])|0;c[j+8>>2]=o;c[j+4>>2]=o;o=c[m+24>>2]|0;c[k>>2]=o;m=-(-o>>c[n+584>>2])|0;c[k+8>>2]=m;c[k+4>>2]=m;m=n+28|0;c[l>>2]=m;p=n+304|0;c[l+8>>2]=p;c[l+4>>2]=p;p=h;n=0;q=b;b=o;o=m;while(1){m=c[f+(n<<2)>>2]|0;r=c[f+32+(n<<2)>>2]|0;s=c[e+(n<<2)>>2]|0;t=c[e+32+(n<<2)>>2]|0;u=c[o+8>>2]|0;v=c[o+12>>2]|0;w=-v|0;x=c[o+16>>2]|0;y=c[o+20>>2]|0;z=c[o+24>>2]|0;do{if((u|0)==0){iDb(m,r,s,t,q,b)}else{A=x<<1;B=(A|0)>0;if(B){C=(v<<1)+q<<2;D=0;do{TGb(c[o+28+(D<<2)>>2]|0,0,C|0)|0;D=D+1|0;}while((D|0)<(A|0))}D=-x|0;C=x+b|0;if((C|0)<=(D|0)){break}E=v<<1;F=(v<<3)-4|0;G=v+q|0;H=(G|0)>(w|0);I=(E|0)>0;J=(ba(x,t)|0)+v|0;K=(ba(x,r)|0)+v|0;L=q-1|0;M=0;N=D;D=s;O=m;while(1){P=(N|0)<(b|0)?D:M;TGb(p|0,0,F|0)|0;a:do{if(H){Q=(N|0)<(x|0);R=P+L|0;if(I){S=w}else{T=w;while(1){do{if((T|0)<1){U=P}else{if((T|0)>=(q|0)){U=R;break}U=P+T|0}}while(0);V=d[U]|0;if(B){W=T+v|0;X=0;Y=V;while(1){Z=(c[o+28+(X<<2)>>2]|0)+(W<<2)|0;_=(c[Z>>2]|0)+Y|0;c[Z>>2]=Y;Z=(c[o+28+((X|1)<<2)>>2]|0)+(W<<2)|0;$=(c[Z>>2]|0)+_|0;c[Z>>2]=_;_=X+2|0;if((_|0)<(A|0)){X=_;Y=$}else{aa=$;break}}}else{aa=V}if(!((T|0)<(v|0)|Q)){Y=d[D+(T-J)|0]|0;X=((ba(Y-((aa+z|0)>>>(y>>>0))|0,u)|0)>>16)+Y|0;if(X>>>0>255>>>0){ca=-X>>31&255}else{ca=X&255}a[O+(T-K)|0]=ca}T=T+1|0;if((T|0)>=(G|0)){break a}}}do{do{if((S|0)<1){da=P}else{if((S|0)>=(q|0)){da=R;break}da=P+S|0}}while(0);V=0;T=d[da]|0;do{X=h+(V<<2)|0;Y=(c[X>>2]|0)+T|0;c[X>>2]=T;X=h+((V|1)<<2)|0;T=(c[X>>2]|0)+Y|0;c[X>>2]=Y;V=V+2|0;}while((V|0)<(E|0));if(B){V=S+v|0;Y=0;X=T;while(1){W=(c[o+28+(Y<<2)>>2]|0)+(V<<2)|0;$=(c[W>>2]|0)+X|0;c[W>>2]=X;W=(c[o+28+((Y|1)<<2)>>2]|0)+(V<<2)|0;_=(c[W>>2]|0)+$|0;c[W>>2]=$;$=Y+2|0;if(($|0)<(A|0)){Y=$;X=_}else{ea=_;break}}}else{ea=T}if(!((S|0)<(v|0)|Q)){X=d[D+(S-J)|0]|0;Y=((ba(X-((ea+z|0)>>>(y>>>0))|0,u)|0)>>16)+X|0;if(Y>>>0>255>>>0){fa=-Y>>31&255}else{fa=Y&255}a[O+(S-K)|0]=fa}S=S+1|0;}while((S|0)<(G|0))}}while(0);if((N|0)>-1){ga=O+r|0;ha=D+t|0}else{ga=O;ha=D}Q=N+1|0;if((Q|0)<(C|0)){M=P;N=Q;D=ha;O=ga}else{break}}}}while(0);t=n+1|0;if((t|0)>=3){break}n=t;q=c[j+(t<<2)>>2]|0;b=c[k+(t<<2)>>2]|0;o=c[l+(t<<2)>>2]|0}i=g;return 0}function tr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=a+8|0;a=c[f>>2]|0;g=c[a+44>>2]|0;h=c[c[a+32>>2]>>2]|0;a=Zr(h,c[h+20>>2]|0,c[h+24>>2]|0)|0;if((a|0)==0){JCb(e);j=-12;i=d;return j|0}NCb(a,b)|0;b=ze[c[g+592>>2]&511](c[f>>2]|0,c[e>>2]|0,a)|0;JCb(e);if((b|0)<0){j=b;i=d;return j|0}j=cj(h,a)|0;i=d;return j|0}function ur(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=a+8|0;e=c[(c[b>>2]|0)+44>>2]|0;f=bFb(c[a+52>>2]|0)|0;g=e+580|0;c[g>>2]=d[f+5|0]|0;c[e+584>>2]=d[f+6|0]|0;f=a+20|0;a=vr(c[b>>2]|0,e+28|0,2156024,c[f>>2]|0)|0;if((a|0)<0){h=a;return h|0}a=vr(c[b>>2]|0,e+304|0,2149120,-(-(c[f>>2]|0)>>c[g>>2])|0)|0;h=(a|0)<0?a:0;return h|0}function vr(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=c[b+8>>2]|0;if((g|0)==0){j=2142416}else{j=(g|0)<0?2136856:2130552}k=c[b>>2]|0;l=c[b+4>>2]|0;m=a;if((k&1&l|0)==0){yDb(m,16,2123936,(n=i,i=i+24|0,c[n>>2]=d,c[n+8>>2]=k,c[n+16>>2]=l,n)|0);i=n;o=-22;i=f;return o|0}yDb(m,40,2118472,(n=i,i=i+40|0,c[n>>2]=j,c[n+8>>2]=d,c[n+16>>2]=k,c[n+24>>2]=l,h[n+32>>3]=+(g|0)/65535.0,n)|0);i=n;n=b+12|0;g=b+16|0;l=0;while(1){if((l|0)>=(c[g>>2]<<1|0)){o=0;p=8;break}k=WDb((c[n>>2]<<1)+e<<2)|0;c[b+28+(l<<2)>>2]=k;if((k|0)==0){o=-12;p=8;break}else{l=l+1|0}}if((p|0)==8){i=f;return o|0}return 0}function wr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[a+8>>2]|0;a=c[e+44>>2]|0;f=Zr(c[c[e+32>>2]>>2]|0,b,d)|0;if((f|0)==0){g=0;return g|0}b=a;a=-d|0;e=f|0;h=c[e>>2]|0;if((h|0)!=0){i=f+32|0;j=c[i>>2]|0;c[e>>2]=h+(ba(j,d-1|0)|0);c[i>>2]=-j}j=f+4|0;i=c[j>>2]|0;if((i|0)!=0){h=f+36|0;e=c[h>>2]|0;c[j>>2]=i+(ba(e,~(a>>c[b>>2]))|0);c[h>>2]=-e}e=f+8|0;h=c[e>>2]|0;if((h|0)!=0){i=f+40|0;j=c[i>>2]|0;c[e>>2]=h+(ba(j,~(a>>c[b>>2]))|0);c[i>>2]=-j}j=f+12|0;i=c[j>>2]|0;if((i|0)==0){g=f;return g|0}b=f+44|0;a=c[b>>2]|0;c[j>>2]=i+(ba(a,d-1|0)|0);c[b>>2]=-a;g=f;return g|0}function xr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a+8|0;e=c[(c[d>>2]|0)+44>>2]|0;f=a+24|0;a=b|0;g=c[a>>2]|0;if((g|0)!=0){h=b+32|0;i=c[h>>2]|0;c[a>>2]=g+(ba(i,(c[f>>2]|0)-1|0)|0);c[h>>2]=-i}i=b+4|0;h=c[i>>2]|0;if((h|0)!=0){g=b+36|0;a=c[g>>2]|0;c[i>>2]=h+(ba(a,~(-(c[f>>2]|0)>>c[e>>2]))|0);c[g>>2]=-a}a=b+8|0;g=c[a>>2]|0;if((g|0)!=0){h=b+40|0;i=c[h>>2]|0;c[a>>2]=g+(ba(i,~(-(c[f>>2]|0)>>c[e>>2]))|0);c[h>>2]=-i}i=b+12|0;h=c[i>>2]|0;if((h|0)==0){j=c[d>>2]|0;k=j+32|0;l=c[k>>2]|0;m=c[l>>2]|0;n=cj(m,b)|0;return n|0}e=b+44|0;g=c[e>>2]|0;c[i>>2]=h+(ba(g,(c[f>>2]|0)-1|0)|0);c[e>>2]=-g;j=c[d>>2]|0;k=j+32|0;l=c[k>>2]|0;m=c[l>>2]|0;n=cj(m,b)|0;return n|0}function yr(a){a=a|0;var b=0;b=c[(c[a+8>>2]|0)+44>>2]|0;c[b>>2]=d[(bFb(c[a+52>>2]|0)|0)+6|0]|0;return 0}function zr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+44>>2]|0;e=a;a=JBb(d+16|0,c[d+20>>2]|0,159944,0,0,0,0,0,e)|0;if((a|0)<0){yDb(e,16,2162032,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=a;i=b;return g|0}a=JBb(d+32|0,c[d+36>>2]|0,159944,0,0,0,0,0,e)|0;if((a|0)<0){yDb(e,16,2091224,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=a;i=b;return g|0}a=JBb(d+48|0,c[d+52>>2]|0,159944,0,0,0,0,0,e)|0;if((a|0)>=0){g=0;i=b;return g|0}yDb(e,16,2038208,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=a;i=b;return g|0}function Ar(a){a=a|0;var b=0;b=c[a+44>>2]|0;$Db(b+120|0);IBb(c[b+16>>2]|0);IBb(c[b+32>>2]|0);IBb(c[b+48>>2]|0);return}function Br(a){a=a|0;Ok(a,xk(550336)|0);return 0}function Cr(b,e){b=b|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0.0,O=0,P=0,Q=0,R=0.0,S=0.0,T=0.0,U=0,V=0.0,W=0,X=0.0,Y=0,Z=0;f=i;i=i+8|0;h=f|0;c[h>>2]=e;j=c[b+8>>2]|0;k=c[j+44>>2]|0;l=c[c[j+32>>2]>>2]|0;j=Zr(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;if((j|0)==0){JCb(h);m=-12;i=f;return m|0}NCb(j,e)|0;if((c[k+12>>2]|0)==1){Er(k,b,c[h>>2]|0)}e=k+4|0;a:do{if((a[(c[e>>2]|0)+7|0]&32)==0){n=k+120|0;o=k+124|0;p=b+20|0;q=b+24|0;r=k+148|0;s=k+144|0;t=0;do{u=c[h>>2]|0;v=c[u+(t<<2)>>2]|0;if((v|0)==0){break a}w=c[u+32+(t<<2)>>2]|0;if((w|0)==0){break a}u=c[j+32+(t<<2)>>2]|0;x=(t-1|0)>>>0<2>>>0;if(x){y=c[e>>2]|0;z=d[y+6|0]|0;A=d[y+5|0]|0}else{z=0;A=0}y=-(c[p>>2]|0)>>A;B=-y|0;C=-(c[q>>2]|0)>>z;D=-C|0;if((C|0)!=0){C=(y|0)==0;y=c[o>>2]<<z;E=c[j+(t<<2)>>2]|0;F=v;v=c[n>>2]|0;G=0;while(1){if(!C){if(x){H=0;I=E;J=F;while(1){if((c[r>>2]|0)==0){K=0.0}else{L=c[s>>2]|0;c[s>>2]=(ba(L,1664525)|0)+1013904223;K=+(L>>>0>>>0)*2.3283064365386963e-10}L=~~(K+(+g[v+(H<<A<<2)>>2]*+((d[J]|0)-127|0)+127.0));if(L>>>0>255>>>0){M=-L>>31&255}else{M=L&255}a[I]=M;L=H+1|0;if(L>>>0<B>>>0){H=L;I=I+1|0;J=J+1|0}else{break}}}else{J=0;I=E;H=F;while(1){if((c[r>>2]|0)==0){N=0.0}else{L=c[s>>2]|0;c[s>>2]=(ba(L,1664525)|0)+1013904223;N=+(L>>>0>>>0)*2.3283064365386963e-10}L=~~(N+ +g[v+(J<<2)>>2]*+(d[H]|0|0));if(L>>>0>255>>>0){O=-L>>31&255}else{O=L&255}a[I]=O;L=J+1|0;if(L>>>0<B>>>0){J=L;I=I+1|0;H=H+1|0}else{break}}}}H=G+1|0;if(H>>>0<D>>>0){E=E+u|0;F=F+w|0;v=v+(y<<2)|0;G=H}else{break}}}t=t+1|0;}while((t|0)<4)}else{t=c[h>>2]|0;s=c[j+32>>2]|0;r=c[t+32>>2]|0;n=c[k+124>>2]|0;o=b+24|0;q=c[o>>2]|0;if((q|0)==0){break}p=b+20|0;G=k+148|0;y=k+144|0;v=c[k+120>>2]|0;w=c[t>>2]|0;t=c[j>>2]|0;F=0;u=c[p>>2]|0;E=q;while(1){if((u|0)==0){P=0;Q=E}else{q=w;D=t;B=0;while(1){R=+g[v+(B<<2)>>2];S=R*+(d[q]|0|0);if((c[G>>2]|0)==0){T=0.0}else{x=c[y>>2]|0;c[y>>2]=(ba(x,1664525)|0)+1013904223;T=+(x>>>0>>>0)*2.3283064365386963e-10}x=~~(S+T);if(x>>>0>255>>>0){U=-x>>31&255}else{U=x&255}a[D]=U;S=R*+(d[q+1|0]|0|0);if((c[G>>2]|0)==0){V=0.0}else{x=c[y>>2]|0;c[y>>2]=(ba(x,1664525)|0)+1013904223;V=+(x>>>0>>>0)*2.3283064365386963e-10}x=~~(S+V);if(x>>>0>255>>>0){W=-x>>31&255}else{W=x&255}a[D+1|0]=W;S=R*+(d[q+2|0]|0|0);if((c[G>>2]|0)==0){X=0.0}else{x=c[y>>2]|0;c[y>>2]=(ba(x,1664525)|0)+1013904223;X=+(x>>>0>>>0)*2.3283064365386963e-10}x=~~(S+X);if(x>>>0>255>>>0){Y=-x>>31&255}else{Y=x&255}a[D+2|0]=Y;x=B+1|0;Z=c[p>>2]|0;if(x>>>0<Z>>>0){q=q+3|0;D=D+3|0;B=x}else{break}}P=Z;Q=c[o>>2]|0}B=F+1|0;if(B>>>0<Q>>>0){v=v+(n<<2)|0;w=w+r|0;t=t+s|0;F=B;u=P;E=Q}else{break}}}}while(0);m=cj(l,j)|0;i=f;return m|0}function Dr(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0.0,u=0,v=0,w=0.0,x=0;b=i;i=i+8|0;d=b|0;e=d;f=i;i=i+8|0;j=i;i=i+8|0;k=c[(c[a+8>>2]|0)+44>>2]|0;l=k;m=a+28|0;n=c[m>>2]|0;o=c[m+4>>2]|0;c[d>>2]=n;c[d+4>>2]=o;c[k+4>>2]=bFb(c[a+52>>2]|0)|0;m=a+20|0;h[k+64>>3]=+(c[m>>2]|0);p=a+24|0;h[k+72>>3]=+(c[p>>2]|0);h[k+112>>3]=+(c[a+56>>2]|0)/+(c[a+60>>2]|0);r=c[a+116>>2]|0;s=n;n=o;do{if((r|0)==0){t=+q}else{o=c[a+120>>2]|0;if((o|0)==0){t=+q;break}t=+(r|0)/+(o|0)}}while(0);h[k+96>>3]=t;do{if((s|0)==0|(n|0)==0){c[e+4>>2]=1;c[d>>2]=1;u=k+152|0;v=8}else{r=k+152|0;if((s|0)<=(n|0)){u=r;v=8;break}kFb(f,e,r);g[k+136>>2]=+(c[f>>2]|0)/+(c[f+4>>2]|0);g[k+140>>2]=1.0}}while(0);if((v|0)==8){kFb(j,u,e);g[k+140>>2]=+(c[j>>2]|0)/+(c[j+4>>2]|0);g[k+136>>2]=1.0}t=+Rb(+(+(c[m>>2]|0)*.5),+(+(c[p>>2]|0)*.5));h[k+128>>3]=t;w=+g[k+140>>2];yDb(k,48,2071480,(j=i,i=i+24|0,h[j>>3]=+g[k+136>>2],h[j+8>>3]=w,h[j+16>>3]=t,j)|0);i=j;j=(c[m>>2]|0)+31&-32;c[k+124>>2]=j;m=WDb(ba(c[p>>2]<<2,j)|0)|0;c[k+120>>2]=m;if((m|0)==0){x=-12;i=b;return x|0}if((c[k+12>>2]|0)!=0){x=0;i=b;return x|0}Er(l,a,0);x=0;i=b;return x|0}function Er(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0,j=0,k=0.0,l=0.0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0;e=c[a+120>>2]|0;f=c[a+124>>2]|0;if((d|0)==0){h[a+80>>3]=0.0;h[a+104>>3]=+q;h[a+88>>3]=+q}else{i=b+160|0;h[a+80>>3]=+((c[i>>2]|0)>>>0)+ +(c[i+4>>2]|0)*4294967296.0;i=d+136|0;d=c[i>>2]|0;j=c[i+4>>2]|0;if((d|0)==0&(j|0)==(-2147483648|0)){h[a+104>>3]=+q;k=+q}else{h[a+104>>3]=(+(d>>>0)+ +(j|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0));k=+(d>>>0)+ +(j|0)*4294967296.0}h[a+88>>3]=k}j=a+64|0;k=+MBb(c[a+16>>2]|0,j,0);if(k<0.0){l=0.0}else{l=k>1.5707963705062866?1.5707963705062866:k}d=a+24|0;h[d>>3]=l;i=a+40|0;h[i>>3]=+MBb(c[a+32>>2]|0,j,0);m=a+56|0;h[m>>3]=+MBb(c[a+48>>2]|0,j,0);j=b+24|0;n=c[j>>2]|0;o=(n|0)>0;if((c[a+8>>2]|0)==0){if(!o){return}p=b+20|0;r=a+136|0;s=a+140|0;t=a+128|0;u=0;v=e;w=c[p>>2]|0;x=n;while(1){if((w|0)>0){l=+(u|0);y=0;do{k=+Rb(+(+(~~((+(y|0)- +h[i>>3])*+g[r>>2])|0)),+(+(~~((l- +h[m>>3])*+g[s>>2])|0)));z=k/+h[t>>3];if(z>1.0){A=0.0}else{k=+T(z*+h[d>>3]);z=k*k;A=z*z}g[v+(y<<2)>>2]=A;y=y+1|0;B=c[p>>2]|0;}while((y|0)<(B|0));C=B;D=c[j>>2]|0}else{C=w;D=x}y=u+1|0;if((y|0)<(D|0)){u=y;v=v+(f<<2)|0;w=C;x=D}else{break}}return}else{if(!o){return}o=b+20|0;b=a+136|0;D=a+140|0;x=a+128|0;a=0;C=e;e=c[o>>2]|0;w=n;while(1){if((e|0)>0){A=+(a|0);n=0;do{l=+Rb(+(+(~~((+(n|0)- +h[i>>3])*+g[b>>2])|0)),+(+(~~((A- +h[m>>3])*+g[D>>2])|0)));z=l/+h[x>>3];if(z>1.0){E=0.0}else{l=+T(z*+h[d>>3]);z=l*l;E=z*z}g[C+(n<<2)>>2]=1.0/E;n=n+1|0;F=c[o>>2]|0;}while((n|0)<(F|0));G=F;H=c[j>>2]|0}else{G=e;H=w}n=a+1|0;if((n|0)<(H|0)){a=n;C=C+(f<<2)|0;e=G;w=H}else{break}}return}}function Fr(a){a=a|0;var b=0;b=c[a+44>>2]|0;JCb(b+56|0);JCb(b+60|0);JCb(b+64|0);$Db(b+68|0);return}function Gr(a){a=a|0;Ok(a,xk(550264)|0);return 0}function Hr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a>>2]|0;a=c[b+44>>2]|0;d=a+60|0;e=a+64|0;f=a+48|0;a=b+16|0;while(1){if((c[f>>2]|0)!=0){g=-541478725;h=9;break}b=Ni(c[c[a>>2]>>2]|0)|0;if((b|0)==-541478725){if((c[d>>2]|0)==0){g=-541478725;h=9;break}i=PCb(c[e>>2]|0)|0;if((i|0)==0){g=-12;h=9;break}j=(c[e>>2]|0)+136|0;k=c[j>>2]|0;l=(c[d>>2]|0)+136|0;m=ZGb(k<<1|0>>>31,c[j+4>>2]<<1|k>>>31,c[l>>2]|0,c[l+4>>2]|0)|0;l=i+136|0;c[l>>2]=m;c[l+4>>2]=F;Jr(c[c[a>>2]>>2]|0,i)|0;c[f>>2]=1}else{if((b|0)<0){g=b;h=9;break}}if((c[d>>2]|0)!=0){g=0;h=9;break}}if((h|0)==9){return g|0}return 0}function Ir(a){a=a|0;var b=0;b=c[c[(c[a>>2]|0)+16>>2]>>2]|0;c[a+56>>2]=c[b+56>>2];c[a+60>>2]=c[b+60>>2]<<1;c[a+116>>2]=c[b+116>>2]<<1;c[a+120>>2]=c[b+120>>2];b=a+156|0;c[b>>2]=c[b>>2]|1;return 0}function Jr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+8>>2]|0;a=c[d+44>>2]|0;e=a+56|0;JCb(e);f=a+60|0;c[e>>2]=c[f>>2];g=a+64|0;h=c[g>>2]|0;c[f>>2]=h;c[g>>2]=b;do{if((h|0)==0){g=PCb(b)|0;c[f>>2]=g;if((g|0)==0){i=-12}else{j=g;break}return i|0}else{j=h}}while(0);if((c[a+8>>2]|0)==0){k=5}else{if((c[j+296>>2]|0)!=0){k=5}}do{if((k|0)==5){if((c[d+76>>2]|0)!=0){break}if((c[e>>2]|0)==0){i=0;return i|0}a=Kr(d,0)|0;if((a|0)<0){i=a;return i|0}i=Kr(d,1)|0;return i|0}}while(0);k=PCb(j)|0;if((k|0)==0){i=-12;return i|0}JCb(e);e=k+136|0;j=c[e>>2]|0;a=c[e+4>>2]|0;if(!((j|0)==0&(a|0)==(-2147483648|0))){c[e>>2]=j<<1|0>>>31;c[e+4>>2]=a<<1|j>>>31}i=cj(c[c[d+32>>2]>>2]|0,k)|0;return i|0}function Kr(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;f=i;i=i+48|0;g=f|0;h=f+24|0;j=b+44|0;k=c[j>>2]|0;l=c[c[b+32>>2]>>2]|0;b=Zr(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;if((b|0)==0){m=-12;i=f;return m|0}n=k+60|0;NCb(b,c[n>>2]|0)|0;c[b+296>>2]=0;do{if((e|0)==0){o=b+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;if((p|0)==0&(q|0)==(-2147483648|0)){break}c[o>>2]=p<<1|0>>>31;c[o+4>>2]=q<<1|p>>>31}else{p=(c[n>>2]|0)+136|0;q=c[p>>2]|0;o=c[p+4>>2]|0;p=(c[k+64>>2]|0)+136|0;r=c[p>>2]|0;s=c[p+4>>2]|0;if((r|0)==0&(s|0)==(-2147483648|0)|(q|0)==0&(o|0)==(-2147483648|0)){p=b+136|0;c[p>>2]=0;c[p+4>>2]=-2147483648;break}else{p=YGb(r,s,q,o)|0;o=b+136|0;c[o>>2]=p;c[o+4>>2]=F;break}}}while(0);e=k+44|0;o=c[e>>2]|0;p=c[((o|0)==0?k+56|0:k+64|0)>>2]|0;q=k+52|0;if((c[q>>2]|0)>0){s=k+4|0;k=g|0;r=g+4|0;t=g+8|0;u=g+12|0;v=h|0;w=h+4|0;x=h+8|0;y=h+12|0;z=g+16|0;A=h+16|0;B=0;do{C=c[n>>2]|0;D=c[s>>2]|0;E=c[j>>2]|0;G=c[C+(B<<2)>>2]|0;H=c[p+(B<<2)>>2]|0;I=c[b+(B<<2)>>2]|0;J=c[E+12+(B<<2)>>2]|0;K=c[E+28+(B<<2)>>2]|0;L=c[C+32+(B<<2)>>2]|0;M=c[p+32+(B<<2)>>2]|0;N=c[b+32+(B<<2)>>2]|0;O=E+44|0;P=c[O>>2]|0;Q=C+300|0;C=c[Q>>2]|0;R=(P|0)==(C|0)|0;S=-R|0;if((R|0)<(K|0)){T=L<<1;U=N<<1;V=I+(N&S)|0;W=G+(L&S)|0;S=R;while(1){UGb(V|0,W|0,J)|0;R=S+2|0;if((R|0)<(K|0)){V=V+U|0;W=W+T|0;S=R}else{break}}X=c[O>>2]|0;Y=c[Q>>2]|0}else{X=P;Y=C}S=(X|0)!=(Y|0);T=S&1;a:do{if((T|0)<(K|0)){W=-T|0;U=E+68|0;V=J<<2;R=a[637936+D|0]|0;Z=D>>>0<2>>>0;_=(J|0)>0;$=1429840+(D<<4)|0;aa=1429844+(D<<4)|0;ca=1429848+(D<<4)|0;da=1429852+(D<<4)|0;ea=a[637944+D|0]|0;fa=N<<1;ga=1429872+(D*20|0)|0;ha=1429876+(D*20|0)|0;ia=1429880+(D*20|0)|0;ja=1429884+(D*20|0)|0;ka=1429888+(D*20|0)|0;la=I+(N&W)|0;ma=T;na=S?2:1;oa=W;while(1){TGb(c[U>>2]|0,0,V|0)|0;if(Z){W=0;pa=na;qa=oa;while(1){ra=pa-R|0;sa=ra+(((ra|0)>0?pa:R)+qa&-2)|0;while(1){if((sa|0)<(K|0)){break}else{sa=sa-2|0}}c[g+(W<<2)>>2]=G+(ba(sa,L)|0);ra=W+1|0;if((ra|0)<(R|0)){W=ra;pa=pa+2|0;qa=qa-2|0}else{break}}}qa=c[U>>2]|0;do{if((R|0)==2){if(!_){break}pa=c[$>>2]|0;W=c[aa>>2]|0;ra=c[k>>2]|0;ta=c[r>>2]|0;ua=qa;va=0;wa=ra;xa=ta;while(1){ya=ba(d[wa]|0,pa)|0;za=ya+(c[ua>>2]|0)|0;c[ua>>2]=za;c[ua>>2]=(ba(d[xa]|0,W)|0)+za;za=va+1|0;if((za|0)<(J|0)){ua=ua+4|0;va=za;wa=wa+1|0;xa=xa+1|0}else{break}}c[k>>2]=ra+J;c[r>>2]=ta+J}else if((R|0)==4){if(!_){break}xa=c[$>>2]|0;wa=c[aa>>2]|0;va=c[ca>>2]|0;ua=c[da>>2]|0;W=c[k>>2]|0;pa=c[r>>2]|0;sa=c[t>>2]|0;za=c[u>>2]|0;ya=za+J|0;Aa=qa;Ba=0;Ca=W;Da=pa;Ea=sa;Fa=za;while(1){za=ba(d[Ca]|0,xa)|0;Ga=za+(c[Aa>>2]|0)|0;c[Aa>>2]=Ga;za=(ba(d[Da]|0,wa)|0)+Ga|0;c[Aa>>2]=za;Ga=za+(ba(d[Ea]|0,va)|0)|0;c[Aa>>2]=Ga;c[Aa>>2]=Ga+(ba(d[Fa]|0,ua)|0);Ga=Ba+1|0;if((Ga|0)<(J|0)){Aa=Aa+4|0;Ba=Ga;Ca=Ca+1|0;Da=Da+1|0;Ea=Ea+1|0;Fa=Fa+1|0}else{break}}c[k>>2]=W+J;c[r>>2]=pa+J;c[t>>2]=sa+J;c[u>>2]=ya}}while(0);if(Z){Fa=0;Ea=na;Da=oa;while(1){Ca=Ea-ea|0;Ba=Ca+(((Ca|0)>0?Ea:ea)+Da&-2)|0;while(1){if((Ba|0)<(K|0)){break}else{Ba=Ba-2|0}}c[g+(Fa<<2)>>2]=G+(ba(Ba,L)|0);c[h+(Fa<<2)>>2]=H+(ba(Ba,M)|0);ya=Fa+1|0;if((ya|0)<(ea|0)){Fa=ya;Ea=Ea+2|0;Da=Da-2|0}else{break}}}do{if((ea|0)==3){if(!_){break}Da=c[ga>>2]|0;Ea=c[ha>>2]|0;Fa=c[ia>>2]|0;ya=c[k>>2]|0;sa=c[v>>2]|0;pa=c[r>>2]|0;W=c[w>>2]|0;Ca=c[t>>2]|0;Aa=c[x>>2]|0;ua=W+J|0;va=qa;wa=0;xa=ya;ta=sa;ra=pa;Ga=W;W=Ca;za=Aa;while(1){Ha=ba(d[xa]|0,Da)|0;Ia=Ha+(c[va>>2]|0)|0;c[va>>2]=Ia;Ha=(ba(d[ta]|0,Da)|0)+Ia|0;c[va>>2]=Ha;Ia=Ha+(ba(d[ra]|0,Ea)|0)|0;c[va>>2]=Ia;Ha=Ia+(ba(d[Ga]|0,Ea)|0)|0;c[va>>2]=Ha;Ia=Ha+(ba(d[W]|0,Fa)|0)|0;c[va>>2]=Ia;c[va>>2]=Ia+(ba(d[za]|0,Fa)|0);Ia=wa+1|0;if((Ia|0)<(J|0)){va=va+4|0;wa=Ia;xa=xa+1|0;ta=ta+1|0;ra=ra+1|0;Ga=Ga+1|0;W=W+1|0;za=za+1|0}else{break}}c[k>>2]=ya+J;c[v>>2]=sa+J;c[r>>2]=pa+J;c[w>>2]=ua;c[t>>2]=Ca+J;c[x>>2]=Aa+J;Ja=42}else if((ea|0)==5){if(!_){break}za=c[ga>>2]|0;W=c[ha>>2]|0;Ga=c[ia>>2]|0;ra=c[ja>>2]|0;ta=c[ka>>2]|0;xa=c[k>>2]|0;wa=c[v>>2]|0;va=c[r>>2]|0;Fa=c[w>>2]|0;Ea=c[t>>2]|0;Da=c[x>>2]|0;Ba=c[u>>2]|0;Ia=c[y>>2]|0;Ha=c[z>>2]|0;Ka=c[A>>2]|0;La=Ia+J|0;Ma=Fa+J|0;Na=qa;Oa=0;Pa=xa;Qa=wa;Ra=va;Sa=Fa;Fa=Ea;Ta=Da;Ua=Ba;Va=Ia;Ia=Ha;Wa=Ka;while(1){Xa=ba(d[Pa]|0,za)|0;Ya=Xa+(c[Na>>2]|0)|0;c[Na>>2]=Ya;Xa=(ba(d[Qa]|0,za)|0)+Ya|0;c[Na>>2]=Xa;Ya=Xa+(ba(d[Ra]|0,W)|0)|0;c[Na>>2]=Ya;Xa=Ya+(ba(d[Sa]|0,W)|0)|0;c[Na>>2]=Xa;Ya=Xa+(ba(d[Fa]|0,Ga)|0)|0;c[Na>>2]=Ya;Xa=Ya+(ba(d[Ta]|0,Ga)|0)|0;c[Na>>2]=Xa;Ya=Xa+(ba(d[Ua]|0,ra)|0)|0;c[Na>>2]=Ya;Xa=Ya+(ba(d[Va]|0,ra)|0)|0;c[Na>>2]=Xa;Ya=Xa+(ba(d[Ia]|0,ta)|0)|0;c[Na>>2]=Ya;c[Na>>2]=Ya+(ba(d[Wa]|0,ta)|0);Ya=Oa+1|0;if((Ya|0)<(J|0)){Na=Na+4|0;Oa=Ya;Pa=Pa+1|0;Qa=Qa+1|0;Ra=Ra+1|0;Sa=Sa+1|0;Fa=Fa+1|0;Ta=Ta+1|0;Ua=Ua+1|0;Va=Va+1|0;Ia=Ia+1|0;Wa=Wa+1|0}else{break}}c[k>>2]=xa+J;c[v>>2]=wa+J;c[r>>2]=va+J;c[w>>2]=Ma;c[t>>2]=Ea+J;c[x>>2]=Da+J;c[u>>2]=Ba+J;c[y>>2]=La;c[z>>2]=Ha+J;c[A>>2]=Ka+J;Ja=42}else{Ja=42}}while(0);do{if((Ja|0)==42){Ja=0;if(_){Za=qa;_a=la;$a=0}else{break}while(1){Wa=c[Za>>2]|0;if((Wa|0)<0){ab=0}else{ab=(Wa|0)>16711680?-1:Wa>>>16&255}a[_a]=ab;Wa=$a+1|0;if((Wa|0)<(J|0)){Za=Za+4|0;_a=_a+1|0;$a=Wa}else{break}}}}while(0);qa=ma+2|0;if((qa|0)>=(K|0)){break a}la=la+fa|0;ma=qa;na=na+2|0;oa=oa-2|0}}}while(0);B=B+1|0;}while((B|0)<(c[q>>2]|0));bb=c[e>>2]|0}else{bb=o}c[e>>2]=(bb|0)==0;m=cj(l,b)|0;i=f;return m|0}function Lr(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=bFb(c[e>>2]|0)|0;g=b+12|0;h=dDb(g,c[e>>2]|0,c[a+20>>2]|0)|0;if((h|0)<0){i=h;return i|0}h=a+24|0;a=-(-(c[h>>2]|0)>>(d[f+6|0]|0))|0;c[b+36>>2]=a;c[b+32>>2]=a;a=c[h>>2]|0;c[b+40>>2]=a;c[b+28>>2]=a;c[b+52>>2]=fFb(c[e>>2]|0)|0;e=dEb(c[g>>2]|0,4)|0;c[b+68>>2]=e;i=(e|0)==0?-12:0;return i|0}function Mr(a){a=a|0;var b=0;b=c[a+44>>2]|0;JCb(b+28|0);JCb(b+20|0);JCb(b+24|0);return}function Nr(a){a=a|0;Ok(a,xk(550128)|0);return 0}function Or(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a|0;a=c[b>>2]|0;d=c[a+44>>2]|0;if((c[d+16>>2]|0)!=0){Ur(a,1)|0;e=0;return e|0}a=d+20|0;f=d+24|0;g=d+48|0;while(1){if((c[g>>2]|0)!=0){e=-541478725;h=11;break}d=Ni(c[c[(c[b>>2]|0)+16>>2]>>2]|0)|0;if((d|0)==-541478725){if((c[a>>2]|0)==0){e=-541478725;h=11;break}i=PCb(c[f>>2]|0)|0;if((i|0)==0){e=-12;h=11;break}j=(c[f>>2]|0)+136|0;k=c[j>>2]|0;l=(c[a>>2]|0)+136|0;m=ZGb(k<<1|0>>>31,c[j+4>>2]<<1|k>>>31,c[l>>2]|0,c[l+4>>2]|0)|0;l=i+136|0;c[l>>2]=m;c[l+4>>2]=F;Vr(c[c[(c[b>>2]|0)+16>>2]>>2]|0,i)|0;c[g>>2]=1}else{if((d|0)<0){e=d;h=11;break}}if((c[a>>2]|0)!=0){e=0;h=11;break}}if((h|0)==11){return e|0}return 0}function Pr(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[a>>2]|0;h=c[g+44>>2]|0;j=c[c[g+16>>2]>>2]|0;c[a+56>>2]=c[j+56>>2];c[a+60>>2]=c[j+60>>2]<<1;k=c[j+20>>2]|0;l=a+20|0;c[l>>2]=k;m=a+24|0;c[m>>2]=c[j+24>>2];if((c[h+4>>2]&1|0)==0){n=k}else{c[e>>2]=2;c[e+4>>2]=1;jFb(f,j+116|0,e);e=a+116|0;j=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=j;n=c[l>>2]|0}do{if((n|0)>=3){if((c[m>>2]|0)<3){break}l=bFb(c[a+52>>2]|0)|0;c[h+44>>2]=l;j=h+36|0;if((b[l+8>>1]&16384)==0){c[j>>2]=64;c[h+40>>2]=76;o=0;i=d;return o|0}else{c[j>>2]=68;c[h+40>>2]=18;o=0;i=d;return o|0}}}while(0);yDb(g,16,2136760,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;o=-22;i=d;return o|0}function Qr(a,c,d,f,g,h,i,j,k){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;l=a;a=c;c=d;d=f;f=(j|0)!=0;j=f?a:c;m=f?c:d;f=(i|0)/2|0;i=(h|0)/2|0;if((g|0)<=0){return}h=f-1|0;n=i-1|0;o=f+1|0;p=i+1|0;q=f-2|0;r=i+2|0;s=f-3|0;t=i+3|0;u=i-2|0;v=f+2|0;w=i-3|0;x=f+3|0;y=f<<1;z=i<<1;if((k&2|0)==0){k=m;A=j;B=0;C=d;D=c;E=a;F=l;while(1){G=b[D+(f<<1)>>1]|0;H=G&65535;I=e[A>>1]|0;J=e[k>>1]|0;K=(J+I|0)>>>1;L=b[D+(i<<1)>>1]|0;M=L&65535;N=I-J|0;J=(e[E+(f<<1)>>1]|0)-H|0;I=(e[E+(i<<1)>>1]|0)-M|0;O=((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)>>1;J=(e[C+(f<<1)>>1]|0)-H|0;I=(e[C+(i<<1)>>1]|0)-M|0;P=((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)>>1;J=((N|0)>-1?N:-N|0)>>1;N=(J|0)>(O|0)?J:O;O=(N|0)>(P|0)?N:P;P=e[D+(h<<1)>>1]|0;N=e[D+(n<<1)>>1]|0;J=P-N|0;I=H-M|0;Q=e[D+(o<<1)>>1]|0;R=e[D+(p<<1)>>1]|0;S=Q-R|0;T=((I|0)>-1?I:-I|0)-1+((J|0)>-1?J:-J|0)+((S|0)>-1?S:-S|0)|0;S=e[D+(q<<1)>>1]|0;J=S-M|0;I=P-R|0;U=e[D+(r<<1)>>1]|0;V=H-U|0;W=((J|0)>-1?J:-J|0)+((I|0)>-1?I:-I|0)+((V|0)>-1?V:-V|0)|0;if((W|0)<(T|0)){V=(e[D+(s<<1)>>1]|0)-R|0;I=S-U|0;J=P-(e[D+(t<<1)>>1]|0)|0;X=((V|0)>-1?V:-V|0)+((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)|0;J=(X|0)<(W|0);Y=J?X:W;Z=J?U+S|0:R+P|0}else{Y=T;Z=M+H|0}T=e[D+(u<<1)>>1]|0;P=H-T|0;R=Q-N|0;S=e[D+(v<<1)>>1]|0;U=S-M|0;J=((R|0)>-1?R:-R|0)+((P|0)>-1?P:-P|0)+((U|0)>-1?U:-U|0)|0;if((J|0)<(Y|0)){U=Q-(e[D+(w<<1)>>1]|0)|0;P=S-T|0;R=(e[D+(x<<1)>>1]|0)-N|0;_=(((U|0)>-1?U:-U|0)+((P|0)>-1?P:-P|0)+((R|0)>-1?R:-R|0)|0)<(J|0)?S+T|0:N+Q|0}else{_=Z}Q=_>>>1;N=(G&65535)>>>0>(L&65535)>>>0;L=K-(N?M:H)|0;G=(((e[k+(y<<1)>>1]|0)+(e[A+(y<<1)>>1]|0)|0)>>>1)-H|0;T=(((e[k+(z<<1)>>1]|0)+(e[A+(z<<1)>>1]|0)|0)>>>1)-M|0;S=(G|0)>(T|0);J=S?T:G;R=K-(N?H:M)|0;M=S?G:T;T=(R|0)>(M|0)?M:R;R=(O|0)>(T|0)?O:T;T=-((L|0)>(J|0)?L:J)|0;J=(R|0)>(T|0)?R:T;T=J+K|0;if((Q|0)>(T|0)){$=T&65535}else{T=K-J|0;$=((Q|0)<(T|0)?T:Q)&65535}b[F>>1]=$;Q=B+1|0;if((Q|0)<(g|0)){k=k+2|0;A=A+2|0;B=Q;C=C+2|0;D=D+2|0;E=E+2|0;F=F+2|0}else{break}}return}else{F=m;m=j;j=0;E=d;d=c;c=a;a=l;while(1){l=e[d+(f<<1)>>1]|0;D=e[m>>1]|0;C=e[F>>1]|0;B=(C+D|0)>>>1;A=e[d+(i<<1)>>1]|0;k=D-C|0;C=(e[c+(f<<1)>>1]|0)-l|0;D=(e[c+(i<<1)>>1]|0)-A|0;$=((D|0)>-1?D:-D|0)+((C|0)>-1?C:-C|0)>>1;C=(e[E+(f<<1)>>1]|0)-l|0;D=(e[E+(i<<1)>>1]|0)-A|0;z=((D|0)>-1?D:-D|0)+((C|0)>-1?C:-C|0)>>1;C=((k|0)>-1?k:-k|0)>>1;k=(C|0)>($|0)?C:$;$=(k|0)>(z|0)?k:z;z=e[d+(h<<1)>>1]|0;k=e[d+(n<<1)>>1]|0;C=z-k|0;D=l-A|0;y=e[d+(o<<1)>>1]|0;_=e[d+(p<<1)>>1]|0;Z=y-_|0;Y=((D|0)>-1?D:-D|0)-1+((C|0)>-1?C:-C|0)+((Z|0)>-1?Z:-Z|0)|0;Z=e[d+(q<<1)>>1]|0;C=Z-A|0;D=z-_|0;Q=e[d+(r<<1)>>1]|0;T=l-Q|0;J=((C|0)>-1?C:-C|0)+((D|0)>-1?D:-D|0)+((T|0)>-1?T:-T|0)|0;if((J|0)<(Y|0)){T=(e[d+(s<<1)>>1]|0)-_|0;D=Z-Q|0;C=z-(e[d+(t<<1)>>1]|0)|0;K=((T|0)>-1?T:-T|0)+((D|0)>-1?D:-D|0)+((C|0)>-1?C:-C|0)|0;C=(K|0)<(J|0);aa=C?K:J;ba=C?Q+Z|0:_+z|0}else{aa=Y;ba=A+l|0}Y=e[d+(u<<1)>>1]|0;z=l-Y|0;l=y-k|0;_=e[d+(v<<1)>>1]|0;Z=_-A|0;A=((l|0)>-1?l:-l|0)+((z|0)>-1?z:-z|0)+((Z|0)>-1?Z:-Z|0)|0;if((A|0)<(aa|0)){Z=y-(e[d+(w<<1)>>1]|0)|0;z=_-Y|0;l=(e[d+(x<<1)>>1]|0)-k|0;ca=(((Z|0)>-1?Z:-Z|0)+((z|0)>-1?z:-z|0)+((l|0)>-1?l:-l|0)|0)<(A|0)?_+Y|0:k+y|0}else{ca=ba}y=ca>>>1;k=$+B|0;if((y|0)>(k|0)){da=k&65535}else{k=B-$|0;da=((y|0)<(k|0)?k:y)&65535}b[a>>1]=da;y=j+1|0;if((y|0)<(g|0)){F=F+2|0;m=m+2|0;j=y;E=E+2|0;d=d+2|0;c=c+2|0;a=a+2|0}else{break}}return}}function Rr(a,c,d,f,g,h,i,j,k){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=a;a=c;c=d;d=f;f=(j|0)!=0;j=f?a:c;m=f?c:d;n=(i|0)/2|0;i=(h|0)/2|0;h=(k&2|0)==0;k=n<<1;o=i<<1;if(h){p=m;q=j;r=0;s=d;t=c;u=a;v=l;while(1){w=b[t+(n<<1)>>1]|0;x=w&65535;y=e[q>>1]|0;z=e[p>>1]|0;A=(z+y|0)>>>1;B=b[t+(i<<1)>>1]|0;C=B&65535;D=y-z|0;z=(e[u+(n<<1)>>1]|0)-x|0;y=(e[u+(i<<1)>>1]|0)-C|0;E=((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)>>1;z=(e[s+(n<<1)>>1]|0)-x|0;y=(e[s+(i<<1)>>1]|0)-C|0;F=((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)>>1;z=((D|0)>-1?D:-D|0)>>1;D=(z|0)>(E|0)?z:E;E=(D|0)>(F|0)?D:F;F=(C+x|0)>>>1;D=(w&65535)>>>0>(B&65535)>>>0;B=A-(D?C:x)|0;w=(((e[p+(k<<1)>>1]|0)+(e[q+(k<<1)>>1]|0)|0)>>>1)-x|0;z=(((e[p+(o<<1)>>1]|0)+(e[q+(o<<1)>>1]|0)|0)>>>1)-C|0;y=(w|0)>(z|0);G=y?z:w;H=A-(D?x:C)|0;C=y?w:z;z=(H|0)>(C|0)?C:H;H=(E|0)>(z|0)?E:z;z=-((B|0)>(G|0)?B:G)|0;G=(H|0)>(z|0)?H:z;z=G+A|0;if((F|0)>(z|0)){I=z&65535}else{z=A-G|0;I=((F|0)<(z|0)?z:F)&65535}b[v>>1]=I;F=r+1|0;if((F|0)<3){p=p+2|0;q=q+2|0;r=F;s=s+2|0;t=t+2|0;u=u+2|0;v=v+2|0}else{break}}}else{v=m;m=j;j=0;u=d;t=c;s=a;r=l;while(1){q=e[t+(n<<1)>>1]|0;p=e[m>>1]|0;I=e[v>>1]|0;F=(I+p|0)>>>1;z=e[t+(i<<1)>>1]|0;G=p-I|0;I=(e[s+(n<<1)>>1]|0)-q|0;p=(e[s+(i<<1)>>1]|0)-z|0;A=((p|0)>-1?p:-p|0)+((I|0)>-1?I:-I|0)>>1;I=(e[u+(n<<1)>>1]|0)-q|0;p=(e[u+(i<<1)>>1]|0)-z|0;H=((p|0)>-1?p:-p|0)+((I|0)>-1?I:-I|0)>>1;I=((G|0)>-1?G:-G|0)>>1;G=(I|0)>(A|0)?I:A;A=(G|0)>(H|0)?G:H;H=(z+q|0)>>>1;q=A+F|0;if((H|0)>(q|0)){J=q&65535}else{q=F-A|0;J=((H|0)<(q|0)?q:H)&65535}b[r>>1]=J;H=j+1|0;if((H|0)<3){v=v+2|0;m=m+2|0;j=H;u=u+2|0;t=t+2|0;s=s+2|0;r=r+2|0}else{break}}}r=g-3|0;s=l+(r<<1)|0;l=a+(r<<1)|0;a=c+(r<<1)|0;c=d+(r<<1)|0;d=f?l:a;t=f?a:c;if(h){h=t;f=d;u=r;j=c;m=a;v=l;J=s;while(1){H=b[m+(n<<1)>>1]|0;q=H&65535;A=e[f>>1]|0;F=e[h>>1]|0;z=(F+A|0)>>>1;G=b[m+(i<<1)>>1]|0;I=G&65535;p=A-F|0;F=(e[v+(n<<1)>>1]|0)-q|0;A=(e[v+(i<<1)>>1]|0)-I|0;B=((A|0)>-1?A:-A|0)+((F|0)>-1?F:-F|0)>>1;F=(e[j+(n<<1)>>1]|0)-q|0;A=(e[j+(i<<1)>>1]|0)-I|0;E=((A|0)>-1?A:-A|0)+((F|0)>-1?F:-F|0)>>1;F=((p|0)>-1?p:-p|0)>>1;p=(F|0)>(B|0)?F:B;B=(p|0)>(E|0)?p:E;E=(I+q|0)>>>1;p=(H&65535)>>>0>(G&65535)>>>0;G=z-(p?I:q)|0;H=(((e[h+(k<<1)>>1]|0)+(e[f+(k<<1)>>1]|0)|0)>>>1)-q|0;F=(((e[h+(o<<1)>>1]|0)+(e[f+(o<<1)>>1]|0)|0)>>>1)-I|0;A=(H|0)>(F|0);C=A?F:H;w=z-(p?q:I)|0;I=A?H:F;F=(w|0)>(I|0)?I:w;w=(B|0)>(F|0)?B:F;F=-((G|0)>(C|0)?G:C)|0;C=(w|0)>(F|0)?w:F;F=C+z|0;if((E|0)>(F|0)){K=F&65535}else{F=z-C|0;K=((E|0)<(F|0)?F:E)&65535}b[J>>1]=K;E=u+1|0;if((E|0)<(g|0)){h=h+2|0;f=f+2|0;u=E;j=j+2|0;m=m+2|0;v=v+2|0;J=J+2|0}else{break}}return}else{J=t;t=d;d=r;r=c;c=a;a=l;l=s;while(1){s=e[c+(n<<1)>>1]|0;v=e[t>>1]|0;m=e[J>>1]|0;j=(m+v|0)>>>1;u=e[c+(i<<1)>>1]|0;f=v-m|0;m=(e[a+(n<<1)>>1]|0)-s|0;v=(e[a+(i<<1)>>1]|0)-u|0;h=((v|0)>-1?v:-v|0)+((m|0)>-1?m:-m|0)>>1;m=(e[r+(n<<1)>>1]|0)-s|0;v=(e[r+(i<<1)>>1]|0)-u|0;K=((v|0)>-1?v:-v|0)+((m|0)>-1?m:-m|0)>>1;m=((f|0)>-1?f:-f|0)>>1;f=(m|0)>(h|0)?m:h;h=(f|0)>(K|0)?f:K;K=(u+s|0)>>>1;s=h+j|0;if((K|0)>(s|0)){L=s&65535}else{s=j-h|0;L=((K|0)<(s|0)?s:K)&65535}b[l>>1]=L;K=d+1|0;if((K|0)<(g|0)){J=J+2|0;t=t+2|0;d=K;r=r+2|0;c=c+2|0;a=a+2|0;l=l+2|0}else{break}}return}}function Sr(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;l=(j|0)!=0;if((g|0)<=0){return}j=i-1|0;m=h-1|0;n=i+1|0;o=h+1|0;p=i-2|0;q=h+2|0;r=i-3|0;s=h+3|0;t=h-2|0;u=i+2|0;v=h-3|0;w=i+3|0;x=(k&2|0)==0;k=i<<1;y=h<<1;z=l?e:f;A=l?c:e;l=0;B=f;f=e;e=c;c=b;while(1){b=a[f+i|0]|0;C=b&255;D=d[A]|0;E=d[z]|0;F=(E+D|0)>>>1;G=a[f+h|0]|0;H=G&255;I=D-E|0;E=(d[e+i|0]|0)-C|0;D=(d[e+h|0]|0)-H|0;J=((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)>>1;E=(d[B+i|0]|0)-C|0;D=(d[B+h|0]|0)-H|0;K=((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)>>1;E=((I|0)>-1?I:-I|0)>>1;I=(E|0)>(J|0)?E:J;J=(I|0)>(K|0)?I:K;K=d[f+j|0]|0;I=d[f+m|0]|0;E=K-I|0;D=C-H|0;L=d[f+n|0]|0;M=d[f+o|0]|0;N=L-M|0;O=((D|0)>-1?D:-D|0)-1+((E|0)>-1?E:-E|0)+((N|0)>-1?N:-N|0)|0;N=d[f+p|0]|0;E=N-H|0;D=K-M|0;P=d[f+q|0]|0;Q=C-P|0;R=((E|0)>-1?E:-E|0)+((D|0)>-1?D:-D|0)+((Q|0)>-1?Q:-Q|0)|0;if((R|0)<(O|0)){Q=(d[f+r|0]|0)-M|0;D=N-P|0;E=K-(d[f+s|0]|0)|0;S=((Q|0)>-1?Q:-Q|0)+((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)|0;E=(S|0)<(R|0);T=E?S:R;U=E?P+N|0:M+K|0}else{T=O;U=H+C|0}O=d[f+t|0]|0;K=C-O|0;M=L-I|0;N=d[f+u|0]|0;P=N-H|0;E=((M|0)>-1?M:-M|0)+((K|0)>-1?K:-K|0)+((P|0)>-1?P:-P|0)|0;if((E|0)<(T|0)){P=L-(d[f+v|0]|0)|0;K=N-O|0;M=(d[f+w|0]|0)-I|0;V=(((P|0)>-1?P:-P|0)+((K|0)>-1?K:-K|0)+((M|0)>-1?M:-M|0)|0)<(E|0)?N+O|0:I+L|0}else{V=U}L=V>>>1;if(x){I=(b&255)>>>0>(G&255)>>>0;G=F-(I?H:C)|0;b=(((d[z+k|0]|0)+(d[A+k|0]|0)|0)>>>1)-C|0;O=(((d[z+y|0]|0)+(d[A+y|0]|0)|0)>>>1)-H|0;N=(b|0)>(O|0);E=N?O:b;M=F-(I?C:H)|0;H=N?b:O;O=(M|0)>(H|0)?H:M;M=(J|0)>(O|0)?J:O;O=-((G|0)>(E|0)?G:E)|0;W=(M|0)>(O|0)?M:O}else{W=J}J=W+F|0;if((L|0)>(J|0)){X=J&255}else{J=F-W|0;X=((L|0)<(J|0)?J:L)&255}a[c]=X;L=l+1|0;if((L|0)<(g|0)){z=z+1|0;A=A+1|0;l=L;B=B+1|0;f=f+1|0;e=e+1|0;c=c+1|0}else{break}}return}function Tr(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;l=(j|0)!=0;j=(k&2|0)==0;k=i<<1;m=h<<1;n=l?e:f;o=l?c:e;p=0;q=f;r=e;s=c;t=b;while(1){u=a[r+i|0]|0;v=u&255;w=d[o]|0;x=d[n]|0;y=(x+w|0)>>>1;z=a[r+h|0]|0;A=z&255;B=w-x|0;x=(d[s+i|0]|0)-v|0;w=(d[s+h|0]|0)-A|0;C=((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)>>1;x=(d[q+i|0]|0)-v|0;w=(d[q+h|0]|0)-A|0;D=((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)>>1;x=((B|0)>-1?B:-B|0)>>1;B=(x|0)>(C|0)?x:C;C=(B|0)>(D|0)?B:D;D=(A+v|0)>>>1;if(j){B=(u&255)>>>0>(z&255)>>>0;z=y-(B?A:v)|0;u=(((d[n+k|0]|0)+(d[o+k|0]|0)|0)>>>1)-v|0;x=(((d[n+m|0]|0)+(d[o+m|0]|0)|0)>>>1)-A|0;w=(u|0)>(x|0);E=w?x:u;F=y-(B?v:A)|0;A=w?u:x;x=(F|0)>(A|0)?A:F;F=(C|0)>(x|0)?C:x;x=-((z|0)>(E|0)?z:E)|0;G=(F|0)>(x|0)?F:x}else{G=C}C=G+y|0;if((D|0)>(C|0)){H=C&255}else{C=y-G|0;H=((D|0)<(C|0)?C:D)&255}a[t]=H;D=p+1|0;if((D|0)<3){n=n+1|0;o=o+1|0;p=D;q=q+1|0;r=r+1|0;s=s+1|0;t=t+1|0}else{break}}t=g-7|0;s=c+t|0;r=e+t|0;q=f+t|0;p=l?s:r;o=l?r:q;l=g-3|0;n=i-1|0;H=h-1|0;G=i+1|0;D=h+1|0;C=i-2|0;y=h+2|0;x=i-3|0;F=h+3|0;E=h-2|0;z=i+2|0;A=h-3|0;u=i+3|0;w=g-6|0;v=(l|0)>(w|0)?l:w;w=v+7-g|0;B=o+w|0;I=f+v|0;f=e+v|0;e=o;o=p;J=t;K=q;q=r;r=s;s=b+t|0;while(1){t=a[q+i|0]|0;L=t&255;M=d[o]|0;N=d[e]|0;O=(N+M|0)>>>1;P=a[q+h|0]|0;Q=P&255;R=M-N|0;N=(d[r+i|0]|0)-L|0;M=(d[r+h|0]|0)-Q|0;S=((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)>>1;N=(d[K+i|0]|0)-L|0;M=(d[K+h|0]|0)-Q|0;T=((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)>>1;N=((R|0)>-1?R:-R|0)>>1;R=(N|0)>(S|0)?N:S;S=(R|0)>(T|0)?R:T;T=d[q+n|0]|0;R=d[q+H|0]|0;N=T-R|0;M=L-Q|0;U=d[q+G|0]|0;V=d[q+D|0]|0;W=U-V|0;X=((M|0)>-1?M:-M|0)-1+((N|0)>-1?N:-N|0)+((W|0)>-1?W:-W|0)|0;W=d[q+C|0]|0;N=W-Q|0;M=T-V|0;Y=d[q+y|0]|0;Z=L-Y|0;_=((N|0)>-1?N:-N|0)+((M|0)>-1?M:-M|0)+((Z|0)>-1?Z:-Z|0)|0;if((_|0)<(X|0)){Z=(d[q+x|0]|0)-V|0;M=W-Y|0;N=T-(d[q+F|0]|0)|0;$=((Z|0)>-1?Z:-Z|0)+((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)|0;N=($|0)<(_|0);aa=N?Y+W|0:V+T|0;ba=N?$:_}else{aa=Q+L|0;ba=X}X=d[q+E|0]|0;_=L-X|0;$=U-R|0;N=d[q+z|0]|0;T=N-Q|0;V=(($|0)>-1?$:-$|0)+((_|0)>-1?_:-_|0)+((T|0)>-1?T:-T|0)|0;if((V|0)<(ba|0)){T=U-(d[q+A|0]|0)|0;_=N-X|0;$=(d[q+u|0]|0)-R|0;ca=(((T|0)>-1?T:-T|0)+((_|0)>-1?_:-_|0)+(($|0)>-1?$:-$|0)|0)<(V|0)?N+X|0:R+U|0}else{ca=aa}U=ca>>>1;if(j){R=(t&255)>>>0>(P&255)>>>0;P=O-(R?Q:L)|0;t=(((d[e+k|0]|0)+(d[o+k|0]|0)|0)>>>1)-L|0;X=(((d[e+m|0]|0)+(d[o+m|0]|0)|0)>>>1)-Q|0;N=(t|0)>(X|0);V=N?X:t;$=O-(R?L:Q)|0;Q=N?t:X;X=($|0)>(Q|0)?Q:$;$=(S|0)>(X|0)?S:X;X=-((P|0)>(V|0)?P:V)|0;da=($|0)>(X|0)?$:X}else{da=S}S=da+O|0;if((U|0)>(S|0)){ea=S&255}else{S=O-da|0;ea=((U|0)<(S|0)?S:U)&255}a[s]=ea;U=J+1|0;if((U|0)<(l|0)){e=e+1|0;o=o+1|0;J=U;K=K+1|0;q=q+1|0;r=r+1|0;s=s+1|0}else{break}}s=B;B=p+w|0;w=l;l=I;I=f;f=c+v|0;c=b+v|0;while(1){v=a[I+i|0]|0;b=v&255;p=d[B]|0;r=d[s]|0;q=(r+p|0)>>>1;K=a[I+h|0]|0;J=K&255;o=p-r|0;r=(d[f+i|0]|0)-b|0;p=(d[f+h|0]|0)-J|0;e=((p|0)>-1?p:-p|0)+((r|0)>-1?r:-r|0)>>1;r=(d[l+i|0]|0)-b|0;p=(d[l+h|0]|0)-J|0;ea=((p|0)>-1?p:-p|0)+((r|0)>-1?r:-r|0)>>1;r=((o|0)>-1?o:-o|0)>>1;o=(r|0)>(e|0)?r:e;e=(o|0)>(ea|0)?o:ea;ea=(J+b|0)>>>1;if(j){o=(v&255)>>>0>(K&255)>>>0;K=q-(o?J:b)|0;v=(((d[s+k|0]|0)+(d[B+k|0]|0)|0)>>>1)-b|0;r=(((d[s+m|0]|0)+(d[B+m|0]|0)|0)>>>1)-J|0;p=(v|0)>(r|0);da=p?r:v;ca=q-(o?b:J)|0;J=p?v:r;r=(ca|0)>(J|0)?J:ca;ca=(e|0)>(r|0)?e:r;r=-((K|0)>(da|0)?K:da)|0;fa=(ca|0)>(r|0)?ca:r}else{fa=e}e=fa+q|0;if((ea|0)>(e|0)){ga=e&255}else{e=q-fa|0;ga=((ea|0)<(e|0)?e:ea)&255}a[c]=ga;ea=w+1|0;if((ea|0)<(g|0)){s=s+1|0;B=B+1|0;w=ea;l=l+1|0;I=I+1|0;f=f+1|0;c=c+1|0}else{break}}return}function Ur(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+24|0;g=f|0;h=b+44|0;j=c[h>>2]|0;k=b+32|0;l=c[c[k>>2]>>2]|0;m=c[j+8>>2]|0;do{if((m|0)==-1){n=c[j+20>>2]|0;if((c[n+296>>2]|0)==0){o=1;break}o=c[n+300>>2]|0}else{o=m^1}}while(0);m=(e|0)!=0;do{if(m){e=Zr(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;n=j+32|0;c[n>>2]=e;if((e|0)==0){p=-12;i=f;return p|0}else{NCb(e,c[j+20>>2]|0)|0;e=c[n>>2]|0;c[e+296>>2]=0;q=c[h>>2]|0;r=e;break}}else{q=j;r=c[j+32>>2]|0}}while(0);h=j+32|0;l=m&1^1;e=g;c[g>>2]=r;n=g+4|0;c[n>>2]=0;s=g+8|0;c[s>>2]=0;t=g+12|0;c[t>>2]=0;c[g+16>>2]=o^l;c[g+20>>2]=o;o=q+44|0;q=c[o>>2]|0;if((a[q+4|0]|0)!=0){g=r+68|0;u=r+72|0;r=b+56|0;v=b+48|0;w=0;x=q;do{q=c[g>>2]|0;y=c[u>>2]|0;if((w-1|0)>>>0<2>>>0){z=-(-y>>d[x+6|0])|0;A=-(-q>>d[x+5|0])|0}else{z=y;A=q}c[s>>2]=A;c[t>>2]=z;c[n>>2]=w;q=c[(c[v>>2]|0)+28>>2]|0;Pe[c[c[r>>2]>>2]&255](b,450,e,0,(z|0)>(q|0)?q:z)|0;w=w+1|0;x=c[o>>2]|0;}while((w|0)<(d[x+4|0]|0))}do{if(m){x=(c[j+20>>2]|0)+136|0;w=c[x>>2]|0;o=c[x+4>>2]|0;x=(c[j+24>>2]|0)+136|0;z=c[x>>2]|0;e=c[x+4>>2]|0;if((z|0)==0&(e|0)==(-2147483648|0)|(w|0)==0&(o|0)==(-2147483648|0)){x=c[h>>2]|0;b=x+136|0;c[b>>2]=0;c[b+4>>2]=-2147483648;B=x;break}else{x=YGb(z,e,w,o)|0;o=c[h>>2]|0;w=o+136|0;c[w>>2]=x;c[w+4>>2]=F;B=o;break}}else{B=c[h>>2]|0}}while(0);h=cj(c[c[k>>2]>>2]|0,B)|0;c[j+16>>2]=(c[j+4>>2]&1|0)==0?0:l;p=h;i=f;return p|0}function Vr(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=c[b+8>>2]|0;h=c[g+44>>2]|0;if((e|0)==0){yDb(0,0,2130512,(j=i,i=i+24|0,c[j>>2]=2123872,c[j+8>>2]=2118440,c[j+16>>2]=317,j)|0);i=j;Cd();return 0}if((c[h+16>>2]|0)!=0){Ur(g,1)|0}k=h+28|0;if((c[k>>2]|0)!=0){JCb(k)}l=h+20|0;c[k>>2]=c[l>>2];m=h+24|0;n=c[m>>2]|0;c[l>>2]=n;c[m>>2]=e;if((n|0)==0){o=0;i=f;return o|0}p=h+44|0;q=a[(c[p>>2]|0)+4|0]|0;r=q&255;s=0;while(1){if((s|0)>=(r|0)){t=e;u=n;v=q;break}if((c[e+32+(s<<2)>>2]|0)==(c[n+32+(s<<2)>>2]|0)){s=s+1|0}else{w=11;break}}if((w|0)==11){yDb(g,40,2110248,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Wr(b,c[m>>2]|0);t=c[m>>2]|0;u=c[l>>2]|0;v=a[(c[p>>2]|0)+4|0]|0}s=v&255;v=0;while(1){if((v|0)>=(s|0)){break}if((c[t+32+(v<<2)>>2]|0)==(c[u+32+(v<<2)>>2]|0)){v=v+1|0}else{w=15;break}}if((w|0)==15){Wr(b,u)}u=c[k>>2]|0;a:do{if((u|0)!=0){v=c[m>>2]|0;t=d[(c[p>>2]|0)+4|0]|0;s=0;while(1){if((s|0)>=(t|0)){break a}if((c[v+32+(s<<2)>>2]|0)==(c[u+32+(s<<2)>>2]|0)){s=s+1|0}else{break}}Wr(b,u)}}while(0);u=c[m>>2]|0;m=c[l>>2]|0;s=d[(c[p>>2]|0)+4|0]|0;p=0;while(1){if((p|0)>=(s|0)){w=24;break}if((c[u+32+(p<<2)>>2]|0)==(c[m+32+(p<<2)>>2]|0)){p=p+1|0}else{break}}b:do{if((w|0)==24){p=c[k>>2]|0;v=(p|0)==0;c:do{if(!v){t=0;while(1){if((t|0)>=(s|0)){break c}if((c[u+32+(t<<2)>>2]|0)==(c[p+32+(t<<2)>>2]|0)){t=t+1|0}else{break b}}}}while(0);if((c[h+12>>2]|0)==0){w=30}else{if((c[m+296>>2]|0)!=0){w=30}}do{if((w|0)==30){if((c[g+76>>2]|0)!=0){break}do{if(v){p=PCb(m)|0;c[k>>2]=p;if((p|0)==0){o=-12}else{break}i=f;return o|0}}while(0);p=Zr(c[c[g+32>>2]>>2]|0,c[b+20>>2]|0,c[b+24>>2]|0)|0;t=h+32|0;c[t>>2]=p;if((p|0)==0){o=-12;i=f;return o|0}NCb(p,c[l>>2]|0)|0;p=c[t>>2]|0;c[p+296>>2]=0;t=p+136|0;p=c[t>>2]|0;n=c[t+4>>2]|0;if(!((p|0)==0&(n|0)==(-2147483648|0))){c[t>>2]=p<<1|0>>>31;c[t+4>>2]=n<<1|p>>>31}o=Ur(g,0)|0;i=f;return o|0}}while(0);v=PCb(m)|0;p=h+32|0;c[p>>2]=v;if((v|0)==0){o=-12;i=f;return o|0}JCb(k);v=c[p>>2]|0;p=v+136|0;n=c[p>>2]|0;t=c[p+4>>2]|0;if(!((n|0)==0&(t|0)==(-2147483648|0))){c[p>>2]=n<<1|0>>>31;c[p+4>>2]=t<<1|n>>>31}o=cj(c[c[g+32>>2]>>2]|0,v)|0;i=f;return o|0}}while(0);yDb(g,16,2097416,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;o=-1;i=f;return o|0}function Wr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+8|0;e=d|0;f=_r(a,c[b+68>>2]|0,c[b+72>>2]|0)|0;c[e>>2]=f;if((f|0)==0){i=d;return}NCb(f,b)|0;jDb(f|0,f+32|0,b|0,b+32|0,c[f+80>>2]|0,c[f+68>>2]|0,c[f+72>>2]|0);KCb(b);QCb(b,f);JCb(e);i=d;return}function Xr(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=c[a+44>>2]|0;a=b+4|0;h=c[a>>2]|0;i=g+20|0;j=c[(c[i>>2]|0)+32+(h<<2)>>2]|0;k=(((e[(c[g+44>>2]|0)+8+(h<<1)>>1]|0)>>>11&15)+8|0)>>>3;h=k*3|0;l=b+12|0;m=c[l>>2]|0;n=(ba(m,d)|0)/(f|0)|0;o=(ba(m,d+1|0)|0)/(f|0)|0;if((n|0)>=(o|0)){return 0}f=b+16|0;d=b;m=b+8|0;p=g+28|0;q=g+24|0;r=g+36|0;s=-j|0;t=b+20|0;b=g+40|0;u=g+4|0;g=n;while(1){n=c[f>>2]|0;if(((n^g)&1|0)==0){v=c[a>>2]|0;w=c[d>>2]|0;x=ba(c[w+32+(v<<2)>>2]|0,g)|0;y=ba(g,j)|0;UGb((c[w+(v<<2)>>2]|0)+x|0,(c[(c[i>>2]|0)+(v<<2)>>2]|0)+y|0,ba(c[m>>2]|0,k)|0)|0;z=g+1|0}else{y=ba(g,j)|0;v=c[a>>2]|0;x=c[(c[p>>2]|0)+(v<<2)>>2]|0;w=x+y|0;A=c[(c[i>>2]|0)+(v<<2)>>2]|0;B=A+y|0;C=c[(c[q>>2]|0)+(v<<2)>>2]|0;D=C+y|0;E=c[d>>2]|0;F=ba(c[E+32+(v<<2)>>2]|0,g)|0;G=c[E+(v<<2)>>2]|0;v=G+F|0;do{if((g|0)==1){H=2;I=c[l>>2]|0}else{E=g+2|0;J=c[l>>2]|0;if((E|0)==(J|0)){H=2;I=E;break}H=c[u>>2]|0;I=J}}while(0);J=y+h|0;E=g+1|0;K=(g|0)!=0?s:j;Le[c[r>>2]&255](G+(F+h)|0,x+J|0,A+J|0,C+J|0,(c[m>>2]|0)-2-(8/(k>>>0)|0)|0,(E|0)<(I|0)?j:s,K,c[t>>2]^n,H);Le[c[b>>2]&255](v,w,B,D,c[m>>2]|0,(E|0)<(c[l>>2]|0)?j:s,K,c[t>>2]^c[f>>2],H);z=E}if((z|0)<(o|0)){g=z}else{break}}return 0}function Yr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=c[c[(c[a+8>>2]|0)+32>>2]>>2]|0;Mi(0,g,0);a=c[(c[g+12>>2]|0)+20>>2]|0;do{if((a|0)!=0){h=ze[a&511](g,b,d)|0;if((h|0)==0){break}else{j=h}i=e;return j|0}}while(0);a=ICb()|0;c[f>>2]=a;if((a|0)==0){j=0;i=e;return j|0}c[a+68>>2]=b;c[a+72>>2]=d;c[a+80>>2]=c[g+52>>2];if((LCb(a,32)|0)>=0){j=a;i=e;return j|0}JCb(f);j=c[f>>2]|0;i=e;return j|0}function Zr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;Mi(0,a,0);g=c[(c[a+12>>2]|0)+20>>2]|0;do{if((g|0)!=0){h=ze[g&511](a,b,d)|0;if((h|0)==0){break}else{j=h}i=e;return j|0}}while(0);g=ICb()|0;c[f>>2]=g;if((g|0)==0){j=0;i=e;return j|0}c[g+68>>2]=b;c[g+72>>2]=d;c[g+80>>2]=c[a+52>>2];if((LCb(g,32)|0)>=0){j=g;i=e;return j|0}JCb(f);j=c[f>>2]|0;i=e;return j|0}function _r(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;g=ICb()|0;c[f>>2]=g;if((g|0)==0){h=0;i=e;return h|0}c[g+68>>2]=b;c[g+72>>2]=d;c[g+80>>2]=c[a+52>>2];if((LCb(g,32)|0)>=0){h=g;i=e;return h|0}JCb(f);h=c[f>>2]|0;i=e;return h|0}function $r(a,b){a=a|0;b=b|0;var d=0;a=i;i=i+8|0;d=a|0;c[d>>2]=b;JCb(d);i=a;return 0}function as(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;f=b+44|0;g=c[f>>2]|0;j=g+4|0;k=g+12|0;do{if((c[j>>2]|0)==0){if((c[k>>2]|0)!=0){break}if((c[g+356>>2]|0)!=0){break}rEb(g,2161680,2090864,0)|0}}while(0);l=(c[g+356>>2]|0)==0;do{if((c[k>>2]|0)==0){if(!l){m=ds(b)|0;if((m|0)<0){n=m}else{break}i=e;return n|0}m=cEb(ba(c[g+8>>2]|0,c[j>>2]|0)|0)|0;o=g+28|0;c[o>>2]=m;if((m|0)==0){n=-12;i=e;return n|0}m=g+72|0;p=c[m>>2]|0;if((p|0)==-1){q=hFb()|0;c[m>>2]=q;r=q}else{r=p}p=g+96|0;oDb(p,r);if((c[j>>2]|0)<=0){break}q=g+352|0;m=g+64|0;s=0;do{t=c[q>>2]|0;c[p+((t&63)<<2)>>2]=(c[p+((t+9&63)<<2)>>2]|0)+(c[p+((t+40&63)<<2)>>2]|0);t=c[q>>2]|0;c[q>>2]=t+1;if(!(+((c[p+((t&63)<<2)>>2]|0)>>>0>>>0)/4294967295.0>+h[m>>3])){a[(c[o>>2]|0)+s|0]=1}s=s+1|0;}while((s|0)<(c[j>>2]|0))}else{if(!l){yDb(b,16,2037936,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;n=-22;i=e;return n|0}s=c[f>>2]|0;o=s+20|0;m=s+24|0;p=aCb(c[s+12>>2]|0,o,m,0,b)|0;if((p|0)<0){n=p;i=e;return n|0}p=WDb((c[m>>2]|0)+1|0)|0;q=s+356|0;c[q>>2]=p;if((p|0)==0){n=-12;i=e;return n|0}UGb(p|0,c[o>>2]|0,c[m>>2]|0)|0;a[(c[q>>2]|0)+(c[m>>2]|0)|0]=0;m=ds(b)|0;if((m|0)<0){n=m}else{break}i=e;return n|0}}while(0);f=c[g+8>>2]|0;l=c[g+56>>2]|0;r=c[g+60>>2]|0;k=d[g+40|0]|0;m=c[g+76>>2]|0;q=c[g+80>>2]|0;o=c[g+84>>2]|0;p=c[g+72>>2]|0;yDb(b,40,1993536,(u=i,i=i+72|0,c[u>>2]=c[j>>2],c[u+8>>2]=f,c[u+16>>2]=l,c[u+24>>2]=r,c[u+32>>2]=k,c[u+40>>2]=m,c[u+48>>2]=q,c[u+56>>2]=o,c[u+64>>2]=p,u)|0);i=u;n=0;i=e;return n|0}function bs(a){a=a|0;var b=0;b=c[a+44>>2]|0;bCb(c[b+20>>2]|0,c[b+24>>2]|0);$Db(b+28|0);$Db(b+356|0);return}function cs(a){a=a|0;Ok(a,xk(550120)|0);return 0}function ds(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=c[b+44>>2]|0;f=e+356|0;g=SGb(c[f>>2]|0)|0;h=b;yDb(h,48,1958680,(b=i,i=i+8|0,c[b>>2]=g,b)|0);i=b;j=e+4|0;k=c[j>>2]|0;do{if((k|0)==0){c[j>>2]=g;l=~~(+(g|0)*1.618033988749895);c[e+8>>2]=l;m=g;n=l}else{if((g|0)<=(k|0)){m=k;n=c[e+8>>2]|0;break}yDb(h,16,1930816,(b=i,i=i+16|0,c[b>>2]=k,c[b+8>>2]=g,b)|0);i=b;o=-22;i=d;return o|0}}while(0);k=cEb(ba(n,m)|0)|0;m=e+28|0;c[m>>2]=k;if((k|0)==0){o=-12;i=d;return o|0}k=((c[j>>2]|0)-g|0)/2|0;g=c[f>>2]|0;while(1){f=a[g]|0;yDb(h,48,1908616,(b=i,i=i+16|0,c[b>>2]=k,c[b+8>>2]=f<<24>>24==10?78:f<<24>>24,b)|0);i=b;f=a[g]|0;if((f<<24>>24|0)==10|(f<<24>>24|0)==0){o=0;break}j=(DAb(f<<24>>24)|0)!=0|0;a[(c[m>>2]|0)+k|0]=j;k=k+1|0;g=g+1|0}i=d;return o|0}function es(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;e=b|0;f=c[(c[e>>2]|0)+44>>2]|0;g=f+8|0;h=Zr(b,c[f+4>>2]|0,c[g>>2]|0)|0;if((h|0)==0){i=-12;return i|0}c[h+124>>2]=1;c[h+128>>2]=1;j=f+88|0;do{if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){if((c[f+84>>2]|0)==0){break}if(((c[g>>2]|0)-1|0)>0){k=0}else{break}do{gs(c[(c[e>>2]|0)+44>>2]|0);k=k+1|0;}while((k|0)<((c[g>>2]|0)-1|0))}}while(0);g=c[(c[e>>2]|0)+44>>2]|0;k=c[h>>2]|0;do{if((c[g+80>>2]|0)==0){l=0;m=c[g+8>>2]|0}else{j=g+88|0;n=c[j+4>>2]|0;o=c[g+8>>2]|0;p=(o|0)<0|0?-1:0;if((n|0)<(p|0)|(n|0)==(p|0)&(c[j>>2]|0)>>>0<o>>>0){l=0;m=o;break}l=((c[g+36>>2]|0)+1|0)%(o|0)|0;m=o}}while(0);o=g+8|0;if((m|0)>0){j=g+28|0;p=g+4|0;n=h+32|0;q=l;l=k;k=1;r=c[p>>2]|0;s=m;while(1){m=c[j>>2]|0;t=ba(q,r)|0;if((r|0)>0){u=0;v=0;w=0;x=l;y=r;while(1){z=v+1|0;A=((d[m+(u+t)|0]|0)<<7-v|w&255)&255;if((z|0)==8){B=15}else{if((u|0)==(y-1|0)){B=15}else{C=x;D=A;E=z;G=y}}if((B|0)==15){B=0;a[x]=A;C=x+1|0;D=0;E=0;G=c[p>>2]|0}A=u+1|0;if((A|0)<(G|0)){u=A;v=E;w=D;x=C;y=G}else{break}}H=G;I=c[o>>2]|0}else{H=r;I=s}if((k|0)>=(I|0)){break}q=(q+1|0)%(I|0)|0;l=l+(c[n>>2]|0)|0;k=k+1|0;r=H;s=I}J=c[(c[e>>2]|0)+44>>2]|0}else{J=g}gs(J);J=f+48|0;f=c[J>>2]|0;g=c[J+4>>2]|0;e=YGb(f,g,1,0)|0;c[J>>2]=e;c[J+4>>2]=F;J=h+136|0;c[J>>2]=f;c[J+4>>2]=g;i=cj(b,h)|0;return i|0}function fs(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+4>>2];c[a+24>>2]=c[b+8>>2];d=a+56|0;a=c[b+56>>2]|0;c[d>>2]=c[b+60>>2];c[d+4>>2]=a;return 0}function gs(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=c[b+28>>2]|0;f=b+36|0;g=c[f>>2]|0;h=b+4|0;i=c[h>>2]|0;j=ba(i,g)|0;c[b+32>>2]=g;k=(g|0)==((c[b+8>>2]|0)-1|0)?0:g+1|0;c[f>>2]=k;f=ba(k,i)|0;if((i|0)<=0){l=b+88|0;m=l;n=m|0;o=c[n>>2]|0;p=m+4|0;q=c[p>>2]|0;r=1;s=0;t=YGb(o,q,r,s)|0;u=F;v=m|0;c[v>>2]=t;w=m+4|0;c[w>>2]=u;return}k=b+76|0;g=j-1|0;x=b+40|0;y=0;z=i;do{if((c[k>>2]|0)==0){if((y|0)>0){A=(d[e+(g+y)|0]|0)<<2}else{A=0}i=y+1|0;if((i|0)<(z|0)){B=d[e+(i+j)|0]|0}else{B=0}C=(d[e+(y+j)|0]|0)<<1|A|B}else{i=y+1|0;C=(d[e+(y+j)|0]|0)<<1|(d[e+(g+((y-1|0)<0?z:y))|0]|0)<<2|(d[e+(((i|0)==(z|0)?0:i)+j)|0]|0)}a[e+(y+f)|0]=((d[x]|0)&1<<C|0)!=0|0;y=y+1|0;z=c[h>>2]|0;}while((y|0)<(z|0));l=b+88|0;m=l;n=m|0;o=c[n>>2]|0;p=m+4|0;q=c[p>>2]|0;r=1;s=0;t=YGb(o,q,r,s)|0;u=F;v=m|0;c[v>>2]=t;w=m+4|0;c[w>>2]=u;return}function hs(d){d=d|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;f=i;i=i+8|0;g=f|0;j=d+44|0;k=c[j>>2]|0;l=k+4|0;do{if((c[l>>2]|0)==0){if((c[k+12>>2]|0)!=0){break}rEb(k,2037864,1993416,0)|0}}while(0);m=k+40|0;n=k+38|0;o=k+16|0;p=c[o>>2]|0;q=d;b[m>>1]=0;b[n>>1]=0;d=a[p]|0;do{if((Ib(2323968,d<<24>>24|0,5)|0)==0){r=kb(p|0,g|0,10)|0;if((a[c[g>>2]|0]|0)!=0){s=15;break}b[m>>1]=r&511;b[n>>1]=r>>>9}else{r=p;t=d;while(1){if((t<<24>>24|0)==98|(t<<24>>24|0)==66){u=m}else{u=n}v=r+1|0;w=a[v]|0;if((w-48&255)>>>0<9>>>0){x=v;v=w;y=b[u>>1]|0;while(1){z=(1<<(v<<24>>24)-48)+(y&65535)&65535;b[u>>1]=z;A=x+1|0;B=a[A]|0;if((B-48&255)>>>0<9>>>0){x=A;v=B;y=z}else{C=x;D=B;break}}}else{C=r;D=w}if(!(D<<24>>24==47)){E=D;break}x=C+2|0;y=a[x]|0;if((Ib(2323968,y<<24>>24|0,5)|0)==0){E=y;break}else{r=x;t=y}}if(!(E<<24>>24==0)){s=15}}}while(0);if((s|0)==15){yDb(q,16,2300864,(F=i,i=i+8|0,c[F>>2]=p,F)|0);i=F;G=-22;i=f;return G|0}do{if((c[k+80>>2]|0)==0){if((PGb(k+92|0,9203304,3)|0)==0){break}yDb(q,24,1958560,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F}}while(0);a:do{if((c[k+12>>2]|0)==0){p=k+8|0;s=dEb(ba(c[l>>2]|0,c[p>>2]|0)|0,1)|0;E=k+28|0;c[E>>2]=s;do{if((s|0)==0){H=0;I=k+32|0}else{C=dEb(ba(c[l>>2]|0,c[p>>2]|0)|0,1)|0;D=k+32|0;c[D>>2]=C;if((C|0)==0){H=c[E>>2]|0;I=D;break}D=k+72|0;C=c[D>>2]|0;if((C|0)==-1){u=hFb()|0;c[D>>2]=u;J=u}else{J=C}C=k+96|0;oDb(C,J);u=c[l>>2]|0;d=c[p>>2]|0;if((ba(d,u)|0)>0){g=k+352|0;t=k+64|0;r=0;while(1){y=c[g>>2]|0;c[C+((y&63)<<2)>>2]=(c[C+((y+9&63)<<2)>>2]|0)+(c[C+((y+40&63)<<2)>>2]|0);y=c[g>>2]|0;c[g>>2]=y+1;if(!(+((c[C+((y&63)<<2)>>2]|0)>>>0>>>0)/4294967295.0>+h[t>>3])){a[(c[E>>2]|0)+r|0]=-1}y=r+1|0;x=c[l>>2]|0;v=c[p>>2]|0;if((y|0)<(ba(v,x)|0)){r=y}else{K=x;L=v;break}}}else{K=u;L=d}a[k+36|0]=0;M=K;N=L;O=D;break a}}while(0);ZDb(H);ZDb(c[I>>2]|0);G=-12;i=f;return G|0}else{p=c[j>>2]|0;E=p+12|0;s=p+20|0;r=p+24|0;t=aCb(c[E>>2]|0,s,r,0,q)|0;if((t|0)<0){G=t;i=f;return G|0}$Db(E);E=c[r>>2]|0;if((E|0)==0){P=0;Q=0}else{r=c[s>>2]|0;t=0;C=0;g=0;w=0;while(1){if((a[r+t|0]|0)==10){R=(g|0)>(w|0)?g:w;S=0;T=C+1|0}else{R=w;S=g+1|0;T=C}v=t+1|0;if(v>>>0<E>>>0){t=v;C=T;g=S;w=R}else{P=T;Q=R;break}}}yDb(q,48,1908520,(F=i,i=i+16|0,c[F>>2]=P,c[F+8>>2]=Q,F)|0);i=F;w=p+4|0;g=c[w>>2]|0;do{if((g|0)==0){c[w>>2]=Q;c[p+8>>2]=P;U=P;V=Q}else{C=c[p+8>>2]|0;if(!((Q|0)>(g|0)|(P|0)>(C|0))){U=C;V=g;break}yDb(q,16,1887624,(F=i,i=i+32|0,c[F>>2]=g,c[F+8>>2]=C,c[F+16>>2]=Q,c[F+24>>2]=P,F)|0);i=F;G=-22;i=f;return G|0}}while(0);g=p+8|0;C=dEb(ba(U,V)|0,1)|0;t=p+28|0;c[t>>2]=C;do{if((C|0)==0){W=0;X=p+32|0}else{E=dEb(ba(c[w>>2]|0,c[g>>2]|0)|0,1)|0;r=p+32|0;c[r>>2]=E;if((E|0)==0){W=c[t>>2]|0;X=r;break}if((P|0)>0){r=c[s>>2]|0;E=((c[g>>2]|0)-P|0)/2|0;v=0;while(1){x=((c[w>>2]|0)-Q|0)/2|0;y=a[r]|0;yDb(q,48,2345584,(F=i,i=i+24|0,c[F>>2]=E,c[F+8>>2]=x,c[F+16>>2]=y<<24>>24==10?78:y<<24>>24,F)|0);i=F;y=a[r]|0;B=r+1|0;if(y<<24>>24==10){Y=B}else{z=x;x=y;y=B;while(1){B=((DAb(x<<24>>24)|0)!=0)<<31>>31;A=(ba(c[w>>2]|0,E)|0)+z|0;a[(c[t>>2]|0)+A|0]=B;B=z+1|0;A=a[y]|0;yDb(q,48,2345584,(F=i,i=i+24|0,c[F>>2]=E,c[F+8>>2]=B,c[F+16>>2]=A<<24>>24==10?78:A<<24>>24,F)|0);i=F;A=a[y]|0;Z=y+1|0;if(A<<24>>24==10){Y=Z;break}else{z=B;x=A;y=Z}}}y=v+1|0;if((y|0)<(P|0)){r=Y;E=E+1|0;v=y}else{break}}}a[p+36|0]=0;M=c[l>>2]|0;N=c[k+8>>2]|0;O=k+72|0;break a}}while(0);ZDb(W);ZDb(c[X>>2]|0);G=-12;i=f;return G|0}}while(0);X=c[k+56>>2]|0;W=c[k+60>>2]|0;l=c[o>>2]|0;o=e[n>>1]|0;n=e[m>>1]|0;m=c[k+76>>2]|0;k=c[O>>2]|0;yDb(q,40,1930696,(F=i,i=i+72|0,c[F>>2]=M,c[F+8>>2]=N,c[F+16>>2]=X,c[F+24>>2]=W,c[F+32>>2]=l,c[F+40>>2]=o,c[F+48>>2]=n,c[F+56>>2]=m,c[F+64>>2]=k,F)|0);i=F;G=0;i=f;return G|0}function is(a){a=a|0;var b=0;b=c[a+44>>2]|0;bCb(c[b+20>>2]|0,c[b+24>>2]|0);$Db(b+16|0);$Db(b+28|0);$Db(b+32|0);return}function js(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=-1;c[d+4>>2]=-1;do{if((c[e+80>>2]|0)==0){if((PGb(e+84|0,2161440,3)|0)!=0){break}if((PGb(e+88|0,9203304,3)|0)!=0){break}c[d>>2]=10;c[e+356>>2]=296;f=d;g=xk(f)|0;Ok(a,g);i=b;return 0}}while(0);c[d>>2]=2;c[e+356>>2]=254;f=d;g=xk(f)|0;Ok(a,g);i=b;return 0}function ks(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=c[b+44>>2]|0;b=c[f+28+((d[f+36|0]|0)<<2)>>2]|0;g=f+8|0;h=c[g>>2]|0;if((h|0)<=0){return}i=e|0;j=e+32|0;e=f+4|0;k=f+80|0;l=f+84|0;m=f+88|0;n=f+92|0;o=f+89|0;p=f+93|0;q=f+90|0;r=f+94|0;f=0;s=c[e>>2]|0;t=h;while(1){if((s|0)>0){h=ba(c[j>>2]|0,f)|0;u=(c[i>>2]|0)+h|0;h=0;v=s;while(1){w=a[b+((ba(v,f)|0)+h)|0]|0;x=c[k>>2]|0;y=w<<24>>24==-1;if((x|0)==0|y){z=y?l:m;a[u+2|0]=a[z+2|0]|0;a[u+1|0]=a[z+1|0]|0;a[u]=a[z]|0}else{z=ba(w&255^255,x)|0;x=(z|0)>255?255:z;z=d[m]|0;a[u]=((((ba((d[n]|0)-z|0,x)|0)+(z<<8)|0)*257|0)+32896|0)>>>16;z=d[o]|0;a[u+1|0]=((((ba((d[p]|0)-z|0,x)|0)+(z<<8)|0)*257|0)+32896|0)>>>16;z=d[q]|0;a[u+2|0]=((((ba((d[r]|0)-z|0,x)|0)+(z<<8)|0)*257|0)+32896|0)>>>16}z=h+1|0;A=c[e>>2]|0;if((z|0)<(A|0)){u=u+3|0;h=z;v=A}else{break}}B=A;C=c[g>>2]|0}else{B=s;C=t}v=f+1|0;if((v|0)<(C|0)){f=v;s=B;t=C}else{break}}return}function ls(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=c[b+44>>2]|0;b=c[f+28+(d[f+36|0]<<2)>>2]|0;g=f+8|0;h=c[g>>2]|0;if((h|0)<=0){return}i=e|0;j=e+32|0;e=f+4|0;f=0;k=c[e>>2]|0;l=h;while(1){if((k|0)>0){h=ba(c[j>>2]|0,f)|0;m=0;n=0;o=0;p=(c[i>>2]|0)+h|0;h=k;while(1){q=n+1|0;r=(((a[b+((ba(h,f)|0)+m)|0]|0)==-1)<<7-n|o&255)&255;if((q|0)==8){s=7}else{if((m|0)==(h-1|0)){s=7}else{t=p;u=r;v=q;w=h}}if((s|0)==7){s=0;a[p]=r;t=p+1|0;u=0;v=0;w=c[e>>2]|0}r=m+1|0;if((r|0)<(w|0)){m=r;n=v;o=u;p=t;h=w}else{break}}x=w;y=c[g>>2]|0}else{x=k;y=l}h=f+1|0;if((h|0)<(y|0)){f=h;k=x;l=y}else{break}}return}function ms(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;d=b|0;f=c[(c[d>>2]|0)+44>>2]|0;g=Zr(b,c[f+4>>2]|0,c[f+8>>2]|0)|0;if((g|0)==0){h=-12;return h|0}c[g+124>>2]=1;c[g+128>>2]=1;i=f+48|0;j=c[i>>2]|0;k=c[i+4>>2]|0;l=YGb(j,k,1,0)|0;c[i>>2]=l;c[i+4>>2]=F;i=g+136|0;c[i>>2]=j;c[i+4>>2]=k;ne[c[f+356>>2]&1023](c[d>>2]|0,g);f=c[(c[d>>2]|0)+44>>2]|0;d=f+36|0;k=a[d]|0;i=f+28|0;j=c[i+((k&255)<<2)>>2]|0;l=f+8|0;m=c[l>>2]|0;if((m|0)>0){n=f+4|0;o=f+76|0;p=f+38|0;q=f+40|0;f=c[i+((k<<24>>24==0)<<2)>>2]|0;i=0;r=c[n>>2]|0;s=m;while(1){if((r|0)>0){m=i-1|0;t=(m|0)<0;u=t?-1:m;m=i+1|0;v=f;w=0;x=r;do{if((c[o>>2]|0)==0){y=w-1|0;z=w+1|0;A=u;B=u;C=(y|0)>-1?y:-1;D=(m|0)==(c[l>>2]|0)?-1:m;E=(z|0)==(x|0)?-1:z}else{z=c[l>>2]|0;y=w+1|0;A=(t?z:i)-1|0;B=(t?z:i)-1|0;C=((w-1|0)<0?x:w)-1|0;D=(m|0)==(z|0)?0:m;E=(y|0)==(x|0)?0:y}y=(C|0)==-1;if((A|0)==-1|y){G=0}else{G=(a[j+((ba(A,x)|0)+C)|0]|0)==-1|0}do{if((B|0)==-1){H=0;I=G;J=(E|0)==-1}else{z=ba(B,x)|0;K=((a[j+(z+w)|0]|0)==-1)+G|0;if((E|0)==-1){H=0;I=K;J=1;break}H=(a[j+(z+E)|0]|0)==-1|0;I=K;J=0}}while(0);if(y){L=0}else{L=(a[j+(C+(ba(x,i)|0))|0]|0)==-1|0}if(J){M=0}else{M=(a[j+(E+(ba(x,i)|0))|0]|0)==-1|0}K=(D|0)==-1;if(K|y){N=0}else{N=(a[j+((ba(D,x)|0)+C)|0]|0)==-1|0}z=H+I+L+M+N|0;do{if(K){O=0;P=z}else{Q=ba(D,x)|0;R=((a[j+(Q+w)|0]|0)==-1)+z|0;if(J){O=0;P=R;break}O=(a[j+(Q+E)|0]|0)==-1|0;P=R}}while(0);z=a[j+((ba(x,i)|0)+w)|0]|0;do{if((e[(z<<24>>24==-1?p:q)>>1]&1<<O+P|0)==0){if(z<<24>>24==0){a[v]=0;break}else{a[v]=z-1;break}}else{a[v]=-1}}while(0);v=v+1|0;w=w+1|0;x=c[n>>2]|0;}while((w|0)<(x|0));S=v;T=x;U=c[l>>2]|0;V=m}else{S=f;T=r;U=s;V=i+1|0}if((V|0)<(U|0)){f=S;i=V;r=T;s=U}else{break}}W=a[d]|0}else{W=k}a[d]=W<<24>>24==0|0;h=cj(b,g)|0;return h|0}function ns(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+4>>2];c[a+24>>2]=c[b+8>>2];d=a+56|0;a=c[b+56>>2]|0;c[d>>2]=c[b+60>>2];c[d+4>>2]=a;return 0}function os(a){a=a|0;var b=0,d=0.0,e=0;b=c[a+44>>2]|0;a=b+80|0;d=+h[a>>3];h[a>>3]=d*d;a=c[b+8>>2]|0;d=+(a|0);e=b+56|0;h[e>>3]=+h[e>>3]/d;e=b+64|0;h[e>>3]=+h[e>>3]/d;e=ba((c[b+4>>2]|0)*3|0,a)|0;a=b+96|0;c[a>>2]=e;c[b+100>>2]=0;c[b+104>>2]=WDb(e*24|0)|0;c[b+108>>2]=WDb((c[a>>2]|0)*24|0)|0;c[b+112>>2]=WDb((c[b+32>>2]<<4)+256|0)|0;return 0}function ps(a){a=a|0;var b=0;b=c[a+44>>2]|0;$Db(b+104|0);$Db(b+108|0);$Db(b+112|0);return}function qs(a){a=a|0;Ok(a,xk(550112)|0);return 0}function rs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0.0,O=0,V=0,W=0,X=0,Y=0,Z=0,_=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0.0,ra=0,sa=0,ta=0,ua=0,va=0.0,wa=0.0,xa=0.0,ya=0,za=0.0,Aa=0.0,Ba=0.0,Ca=0.0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0.0,Pa=0,Qa=0.0,Ra=0,Sa=0.0,Ta=0.0,Ua=0.0,Va=0.0,Wa=0,Xa=0.0,Ya=0.0,Za=0,_a=0.0,$a=0.0,ab=0.0,bb=0.0,cb=0.0,db=0.0,eb=0,fb=0,gb=0.0,hb=0.0,ib=0.0,jb=0,kb=0,lb=0.0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0;b=i;d=a|0;e=c[(c[d>>2]|0)+44>>2]|0;f=Zr(a,c[e+4>>2]|0,c[e+8>>2]|0)|0;if((f|0)==0){g=-12;i=b;return g|0}c[f+124>>2]=1;c[f+128>>2]=1;j=e+24|0;e=c[j>>2]|0;k=c[j+4>>2]|0;l=YGb(e,k,1,0)|0;c[j>>2]=l;c[j+4>>2]=F;j=f+136|0;c[j>>2]=e;c[j+4>>2]=k;j=c[d>>2]|0;d=c[f>>2]|0;l=d;m=(c[f+32>>2]|0)/4|0;n=j+44|0;o=c[n>>2]|0;p=+h[o+56>>3];q=+(e>>>0)+ +(k|0)*4294967296.0;r=p*+S(+(+h[o+64>>3]/p),+(q/+h[o+72>>3]));k=o+48|0;e=o+8|0;p=+h[k>>3]+r*(+((c[e>>2]|0)/-2|0|0)+-.5);s=o+136|0;a:do{if(+h[s>>3]!=0.0){t=0}else{u=c[o+100>>2]|0;if((u|0)<=0){t=0;break}v=c[o+104>>2]|0;w=0;while(1){if(+h[v+(w*24|0)+8>>3]>p){t=w;break a}x=w+1|0;if((x|0)<(u|0)){w=x}else{t=x;break}}}}while(0);w=o+4|0;TGb(d|0,0,c[w>>2]<<2|0)|0;d=c[e>>2]|0;if((d|0)>0){p=r*3.0*.5;y=r*.5;u=o+40|0;v=o+116|0;x=o+120|0;z=o+128|0;A=o+32|0;B=o+112|0;C=o+80|0;D=o+88|0;E=o+92|0;G=o+96|0;H=o+108|0;I=t;J=0;K=t;L=0.0;t=0;M=d;while(1){d=t+1|0;N=+h[k>>3]+r*+(t-((M|0)/2|0)|0);O=c[n>>2]|0;do{if(+h[O+136>>3]!=0.0){V=J;W=I;X=M}else{Y=O+104|0;Z=O+100|0;_=c[Z>>2]|0;if((I|0)>=(_|0)){V=J;W=I;X=M;break}aa=O+40|0;ca=O+4|0;da=O+96|0;ea=O+108|0;fa=J;ga=I;ha=_;while(1){_=c[Y>>2]|0;ia=_+(ga*24|0)|0;if(+h[_+(ga*24|0)+8>>3]>N){ja=fa;ka=ga;break}_=c[ca>>2]|0;la=~~+Hb(+((+h[ia>>3]- +h[aa>>3])/r+ +((_|0)/2|0|0)));do{if((la|0)>=(_|0)|(la|0)<0){ma=fa;na=ha}else{if((fa|0)>=(c[da>>2]|0)){ma=fa;na=ha;break}oa=(c[ea>>2]|0)+(fa*24|0)|0;pa=ia;c[oa>>2]=c[pa>>2];c[oa+4>>2]=c[pa+4>>2];c[oa+8>>2]=c[pa+8>>2];c[oa+12>>2]=c[pa+12>>2];c[oa+16>>2]=c[pa+16>>2];c[oa+20>>2]=c[pa+20>>2];ma=fa+1|0;na=c[Z>>2]|0}}while(0);ia=ga+1|0;if((ia|0)<(na|0)){fa=ma;ga=ia;ha=na}else{ja=ma;ka=ia;break}}V=ja;W=ka;X=c[e>>2]|0}}while(0);b:do{if((d|0)<(X|0)){O=ba(d,m)|0;ha=l+(O<<2)|0;TGb(ha|0,0,c[w>>2]<<2|0)|0;qa=p+N;ga=c[n>>2]|0;if(+h[ga+136>>3]!=0.0){ra=K;break}fa=ga+100|0;Z=c[fa>>2]|0;if((K|0)>=(Z|0)){ra=K;break}ea=ga+40|0;da=ga+4|0;aa=c[ga+104>>2]|0;if((ha|0)==0){ha=K;while(1){if(+h[aa+(ha*24|0)+8>>3]>qa){ra=ha;break b}ga=ha+1|0;if((ga|0)<(Z|0)){ha=ga}else{ra=ga;break b}}}else{sa=K;ta=Z}while(1){if(+h[aa+(sa*24|0)+8>>3]>qa){ra=sa;break b}ha=c[da>>2]|0;ga=~~+Hb(+((+h[aa+(sa*24|0)>>3]- +h[ea>>3])/r+ +((ha|0)/2|0|0)));if((ga|0)>-1&(ga|0)<(ha|0)){c[l+(ga+O<<2)>>2]=c[aa+(sa*24|0)+16>>2];ua=c[fa>>2]|0}else{ua=ta}ga=sa+1|0;if((ga|0)<(ua|0)){sa=ga;ta=ua}else{ra=ga;break}}}else{ra=K}}while(0);fa=c[w>>2]|0;if((fa|0)>0){aa=ba(t,m)|0;O=aa-1|0;ea=(t|0)==0;da=ba(d,m)|0;Z=ba(t-1|0,m)|0;ga=V;qa=L;ha=0;ca=fa;while(1){fa=ha-((ca|0)/2|0)|0;va=+h[u>>3]+r*+(fa|0);Y=c[v>>2]|0;wa=+(Y>>>0>>>0)*2.3283064365386963e-10;c[v>>2]=(ba(Y,1664525)|0)+1013904223;Y=l+(ha+aa<<2)|0;c:do{if((c[Y>>2]|0)>>>0>16777215>>>0){xa=qa;ya=ga}else{za=+h[s>>3];d:do{if(za!=0.0){Aa=va+za*+T(q*+h[x>>3]);Ba=N+za*+U(q*+h[z>>3]);Ca=Aa}else{if((ha|0)==0|ea){Ba=N;Ca=va;break}ia=ha+1|0;if((ia|0)==(ca|0)){Ba=N;Ca=va;break}la=c[e>>2]|0;if((d|0)==(la|0)){Ba=N;Ca=va;break}_=ha-(ca>>1)|0;pa=ba(la,(_|0)>-1?_:-_|0)|0;_=t-(la>>1)|0;oa=ba((_|0)>-1?_:-_|0,ca)|0;if((((pa|0)>(oa|0)?pa:oa)|0)<((ba(la,ca)|0)>>3|0)){Ba=N;Ca=va;break}la=c[l+(ia+aa<<2)>>2]|0;oa=ha-1|0;pa=c[l+(oa+da<<2)>>2]|0;_=c[l+(ha+da<<2)>>2]|0;Da=c[l+(ia+da<<2)>>2]|0;Ea=(_|0)==0;do{if((la|0)==0|Ea){Fa=(Da|0)==0;if(!((pa|0)==0|Fa)){Ga=c[l+(ia+Z<<2)>>2]|0;Ha=pa;Ia=c[l+(oa+Z<<2)>>2]|0;Ja=Da;break}if(!Ea){Ga=c[l+(oa+aa<<2)>>2]|0;Ha=c[l+(ia+Z<<2)>>2]|0;Ia=_;Ja=c[l+(ha+Z<<2)>>2]|0;break}if(Fa){Ba=N;Ca=va;break d}Ga=c[l+(oa+aa<<2)>>2]|0;Ha=c[l+(ia+Z<<2)>>2]|0;Ia=c[l+(oa+Z<<2)>>2]|0;Ja=Da}else{Ga=la;Ha=c[l+(oa+aa<<2)>>2]|0;Ia=_;Ja=c[l+(ha+Z<<2)>>2]|0}}while(0);_=Ga&255;oa=Ha&255;la=_+oa|0;Da=Ia&255;ia=Ja&255;Ea=Da+ia|0;pa=la-Ea|0;if((((pa|0)>-1?pa:-pa|0)|0)>5){Ba=N;Ca=va;break}pa=_-oa|0;oa=Da-ia|0;if((((pa|0)>-1?pa:-pa|0)+((oa|0)>-1?oa:-oa|0)|0)>20){Ba=N;Ca=va;break}oa=Ga>>>8&255;pa=Ha>>>8&255;ia=oa+pa|0;Da=Ia>>>8&255;_=Ja>>>8&255;Fa=Da+_|0;Ka=ia-Fa|0;if((((Ka|0)>-1?Ka:-Ka|0)|0)>5){Ba=N;Ca=va;break}Ka=oa-pa|0;pa=Da-_|0;if((((Ka|0)>-1?Ka:-Ka|0)+((pa|0)>-1?pa:-pa|0)|0)>20){Ba=N;Ca=va;break}pa=Ga>>>16&255;Ka=Ha>>>16&255;_=pa+Ka|0;Da=Ia>>>16&255;oa=Ja>>>16&255;La=Da+oa|0;Ma=_-La|0;if((((Ma|0)>-1?Ma:-Ma|0)|0)>5){Ba=N;Ca=va;break}Ma=pa-Ka|0;Ka=Da-oa|0;if((((Ma|0)>-1?Ma:-Ma|0)+((Ka|0)>-1?Ka:-Ka|0)|0)>20){Ba=N;Ca=va;break}Ka=(Ea+2+la|0)>>>2|(Fa+2+ia|0)>>>2<<8|(La+2+_|0)>>>2<<16|-16777216;c[Y>>2]=Ka;if((ga|0)>=(c[G>>2]|0)){xa=qa;ya=ga;break c}_=c[H>>2]|0;h[_+(ga*24|0)>>3]=va;h[_+(ga*24|0)+8>>3]=N;c[_+(ga*24|0)+16>>2]=Ka;xa=qa;ya=ga+1|0;break c}}while(0);do{if((ha|0)==0){Na=57}else{if((c[E>>2]|0)!=0){Na=57;break}if((c[l+(O+ha<<2)>>2]|0)==-16777216){Na=57}else{Oa=qa;Pa=0}}}while(0);if((Na|0)==57){Na=0;Ka=ba(fa,fa)|0;_=t-((c[e>>2]|0)/2|0)|0;Oa=r*+R(+((ba(_,_)|0)+Ka|0))/+(ca|0);Pa=1}Ka=c[A>>2]|0;_=Ka-8|0;za=Oa;Aa=Ba;Qa=Ca;La=0;while(1){if((La|0)>=(_|0)){Ra=La;Sa=Qa;Ta=Aa;Na=77;break}Ua=va+(Qa*Qa-Aa*Aa);Va=N+Qa*2.0*Aa;Wa=c[B>>2]|0;h[Wa+(La<<4)>>3]=Ua;h[Wa+(La<<4)+8>>3]=Va;ia=La|1;Xa=va+(Ua*Ua-Va*Va);Ya=N+Va*Ua*2.0;if(Pa){Fa=La>>1;Ua=+Q(+(+h[Wa+(Fa<<4)>>3]-Xa));if(!(Ua+ +Q(+(+h[Wa+(Fa<<4)+8>>3]-Ya))>za)){Ra=ia;Sa=Xa;Ta=Ya;Na=77;break}}h[Wa+(ia<<4)>>3]=Xa;h[Wa+(ia<<4)+8>>3]=Ya;ia=La|2;Ua=va+(Xa*Xa-Ya*Ya);Va=N+Ya*Xa*2.0;h[Wa+(ia<<4)>>3]=Ua;h[Wa+(ia<<4)+8>>3]=Va;ia=La|3;Xa=va+(Ua*Ua-Va*Va);Ya=N+Va*Ua*2.0;if(Pa){Fa=ia>>1;Ua=+Q(+(+h[Wa+(Fa<<4)>>3]-Xa));if(!(Ua+ +Q(+(+h[Wa+(Fa<<4)+8>>3]-Ya))>za)){Ra=ia;Sa=Xa;Ta=Ya;Na=77;break}}h[Wa+(ia<<4)>>3]=Xa;h[Wa+(ia<<4)+8>>3]=Ya;ia=La|4;Ua=va+(Xa*Xa-Ya*Ya);Va=N+Ya*Xa*2.0;h[Wa+(ia<<4)>>3]=Ua;h[Wa+(ia<<4)+8>>3]=Va;ia=La|5;Xa=va+(Ua*Ua-Va*Va);Ya=N+Va*Ua*2.0;if(Pa){Fa=ia>>1;Ua=+Q(+(+h[Wa+(Fa<<4)>>3]-Xa));if(!(Ua+ +Q(+(+h[Wa+(Fa<<4)+8>>3]-Ya))>za)){Ra=ia;Sa=Xa;Ta=Ya;Na=77;break}}h[Wa+(ia<<4)>>3]=Xa;h[Wa+(ia<<4)+8>>3]=Ya;ia=La|6;Ua=va+(Xa*Xa-Ya*Ya);Va=N+Ya*Xa*2.0;h[Wa+(ia<<4)>>3]=Ua;h[Wa+(ia<<4)+8>>3]=Va;Za=La|7;_a=va+(Ua*Ua-Va*Va);$a=N+Va*Ua*2.0;if(Pa){ia=Za>>1;Ua=+Q(+(+h[Wa+(ia<<4)>>3]-_a));if(!(Ua+ +Q(+(+h[Wa+(ia<<4)+8>>3]-$a))>za)){Ra=Za;Sa=_a;Ta=$a;Na=77;break}}h[Wa+(Za<<4)>>3]=_a;h[Wa+(Za<<4)+8>>3]=$a;ab=+h[C>>3];if(_a*_a+$a*$a>ab){Na=69;break}else{Aa=$a;Qa=_a;La=La+8|0}}e:do{if((Na|0)==69){Na=0;Qa=$a;Aa=_a;La=Za-((Za|0)<7?Za:7)|0;while(1){if((La|0)>=(Ka|0)){Ra=La;Sa=Aa;Ta=Qa;Na=77;break e}bb=+h[Wa+(La<<4)>>3];cb=+h[Wa+(La<<4)+8>>3];db=bb*bb+cb*cb;if(db>ab){break}else{Qa=cb;Aa=bb;La=La+1|0}}_=c[D>>2]|0;if((_|0)==2){eb=16777215;break}else if((_|0)==0){Aa=+(La|0);ia=Gc(+((+U(Aa)+1.0)*127.0))|0;Fa=((Gc(+((+U(Aa/1.234)+1.0)*127.0))|0)<<16)+ia|0;fb=Fa+((Gc(+((+U(Aa/100.0)+1.0)*127.0))|0)<<8)|0;gb=cb;hb=Aa}else if((_|0)==1){Aa=+(La|0)+ +gc(+(+$(ab)/+$(db)));Fa=Gc(+((+U(Aa)+1.0)*127.0))|0;ia=((Gc(+((+U(Aa/1.234)+1.0)*127.0))|0)<<16)+Fa|0;fb=ia+((Gc(+((+U(Aa/100.0)+1.0)*127.0))|0)<<8)|0;gb=cb;hb=Aa}else if((_|0)==3){Aa=bb/ab;Qa=cb/ab;fb=~~(Aa*128.0+128.0)<<8&65280|~~(Qa*128.0+128.0)&255;gb=Qa;hb=Aa}else{Ra=La;Sa=bb;Ta=cb;Na=77;break}if((fb|0)==0){Ra=La;Sa=hb;Ta=gb;Na=77}else{eb=fb}}}while(0);f:do{if((Na|0)==77){Na=0;Ka=c[E>>2]|0;if((Ka|0)==1){Aa=Oa*Oa*10.0;_=Ra;do{_=_-1|0;if((_|0)==0){eb=0;break f}ia=c[B>>2]|0;Qa=+h[ia+(_<<4)>>3]-Sa;za=+h[ia+(_<<4)+8>>3]-Ta;}while(!(Qa*Qa+za*za<Aa));La=Ra-_|0;eb=La<<5&224|La<<10&57344|La<<15&14680064;break}else if((Ka|0)==3){La=c[B>>2]|0;if((Ra|0)>0){Aa=9999.0;ia=0;Fa=Ra;while(1){la=Fa-1|0;za=+h[La+(la<<4)>>3];Qa=+h[La+(la<<4)+8>>3];Ua=za*za+Qa*Qa;Ea=Ua<Aa;Qa=Ea?Ua:Aa;Ma=Ea?la:ia;if((la|0)>0){Aa=Qa;ia=Ma;Fa=la}else{ib=Qa;jb=Ma;break}}}else{ib=9999.0;jb=0}Aa=+R(ib);Fa=Gc(+(wa+(+h[La+(jb<<4)>>3]/Aa+1.0)*127.0))|0;eb=((Gc(+(wa+(+h[(c[B>>2]|0)+(jb<<4)+8>>3]/Aa+1.0)*127.0))|0)<<8)+Fa|0;break}else if((Ka|0)==2){eb=~~(+P(wa+ +(Ra|0)*255.0/+(c[A>>2]|0))*65793.0);break}else{eb=0;break}}}while(0);Fa=eb|-16777216;c[Y>>2]=Fa;if((ga|0)>=(c[G>>2]|0)){xa=Oa;ya=ga;break}ia=c[H>>2]|0;h[ia+(ga*24|0)>>3]=va;h[ia+(ga*24|0)+8>>3]=N;c[ia+(ga*24|0)+16>>2]=Fa;xa=Oa;ya=ga+1|0}}while(0);Y=ha+1|0;fa=c[w>>2]|0;if((Y|0)<(fa|0)){ga=ya;qa=xa;ha=Y;ca=fa}else{kb=ya;lb=xa;break}}}else{kb=V;lb=L}qa=y+N;ca=c[n>>2]|0;g:do{if(+h[ca+136>>3]!=0.0){mb=kb;nb=W}else{ha=ca+104|0;ga=ca+100|0;O=c[ga>>2]|0;if((W|0)>=(O|0)){mb=kb;nb=W;break}Z=ca+40|0;aa=ca+4|0;da=ca+96|0;ea=ca+108|0;fa=kb;Y=W;Fa=O;while(1){O=c[ha>>2]|0;ia=O+(Y*24|0)|0;if(+h[O+(Y*24|0)+8>>3]>qa){mb=fa;nb=Y;break g}O=c[aa>>2]|0;_=~~+Hb(+((+h[ia>>3]- +h[Z>>3])/r+ +((O|0)/2|0|0)));do{if((_|0)>=(O|0)|(_|0)<0){ob=fa;pb=Fa}else{if((fa|0)>=(c[da>>2]|0)){ob=fa;pb=Fa;break}Ma=(c[ea>>2]|0)+(fa*24|0)|0;la=ia;c[Ma>>2]=c[la>>2];c[Ma+4>>2]=c[la+4>>2];c[Ma+8>>2]=c[la+8>>2];c[Ma+12>>2]=c[la+12>>2];c[Ma+16>>2]=c[la+16>>2];c[Ma+20>>2]=c[la+20>>2];ob=fa+1|0;pb=c[ga>>2]|0}}while(0);ia=Y+1|0;if((ia|0)<(pb|0)){fa=ob;Y=ia;Fa=pb}else{mb=ob;nb=ia;break}}}}while(0);ca=c[e>>2]|0;if((d|0)<(ca|0)){I=nb;J=mb;K=ra;L=lb;t=d;M=ca}else{qb=mb;rb=H;sb=G;break}}}else{qb=0;rb=o+108|0;sb=o+96|0}G=o+104|0;H=c[G>>2]|0;c[G>>2]=c[rb>>2];c[rb>>2]=H;c[o+100>>2]=qb;if((qb|0)==(c[sb>>2]|0)){yDb(j,32,2006528,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}g=cj(a,f)|0;i=b;return g|0}function ss(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=d+4|0;f=d+8|0;if((hDb(c[e>>2]|0,c[f>>2]|0,0,b)|0)<0){g=-22;return g|0}c[a+20>>2]=c[e>>2];c[a+24>>2]=c[f>>2];f=a+56|0;a=c[d+12>>2]|0;c[f>>2]=c[d+16>>2];c[f+4>>2]=a;g=0;return g|0}function ts(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+68>>2]=530;c[e+56>>2]=1;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;yDb(a,40,2267944,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function us(a){a=a|0;JCb((c[a+44>>2]|0)+64|0);return}function vs(a){a=a|0;Ok(a,Gw(0)|0);return 0}function ws(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0;h=i;i=i+8|0;g=h|0;f=c[b+44>>2]|0;do{if((QGb(d,2071848)|0)!=0){if((QGb(d,2062616)|0)==0){break}else{j=-38}i=h;return j|0}}while(0);d=QEb(g,e,-1,b)|0;if((d|0)<0){j=d;i=h;return j|0}d=f+140|0;b=d;x=c[g>>2]|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;Cw(f+76|0,f+120|0,d);c[f+60>>2]=1;j=0;i=h;return j|0}function xs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+68>>2]=4;c[e+56>>2]=1;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;yDb(a,40,2267944,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function ys(a){a=a|0;Ok(a,xk(982128)|0);return 0}function zs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;c[(c[d>>2]|0)+68>>2]=102;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;yDb(a,40,2267944,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function As(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;c[(c[d>>2]|0)+68>>2]=476;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;yDb(a,40,2267944,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Bs(a){a=a|0;Ok(a,xk(188224)|0);return 0}function Cs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+56>>2]=1;c[e+68>>2]=162;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;yDb(a,40,2267944,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Ds(a){a=a|0;Ok(a,xk(547720)|0);return 0}function Es(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+68>>2]=32;c[e+56>>2]=1;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;yDb(a,40,2267944,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Fs(a){a=a|0;Ok(a,xk(435512)|0);return 0}function Gs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+68>>2]=236;c[e+56>>2]=1;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;yDb(a,40,2267944,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Hs(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+8|0;g=f|0;h=c[b+44>>2]|0;b=h;j=bFb(c[e+80>>2]|0)|0;CCb(e,1);k=h+4|0;l=j+5|0;m=1<<(d[l]|0);n=((c[k>>2]|0)/8|0)-1+m&-m;m=h+8|0;h=j+6|0;j=1<<(d[h]|0);o=(((c[m>>2]|0)*7|0|0)/12|0)-1+j&-j;Is(b,986152,0,0,n,o,e);j=1<<(d[l]|0);p=(((((c[k>>2]|0)+3|0)/4|0)*3|0|0)/7|0)-1+j&-j;Is(b,549600,n,0,p,o,e);j=n+p|0;Is(b,549604,j,0,p,o,e);q=j+p|0;Is(b,549608,q,0,p,o,e);r=q+p|0;Is(b,549612,r,0,p,o,e);q=r+p|0;Is(b,549616,q,0,p,o,e);r=q+p|0;Is(b,549620,r,0,p,o,e);Is(b,549624,r+p|0,0,p,o,e);r=g;q=n+(p*7|0)|0;Is(b,986152,q,0,(c[k>>2]|0)-q|0,o,e);q=1<<(d[h]|0);h=((c[m>>2]|0)/12|0)-1+q&-q;Is(b,1410096,0,o,n,h,e);Is(b,918496,n,o,p,h,e);q=p*6|0;Is(b,549600,j,o,q,h,e);s=j+q|0;Is(b,1680176,s,o,(c[k>>2]|0)-s|0,h,e);t=h+o|0;Is(b,896,0,t,n,h,e);Is(b,559488,n,t,p,h,e);if((q|0)>0){o=g;u=r+1|0;v=r+2|0;w=r+3|0;r=0;x=j;y=a[l]|0;while(1){c[g>>2]=0;a[o]=(r*255|0|0)/(q|0)|0;a[u]=-128;a[v]=-128;a[w]=-1;Is(b,o,x,t,1<<(y&255),h,e);z=a[l]|0;A=1<<(z&255);B=A+x|0;C=A+r|0;if((C|0)<(q|0)){r=C;x=B;y=z}else{D=B;break}}}else{D=j}Is(b,549240,D,t,(c[k>>2]|0)-D|0,h,e);D=t+h|0;Is(b,986160,0,D,n,(c[m>>2]|0)-D|0,e);h=1<<(d[l]|0);t=((p*3|0|0)/2|0)-1+h&-h;Is(b,1683800,n,D,t,(c[m>>2]|0)-D|0,e);h=t+n|0;n=1<<(d[l]|0);t=(p<<1)-1+n&-n;Is(b,57832,h,D,t,(c[m>>2]|0)-D|0,e);n=t+h|0;h=1<<(d[l]|0);t=((p*5|0|0)/6|0)-1+h&-h;Is(b,1683800,n,D,t,(c[m>>2]|0)-D|0,e);h=t+n|0;n=1<<(d[l]|0);l=((p|0)/3|0)-1+n&-n;Is(b,637656,h,D,l,(c[m>>2]|0)-D|0,e);n=l+h|0;Is(b,1683800,n,D,l,(c[m>>2]|0)-D|0,e);h=n+l|0;Is(b,1683792,h,D,l,(c[m>>2]|0)-D|0,e);n=h+l|0;Is(b,1683800,n,D,l,(c[m>>2]|0)-D|0,e);h=n+l|0;Is(b,1683784,h,D,l,(c[m>>2]|0)-D|0,e);n=h+l|0;Is(b,1683800,n,D,s-n|0,(c[m>>2]|0)-D|0,e);Is(b,986160,s,D,(c[k>>2]|0)-s|0,(c[m>>2]|0)-D|0,e);i=f;return}function Is(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=i;m=bFb(c[k+80>>2]|0)|0;n=c[b+4>>2]|0;o=n-1|0;p=o>>>0<f>>>0?o:f;f=c[b+8>>2]|0;b=f-1|0;o=b>>>0<g>>>0?b:g;g=n-p|0;b=g>>>0<h>>>0?g:h;h=f-o|0;g=h>>>0<j>>>0?h:j;if((b+p|0)>>>0>n>>>0){yDb(0,0,2252416,(q=i,i=i+24|0,c[q>>2]=2238336,c[q+8>>2]=2226024,c[q+16>>2]=850,q)|0);i=q;Cd()}if((g+o|0)>>>0>f>>>0){yDb(0,0,2252416,(q=i,i=i+24|0,c[q>>2]=2215552,c[q+8>>2]=2226024,c[q+16>>2]=851,q)|0);i=q;Cd()}q=c[k>>2]|0;if((q|0)==0){i=l;return}f=m+5|0;n=m+6|0;m=0;j=q;do{q=c[k+32+(m<<2)>>2]|0;if((m-1|0)>>>0<2>>>0){h=d[f]|0;r=d[n]|0;s=g>>>(r>>>0);t=b>>>(h>>>0);u=o>>>(r>>>0);v=p>>>(h>>>0)}else{s=g;t=b;u=o;v=p}h=(ba(u,q)|0)+v|0;r=j+h|0;TGb(r|0,a[e+m|0]|0,t|0)|0;if((s|0)>1){w=j+(h+q)|0;h=1;while(1){UGb(w|0,r|0,t)|0;x=h+1|0;if((x|0)<(s|0)){w=w+q|0;h=x}else{break}}}m=m+1|0;j=c[k+(m<<2)>>2]|0;}while((j|0)!=0);i=l;return}function Js(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[a+44>>2]|0;a=e;f=bFb(c[b+80>>2]|0)|0;CCb(b,5);g=e+4|0;h=f+5|0;i=1<<(d[h]|0);j=-i|0;k=(((c[g>>2]|0)+6|0)/7|0)-1+i&j;l=c[e+8>>2]|0;e=1<<(d[f+6|0]|0);f=-e|0;m=((l<<1|0)/3|0)-1+e&f;n=((l*3|0|0)/4|0)-1+e-m&f;f=k*5|0;e=i-1+((f|0)/4|0)|0;i=l-n|0;l=0;o=0;while(1){Is(a,549600+(o<<2)|0,l,0,k,m,b);Is(a,16904+(o<<2)|0,l,m,k,n,b);p=o+1|0;if((p|0)<7){l=l+k|0;o=p}else{break}}o=e&j;j=i-m|0;i=n+m|0;Is(a,918496,0,i,o,j,b);Is(a,57832,o,i,o,j,b);m=o<<1;Is(a,559488,m,i,o,j,b);n=m+o|0;o=1<<(d[h]|0);m=f-1-n+o&-o;Is(a,1683808,n,i,m,j,b);o=m+n|0;n=1<<(d[h]|0);h=((k|0)/3|0)-1+n&-n;Is(a,637648,o,i,h,j,b);n=h+o|0;Is(a,1683808,n,i,h,j,b);o=n+h|0;Is(a,563584,o,i,h,j,b);n=o+h|0;Is(a,1683808,n,i,(c[g>>2]|0)-n|0,j,b);return}function Ks(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+8|0;d=b|0;e=a|0;f=c[(c[e>>2]|0)+44>>2]|0;g=f+40|0;h=c[g+4>>2]|0;j=-1;do{if((h|0)>(j|0)|(h|0)==(j|0)&(c[g>>2]|0)>>>0>-1>>>0){k=f+32|0;l=c[k>>2]|0;m=c[k+4>>2]|0;c[d>>2]=1;c[d+4>>2]=1e6;k=KDb(l,m,f+16|0,d)|0;m=F;l=c[g+4>>2]|0;if((m|0)<(l|0)|(m|0)==(l|0)&k>>>0<(c[g>>2]|0)>>>0){break}else{n=-541478725}i=b;return n|0}}while(0);g=f+56|0;if((c[g>>2]|0)==0){o=Zr(a,c[f+4>>2]|0,c[f+8>>2]|0)|0}else{d=f+60|0;j=f+64|0;if((c[d>>2]|0)!=0){JCb(j);c[d>>2]=0}d=c[j>>2]|0;do{if((d|0)==0){h=Zr(a,c[f+4>>2]|0,c[f+8>>2]|0)|0;c[j>>2]=h;if((h|0)==0){n=-12;i=b;return n|0}else{ne[c[f+68>>2]&1023](c[e>>2]|0,h);p=c[j>>2]|0;break}}else{p=d}}while(0);o=PCb(p)|0}if((o|0)==0){n=-12;i=b;return n|0}p=f+32|0;d=c[p+4>>2]|0;j=o+136|0;c[j>>2]=c[p>>2];c[j+4>>2]=d;c[o+84>>2]=1;c[o+296>>2]=0;c[o+88>>2]=1;d=f+48|0;j=o+124|0;h=c[d+4>>2]|0;c[j>>2]=c[d>>2];c[j+4>>2]=h;if((c[g>>2]|0)==0){ne[c[f+68>>2]&1023](c[e>>2]|0,o)}e=YGb(c[p>>2]|0,c[p+4>>2]|0,1,0)|0;c[p>>2]=e;c[p+4>>2]=F;p=f+12|0;c[p>>2]=(c[p>>2]|0)+1;n=cj(a,o)|0;i=b;return n|0}function Ls(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+4>>2];c[a+24>>2]=c[b+8>>2];d=b+48|0;e=a+28|0;f=c[d+4>>2]|0;c[e>>2]=c[d>>2];c[e+4>>2]=f;f=b+24|0;e=a+116|0;d=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=d;d=b+16|0;b=a+56|0;a=c[d+4>>2]|0;c[b>>2]=c[d>>2];c[b+4>>2]=a;return 0}function Ms(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=c[e+44>>2]|0;h=c[f+68>>2]|0;i=c[f+72>>2]|0;if((i|0)<=0){return}j=(h|0)>0;k=f|0;l=f+32|0;f=e+32|0;e=g+144|0;m=g+145|0;n=g+146|0;o=g+147|0;g=i<<1;p=0;do{a:do{if(j){q=p*3|0;r=(q|0)<(g|0);if((q|0)<(i|0)){q=0;while(1){s=(q<<8|0)/(h|0)|0;t=c[k>>2]|0;u=c[l>>2]|0;switch(c[(c[c[f>>2]>>2]|0)+52>>2]|0){case 2:case 3:{v=s<<((d[e]|0)<<3);w=(ba(u,p)|0)+(q*3|0)|0;a[t+w|0]=v;a[t+(w+1)|0]=v>>>8;a[t+(w+2)|0]=v>>>16;break};case 62:{b[t+(ba(u,p)|0)+(q<<1)>>1]=s>>>4;break};case 44:{b[t+(ba(u,p)|0)+(q<<1)>>1]=s>>>3;break};case 64:{b[t+(ba(u,p)|0)+(q<<1)>>1]=s>>>4<<8;break};case 46:{b[t+(ba(u,p)|0)+(q<<1)>>1]=s>>>3;break};case 50:{b[t+(ba(u,p)|0)+(q<<1)>>1]=s>>>3<<10;break};case 48:{b[t+(ba(u,p)|0)+(q<<1)>>1]=s>>>3<<11;break};case 28:case 30:case 27:case 29:{v=t+((ba(u,p)|0)+(q<<2))|0;x=(s<<((d[e]|0)<<3))+(255<<((d[o]|0)<<3))|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;break};default:{}}q=q+1|0;if((q|0)>=(h|0)){break a}}}else{q=0;while(1){v=(q<<8|0)/(h|0)|0;s=r?v:0;u=r?0:v;v=c[k>>2]|0;t=c[l>>2]|0;switch(c[(c[c[f>>2]>>2]|0)+52>>2]|0){case 44:{b[v+(ba(t,p)|0)+(q<<1)>>1]=s>>>2<<5|u>>>3<<11;break};case 62:{b[v+(ba(t,p)|0)+(q<<1)>>1]=s&65520|u>>>4<<8;break};case 48:{b[v+(ba(t,p)|0)+(q<<1)>>1]=s>>>2<<5|u>>>3;break};case 64:{b[v+(ba(t,p)|0)+(q<<1)>>1]=s&65520|u>>>4;break};case 46:{b[v+(ba(t,p)|0)+(q<<1)>>1]=s>>>3<<5|u>>>3<<10;break};case 28:case 30:case 27:case 29:{w=v+((ba(t,p)|0)+(q<<2))|0;x=(s<<((d[m]|0)<<3))+(u<<((d[n]|0)<<3))+(255<<((d[o]|0)<<3))|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;break};case 50:{b[v+(ba(t,p)|0)+(q<<1)>>1]=s>>>3<<5|u>>>3;break};case 2:case 3:{w=(s<<((d[m]|0)<<3))+(u<<((d[n]|0)<<3))|0;u=(ba(t,p)|0)+(q*3|0)|0;a[v+u|0]=w;a[v+(u+1)|0]=w>>>8;a[v+(u+2)|0]=w>>>16;break};default:{}}q=q+1|0;if((q|0)>=(h|0)){break a}}}}}while(0);p=p+1|0;}while((p|0)<(i|0));return}function Ns(a){a=a|0;var b=0,d=0,e=0,f=0;b=a|0;Aw((c[(c[b>>2]|0)+44>>2]|0)+144|0,c[a+52>>2]|0)|0;d=c[(c[b>>2]|0)+44>>2]|0;c[a+20>>2]=c[d+4>>2];c[a+24>>2]=c[d+8>>2];b=d+48|0;e=a+28|0;f=c[b+4>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=f;f=d+24|0;e=a+116|0;b=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=b;b=d+16|0;d=a+56|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;return 0}function Os(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;f=c[b+44>>2]|0;b=c[e>>2]|0;g=c[e+68>>2]|0;h=c[e+72>>2]|0;i=(h+g|0)/4|0;do{if((h|0)>0){j=((ba(h,h)|0)>>>2)+((ba(g,g)|0)>>>2)-(ba(i,i)|0)|0;k=1-g|0;l=e+32|0;if((g|0)>0){m=j;n=1-h|0;o=0;p=b}else{q=l;break}while(1){j=m;r=k;s=0;t=0;u=0;v=p;while(1){w=(j|0)<0?t^7:t;a[v]=w<<31>>31;a[v+1|0]=w<<30>>31;a[v+2|0]=w<<29>>31;w=s+8|0;if((w|0)<(g|0)){x=t;y=w}else{x=t+1|0;y=w-g|0}w=u+1|0;if((w|0)<(g|0)){j=r+j|0;r=r+2|0;s=y;t=x;u=w;v=v+3|0}else{break}}v=o+1|0;if((v|0)<(h|0)){m=n+m|0;n=n+2|0;o=v;p=p+(c[l>>2]|0)|0}else{q=l;break}}}else{q=e+32|0}}while(0);e=b+(ba((h*3|0|0)/4|0,c[q>>2]|0)|0)|0;p=f+12|0;o=f+16|0;n=f+20|0;m=1536/(g|0)|0;x=1536%(g|0)|0;if((g|0)>0){y=((((ba(c[p>>2]<<8,c[o>>2]|0)|0)>>>0)/((c[n>>2]|0)>>>0)|0)>>>0)%1536|0;i=0;l=0;k=e;while(1){v=(y|0)<256;u=y-256|0;do{if(u>>>0>1023>>>0){z=-1;A=15}else{if((y-512|0)>>>0<512>>>0){a[k]=0;B=k+1|0;A=17;break}else{z=((y|0)<512?511-y|0:y)&255;A=15;break}}}while(0);do{if((A|0)==15){A=0;t=k+1|0;a[k]=z;if((y|0)<=1023){B=t;A=17;break}a[t]=0;C=k+2|0;A=20}}while(0);if((A|0)==17){A=0;if(u>>>0<512>>>0){D=-1}else{D=(v?y:1023-y|0)&255}t=k+2|0;a[B]=D;if((y|0)<512){E=0;G=t}else{C=t;A=20}}do{if((A|0)==20){A=0;if((y-768|0)>>>0<512>>>0){E=-1;G=C;break}E=((y|0)<768?y:1535-y|0)&255;G=C}}while(0);a[G]=E;v=y+m|0;u=i+x|0;if((u|0)>1535){H=u-1536|0;I=v+1|0}else{H=u;I=v}v=l+1|0;if((v|0)<(g|0)){y=(I|0)>1535?I-1536|0:I;i=H;l=v;k=k+3|0}else{break}}}if((h|0)>7){k=g*3|0;l=(h|0)/8|0;H=e;e=c[q>>2]|0;while(1){UGb(H+e|0,H|0,k)|0;i=c[q>>2]|0;I=l-1|0;if((I|0)>0){l=I;H=H+i|0;e=i}else{break}}}e=(g|0)/80|0;if((g|0)<=79){return}H=e*13|0;if((h|0)<(H|0)){return}l=c[o>>2]|0;o=c[n>>2]|0;n=c[p>>2]|0;p=c[f+72>>2]|0;if(!(+(l|0)/+(o|0)*+(n>>>0>>>0)*+S(+10.0,+(+(p|0)))<2147483647.0)){return}if((p|0)>0){f=0;k=0;i=1;while(1){I=gHb(i,k,10,0)|0;y=F;x=f+1|0;if((x|0)<(p|0)){f=x;k=y;i=I}else{J=y;K=I;break}}}else{J=0;K=1}i=ba(l,n)|0;n=HDb(i,0,K,J,o,(o|0)<0|0?-1:0,0)|0;o=c[q>>2]|0;J=e*-24|0;K=e*3|0;i=e*24|0;l=(H|0)>0;k=n;n=1;f=b+((ba(o,(h-H|0)/2|0)|0)+((g-((g-(e<<6)|0)/2|0)|0)*3|0))|0;g=o;while(1){o=f+J|0;h=d[1349824+((k|0)%10|0)|0]|0;if(l){b=0;p=o;while(1){TGb(p|0,0,i|0)|0;I=b+1|0;if((I|0)<(H|0)){b=I;p=p+g|0}else{L=0;break}}}else{L=0}do{do{if((1<<L&h|0)!=0){p=ba(K,c[1349720+(L<<4)>>2]|0)|0;b=ba(c[1349724+(L<<4)>>2]|0,e)|0;if((b|0)<=0){break}I=0;y=f+(ba((ba(c[1349716+(L<<4)>>2]|0,g)|0)-24+((c[1349712+(L<<4)>>2]|0)*3|0)|0,e)|0)|0;while(1){TGb(y|0,-1|0,p|0)|0;x=I+1|0;if((x|0)<(b|0)){I=x;y=y+g|0}else{break}}}}while(0);L=L+1|0;}while(L>>>0<7>>>0);if(!((k+9|0)>>>0>18>>>0&(n|0)<8)){break}k=(k|0)/10|0;n=n+1|0;f=o;g=c[q>>2]|0}return}function Ps(a,b){a=a|0;b=b|0;return}function Qs(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;i=i+8|0;h=g|0;j=c[(c[e+44>>2]|0)+148>>2]|0;e=c[f+68>>2]|0;k=c[f+72>>2]|0;l=c[f>>2]|0;m=c[f+32>>2]|0;n=f+80|0;f=bFb(c[n>>2]|0)|0;if((e|0)!=(k|0)){yDb(0,0,2252416,(o=i,i=i+24|0,c[o>>2]=2075864,c[o+8>>2]=2226024,c[o+16>>2]=300,o)|0);i=o;Cd()}k=ba(j,j)|0;if((e|0)!=(ba(k,j)|0)){yDb(0,0,2252416,(o=i,i=i+24|0,c[o>>2]=2075864,c[o+8>>2]=2226024,c[o+16>>2]=300,o)|0);i=o;Cd()}o=h|0;Aw(o,c[n>>2]|0)|0;switch(c[n>>2]|0){case 42:case 68:case 292:case 294:{p=1;q=-1;r=-1;break};case 28:case 30:case 27:case 29:{p=0;q=255;r=-1;break};default:{p=0;q=0;r=0}}n=(aFb(f)|0)>>p+3;s=(+(1<<(p<<3)+8|0)+-1.0)/+(k-1|0);if((k|0)==0){i=g;return}f=(p|0)==0;p=h+1|0;j=h+2|0;t=(n|0)==4;u=h+3|0;h=0;v=0;w=0;while(1){x=~~(s*+(w|0));y=x>>>0>255>>>0;z=-x>>31;A=x>>>0>65535>>>0;B=h;C=v;D=0;while(1){E=~~(s*+(D|0));F=E>>>0>255>>>0;G=-E>>31;H=E>>>0>65535>>>0;I=B;J=C;K=0;do{L=ba(I,m)|0;do{if(f){M=(ba(J,n)|0)+L|0;N=~~(s*+(K|0));if(N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}a[l+((d[o]|0)+M)|0]=O;a[l+((d[p]|0)+M)|0]=F?G:E;a[l+((d[j]|0)+M)|0]=y?z:x;if(!t){break}a[l+((d[u]|0)+M)|0]=r}else{M=l+L|0;N=ba(J,n)|0;P=~~(s*+(K|0));if(P>>>0>65535>>>0){Q=-P>>31&65535}else{Q=P&65535}b[M+((d[o]|0)+N<<1)>>1]=Q;b[M+((d[p]|0)+N<<1)>>1]=H?G:E;b[M+((d[j]|0)+N<<1)>>1]=A?z:x;if(!t){break}b[M+((d[u]|0)+N<<1)>>1]=q}}while(0);L=J+1|0;N=(L|0)==(e|0);I=(N&1)+I|0;J=N?0:L;K=K+1|0;}while((K|0)<(k|0));K=D+1|0;if((K|0)<(k|0)){B=I;C=J;D=K}else{break}}D=w+1|0;if((D|0)<(k|0)){h=I;v=J;w=D}else{break}}i=g;return}function Rs(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[(c[a>>2]|0)+44>>2]|0;d=c[b+148>>2]|0;e=ba(ba(d,d)|0,d)|0;d=b+8|0;c[d>>2]=e;c[b+4>>2]=e;c[a+20>>2]=e;c[a+24>>2]=c[d>>2];d=b+48|0;e=a+28|0;f=c[d+4>>2]|0;c[e>>2]=c[d>>2];c[e+4>>2]=f;f=b+24|0;e=a+116|0;d=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=d;d=b+16|0;b=a+56|0;a=c[d+4>>2]|0;c[b>>2]=c[d>>2];c[b+4>>2]=a;return 0}function Ss(a,b){a=a|0;b=b|0;var d=0;d=c[a+44>>2]|0;Ew(d+76|0,d+120|0,b|0,b+32|0,0,0,c[d+4>>2]|0,c[d+8>>2]|0);return}function Ts(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a|0;d=c[b>>2]|0;e=c[d+44>>2]|0;f=e+76|0;Bw(f,c[a+52>>2]|0,0)|0;Cw(f,e+120|0,e+140|0);g=e+4|0;c[g>>2]=Fw(f,0,-1,c[g>>2]|0)|0;h=e+8|0;e=Fw(f,1,-1,c[h>>2]|0)|0;c[h>>2]=e;if((hDb(c[g>>2]|0,e,0,d)|0)<0){i=-22;return i|0}d=c[(c[b>>2]|0)+44>>2]|0;c[a+20>>2]=c[d+4>>2];c[a+24>>2]=c[d+8>>2];b=d+48|0;e=a+28|0;g=c[b+4>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=g;g=d+24|0;e=a+116|0;b=c[g+4>>2]|0;c[e>>2]=c[g>>2];c[e+4>>2]=b;b=d+16|0;d=a+56|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;i=0;return i|0}function Us(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+44>>2]|0;e=c[d+24>>2]|0;a:do{if((e|0)==0){f=Zs(a,-1)|0;if((f|0)<0){g=f;i=b;return g|0}h=d+28|0;j=jBb(c[h>>2]|0)|0;k=F;l=d+16|0;c[l>>2]=j;c[l+4>>2]=k;if(!((j|0)==0&(k|0)==0)){m=f;break}k=c[h>>2]|0;if((k|0)>=1){m=f;break}yDb(a,16,2187312,(f=i,i=i+8|0,c[f>>2]=k,f)|0);i=f;g=-22;i=b;return g|0}else{do{if((QGb(e,2197960)|0)==0){if((QGb(c[c[a+4>>2]>>2]|0,2160824)|0)!=0){break}c[d+36>>2]=1;m=0;break a}}while(0);f=d+16|0;k=Uk(f,0,e,a)|0;if((k|0)<0){g=k;i=b;return g|0}k=Zs(a,hBb(c[f>>2]|0,c[f+4>>2]|0)|0)|0;if((k|0)<0){g=k}else{m=k;break}i=b;return g|0}}while(0);e=c[d+4>>2]|0;do{if((e|0)==0){n=m}else{k=Tk(d+8|0,e,a)|0;if((k|0)==0){n=0;break}else{g=k}i=b;return g|0}}while(0);a=d+72|0;c[a>>2]=0;c[a+4>>2]=0;g=n;i=b;return g|0}function Vs(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;a=b+28|0;d=b+48|0;if((c[a>>2]|0)<=0){$Db(d);return}b=d;e=0;do{IBb(c[(c[b>>2]|0)+(e<<2)>>2]|0);c[(c[b>>2]|0)+(e<<2)>>2]=0;e=e+1|0;}while((e|0)<(c[a>>2]|0));$Db(d);return}function Ws(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+16|0;f=c[a+44>>2]|0;g=d|0;h=f+16|0;j=c[h>>2]|0;k=c[h+4>>2]|0;if((j|0)==0&(k|0)==0){h=c[f+28>>2]|0;l=((h|0)<0|0?-1:0)|-2147483648;m=h|0}else{l=k;m=j}c[g>>2]=m;c[g+4>>2]=l;l=d+8|0;c[l>>2]=-1;c[l+4>>2]=-1;l=e|0;c[l>>2]=c[f+8>>2];c[e+4>>2]=-1;Ok(a,xk(550048)|0);Mk(a,yk(g)|0);Nk(a,xk(l)|0);i=b;return 0}function Xs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+8|0;d=b|0;e=c[c[a+16>>2]>>2]|0;f=c[c[a+32>>2]>>2]|0;g=c[a+44>>2]|0;h=Fk()|0;c[d>>2]=h;Gk(h,e+84|0);do{if((c[g+36>>2]|0)==0){c[d>>2]=0;e=g+136|0;h=c[e>>2]|0;j=c[e+4>>2]|0;if((h|0)==0&(j|0)==0){e=c[g+28>>2]|0;k=((e|0)<0|0?-1:0)|-2147483648;l=e|0}else{k=j;l=h}Ak(d,l,k)|0;Gk(c[d>>2]|0,f+80|0)}else{h=Fk()|0;c[d>>2]=h;if((h|0)==0){m=-12;i=b;return m|0}else{Mk(a,h);break}}}while(0);d=xk(1808336)|0;if((d|0)==0){m=-12;i=b;return m|0}Ok(a,d);d=Dk()|0;if((d|0)==0){m=-12;i=b;return m|0}Nk(a,d);m=0;i=b;return m|0}function Ys(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=c[c[b+16>>2]>>2]|0;do{if((c[d+36>>2]|0)==0){f=e+148|0}else{g=e+40|0;i=c[g+4>>2]|0;j=d+16|0;c[j>>2]=c[g>>2];c[j+4>>2]=i;i=e+148|0;j=Zs(b,c[i>>2]|0)|0;if((j|0)<0){k=j}else{f=i;break}return k|0}}while(0);b=d+72|0;c[b>>2]=0;c[b+4>>2]=0;b=c[f>>2]|0;h[d+96>>3]=+(b|0);c[d+32>>2]=b;h[d+104>>3]=+(c[a+148>>2]|0);h[d+120>>3]=+(c[e+48>>2]|0);h[d+112>>3]=+q;e=d+128|0;d=YDb(c[e>>2]|0,c[f>>2]|0,8)|0;c[e>>2]=d;k=(d|0)==0?-12:0;return k|0}function Zs(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;f=c[a+44>>2]|0;g=f+52|0;h=eEb(c[g>>2]|0)|0;if((h|0)==0){j=-12;i=d;return j|0}if((c[g>>2]|0)==0){yDb(a,16,2345400,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;j=-22;i=d;return j|0}g=(QGb(c[c[a+4>>2]>>2]|0,2160824)|0)==0;l=g?1808784:0;m=g?1808776:0;g=f+28|0;n=f+48|0;f=n;if((c[g>>2]|0)>0){o=0;do{IBb(c[(c[f>>2]|0)+(o<<2)>>2]|0);c[(c[f>>2]|0)+(o<<2)>>2]=0;o=o+1|0;}while((o|0)<(c[g>>2]|0))}$Db(n);c[g>>2]=0;c[e>>2]=h;o=n;n=a;a=0;p=0;q=h;while(1){r=xAb(q,2323696,e)|0;if((r|0)==0){s=11;break}if((hEb(o,g,4,0)|0)==0){t=-12;break}u=(c[g>>2]|0)-1|0;c[(c[f>>2]|0)+(u<<2)>>2]=0;v=JBb((c[f>>2]|0)+(u<<2)|0,r,159912,m,l,0,0,0,n)|0;if((v|0)<0){t=v;break}a=v;p=r;q=c[e>>2]|0}a:do{if((s|0)==11){e=c[g>>2]|0;b:do{if((e|0)<(b|0)){q=a;r=e;while(1){if((r|0)>=(b|0)){w=q;break b}if((hEb(o,g,4,0)|0)==0){t=-12;break a}v=(c[g>>2]|0)-1|0;c[(c[f>>2]|0)+(v<<2)>>2]=0;u=JBb((c[f>>2]|0)+(v<<2)|0,p,159912,m,l,0,0,0,n)|0;if((u|0)<0){t=u;break a}else{q=u;r=r+1|0}}}else{w=a}}while(0);if((b|0)<=0){t=w;break}e=c[g>>2]|0;if((e|0)==(b|0)){t=w;break}yDb(n,16,2300496,(k=i,i=i+16|0,c[k>>2]=e,c[k+8>>2]=b,k)|0);i=k;t=-22}}while(0);ZDb(h);j=t;i=d;return j|0}function _s(a,b){a=a|0;b=+b;var d=0,e=0;d=~~b;e=(c[a+32>>2]|0)-1|0;return+(+h[(c[a+128>>2]|0)+(((d|0)>(e|0)?e:d)<<3)>>3])}function $s(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,G=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;j=c[c[f+32>>2]>>2]|0;f=c[b+76>>2]|0;k=fi(j,f)|0;if((k|0)==0){l=-12;i=d;return l|0}NCb(k,b)|0;m=b+136|0;b=c[m>>2]|0;n=c[m+4>>2]|0;if((b|0)==0&(n|0)==(-2147483648|0)){o=+q}else{o=(+(b>>>0)+ +(n|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}if((f|0)>0){n=g+72|0;b=g+88|0;m=a+48|0;p=g+112|0;r=a+148|0;a=j+148|0;s=g+80|0;t=g+48|0;u=k+64|0;v=g+128|0;w=0;x=c[n+4>>2]|0;y=c[n>>2]|0;do{h[b>>3]=+(y>>>0)+ +(x>>>0)*4294967296.0;h[p>>3]=o+ +(w|0)/+(c[m>>2]|0);z=c[r>>2]|0;if((z|0)>0){A=c[(c[e>>2]|0)+64>>2]|0;B=c[v>>2]|0;C=0;do{h[B+(C<<3)>>3]=+h[(c[A+(C<<2)>>2]|0)+(w<<3)>>3];C=C+1|0;}while((C|0)<(z|0))}if((c[a>>2]|0)>0){z=0;do{h[s>>3]=+(z|0);D=+MBb(c[(c[t>>2]|0)+(z<<2)>>2]|0,s,g);h[(c[(c[u>>2]|0)+(z<<2)>>2]|0)+(w<<3)>>3]=D;z=z+1|0;}while((z|0)<(c[a>>2]|0));E=c[n+4>>2]|0;G=c[n>>2]|0}else{E=x;G=y}w=w+1|0;y=YGb(G,E,1,0)|0;x=F;c[n>>2]=y;c[n+4>>2]=x;}while((w|0)<(f|0))}JCb(e);l=cj(j,k)|0;i=d;return l|0}function at(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[(c[a>>2]|0)+44>>2]|0;d=b+72|0;e=b+8|0;f=b+64|0;g=c[f>>2]|0;i=c[f+4>>2]|0;f=-1;do{if((i|0)>(f|0)|(i|0)==(f|0)&g>>>0>-1>>>0){j=c[e>>2]|0;k=IDb(c[d>>2]|0,c[d+4>>2]|0,1e6,0,j,(j|0)<0|0?-1:0)|0;j=F;if((j|0)<(i|0)|(j|0)==(i|0)&k>>>0<g>>>0){break}else{l=-541478725}return l|0}}while(0);g=b+56|0;i=fi(a,c[g>>2]|0)|0;if((i|0)==0){l=-12;return l|0}f=c[g>>2]|0;if((f|0)>0){k=b+88|0;j=b+112|0;m=b+28|0;n=b+48|0;o=b+80|0;p=i+64|0;q=0;r=c[d+4>>2]|0;s=c[d>>2]|0;t=c[m>>2]|0;u=f;while(1){v=+(s>>>0)+ +(r>>>0)*4294967296.0;h[k>>3]=v;h[j>>3]=v/+(c[e>>2]|0);if((t|0)>0){f=0;do{v=+MBb(c[(c[n>>2]|0)+(f<<2)>>2]|0,o,0);h[(c[(c[p>>2]|0)+(f<<2)>>2]|0)+(q<<3)>>3]=v;f=f+1|0;w=c[m>>2]|0;}while((f|0)<(w|0));x=w;y=c[d+4>>2]|0;z=c[d>>2]|0;A=c[g>>2]|0}else{x=t;y=r;z=s;A=u}f=q+1|0;B=YGb(z,y,1,0)|0;C=F;c[d>>2]=B;c[d+4>>2]=C;if((f|0)<(A|0)){q=f;r=C;s=B;t=x;u=A}else{break}}}A=b+40|0;b=c[A+4>>2]|0;u=i+136|0;c[u>>2]=c[A>>2];c[u+4>>2]=b;c[i+344>>2]=c[e>>2];e=c[g>>2]|0;g=YGb(c[A>>2]|0,c[A+4>>2]|0,e,(e|0)<0|0?-1:0)|0;c[A>>2]=g;c[A+4>>2]=F;l=cj(a,i)|0;return l|0}function bt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0;b=i;i=i+128|0;d=a|0;e=c[(c[d>>2]|0)+44>>2]|0;f=e+8|0;g=c[f>>2]|0;c[a+56>>2]=1;c[a+60>>2]=g;c[a+48>>2]=c[f>>2];h[e+120>>3]=+(c[f>>2]|0);h[e+96>>3]=+q;h[e+104>>3]=+(c[a+148>>2]|0);a=b|0;g=e+16|0;iBb(a,128,0,c[g>>2]|0,c[g+4>>2]|0);g=e+64|0;e=c[g>>2]|0;j=c[g+4>>2]|0;yDb(c[d>>2]|0,40,2118336,(d=i,i=i+32|0,c[d>>2]=c[f>>2],c[d+8>>2]=a,c[d+16>>2]=e,c[d+24>>2]=j,d)|0);i=d;i=b;return 0}function ct(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+44>>2]|0;e=a;yDb(e,24,2160664,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;a=d+4|0;c[a>>2]=-1;f=d+8|0;c[f>>2]=0;c[f+4>>2]=0;g=c[d+20>>2]|0;do{if((g|0)==0){h=0}else{if((QGb(g,2089648)|0)==0){h=0;break}j=Sk(a,g,e)|0;if((j|0)<0){k=j}else{h=j;break}i=b;return k|0}}while(0);g=c[d+24>>2]|0;if((g|0)==0){k=h;i=b;return k|0}if((QGb(g,2089648)|0)==0){k=h;i=b;return k|0}k=Uk(f,0,g,e)|0;i=b;return k|0}function dt(a){a=a|0;Tqb((c[a+44>>2]|0)+16|0);return}function et(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[d>>2]=0;f=c[a+44>>2]|0;g=c[c[a+16>>2]>>2]|0;h=c[c[a+32>>2]>>2]|0;Hk(Bk(1)|0,g+68|0);a=c[f+4>>2]|0;if((a|0)==-1){Hk(Bk(1)|0,h+64|0)}else{c[d>>2]=0;zk(d,a,(a|0)<0|0?-1:0)|0;Hk(c[d>>2]|0,h+64|0)}Gk(Ek()|0,g+84|0);g=f+8|0;f=c[g>>2]|0;d=c[g+4>>2]|0;if((f|0)==0&(d|0)==0){Gk(Ek()|0,h+80|0);i=b;return 0}else{c[e>>2]=0;Ak(e,f,d)|0;Gk(c[e>>2]|0,h+80|0);i=b;return 0}return 0}function ft(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+128|0;d=c[a>>2]|0;e=c[c[d+16>>2]>>2]|0;f=c[d+44>>2]|0;g=f+4|0;h=c[g>>2]|0;if((h|0)==-1){j=c[a+52>>2]|0;c[g>>2]=j;k=j}else{k=h}h=f+8|0;j=c[h>>2]|0;g=c[h+4>>2]|0;if((j|0)==0&(g|0)==0){l=a+40|0;m=c[l>>2]|0;n=c[l+4>>2]|0;c[h>>2]=m;c[h+4>>2]=n;o=n;p=m}else{o=g;p=j}j=f+16|0;f=c[e+48>>2]|0;g=e+40|0;m=e+52|0;e=d;d=Sqb(c[j>>2]|0,p,o,k,f,c[g>>2]|0,c[g+4>>2]|0,c[m>>2]|0,f,0,e)|0;c[j>>2]=d;if((d|0)==0){q=-12;i=b;return q|0}j=Vqb(d)|0;if((j|0)<0){q=j;i=b;return q|0}j=b|0;iBb(j,64,-1,c[g>>2]|0,c[g+4>>2]|0);g=b+64|0;d=a+40|0;iBb(g,64,-1,c[d>>2]|0,c[d+4>>2]|0);d=wFb(c[m>>2]|0)|0;m=wFb(c[a+52>>2]|0)|0;yDb(e,40,1908240,(e=i,i=i+32|0,c[e>>2]=d,c[e+8>>2]=j,c[e+16>>2]=m,c[e+24>>2]=g,e)|0);i=e;q=0;i=b;return q|0}function gt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=c[b+76>>2]|0;h=c[c[f+32>>2]>>2]|0;f=fi(h,g)|0;if((f|0)==0){j=-12;i=d;return j|0}Xqb(c[a+16>>2]|0,c[f+64>>2]|0,g,c[b+64>>2]|0,g)|0;NCb(f,b)|0;wCb(f,c[h+148>>2]|0);b=h+40|0;g=c[b+4>>2]|0;a=f+352|0;c[a>>2]=c[b>>2];c[a+4>>2]=g;g=cj(h,f)|0;JCb(e);j=g;i=d;return j|0}function ht(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;a=b+12|0;d=b+8|0;if((c[a>>2]|0)<=0){$Db(d);return}b=d;e=0;do{ZDb(c[(c[b>>2]|0)+(e<<4)+12>>2]|0);e=e+1|0;}while((e|0)<(c[a>>2]|0));$Db(d);return}function it(a){a=a|0;var b=0,c=0,d=0;b=Ek()|0;do{if((b|0)==0){c=-12}else{Mk(a,b);d=xk(550024)|0;if((d|0)==0){c=-12;break}Ok(a,d);d=Dk()|0;if((d|0)==0){c=-12;break}Nk(a,d);c=0}}while(0);return c|0}function jt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=e+16|0;h=Ni(c[c[g>>2]>>2]|0)|0;if(!((h|0)==-541478725)){j=h;i=b;return j|0}if((c[e+76>>2]|0)!=0){j=-541478725;i=b;return j|0}e=f+20|0;h=c[e>>2]|0;if((h|0)==0){j=-541478725;i=b;return j|0}k=h>>>0>2048>>>0?2048:h;h=fi(a,k)|0;if((h|0)==0){j=-12;i=b;return j|0}c[e>>2]=(c[e>>2]|0)-k;GFb(c[h+64>>2]|0,0,c[h+76>>2]|0,c[a+148>>2]|0,c[h+80>>2]|0)|0;e=f+24|0;f=c[e+4>>2]|0;l=h+136|0;c[l>>2]=c[e>>2];c[l+4>>2]=f;if(!((c[e>>2]|0)==0&(c[e+4>>2]|0)==(-2147483648|0))){c[d>>2]=1;c[d+4>>2]=c[a+48>>2];f=KDb(k,(k|0)<0|0?-1:0,d,a+56|0)|0;a=YGb(c[e>>2]|0,c[e+4>>2]|0,f,F)|0;c[e>>2]=a;c[e+4>>2]=F}j=kt(c[c[g>>2]>>2]|0,h)|0;i=b;return j|0}function kt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;h=c[g+44>>2]|0;do{if((c[g+76>>2]|0)==0){if((c[h+4>>2]|0)==0){break}j=fi(a,c[b+76>>2]|0)|0;if((j|0)==0){k=-12;i=d;return k|0}NCb(j,b)|0;l=h+12|0;if((c[l>>2]|0)>0){m=h+8|0;n=j+64|0;o=h+16|0;p=h+32|0;q=0;r=b;while(1){s=(c[m>>2]|0)+(q<<4)|0;t=c[(c[r+64>>2]|0)+(q<<2)>>2]|0;u=c[(c[n>>2]|0)+(q<<2)>>2]|0;if((c[s>>2]|0)==0){UGb(u|0,t|0,ba(c[o>>2]|0,c[r+76>>2]|0)|0)|0}else{cf[c[p>>2]&1023](s,c[r+76>>2]|0,t,u)}u=q+1|0;t=c[e>>2]|0;if((u|0)<(c[l>>2]|0)){q=u;r=t}else{v=t;break}}}else{v=b}r=v+136|0;q=c[r>>2]|0;l=c[r+4>>2]|0;r=c[v+76>>2]|0;c[f>>2]=1;c[f+4>>2]=c[a+48>>2];p=KDb(r,(r|0)<0|0?-1:0,f,a+56|0)|0;r=YGb(p,F,q,l)|0;l=h+24|0;c[l>>2]=r;c[l+4>>2]=F;JCb(e);k=cj(c[c[g+32>>2]>>2]|0,j)|0;i=d;return k|0}}while(0);k=cj(c[c[g+32>>2]>>2]|0,b)|0;i=d;return k|0}function lt(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+8>>2]|0;h=c[f+44>>2]|0;c[d>>2]=0;j=a+148|0;k=dEb(c[j>>2]|0,16)|0;l=h+8|0;c[l>>2]=k;if((k|0)==0){m=-12;i=b;return m|0}k=h+12|0;c[k>>2]=c[j>>2];j=a+52|0;n=h+16|0;c[n>>2]=BFb(c[j>>2]|0)|0;o=a+48|0;a=c[h+4>>2]|0;p=0;while(1){q=c[k>>2]|0;if((p|0)>=(q|0)){r=q;break}q=c[l>>2]|0;s=xAb(a,1992672,d)|0;if((s|0)==0){t=6;break}xd(s|0,1958176,(u=i,i=i+8|0,c[u>>2]=e,u)|0)|0;i=u;s=~~(+g[e>>2]*+(c[o>>2]|0)/1.0e3);c[q+(p<<4)>>2]=s;if((s|0)<0){t=8;break}else{a=0;p=p+1|0}}if((t|0)==6){r=c[k>>2]|0}else if((t|0)==8){yDb(f,16,1930304,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;m=-22;i=b;return m|0}p=h+20|0;a:do{if((r|0)>0){a=0;o=r;while(1){v=c[l>>2]|0;e=v+(a<<4)|0;d=c[e>>2]|0;if((d|0)==0){w=o}else{s=c[n>>2]|0;if((s|0)==0){break}if(!((2147483647/(s>>>0)|0)>>>0>d>>>0)){break}q=WDb(ba(s,d)|0)|0;c[v+(a<<4)+12>>2]=q;if((q|0)==0){m=-12;t=24;break}q=c[p>>2]|0;d=c[e>>2]|0;c[p>>2]=q>>>0>d>>>0?q:d;w=c[k>>2]|0}d=a+1|0;if((d|0)<(w|0)){a=d;o=w}else{break a}}if((t|0)==24){i=b;return m|0}c[v+(a<<4)+12>>2]=0;m=-12;i=b;return m|0}}while(0);if((c[p>>2]|0)==0){yDb(f,16,1908192,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;m=-22;i=b;return m|0}switch(c[j>>2]|0){case 8:{c[h+32>>2]=508;m=0;i=b;return m|0};case 7:{c[h+32>>2]=8;m=0;i=b;return m|0};case 9:{c[h+32>>2]=124;m=0;i=b;return m|0};case 5:{c[h+32>>2]=594;m=0;i=b;return m|0};case 6:{c[h+32>>2]=388;m=0;i=b;return m|0};default:{m=0;i=b;return m|0}}return 0}function mt(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b+12>>2]|0;if((d|0)==0){return}h=b+4|0;i=b|0;j=b+8|0;b=f;f=e;e=d;while(1){d=c[h>>2]|0;k=c[i>>2]|0;if(d>>>0<k>>>0){l=k-d|0;k=e>>>0>l>>>0?l:e;UGb(g+d|0,f|0,k)|0;TGb(b|0,-128|0,k|0)|0;c[h>>2]=(c[h>>2]|0)+k;m=e-k|0;n=f+k|0;o=b+k|0}else{a[b]=a[g+(c[j>>2]|0)|0]|0;a[g+(c[j>>2]|0)|0]=a[f]|0;k=(c[j>>2]|0)+1|0;c[j>>2]=k>>>0<(c[i>>2]|0)>>>0?k:0;m=e-1|0;n=f+1|0;o=b+1|0}if((m|0)==0){break}else{b=o;f=n;e=m}}return}function nt(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=c[a+12>>2]|0;if((d|0)==0){return}h=a+4|0;i=a|0;j=a+8|0;a=f;f=e;e=d;d=c[h>>2]|0;while(1){k=c[i>>2]|0;if(d>>>0<k>>>0){l=k-d|0;m=e>>>0>l>>>0?l:e;l=m<<1;UGb(g+(d<<1)|0,f|0,l)|0;TGb(a|0,0,l|0)|0;l=(c[h>>2]|0)+m|0;c[h>>2]=l;n=e-m|0;o=f+(m<<1)|0;p=a+(m<<1)|0;q=l}else{l=c[j>>2]|0;m=g+(l<<1)|0;b[a>>1]=b[m>>1]|0;b[m>>1]=b[f>>1]|0;m=l+1|0;c[j>>2]=m>>>0<k>>>0?m:0;n=e-1|0;o=f+2|0;p=a+2|0;q=d}if((n|0)==0){break}else{a=p;f=o;e=n;d=q}}return}function ot(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[a+12>>2]|0;if((b|0)==0){return}g=a+4|0;h=a|0;i=a+8|0;a=e;e=d;d=b;while(1){b=c[g>>2]|0;j=c[h>>2]|0;if(b>>>0<j>>>0){k=j-b|0;j=d>>>0>k>>>0?k:d;k=j<<2;UGb(f+(b<<2)|0,e|0,k)|0;TGb(a|0,0,k|0)|0;c[g>>2]=(c[g>>2]|0)+j;l=d-j|0;m=e+(j<<2)|0;n=a+(j<<2)|0}else{c[a>>2]=c[f+(c[i>>2]<<2)>>2];c[f+(c[i>>2]<<2)>>2]=c[e>>2];j=(c[i>>2]|0)+1|0;c[i>>2]=j>>>0<(c[h>>2]|0)>>>0?j:0;l=d-1|0;m=e+4|0;n=a+4|0}if((l|0)==0){break}else{a=n;e=m;d=l}}return}function pt(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[a+12>>2]|0;if((b|0)==0){return}h=a+4|0;i=a|0;j=a+8|0;a=e;e=d;d=b;b=c[h>>2]|0;while(1){k=c[i>>2]|0;if(b>>>0<k>>>0){l=k-b|0;m=d>>>0>l>>>0?l:d;l=m<<2;UGb(f+(b<<2)|0,e|0,l)|0;TGb(a|0,0,l|0)|0;l=(c[h>>2]|0)+m|0;c[h>>2]=l;n=d-m|0;o=e+(m<<2)|0;p=a+(m<<2)|0;q=l}else{l=c[j>>2]|0;m=f+(l<<2)|0;g[a>>2]=+g[m>>2];g[m>>2]=+g[e>>2];m=l+1|0;c[j>>2]=m>>>0<k>>>0?m:0;n=d-1|0;o=e+4|0;p=a+4|0;q=b}if((n|0)==0){break}else{a=p;e=o;d=n;b=q}}return}function qt(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[a+12>>2]|0;if((b|0)==0){return}g=a+4|0;i=a|0;j=a+8|0;a=e;e=d;d=b;b=c[g>>2]|0;while(1){k=c[i>>2]|0;if(b>>>0<k>>>0){l=k-b|0;m=d>>>0>l>>>0?l:d;l=m<<3;UGb(f+(b<<3)|0,e|0,l)|0;TGb(a|0,0,l|0)|0;l=(c[g>>2]|0)+m|0;c[g>>2]=l;n=d-m|0;o=e+(m<<3)|0;p=a+(m<<3)|0;q=l}else{l=c[j>>2]|0;m=f+(l<<3)|0;h[a>>3]=+h[m>>3];h[m>>3]=+h[e>>3];m=l+1|0;c[j>>2]=m>>>0<k>>>0?m:0;n=d-1|0;o=e+8|0;p=a+8|0;q=b}if((n|0)==0){break}else{a=p;e=o;d=n;b=q}}return}function rt(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0;d=i;i=i+16|0;e=d|0;f=d+8|0;j=c[b+44>>2]|0;k=j+12|0;l=c[k>>2]|0;do{if((l|0)!=0){m=j+16|0;n=c[m>>2]|0;if((n|0)==0){break}else{o=l;p=1}while(1){q=a[o]|0;if((q<<24>>24|0)==0){r=n;s=1;break}else if((q<<24>>24|0)==124){t=p+1|0}else{t=p}o=o+1|0;p=t}while(1){n=a[r]|0;if((n<<24>>24|0)==124){u=s+1|0}else if((n<<24>>24|0)==0){break}else{u=s}r=r+1|0;s=u}n=j+20|0;c[n>>2]=YDb(c[n>>2]|0,p,4)|0;q=j+24|0;v=YDb(c[q>>2]|0,s,4)|0;c[q>>2]=v;w=c[n>>2]|0;if((w|0)==0|(v|0)==0){x=-12;i=d;return x|0}v=c[k>>2]|0;c[e>>2]=0;if((p|0)>0){y=0;z=0;A=v;while(1){v=xd(xAb(A,1908184,e)|0,1887328,(B=i,i=i+8|0,c[B>>2]=w+(y<<2),B)|0)|0;i=B;C=((v|0)==1)+z|0;v=y+1|0;if((v|0)<(p|0)){y=v;z=C;A=0}else{D=C;break}}}else{D=0}A=c[m>>2]|0;z=c[q>>2]|0;c[f>>2]=0;if((s|0)>0){y=0;w=0;C=A;while(1){A=xd(xAb(C,1908184,f)|0,1887328,(B=i,i=i+8|0,c[B>>2]=z+(y<<2),B)|0)|0;i=B;v=((A|0)==1)+w|0;A=y+1|0;if((A|0)<(s|0)){y=A;w=v;C=0}else{E=v;break}}}else{E=0}if((D|0)!=(E|0)){yDb(b,16,2089552,(B=i,i=i+16|0,c[B>>2]=D,c[B+8>>2]=E,B)|0);i=B;x=-22;i=d;return x|0}C=j+28|0;c[C>>2]=D;if((D|0)==0){yDb(b,16,2037336,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;x=-22;i=d;return x|0}w=j+48|0;y=YDb(c[w>>2]|0,D,4)|0;c[w>>2]=y;if((y|0)==0){x=-12;i=d;return x|0}else{F=0}while(1){if((F|0)>=(D|0)){G=25;break}H=+g[(c[n>>2]|0)+(F<<2)>>2];if(H<=0.0|H>9.0e4){G=22;break}I=+g[(c[q>>2]|0)+(F<<2)>>2];if(I<=0.0|I>1.0){G=24;break}else{F=F+1|0}}if((G|0)==22){yDb(b,16,1992616,(B=i,i=i+16|0,c[B>>2]=F,h[B+8>>3]=H,B)|0);i=B;x=-22;i=d;return x|0}else if((G|0)==24){yDb(b,16,1958128,(B=i,i=i+16|0,c[B>>2]=F,h[B+8>>3]=I,B)|0);i=B;x=-22;i=d;return x|0}else if((G|0)==25){q=j+56|0;c[q>>2]=0;c[q+4>>2]=-2147483648;yDb(b,48,1930288,(B=i,i=i+8|0,c[B>>2]=c[C>>2],B)|0);i=B;x=0;i=d;return x|0}}}while(0);yDb(b,16,2160568,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;x=-22;i=d;return x|0}function st(a){a=a|0;var b=0;b=c[a+44>>2]|0;$Db(b+20|0);$Db(b+24|0);$Db(b+48|0);a=b+36|0;b=c[a>>2]|0;if((b|0)==0){$Db(a);return}$Db(b);$Db(a);return}function tt(a){a=a|0;var b=0,c=0,d=0;b=Ek()|0;do{if((b|0)==0){c=-12}else{Mk(a,b);d=xk(55e4)|0;if((d|0)==0){c=-12;break}Ok(a,d);d=Dk()|0;if((d|0)==0){c=-12;break}Nk(a,d);c=0}}while(0);return c|0}function ut(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=Ni(c[c[e+16>>2]>>2]|0)|0;if(!((g|0)==-541478725)){h=g;i=b;return h|0}if((c[e+76>>2]|0)!=0){h=-541478725;i=b;return h|0}e=f+44|0;g=c[e>>2]|0;if((g|0)==0){h=-541478725;i=b;return h|0}j=(g|0)>2048?2048:g;g=fi(a,j)|0;if((g|0)==0){h=-12;i=b;return h|0}c[e>>2]=(c[e>>2]|0)-j;e=g+64|0;k=g+76|0;l=a+148|0;GFb(c[e>>2]|0,0,c[k>>2]|0,c[l>>2]|0,c[g+80>>2]|0)|0;m=c[e>>2]|0;Se[c[f+64>>2]&511](f,c[f+36>>2]|0,m,m,c[k>>2]|0,c[l>>2]|0);l=f+56|0;f=c[l+4>>2]|0;k=g+136|0;c[k>>2]=c[l>>2];c[k+4>>2]=f;if(!((c[l>>2]|0)==0&(c[l+4>>2]|0)==(-2147483648|0))){c[d>>2]=1;c[d+4>>2]=c[a+48>>2];f=KDb(j,(j|0)<0|0?-1:0,d,a+56|0)|0;d=YGb(c[l>>2]|0,c[l+4>>2]|0,f,F)|0;c[l>>2]=d;c[l+4>>2]=F}h=cj(a,g)|0;i=b;return h|0}function vt(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0,w=0,x=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=e+28|0;if((c[f>>2]|0)>0){j=c[e+20>>2]|0;k=a+48|0;l=c[e+48>>2]|0;m=e+40|0;n=c[e+24>>2]|0;o=1.0;p=0;while(1){q=~~(+g[j+(p<<2)>>2]*+(c[k>>2]|0)/1.0e3);c[l+(p<<2)>>2]=q;r=c[m>>2]|0;s=(r|0)>(q|0)?r:q;c[m>>2]=s;t=o+ +g[n+(p<<2)>>2];q=p+1|0;if((q|0)<(c[f>>2]|0)){o=t;p=q}else{u=t;v=s;break}}}else{u=1.0;v=c[e+40>>2]|0}p=e+40|0;if((v|0)<1){yDb(d,16,2187184,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-22;i=b;return x|0}c[e+44>>2]=v;o=+g[e+8>>2];if(u*+g[e+4>>2]*o>1.0){yDb(d,24,2171408,(w=i,i=i+8|0,h[w>>3]=o,w)|0);i=w}w=a+52|0;d=c[w>>2]|0;if((d|0)==7){c[e+64>>2]=190}else if((d|0)==6){c[e+64>>2]=200}else if((d|0)==9){c[e+64>>2]=276}else if((d|0)==8){c[e+64>>2]=116}d=e+36|0;e=d;v=c[e>>2]|0;if((v|0)!=0){$Db(v)}$Db(d);x=HFb(e,0,c[a+148>>2]|0,c[p>>2]|0,c[w>>2]|0,0)|0;i=b;return x|0}function wt(a,b,d,e,f,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;i=i|0;var j=0.0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0,L=0.0,M=0.0;j=+g[a+8>>2];k=+g[a+4>>2];l=c[a+28>>2]|0;m=c[a+40>>2]|0;n=a+32|0;if((i|0)<=0){o=0;c[n>>2]=o;return}p=c[n>>2]|0;q=(f|0)>0;r=(l|0)>0;s=a+48|0;t=a+24|0;a=0;while(1){u=c[d+(a<<2)>>2]|0;v=c[e+(a<<2)>>2]|0;w=c[b+(a<<2)>>2]|0;a:do{if(q){if(r){x=p;y=u;z=v;A=0}else{B=p;C=u;D=v;E=0;while(1){F=+h[C>>3];G=j*k*F;if(G<-1.0){H=-1.0}else{H=G>1.0?1.0:G}h[D>>3]=H;h[w+(B<<3)>>3]=F;I=B+1|0;J=I-((I|0)<(m|0)?0:m)|0;I=E+1|0;if((I|0)<(f|0)){B=J;C=C+8|0;D=D+8|0;E=I}else{K=J;break a}}}while(1){F=+h[y>>3];E=x+m|0;D=c[s>>2]|0;C=c[t>>2]|0;B=0;G=k*F;do{J=E-(c[D+(B<<2)>>2]|0)|0;G=G+ +h[w+(J-((J|0)<(m|0)?0:m)<<3)>>3]*+g[C+(B<<2)>>2];B=B+1|0;}while((B|0)<(l|0));L=j*G;if(L<-1.0){M=-1.0}else{M=L>1.0?1.0:L}h[z>>3]=M;h[w+(x<<3)>>3]=F;B=x+1|0;C=B-((B|0)<(m|0)?0:m)|0;B=A+1|0;if((B|0)<(f|0)){x=C;y=y+8|0;z=z+8|0;A=B}else{K=C;break}}}else{K=p}}while(0);w=a+1|0;if((w|0)<(i|0)){a=w}else{o=K;break}}c[n>>2]=o;return}function xt(a,b,d,e,f,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0.0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0.0,G=0.0,H=0,I=0,J=0,K=0.0,L=0.0;i=+g[a+8>>2];j=+g[a+4>>2];k=c[a+28>>2]|0;l=c[a+40>>2]|0;m=a+32|0;if((h|0)<=0){n=0;c[m>>2]=n;return}o=c[m>>2]|0;p=(f|0)>0;q=(k|0)>0;r=a+48|0;s=a+24|0;a=0;while(1){t=c[d+(a<<2)>>2]|0;u=c[e+(a<<2)>>2]|0;v=c[b+(a<<2)>>2]|0;a:do{if(p){if(q){w=o;x=t;y=u;z=0}else{A=o;B=t;C=u;D=0;while(1){E=+g[B>>2];F=i*j*E;if(F<-1.0){G=-1.0}else{G=F>1.0?1.0:F}g[C>>2]=G;g[v+(A<<2)>>2]=E;H=A+1|0;I=H-((H|0)<(l|0)?0:l)|0;H=D+1|0;if((H|0)<(f|0)){A=I;B=B+4|0;C=C+4|0;D=H}else{J=I;break a}}}while(1){E=+g[x>>2];D=w+l|0;C=c[r>>2]|0;B=c[s>>2]|0;A=0;F=j*E;do{I=D-(c[C+(A<<2)>>2]|0)|0;F=F+ +g[v+(I-((I|0)<(l|0)?0:l)<<2)>>2]*+g[B+(A<<2)>>2];A=A+1|0;}while((A|0)<(k|0));K=i*F;if(K<-1.0){L=-1.0}else{L=K>1.0?1.0:K}g[y>>2]=L;g[v+(w<<2)>>2]=E;A=w+1|0;B=A-((A|0)<(l|0)?0:l)|0;A=z+1|0;if((A|0)<(f|0)){w=B;x=x+4|0;y=y+4|0;z=A}else{J=B;break}}}else{J=o}}while(0);v=a+1|0;if((v|0)<(h|0)){a=v}else{n=J;break}}c[m>>2]=n;return}function yt(a,d,e,f,h,i){a=a|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0.0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0.0,I=0.0,J=0,K=0;j=+g[a+8>>2];k=+g[a+4>>2];l=c[a+28>>2]|0;m=c[a+40>>2]|0;n=a+32|0;if((i|0)<=0){o=0;c[n>>2]=o;return}p=c[n>>2]|0;q=(h|0)>0;r=(l|0)>0;s=a+48|0;t=a+24|0;a=0;while(1){u=c[d+(a<<2)>>2]|0;if(q){v=p;w=c[e+(a<<2)>>2]|0;x=c[f+(a<<2)>>2]|0;y=0;while(1){z=b[w>>1]|0;A=k*+(z<<16>>16|0);if(r){B=v+m|0;C=c[s>>2]|0;D=c[t>>2]|0;E=0;F=A;while(1){G=B-(c[C+(E<<2)>>2]|0)|0;H=F+ +(b[u+(G-((G|0)<(m|0)?0:m)<<1)>>1]|0)*+g[D+(E<<2)>>2];G=E+1|0;if((G|0)<(l|0)){E=G;F=H}else{I=H;break}}}else{I=A}F=j*I;if(F<-32768.0){J=-32768}else{J=F>32767.0?32767:~~F}b[x>>1]=J;b[u+(v<<1)>>1]=z;E=v+1|0;D=E-((E|0)<(m|0)?0:m)|0;E=y+1|0;if((E|0)<(h|0)){v=D;w=w+2|0;x=x+2|0;y=E}else{K=D;break}}}else{K=p}y=a+1|0;if((y|0)<(i|0)){a=y}else{o=K;break}}c[n>>2]=o;return}function zt(a,b,d,e,f,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0.0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0.0,H=0.0,I=0,J=0;i=+g[a+8>>2];j=+g[a+4>>2];k=c[a+28>>2]|0;l=c[a+40>>2]|0;m=a+32|0;if((h|0)<=0){n=0;c[m>>2]=n;return}o=(f|0)>0;p=(k|0)>0;q=a+48|0;r=a+24|0;a=0;while(1){s=c[b+(a<<2)>>2]|0;t=c[m>>2]|0;if(o){u=t;v=c[d+(a<<2)>>2]|0;w=c[e+(a<<2)>>2]|0;x=0;while(1){y=c[v>>2]|0;z=j*+(y|0);if(p){A=u+l|0;B=c[q>>2]|0;C=c[r>>2]|0;D=0;E=z;while(1){F=A-(c[B+(D<<2)>>2]|0)|0;G=E+ +(c[s+(F-((F|0)<(l|0)?0:l)<<2)>>2]|0)*+g[C+(D<<2)>>2];F=D+1|0;if((F|0)<(k|0)){D=F;E=G}else{H=G;break}}}else{H=z}E=i*H;if(E<-2147483648.0){I=-2147483648}else{I=E>2147483647.0?2147483647:~~E}c[w>>2]=I;c[s+(u<<2)>>2]=y;D=u+1|0;C=D-((D|0)<(l|0)?0:l)|0;D=x+1|0;if((D|0)<(f|0)){u=C;v=v+4|0;w=w+4|0;x=D}else{J=C;break}}}else{J=t}x=a+1|0;if((x|0)<(h|0)){a=x}else{n=J;break}}c[m>>2]=n;return}function At(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;h=c[g+44>>2]|0;j=h;do{if((RCb(b)|0)==0){k=fi(a,c[b+76>>2]|0)|0;if((k|0)==0){l=-12;i=d;return l|0}else{NCb(k,c[e>>2]|0)|0;m=k;n=c[e>>2]|0;break}}else{m=b;n=b}}while(0);b=n+76|0;Se[c[h+64>>2]&511](j,c[h+36>>2]|0,c[n+64>>2]|0,c[m+64>>2]|0,c[b>>2]|0,c[a+148>>2]|0);j=n+136|0;k=c[j>>2]|0;o=c[j+4>>2]|0;j=c[b>>2]|0;c[f>>2]=1;c[f+4>>2]=c[a+48>>2];b=KDb(j,(j|0)<0|0?-1:0,f,a+56|0)|0;a=YGb(b,F,k,o)|0;o=h+56|0;c[o>>2]=a;c[o+4>>2]=F;if((n|0)!=(m|0)){JCb(e)}l=cj(c[c[g+32>>2]>>2]|0,m)|0;i=d;return l|0}function Bt(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;a=c[b+12>>2]|0;d=ZGb(-1,2147483647,a,(a|0)<0|0?-1:0)|0;a=F;e=b+16|0;b=c[e+4>>2]|0;return((a|0)<(b|0)|(a|0)==(b|0)&d>>>0<(c[e>>2]|0)>>>0?-22:0)|0}function Ct(a){a=a|0;var b=0,c=0,d=0;b=Ek()|0;do{if((b|0)==0){c=-12}else{Mk(a,b);d=xk(549960)|0;if((d|0)==0){c=-12;break}Ok(a,d);d=Dk()|0;if((d|0)==0){c=-12;break}Nk(a,d);c=0}}while(0);return c|0}function Dt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;h=c[g+44>>2]|0;j=c[c[g+32>>2]>>2]|0;g=c[b+76>>2]|0;k=b+136|0;b=c[k>>2]|0;l=c[k+4>>2]|0;c[f>>2]=1;c[f+4>>2]=c[j+48>>2];k=KDb(b,l,f,j+56|0)|0;f=F;l=h+4|0;if((c[l>>2]|0)==0){b=h+16|0;m=c[h+12>>2]|0;n=YGb(m,(m|0)<0|0?-1:0,c[b>>2]|0,c[b+4>>2]|0)|0;b=F;if((b|0)<(f|0)|(b|0)==(f|0)&n>>>0<k>>>0){o=4}}else{n=c[h+12>>2]|0;b=h+16|0;m=c[b>>2]|0;p=c[b+4>>2]|0;b=YGb(n,(n|0)<0|0?-1:0,k,f)|0;n=F;if((n|0)<(p|0)|(n|0)==(p|0)&b>>>0<m>>>0){o=4}}if((o|0)==4){q=cj(j,c[e>>2]|0)|0;i=d;return q|0}m=c[e>>2]|0;do{if((RCb(m)|0)==0){b=fi(a,g)|0;if((b|0)==0){q=-12;i=d;return q|0}else{NCb(b,c[e>>2]|0)|0;r=b;break}}else{r=m}}while(0);do{if((c[l>>2]|0)==0){m=YGb(k,f,g,(g|0)<0|0?-1:0)|0;a=F;b=h+16|0;p=c[b>>2]|0;n=c[b+4>>2]|0;if((a|0)<(n|0)|(a|0)==(n|0)&m>>>0<p>>>0){o=11;break}m=ZGb(k,f,p,n)|0;s=F;t=m;u=h+12|0;o=14}else{m=h+16|0;n=c[m>>2]|0;p=c[m+4>>2]|0;m=h+12|0;a=c[m>>2]|0;b=a;v=(a|0)<0|0?-1:0;a=YGb(b,v,n,p)|0;w=F;if((w|0)<(f|0)|(w|0)==(f|0)&a>>>0<k>>>0){o=11;break}a=ZGb(n,p,k,f)|0;p=YGb(a,F,b,v)|0;s=F;t=p;u=m;o=14}}while(0);if((o|0)==11){f=c[r+64>>2]|0;k=vCb(r)|0;GFb(f,0,g,k,c[r+80>>2]|0)|0}else if((o|0)==14){o=c[h+40>>2]|0;k=c[r+64>>2]|0;f=c[e>>2]|0;m=c[f+64>>2]|0;p=vCb(f)|0;Le[o&255](k,m,g,p,(c[l>>2]|0)!=0?-1:1,t,s,c[u>>2]|0,c[h+8>>2]|0)}if((c[e>>2]|0)!=(r|0)){JCb(e)}q=cj(j,r)|0;i=d;return q|0}function Et(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[(c[a+8>>2]|0)+44>>2]|0;switch(c[a+52>>2]|0){case 7:{c[b+40>>2]=20;break};case 6:{c[b+40>>2]=136;break};case 8:{c[b+40>>2]=26;break};case 4:{c[b+40>>2]=106;break};case 2:{c[b+40>>2]=44;break};case 1:{c[b+40>>2]=36;break};case 9:{c[b+40>>2]=160;break};case 3:{c[b+40>>2]=40;break};default:{}}d=b+24|0;e=c[d>>2]|0;f=c[d+4>>2]|0;if(!((e|0)==0&(f|0)==0)){d=c[a+48>>2]|0;g=IDb(e,f,d,(d|0)<0|0?-1:0,1e6,0)|0;c[b+12>>2]=g}g=b+32|0;d=c[g>>2]|0;f=c[g+4>>2]|0;if((d|0)==0&(f|0)==0){return 0}g=c[a+48>>2]|0;a=IDb(d,f,g,(g|0)<0|0?-1:0,1e6,0)|0;g=b+16|0;c[g>>2]=a;c[g+4>>2]=F;return 0}function Ft(a,b,d,e,f,g,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;var l=0,m=0.0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0;l=c[a>>2]|0;a=c[b>>2]|0;if((d|0)<=0){return}m=+(j|0);j=(e|0)>0;if((k|0)==1){b=0;n=0;while(1){o=ba(n,f)|0;p=YGb(o,(o|0)<0|0?-1:0,g,i)|0;q=(+(p>>>0)+ +(F|0)*4294967296.0)/m;if(q<1.0){r=q<0.0?0.0:q*3.141592653589793*.5}else{r=1.5707963267948966}q=+U(r);if(j){p=0;o=b;while(1){h[l+(o<<3)>>3]=q*+h[a+(o<<3)>>3];s=p+1|0;if((s|0)<(e|0)){p=s;o=o+1|0}else{break}}t=b+e|0}else{t=b}o=n+1|0;if((o|0)<(d|0)){b=t;n=o}else{break}}return}else{u=0;v=0}while(1){n=ba(v,f)|0;t=YGb(n,(n|0)<0|0?-1:0,g,i)|0;r=(+(t>>>0)+ +(F|0)*4294967296.0)/m;if(r<1.0){w=r<0.0?0.0:r}else{w=1.0}switch(k|0){case 6:{x=w*w;break};case 8:{x=+R(w);break};case 3:{x=(1.0- +T(w*3.141592653589793))*.5;break};case 7:{x=w*w*w;break};case 5:{r=1.0-w;x=1.0-r*r;break};case 9:{x=+sb(+w);break};case 2:{x=1.0- +T((+S(+(w*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 4:{x=+S(+.1,+((1.0-w)*5.0));break};default:{x=w}}if(j){t=0;n=u;while(1){h[l+(n<<3)>>3]=x*+h[a+(n<<3)>>3];b=t+1|0;if((b|0)<(e|0)){t=b;n=n+1|0}else{break}}y=u+e|0}else{y=u}n=v+1|0;if((n|0)<(d|0)){u=y;v=n}else{break}}return}function Gt(a,b,d,e,f,g,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;var l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0;if((d|0)<=0){return}l=+(j|0);j=(e|0)>0;m=0;do{n=ba(m,f)|0;o=YGb(n,(n|0)<0|0?-1:0,g,i)|0;p=(+(o>>>0)+ +(F|0)*4294967296.0)/l;if(p<1.0){q=p<0.0?0.0:p}else{q=1.0}switch(k|0){case 5:{p=1.0-q;r=1.0-p*p;break};case 4:{r=+S(+.1,+((1.0-q)*5.0));break};case 6:{r=q*q;break};case 1:{r=+U(q*3.141592653589793*.5);break};case 9:{r=+sb(+q);break};case 8:{r=+R(q);break};case 3:{r=(1.0- +T(q*3.141592653589793))*.5;break};case 7:{r=q*q*q;break};case 2:{r=1.0- +T((+S(+(q*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};default:{r=q}}if(j){o=0;do{h[(c[a+(o<<2)>>2]|0)+(m<<3)>>3]=r*+h[(c[b+(o<<2)>>2]|0)+(m<<3)>>3];o=o+1|0;}while((o|0)<(e|0))}m=m+1|0;}while((m|0)<(d|0));return}function Ht(a,b,d,e,f,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0.0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0,u=0;l=c[a>>2]|0;a=c[b>>2]|0;if((d|0)<=0){return}m=+(j|0);j=(e|0)>0;b=0;n=0;while(1){o=ba(n,f)|0;p=YGb(o,(o|0)<0|0?-1:0,h,i)|0;q=(+(p>>>0)+ +(F|0)*4294967296.0)/m;if(q<1.0){r=q<0.0?0.0:q}else{r=1.0}switch(k|0){case 2:{s=1.0- +T((+S(+(r*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 5:{q=1.0-r;s=1.0-q*q;break};case 7:{s=r*r*r;break};case 3:{s=(1.0- +T(r*3.141592653589793))*.5;break};case 4:{s=+S(+.1,+((1.0-r)*5.0));break};case 1:{s=+U(r*3.141592653589793*.5);break};case 6:{s=r*r;break};case 8:{s=+R(r);break};case 9:{s=+sb(+r);break};default:{s=r}}if(j){p=0;o=b;while(1){g[l+(o<<2)>>2]=s*+g[a+(o<<2)>>2];t=p+1|0;if((t|0)<(e|0)){p=t;o=o+1|0}else{break}}u=b+e|0}else{u=b}o=n+1|0;if((o|0)<(d|0)){b=u;n=o}else{break}}return}function It(a,b,d,e,f,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0;if((d|0)<=0){return}l=+(j|0);j=(e|0)>0;m=0;do{n=ba(m,f)|0;o=YGb(n,(n|0)<0|0?-1:0,h,i)|0;p=(+(o>>>0)+ +(F|0)*4294967296.0)/l;if(p<1.0){q=p<0.0?0.0:p}else{q=1.0}switch(k|0){case 4:{r=+S(+.1,+((1.0-q)*5.0));break};case 6:{r=q*q;break};case 9:{r=+sb(+q);break};case 8:{r=+R(q);break};case 3:{r=(1.0- +T(q*3.141592653589793))*.5;break};case 7:{r=q*q*q;break};case 2:{r=1.0- +T((+S(+(q*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 5:{p=1.0-q;r=1.0-p*p;break};case 1:{r=+U(q*3.141592653589793*.5);break};default:{r=q}}if(j){o=0;do{g[(c[a+(o<<2)>>2]|0)+(m<<2)>>2]=r*+g[(c[b+(o<<2)>>2]|0)+(m<<2)>>2];o=o+1|0;}while((o|0)<(e|0))}m=m+1|0;}while((m|0)<(d|0));return}function Jt(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0.0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0,u=0;l=c[a>>2]|0;a=c[d>>2]|0;if((e|0)<=0){return}m=+(j|0);j=(f|0)>0;d=0;n=0;while(1){o=ba(n,g)|0;p=YGb(o,(o|0)<0|0?-1:0,h,i)|0;q=(+(p>>>0)+ +(F|0)*4294967296.0)/m;if(q<1.0){r=q<0.0?0.0:q}else{r=1.0}switch(k|0){case 2:{s=1.0- +T((+S(+(r*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 3:{s=(1.0- +T(r*3.141592653589793))*.5;break};case 7:{s=r*r*r;break};case 9:{s=+sb(+r);break};case 4:{s=+S(+.1,+((1.0-r)*5.0));break};case 5:{q=1.0-r;s=1.0-q*q;break};case 1:{s=+U(r*3.141592653589793*.5);break};case 8:{s=+R(r);break};case 6:{s=r*r;break};default:{s=r}}if(j){p=0;o=d;while(1){b[l+(o<<1)>>1]=~~(s*+(b[a+(o<<1)>>1]|0));t=p+1|0;if((t|0)<(f|0)){p=t;o=o+1|0}else{break}}u=d+f|0}else{u=d}o=n+1|0;if((o|0)<(e|0)){d=u;n=o}else{break}}return}function Kt(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0;if((e|0)<=0){return}l=+(j|0);j=(f|0)>0;m=0;do{n=ba(m,g)|0;o=YGb(n,(n|0)<0|0?-1:0,h,i)|0;p=(+(o>>>0)+ +(F|0)*4294967296.0)/l;if(p<1.0){q=p<0.0?0.0:p}else{q=1.0}switch(k|0){case 5:{p=1.0-q;r=1.0-p*p;break};case 4:{r=+S(+.1,+((1.0-q)*5.0));break};case 7:{r=q*q*q;break};case 9:{r=+sb(+q);break};case 3:{r=(1.0- +T(q*3.141592653589793))*.5;break};case 8:{r=+R(q);break};case 2:{r=1.0- +T((+S(+(q*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 6:{r=q*q;break};case 1:{r=+U(q*3.141592653589793*.5);break};default:{r=q}}if(j){o=0;do{b[(c[a+(o<<2)>>2]|0)+(m<<1)>>1]=~~(r*+(b[(c[d+(o<<2)>>2]|0)+(m<<1)>>1]|0));o=o+1|0;}while((o|0)<(f|0))}m=m+1|0;}while((m|0)<(e|0));return}function Lt(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0,t=0;k=c[a>>2]|0;a=c[b>>2]|0;if((d|0)<=0){return}l=+(i|0);i=(e|0)>0;b=0;m=0;while(1){n=ba(m,f)|0;o=YGb(n,(n|0)<0|0?-1:0,g,h)|0;p=(+(o>>>0)+ +(F|0)*4294967296.0)/l;if(p<1.0){q=p<0.0?0.0:p}else{q=1.0}switch(j|0){case 2:{r=1.0- +T((+S(+(q*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 3:{r=(1.0- +T(q*3.141592653589793))*.5;break};case 7:{r=q*q*q;break};case 9:{r=+sb(+q);break};case 4:{r=+S(+.1,+((1.0-q)*5.0));break};case 5:{p=1.0-q;r=1.0-p*p;break};case 1:{r=+U(q*3.141592653589793*.5);break};case 8:{r=+R(q);break};case 6:{r=q*q;break};default:{r=q}}if(i){o=0;n=b;while(1){c[k+(n<<2)>>2]=~~(r*+(c[a+(n<<2)>>2]|0));s=o+1|0;if((s|0)<(e|0)){o=s;n=n+1|0}else{break}}t=b+e|0}else{t=b}n=m+1|0;if((n|0)<(d|0)){b=t;m=n}else{break}}return}function Mt(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0.0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0;if((d|0)<=0){return}k=+(i|0);i=(e|0)>0;l=0;do{m=ba(l,f)|0;n=YGb(m,(m|0)<0|0?-1:0,g,h)|0;o=(+(n>>>0)+ +(F|0)*4294967296.0)/k;if(o<1.0){p=o<0.0?0.0:o}else{p=1.0}switch(j|0){case 6:{q=p*p;break};case 5:{o=1.0-p;q=1.0-o*o;break};case 8:{q=+R(p);break};case 1:{q=+U(p*3.141592653589793*.5);break};case 4:{q=+S(+.1,+((1.0-p)*5.0));break};case 9:{q=+sb(+p);break};case 3:{q=(1.0- +T(p*3.141592653589793))*.5;break};case 7:{q=p*p*p;break};case 2:{q=1.0- +T((+S(+(p*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};default:{q=p}}if(i){n=0;do{c[(c[a+(n<<2)>>2]|0)+(l<<2)>>2]=~~(q*+(c[(c[b+(n<<2)>>2]|0)+(l<<2)>>2]|0));n=n+1|0;}while((n|0)<(e|0))}l=l+1|0;}while((l|0)<(d|0));return}function Nt(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[b+44>>2]|0;f=c[e+16>>2]|0;a:do{if((f|0)!=0){if((Vb(f|0,44)|0)==0){g=124}else{yDb(b,24,2160168,(h=i,i=i+8|0,c[h>>2]=2089352,h)|0);i=h;g=44}j=e+4|0;k=f;while(1){l=Vb(k|0,g|0)|0;if((l|0)==0){m=0}else{a[l]=0;m=l+1|0}l=xFb(k)|0;if((l|0)==-1){break}zk(j,l,(l|0)<0|0?-1:0)|0;if((m|0)==0){break a}else{k=m}}yDb(b,16,2037096,(h=i,i=i+8|0,c[h>>2]=k,h)|0);i=h;n=-22;i=d;return n|0}}while(0);m=c[e+20>>2]|0;b:do{if((m|0)!=0){if((Vb(m|0,44)|0)==0){o=124}else{yDb(b,24,2160168,(h=i,i=i+8|0,c[h>>2]=1992432,h)|0);i=h;o=44}g=e+8|0;f=m;while(1){j=Vb(f|0,o|0)|0;if((j|0)==0){p=0}else{a[j]=0;p=j+1|0}j=kb(f|0,0,0)|0;l=(j|0)>0?j:0;if((l|0)==0){break}zk(g,l,(l|0)<0|0?-1:0)|0;if((p|0)==0){break b}else{f=p}}yDb(b,16,1957960,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;n=-22;i=d;return n|0}}while(0);p=c[e+24>>2]|0;if((p|0)==0){n=0;i=d;return n|0}if((Vb(p|0,44)|0)==0){q=124}else{yDb(b,24,2160168,(h=i,i=i+8|0,c[h>>2]=1930192,h)|0);i=h;q=44}o=e+12|0;e=p;while(1){p=Vb(e|0,q|0)|0;if((p|0)==0){r=0}else{a[p]=0;r=p+1|0}p=fBb(e)|0;m=F;if((p|0)==0&(m|0)==0){break}Ak(o,p,m)|0;if((r|0)==0){n=0;s=28;break}else{e=r}}if((s|0)==28){i=d;return n|0}yDb(b,16,1908080,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;n=-22;i=d;return n|0}function Ot(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+44>>2]|0;d=c[b+4>>2]|0;if((d|0)==0){e=Bk(1)|0}else{e=d}Ok(a,e);e=c[b+8>>2]|0;if((e|0)==0){f=Dk()|0}else{f=e}Nk(a,f);f=c[b+12>>2]|0;if((f|0)!=0){g=f;Mk(a,g);return 0}g=Fk()|0;Mk(a,g);return 0}function Pt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=e+4|0;g=dEb(c[f>>2]|0,144)|0;c[e+140>>2]=g;if((g|0)==0){h=-12;i=b;return h|0}if((c[f>>2]|0)<=0){h=0;i=b;return h|0}g=d;e=d|0;j=d+4|0;k=d+36|0;l=a+24|0;m=a+12|0;n=a+16|0;o=a+20|0;a=0;while(1){p=vAb(1887216,(q=i,i=i+8|0,c[q>>2]=a,q)|0)|0;i=q;TGb(g|0,0,60)|0;c[e>>2]=p;c[j>>2]=1;c[k>>2]=866;if((p|0)==0){h=-12;r=6;break}Hi(a,l,12,m,n,d)|0;c[o>>2]=c[l>>2];p=a+1|0;if((p|0)<(c[f>>2]|0)){a=p}else{h=0;r=6;break}}if((r|0)==6){i=b;return h|0}return 0}function Qt(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;f=d|0;g=c[a+44>>2]|0;h=g+4|0;j=g+140|0;if((c[h>>2]|0)<=0){$Db(j);i=d;return}g=j;k=a+12|0;a=0;do{l=c[g>>2]|0;do{if((l|0)!=0){m=l+(a*144|0)+130|0;n=b[m>>1]|0;if(n<<16>>16==0){break}o=l+(a*144|0)+128|0;p=n;do{n=l+(a*144|0)+((e[o>>1]|0)<<2)|0;q=c[n>>2]|0;b[m>>1]=p-1;c[n>>2]=0;b[o>>1]=(b[o>>1]|0)+1&31;c[f>>2]=q;JCb(f);p=b[m>>1]|0;}while(!(p<<16>>16==0))}}while(0);l=c[k>>2]|0;if((l|0)!=0){$Db(l+(a*60|0)|0)}a=a+1|0;}while((a|0)<(c[h>>2]|0));$Db(j);i=d;return}function Rt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;b=i;i=i+648|0;d=b|0;e=b+256|0;f=b+520|0;g=c[a+44>>2]|0;h=g+4|0;j=c[h>>2]|0;a:do{if((j|0)>0){k=a+16|0;l=b+264|0;m=a;n=g+140|0;o=0;p=0;q=0;r=0;s=0;while(1){t=c[(c[(c[k>>2]|0)+(q<<2)>>2]|0)+80>>2]|0;if((t|0)==0){u=6;break}v=c[t+4>>2]|0;if((v|0)==0){u=6;break}w=c[t>>2]|0;t=c[w>>2]|0;x=c[w+4>>2]|0;w=d+(q<<3)|0;c[w>>2]=t;c[w+4>>2]=x;if((v|0)>1){iBb(l,256,0,t,x);v=q+1|0;yDb(m,32,2089280,(y=i,i=i+16|0,c[y>>2]=l,c[y+8>>2]=v,y)|0);i=y;z=v}else{z=q+1|0}v=hBb(t,x)|0;c[(c[n>>2]|0)+(q*144|0)+132>>2]=v;A=(((t&p|0)!=0|(x&o|0)!=0)&1)+r|0;B=t|p;C=x|o;D=v+s|0;E=c[h>>2]|0;if((z|0)<(E|0)){o=C;p=B;q=z;r=A;s=D}else{break}}if((u|0)==6){yDb(m,24,2160104,(y=i,i=i+8|0,c[y>>2]=q+1,y)|0);i=y;G=-11;i=b;return G|0}if((D|0)>32){yDb(a,16,2037056,(y=i,i=i+8|0,c[y>>2]=32,y)|0);i=y;G=-22;i=b;return G|0}if((A|0)==0){s=g+8|0;c[f>>2]=s;if((E|0)<=1){H=0;I=0;J=E;K=C;L=B;u=22;break}r=c[g+140>>2]|0;p=1;o=s;while(1){s=o+(c[r+((p-1|0)*144|0)+132>>2]<<2)|0;c[f+(p<<2)>>2]=s;n=p+1|0;if((n|0)<(E|0)){p=n;o=s}else{H=0;I=0;J=E;K=C;L=B;u=22;break a}}}yDb(a,24,1992320,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;if((D|0)>0){o=g+8|0;p=0;do{c[o+(p<<2)>>2]=p;p=p+1|0;}while((p|0)<(D|0))}p=jBb(D)|0;o=F;if(!((p|0)==0&(o|0)==0)){M=o;N=p;break}p=_Gb(1,0,D|0)|0;o=YGb(p,F,-1,-1)|0;M=F;N=o}else{c[f>>2]=g+8;H=0;I=0;J=j;K=0;L=0;u=22}}while(0);if((u|0)==22){while(1){u=0;if((J|0)>0){j=_Gb(1,0,H|0)|0;g=F;D=0;y=I;B=J;while(1){C=d+(D<<3)|0;if((c[C>>2]&j|0)==0&(c[C+4>>2]&g|0)==0){O=y;P=B}else{C=f+(D<<2)|0;E=c[C>>2]|0;c[C>>2]=E+4;c[E>>2]=y;O=y+1|0;P=c[h>>2]|0}E=D+1|0;if((E|0)<(P|0)){D=E;y=O;B=P}else{Q=O;R=P;break}}}else{Q=I;R=J}B=H+1|0;if((B|0)<64){H=B;I=Q;J=R;K=K;L=L;u=22}else{M=K;N=L;break}}}Ok(a,xk(1166776)|0);L=(c[h>>2]|0)>0;c[e>>2]=0;if(L){L=a+16|0;K=0;do{u=d+(K<<3)|0;Ak(e,c[u>>2]|0,c[u+4>>2]|0)|0;Gk(c[e>>2]|0,(c[(c[L>>2]|0)+(K<<2)>>2]|0)+84|0);K=K+1|0;u=(K|0)<(c[h>>2]|0);c[e>>2]=0}while(u)}Ak(e,N,M)|0;Gk(c[e>>2]|0,(c[c[a+32>>2]>>2]|0)+80|0);Nk(a,Dk()|0);G=0;i=b;return G|0}function St(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;h=i;i=i+272|0;j=h|0;k=h+8|0;l=h+136|0;m=h+264|0;c[j>>2]=g;n=c[f+8>>2]|0;o=c[n+44>>2]|0;p=n+32|0;q=c[c[p>>2]>>2]|0;r=n+16|0;s=o+4|0;t=c[s>>2]|0;u=0;while(1){if((u|0)>=(t|0)){break}if((c[(c[r>>2]|0)+(u<<2)>>2]|0)==(f|0)){break}else{u=u+1|0}}f=o+140|0;t=c[f>>2]|0;v=t+(u*144|0)+130|0;if((b[v>>1]|0)==32){JCb(j);w=-12;i=h;return w|0}y=PCb(g)|0;g=b[v>>1]|0;if(g<<16>>16==32){yDb(n,24,2345176,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;n=t+(u*144|0)+128|0;A=e[n>>1]|0;B=(b[v>>1]|0)-1&65535;b[v>>1]=B;JCb(t+(u*144|0)+(((B&65535)+A&31)<<2)|0);C=b[v>>1]|0;D=n}else{C=g;D=t+(u*144|0)+128|0}g=e[D>>1]|0;b[v>>1]=C+1;c[t+(u*144|0)+((g+(C&65535)&31)<<2)>>2]=y;y=(c[f>>2]|0)+(u*144|0)+136|0;c[y>>2]=(c[y>>2]|0)+(c[(c[j>>2]|0)+76>>2]|0);JCb(j);j=c[f>>2]|0;y=c[j+136>>2]|0;u=c[s>>2]|0;if((u|0)>1){C=y;g=1;while(1){t=c[j+(g*144|0)+136>>2]|0;v=(C|0)>(t|0)?t:C;t=g+1|0;if((t|0)<(u|0)){C=v;g=t}else{E=v;break}}}else{E=y}if((E|0)==0){w=0;i=h;return w|0}y=fi(c[c[p>>2]>>2]|0,E)|0;if((y|0)==0){w=-12;i=h;return w|0}g=c[y>>2]|0;C=c[s>>2]|0;if((C|0)>0){u=c[o+136>>2]|0;j=0;v=c[f>>2]|0;do{if((b[v+(j*144|0)+130>>1]|0)==0){G=0}else{G=c[v+(j*144|0)+((b[v+(j*144|0)+128>>1]&31)<<2)>>2]|0}c[k+(j<<2)>>2]=G;v=c[f>>2]|0;c[l+(j<<2)>>2]=(c[G>>2]|0)+(ba(ba(c[v+(j*144|0)+132>>2]|0,c[v+(j*144|0)+140>>2]|0)|0,u)|0);j=j+1|0;}while((j|0)<(C|0))}C=c[k>>2]|0;NCb(y,C)|0;j=C+136|0;C=c[j>>2]|0;u=c[j+4>>2]|0;if((C|0)==0&(u|0)==(-2147483648|0)){H=-2147483648;I=0}else{j=c[(c[f>>2]|0)+140>>2]|0;v=c[(c[c[r>>2]>>2]|0)+48>>2]|0;c[m>>2]=1;c[m+4>>2]=v;v=KDb(j,(j|0)<0|0?-1:0,m,(c[c[p>>2]>>2]|0)+56|0)|0;m=YGb(v,F,C,u)|0;H=F;I=m}m=y+136|0;c[m>>2]=I;c[m+4>>2]=H;c[y+76>>2]=E;H=q+40|0;m=c[H+4>>2]|0;I=y+352|0;c[I>>2]=c[H>>2];c[I+4>>2]=m;wCb(y,c[q+148>>2]|0);q=o+136|0;m=o+8|0;o=g;g=E;E=c[s>>2]|0;a:while(1){I=(E|0)>0;if(I){H=c[f>>2]|0;u=g;C=0;while(1){v=(c[(c[k+(C<<2)>>2]|0)+76>>2]|0)-(c[H+(C*144|0)+140>>2]|0)|0;j=(u|0)>(v|0)?v:u;v=C+1|0;if((v|0)<(E|0)){u=j;C=v}else{J=j;break}}}else{J=g}C=c[q>>2]|0;do{if((C|0)==1){u=c[f>>2]|0;if(I){H=0;j=0;while(1){v=(c[u+(H*144|0)+132>>2]|0)+j|0;r=H+1|0;if((r|0)<(E|0)){H=r;j=v}else{K=v;break}}}else{K=0}if((J|0)==0){L=o;break}j=ba(K,J)|0;if(I){M=J;N=o}else{L=o+j|0;break}while(1){H=M-1|0;v=m;r=0;while(1){G=u+(r*144|0)+132|0;if((c[G>>2]|0)>0){t=l+(r<<2)|0;D=v;n=1;A=c[t>>2]|0;while(1){B=D+4|0;a[N+(c[D>>2]|0)|0]=a[A]|0;O=(c[t>>2]|0)+1|0;c[t>>2]=O;if((n|0)<(c[G>>2]|0)){D=B;n=n+1|0;A=O}else{P=B;break}}}else{P=v}A=r+1|0;if((A|0)<(E|0)){v=P;r=A}else{break}}if((H|0)==0){break}else{M=H;N=N+K|0}}L=o+j|0}else if((C|0)==2){u=c[f>>2]|0;if(I){r=0;v=0;do{v=(c[u+(r*144|0)+132>>2]|0)+v|0;r=r+1|0;}while((r|0)<(E|0));Q=v<<1}else{Q=0}if((J|0)==0){L=o;break}r=ba(Q,J)|0;if(I){R=J;S=o}else{L=o+r|0;break}while(1){j=R-1|0;A=m;n=0;while(1){D=u+(n*144|0)+132|0;if((c[D>>2]|0)>0){G=l+(n<<2)|0;t=A;B=1;O=c[G>>2]|0;while(1){T=t+4|0;U=O;V=S+(c[t>>2]<<1)|0;x=(d[U]|d[U+1|0]<<8)<<16>>16;a[V]=x;x=x>>8;a[V+1|0]=x;V=(c[G>>2]|0)+2|0;c[G>>2]=V;if((B|0)<(c[D>>2]|0)){t=T;B=B+1|0;O=V}else{W=T;break}}}else{W=A}O=n+1|0;if((O|0)<(E|0)){A=W;n=O}else{break}}if((j|0)==0){break}else{R=j;S=S+Q|0}}L=o+r|0}else if((C|0)==4){u=c[f>>2]|0;if(I){v=0;n=0;do{n=(c[u+(v*144|0)+132>>2]|0)+n|0;v=v+1|0;}while((v|0)<(E|0));X=n<<2}else{X=0}if((J|0)==0){L=o;break}v=ba(X,J)|0;if(I){Y=J;Z=o}else{L=o+v|0;break}while(1){r=Y-1|0;A=m;H=0;while(1){O=u+(H*144|0)+132|0;if((c[O>>2]|0)>0){B=l+(H<<2)|0;t=A;D=1;G=c[B>>2]|0;while(1){T=t+4|0;V=G;U=Z+(c[t>>2]<<2)|0;x=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=(c[B>>2]|0)+4|0;c[B>>2]=U;if((D|0)<(c[O>>2]|0)){t=T;D=D+1|0;G=U}else{_=T;break}}}else{_=A}G=H+1|0;if((G|0)<(E|0)){A=_;H=G}else{break}}if((r|0)==0){break}else{Y=r;Z=Z+X|0}}L=o+v|0}else{u=c[f>>2]|0;if(I){n=0;H=0;while(1){A=(c[u+(n*144|0)+132>>2]|0)+H|0;j=n+1|0;if((j|0)<(E|0)){n=j;H=A}else{$=A;break}}}else{$=0}if((J|0)==0){L=o;break}H=ba($,C)|0;n=ba(ba($,J)|0,C)|0;if(I){aa=J;ca=o}else{L=o+n|0;break}while(1){v=aa-1|0;A=m;j=0;while(1){G=u+(j*144|0)+132|0;if((c[G>>2]|0)>0){D=l+(j<<2)|0;t=A;O=1;B=c[D>>2]|0;while(1){T=t+4|0;UGb(ca+(ba(c[t>>2]|0,C)|0)|0,B|0,C)|0;U=(c[D>>2]|0)+C|0;c[D>>2]=U;if((O|0)<(c[G>>2]|0)){t=T;O=O+1|0;B=U}else{da=T;break}}}else{da=A}B=j+1|0;if((B|0)<(E|0)){A=da;j=B}else{break}}if((v|0)==0){break}else{aa=v;ca=ca+H|0}}L=o+n|0}}while(0);C=g-J|0;I=c[s>>2]|0;if((I|0)>0){H=0;while(1){u=c[f>>2]|0;j=u+(H*144|0)+136|0;c[j>>2]=(c[j>>2]|0)-J;j=u+(H*144|0)+140|0;u=(c[j>>2]|0)+J|0;c[j>>2]=u;A=k+(H<<2)|0;if((u|0)==(c[(c[A>>2]|0)+76>>2]|0)){c[j>>2]=0;JCb(A);j=c[f>>2]|0;u=j+(H*144|0)+128|0;r=j+(H*144|0)+130|0;B=b[r>>1]|0;if(B<<16>>16==0){ea=79;break a}O=j+(H*144|0)+(e[u>>1]<<2)|0;b[r>>1]=B-1;c[O>>2]=0;b[u>>1]=(b[u>>1]|0)+1&31;u=c[f>>2]|0;do{if((b[u+(H*144|0)+130>>1]|0)==0){c[A>>2]=0;fa=0}else{O=c[u+(H*144|0)+((b[u+(H*144|0)+128>>1]&31)<<2)>>2]|0;c[A>>2]=O;if((O|0)==0){fa=0;break}fa=c[O>>2]|0}}while(0);c[l+(H<<2)>>2]=fa}A=H+1|0;u=c[s>>2]|0;if((A|0)<(u|0)){H=A}else{ga=u;break}}}else{ga=I}if((g|0)==(J|0)){break}else{o=L;g=C;E=ga}}if((ea|0)==79){yDb(0,0,1957928,(z=i,i=i+24|0,c[z>>2]=1930168,c[z+8>>2]=1908048,c[z+16>>2]=101,z)|0);i=z;Cd();return 0}w=cj(c[c[p>>2]>>2]|0,y)|0;i=h;return w|0}function Tt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a>>2]|0;a=c[b+44>>2]|0;d=b+16|0;b=a+4|0;e=c[b>>2]|0;if((e|0)<=0){f=0;return f|0}g=a+140|0;a=0;h=e;while(1){if((c[(c[g>>2]|0)+(a*144|0)+136>>2]|0)==0){e=Ni(c[(c[d>>2]|0)+(a<<2)>>2]|0)|0;if((e|0)<0){f=e;i=7;break}j=c[b>>2]|0}else{j=h}e=a+1|0;if((e|0)<(j|0)){a=e;h=j}else{f=0;i=7;break}}if((i|0)==7){return f|0}return 0}function Ut(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+1024|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=f+4|0;h=c[g>>2]|0;j=e+16|0;k=1;while(1){if((k|0)>=(h|0)){break}l=c[j>>2]|0;m=c[(c[l+(k<<2)>>2]|0)+48>>2]|0;n=c[(c[l>>2]|0)+48>>2]|0;if((m|0)==(n|0)){k=k+1|0}else{o=4;break}}if((o|0)==4){yDb(e,16,2267608,(p=i,i=i+24|0,c[p>>2]=m,c[p+8>>2]=k,c[p+16>>2]=n,p)|0);i=p;q=-22;i=b;return q|0}n=e+32|0;c[f+136>>2]=BFb(c[(c[c[n>>2]>>2]|0)+52>>2]|0)|0;f=c[c[j>>2]>>2]|0;c[a+48>>2]=c[f+48>>2];k=f+56|0;f=a+56|0;a=c[k+4>>2]|0;c[f>>2]=c[k>>2];c[f+4>>2]=a;IAb(d,0,1);if((c[g>>2]|0)>0){a=0;do{KAb(d,2252232,(p=i,i=i+16|0,c[p>>2]=(a|0)!=0?2238192:9203496,c[p+8>>2]=a,p)|0);i=p;f=(c[(c[j>>2]|0)+(a<<2)>>2]|0)+40|0;gBb(d,-1,c[f>>2]|0,c[f+4>>2]|0);a=a+1|0;}while((a|0)<(c[g>>2]|0))}KAb(d,2215440,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;g=(c[c[n>>2]>>2]|0)+40|0;gBb(d,-1,c[g>>2]|0,c[g+4>>2]|0);yDb(e,40,2205448,(p=i,i=i+8|0,c[p>>2]=c[d>>2],p)|0);i=p;q=0;i=b;return q|0}function Vt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+96|0;d=b+32|0;e=c[a+44>>2]|0;f=e+40|0;if((c[f>>2]|0)<=0){g=e+4|0;h=g;fCb(h,0);i=b;return 0}j=d;k=b|0;l=d+4|0;m=d|0;n=d+36|0;o=a+24|0;p=a+12|0;q=a+16|0;r=a+20|0;a=0;do{TGb(j|0,0,60)|0;Lb(k|0,32,2160008,(s=i,i=i+8|0,c[s>>2]=a,s)|0)|0;i=s;c[l>>2]=1;c[m>>2]=eEb(k)|0;c[n>>2]=502;Hi(a,o,12,p,q,d)|0;c[r>>2]=c[o>>2];a=a+1|0;}while((a|0)<(c[f>>2]|0));g=e+4|0;h=g;fCb(h,0);i=b;return 0}function Wt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+44>>2]|0;d=b+68|0;e=d;f=c[e>>2]|0;if((f|0)!=0){g=b+40|0;a:do{if((c[g>>2]|0)>0){h=0;i=f;while(1){jAb(c[i+(h<<2)>>2]|0);j=h+1|0;if((j|0)>=(c[g>>2]|0)){break a}h=j;i=c[e>>2]|0}}}while(0);$Db(d)}d=b+96|0;e=c[d>>2]|0;if((e|0)!=0){g=e+8|0;f=c[g>>2]|0;if((f|0)!=0){i=f;do{c[g>>2]=c[i+16>>2];ZDb(i);i=c[g>>2]|0;}while((i|0)!=0)}c[e>>2]=0;c[e+4>>2]=0;c[e+12>>2]=0}$Db(d);$Db(b+72|0);$Db(b+76|0);b=a+24|0;if((c[b>>2]|0)==0){return}d=a+12|0;a=0;do{$Db((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function Xt(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=0;zk(d,3,0)|0;zk(d,8,0)|0;Ok(a,c[d>>2]|0);Mk(a,Ek()|0);Nk(a,Dk()|0);i=b;return 0}function Yt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=c[c[f+32>>2]>>2]|0;j=f+16|0;k=c[f+24>>2]|0;l=0;while(1){if(!(l>>>0<k>>>0)){m=4;break}if((c[(c[j>>2]|0)+(l<<2)>>2]|0)==(a|0)){break}else{l=l+1|0}}if((m|0)==4){yDb(f,16,2089152,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;JCb(e);i=d;return o|0}if((l|0)==0){f=b+136|0;m=KDb(c[f>>2]|0,c[f+4>>2]|0,a+56|0,h+56|0)|0;h=F;a=c[g+96>>2]|0;f=c[(c[e>>2]|0)+76>>2]|0;j=WDb(24)|0;k=j;if((j|0)==0){o=-12;JCb(e);i=d;return o|0}c[j>>2]=f;p=j+8|0;c[p>>2]=m;c[p+4>>2]=h;c[j+16>>2]=0;j=a+8|0;do{if((c[j>>2]|0)==0){c[j>>2]=k;c[a+12>>2]=k}else{h=a+12|0;p=c[h>>2]|0;if((p|0)==0){yDb(0,0,2036976,(n=i,i=i+24|0,c[n>>2]=1992240,c[n+8>>2]=1957808,c[n+16>>2]=145,n)|0);i=n;Cd();return 0}else{c[p+16>>2]=k;c[h>>2]=k;break}}}while(0);k=a|0;c[k>>2]=(c[k>>2]|0)+1;k=a+4|0;c[k>>2]=(c[k>>2]|0)+f;q=c[e>>2]|0}else{q=b}o=mAb(c[(c[g+68>>2]|0)+(l<<2)>>2]|0,c[q+64>>2]|0,c[q+76>>2]|0)|0;JCb(e);i=d;return o|0}function Zt(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;d=i;e=c[b>>2]|0;f=c[e+44>>2]|0;g=f+40|0;h=c[g>>2]|0;if((h|0)<=0){c[f+44>>2]=0;j=-541478725;i=d;return j|0}k=f+72|0;l=c[k>>2]|0;m=0;n=0;do{n=((a[l+m|0]|0)!=0)+n|0;m=m+1|0;}while((m|0)<(h|0));m=f+44|0;c[m>>2]=n;if((n|0)==0){j=-541478725;i=d;return j|0}o=f+48|0;p=c[o>>2]|0;do{if((p|0)==1){if((n|0)==(h|0)){q=9;break}else{j=-541478725}i=d;return j|0}else if((p|0)==2){if((a[l]|0)==0){j=-541478725}else{break}i=d;return j|0}else{q=9}}while(0);do{if((q|0)==9){if((a[l]|0)!=0){break}p=$t(e,1)|0;if((p|0)<0){j=p;i=d;return j|0}p=c[g>>2]|0;if((p|0)<=0){c[m>>2]=0;j=-541478725;i=d;return j|0}h=c[k>>2]|0;n=0;r=0;do{r=((a[h+n|0]|0)!=0)+r|0;n=n+1|0;}while((n|0)<(p|0));c[m>>2]=r;if((r|0)==0){j=-541478725;i=d;return j|0}n=c[o>>2]|0;do{if((n|0)==1){if((r|0)==(p|0)){break}else{j=-541478725}i=d;return j|0}else if((n|0)==2){if((a[h]|0)==0){j=-541478725}else{break}i=d;return j|0}}while(0);if((p|0)<=1){yDb(0,0,2036976,(s=i,i=i+24|0,c[s>>2]=2162448,c[s+8>>2]=1957808,c[s+16>>2]=325,s)|0);i=s;Cd();return 0}n=f+68|0;r=1;t=2147483647;u=p;v=h;while(1){if((a[v+r|0]|0)==0){w=t;x=u}else{y=oAb(c[(c[n>>2]|0)+(r<<2)>>2]|0)|0;w=(t|0)>(y|0)?y:t;x=c[g>>2]|0}y=r+1|0;if((y|0)>=(x|0)){break}r=y;t=w;u=x;v=c[k>>2]|0}v=(w|0)==2147483647?0:w;if((v|0)==0){j=-11;i=d;return j|0}j=au(b,v)|0;i=d;return j|0}}while(0);w=f+96|0;x=c[w>>2]|0;l=c[x>>2]|0;do{if((l|0)==0){v=Ni(c[c[e+16>>2]>>2]|0)|0;if((v|0)==-541478725){a[c[k>>2]|0]=0;j=(c[g>>2]|0)==1?-541478725:-11;i=d;return j|0}if((v|0)<0){j=v;i=d;return j|0}else{v=c[w>>2]|0;z=v;A=c[v>>2]|0;break}}else{z=x;A=l}}while(0);if((A|0)<=0){yDb(0,0,2036976,(s=i,i=i+24|0,c[s>>2]=2186944,c[s+8>>2]=1957808,c[s+16>>2]=425,s)|0);i=s;Cd();return 0}A=c[z+8>>2]|0;if((A|0)==0){B=0}else{B=c[A>>2]|0}do{if((c[m>>2]|0)>1){A=$t(e,B)|0;if((A|0)<0){j=A;i=d;return j|0}A=c[g>>2]|0;if((A|0)<=0){c[m>>2]=0;j=-541478725;i=d;return j|0}z=c[k>>2]|0;l=0;x=0;do{x=((a[z+l|0]|0)!=0)+x|0;l=l+1|0;}while((l|0)<(A|0));c[m>>2]=x;if((x|0)==0){j=-541478725;i=d;return j|0}l=c[o>>2]|0;do{if((l|0)==2){if((a[z]|0)==0){j=-541478725}else{break}i=d;return j|0}else if((l|0)==1){if((x|0)==(A|0)){break}else{j=-541478725}i=d;return j|0}}while(0);if((x|0)<=1){C=B;break}if((A|0)<=1){yDb(0,0,2036976,(s=i,i=i+24|0,c[s>>2]=2162448,c[s+8>>2]=1957808,c[s+16>>2]=325,s)|0);i=s;Cd();return 0}l=f+68|0;v=1;u=2147483647;t=A;r=z;while(1){if((a[r+v|0]|0)==0){D=u;E=t}else{n=oAb(c[(c[l>>2]|0)+(v<<2)>>2]|0)|0;D=(u|0)>(n|0)?n:u;E=c[g>>2]|0}n=v+1|0;if((n|0)>=(E|0)){break}v=n;u=D;t=E;r=c[k>>2]|0}r=(D|0)==2147483647?0:D;if((r|0)==0){j=-11;i=d;return j|0}else{C=(r|0)>(B|0)?B:r;break}}else{C=B}}while(0);B=c[w>>2]|0;w=B+8|0;D=c[w>>2]|0;k=(D|0)==0;if(k){G=-2147483648;H=0}else{E=D+8|0;G=c[E+4>>2]|0;H=c[E>>2]|0}E=f+88|0;c[E>>2]=H;c[E+4>>2]=G;G=B+4|0;a:do{if((c[G>>2]|0)>(C|0)){if((C|0)<=0){break}E=B+12|0;H=B|0;f=C;g=D;while(1){if((g|0)==0){q=66;break}I=g|0;J=c[I>>2]|0;if((J|0)>(f|0)){q=70;break}o=f-J|0;m=c[g+16>>2]|0;c[w>>2]=m;if((m|0)==0){c[E>>2]=0}c[H>>2]=(c[H>>2]|0)-1;c[G>>2]=(c[G>>2]|0)-(c[I>>2]|0);ZDb(g);if((o|0)<=0){break a}f=o;g=c[w>>2]|0}if((q|0)==66){yDb(0,0,2036976,(s=i,i=i+24|0,c[s>>2]=2171304,c[s+8>>2]=1957808,c[s+16>>2]=113,s)|0);i=s;Cd();return 0}else if((q|0)==70){c[I>>2]=J-f;H=g+8|0;E=YGb(c[H>>2]|0,c[H+4>>2]|0,f,(f|0)<0|0?-1:0)|0;c[H>>2]=E;c[H+4>>2]=F;c[G>>2]=(c[G>>2]|0)-f;break}}else{if(!k){H=D;do{c[w>>2]=c[H+16>>2];ZDb(H);H=c[w>>2]|0;}while((H|0)!=0)}c[B>>2]=0;c[G>>2]=0;c[B+12>>2]=0}}while(0);j=au(b,C)|0;i=d;return j|0}function _t(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+64|0;e=d|0;f=c[b>>2]|0;h=c[f+44>>2]|0;j=b+52|0;c[h+64>>2]=CFb(c[j>>2]|0)|0;k=b+48|0;c[h+60>>2]=c[k>>2];l=c[k>>2]|0;c[b+56>>2]=1;c[b+60>>2]=l;l=h+88|0;c[l>>2]=0;c[l+4>>2]=-2147483648;l=cEb(16)|0;c[h+96>>2]=l;if((l|0)==0){m=-12;i=d;return m|0}l=h+40|0;n=cEb(c[l>>2]<<2)|0;o=h+68|0;c[o>>2]=n;if((n|0)==0){m=-12;i=d;return m|0}n=b+40|0;b=h+56|0;c[b>>2]=hBb(c[n>>2]|0,c[n+4>>2]|0)|0;p=0;while(1){q=c[l>>2]|0;if((p|0)>=(q|0)){break}r=kAb(c[j>>2]|0,c[b>>2]|0,1024)|0;c[(c[o>>2]|0)+(p<<2)>>2]=r;if((c[(c[o>>2]|0)+(p<<2)>>2]|0)==0){m=-12;s=15;break}else{p=p+1|0}}if((s|0)==15){i=d;return m|0}s=WDb(q)|0;q=h+72|0;c[q>>2]=s;if((s|0)==0){m=-12;i=d;return m|0}TGb(s|0,1,c[l>>2]|0)|0;s=c[l>>2]|0;p=h+44|0;c[p>>2]=s;o=cEb(s<<2)|0;s=o;c[h+76>>2]=s;if((o|0)==0){m=-12;i=d;return m|0}o=h+80|0;g[o>>2]=+(c[p>>2]|0);p=c[l>>2]|0;if((p|0)>0){h=c[q>>2]|0;q=0;do{if((a[h+q|0]|0)==1){g[s+(q<<2)>>2]=1.0/+g[o>>2]}else{g[s+(q<<2)>>2]=0.0}q=q+1|0;}while((q|0)<(p|0))}p=e|0;iBb(p,64,-1,c[n>>2]|0,c[n+4>>2]|0);n=c[l>>2]|0;l=wFb(c[j>>2]|0)|0;j=c[k>>2]|0;yDb(f,40,2197856,(f=i,i=i+32|0,c[f>>2]=n,c[f+8>>2]=l,c[f+16>>2]=j,c[f+24>>2]=p,f)|0);i=f;m=0;i=d;return m|0}function $t(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[b+44>>2]|0;g=f+40|0;if((c[g>>2]|0)<=1){yDb(0,0,2036976,(h=i,i=i+24|0,c[h>>2]=2162448,c[h+8>>2]=1957808,c[h+16>>2]=347,h)|0);i=h;Cd();return 0}h=f+72|0;j=f+68|0;f=b+16|0;b=1;a:while(1){b:do{if((a[(c[h>>2]|0)+b|0]|0)!=0){k=0;while(1){if((k|0)==(-541478725|0)){break}else if((k|0)!=0){l=10;break}if((oAb(c[(c[j>>2]|0)+(b<<2)>>2]|0)|0)>=(d|0)){break b}k=Ni(c[(c[f>>2]|0)+(b<<2)>>2]|0)|0}if((l|0)==10){l=0;if((k|0)<0){m=k;l=12;break a}else{break}}if((oAb(c[(c[j>>2]|0)+(b<<2)>>2]|0)|0)!=0){break}a[(c[h>>2]|0)+b|0]=0}}while(0);n=b+1|0;if((n|0)<(c[g>>2]|0)){b=n}else{m=0;l=12;break}}if((l|0)==12){i=e;return m|0}return 0}function au(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+16|0;f=e|0;h=e+8|0;j=c[(c[b>>2]|0)+44>>2]|0;k=j+80|0;l=+g[k>>2];m=+(c[j+44>>2]|0);if(l>m){n=l- +(d|0)/(+g[j+52>>2]*+(c[j+60>>2]|0));g[k>>2]=n>m?n:m}o=j+40|0;p=c[o>>2]|0;if((p|0)>0){q=j+76|0;r=c[j+72>>2]|0;s=0;do{if((a[r+s|0]|0)==1){g[(c[q>>2]|0)+(s<<2)>>2]=1.0/+g[k>>2]}else{g[(c[q>>2]|0)+(s<<2)>>2]=0.0}s=s+1|0;}while((s|0)<(p|0))}p=fi(b,d)|0;c[f>>2]=p;if((p|0)==0){t=-12;i=e;return t|0}p=fi(b,d)|0;c[h>>2]=p;if((p|0)==0){JCb(f);t=-12;i=e;return t|0}p=c[o>>2]|0;if((p|0)>0){s=j+72|0;q=j+68|0;k=j+64|0;r=j+56|0;u=j+8|0;v=j+76|0;w=0;x=p;while(1){if((a[(c[s>>2]|0)+w|0]|0)==1){pAb(c[(c[q>>2]|0)+(w<<2)>>2]|0,c[(c[h>>2]|0)+64>>2]|0,d)|0;p=c[r>>2]|0;if((c[k>>2]|0)==0){y=1;z=ba(p,d)|0;A=18}else{if((p|0)>0){y=p;z=d;A=18}}if((A|0)==18){A=0;p=z+15&-16;B=0;do{te[c[u>>2]&7](c[(c[(c[f>>2]|0)+64>>2]|0)+(B<<2)>>2]|0,c[(c[(c[h>>2]|0)+64>>2]|0)+(B<<2)>>2]|0,+g[(c[v>>2]|0)+(w<<2)>>2],p);B=B+1|0;}while((B|0)<(y|0))}C=c[o>>2]|0}else{C=x}B=w+1|0;if((B|0)<(C|0)){w=B;x=C}else{break}}}JCb(h);h=j+88|0;j=c[h+4>>2]|0;C=c[f>>2]|0;f=C+136|0;c[f>>2]=c[h>>2];c[f+4>>2]=j;j=c[h>>2]|0;f=c[h+4>>2]|0;if(!((j|0)==0&(f|0)==(-2147483648|0))){x=YGb(j,f,d,(d|0)<0|0?-1:0)|0;c[h>>2]=x;c[h+4>>2]=F}t=cj(b,C)|0;i=e;return t|0}function bu(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+44>>2]|0;e=d+8|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=d+32|0;if((c[e>>2]|0)==0&(c[e+4>>2]|0)==0){f=0;i=b;return f|0}e=d+24|0;if((c[e>>2]|0)==0&(c[e+4>>2]|0)==0){f=0;i=b;return f|0}yDb(a,16,2159880,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-22;i=b;return f|0}function cu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=Ni(c[c[e+16>>2]>>2]|0)|0;if(!((g|0)==-541478725)){h=g;i=b;return h|0}if((c[e+76>>2]|0)!=0){h=-541478725;i=b;return h|0}e=c[f+16>>2]|0;g=f+32|0;j=c[g>>2]|0;k=c[g+4>>2]|0;l=0;m=f+24|0;if((k|0)>(l|0)|(k|0)==(l|0)&j>>>0>0>>>0){c[m>>2]=j;c[m+4>>2]=k;c[g>>2]=0;c[g+4>>2]=0;n=k;o=j;p=6}else{j=c[m>>2]|0;k=c[m+4>>2]|0;m=0;if((k|0)>(m|0)|(k|0)==(m|0)&j>>>0>0>>>0){n=k;o=j;p=6}else{q=e}}if((p|0)==6){p=f+24|0;j=(e|0)<0|0?-1:0;k=(j|0)>(n|0)|(j|0)==(n|0)&e>>>0>o>>>0?o:e;e=ZGb(o,n,k,(k|0)<0|0?-1:0)|0;c[p>>2]=e;c[p+4>>2]=F;q=k}if((q|0)==0){h=-541478725;i=b;return h|0}k=fi(a,q)|0;if((k|0)==0){h=-12;i=b;return h|0}p=a+48|0;if((c[k+344>>2]|0)!=(c[p>>2]|0)){yDb(0,0,2345024,(r=i,i=i+24|0,c[r>>2]=2323232,c[r+8>>2]=2300160,c[r+16>>2]=111,r)|0);i=r;Cd();return 0}if((c[k+76>>2]|0)!=(q|0)){yDb(0,0,2345024,(r=i,i=i+24|0,c[r>>2]=2282832,c[r+8>>2]=2300160,c[r+16>>2]=112,r)|0);i=r;Cd();return 0}r=c[k+64>>2]|0;e=vCb(k)|0;GFb(r,0,q,e,c[k+80>>2]|0)|0;e=f+8|0;f=c[e+4>>2]|0;r=k+136|0;c[r>>2]=c[e>>2];c[r+4>>2]=f;if(!((c[e>>2]|0)==0&(c[e+4>>2]|0)==(-2147483648|0))){c[d>>2]=1;c[d+4>>2]=c[p>>2];p=KDb(q,(q|0)<0|0?-1:0,d,a+56|0)|0;d=YGb(c[e>>2]|0,c[e+4>>2]|0,p,F)|0;c[e>>2]=d;c[e+4>>2]=F}h=cj(a,k)|0;i=b;return h|0}function du(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=g+32|0;j=c[h>>2]|0;k=c[h+4>>2]|0;l=c[b+76>>2]|0;if(!((j|0)==0&(k|0)==0)){m=ZGb(j,k,l,(l|0)<0|0?-1:0)|0;c[h>>2]=m;c[h+4>>2]=F}h=b+136|0;m=c[h>>2]|0;k=c[h+4>>2]|0;c[e>>2]=1;c[e+4>>2]=c[a+48>>2];h=KDb(l,(l|0)<0|0?-1:0,e,a+56|0)|0;a=YGb(h,F,m,k)|0;k=g+8|0;c[k>>2]=a;c[k+4>>2]=F;k=cj(c[c[f+32>>2]>>2]|0,b)|0;i=d;return k|0}function eu(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0,j=0.0,k=0,l=0.0,m=0.0;b=i;d=c[a+44>>2]|0;e=d+8|0;f=+h[e>>3];g=d+32|0;j=+h[g>>3];if(f>1.0-j*j){yDb(a,24,2159840,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=+h[e>>3];m=+h[g>>3]}else{l=f;m=j}if(!(l/(1.0-m)>1.0/+h[d+16>>3])){i=b;return 0}yDb(a,24,2089032,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;i=b;return 0}function fu(a){a=a|0;var b=0;b=c[a+44>>2]|0;$Db(b+56|0);$Db(b+64|0);return}function gu(a){a=a|0;var b=0,c=0,d=0;b=Ek()|0;do{if((b|0)==0){c=-12}else{Mk(a,b);d=xk(549920)|0;if((d|0)==0){c=-12;break}Ok(a,d);d=Dk()|0;if((d|0)==0){c=-12;break}Nk(a,d);c=0}}while(0);return c|0}function hu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0.0,q=0,r=0.0,s=0;b=i;d=c[a>>2]|0;a=c[d+44>>2]|0;e=c[c[d+16>>2]>>2]|0;d=e+48|0;f=~~(+h[a+24>>3]*.001*+(c[d>>2]|0)+.5);g=a+52|0;c[g>>2]=f;j=a+56|0;c[j>>2]=dEb(f,c[e+148>>2]<<3)|0;f=~~(+(c[d>>2]|0)/+h[a+40>>3]+.5);d=a+60|0;c[d>>2]=f;k=WDb(f<<2)|0;c[a+64>>2]=k;if((k|0)==0){l=-12;i=b;return l|0}if((c[j>>2]|0)==0){l=-12;i=b;return l|0}j=c[d>>2]|0;m=+(j|0);d=~~(m*.25+.5);if((j|0)!=0){f=c[a+48>>2]|0;n=+(c[g>>2]|0)+-1.0;if((f|0)==0){g=0;o=k;while(1){p=n*(+U(+((((g+d|0)>>>0)%(j>>>0)|0)>>>0>>>0)/m*2.0*3.141592653589793)+1.0)*.5+1.0;c[o>>2]=~~(p+(p<0.0?-.5:.5));q=g+1|0;if(q>>>0<j>>>0){g=q;o=o+4|0}else{break}}}else if((f|0)==1){f=0;o=k;while(1){k=((f+d|0)>>>0)%(j>>>0)|0;p=+(k>>>0>>>0)*2.0/m;g=(k<<2>>>0)/(j>>>0)|0;if((g|0)==1|(g|0)==2){r=1.5-p}else if((g|0)==0){r=p+.5}else if((g|0)==3){r=p+ -1.5}else{r=p}p=n*r+1.0;c[o>>2]=~~(p+(p<0.0?-.5:.5));g=f+1|0;if(g>>>0<j>>>0){f=g;o=o+4|0}else{break}}}else{yDb(0,0,2186832,(s=i,i=i+24|0,c[s>>2]=2171288,c[s+8>>2]=2162416,c[s+16>>2]=145,s)|0);i=s;Cd();return 0}}c[a+72>>2]=0;c[a+68>>2]=0;switch(c[e+52>>2]|0){case 3:{c[a+76>>2]=296;l=0;i=b;return l|0};case 6:{c[a+76>>2]=194;l=0;i=b;return l|0};case 2:{c[a+76>>2]=444;l=0;i=b;return l|0};case 4:{c[a+76>>2]=530;l=0;i=b;return l|0};case 7:{c[a+76>>2]=138;l=0;i=b;return l|0};case 8:{c[a+76>>2]=282;l=0;i=b;return l|0};case 1:{c[a+76>>2]=418;l=0;i=b;return l|0};case 9:{c[a+76>>2]=144;l=0;i=b;return l|0};default:{yDb(0,0,2186832,(s=i,i=i+24|0,c[s>>2]=2171288,c[s+8>>2]=2162416,c[s+16>>2]=292,s)|0);i=s;Cd();return 0}}return 0}function iu(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0;g=c[a+56>>2]|0;i=a+68|0;j=c[i>>2]|0;k=a+72|0;l=c[k>>2]|0;if((e|0)<=0){m=l;n=j;c[i>>2]=n;c[k>>2]=m;return}o=c[a+64>>2]|0;p=c[a+52>>2]|0;q=c[a+60>>2]|0;r=a+8|0;s=a+32|0;t=a+16|0;if((f|0)>0){u=c[b>>2]|0;v=c[d>>2]|0;w=l;x=j;y=0}else{d=l;l=j;j=0;while(1){b=l+1|0;a=b-((b|0)<(p|0)?0:p)|0;b=d+1|0;z=b-((b|0)<(q|0)?0:q)|0;b=j+1|0;if((b|0)<(e|0)){d=z;l=a;j=b}else{m=z;n=a;break}}c[i>>2]=n;c[k>>2]=m;return}while(1){j=(c[o+(w<<2)>>2]|0)+x|0;l=ba(j-((j|0)<(p|0)?0:p)|0,f)|0;j=x+1|0;d=j-((j|0)<(p|0)?0:p)|0;j=ba(d,f)|0;a=v+(f<<3)|0;z=u;b=v;A=0;while(1){B=+h[z>>3]*+h[r>>3]+ +h[g+(A+l<<3)>>3]*+h[s>>3];h[g+(A+j<<3)>>3]=B;h[b>>3]=+h[t>>3]*B;C=A+1|0;if((C|0)<(f|0)){z=z+8|0;b=b+8|0;A=C}else{break}}A=w+1|0;b=A-((A|0)<(q|0)?0:q)|0;A=y+1|0;if((A|0)<(e|0)){u=u+(f<<3)|0;v=a;w=b;x=d;y=A}else{m=b;n=d;break}}c[i>>2]=n;c[k>>2]=m;return}function ju(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0;g=i;if((f|0)<=0){yDb(0,0,2186832,(j=i,i=i+24|0,c[j>>2]=2155800,c[j+8>>2]=2162416,c[j+16>>2]=254,j)|0);i=j;Cd()}j=c[a+56>>2]|0;k=c[a+52>>2]|0;l=a+68|0;m=c[l>>2]|0;n=a+72|0;o=c[n>>2]|0;p=(e|0)>0;q=a+8|0;r=a+64|0;s=a+32|0;t=a+60|0;u=a+16|0;a=0;do{v=ba(k,a)|0;if(p){w=c[r>>2]|0;x=c[t>>2]|0;y=m;z=o;A=c[b+(a<<2)>>2]|0;B=c[d+(a<<2)>>2]|0;C=0;while(1){D=(c[w+(z<<2)>>2]|0)+y|0;E=+h[A>>3]*+h[q>>3]+ +h[j+(D+v+((D|0)<(k|0)?0:-k|0)<<3)>>3]*+h[s>>3];D=z+1|0;F=D-((D|0)<(x|0)?0:x)|0;D=y+1|0;G=D-((D|0)<(k|0)?0:k)|0;h[j+(G+v<<3)>>3]=E;h[B>>3]=E*+h[u>>3];D=C+1|0;if((D|0)<(e|0)){y=G;z=F;A=A+8|0;B=B+8|0;C=D}else{H=G;I=F;break}}}else{H=m;I=o}a=a+1|0;}while((a|0)<(f|0));c[l>>2]=H;c[n>>2]=I;i=g;return}function ku(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0;i=c[a+56>>2]|0;j=a+68|0;k=c[j>>2]|0;l=a+72|0;m=c[l>>2]|0;if((e|0)<=0){n=m;o=k;c[j>>2]=o;c[l>>2]=n;return}p=c[a+64>>2]|0;q=c[a+52>>2]|0;r=(f|0)>0;s=c[a+60>>2]|0;t=a+8|0;u=a+32|0;v=a+16|0;a=c[b>>2]|0;b=c[d>>2]|0;d=m;m=k;k=0;while(1){w=(c[p+(d<<2)>>2]|0)+m|0;x=ba(w-((w|0)<(q|0)?0:q)|0,f)|0;w=m+1|0;y=w-((w|0)<(q|0)?0:q)|0;w=ba(y,f)|0;if(r){z=b+(f<<2)|0;A=a;B=b;C=0;while(1){D=+g[A>>2]*+h[t>>3]+ +h[i+(C+x<<3)>>3]*+h[u>>3];h[i+(C+w<<3)>>3]=D;g[B>>2]=+h[v>>3]*D;E=C+1|0;if((E|0)<(f|0)){A=A+4|0;B=B+4|0;C=E}else{break}}F=a+(f<<2)|0;G=z}else{F=a;G=b}C=d+1|0;B=C-((C|0)<(s|0)?0:s)|0;C=k+1|0;if((C|0)<(e|0)){a=F;b=G;d=B;m=y;k=C}else{n=B;o=y;break}}c[j>>2]=o;c[l>>2]=n;return}function lu(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0;j=i;if((f|0)<=0){yDb(0,0,2186832,(k=i,i=i+24|0,c[k>>2]=2155800,c[k+8>>2]=2162416,c[k+16>>2]=255,k)|0);i=k;Cd()}k=c[a+56>>2]|0;l=c[a+52>>2]|0;m=a+68|0;n=c[m>>2]|0;o=a+72|0;p=c[o>>2]|0;q=(e|0)>0;r=a+8|0;s=a+64|0;t=a+32|0;u=a+60|0;v=a+16|0;a=0;do{w=ba(l,a)|0;if(q){x=c[s>>2]|0;y=c[u>>2]|0;z=n;A=p;B=c[b+(a<<2)>>2]|0;C=c[d+(a<<2)>>2]|0;D=0;while(1){E=(c[x+(A<<2)>>2]|0)+z|0;F=+g[B>>2]*+h[r>>3]+ +h[k+(E+w+((E|0)<(l|0)?0:-l|0)<<3)>>3]*+h[t>>3];E=A+1|0;G=E-((E|0)<(y|0)?0:y)|0;E=z+1|0;H=E-((E|0)<(l|0)?0:l)|0;h[k+(H+w<<3)>>3]=F;g[C>>2]=F*+h[v>>3];E=D+1|0;if((E|0)<(e|0)){z=H;A=G;B=B+4|0;C=C+4|0;D=E}else{I=H;J=G;break}}}else{I=n;J=p}a=a+1|0;}while((a|0)<(f|0));c[m>>2]=I;c[o>>2]=J;i=j;return}function mu(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0;i=c[a+56>>2]|0;j=a+68|0;k=c[j>>2]|0;l=a+72|0;m=c[l>>2]|0;if((f|0)<=0){n=m;o=k;c[j>>2]=o;c[l>>2]=n;return}p=c[a+64>>2]|0;q=c[a+52>>2]|0;r=(g|0)>0;s=c[a+60>>2]|0;t=a+8|0;u=a+32|0;v=a+16|0;a=c[d>>2]|0;d=c[e>>2]|0;e=m;m=k;k=0;while(1){w=(c[p+(e<<2)>>2]|0)+m|0;x=ba(w-((w|0)<(q|0)?0:q)|0,g)|0;w=m+1|0;y=w-((w|0)<(q|0)?0:q)|0;w=ba(y,g)|0;if(r){z=d+(g<<1)|0;A=a;B=d;C=0;while(1){D=+(b[A>>1]|0)*+h[t>>3]+ +h[i+(C+x<<3)>>3]*+h[u>>3];h[i+(C+w<<3)>>3]=D;b[B>>1]=~~(+h[v>>3]*D);E=C+1|0;if((E|0)<(g|0)){A=A+2|0;B=B+2|0;C=E}else{break}}F=a+(g<<1)|0;G=z}else{F=a;G=d}C=e+1|0;B=C-((C|0)<(s|0)?0:s)|0;C=k+1|0;if((C|0)<(f|0)){a=F;d=G;e=B;m=y;k=C}else{n=B;o=y;break}}c[j>>2]=o;c[l>>2]=n;return}function nu(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0;j=i;if((g|0)<=0){yDb(0,0,2186832,(k=i,i=i+24|0,c[k>>2]=2155800,c[k+8>>2]=2162416,c[k+16>>2]=256,k)|0);i=k;Cd()}k=c[a+56>>2]|0;l=c[a+52>>2]|0;m=a+68|0;n=c[m>>2]|0;o=a+72|0;p=c[o>>2]|0;q=(f|0)>0;r=a+8|0;s=a+64|0;t=a+32|0;u=a+60|0;v=a+16|0;a=0;do{w=ba(l,a)|0;if(q){x=c[s>>2]|0;y=c[u>>2]|0;z=n;A=p;B=c[d+(a<<2)>>2]|0;C=c[e+(a<<2)>>2]|0;D=0;while(1){E=(c[x+(A<<2)>>2]|0)+z|0;F=+(b[B>>1]|0)*+h[r>>3]+ +h[k+(E+w+((E|0)<(l|0)?0:-l|0)<<3)>>3]*+h[t>>3];E=A+1|0;G=E-((E|0)<(y|0)?0:y)|0;E=z+1|0;H=E-((E|0)<(l|0)?0:l)|0;h[k+(H+w<<3)>>3]=F;b[C>>1]=~~(F*+h[v>>3]);E=D+1|0;if((E|0)<(f|0)){z=H;A=G;B=B+2|0;C=C+2|0;D=E}else{I=H;J=G;break}}}else{I=n;J=p}a=a+1|0;}while((a|0)<(g|0));c[m>>2]=I;c[o>>2]=J;i=j;return}function ou(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0;g=c[a+56>>2]|0;i=a+68|0;j=c[i>>2]|0;k=a+72|0;l=c[k>>2]|0;if((e|0)<=0){m=l;n=j;c[i>>2]=n;c[k>>2]=m;return}o=c[a+64>>2]|0;p=a+52|0;q=(f|0)>0;r=a+60|0;s=a+8|0;t=a+32|0;u=a+16|0;a=c[b>>2]|0;b=c[d>>2]|0;d=l;l=j;j=1;while(1){v=(c[o+(d<<2)>>2]|0)+l|0;w=c[p>>2]|0;x=ba(v-((v|0)<(w|0)?0:w)|0,f)|0;v=l+1|0;y=v-((v|0)<(w|0)?0:w)|0;w=ba(y,f)|0;if(q){v=b+(f<<2)|0;z=a;A=b;B=0;while(1){C=+(c[z>>2]|0)*+h[s>>3]+ +h[g+(B+x<<3)>>3]*+h[t>>3];h[g+(B+w<<3)>>3]=C;c[A>>2]=~~(+h[u>>3]*C);D=B+1|0;if((D|0)<(f|0)){z=z+4|0;A=A+4|0;B=D}else{break}}E=a+(f<<2)|0;F=v}else{E=a;F=b}B=d+1|0;A=c[r>>2]|0;z=B-((B|0)<(A|0)?0:A)|0;if((j|0)>=(e|0)){m=z;n=y;break}a=E;b=F;d=z;l=y;j=j+1|0}c[i>>2]=n;c[k>>2]=m;return}function pu(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0;g=i;if((f|0)<=0){yDb(0,0,2186832,(j=i,i=i+24|0,c[j>>2]=2155800,c[j+8>>2]=2162416,c[j+16>>2]=257,j)|0);i=j;Cd()}j=c[a+56>>2]|0;k=a+52|0;l=a+68|0;m=a+72|0;n=(e|0)>0;o=a+8|0;p=a+64|0;q=a+32|0;r=a+60|0;s=a+16|0;a=0;do{t=c[k>>2]|0;u=ba(t,a)|0;v=c[l>>2]|0;w=c[m>>2]|0;a:do{if(n){x=c[p>>2]|0;y=v;z=w;A=c[b+(a<<2)>>2]|0;B=c[d+(a<<2)>>2]|0;C=1;D=t;while(1){E=(c[x+(z<<2)>>2]|0)+y|0;F=+(c[A>>2]|0)*+h[o>>3]+ +h[j+(E+u+((E|0)<(D|0)?0:-D|0)<<3)>>3]*+h[q>>3];E=z+1|0;G=c[r>>2]|0;H=E-((E|0)<(G|0)?0:G)|0;G=y+1|0;E=G-((G|0)<(D|0)?0:D)|0;h[j+(E+u<<3)>>3]=F;c[B>>2]=~~(F*+h[s>>3]);if((C|0)>=(e|0)){I=E;J=H;break a}y=E;z=H;A=A+4|0;B=B+4|0;C=C+1|0;D=c[k>>2]|0}}else{I=v;J=w}}while(0);a=a+1|0;}while((a|0)<(f|0));c[l>>2]=I;c[m>>2]=J;i=g;return}function qu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=g;j=c[c[f+32>>2]>>2]|0;do{if((RCb(b)|0)==0){f=fi(a,c[b+76>>2]|0)|0;if((f|0)==0){k=-12;i=d;return k|0}else{NCb(f,c[e>>2]|0)|0;l=f;m=c[e>>2]|0;break}}else{l=b;m=b}}while(0);b=c[g+76>>2]|0;g=c[m+64>>2]|0;a=c[l+64>>2]|0;f=c[l+76>>2]|0;n=vCb(l)|0;le[b&1023](h,g,a,f,n);if((m|0)!=(l|0)){JCb(e)}k=cj(j,l)|0;i=d;return k|0}function ru(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+44>>2]|0;a=d+24|0;c[a>>2]=0;c[a+4>>2]=-2147483648;a=Rqb()|0;e=d+16|0;c[e>>2]=a;if((a|0)==0){f=-12;return f|0}do{if((b|0)==0){g=0}else{a=0;h=0;while(1){i=BBb(c[b>>2]|0,9203184,a,2)|0;if((i|0)==0){j=5;break}k=rEb(c[e>>2]|0,c[i>>2]|0,c[i+4>>2]|0,0)|0;if((k|0)<0){f=k;j=8;break}else{a=i;h=k}}if((j|0)==5){DBb(b);g=h;break}else if((j|0)==8){return f|0}}}while(0);j=c[d+4>>2]|0;if((j|0)<=0){f=g;return f|0}vEb(c[e>>2]|0,2159824,j,(j|0)<0|0?-1:0,0)|0;f=g;return f|0}function su(a){a=a|0;Tqb((c[a+44>>2]|0)+16|0);return}function tu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=(c[a+44>>2]|0)+16|0;h=yEb(c[g>>2]|0,2159824,0)|0;j=h;h=yEb(c[g>>2]|0,2089024,0)|0;k=F;l=yEb(c[g>>2]|0,2036888,0)|0;g=l;l=c[c[a+16>>2]>>2]|0;m=c[c[a+32>>2]>>2]|0;a=Bk(1)|0;n=Dk()|0;o=Fk()|0;Hk(a,l+68|0);Hk(n,l+76|0);Gk(o,l+84|0);if((j|0)>0){l=d|0;c[l>>2]=j;c[d+4>>2]=-1;p=xk(l)|0}else{p=Dk()|0}Hk(p,m+72|0);if((g|0)==-1){q=Bk(1)|0}else{p=e|0;c[p>>2]=g;c[e+4>>2]=-1;q=xk(p)|0}Hk(q,m+64|0);if((h|0)==0&(k|0)==0){r=Fk()|0;s=m+80|0;Gk(r,s);i=b;return 0}else{q=f|0;c[q>>2]=h;c[q+4>>2]=k;k=f+8|0;c[k>>2]=-1;c[k+4>>2]=-1;r=yk(q)|0;s=m+80|0;Gk(r,s);i=b;return 0}return 0}function uu(a,b){a=a|0;b=b|0;var d=0;if((b|0)!=0){d=0;return d|0}d=c[a+16>>2]|0;return d|0}function vu(a){a=a|0;var b=0;if((a|0)==0){b=Qqb()|0}else{b=0}return b|0}function wu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=e+16|0;e=c[c[g>>2]>>2]|0;h=f+32|0;c[h>>2]=0;j=e;while(1){k=Ni(j)|0;if(!((c[h>>2]|0)==0&(k|0)>-1)){break}j=c[c[g>>2]>>2]|0}if(!((k|0)==-541478725)){l=k;i=b;return l|0}k=fi(a,4096)|0;c[d>>2]=k;if((k|0)==0){l=-12;i=b;return l|0}g=f+16|0;f=arb(c[g>>2]|0,0,-2147483648)|0;j=F;h=c[e+48>>2]|0;e=h>>1;m=e;n=(e|0)<0|0?-1:0;e=Xqb(c[g>>2]|0,c[k+64>>2]|0,4096,0,0)|0;if((e|0)<1){JCb(d);l=(e|0)==0?-541478725:e;i=b;return l|0}else{d=ZGb(0,0,m,n)|0;g=0;o=(j|0)>(g|0)|(j|0)==(g|0)&f>>>0>0>>>0;g=YGb(o?m:d,o?n:F,f,j)|0;j=eHb(g,F,h,(h|0)<0|0?-1:0)|0;c[k+344>>2]=c[a+48>>2];c[k+76>>2]=e;e=k+136|0;c[e>>2]=j;c[e+4>>2]=F;l=cj(a,k)|0;i=b;return l|0}return 0}function xu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+256|0;d=c[a>>2]|0;e=c[c[d+16>>2]>>2]|0;f=c[d+44>>2]|0;g=f+16|0;j=a+40|0;k=a+52|0;l=a+48|0;m=e+40|0;n=e+52|0;o=e+48|0;p=d;d=Sqb(c[g>>2]|0,c[j>>2]|0,c[j+4>>2]|0,c[k>>2]|0,c[l>>2]|0,c[m>>2]|0,c[m+4>>2]|0,c[n>>2]|0,c[o>>2]|0,0,p)|0;c[g>>2]=d;if((d|0)==0){q=-12;i=b;return q|0}if((c[m>>2]|0)==0&(c[m+4>>2]|0)==0){r=c[e+148>>2]|0;vEb(d,1907904,r,(r|0)<0|0?-1:0,0)|0}if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){r=c[a+148>>2]|0;vEb(c[g>>2]|0,1887096,r,(r|0)<0|0?-1:0,0)|0}r=Vqb(c[g>>2]|0)|0;if((r|0)<0){q=r;i=b;return q|0}r=yEb(c[g>>2]|0,2159824,0)|0;d=r;r=yEb(c[g>>2]|0,2089024,0)|0;s=F;t=yEb(c[g>>2]|0,2036888,0)|0;c[a+56>>2]=1;c[a+60>>2]=d;if((c[l>>2]|0)!=(d|0)){yDb(0,0,2344984,(u=i,i=i+24|0,c[u>>2]=2323112,c[u+8>>2]=2300088,c[u+16>>2]=157,u)|0);i=u;Cd();return 0}g=c[j>>2]|0;v=c[j+4>>2]|0;if(!((g|0)==(r|0)&(v|0)==(s|0)|(g|0)==0&(v|0)==0)){yDb(0,0,2344984,(u=i,i=i+24|0,c[u>>2]=2282712,c[u+8>>2]=2300088,c[u+16>>2]=158,u)|0);i=u;Cd();return 0}if((c[k>>2]|0)!=(t|0)){yDb(0,0,2344984,(u=i,i=i+24|0,c[u>>2]=2267448,c[u+8>>2]=2300088,c[u+16>>2]=159,u)|0);i=u;Cd();return 0}h[f+8>>3]=+(d|0)/+(c[o>>2]|0);d=b|0;f=e+148|0;iBb(d,128,c[f>>2]|0,c[m>>2]|0,c[m+4>>2]|0);m=b+128|0;e=a+148|0;iBb(m,128,c[e>>2]|0,c[j>>2]|0,c[j+4>>2]|0);j=c[f>>2]|0;f=wFb(c[n>>2]|0)|0;n=c[o>>2]|0;o=c[e>>2]|0;e=wFb(c[k>>2]|0)|0;k=c[l>>2]|0;yDb(p,40,2252072,(u=i,i=i+64|0,c[u>>2]=j,c[u+8>>2]=d,c[u+16>>2]=f,c[u+24>>2]=n,c[u+32>>2]=o,c[u+40>>2]=m,c[u+48>>2]=e,c[u+56>>2]=k,u)|0);i=u;q=0;i=b;return q|0}function yu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;j=c[g+44>>2]|0;k=c[b+76>>2]|0;l=~~(+(k|0)*+h[j+8>>3]+32.0);m=c[c[g+32>>2]>>2]|0;g=j+16|0;n=m+48|0;o=c[n>>2]|0;p=$qb(c[g>>2]|0,o,(o|0)<0|0?-1:0)|0;o=F;q=0;if((o|0)>(q|0)|(o|0)==(q|0)&p>>>0>0>>>0){q=YGb(p,o,l,0)|0;r=q}else{r=l}l=fi(m,r)|0;c[f>>2]=l;if((l|0)==0){s=-12;i=d;return s|0}NCb(l,b)|0;c[l+80>>2]=c[m+52>>2];wCb(l,c[m+148>>2]|0);q=m+40|0;o=c[q+4>>2]|0;p=l+352|0;c[p>>2]=c[q>>2];c[p+4>>2]=o;c[l+344>>2]=c[n>>2];o=b+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;if((p|0)==0&(q|0)==(-2147483648|0)){o=l+136|0;c[o>>2]=0;c[o+4>>2]=-2147483648;t=l;u=b}else{b=c[a+56>>2]|0;l=c[n>>2]|0;n=gHb(l,(l|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;b=a+48|0;l=c[b>>2]|0;o=gHb(n,F,l,(l|0)<0|0?-1:0)|0;l=c[a+60>>2]|0;a=IDb(p,q,o,F,l,(l|0)<0|0?-1:0)|0;l=arb(c[g>>2]|0,a,F)|0;a=F;o=0;q=(a|0)>(o|0)|(a|0)==(o|0)&l>>>0>0>>>0;o=c[b>>2]|0;b=o>>1;p=b;n=(b|0)<0|0?-1:0;b=ZGb(0,0,p,n)|0;v=YGb(q?p:b,q?n:F,l,a)|0;a=eHb(v,F,o,(o|0)<0|0?-1:0)|0;o=F;v=c[f>>2]|0;l=v+136|0;c[l>>2]=a;c[l+4>>2]=o;l=j+24|0;c[l>>2]=a;c[l+4>>2]=o;t=v;u=c[e>>2]|0}v=Xqb(c[g>>2]|0,c[t+64>>2]|0,r,c[u+64>>2]|0,k)|0;if((v|0)<1){JCb(f);JCb(e);s=0;i=d;return s|0}else{c[t+76>>2]=v;v=cj(m,t)|0;c[j+32>>2]=1;JCb(e);s=v;i=d;return s|0}return 0}function zu(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[a+44>>2]|0;e=d+16|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=c[d+24>>2]|0;yDb(a,40,2159584,(a=i,i=i+16|0,c[a>>2]=c[d+4>>2],c[a+8>>2]=e,a)|0);i=a;i=b;return 0}function Au(a){a=a|0;jAb(c[(c[a+44>>2]|0)+8>>2]|0);return}function Bu(a){a=a|0;var b=0,d=0;b=Ni(c[c[(c[a>>2]|0)+16>>2]>>2]|0)|0;if(!((b|0)==-541478725)){d=b;return d|0}b=Du(a)|0;if((b|0)<0){d=b;return d|0}d=(b|0)>0?0:-541478725;return d|0}function Cu(a){a=a|0;var b=0,d=0,e=0;b=c[(c[a>>2]|0)+44>>2]|0;d=kAb(c[a+52>>2]|0,c[a+148>>2]|0,c[b+4>>2]|0)|0;c[b+8>>2]=d;if((d|0)==0){e=-12;return e|0}d=a+156|0;c[d>>2]=c[d>>2]|1;e=0;return e|0}function Du(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[(c[a>>2]|0)+44>>2]|0;do{if((c[b+24>>2]|0)==0){d=b+4|0;e=c[d>>2]|0;f=b+8|0;if((e|0)>(oAb(c[f>>2]|0)|0)){g=0;h=oAb(c[f>>2]|0)|0;break}else{g=0;h=c[d>>2]|0;break}}else{d=b+8|0;if((oAb(c[d>>2]|0)|0)==0){i=0}else{i=c[b+4>>2]|0}if((i|0)>(oAb(c[d>>2]|0)|0)){j=oAb(c[d>>2]|0)|0}else{j=i}g=i-j|0;h=i}}while(0);if((h|0)==0){k=0;return k|0}i=fi(a,h)|0;if((i|0)==0){k=-12;return k|0}j=i+64|0;pAb(c[b+8>>2]|0,c[j>>2]|0,h)|0;if((g|0)!=0){GFb(c[j>>2]|0,h-g|0,g,c[a+148>>2]|0,c[a+52>>2]|0)|0}c[i+76>>2]=h;g=a+40|0;j=c[g+4>>2]|0;d=i+352|0;c[d>>2]=c[g>>2];c[d+4>>2]=j;c[i+344>>2]=c[a+48>>2];j=b+16|0;b=c[j+4>>2]|0;d=i+136|0;c[d>>2]=c[j>>2];c[d+4>>2]=b;b=c[j>>2]|0;d=c[j+4>>2]|0;if(!((b|0)==0&(d|0)==(-2147483648|0))){g=YGb(b,d,h,(h|0)<0|0?-1:0)|0;c[j>>2]=g;c[j+4>>2]=F}j=cj(a,i)|0;k=(j|0)<0?j:h;return k|0}function Eu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=c[c[f+32>>2]>>2]|0;h=c[b+76>>2]|0;j=a+8|0;do{if((nAb(c[j>>2]|0)|0)<(h|0)){k=f;yDb(k,48,2344864,(l=i,i=i+8|0,c[l>>2]=h,l)|0);i=l;m=c[j>>2]|0;if((lAb(m,(oAb(m)|0)+h|0)|0)>=0){n=c[e>>2]|0;break}yDb(k,16,2323e3,(l=i,i=i+8|0,c[l>>2]=h,l)|0);i=l;o=-1;i=d;return o|0}else{n=b}}while(0);mAb(c[j>>2]|0,c[n+64>>2]|0,h)|0;h=a+16|0;if((c[h>>2]|0)==0&(c[h+4>>2]|0)==(-2147483648|0)){b=n+136|0;n=c[b+4>>2]|0;c[h>>2]=c[b>>2];c[h+4>>2]=n}JCb(e);e=oAb(c[j>>2]|0)|0;n=a+4|0;if((e|0)<(c[n>>2]|0)){o=0;i=d;return o|0}while(1){Du(g)|0;e=oAb(c[j>>2]|0)|0;if((e|0)<(c[n>>2]|0)){o=0;break}}i=d;return o|0}function Fu(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+8|0;d=b|0;e=d|0;c[e>>2]=c[(c[a+44>>2]|0)+4>>2];c[d+4>>2]=-1;d=xk(e)|0;Hk(d,(c[c[a+32>>2]>>2]|0)+72|0);i=b;return 0}function Gu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=c[a>>2]|0;e=c[c[d+16>>2]>>2]|0;f=e+56|0;g=c[f>>2]|0;h=c[f+4>>2]|0;f=g;j=h;k=j;l=c[e+48>>2]|0;if((f|0)==1&(k|0)==(l|0)){c[a+56>>2]=1;c[a+60>>2]=c[a+48>>2];i=b;return 0}e=c[d+44>>2]|0;m=a+56|0;c[m>>2]=g|0;c[m+4>>2]=j|h&0;c[e+8>>2]=1;e=c[a+48>>2]|0;if(!(+(f|0)/+(k|0)>1.0/+(((l|0)>(e|0)?l:e)|0))){i=b;return 0}yDb(d,24,1957512,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;i=b;return 0}function Hu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=c[c[d+32>>2]>>2]|0;d=f+48|0;c[b+344>>2]=c[d>>2];if((c[e+8>>2]|0)==0){g=cj(f,b)|0;return g|0}e=b+136|0;h=c[a+48>>2]|0;a=c[d>>2]|0;d=IDb(c[e>>2]|0,c[e+4>>2]|0,h,(h|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;c[e>>2]=d;c[e+4>>2]=F;g=cj(f,b)|0;return g|0}function Iu(a){a=a|0;$Db(c[a+44>>2]|0);return}function Ju(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+192|0;f=e|0;g=e+128|0;j=e+160|0;k=b+8|0;l=c[k>>2]|0;m=c[l+44>>2]|0;n=c[b+148>>2]|0;o=d+80|0;p=CFb(c[o>>2]|0)|0;q=BFb(c[o>>2]|0)|0;r=(p|0)!=0;p=ba(q,r?1:n)|0;q=d+76|0;s=ba(p,c[q>>2]|0)|0;p=r?n:1;r=m;m=XDb(c[r>>2]|0,n<<2)|0;if((m|0)==0){t=-12;i=e;return t|0}n=m;c[r>>2]=n;m=(p|0)>0;if(m){u=c[d+64>>2]|0;v=0;w=0;while(1){x=c[u+(v<<2)>>2]|0;c[n+(v<<2)>>2]=eAb(0,x,s)|0;if((v|0)==0){y=c[n>>2]|0}else{y=eAb(w,x,s)|0}x=v+1|0;if((x|0)<(p|0)){v=x;w=y}else{z=y;break}}}else{z=0}y=f|0;f=d+352|0;iBb(y,128,-1,c[f>>2]|0,c[f+4>>2]|0);f=l;l=b+160|0;w=c[l>>2]|0;v=c[l+4>>2]|0;l=g|0;TGb(l|0,0,32)|0;a[l]=0;g=d+136|0;s=c[g>>2]|0;n=c[g+4>>2]|0;if((s|0)==0&(n|0)==(-2147483648|0)){Lb(l|0,32,1929864,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0)|0;i=A}else{Lb(l|0,32,1886944,(A=i,i=i+16|0,c[A>>2]=s,c[A+8>>2]=n,A)|0)|0;i=A}n=j|0;TGb(n|0,0,32)|0;a[n]=0;j=c[g>>2]|0;s=c[g+4>>2]|0;if((j|0)==0&(s|0)==(-2147483648|0)){Lb(n|0,32,1929864,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0)|0;i=A}else{Lb(n|0,32,1907608,(A=i,i=i+8|0,h[A>>3]=(+(j>>>0)+ +(s|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),A)|0)|0;i=A}b=sCb(d)|0;s=F;j=wFb(c[o>>2]|0)|0;o=vCb(d)|0;g=c[d+344>>2]|0;u=c[q>>2]|0;yDb(f,32,2088288,(A=i,i=i+96|0,c[A>>2]=w,c[A+8>>2]=v,c[A+16>>2]=l,c[A+24>>2]=n,c[A+32>>2]=b,c[A+40>>2]=s,c[A+48>>2]=j,c[A+56>>2]=o,c[A+64>>2]=y,c[A+72>>2]=g,c[A+80>>2]=u,c[A+88>>2]=z,A)|0);i=A;yDb(f,32,2036384,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;if(m){m=0;do{yDb(f,32,1991720,(A=i,i=i+8|0,c[A>>2]=c[(c[r>>2]|0)+(m<<2)>>2],A)|0);i=A;m=m+1|0;}while((m|0)<(p|0))}yDb(f,32,1957472,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;t=cj(c[c[(c[k>>2]|0)+32>>2]>>2]|0,d)|0;i=e;return t|0}function Ku(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0,L=0.0,M=0.0,N=0,O=0.0,P=0,S=0.0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0,aa=0.0,ba=0,ca=0.0,da=0,ea=0.0,fa=0.0,ga=0.0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0.0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0.0,ta=0,ua=0,va=0,wa=0.0,xa=0,ya=0,za=0.0,Aa=0.0,Ba=0.0,Ca=0.0,Da=0,Ea=0.0,Fa=0.0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;b=i;d=c[a+44>>2]|0;e=d+8|0;if((c[e>>2]|0)>0){f=d+4|0;g=d+16|0;j=a;k=0;l=0;m=0;n=0;o=0.0;p=0.0;q=1.7976931348623157e+308;r=2.2250738585072014e-308;s=0.0;t=0.0;u=1.7976931348623157e+308;v=2.2250738585072014e-308;w=0;x=0;y=0;while(1){z=c[f>>2]|0;A=z+(w*120|0)+112|0;B=c[A>>2]|0;C=c[A+4>>2]|0;D=c[g+4>>2]|0;if(C>>>0<D>>>0|C>>>0==D>>>0&B>>>0<(c[g>>2]|0)>>>0){E=+h[z+(w*120|0)+16>>3];G=E/(+(B>>>0)+ +(C>>>0)*4294967296.0);h[z+(w*120|0)+40>>3]=G;h[z+(w*120|0)+32>>3]=G;H=G;I=G;J=E}else{H=+h[z+(w*120|0)+32>>3];I=+h[z+(w*120|0)+40>>3];J=+h[z+(w*120|0)+16>>3]}D=z+(w*120|0)+48|0;E=+h[D>>3];G=q>E?E:q;K=z+(w*120|0)+56|0;E=+h[K>>3];L=r>E?r:E;E=u>H?H:u;M=v>I?v:I;N=z+(w*120|0)+8|0;O=+h[N>>3];P=z+(w*120|0)+16|0;S=t+J;T=z+(w*120|0)+96|0;U=YGb(c[T>>2]|0,c[T+4>>2]|0,y,x)|0;V=F;W=z+(w*120|0)+104|0;X=YGb(c[W>>2]|0,c[W+4>>2]|0,l,k)|0;Y=F;Z=z+(w*120|0)+80|0;_=o+ +h[Z>>3];$=z+(w*120|0)+88|0;aa=p+ +h[$>>3];ba=YGb(B,C,n,m)|0;C=F;B=+Q(+O)>+Q(+s);ca=B?O:s;B=w+1|0;yDb(j,32,2158288,(da=i,i=i+8|0,c[da>>2]=B,da)|0);i=da;yDb(j,32,2087896,(da=i,i=i+8|0,h[da>>3]=+h[N>>3]/(+((c[A>>2]|0)>>>0)+ +((c[A+4>>2]|0)>>>0)*4294967296.0),da)|0);i=da;yDb(j,32,2036160,(da=i,i=i+8|0,h[da>>3]=+h[D>>3],da)|0);i=da;yDb(j,32,1991464,(da=i,i=i+8|0,h[da>>3]=+h[K>>3],da)|0);i=da;O=-0.0- +h[D>>3];ea=+h[K>>3];fa=+ad(+(ea<O?O:ea))*20.0;yDb(j,32,1957312,(da=i,i=i+8|0,h[da>>3]=fa,da)|0);i=da;fa=+ad(+(+R(+h[P>>3]/(+((c[A>>2]|0)>>>0)+ +((c[A+4>>2]|0)>>>0)*4294967296.0))))*20.0;yDb(j,32,1929712,(da=i,i=i+8|0,h[da>>3]=fa,da)|0);i=da;fa=+ad(+(+R(+h[z+(w*120|0)+40>>3])))*20.0;yDb(j,32,1907560,(da=i,i=i+8|0,h[da>>3]=fa,da)|0);i=da;fa=+h[z+(w*120|0)+32>>3];if(fa!=1.0){ea=+ad(+(+R(fa)))*20.0;yDb(j,32,1886864,(da=i,i=i+8|0,h[da>>3]=ea,da)|0);i=da}ea=+h[P>>3];if(ea!=0.0){fa=-0.0- +h[D>>3];O=+h[K>>3];ga=(O<fa?fa:O)/+R(ea/(+((c[A>>2]|0)>>>0)+ +((c[A+4>>2]|0)>>>0)*4294967296.0))}else{ga=1.0}yDb(j,32,2344728,(da=i,i=i+8|0,h[da>>3]=ga,da)|0);i=da;ea=+h[Z>>3]+ +h[$>>3];$=YGb(c[W>>2]|0,c[W+4>>2]|0,c[T>>2]|0,c[T+4>>2]|0)|0;O=+ad(+(ea/(+($>>>0)+ +(F>>>0)*4294967296.0)))*20.0;yDb(j,32,2322928,(da=i,i=i+8|0,h[da>>3]=O,da)|0);i=da;$=YGb(c[W>>2]|0,c[W+4>>2]|0,c[T>>2]|0,c[T+4>>2]|0)|0;T=F;yDb(j,32,2299992,(da=i,i=i+16|0,c[da>>2]=$,c[da+8>>2]=T,da)|0);i=da;if((B|0)<(c[e>>2]|0)){k=Y;l=X;m=C;n=ba;o=_;p=aa;q=G;r=L;s=ca;t=S;u=E;v=M;w=B;x=V;y=U}else{ha=Y;ia=X;ja=C;ka=ba;la=_;ma=aa;na=G;oa=L;pa=ca;qa=S;ra=E;sa=M;ta=V;ua=U;va=j;break}}}else{ha=0;ia=0;ja=0;ka=0;la=0.0;ma=0.0;na=1.7976931348623157e+308;oa=2.2250738585072014e-308;pa=0.0;qa=0.0;ra=1.7976931348623157e+308;sa=2.2250738585072014e-308;ta=0;ua=0;va=a}yDb(va,32,2282544,(da=i,i=i+1|0,i=i+7&-8,c[da>>2]=0,da)|0);i=da;a=c[e>>2]|0;j=hHb(ka,ja,a,(a|0)<0|0?-1:0)|0;v=pa/(+(j>>>0)+ +(F>>>0)*4294967296.0);yDb(va,32,2087896,(da=i,i=i+8|0,h[da>>3]=v,da)|0);i=da;yDb(va,32,2036160,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;yDb(va,32,1991464,(da=i,i=i+8|0,h[da>>3]=oa,da)|0);i=da;v=-0.0-na;na=+ad(+(oa<v?v:oa))*20.0;yDb(va,32,1957312,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;na=+ad(+(+R(qa/(+(ka>>>0)+ +(ja>>>0)*4294967296.0))))*20.0;yDb(va,32,1929712,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;na=+ad(+(+R(sa)))*20.0;yDb(va,32,1907560,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;if(!(ra!=1.0)){wa=ma+la;xa=YGb(ia,ha,ua,ta)|0;ya=F;za=+(xa>>>0)+ +(ya>>>0)*4294967296.0;Aa=wa/za;Ba=+ad(+Aa);Ca=Ba*20.0;yDb(va,32,2322928,(da=i,i=i+8|0,h[da>>3]=Ca,da)|0);i=da;Da=c[e>>2]|0;Ea=+(Da|0);Fa=za/Ea;yDb(va,32,2267256,(da=i,i=i+8|0,h[da>>3]=Fa,da)|0);i=da;Ga=c[e>>2]|0;Ha=Ga;Ia=(Ga|0)<0|0?-1:0;Ja=hHb(ka,ja,Ha,Ia)|0;Ka=F;La=2251952;yDb(va,32,La,(da=i,i=i+16|0,c[da>>2]=Ja,c[da+8>>2]=Ka,da)|0);i=da;Ma=d+4|0;$Db(Ma);i=b;return}na=+ad(+(+R(ra)))*20.0;yDb(va,32,1886864,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;wa=ma+la;xa=YGb(ia,ha,ua,ta)|0;ya=F;za=+(xa>>>0)+ +(ya>>>0)*4294967296.0;Aa=wa/za;Ba=+ad(+Aa);Ca=Ba*20.0;yDb(va,32,2322928,(da=i,i=i+8|0,h[da>>3]=Ca,da)|0);i=da;Da=c[e>>2]|0;Ea=+(Da|0);Fa=za/Ea;yDb(va,32,2267256,(da=i,i=i+8|0,h[da>>3]=Fa,da)|0);i=da;Ga=c[e>>2]|0;Ha=Ga;Ia=(Ga|0)<0|0?-1:0;Ja=hHb(ka,ja,Ha,Ia)|0;Ka=F;La=2251952;yDb(va,32,La,(da=i,i=i+16|0,c[da>>2]=Ja,c[da+8>>2]=Ka,da)|0);i=da;Ma=d+4|0;$Db(Ma);i=b;return}function Lu(a){a=a|0;var b=0,c=0,d=0;b=Ek()|0;do{if((b|0)==0){c=-12}else{Mk(a,b);d=xk(549904)|0;if((d|0)==0){c=-12;break}Ok(a,d);d=Dk()|0;if((d|0)==0){c=-12;break}Nk(a,d);c=0}}while(0);return c|0}function Mu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0.0,j=0.0,k=0.0,l=0;b=c[(c[a>>2]|0)+44>>2]|0;d=a+148|0;e=dEb(120,c[d>>2]|0)|0;f=e;c[b+4>>2]=f;if((e|0)==0){g=-12;return g|0}e=c[d>>2]|0;c[b+8>>2]=e;i=+h[b+24>>3];j=+(c[a+48>>2]|0);h[b+32>>3]=+_(-1.0/i/j);k=i*5.0*j+.5;a=(E=+k,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);d=b+16|0;c[d>>2]=~~+k>>>0;c[d+4>>2]=a;if((e|0)>0){l=0}else{g=0;return g|0}while(1){h[f+(l*120|0)+32>>3]=1.7976931348623157e+308;h[f+(l*120|0)+48>>3]=1.7976931348623157e+308;h[f+(l*120|0)+40>>3]=2.2250738585072014e-308;h[f+(l*120|0)+56>>3]=2.2250738585072014e-308;a=l+1|0;if((a|0)<(e|0)){l=a}else{g=0;break}}return g|0}function Nu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a+8|0;e=c[(c[d>>2]|0)+44>>2]|0;f=e;g=c[e+8>>2]|0;i=c[a+52>>2]|0;a:do{if((i|0)==4){a=b+76|0;j=c[a>>2]|0;if((j|0)<=0){break}k=e+4|0;if((g|0)>0){l=0;m=c[c[b+64>>2]>>2]|0}else{n=0;while(1){n=n+1|0;if((n|0)>=(j|0)){break a}}}while(1){j=0;n=m;while(1){Ou(f,(c[k>>2]|0)+(j*120|0)|0,+h[n>>3]);o=j+1|0;if((o|0)<(g|0)){j=o;n=n+8|0}else{break}}n=l+1|0;if((n|0)<(c[a>>2]|0)){l=n;m=m+(g<<3)|0}else{break}}}else if((i|0)==9){if((g|0)<=0){break}a=e+4|0;k=b+64|0;n=b+76|0;j=0;o=c[n>>2]|0;while(1){p=(c[a>>2]|0)+(j*120|0)|0;if((o|0)>0){q=0;r=c[(c[k>>2]|0)+(j<<2)>>2]|0;while(1){Ou(f,p,+h[r>>3]);s=q+1|0;t=c[n>>2]|0;if((s|0)<(t|0)){q=s;r=r+8|0}else{u=t;break}}}else{u=o}r=j+1|0;if((r|0)<(g|0)){j=r;o=u}else{break}}}}while(0);return cj(c[c[(c[d>>2]|0)+32>>2]>>2]|0,b)|0}function Ou(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0.0,g=0,i=0.0,j=0,k=0.0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+48|0;f=+h[e>>3];do{if(f>d){h[e>>3]=d;h[b+64>>3]=1.0;h[b+80>>3]=0.0;g=b+96|0;c[g>>2]=1;c[g+4>>2]=0}else{if(!(f==d)){if(!(+h[b>>3]==f)){break}i=+h[b+64>>3];g=b+80|0;h[g>>3]=+h[g>>3]+i*i;break}g=b+96|0;j=YGb(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=j;c[g+4>>2]=F;g=b+64|0;if(+h[b>>3]==d){k=+h[g>>3]+1.0}else{k=1.0}h[g>>3]=k}}while(0);e=b+56|0;k=+h[e>>3];do{if(k<d){h[e>>3]=d;h[b+72>>3]=1.0;h[b+88>>3]=0.0;g=b+104|0;c[g>>2]=1;c[g+4>>2]=0;l=b|0}else{if(!(k==d)){g=b|0;if(!(+h[g>>3]==k)){l=g;break}f=+h[b+72>>3];j=b+88|0;h[j>>3]=+h[j>>3]+f*f;l=g;break}g=b+104|0;j=YGb(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=j;c[g+4>>2]=F;g=b|0;j=b+72|0;if(+h[g>>3]==d){m=+h[j>>3]+1.0}else{m=1.0}h[j>>3]=m;l=g}}while(0);e=b+8|0;h[e>>3]=+h[e>>3]+d;e=b+16|0;h[e>>3]=d*d+ +h[e>>3];e=b+24|0;m=+h[a+32>>3];k=+h[e>>3]*m+(1.0-m)*d*d;h[e>>3]=k;h[l>>3]=d;l=b+112|0;e=c[l>>2]|0;g=c[l+4>>2]|0;j=a+16|0;a=c[j+4>>2]|0;if(g>>>0<a>>>0|g>>>0==a>>>0&e>>>0<(c[j>>2]|0)>>>0){n=1;o=0;p=YGb(e,g,n,o)|0;q=F;r=l|0;c[r>>2]=p;s=l+4|0;c[s>>2]=q;return}j=b+40|0;d=+h[j>>3];h[j>>3]=d>k?d:k;j=b+32|0;d=+h[j>>3];h[j>>3]=d>k?k:d;n=1;o=0;p=YGb(e,g,n,o)|0;q=F;r=l|0;c[r>>2]=p;s=l+4|0;c[s>>2]=q;return}function Pu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;e=d+4|0;f=d+8|0;g=a;a=JBb(e,c[f>>2]|0,159880,0,0,0,0,0,g)|0;if((a|0)<0){yDb(g,16,2157600,(g=i,i=i+8|0,c[g>>2]=c[f>>2],g)|0);i=g;h=a;i=b;return h|0}a=d+16|0;d=0;while(1){+MBb(c[e>>2]|0,a,0);g=d+1|0;if((g|0)<42){d=g}else{h=0;break}}i=b;return h|0}function Qu(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+4|0;IBb(c[b>>2]|0);c[b>>2]=0;return}function Ru(a){a=a|0;var b=0,d=0,e=0;b=a+16|0;d=a+32|0;a=c[c[b>>2]>>2]|0;e=c[a+64>>2]|0;Hk(e,a+68|0);Hk(e,(c[c[d>>2]>>2]|0)+64|0);e=Dk()|0;Hk(e,(c[c[b>>2]>>2]|0)+76|0);Hk(e,(c[c[d>>2]>>2]|0)+72|0);e=c[c[b>>2]>>2]|0;a=c[e+80>>2]|0;Gk(a,e+84|0);Gk(a,(c[c[d>>2]>>2]|0)+80|0);a=c[(c[b>>2]|0)+4>>2]|0;e=c[a+64>>2]|0;Hk(e,a+68|0);Hk(e,(c[(c[d>>2]|0)+4>>2]|0)+64|0);e=Dk()|0;Hk(e,(c[(c[b>>2]|0)+4>>2]|0)+76|0);Hk(e,(c[(c[d>>2]|0)+4>>2]|0)+72|0);e=c[(c[b>>2]|0)+4>>2]|0;b=c[e+80>>2]|0;Gk(b,e+84|0);Gk(b,(c[(c[d>>2]|0)+4>>2]|0)+80|0);return 0}function Su(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=(c[(c[b+32>>2]|0)+4>>2]|0)==(a|0)|0;a=d+208+(e<<2)|0;f=(c[a>>2]|0)+1|0;c[a>>2]=f;g=d+220|0;if((f|0)==0){return 0}f=1<<e;e=d+216|0;h=d+64|0;d=b+16|0;while(1){i=c[g>>2]|0;if((i&f|0)!=0){j=9;break}k=c[e>>2]|0;do{if((c[h+(k*72|0)+68>>2]|0)==0){c[g>>2]=1<<k|i;Ni(c[(c[d>>2]|0)+(k<<2)>>2]|0)|0;l=c[e>>2]|0;if((1<<l&c[g>>2]|0)==0){break}c[e>>2]=(l|0)==0}else{Uu(b)}}while(0);if((c[a>>2]|0)==0){j=9;break}}if((j|0)==9){return 0}return 0}function Tu(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;d=c[(c[b+16>>2]|0)+(((c[(c[b+32>>2]|0)+4>>2]|0)==(a|0))<<2)>>2]|0;c[a+48>>2]=c[d+48>>2];b=d+56|0;d=a+56|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;return 0}function Uu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+44>>2]|0;d=b+216|0;e=c[d>>2]|0;f=b+64|0;if((c[f+(e*72|0)+68>>2]|0)!=0){g=b+220|0;h=b+4|0;i=b+16|0;j=e;while(1){Vu(a,j);if((c[g>>2]|0)==0){e=+MBb(c[h>>2]|0,i,0)>=0.0|0;c[d>>2]=e;k=e}else{k=c[d>>2]|0}if((c[f+(k*72|0)+68>>2]|0)==0){break}else{j=k}}}if((c[b+132>>2]|0)==16){Vu(a,0)}if((c[b+204>>2]|0)!=16){return}Vu(a,1);return}function Vu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0;d=c[a+44>>2]|0;e=d+64|0;f=e+(b*72|0)+64|0;g=e+(b*72|0)+(c[f>>2]<<2)|0;i=c[g>>2]|0;c[g>>2]=0;g=d+16|0;j=g+(b<<3)|0;h[j>>3]=+h[j>>3]+1.0;k=+(c[i+76>>2]|0);j=g+(b+2<<3)|0;h[j>>3]=+h[j>>3]+k;j=i+136|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=c[(c[a+32>>2]|0)+(b<<2)>>2]|0;if((l|0)==0&(m|0)==(-2147483648|0)){n=g+(b+4<<3)|0}else{o=g+(b+4<<3)|0;h[o>>3]=(+(l>>>0)+ +(m|0)*4294967296.0)*(+(c[j+56>>2]|0)/+(c[j+60>>2]|0));n=o}h[n>>3]=k/+(c[(c[(c[a+16>>2]|0)+(b<<2)>>2]|0)+48>>2]|0)+ +h[n>>3];cj(j,i)|0;i=e+(b*72|0)+68|0;c[i>>2]=(c[i>>2]|0)-1;c[f>>2]=(c[f>>2]|0)+1&15;f=d+208+(b<<2)|0;b=c[f>>2]|0;if((b|0)==0){return}c[f>>2]=b-1;return}function Wu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=(c[(c[d+16>>2]|0)+4>>2]|0)==(a|0)|0;a=e+64|0;g=c[a+(f*72|0)+64>>2]|0;h=a+(f*72|0)+68|0;i=c[h>>2]|0;c[h>>2]=i+1;c[a+(f*72|0)+((i+g&15)<<2)>>2]=b;b=e+220|0;c[b>>2]=c[b>>2]&~(1<<f);Uu(d);return 0}function Xu(a){a=a|0;var b=0;b=c[a+44>>2]|0;c[b+40>>2]=-1;c[b+160>>2]=0;return 0}function Yu(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=b+152|0;c[a>>2]=0;c[a+4>>2]=0;c[b+160>>2]=0;a=b+88|0;d=b+96|0;c[b+108>>2]=0;c[b+140>>2]=0;TGb(b+12|0,0,28)|0;TGb(b+72|0,0,16)|0;TGb(b+120|0,0,16)|0;e=(c[b+52>>2]|0)/2|0;f=ZGb(0,0,e,(e|0)<0|0?-1:0)|0;e=F;c[a>>2]=f;c[a+4>>2]=e;c[d>>2]=f;c[d+4>>2]=e;JCb(b+176|0);c[b+180>>2]=0;c[b+184>>2]=0;TGb(b+192|0,0,16)|0;$Db(b+104|0);$Db(b+136|0);$Db(b+112|0);$Db(b+144|0);$Db(b+4|0);$Db(b+56|0);$Db(b+172|0);e=b+164|0;rZ(c[e>>2]|0);c[e>>2]=0;e=b+168|0;rZ(c[e>>2]|0);c[e>>2]=0;return}function Zu(a){a=a|0;var b=0,c=0,d=0;b=Ek()|0;do{if((b|0)==0){c=-12}else{Mk(a,b);d=xk(549880)|0;if((d|0)==0){c=-12;break}Ok(a,d);d=Dk()|0;if((d|0)==0){c=-12;break}Nk(a,d);c=0}}while(0);return c|0}function _u(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0.0,m=0,n=0;j=i;i=i+8|0;g=j|0;if((QGb(d,2156952)|0)!=0){k=-38;i=j;return k|0}d=c[b+44>>2]|0;f=d;c[g>>2]=0;l=+HBb(e,g);m=c[g>>2]|0;do{if((m|0)!=0){if((a[m]|0)==0){break}yDb(b,16,2087280,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;k=-22;i=j;return k|0}}while(0);if(l<.5|l>2.0){yDb(b,16,2035760,(n=i,i=i+8|0,h[n>>3]=l,n)|0);i=n;k=-22;i=j;return k|0}else{n=c[d+152>>2]&1^1;b=f+88+(n<<5)|0;e=(c[d+52>>2]|0)/2|0;m=e;g=(e|0)<0|0?-1:0;e=YGb(m,g,c[b>>2]|0,c[b+4>>2]|0)|0;b=d+72|0;c[b>>2]=e;c[b+4>>2]=F;b=f+88+(n<<5)+8|0;n=YGb(m,g,c[b>>2]|0,c[b+4>>2]|0)|0;b=d+80|0;c[b>>2]=n;c[b+4>>2]=F;h[d+64>>3]=l;k=0;i=j;return k|0}return 0}function $u(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=f;h=Ni(c[c[e+16>>2]>>2]|0)|0;if(!((h|0)==-541478725)){j=h;i=b;return j|0}h=c[f+8>>2]|0;e=f+176|0;k=f+180|0;l=f+48|0;m=f+184|0;n=f+152|0;o=f+160|0;p=f+24|0;q=f+32|0;r=a+48|0;s=f+200|0;t=d|0;u=d+4|0;v=a+56|0;w=f+164|0;x=f+52|0;f=c[e>>2]|0;a:while(1){if((f|0)==0){y=fi(a,h)|0;c[e>>2]=y;if((y|0)==0){j=-12;z=24;break}A=c[y>>2]|0;c[k>>2]=A;y=A+(ba(c[l>>2]|0,h)|0)|0;c[m>>2]=y;B=y}else{B=c[m>>2]|0}y=c[n>>2]&1;A=g+88+(y<<5)|0;c[o>>2]=4;C=c[p>>2]|0;D=c[p+4>>2]|0;E=A|0;G=g+88+(y<<5)+20|0;H=c[G>>2]|0;I=H;J=(H|0)<0|0?-1:0;H=YGb(I,J,c[E>>2]|0,c[E+4>>2]|0)|0;E=F;if((C|0)==(H|0)&(D|0)==(E|0)){K=c[q>>2]|0;L=c[q+4>>2]|0;M=g+88+(y<<5)+8|0;N=YGb(c[M>>2]|0,c[M+4>>2]|0,I,J)|0;if((K|0)==(N|0)&(L|0)==(F|0)){O=0}else{z=9}}else{z=9}b:do{if((z|0)==9){z=0;do{if((E|0)<(D|0)|(E|0)==(D|0)&H>>>0<C>>>0){av(g,0,0)|0;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){break}bv(g,A);qZ(c[w>>2]|0,c[g+88+(y<<5)+24>>2]|0);if((cv(g)|0)==0){break}av(g,0,0)|0}}while(0);L=g+88+(y<<5)+8|0;N=(c[x>>2]|0)/2|0;K=c[G>>2]|0;J=(N|0)>(K|0)?K:N;N=YGb(J,(J|0)<0|0?-1:0,c[L>>2]|0,c[L+4>>2]|0)|0;J=F;while(1){P=c[q>>2]|0;Q=c[q+4>>2]|0;if(!((Q|0)<(J|0)|(Q|0)==(J|0)&P>>>0<N>>>0)){break}if((dv(g,k,B)|0)!=0){O=-11;break b}}K=(Q|0)>(J|0)|(Q|0)==(J|0)&P>>>0>N>>>0;I=K?P:N;M=K?Q:J;K=c[L>>2]|0;R=c[L+4>>2]|0;S=c[G>>2]|0;T=YGb(S,(S|0)<0|0?-1:0,K,R)|0;S=F;if((M|0)>(S|0)|(M|0)==(S|0)&I>>>0>T>>>0|((R|0)>(M|0)|(R|0)==(M|0)&K>>>0>I>>>0)){z=17;break a}U=ZGb(I,M,K,R)|0;R=c[g+88+(y<<5)+16>>2]|0;K=c[l>>2]|0;V=gHb(K,(K|0)<0|0?-1:0,U,F)|0;U=c[k>>2]|0;W=ZGb(T,S,I,M)|0;M=ba(K,W)|0;W=B-U|0;K=(M|0)>(W|0)?W:M;UGb(U|0,R+V|0,K)|0;V=(K|0)/(c[l>>2]|0)|0;R=YGb(c[q>>2]|0,c[q+4>>2]|0,V,(V|0)<0|0?-1:0)|0;V=F;c[q>>2]=R;c[q+4>>2]=V;c[k>>2]=U+K;O=(R|0)==(T|0)&(V|0)==(S|0)?0:-11}}while(0);y=c[e>>2]|0;G=((c[k>>2]|0)-(c[y>>2]|0)|0)/(c[l>>2]|0)|0;do{if((G|0)==0){X=y}else{c[y+344>>2]=c[r>>2];c[y+76>>2]=G;A=c[s>>2]|0;C=c[s+4>>2]|0;c[t>>2]=1;c[u>>2]=c[r>>2];H=KDb(A,C,d,v)|0;C=c[e>>2]|0;A=C+136|0;c[A>>2]=H;c[A+4>>2]=F;A=cj(a,C)|0;c[e>>2]=0;c[k>>2]=0;c[m>>2]=0;if((A|0)<0){X=0;break}A=YGb(c[s>>2]|0,c[s+4>>2]|0,G,(G|0)<0|0?-1:0)|0;c[s>>2]=A;c[s+4>>2]=F;X=0}}while(0);if((O|0)==-11){f=X}else{z=23;break}}if((z|0)==17){yDb(0,0,1929576,(X=i,i=i+24|0,c[X>>2]=1907400,c[X+8>>2]=1886712,c[X+16>>2]=956,X)|0);i=X;Cd();return 0}else if((z|0)==23){JCb(e);c[k>>2]=0;c[m>>2]=0;j=-541478725;i=b;return j|0}else if((z|0)==24){i=b;return j|0}return 0}function av(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;e=i;f=c[a+152>>2]&1;g=a+88+(f<<5)|0;h=a+52|0;j=c[h>>2]|0;k=YGb(j,(j|0)<0|0?-1:0,c[g>>2]|0,c[g+4>>2]|0)|0;l=F;m=a+24|0;n=c[m>>2]|0;o=c[m+4>>2]|0;do{if((b|0)==0){p=o;q=n;r=j}else{s=ZGb(k,l,n,o)|0;t=s;if(!((o|0)<(l|0)|(o|0)==(l|0)&n>>>0<k>>>0)){p=o;q=n;r=j;break}s=c[b>>2]|0;u=a+8|0;v=c[u>>2]|0;if((t|0)>(v|0)){yDb(0,0,1929576,(w=i,i=i+24|0,c[w>>2]=2282464,c[w+8>>2]=1886712,c[w+16>>2]=443,w)|0);i=w;Cd();return 0}if(s>>>0<d>>>0){x=d;y=a+48|0;z=a+20|0;A=a+4|0;B=a+12|0;C=a+16|0;D=s;E=c[y>>2]|0;G=v;v=c[z>>2]|0;H=o;I=n;while(1){J=(x-D|0)/(E|0)|0;K=(t|0)>(J|0)?J:t;J=(K|0)>(G|0)?G:K;K=G-v|0;L=(J|0)>(K|0)?K:J;K=J-L|0;J=(K|0)>(G|0)?G:K;if((L|0)==0){M=D;N=E;O=G;P=v;Q=H;R=I}else{UGb((c[A>>2]|0)+(ba(E,v)|0)|0,D|0,ba(L,E)|0)|0;K=c[y>>2]|0;S=D+(ba(K,L)|0)|0;T=YGb(c[m>>2]|0,c[m+4>>2]|0,L,(L|0)<0|0?-1:0)|0;U=F;c[m>>2]=T;c[m+4>>2]=U;V=(c[B>>2]|0)+L|0;W=c[u>>2]|0;X=(V|0)>(W|0)?W:V;c[B>>2]=X;V=((c[z>>2]|0)+L|0)%(W|0)|0;c[z>>2]=V;c[C>>2]=V-((X|0)<(W|0)?X:0);M=S;N=K;O=W;P=V;Q=U;R=T}if((J|0)==0){Y=M;Z=N;_=O;$=P;aa=Q;ca=R}else{UGb(c[A>>2]|0,M|0,ba(N,J)|0)|0;T=c[y>>2]|0;U=M+(ba(T,J)|0)|0;V=YGb(c[m>>2]|0,c[m+4>>2]|0,J,(J|0)<0|0?-1:0)|0;W=F;c[m>>2]=V;c[m+4>>2]=W;K=(c[B>>2]|0)+J|0;S=c[u>>2]|0;X=(K|0)>(S|0)?S:K;c[B>>2]=X;K=((c[z>>2]|0)+J|0)%(S|0)|0;c[z>>2]=K;c[C>>2]=K-((X|0)<(S|0)?X:0);Y=U;Z=T;_=S;$=K;aa=W;ca=V}if(((aa|0)<(l|0)|(aa|0)==(l|0)&ca>>>0<k>>>0)&Y>>>0<d>>>0){D=Y;E=Z;G=_;v=$;H=aa;I=ca}else{da=Y;ea=aa;fa=ca;break}}}else{da=s;ea=o;fa=n}c[b>>2]=da;if((ea|0)>(l|0)|(ea|0)==(l|0)&fa>>>0>k>>>0){yDb(0,0,1929576,(w=i,i=i+24|0,c[w>>2]=2267168,c[w+8>>2]=1886712,c[w+16>>2]=492,w)|0);i=w;Cd();return 0}if((fa|0)==(k|0)&(ea|0)==(l|0)){p=l;q=k;r=c[h>>2]|0;break}else{ga=-11;i=e;return ga|0}}}while(0);h=(l|0)>(p|0)|(l|0)==(p|0)&k>>>0>q>>>0;ea=ZGb(k,l,q,p)|0;l=h?ea:0;ea=h?F:0;h=r;k=(r|0)<0|0?-1:0;if((ea|0)<(k|0)|(ea|0)==(k|0)&l>>>0<h>>>0){r=ZGb(h,k,l,ea)|0;ha=r}else{ha=0}c[a+88+(f<<5)+20>>2]=ha;r=c[a+88+(f<<5)+16>>2]|0;f=c[a+12>>2]|0;ea=ZGb(q,p,f,(f|0)<0|0?-1:0)|0;f=F;p=c[g>>2]|0;q=c[g+4>>2]|0;do{if((q|0)<(f|0)|(q|0)==(f|0)&p>>>0<ea>>>0){l=ZGb(ea,f,p,q)|0;k=F;h=ha;fa=0;da=(k|0)>(fa|0)|(k|0)==(fa|0)&l>>>0>h>>>0;b=da?h:l;l=da?fa:k;if((b|0)==(h|0)&(l|0)==(fa|0)){yDb(0,0,1929576,(w=i,i=i+24|0,c[w>>2]=2322808,c[w+8>>2]=1886712,c[w+16>>2]=540,w)|0);i=w;Cd();return 0}else{k=a+48|0;da=c[k>>2]|0;n=gHb(da,(da|0)<0|0?-1:0,b,l)|0;TGb(r|0,0,n|0)|0;n=c[k>>2]|0;k=gHb(n,(n|0)<0|0?-1:0,b,l)|0;ia=r+k|0;ja=l;ka=b;la=fa;ma=h;break}}else{ia=r;ja=0;ka=0;la=0;ma=ha}}while(0);if((ka|0)==(ma|0)&(ja|0)==(la|0)){ga=0;i=e;return ga|0}ha=c[a+16>>2]|0;r=c[a+20>>2]|0;q=(ha|0)<(r|0);if(q){na=r}else{na=c[a+8>>2]|0}p=na-ha|0;na=YGb(p,(p|0)<0|0?-1:0,ka,ja)|0;h=YGb(na,F,q?0:r,q?0:(r|0)<0|0?-1:0)|0;r=F;if((la|0)>(r|0)|(la|0)==(r|0)&ma>>>0>h>>>0){yDb(0,0,1929576,(w=i,i=i+24|0,c[w>>2]=2299912,c[w+8>>2]=1886712,c[w+16>>2]=558,w)|0);i=w;Cd();return 0}w=c[a+4>>2]|0;h=a+48|0;a=c[h>>2]|0;r=c[g>>2]|0;q=c[g+4>>2]|0;g=ZGb(ka,ja,ea,f)|0;f=YGb(g,F,r,q)|0;q=f;f=(q|0)<(p|0);r=f?0:q-p|0;do{if(f){g=p-q|0;ea=ZGb(ma,la,ka,ja)|0;na=ea;fa=(g|0)>(na|0)?na:g;g=ZGb(ea,F,fa,0)|0;ea=g;if((fa|0)==0){oa=ia;pa=ea;qa=a;break}UGb(ia|0,w+(ba(a,q+ha|0)|0)|0,ba(a,fa)|0)|0;g=c[h>>2]|0;oa=ia+(ba(g,fa)|0)|0;pa=ea;qa=g}else{g=ZGb(ma,la,ka,ja)|0;oa=ia;pa=g;qa=a}}while(0);if((pa|0)==0){ga=0;i=e;return ga|0}UGb(oa|0,w+(ba(qa,r)|0)|0,ba(qa,pa)|0)|0;ga=0;i=e;return ga|0}function bv(a,e){a=a|0;e=e|0;var f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0,A=0,B=0.0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0.0,K=0,L=0,M=0,N=0,O=0,P=0.0,R=0,S=0,T=0,U=0,V=0.0;f=c[e+16>>2]|0;i=e+24|0;TGb(c[i>>2]|0,0,c[a+52>>2]<<3|0)|0;switch(c[a+40>>2]|0){case 3:{j=c[a+44>>2]|0;k=ba(c[e+20>>2]<<2,j)|0;l=f+k|0;m=c[i>>2]|0;n=(k|0)>0;if((j|0)==1){if(n){o=m;p=f}else{return}while(1){k=p+4|0;g[o>>2]=+g[p>>2];if(k>>>0<l>>>0){o=o+4|0;p=k}else{break}}return}if(!n){return}if((j|0)>1){q=m;r=f}else{n=m;m=f;while(1){p=m+4|0;g[n>>2]=+g[m>>2];if(p>>>0<l>>>0){n=n+4|0;m=p}else{break}}return}while(1){s=+g[r>>2];t=+Q(+s);m=(j|0)>2?j<<2:8;u=t<1.0?t:1.0;t=s;n=1;p=r;while(1){o=p+4|0;s=+g[o>>2];v=+Q(+s);w=v<1.0?v:1.0;k=u<w;x=k?s:t;y=n+1|0;if((y|0)<(j|0)){u=k?w:u;t=x;n=y;p=o}else{break}}p=r+m|0;g[q>>2]=x;if(p>>>0<l>>>0){q=q+4|0;r=p}else{break}}return};case 4:{r=c[a+44>>2]|0;q=ba(c[e+20>>2]<<3,r)|0;l=f+q|0;j=c[i>>2]|0;p=(q|0)>0;if((r|0)==1){if(p){z=j;A=f}else{return}while(1){q=A+8|0;g[z>>2]=+h[A>>3];if(q>>>0<l>>>0){z=z+4|0;A=q}else{break}}return}if(!p){return}p=(r|0)>1;A=j;j=f;while(1){x=+h[j>>3];t=+Q(+x);z=j+8|0;if(p){q=(r|0)>2?r<<3:16;u=t<1.0?t:1.0;t=x;n=1;o=z;while(1){w=+h[o>>3];s=+Q(+w);v=s<1.0?s:1.0;y=u<v;B=y?w:t;k=n+1|0;if((k|0)<(r|0)){u=y?v:u;t=B;n=k;o=o+8|0}else{break}}C=B;D=j+q|0}else{C=x;D=z}g[A>>2]=C;if(D>>>0<l>>>0){A=A+4|0;j=D}else{break}}return};case 0:{D=c[a+44>>2]|0;j=ba(D,c[e+20>>2]|0)|0;A=f+j|0;l=c[i>>2]|0;r=(j|0)>0;if((D|0)==1){if(r){E=l;F=f}else{return}while(1){j=F+1|0;g[E>>2]=+((d[F]|0)>>>0);if(j>>>0<A>>>0){E=E+4|0;F=j}else{break}}return}if(r){G=l;H=f}else{return}while(1){C=+((d[H]|0)>>>0);B=+Q(+C);l=H+1|0;if((D|0)>1){r=(D|0)>2?D:2;F=1;t=C;u=B<127.0?B:127.0;E=l;while(1){B=+((d[E]|0)>>>0);v=+Q(+B);w=v<127.0?v:127.0;j=u<w;I=j?B:t;p=F+1|0;if((p|0)<(D|0)){F=p;t=I;u=j?w:u;E=E+1|0}else{break}}J=I;K=H+r|0}else{J=C;K=l}g[G>>2]=J;if(K>>>0<A>>>0){G=G+4|0;H=K}else{break}}return};case 2:{K=c[a+44>>2]|0;H=ba(c[e+20>>2]<<2,K)|0;G=f+H|0;A=c[i>>2]|0;D=(H|0)>0;if((K|0)==1){if(D){L=A;M=f}else{return}while(1){H=M+4|0;g[L>>2]=+(c[M>>2]|0);if(H>>>0<G>>>0){L=L+4|0;M=H}else{break}}return}if(!D){return}if((K|0)>1){N=A;O=f}else{D=A;A=f;while(1){M=A+4|0;g[D>>2]=+(c[A>>2]|0);if(M>>>0<G>>>0){D=D+4|0;A=M}else{break}}return}while(1){J=+(c[O>>2]|0);I=+Q(+J);A=(K|0)>2?K<<2:8;u=I<2147483648.0?I:2147483648.0;I=J;D=1;M=O;while(1){L=M+4|0;J=+(c[L>>2]|0);t=+Q(+J);x=t<2147483648.0?t:2147483648.0;H=u<x;P=H?J:I;E=D+1|0;if((E|0)<(K|0)){u=H?x:u;I=P;D=E;M=L}else{break}}M=O+A|0;g[N>>2]=P;if(M>>>0<G>>>0){N=N+4|0;O=M}else{break}}return};case 1:{O=c[a+44>>2]|0;a=ba(c[e+20>>2]<<1,O)|0;e=f+a|0;N=c[i>>2]|0;i=(a|0)>0;if((O|0)==1){if(i){R=N;S=f}else{return}while(1){a=S+2|0;g[R>>2]=+(b[S>>1]|0);if(a>>>0<e>>>0){R=R+4|0;S=a}else{break}}return}if(!i){return}if((O|0)>1){T=N;U=f}else{i=N;N=f;while(1){f=N+2|0;g[i>>2]=+(b[N>>1]|0);if(f>>>0<e>>>0){i=i+4|0;N=f}else{break}}return}while(1){P=+(b[U>>1]|0);I=+Q(+P);N=(O|0)>2?O<<1:4;u=P;i=1;P=I<32767.0?I:32767.0;f=U;while(1){S=f+2|0;I=+(b[S>>1]|0);C=+Q(+I);x=C<32767.0?C:32767.0;R=P<x;V=R?I:u;a=i+1|0;if((a|0)<(O|0)){u=V;i=a;P=R?x:P;f=S}else{break}}f=U+N|0;g[T>>2]=V;if(f>>>0<e>>>0){T=T+4|0;U=f}else{break}}return};default:{return}}}function cv(a){a=a|0;var b=0,d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0;b=c[a+152>>2]|0;d=b&1^1;e=b&1;b=a+88+(d<<5)+8|0;f=a+80|0;i=ZGb(c[b>>2]|0,c[b+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;f=c[a+52>>2]|0;b=(f|0)/2|0;j=b;k=(b|0)<0|0?-1:0;l=YGb(i,F,j,k)|0;m=+(l>>>0)+ +(F|0)*4294967296.0;l=a+88+(d<<5)|0;i=a+72|0;n=c[i>>2]|0;o=c[i+4>>2]|0;i=YGb(j,k,c[l>>2]|0,c[l+4>>2]|0)|0;l=ZGb(i,F,n,o)|0;o=~~(m-(+(l>>>0)+ +(F|0)*4294967296.0)/+h[a+64>>3]);l=c[a+172>>2]|0;n=c[a+168>>2]|0;i=c[a+88+(e<<5)+24>>2]|0;k=c[a+88+(d<<5)+24>>2]|0;d=-o|0;g[l>>2]=+g[k>>2]*+g[i>>2];g[l+4>>2]=+g[k+4>>2]*+g[i+4>>2];if((f|0)>1){j=l+8|0;p=1;q=k;k=i;while(1){i=q+8|0;r=k+8|0;s=i|0;t=r|0;u=q+12|0;v=k+12|0;g[j>>2]=+g[s>>2]*+g[t>>2]+ +g[u>>2]*+g[v>>2];g[j+4>>2]=+g[u>>2]*+g[t>>2]- +g[s>>2]*+g[v>>2];v=p+1|0;if((v|0)<(f|0)){j=j+8|0;p=v;q=i;k=r}else{break}}}qZ(n,l);n=(d|0)>0?d:0;k=(n|0)>(f|0)?f:n;n=b-o+b|0;q=f-((f|0)/16|0)|0;f=(n|0)>(q|0)?q:n;n=(f|0)>0?f:0;if((k|0)<(n|0)){m=-3.4028234663852886e+38;f=l+(k<<2)|0;l=k;q=d;while(1){w=+g[f>>2]*+(n-l|0)*+(l+o|0)*+(l-k|0);p=w>m;j=p?l-b|0:q;r=l+1|0;if((r|0)<(n|0)){m=p?w:m;f=f+4|0;l=r;q=j}else{x=j;break}}}else{x=d}if((x|0)==0){return x|0}d=a+88+(e<<5)|0;q=ZGb(c[d>>2]|0,c[d+4>>2]|0,x,(x|0)<0|0?-1:0)|0;c[d>>2]=q;c[d+4>>2]=F;c[a+88+(e<<5)+20>>2]=0;return x|0}function dv(e,f,j){e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0.0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0.0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0;k=i;l=c[e+152>>2]|0;m=l&1^1;n=l&1;l=e+88+(n<<5)|0;o=e+32|0;p=c[o>>2]|0;q=c[o+4>>2]|0;r=e+88+(n<<5)+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;r=(q|0)>(t|0)|(q|0)==(t|0)&p>>>0>s>>>0;u=r?p:s;v=r?q:t;r=e+88+(m<<5)+8|0;w=c[r>>2]|0;x=c[r+4>>2]|0;r=c[e+88+(m<<5)+20>>2]|0;y=YGb(r,(r|0)<0|0?-1:0,w,x)|0;r=F;z=c[e+88+(n<<5)+20>>2]|0;A=z;B=(z|0)<0|0?-1:0;z=YGb(A,B,s,t)|0;C=F;D=(r|0)>(C|0)|(r|0)==(C|0)&y>>>0>z>>>0;E=D?z:y;y=D?C:r;r=ZGb(E,y,u,v)|0;C=F;D=ZGb(u,v,w,x)|0;x=F;w=ZGb(u,v,s,t)|0;t=F;s=c[e+56>>2]|0;z=s+(D<<2)|0;G=s+(w<<2)|0;s=c[e+88+(m<<5)+16>>2]|0;m=c[e+48>>2]|0;H=m;I=(m|0)<0|0?-1:0;m=gHb(H,I,D,x)|0;x=s+m|0;m=c[e+88+(n<<5)+16>>2]|0;n=gHb(H,I,w,t)|0;t=m+n|0;n=c[f>>2]|0;if((v|0)>(y|0)|(v|0)==(y|0)&u>>>0>E>>>0|((C|0)>(B|0)|(C|0)==(B|0)&r>>>0>A>>>0)){yDb(0,0,1929576,(A=i,i=i+24|0,c[A>>2]=2344528,c[A+8>>2]=1886712,c[A+16>>2]=798,A)|0);i=A;Cd();return 0}switch(c[e+40>>2]|0){case 2:{A=n;B=j;u=0;if(((C|0)>(u|0)|(C|0)==(u|0)&r>>>0>0>>>0)&n>>>0<j>>>0){u=e+44|0;v=l|0;m=A;w=t;I=0;H=0;s=x;D=G;J=z;K=q;L=p;M=c[u>>2]|0;while(1){N=+g[J>>2];O=+g[D>>2];if((M|0)>0){P=YGb(c[v>>2]|0,c[v+4>>2]|0,H,I)|0;Q=F;R=0;if((Q|0)<(R|0)|(Q|0)==(R|0)&P>>>0<0>>>0){P=m;R=w;Q=s;S=0;while(1){c[P>>2]=c[Q>>2];T=S+1|0;U=Q+4|0;V=R+4|0;W=P+4|0;X=c[u>>2]|0;if((T|0)<(X|0)){P=W;R=V;Q=U;S=T}else{Y=W;Z=V;_=U;$=X;break}}}else{S=m;Q=w;R=s;P=0;while(1){c[S>>2]=~~(N*+(c[R>>2]|0)+O*+(c[Q>>2]|0));X=P+1|0;U=R+4|0;V=Q+4|0;W=S+4|0;T=c[u>>2]|0;if((X|0)<(T|0)){S=W;Q=V;R=U;P=X}else{Y=W;Z=V;_=U;$=T;break}}}}else{Y=m;Z=w;_=s;$=M}P=YGb(H,I,1,0)|0;R=F;aa=YGb(L,K,1,0)|0;ba=F;if(((R|0)<(C|0)|(R|0)==(C|0)&P>>>0<r>>>0)&Y>>>0<B>>>0){m=Y;w=Z;I=R;H=P;s=_;D=D+4|0;J=J+4|0;K=ba;L=aa;M=$}else{break}}c[o>>2]=aa;c[o+4>>2]=ba;ca=Y;da=ba;ea=aa}else{ca=A;da=q;ea=p}fa=ca;ga=da;ha=ea;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};case 3:{ea=n;da=j;ca=0;if(((C|0)>(ca|0)|(C|0)==(ca|0)&r>>>0>0>>>0)&n>>>0<j>>>0){ca=c[e+44>>2]|0;A=(ca|0)>0;aa=l|0;ba=x;Y=t;$=ea;M=0;L=0;K=G;J=z;D=q;_=p;while(1){O=+g[J>>2];N=+g[K>>2];if(A){s=YGb(c[aa>>2]|0,c[aa+4>>2]|0,L,M)|0;H=F;I=0;Z=(H|0)<(I|0)|(H|0)==(I|0)&s>>>0<0>>>0;s=(ca|0)>1?ca:1;I=Y+(s<<2)|0;H=ba;w=Y;m=$;B=0;while(1){ka=+g[H>>2];if(Z){la=ka}else{la=O*ka+N*+g[w>>2]}g[m>>2]=la;u=B+1|0;if((u|0)<(ca|0)){H=H+4|0;w=w+4|0;m=m+4|0;B=u}else{break}}ma=ba+(s<<2)|0;na=I;oa=$+(s<<2)|0}else{ma=ba;na=Y;oa=$}B=YGb(L,M,1,0)|0;m=F;pa=YGb(_,D,1,0)|0;qa=F;if(((m|0)<(C|0)|(m|0)==(C|0)&B>>>0<r>>>0)&oa>>>0<da>>>0){ba=ma;Y=na;$=oa;M=m;L=B;K=K+4|0;J=J+4|0;D=qa;_=pa}else{break}}c[o>>2]=pa;c[o+4>>2]=qa;ra=oa;sa=qa;ta=pa}else{ra=ea;sa=q;ta=p}fa=ra;ga=sa;ha=ta;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};case 4:{ta=n;sa=j;ra=0;if(((C|0)>(ra|0)|(C|0)==(ra|0)&r>>>0>0>>>0)&n>>>0<j>>>0){ra=c[e+44>>2]|0;ea=(ra|0)>0;pa=l|0;qa=x;oa=t;_=ta;D=0;J=0;K=G;L=z;M=q;$=p;while(1){la=+g[L>>2];N=+g[K>>2];if(ea){na=YGb(c[pa>>2]|0,c[pa+4>>2]|0,J,D)|0;Y=F;ma=0;ba=(Y|0)<(ma|0)|(Y|0)==(ma|0)&na>>>0<0>>>0;na=(ra|0)>1?ra:1;ma=oa+(na<<3)|0;Y=qa;da=oa;ca=_;aa=0;while(1){O=+h[Y>>3];if(ba){ua=O}else{ua=la*O+N*+h[da>>3]}h[ca>>3]=ua;A=aa+1|0;if((A|0)<(ra|0)){Y=Y+8|0;da=da+8|0;ca=ca+8|0;aa=A}else{break}}va=qa+(na<<3)|0;wa=ma;xa=_+(na<<3)|0}else{va=qa;wa=oa;xa=_}aa=YGb(J,D,1,0)|0;ca=F;ya=YGb($,M,1,0)|0;za=F;if(((ca|0)<(C|0)|(ca|0)==(C|0)&aa>>>0<r>>>0)&xa>>>0<sa>>>0){qa=va;oa=wa;_=xa;D=ca;J=aa;K=K+4|0;L=L+4|0;M=za;$=ya}else{break}}c[o>>2]=ya;c[o+4>>2]=za;Aa=xa;Ba=za;Ca=ya}else{Aa=ta;Ba=q;Ca=p}fa=Aa;ga=Ba;ha=Ca;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};case 0:{Ca=0;if(!(((C|0)>(Ca|0)|(C|0)==(Ca|0)&r>>>0>0>>>0)&n>>>0<j>>>0)){fa=n;ga=q;ha=p;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0}Ca=e+44|0;Ba=l|0;Aa=0;ta=0;ya=n;za=t;xa=x;$=G;M=z;L=c[Ca>>2]|0;K=q;J=p;while(1){ua=+g[M>>2];N=+g[$>>2];if((L|0)>0){D=0;_=ya;wa=za;oa=xa;do{va=a[oa]|0;qa=YGb(c[Ba>>2]|0,c[Ba+4>>2]|0,ta,Aa)|0;sa=F;ra=0;if((sa|0)<(ra|0)|(sa|0)==(ra|0)&qa>>>0<0>>>0){Da=va}else{Da=~~(ua*+((va&255)>>>0)+N*+((d[wa]|0)>>>0))}a[_]=Da;D=D+1|0;oa=oa+1|0;wa=wa+1|0;_=_+1|0;Ea=c[Ca>>2]|0;}while((D|0)<(Ea|0));Fa=_;Ga=wa;Ha=oa;Ia=Ea;Ja=c[o+4>>2]|0;Ka=c[o>>2]|0}else{Fa=ya;Ga=za;Ha=xa;Ia=L;Ja=K;Ka=J}D=YGb(ta,Aa,1,0)|0;na=F;ma=YGb(Ka,Ja,1,0)|0;va=F;c[o>>2]=ma;c[o+4>>2]=va;if(((na|0)<(C|0)|(na|0)==(C|0)&D>>>0<r>>>0)&Fa>>>0<j>>>0){Aa=na;ta=D;ya=Fa;za=Ga;xa=Ha;$=$+4|0;M=M+4|0;L=Ia;K=va;J=ma}else{fa=Fa;ga=va;ha=ma;break}}c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};case 1:{Fa=n;J=j;K=0;if(((C|0)>(K|0)|(C|0)==(K|0)&r>>>0>0>>>0)&n>>>0<j>>>0){j=c[e+44>>2]|0;e=(j|0)>0;K=l|0;l=0;Ia=0;L=Fa;M=t;t=x;x=G;G=z;z=q;$=p;while(1){N=+g[G>>2];ua=+g[x>>2];if(e){Ha=YGb(c[K>>2]|0,c[K+4>>2]|0,Ia,l)|0;xa=F;Ga=0;za=(j|0)>1?j:1;if((xa|0)<(Ga|0)|(xa|0)==(Ga|0)&Ha>>>0<0>>>0){Ha=0;Ga=L;xa=t;while(1){b[Ga>>1]=b[xa>>1]|0;ya=Ha+1|0;if((ya|0)<(j|0)){Ha=ya;Ga=Ga+2|0;xa=xa+2|0}else{break}}}else{xa=0;Ga=L;Ha=M;oa=t;while(1){b[Ga>>1]=~~(N*+(b[oa>>1]|0)+ua*+(b[Ha>>1]|0));wa=xa+1|0;if((wa|0)<(j|0)){xa=wa;Ga=Ga+2|0;Ha=Ha+2|0;oa=oa+2|0}else{break}}}La=L+(za<<1)|0;Ma=M+(za<<1)|0;Na=t+(za<<1)|0}else{La=L;Ma=M;Na=t}oa=YGb(Ia,l,1,0)|0;Ha=F;Oa=YGb($,z,1,0)|0;Pa=F;if(((Ha|0)<(C|0)|(Ha|0)==(C|0)&oa>>>0<r>>>0)&La>>>0<J>>>0){l=Ha;Ia=oa;L=La;M=Ma;t=Na;x=x+4|0;G=G+4|0;z=Pa;$=Oa}else{break}}c[o>>2]=Oa;c[o+4>>2]=Pa;Qa=La;Ra=Pa;Sa=Oa}else{Qa=Fa;Ra=q;Sa=p}fa=Qa;ga=Ra;ha=Sa;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};default:{fa=n;ga=q;ha=p;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0}}return 0}function ev(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0.0,R=0,S=0,T=0,U=0,V=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[f>>2]=b;j=c[a+8>>2]|0;a=c[j+44>>2]|0;k=a;l=c[c[j+32>>2]>>2]|0;j=c[b+76>>2]|0;m=a+64|0;n=~~(+(j|0)/+h[m>>3]+.5);o=c[b>>2]|0;c[g>>2]=o;b=a+48|0;p=ba(c[b>>2]|0,j)|0;q=o+p|0;a:do{if((p|0)>0){o=a+176|0;r=a+180|0;s=a+184|0;t=a+160|0;u=a+152|0;v=a+164|0;w=a+52|0;x=a+88|0;y=a+120|0;z=a+96|0;A=a+128|0;B=a+140|0;C=l+48|0;D=a+200|0;G=e|0;H=e+4|0;I=l+56|0;while(1){if((c[o>>2]|0)==0){J=fi(l,n)|0;c[o>>2]=J;if((J|0)==0){K=-12;break}NCb(J,c[f>>2]|0)|0;J=c[c[o>>2]>>2]|0;c[r>>2]=J;L=J+(ba(c[b>>2]|0,n)|0)|0;c[s>>2]=L;M=L}else{M=c[s>>2]|0}b:while(1){L=c[t>>2]|0;while(1){if((L|0)==1){N=14}else if((L|0)==2){N=17}else if((L|0)==0){if((av(k,g,q)|0)!=0){break b}bv(k,k+88+((c[u>>2]&1)<<5)|0);qZ(c[v>>2]|0,c[k+88+((c[u>>2]&1)<<5)+24>>2]|0);if((c[u>>2]|0)==0&(c[u+4>>2]|0)==0){break}c[t>>2]=1;N=14}else if((L|0)!=3){continue b}do{if((N|0)==14){N=0;if((cv(k)|0)==0){c[t>>2]=3;break}else{c[t>>2]=2;N=17;break}}}while(0);if((N|0)==17){N=0;if((av(k,g,q)|0)!=0){break b}bv(k,k+88+((c[u>>2]&1)<<5)|0);qZ(c[v>>2]|0,c[k+88+((c[u>>2]&1)<<5)+24>>2]|0);c[t>>2]=3}if((dv(k,r,M)|0)!=0){break b}J=(c[w>>2]|0)/2|0;O=+h[m>>3]*+(J|0);R=YGb(c[u>>2]|0,c[u+4>>2]|0,1,0)|0;c[u>>2]=R;c[u+4>>2]=F;S=R&1^1;T=R&1;R=k+88+(S<<5)|0;U=YGb(~~+O>>>0,(E=+O,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0),c[R>>2]|0,c[R+4>>2]|0)|0;R=k+88+(T<<5)|0;c[R>>2]=U;c[R+4>>2]=F;R=k+88+(S<<5)+8|0;S=YGb(c[R>>2]|0,c[R+4>>2]|0,J,(J|0)<0|0?-1:0)|0;J=k+88+(T<<5)+8|0;c[J>>2]=S;c[J+4>>2]=F;c[k+88+(T<<5)+20>>2]=0;c[t>>2]=0;L=0}L=(c[w>>2]|0)/2|0;O=+h[m>>3]*+(L|0);c[u>>2]=1;c[u+4>>2]=0;T=YGb(~~+O>>>0,(E=+O,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0),c[x>>2]|0,c[x+4>>2]|0)|0;c[y>>2]=T;c[y+4>>2]=F;T=YGb(c[z>>2]|0,c[z+4>>2]|0,L,(L|0)<0|0?-1:0)|0;c[A>>2]=T;c[A+4>>2]=F;c[B>>2]=0}T=c[r>>2]|0;if((T|0)==(c[s>>2]|0)){L=c[o>>2]|0;J=(T-(c[L>>2]|0)|0)/(c[b>>2]|0)|0;c[L+344>>2]=c[C>>2];c[L+76>>2]=J;L=c[D>>2]|0;T=c[D+4>>2]|0;c[G>>2]=1;c[H>>2]=c[C>>2];S=KDb(L,T,e,I)|0;T=c[o>>2]|0;L=T+136|0;c[L>>2]=S;c[L+4>>2]=F;L=cj(l,T)|0;c[o>>2]=0;c[r>>2]=0;c[s>>2]=0;if((L|0)<0){V=L;break a}L=YGb(c[D>>2]|0,c[D+4>>2]|0,J,(J|0)<0|0?-1:0)|0;c[D>>2]=L;c[D+4>>2]=F}if(!((c[g>>2]|0)>>>0<q>>>0)){N=25;break a}}i=d;return K|0}else{N=25}}while(0);if((N|0)==25){N=a+192|0;a=YGb(c[N>>2]|0,c[N+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[N>>2]=a;c[N+4>>2]=F;V=0}JCb(f);K=V;i=d;return K|0}function fv(a){a=a|0;var b=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;b=i;e=c[a+8>>2]|0;f=c[e+44>>2]|0;h=c[a+52>>2]|0;j=c[a+48>>2]|0;k=a+40|0;a=hBb(c[k>>2]|0,c[k+4>>2]|0)|0;k=(c[c[e+32>>2]>>2]|0)+156|0;c[k>>2]=c[k>>2]|1;k=BFb(h)|0;c[f+40>>2]=h;c[f+44>>2]=a;h=f+48|0;c[h>>2]=ba(k,a)|0;a=(j|0)/24|0;j=f+52|0;c[j>>2]=a;k=a>>>0>65535>>>0;e=k?a>>>16:a;l=k?16:0;if((e&65280|0)==0){m=l;n=e}else{m=l|8;n=e>>>8}e=(d[1191992+n|0]|0)+m|0;m=1<<e;if(m>>>0>a>>>0){yDb(0,0,1929576,(n=i,i=i+24|0,c[n>>2]=2251872,c[n+8>>2]=1886712,c[n+16>>2]=272,n)|0);i=n;Cd();return 0}if(m>>>0<a>>>0){c[j>>2]=m<<1;o=e+1|0}else{o=e}e=f+104|0;$Db(e);m=WDb(ba(c[h>>2]|0,c[j>>2]|0)|0)|0;c[e>>2]=m;if((m|0)==0){m=f+152|0;c[m>>2]=0;c[m+4>>2]=0;c[f+160>>2]=0;m=f+88|0;a=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;n=(c[j>>2]|0)/2|0;l=ZGb(0,0,n,(n|0)<0|0?-1:0)|0;n=F;c[m>>2]=l;c[m+4>>2]=n;c[a>>2]=l;c[a+4>>2]=n;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;$Db(e);$Db(f+136|0);$Db(f+112|0);$Db(f+144|0);$Db(f+4|0);$Db(f+56|0);$Db(f+172|0);n=f+164|0;rZ(c[n>>2]|0);c[n>>2]=0;n=f+168|0;rZ(c[n>>2]|0);c[n>>2]=0;p=-12;i=b;return p|0}n=f+136|0;$Db(n);a=WDb(ba(c[h>>2]|0,c[j>>2]|0)|0)|0;c[n>>2]=a;if((a|0)==0){a=f+152|0;c[a>>2]=0;c[a+4>>2]=0;c[f+160>>2]=0;a=f+88|0;l=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;m=(c[j>>2]|0)/2|0;k=ZGb(0,0,m,(m|0)<0|0?-1:0)|0;m=F;c[a>>2]=k;c[a+4>>2]=m;c[l>>2]=k;c[l+4>>2]=m;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;$Db(e);$Db(n);$Db(f+112|0);$Db(f+144|0);$Db(f+4|0);$Db(f+56|0);$Db(f+172|0);m=f+164|0;rZ(c[m>>2]|0);c[m>>2]=0;m=f+168|0;rZ(c[m>>2]|0);c[m>>2]=0;p=-12;i=b;return p|0}m=f+112|0;$Db(m);l=WDb(c[j>>2]<<3)|0;c[m>>2]=l;if((l|0)==0){l=f+152|0;c[l>>2]=0;c[l+4>>2]=0;c[f+160>>2]=0;l=f+88|0;k=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;a=(c[j>>2]|0)/2|0;q=ZGb(0,0,a,(a|0)<0|0?-1:0)|0;a=F;c[l>>2]=q;c[l+4>>2]=a;c[k>>2]=q;c[k+4>>2]=a;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;$Db(e);$Db(n);$Db(m);$Db(f+144|0);$Db(f+4|0);$Db(f+56|0);$Db(f+172|0);a=f+164|0;rZ(c[a>>2]|0);c[a>>2]=0;a=f+168|0;rZ(c[a>>2]|0);c[a>>2]=0;p=-12;i=b;return p|0}a=f+144|0;$Db(a);k=WDb(c[j>>2]<<3)|0;c[a>>2]=k;if((k|0)==0){k=f+152|0;c[k>>2]=0;c[k+4>>2]=0;c[f+160>>2]=0;k=f+88|0;q=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;l=(c[j>>2]|0)/2|0;r=ZGb(0,0,l,(l|0)<0|0?-1:0)|0;l=F;c[k>>2]=r;c[k+4>>2]=l;c[q>>2]=r;c[q+4>>2]=l;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;$Db(e);$Db(n);$Db(m);$Db(a);$Db(f+4|0);$Db(f+56|0);$Db(f+172|0);l=f+164|0;rZ(c[l>>2]|0);c[l>>2]=0;l=f+168|0;rZ(c[l>>2]|0);c[l>>2]=0;p=-12;i=b;return p|0}l=f+164|0;rZ(c[l>>2]|0);c[l>>2]=0;q=f+168|0;rZ(c[q>>2]|0);c[q>>2]=0;r=o+1|0;o=pZ(r,0)|0;c[l>>2]=o;if((o|0)==0){o=f+152|0;c[o>>2]=0;c[o+4>>2]=0;c[f+160>>2]=0;o=f+88|0;k=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;s=(c[j>>2]|0)/2|0;t=ZGb(0,0,s,(s|0)<0|0?-1:0)|0;s=F;c[o>>2]=t;c[o+4>>2]=s;c[k>>2]=t;c[k+4>>2]=s;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;$Db(e);$Db(n);$Db(m);$Db(a);$Db(f+4|0);$Db(f+56|0);$Db(f+172|0);rZ(c[l>>2]|0);c[l>>2]=0;rZ(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}s=pZ(r,1)|0;c[q>>2]=s;if((s|0)==0){s=f+152|0;c[s>>2]=0;c[s+4>>2]=0;c[f+160>>2]=0;s=f+88|0;r=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;k=(c[j>>2]|0)/2|0;t=ZGb(0,0,k,(k|0)<0|0?-1:0)|0;k=F;c[s>>2]=t;c[s+4>>2]=k;c[r>>2]=t;c[r+4>>2]=k;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;$Db(e);$Db(n);$Db(m);$Db(a);$Db(f+4|0);$Db(f+56|0);$Db(f+172|0);rZ(c[l>>2]|0);c[l>>2]=0;rZ(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}k=f+172|0;$Db(k);r=WDb(c[j>>2]<<3)|0;c[k>>2]=r;if((r|0)==0){r=f+152|0;c[r>>2]=0;c[r+4>>2]=0;c[f+160>>2]=0;r=f+88|0;t=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;s=(c[j>>2]|0)/2|0;o=ZGb(0,0,s,(s|0)<0|0?-1:0)|0;s=F;c[r>>2]=o;c[r+4>>2]=s;c[t>>2]=o;c[t+4>>2]=s;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;$Db(e);$Db(n);$Db(m);$Db(a);$Db(f+4|0);$Db(f+56|0);$Db(k);rZ(c[l>>2]|0);c[l>>2]=0;rZ(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}s=f+8|0;c[s>>2]=(c[j>>2]|0)*3|0;t=f+4|0;$Db(t);o=WDb(ba(c[h>>2]|0,c[s>>2]|0)|0)|0;c[t>>2]=o;if((o|0)==0){o=f+152|0;c[o>>2]=0;c[o+4>>2]=0;c[f+160>>2]=0;o=f+88|0;s=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;h=(c[j>>2]|0)/2|0;r=ZGb(0,0,h,(h|0)<0|0?-1:0)|0;h=F;c[o>>2]=r;c[o+4>>2]=h;c[s>>2]=r;c[s+4>>2]=h;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;$Db(e);$Db(n);$Db(m);$Db(a);$Db(t);$Db(f+56|0);$Db(k);rZ(c[l>>2]|0);c[l>>2]=0;rZ(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}h=f+56|0;$Db(h);s=WDb(c[j>>2]<<2)|0;r=s;c[h>>2]=r;if((s|0)==0){s=f+152|0;c[s>>2]=0;c[s+4>>2]=0;c[f+160>>2]=0;s=f+88|0;o=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;u=(c[j>>2]|0)/2|0;v=ZGb(0,0,u,(u|0)<0|0?-1:0)|0;u=F;c[s>>2]=v;c[s+4>>2]=u;c[o>>2]=v;c[o+4>>2]=u;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;$Db(e);$Db(n);$Db(m);$Db(a);$Db(t);$Db(h);$Db(k);rZ(c[l>>2]|0);c[l>>2]=0;rZ(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}q=c[j>>2]|0;if((q|0)>0){w=+(q-1|0);j=0;do{g[r+(j<<2)>>2]=(1.0- +T(+(j|0)/w*6.283185307179586))*.5;j=j+1|0;}while((j|0)<(q|0))}j=f+152|0;c[j>>2]=0;c[j+4>>2]=0;c[f+160>>2]=0;j=f+88|0;r=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;TGb(f+12|0,0,28)|0;TGb(f+72|0,0,16)|0;TGb(f+120|0,0,16)|0;l=(q|0)/2|0;q=ZGb(0,0,l,(l|0)<0|0?-1:0)|0;l=F;c[j>>2]=q;c[j+4>>2]=l;c[r>>2]=q;c[r+4>>2]=l;JCb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;TGb(f+192|0,0,16)|0;p=0;i=b;return p|0}function gv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1341688;c[e+4>>2]=1;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}yDb(a,16,2215104,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function hv(a){a=a|0;$Db((c[a+44>>2]|0)+96|0);return}function iv(a){a=a|0;var b=0,c=0,d=0;b=Ek()|0;do{if((b|0)==0){c=-12}else{Mk(a,b);d=xk(549856)|0;if((d|0)==0){c=-12;break}Ok(a,d);d=Dk()|0;if((d|0)==0){c=-12;break}Nk(a,d);c=0}}while(0);return c|0}function jv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1734752;c[e+4>>2]=2;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}yDb(a,16,2215104,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function kv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=183704;c[e+4>>2]=3;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}yDb(a,16,2215104,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function lv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1738144;c[e+4>>2]=5;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}yDb(a,16,2215104,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function mv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1737568;c[e+4>>2]=6;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}yDb(a,16,2215104,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function nv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=766512;c[e+4>>2]=9;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}yDb(a,16,2215104,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function ov(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=943648;c[e+4>>2]=8;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}yDb(a,16,2215104,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function pv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1797776;c[e+4>>2]=7;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}yDb(a,16,2215104,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function qv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1693328;c[e+4>>2]=0;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}yDb(a,16,2215104,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function rv(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0.0,j=0,k=0.0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0;b=i;d=c[a>>2]|0;a=c[d+44>>2]|0;e=c[c[d+16>>2]>>2]|0;f=+_(+h[a+24>>3]/40.0*2.302585092994046);g=+h[a+32>>3];j=c[e+48>>2]|0;k=g*6.283185307179586/+(j|0);if(k>3.141592653589793){yDb(d,16,1990320,(l=i,i=i+16|0,h[l>>3]=g,c[l+8>>2]=j,l)|0);i=l;m=-22;i=b;return m|0}switch(c[a+8>>2]|0){case 0:{n=0.0;break};case 3:{n=+U(k)/(+h[a+40>>3]*2.0);break};case 1:{n=+U(k)/(g*2.0/+h[a+40>>3]);break};case 4:{n=+U(k)*.5*+R((f+1.0/f)*(1.0/+h[a+40>>3]+-1.0)+2.0);break};case 2:{g=+U(k);n=g*+oc(+(k*+h[a+40>>3]*.34657359027997264/g));break};default:{yDb(0,0,1986768,(l=i,i=i+24|0,c[l>>2]=1982888,c[l+8>>2]=1979928,c[l+16>>2]=266,l)|0);i=l;Cd();return 0}}a:do{switch(c[a+4>>2]|0){case 8:{if((c[a+12>>2]|0)==1){h[a+48>>3]=1.0;g=+_(-0.0-k);o=-0.0-g;h[a+56>>3]=o;h[a+64>>3]=0.0;p=(g+1.0)*.5;h[a+72>>3]=p;g=-0.0-p;h[a+80>>3]=g;h[a+88>>3]=0.0;q=1.0;r=o;s=0.0;t=p;u=g;v=0.0;break a}else{g=n+1.0;h[a+48>>3]=g;p=+T(k);o=p*-2.0;h[a+56>>3]=o;w=1.0-n;h[a+64>>3]=w;x=p+1.0;p=x*.5;h[a+72>>3]=p;y=-0.0-x;h[a+80>>3]=y;h[a+88>>3]=p;q=g;r=o;s=w;t=p;u=y;v=p;break a}break};case 7:{p=n+1.0;h[a+48>>3]=p;y=+T(k)*-2.0;h[a+56>>3]=y;w=1.0-n;h[a+64>>3]=w;h[a+72>>3]=w;h[a+80>>3]=y;h[a+88>>3]=p;q=p;r=y;s=w;t=w;u=y;v=p;break};case 0:{q=+h[a+48>>3];r=+h[a+56>>3];s=+h[a+64>>3];t=+h[a+72>>3];u=+h[a+80>>3];v=+h[a+88>>3];break};case 1:{p=n/f;y=p+1.0;h[a+48>>3]=y;w=+T(k)*-2.0;h[a+56>>3]=w;o=1.0-p;h[a+64>>3]=o;p=f*n;g=p+1.0;h[a+72>>3]=g;h[a+80>>3]=w;x=1.0-p;h[a+88>>3]=x;q=y;r=w;s=o;t=g;u=w;v=x;break};case 5:{j=(c[a+16>>2]|0)==0;x=n+1.0;h[a+48>>3]=x;w=+T(k)*-2.0;h[a+56>>3]=w;g=1.0-n;h[a+64>>3]=g;if(j){h[a+72>>3]=n;h[a+80>>3]=0.0;o=-0.0-n;h[a+88>>3]=o;q=x;r=w;s=g;t=n;u=0.0;v=o;break a}else{o=+U(k);y=o*.5;h[a+72>>3]=y;h[a+80>>3]=0.0;p=o*-.5;h[a+88>>3]=p;q=x;r=w;s=g;t=y;u=0.0;v=p;break a}break};case 6:{p=n+1.0;h[a+48>>3]=p;y=+T(k)*-2.0;h[a+56>>3]=y;g=1.0-n;h[a+64>>3]=g;h[a+72>>3]=1.0;h[a+80>>3]=y;h[a+88>>3]=1.0;q=p;r=y;s=g;t=1.0;u=y;v=1.0;break};case 3:{y=f+1.0;g=f+-1.0;p=+T(k);w=g*p;x=y-w;o=n*+R(f)*2.0;z=x+o;h[a+48>>3]=z;A=y*p;p=(g-A)*2.0;h[a+56>>3]=p;B=x-o;h[a+64>>3]=B;x=y+w;w=f*(x+o);h[a+72>>3]=w;y=f*-2.0*(g+A);h[a+80>>3]=y;A=f*(x-o);h[a+88>>3]=A;q=z;r=p;s=B;t=w;u=y;v=A;break};case 2:{A=f+1.0;y=f+-1.0;w=+T(k);B=y*w;p=A+B;z=n*+R(f)*2.0;o=p+z;h[a+48>>3]=o;x=A*w;w=(y+x)*-2.0;h[a+56>>3]=w;g=p-z;h[a+64>>3]=g;p=A-B;B=f*(p+z);h[a+72>>3]=B;A=f*2.0*(y-x);h[a+80>>3]=A;x=f*(p-z);h[a+88>>3]=x;q=o;r=w;s=g;t=B;u=A;v=x;break};case 9:{if((c[a+12>>2]|0)==1){h[a+48>>3]=1.0;x=+_(-0.0-k);A=-0.0-x;h[a+56>>3]=A;h[a+64>>3]=0.0;B=1.0-x;h[a+72>>3]=B;TGb(a+80|0,0,16)|0;q=1.0;r=A;s=0.0;t=B;u=0.0;v=0.0;break a}else{B=n+1.0;h[a+48>>3]=B;A=+T(k);x=A*-2.0;h[a+56>>3]=x;g=1.0-n;h[a+64>>3]=g;w=1.0-A;A=w*.5;h[a+72>>3]=A;h[a+80>>3]=w;h[a+88>>3]=A;q=B;r=x;s=g;t=A;u=w;v=A;break a}break};default:{yDb(0,0,1986768,(l=i,i=i+24|0,c[l>>2]=1982888,c[l+8>>2]=1979928,c[l+16>>2]=364,l)|0);i=l;Cd();return 0}}}while(0);h[a+56>>3]=r/q;h[a+64>>3]=s/q;h[a+72>>3]=t/q;h[a+80>>3]=u/q;h[a+88>>3]=v/q;j=a+96|0;d=e+148|0;C=YDb(c[j>>2]|0,32,c[d>>2]|0)|0;c[j>>2]=C;if((C|0)==0){m=-12;i=b;return m|0}TGb(C|0,0,c[d>>2]<<5|0)|0;d=c[e+52>>2]|0;if((d|0)==6){c[a+100>>2]=8;m=0;i=b;return m|0}else if((d|0)==7){c[a+100>>2]=2;m=0;i=b;return m|0}else if((d|0)==8){c[a+100>>2]=4;m=0;i=b;return m|0}else if((d|0)==9){c[a+100>>2]=6;m=0;i=b;return m|0}else{yDb(0,0,1986768,(l=i,i=i+24|0,c[l>>2]=1982888,c[l+8>>2]=1979928,c[l+16>>2]=383,l)|0);i=l;Cd();return 0}return 0}function sv(a,d,e,f,g,j,k,l,m,n,o,p){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=+l;m=+m;n=+n;o=+o;p=+p;var q=0,r=0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0.0,F=0.0,G=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0;q=i;r=a;a=d;s=+h[f>>3];t=+h[g>>3];u=+h[j>>3];v=+h[k>>3];w=-0.0-o;o=-0.0-p;if((e|0)>1){p=s;x=t;y=u;z=v;d=0;A=1;while(1){B=+(b[r+(d<<1)>>1]|0);C=y*w+(z*o+(p*m+x*n+B*l));do{if(C<-32768.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(d<<1)>>1]=-32768}else{if(C>32767.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(d<<1)>>1]=32767;break}else{b[a+(d<<1)>>1]=~~C;break}}}while(0);E=+(b[r+(A<<1)>>1]|0);F=C*w+(y*o+(p*n+B*m+E*l));do{if(F<-32768.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(A<<1)>>1]=-32768}else{if(F>32767.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(A<<1)>>1]=32767;break}else{b[a+(A<<1)>>1]=~~F;break}}}while(0);G=d+2|0;H=G|1;if((H|0)<(e|0)){p=E;x=B;y=F;z=C;d=G;A=H}else{I=E;J=B;K=F;L=C;M=G;break}}}else{I=s;J=t;K=u;L=v;M=0}if((M|0)>=(e|0)){N=L;O=K;P=J;Q=I;h[f>>3]=Q;h[g>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}v=+(b[r+(M<<1)>>1]|0);u=L*o+(K*w+(J*n+(I*m+v*l)));if(u<-32768.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(M<<1)>>1]=-32768;N=K;O=u;P=I;Q=v;h[f>>3]=Q;h[g>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}if(u>32767.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(M<<1)>>1]=32767;N=K;O=u;P=I;Q=v;h[f>>3]=Q;h[g>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}else{b[a+(M<<1)>>1]=~~u;N=K;O=u;P=I;Q=v;h[f>>3]=Q;h[g>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}}function tv(a,b,d,e,f,g,j,k,l,m,n,o){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=+k;l=+l;m=+m;n=+n;o=+o;var p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0,D=0.0,E=0.0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0,M=0.0,N=0.0,O=0.0,P=0.0;p=i;q=a;a=b;r=+h[e>>3];s=+h[f>>3];t=+h[g>>3];u=+h[j>>3];v=-0.0-n;n=-0.0-o;if((d|0)>1){o=r;w=s;x=t;y=u;b=0;z=1;while(1){A=+(c[q+(b<<2)>>2]|0);B=x*v+(y*n+(o*l+w*m+A*k));do{if(B<-2147483648.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(b<<2)>>2]=-2147483648}else{if(B>2147483647.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(b<<2)>>2]=2147483647;break}else{c[a+(b<<2)>>2]=~~B;break}}}while(0);D=+(c[q+(z<<2)>>2]|0);E=B*v+(x*n+(o*m+A*l+D*k));do{if(E<-2147483648.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(z<<2)>>2]=-2147483648}else{if(E>2147483647.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(z<<2)>>2]=2147483647;break}else{c[a+(z<<2)>>2]=~~E;break}}}while(0);F=b+2|0;G=F|1;if((G|0)<(d|0)){o=D;w=A;x=E;y=B;b=F;z=G}else{H=D;I=A;J=E;K=B;L=F;break}}}else{H=r;I=s;J=t;K=u;L=0}if((L|0)>=(d|0)){M=K;N=J;O=I;P=H;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}u=+(c[q+(L<<2)>>2]|0);t=K*n+(J*v+(I*m+(H*l+u*k)));if(t<-2147483648.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(L<<2)>>2]=-2147483648;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}if(t>2147483647.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(L<<2)>>2]=2147483647;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}else{c[a+(L<<2)>>2]=~~t;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}}function uv(a,b,d,e,f,j,k,l,m,n,o,p){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;j=j|0;k=k|0;l=+l;m=+m;n=+n;o=+o;p=+p;var q=0,r=0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0.0,F=0.0,G=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0;q=i;r=a;a=b;s=+h[e>>3];t=+h[f>>3];u=+h[j>>3];v=+h[k>>3];w=-0.0-o;o=-0.0-p;if((d|0)>1){p=s;x=t;y=u;z=v;b=0;A=1;while(1){B=+g[r+(b<<2)>>2];C=y*w+(z*o+(p*m+x*n+B*l));do{if(C<-1.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(b<<2)>>2]=-1.0}else{if(C>1.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(b<<2)>>2]=1.0;break}else{g[a+(b<<2)>>2]=C;break}}}while(0);E=+g[r+(A<<2)>>2];F=C*w+(y*o+(p*n+B*m+E*l));do{if(F<-1.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(A<<2)>>2]=-1.0}else{if(F>1.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(A<<2)>>2]=1.0;break}else{g[a+(A<<2)>>2]=F;break}}}while(0);G=b+2|0;H=G|1;if((H|0)<(d|0)){p=E;x=B;y=F;z=C;b=G;A=H}else{I=E;J=B;K=F;L=C;M=G;break}}}else{I=s;J=t;K=u;L=v;M=0}if((M|0)>=(d|0)){N=L;O=K;P=J;Q=I;h[e>>3]=Q;h[f>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}v=+g[r+(M<<2)>>2];u=L*o+(K*w+(J*n+(I*m+v*l)));if(u<-1.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(M<<2)>>2]=-1.0;N=K;O=u;P=I;Q=v;h[e>>3]=Q;h[f>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}if(u>1.0){yDb(0,24,1977256,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(M<<2)>>2]=1.0;N=K;O=u;P=I;Q=v;h[e>>3]=Q;h[f>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}else{g[a+(M<<2)>>2]=u;N=K;O=u;P=I;Q=v;h[e>>3]=Q;h[f>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}}function vv(a,b,d,e,f,g,j,k,l,m,n,o){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=+k;l=+l;m=+m;n=+n;o=+o;var p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0,D=0.0,E=0.0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0,M=0.0,N=0.0,O=0.0,P=0.0;p=i;q=a;a=b;r=+h[e>>3];s=+h[f>>3];t=+h[g>>3];u=+h[j>>3];v=-0.0-n;n=-0.0-o;if((d|0)>1){o=r;w=s;x=t;y=u;b=0;z=1;while(1){A=+h[q+(b<<3)>>3];B=x*v+(y*n+(o*l+w*m+A*k));do{if(B<-1.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(b<<3)>>3]=-1.0}else{if(B>1.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(b<<3)>>3]=1.0;break}else{h[a+(b<<3)>>3]=B;break}}}while(0);D=+h[q+(z<<3)>>3];E=B*v+(x*n+(o*m+A*l+D*k));do{if(E<-1.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(z<<3)>>3]=-1.0}else{if(E>1.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(z<<3)>>3]=1.0;break}else{h[a+(z<<3)>>3]=E;break}}}while(0);F=b+2|0;G=F|1;if((G|0)<(d|0)){o=D;w=A;x=E;y=B;b=F;z=G}else{H=D;I=A;J=E;K=B;L=F;break}}}else{H=r;I=s;J=t;K=u;L=0}if((L|0)>=(d|0)){M=K;N=J;O=I;P=H;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}u=+h[q+(L<<3)>>3];t=K*n+(J*v+(I*m+(H*l+u*k)));if(t<-1.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(L<<3)>>3]=-1.0;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}if(t>1.0){yDb(0,24,1977256,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(L<<3)>>3]=1.0;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}else{h[a+(L<<3)>>3]=t;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}}function wv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;j=c[c[f+32>>2]>>2]|0;f=c[b+76>>2]|0;do{if((RCb(b)|0)==0){k=fi(a,f)|0;if((k|0)==0){l=-12;i=d;return l|0}else{NCb(k,c[e>>2]|0)|0;m=k;n=c[e>>2]|0;break}}else{m=b;n=b}}while(0);if((vCb(n)|0)>0){b=g+100|0;a=m+64|0;k=g+96|0;o=g+72|0;p=g+80|0;q=g+88|0;r=g+56|0;s=g+64|0;g=0;t=n;while(1){u=c[k>>2]|0;bf[c[b>>2]&15](c[(c[t+64>>2]|0)+(g<<2)>>2]|0,c[(c[a>>2]|0)+(g<<2)>>2]|0,f,u+(g<<5)|0,u+(g<<5)+8|0,u+(g<<5)+16|0,u+(g<<5)+24|0,+h[o>>3],+h[p>>3],+h[q>>3],+h[r>>3],+h[s>>3]);u=g+1|0;v=(u|0)<(vCb(c[e>>2]|0)|0);w=c[e>>2]|0;if(v){g=u;t=w}else{x=w;break}}}else{x=n}if((x|0)!=(m|0)){JCb(e)}l=cj(j,m)|0;i=d;return l|0}function xv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=i;i=i+312|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+296|0;m=d+304|0;n=c[b+44>>2]|0;o=c[n+8>>2]|0;a:do{if((o|0)==0){p=0;q=0;r=1;s=68}else{t=Vb(o|0,45)|0;u=(CAb(a[o]|0)|0)!=0;do{if((t|0)==0){v=u?1:2}else{w=(CAb(a[t+1|0]|0)|0)!=0;if(u){v=w?3:4;break}else{v=w?5:6;break}}}while(0);if((Vb(o|0,44)|0)==0){x=124}else{yDb(b,24,2156120,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;x=44}u=Vb(o|0,x|0)|0;do{if((u|0)==0){z=1}else{t=1;w=u;do{A=w+1|0;t=((a[A]|0)!=0)+t|0;w=Vb(A|0,x|0)|0;}while((w|0)!=0);if((t|0)<=64){if((t|0)>0){z=t;break}else{p=t;q=v;r=0;s=68;break a}}yDb(b,16,2086648,(y=i,i=i+8|0,c[y>>2]=t,y)|0);i=y;B=-22;i=d;return B|0}}while(0);u=n+24|0;w=o;A=0;C=0;D=0;b:while(1){c[l>>2]=-1;c[m>>2]=-1;switch(v|0){case 5:{E=Vb(w|0,45)|0;if((E|0)==0){s=56;break b}G=E+1|0;a[E]=0;if((G|0)==0){s=56;break b}E=fBb(w)|0;H=F;if((hBb(E,H)|0)!=1){s=56;break b}I=Vb(G|0,x|0)|0;if((I|0)==0){J=0}else{a[I]=0;J=I+1|0}c[e>>2]=0;I=SGb(G|0)|0;xd(G|0,1907224,(y=i,i=i+16|0,c[y>>2]=m,c[y+8>>2]=e,y)|0)|0;i=y;if((c[e>>2]|0)!=(I|0)){s=56;break b}I=c[m>>2]|0;if(I>>>0>64>>>0){s=56;break b}G=u+(D*24|0)|0;c[G>>2]=E;c[G+4>>2]=H;c[u+(D*24|0)+20>>2]=I;K=A;L=C;M=J;break};case 4:{I=Vb(w|0,45)|0;if((I|0)==0){s=39;break b}H=I+1|0;a[I]=0;c[f>>2]=0;if((H|0)==0){s=47;break b}I=SGb(w|0)|0;xd(w|0,1907224,(y=i,i=i+16|0,c[y>>2]=l,c[y+8>>2]=f,y)|0)|0;i=y;if((c[f>>2]|0)!=(I|0)){s=47;break b}if((c[l>>2]|0)>>>0>64>>>0){s=47;break b}I=Vb(H|0,x|0)|0;if((I|0)==0){N=0}else{a[I]=0;N=I+1|0}I=fBb(H)|0;H=F;if((hBb(I,H)|0)!=1){s=47;break b}if(!((I&C|0)==0&(H&A|0)==0)){s=47;break b}c[u+(D*24|0)+16>>2]=c[l>>2];G=u+(D*24|0)+8|0;c[G>>2]=I;c[G+4>>2]=H;K=H|A;L=I|C;M=N;break};case 2:{I=Vb(w|0,x|0)|0;if((I|0)==0){O=0}else{a[I]=0;O=I+1|0}I=fBb(w)|0;H=F;if((hBb(I,H)|0)!=1){s=25;break b}G=u+(D*24|0)|0;c[G>>2]=I;c[G+4>>2]=H;c[u+(D*24|0)+20>>2]=D;K=A;L=C;M=O;break};case 1:{H=Vb(w|0,x|0)|0;if((H|0)==0){P=0}else{a[H]=0;P=H+1|0}c[j>>2]=0;H=SGb(w|0)|0;xd(w|0,1907224,(y=i,i=i+16|0,c[y>>2]=l,c[y+8>>2]=j,y)|0)|0;i=y;if((c[j>>2]|0)!=(H|0)){s=20;break b}H=c[l>>2]|0;if(H>>>0>64>>>0){s=20;break b}c[u+(D*24|0)+16>>2]=H;c[u+(D*24|0)+20>>2]=D;K=A;L=C;M=P;break};case 6:{H=Vb(w|0,45)|0;if((H|0)==0){s=65;break b}G=H+1|0;a[H]=0;if((G|0)==0){s=65;break b}H=fBb(w)|0;I=F;if((hBb(H,I)|0)!=1){s=65;break b}E=Vb(G|0,x|0)|0;if((E|0)==0){Q=0}else{a[E]=0;Q=E+1|0}E=fBb(G)|0;G=F;if((hBb(E,G)|0)!=1){s=65;break b}if(!((E&C|0)==0&(G&A|0)==0)){s=65;break b}R=u+(D*24|0)|0;c[R>>2]=H;c[R+4>>2]=I;I=u+(D*24|0)+8|0;c[I>>2]=E;c[I+4>>2]=G;K=G|A;L=E|C;M=Q;break};case 3:{E=Vb(w|0,45)|0;if((E|0)==0){s=28;break b}G=E+1|0;a[E]=0;c[h>>2]=0;if((G|0)==0){s=36;break b}E=SGb(w|0)|0;xd(w|0,1907224,(y=i,i=i+16|0,c[y>>2]=l,c[y+8>>2]=h,y)|0)|0;i=y;if((c[h>>2]|0)!=(E|0)){s=36;break b}if((c[l>>2]|0)>>>0>64>>>0){s=36;break b}E=Vb(G|0,x|0)|0;if((E|0)==0){S=0}else{a[E]=0;S=E+1|0}c[g>>2]=0;E=SGb(G|0)|0;xd(G|0,1907224,(y=i,i=i+16|0,c[y>>2]=m,c[y+8>>2]=g,y)|0)|0;i=y;if((c[g>>2]|0)!=(E|0)){s=36;break b}if((c[m>>2]|0)>>>0>64>>>0){s=36;break b}c[u+(D*24|0)+16>>2]=c[l>>2];c[u+(D*24|0)+20>>2]=c[m>>2];K=A;L=C;M=S;break};default:{K=A;L=C;M=w}}E=D+1|0;if((E|0)<(z|0)){w=M;A=K;C=L;D=E}else{s=69;break}}if((s|0)==20){yDb(b,16,1492512,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==25){yDb(b,16,1492512,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==28){c[h>>2]=0;s=36}else if((s|0)==39){c[f>>2]=0;s=47}else if((s|0)==56){yDb(b,16,1492512,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==65){yDb(b,16,1492512,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==69){c[n+1564>>2]=v;D=n+1560|0;c[D>>2]=z;if((L|0)==0&(K|0)==0){T=0;U=v;V=z;W=D;s=70;break}else{X=K;Y=L;Z=0;_=v;$=K;aa=L;ba=D;ca=0;break}}if((s|0)==36){yDb(b,16,1492512,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==47){yDb(b,16,1492512,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}}}while(0);if((s|0)==68){c[n+1564>>2]=q;L=n+1560|0;c[L>>2]=p;T=r;U=q;V=p;W=L;s=70}if((s|0)==70){s=jBb(V)|0;X=F;Y=s;Z=T;_=U;$=0;aa=0;ba=W;ca=1}W=n+16|0;c[W>>2]=Y;c[W+4>>2]=X;U=n+12|0;T=c[U>>2]|0;if((T|0)==0){da=X;ea=Y}else{Y=fBb(T)|0;T=F;if((Y|0)==0&(T|0)==0){yDb(b,16,2035256,(y=i,i=i+8|0,c[y>>2]=c[U>>2],y)|0);i=y;B=-22;i=d;return B|0}do{if(Z){X=hBb(Y,T)|0;c[ba>>2]=X;if((X|0)<=0){break}X=n+24|0;s=0;do{c[X+(s*24|0)+16>>2]=s;c[X+(s*24|0)+20>>2]=s;s=s+1|0;}while((s|0)<(c[ba>>2]|0))}else{if(!((aa|0)==(Y|0)&($|0)==(T|0)|ca)){s=k|0;iBb(s,256,0,aa,$);yDb(b,16,1990600,(y=i,i=i+16|0,c[y>>2]=c[U>>2],c[y+8>>2]=s,y)|0);i=y;B=-22;i=d;return B|0}s=c[ba>>2]|0;if((s|0)==(hBb(Y,T)|0)){break}s=c[ba>>2]|0;yDb(b,16,1956760,(y=i,i=i+16|0,c[y>>2]=c[U>>2],c[y+8>>2]=s,y)|0);i=y;B=-22;i=d;return B|0}}while(0);c[W>>2]=Y;c[W+4>>2]=T;da=T;ea=Y}if((ea|0)==0&(da|0)==0){yDb(b,16,1929288,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}Ak(n+4|0,ea,da)|0;if(!((_|0)==6|(_|0)==4)){B=0;i=d;return B|0}if((c[ba>>2]|0)<=0){B=0;i=d;return B|0}_=n+24|0;n=0;while(1){da=_+(n*24|0)+8|0;c[_+(n*24|0)+20>>2]=kBb(c[W>>2]|0,c[W+4>>2]|0,c[da>>2]|0,c[da+4>>2]|0)|0;da=n+1|0;if((da|0)<(c[ba>>2]|0)){n=da}else{B=0;break}}i=d;return B|0}function yv(a){a=a|0;var b=0,d=0;b=c[a+44>>2]|0;Ok(a,Ck()|0);Nk(a,Dk()|0);d=Ek()|0;Gk(d,(c[c[a+16>>2]>>2]|0)+84|0);Gk(c[b+4>>2]|0,(c[c[a+32>>2]>>2]|0)+80|0);return 0}function zv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+264|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;h=c[c[g+32>>2]>>2]|0;j=c[g+44>>2]|0;g=a+40|0;a=hBb(c[g>>2]|0,c[g+4>>2]|0)|0;g=c[j+1560>>2]|0;k=b+64|0;l=c[k>>2]|0;m=l;UGb(f|0,m|0,a<<2)|0;do{if((g|0)>(a|0)){if(!(g>>>0>8>>>0)){if((l|0)==(b|0)){break}ZDb(m);n=c[e>>2]|0;c[n+64>>2]=n;break}n=cEb(g<<2)|0;o=n;if((n|0)==0){JCb(e);p=-12;i=d;return p|0}n=c[k>>2]|0;if((n|0)==(b|0)){c[k>>2]=o;break}else{ZDb(n);c[(c[e>>2]|0)+64>>2]=o;break}}}while(0);if((g|0)>0){k=j+24|0;j=0;do{c[(c[(c[e>>2]|0)+64>>2]|0)+(c[k+(j*24|0)+20>>2]<<2)>>2]=c[f+(c[k+(j*24|0)+16>>2]<<2)>>2];j=j+1|0;}while((j|0)<(g|0))}j=c[e>>2]|0;k=c[j+64>>2]|0;if((j|0)==(k|0)){q=j}else{UGb(j|0,k|0,g>>>0<8>>>0?g<<2:32)|0;q=c[e>>2]|0}p=cj(h,q)|0;i=d;return p|0}function Av(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+256|0;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=a+40|0;a=hBb(c[f>>2]|0,c[f+4>>2]|0)|0;g=e+1560|0;if((c[g>>2]|0)<=0){h=0;i=b;return h|0}j=e+24|0;k=e+1564|0;e=b|0;l=d;d=0;m=0;while(1){n=j+(m*24|0)|0;if(((c[k>>2]|0)-5|0)>>>0<2>>>0){o=n|0;p=kBb(c[f>>2]|0,c[f+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;c[j+(m*24|0)+16>>2]=p;q=p}else{q=c[j+(m*24|0)+16>>2]|0}p=j+(m*24|0)+16|0;do{if((q|0)>-1&(q|0)<(a|0)){r=d}else{iBb(e,256,0,c[f>>2]|0,c[f+4>>2]|0);o=n|0;s=c[o>>2]|0;t=c[o+4>>2]|0;if((s|0)==0&(t|0)==0){yDb(l,16,2251616,(u=i,i=i+16|0,c[u>>2]=c[p>>2],c[u+8>>2]=e,u)|0);i=u;r=-22;break}else{o=lBb(s,t)|0;yDb(l,16,2266968,(u=i,i=i+16|0,c[u>>2]=o,c[u+8>>2]=e,u)|0);i=u;r=-22;break}}}while(0);p=m+1|0;if((p|0)<(c[g>>2]|0)){d=r;m=p}else{h=r;break}}i=b;return h|0}function Bv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=e+16|0;g=fBb(c[f>>2]|0)|0;h=F;j=e+8|0;c[j>>2]=g;c[j+4>>2]=h;if((g|0)==0&(h|0)==0){yDb(a,16,2156032,(e=i,i=i+8|0,c[e>>2]=c[f>>2],e)|0);i=e;k=-22;i=b;return k|0}e=hBb(g,h)|0;if((e|0)<=0){k=0;i=b;return k|0}h=d;g=d+4|0;f=d|0;l=a+40|0;m=a+28|0;n=a+32|0;o=a+36|0;a=0;while(1){p=nBb(c[j>>2]|0,c[j+4>>2]|0,a)|0;q=F;TGb(h|0,0,60)|0;c[g>>2]=1;c[f>>2]=lBb(p,q)|0;Hi(a,l,4,m,n,d)|0;c[o>>2]=c[l>>2];q=a+1|0;if((q|0)<(e|0)){a=q}else{k=0;break}}i=b;return k|0}function Cv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+44>>2]|0;c[d>>2]=0;Ok(a,Ck()|0);Nk(a,Dk()|0);g=f+8|0;Ak(d,c[g>>2]|0,c[g+4>>2]|0)|0;Gk(c[d>>2]|0,(c[c[a+16>>2]>>2]|0)+84|0);d=a+40|0;if((c[d>>2]|0)==0){i=b;return 0}f=a+32|0;a=0;do{c[e>>2]=0;h=nBb(c[g>>2]|0,c[g+4>>2]|0,a)|0;Ak(e,h,F)|0;Gk(c[e>>2]|0,(c[(c[f>>2]|0)+(a<<2)>>2]|0)+80|0);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0);i=b;return 0}function Dv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=c[a+8>>2]|0;a=b+40|0;f=b+32|0;b=0;g=0;while(1){if(!(b>>>0<(c[a>>2]|0)>>>0)){h=g;j=5;break}k=PCb(c[e>>2]|0)|0;if((k|0)==0){h=-12;j=5;break}l=c[k+64>>2]|0;m=c[l+(b<<2)>>2]|0;c[l>>2]=m;c[k>>2]=m;m=(c[e>>2]|0)+352|0;l=nBb(c[m>>2]|0,c[m+4>>2]|0,b)|0;m=k+352|0;c[m>>2]=l;c[m+4>>2]=F;wCb(k,1);m=cj(c[(c[f>>2]|0)+(b<<2)>>2]|0,k)|0;if((m|0)<0){h=m;j=5;break}else{b=b+1|0;g=m}}if((j|0)==5){JCb(e);i=d;return h|0}return 0}function Ev(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+96|0;c[b>>2]=0;c[b+4>>2]=-2147483648;return 0}function Fv(a){a=a|0;var b=0;b=c[a+44>>2]|0;$Db(b+24|0);$Db(b+20|0);JCb(b+80|0);return}function Gv(a){a=a|0;var b=0,c=0,d=0;b=Ek()|0;do{if((b|0)==0){c=-12}else{Mk(a,b);d=xk(549848)|0;if((d|0)==0){c=-12;break}Ok(a,d);d=Dk()|0;if((d|0)==0){c=-12;break}Nk(a,d);c=0}}while(0);return c|0}function Hv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0,L=0,M=0,N=0.0;b=i;i=i+8|0;d=b|0;e=a|0;f=c[e>>2]|0;g=c[f+44>>2]|0;j=Ni(c[c[f+16>>2]>>2]|0)|0;if(!((j|0)==-541478725)){k=j;i=b;return k|0}if((c[f+76>>2]|0)!=0){k=-541478725;i=b;return k|0}if((c[g+88>>2]|0)==0){k=-541478725;i=b;return k|0}g=c[(c[e>>2]|0)+44>>2]|0;e=c[a+148>>2]|0;f=g+88|0;j=c[f>>2]|0;l=fi(a,(j|0)<2048?j:2048)|0;if((l|0)==0){k=-12;i=b;return k|0}j=g+96|0;m=c[j+4>>2]|0;n=l+136|0;c[n>>2]=c[j>>2];c[n+4>>2]=m;m=l+76|0;n=c[m>>2]|0;c[d>>2]=1;c[d+4>>2]=c[a+48>>2];o=KDb(n,(n|0)<0|0?-1:0,d,a+56|0)|0;d=YGb(c[j>>2]|0,c[j+4>>2]|0,o,F)|0;c[j>>2]=d;c[j+4>>2]=F;do{if((e|0)>0){j=c[(c[g+80>>2]|0)+64>>2]|0;d=c[l+64>>2]|0;o=c[g+24>>2]|0;n=g+92|0;p=c[n>>2]|0;q=c[m>>2]|0;r=g+32|0;s=g+40|0;t=g+20|0;u=g+4|0;if((q|0)<=0){v=p;w=q;x=n;break}y=c[g+84>>2]|0;z=0;while(1){A=c[j+(z<<2)>>2]|0;B=c[d+(z<<2)>>2]|0;C=o+(z*24|0)+16|0;D=p;E=0;do{G=+h[A+(D<<3)>>3];H=+h[C>>3];if(+h[r>>3]>H){I=+h[s>>3]}else{J=+$(H);K=c[u>>2]|0;L=c[t>>2]|0;M=1;while(1){if((M|0)>=(K|0)){break}if(J>+h[L+(M<<5)>>3]){M=M+1|0}else{break}}K=M-1|0;H=J- +h[L+(K<<5)>>3];I=+_(+h[L+(K<<5)+8>>3]+H*(H*+h[L+(K<<5)+16>>3]+ +h[L+(K<<5)+24>>3]))}H=G*I;if(H<-1.0){N=-1.0}else{N=H>1.0?1.0:H}h[B+(E<<3)>>3]=N;K=D+1|0;D=K-((K|0)<(y|0)?0:y)|0;E=E+1|0;}while((E|0)<(q|0));E=z+1|0;if((E|0)<(e|0)){z=E}else{v=D;w=q;x=n;break}}}else{v=0;w=c[m>>2]|0;x=g+92|0}}while(0);c[f>>2]=(c[f>>2]|0)-w;c[x>>2]=v;k=cj(a,l)|0;i=b;return k|0}function Iv(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0,P=0,Q=0,V=0.0,W=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0,na=0,oa=0.0,pa=0.0;d=i;i=i+8|0;e=d|0;f=c[b>>2]|0;g=f+44|0;j=c[g>>2]|0;k=c[b+48>>2]|0;l=j+48|0;m=+h[l>>3]*2.302585092994046;c[e>>2]=0;n=c[b+148>>2]|0;o=j+8|0;p=c[o>>2]|0;q=1;while(1){r=a[p]|0;if((r<<24>>24|0)==32|(r<<24>>24|0)==124){s=q+1|0}else if((r<<24>>24|0)==0){break}else{s=q}p=p+1|0;q=s}t=m/20.0;s=j+12|0;p=c[s>>2]|0;r=1;while(1){u=a[p]|0;if((u<<24>>24|0)==32|(u<<24>>24|0)==124){v=r+1|0}else if((u<<24>>24|0)==0){break}else{v=r}p=p+1|0;r=v}v=j+16|0;p=c[v>>2]|0;u=1;while(1){w=a[p]|0;if((w<<24>>24|0)==0){break}else if((w<<24>>24|0)==32|(w<<24>>24|0)==124){x=u+1|0}else{x=u}p=p+1|0;u=x}if((n|0)<1){yDb(f,16,2197672,(y=i,i=i+8|0,c[y>>2]=n,y)|0);i=y;z=-22;i=d;return z|0}if((q|0)>(n|0)|(r|0)>(n|0)){yDb(f,16,2186496,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;z=-22;i=d;return z|0}x=c[g>>2]|0;$Db(x+24|0);$Db(x+20|0);JCb(x+80|0);if(n>>>0<89478485>>>0){A=cEb(n*24|0)|0}else{A=0}x=j+24|0;c[x>>2]=A;A=(u<<1)+8|0;c[j+4>>2]=A;do{if(A>>>0<67108863>>>0){p=cEb(A<<5)|0;w=j+20|0;c[w>>2]=p;if((c[x>>2]|0)==0|(p|0)==0){break}a:do{if((q|0)>0){p=0;B=0;C=c[o>>2]|0;while(1){D=xAb(C,2170608,e)|0;E=xd(D|0,2162256,(y=i,i=i+8|0,c[y>>2]=(c[x>>2]|0)+(p*24|0),y)|0)|0;i=y;if(+h[(c[x>>2]|0)+(p*24|0)>>3]<0.0){break}D=((E|0)==1)+B|0;E=p+1|0;if((E|0)<(q|0)){p=E;B=D;C=0}else{F=D;break a}}C=c[g>>2]|0;$Db(C+24|0);$Db(C+20|0);JCb(C+80|0);z=-22;i=d;return z|0}else{F=0}}while(0);b:do{if((r|0)>0){C=0;B=0;p=c[s>>2]|0;while(1){D=xAb(p,2170608,e)|0;E=xd(D|0,2162256,(y=i,i=i+8|0,c[y>>2]=(c[x>>2]|0)+(C*24|0)+8,y)|0)|0;i=y;if(+h[(c[x>>2]|0)+(C*24|0)+8>>3]<0.0){break}D=((E|0)==1)+B|0;E=C+1|0;if((E|0)<(r|0)){C=E;B=D;p=0}else{G=D;break b}}p=c[g>>2]|0;$Db(p+24|0);$Db(p+20|0);JCb(p+80|0);z=-22;i=d;return z|0}else{G=0}}while(0);if((F|0)!=(G|0)){yDb(f,16,2155592,(y=i,i=i+16|0,c[y>>2]=F,c[y+8>>2]=G,y)|0);i=y;p=c[g>>2]|0;$Db(p+24|0);$Db(p+20|0);JCb(p+80|0);z=-22;i=d;return z|0}do{if((u|0)>0){p=f;B=0;C=c[v>>2]|0;while(1){D=xAb(C,2170608,e)|0;H=B+1|0;E=H<<1;I=c[w>>2]|0;J=xd(D|0,2148680,(y=i,i=i+16|0,c[y>>2]=I+(E<<5),c[y+8>>2]=I+(E<<5)+8,y)|0)|0;i=y;if((J|0)!=2){K=38;break}if((B|0)==0){J=c[w>>2]|0;L=J;M=+h[J+(E<<5)>>3]}else{J=c[w>>2]|0;m=+h[J+(E<<5)>>3];if(+h[J+(B<<1<<5)>>3]>m){K=42;break}else{L=J;M=m}}J=L+(E<<5)+8|0;m=+h[J>>3]-M;h[J>>3]=m;yDb(p,48,2130192,(y=i,i=i+24|0,c[y>>2]=B,h[y+8>>3]=M,h[y+16>>3]=m,y)|0);i=y;if((H|0)<(u|0)){B=H;C=0}else{K=44;break}}if((K|0)==38){yDb(p,16,2142112,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;C=c[g>>2]|0;$Db(C+24|0);$Db(C+20|0);JCb(C+80|0);z=-22;i=d;return z|0}else if((K|0)==42){yDb(p,16,2136320,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;C=c[g>>2]|0;$Db(C+24|0);$Db(C+20|0);JCb(C+80|0);z=-22;i=d;return z|0}else if((K|0)==44){if((H|0)==0){K=45;break}C=c[w>>2]|0;if(+h[C+(H<<1<<5)>>3]!=0.0){N=C;O=H;K=47;break}else{P=H;Q=C;break}}}else{K=45}}while(0);if((K|0)==45){N=c[w>>2]|0;O=0;K=47}if((K|0)==47){P=O+1|0;Q=N}h[Q>>3]=+h[Q+64>>3]- +h[l>>3]*2.0;h[Q+8>>3]=+h[Q+72>>3];C=P+1|0;if((C|0)>2){B=2;J=C;C=Q;while(1){E=B<<1;I=E-2|0;m=+h[C+(I<<5)+8>>3];D=E-4|0;V=+h[C+(I<<5)>>3];c:do{if((m- +h[C+(D<<5)+8>>3])*(+h[C+(E<<5)>>3]-V)-(+h[C+(E<<5)+8>>3]-m)*(V- +h[C+(D<<5)>>3])!=0.0){W=J;X=B}else{I=J-1|0;Y=B-1|0;if((Y|0)<(I|0)){$=Y;aa=C}else{W=I;X=Y;break}while(1){ba=$+1|0;ca=aa+($<<1<<5)|0;da=aa+(ba<<1<<5)|0;c[ca>>2]=c[da>>2];c[ca+4>>2]=c[da+4>>2];c[ca+8>>2]=c[da+8>>2];c[ca+12>>2]=c[da+12>>2];c[ca+16>>2]=c[da+16>>2];c[ca+20>>2]=c[da+20>>2];c[ca+24>>2]=c[da+24>>2];c[ca+28>>2]=c[da+28>>2];if((ba|0)>=(I|0)){W=I;X=Y;break c}$=ba;aa=c[w>>2]|0}}}while(0);D=X+1|0;E=c[w>>2]|0;if((D|0)<(W|0)){B=D;J=W;C=E}else{ea=E;break}}}else{ea=Q}C=j+56|0;J=0;while(1){if((J|0)!=0){if(!(+h[ea+(J-2<<5)>>3]!=0.0)){break}}B=ea+(J<<5)+8|0;V=+h[C>>3]+ +h[B>>3];w=ea+(J<<5)|0;h[w>>3]=+h[w>>3]*.11512925464970229;h[B>>3]=V*.11512925464970229;J=J+2|0}V=+h[ea+64>>3];if(V!=0.0){J=4;C=2;m=V;while(1){B=J-4|0;h[ea+(B<<5)+16>>3]=0.0;w=ea+(C<<5)+8|0;V=+h[w>>3];fa=V- +h[ea+(B<<5)+8>>3];E=ea+(C<<5)|0;ga=m- +h[ea+(B<<5)>>3];h[ea+(B<<5)+24>>3]=fa/ga;h[ea+(C<<5)+16>>3]=0.0;ha=+h[ea+(J<<5)+8>>3];B=ea+(J<<5)|0;ia=+h[B>>3];h[ea+(C<<5)+24>>3]=(ha-V)/(ia-m);ja=+Z(+fa,+ga);ka=+R(fa*fa+ga*ga);ga=t>ka?ka:t;ka=m- +T(ja)*ga;D=J-3|0;p=ea+(D<<5)|0;h[p>>3]=ka;fa=V-ga*+U(ja);Y=ea+(D<<5)+8|0;h[Y>>3]=fa;ja=+h[w>>3];ga=ha-ja;ha=+h[E>>3];V=ia-ha;ia=+Z(+ga,+V);la=+R(ga*ga+V*V)*.5;V=t>la?la:t;la=ha+ +T(ia)*V;ga=ja+ +U(ia)*V;h[E>>3]=la;h[w>>3]=ga;V=+h[p>>3];ia=(ha+ka+la)/3.0-V;ka=+h[Y>>3];ha=la-V;V=((ga+(ja+fa))/3.0-ka)/ia;fa=((ga-ka)/ha-V)/(ha-ia);h[ea+(D<<5)+16>>3]=fa;h[ea+(D<<5)+24>>3]=V-ia*fa;fa=+h[B>>3];if(fa!=0.0){C=J;J=J+2|0;m=fa}else{break}}ma=J-1|0;na=J}else{ma=1;na=2}h[ea+(ma<<5)>>3]=0.0;h[ea+(ma<<5)+8>>3]=+h[ea+(na<<5)+8>>3];h[j+32>>3]=+_(+h[ea+32>>3]);h[j+40>>3]=+_(+h[ea+40>>3]);m=+(k|0);if((n|0)>0){fa=1.0/m;C=j+64|0;B=0;do{D=c[x>>2]|0;Y=D+(B*24|0)|0;ia=+h[Y>>3];if(ia>fa){oa=1.0- +_(-1.0/(m*ia))}else{oa=1.0}h[Y>>3]=oa;Y=D+(B*24|0)+8|0;ia=+h[Y>>3];if(ia>fa){pa=1.0- +_(-1.0/(m*ia))}else{pa=1.0}h[Y>>3]=pa;h[D+(B*24|0)+16>>3]=+S(+10.0,+(+h[C>>3]/20.0));B=B+1|0;}while((B|0)<(n|0))}B=~~(m*+h[j+72>>3]);C=j+84|0;c[C>>2]=B;if((B|0)<1){c[j+104>>2]=160;z=0;i=d;return z|0}B=ICb()|0;c[j+80>>2]=B;if((B|0)==0){J=c[g>>2]|0;$Db(J+24|0);$Db(J+20|0);JCb(J+80|0);z=-12;i=d;return z|0}c[B+80>>2]=c[b+52>>2];c[B+76>>2]=c[C>>2];C=b+40|0;J=c[C+4>>2]|0;D=B+352|0;c[D>>2]=c[C>>2];c[D+4>>2]=J;J=LCb(B,32)|0;if((J|0)!=0){z=J;i=d;return z|0}J=b+156|0;c[J>>2]=c[J>>2]|1;c[j+104>>2]=784;z=0;i=d;return z|0}else{c[j+20>>2]=0}}while(0);j=c[g>>2]|0;$Db(j+24|0);$Db(j+20|0);JCb(j+80|0);z=-12;i=d;return z|0}function Jv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0.0,H=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+44>>2]|0;j=c[c[a+16>>2]>>2]|0;k=c[j+148>>2]|0;l=c[b+76>>2]|0;do{if((RCb(b)|0)==0){m=fi(j,l)|0;c[f>>2]=m;if((m|0)==0){JCb(e);n=-12;i=d;return n|0}o=NCb(m,c[e>>2]|0)|0;if((o|0)>=0){p=m;q=c[e>>2]|0;break}JCb(f);JCb(e);n=o;i=d;return n|0}else{c[f>>2]=b;p=b;q=b}}while(0);if((k|0)>0){b=g+24|0;j=(l|0)>0;o=g+32|0;m=g+40|0;r=g+20|0;s=g+4|0;g=0;do{t=c[(c[q+64>>2]|0)+(g<<2)>>2]|0;u=c[(c[p+64>>2]|0)+(g<<2)>>2]|0;v=c[b>>2]|0;if(j){w=v+(g*24|0)+16|0;x=v+(g*24|0)+8|0;y=v+(g*24|0)|0;v=0;do{z=t+(v<<3)|0;A=+Q(+(+h[z>>3]));B=+h[w>>3];C=A-B;A=B+C*+h[(C>0.0?y:x)>>3];h[w>>3]=A;C=+h[z>>3];if(+h[o>>3]>A){D=+h[m>>3]}else{B=+$(A);z=c[s>>2]|0;E=c[r>>2]|0;F=1;while(1){if((F|0)>=(z|0)){break}if(B>+h[E+(F<<5)>>3]){F=F+1|0}else{break}}z=F-1|0;A=B- +h[E+(z<<5)>>3];D=+_(+h[E+(z<<5)+8>>3]+A*(A*+h[E+(z<<5)+16>>3]+ +h[E+(z<<5)+24>>3]))}A=C*D;if(A<-1.0){G=-1.0}else{G=A>1.0?1.0:A}h[u+(v<<3)>>3]=G;v=v+1|0;}while((v|0)<(l|0))}g=g+1|0;}while((g|0)<(k|0))}if((q|0)==(p|0)){H=q}else{JCb(e);H=c[f>>2]|0}n=cj(c[c[a+32>>2]>>2]|0,H)|0;i=d;return n|0}function Kv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0.0,U=0.0,V=0.0,W=0.0,X=0,Y=0,Z=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0.0,ka=0.0,la=0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[e>>2]=b;j=c[a+44>>2]|0;k=c[c[a+16>>2]>>2]|0;l=c[k+148>>2]|0;m=c[b+76>>2]|0;c[f>>2]=0;n=j+96|0;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==(-2147483648|0)){o=b+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;o=(p|0)==0&(q|0)==(-2147483648|0);c[n>>2]=o?0:p;c[n+4>>2]=o?0:q}a:do{if((l|0)>0){q=j+80|0;o=j+24|0;p=j+88|0;r=j+92|0;s=(m|0)>0;t=j+84|0;u=g|0;v=g+4|0;w=k+48|0;x=k+56|0;y=j+32|0;z=j+40|0;A=j+20|0;B=j+4|0;C=0;D=0;E=b;b:while(1){G=c[(c[E+64>>2]|0)+(C<<2)>>2]|0;H=c[(c[(c[q>>2]|0)+64>>2]|0)+(C<<2)>>2]|0;I=c[o>>2]|0;J=c[p>>2]|0;K=c[r>>2]|0;if(s){L=I+(C*24|0)+16|0;M=I+(C*24|0)+8|0;N=I+(C*24|0)|0;I=J;O=0;P=K;R=0;S=D;while(1){T=+h[G+(R<<3)>>3];U=+Q(+T);V=+h[L>>3];W=U-V;U=V+W*+h[(W>0.0?N:M)>>3];h[L>>3]=U;X=c[t>>2]|0;if((I|0)<(X|0)){Y=O;Z=I+1|0;aa=X;ba=S;ca=H+(P<<3)|0}else{if((S|0)==0){X=m-R|0;da=fi(k,X)|0;c[f>>2]=da;if((da|0)==0){ea=11;break b}fa=NCb(da,c[e>>2]|0)|0;if((fa|0)<0){ea=13;break b}ga=c[n+4>>2]|0;ha=da+136|0;c[ha>>2]=c[n>>2];c[ha+4>>2]=ga;c[u>>2]=1;c[v>>2]=c[w>>2];ga=KDb(X,(X|0)<0|0?-1:0,g,x)|0;X=YGb(c[n>>2]|0,c[n+4>>2]|0,ga,F)|0;c[n>>2]=X;c[n+4>>2]=F;ia=c[f>>2]|0;ja=+h[L>>3]}else{ia=S;ja=U}X=c[(c[ia+64>>2]|0)+(C<<2)>>2]|0;ga=H+(P<<3)|0;U=+h[ga>>3];if(+h[y>>3]>ja){ka=+h[z>>3]}else{W=+$(ja);ha=c[B>>2]|0;da=c[A>>2]|0;la=1;while(1){if((la|0)>=(ha|0)){break}if(W>+h[da+(la<<5)>>3]){la=la+1|0}else{break}}ha=la-1|0;V=W- +h[da+(ha<<5)>>3];ka=+_(+h[da+(ha<<5)+8>>3]+V*(V*+h[da+(ha<<5)+16>>3]+ +h[da+(ha<<5)+24>>3]))}V=U*ka;if(V<-1.0){ma=-1.0}else{ma=V>1.0?1.0:V}h[X+(O<<3)>>3]=ma;Y=O+1|0;Z=I;aa=c[t>>2]|0;ba=ia;ca=ga}h[ca>>3]=T;ha=P+1|0;na=ha-((ha|0)<(aa|0)?0:aa)|0;ha=R+1|0;if((ha|0)<(m|0)){I=Z;O=Y;P=na;R=ha;S=ba}else{oa=Z;pa=na;qa=ba;break}}}else{oa=J;pa=K;qa=D}S=C+1|0;if((S|0)>=(l|0)){ra=oa;sa=pa;ta=p;ua=r;break a}C=S;D=qa;E=c[e>>2]|0}if((ea|0)==11){JCb(e);va=-12;i=d;return va|0}else if((ea|0)==13){JCb(f);JCb(e);va=fa;i=d;return va|0}}else{ra=0;sa=0;ta=j+88|0;ua=j+92|0}}while(0);c[ta>>2]=ra;c[ua>>2]=sa;JCb(e);e=c[f>>2]|0;if((e|0)==0){va=0;i=d;return va|0}va=cj(c[c[a+32>>2]>>2]|0,e)|0;i=d;return va|0}function Lv(a,b){a=a|0;b=b|0;var d=0;d=c[a+8>>2]|0;return Oe[c[(c[d+44>>2]|0)+104>>2]&1023](d,b)|0}function Mv(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[d>>2]=0;c[e>>2]=0;zk(d,1,0)|0;Ok(a,c[d>>2]|0);Ak(e,3,0)|0;Mk(a,c[e>>2]|0);Nk(a,xk(549680)|0);i=b;return 0}function Nv(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=d+8|0;j=c[c[(c[h>>2]|0)+32>>2]>>2]|0;k=fi(d,c[e+76>>2]|0)|0;if((k|0)==0){JCb(g);l=-12;i=f;return l|0}NCb(k,e)|0;e=c[(c[h>>2]|0)+44>>2]|0;h=e;d=c[k>>2]|0;m=c[g>>2]|0;n=c[m>>2]|0;o=n;p=c[m+76>>2]<<1;m=(p|0)<64?p:64;UGb(e+128|0,n|0,m<<1)|0;n=h+(m<<1)|0;if(h>>>0<n>>>0){m=h;p=d;while(1){q=0;r=0;s=0;while(1){t=(ba(a[1068160+s|0]|0,b[m+(s<<1)>>1]|0)|0)+q|0;u=r+1&65535;if(u<<16>>16<64){q=t;r=u;s=u<<16>>16}else{break}}s=t>>6;if((s+32768|0)>>>0>65535>>>0){v=(t>>31^32767)&65535}else{v=s&65535}b[p>>1]=v;s=p+2|0;r=m+2|0;if(r>>>0<n>>>0){m=r;p=s}else{w=s;break}}}else{w=d}d=c[(c[g>>2]|0)+76>>2]<<1;if((d|0)>63){p=o+(d-64<<1)|0;if(o>>>0<p>>>0){m=o;o=w;while(1){w=0;n=0;v=0;while(1){x=(ba(a[1068160+v|0]|0,b[m+(v<<1)>>1]|0)|0)+w|0;t=n+1&65535;if(t<<16>>16<64){w=x;n=t;v=t<<16>>16}else{break}}v=x>>6;if((v+32768|0)>>>0>65535>>>0){y=(x>>31^32767)&65535}else{y=v&65535}b[o>>1]=y;v=m+2|0;if(v>>>0<p>>>0){m=v;o=o+2|0}else{break}}}UGb(e|0,p|0,128)|0}else{VGb(e|0,h+(d<<1)|0,128)|0}JCb(g);l=cj(j,k)|0;i=f;return l|0}function Ov(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=i;i=i+112|0;e=d|0;f=d+8|0;g=d+16|0;h=d+48|0;j=b+44|0;k=c[j>>2]|0;l=k+12|0;m=fBb(c[l>>2]|0)|0;n=F;o=k+16|0;c[o>>2]=m;c[o+4>>2]=n;if((m|0)==0&(n|0)==0){yDb(b,16,2155824,(p=i,i=i+8|0,c[p>>2]=c[l>>2],p)|0);i=p;q=-22;i=d;return q|0}l=hBb(m,n)|0;n=k+24|0;c[n>>2]=l;m=k+28|0;c[m>>2]=cEb(l*24|0)|0;l=k+36|0;c[l>>2]=cEb(c[n>>2]<<2)|0;r=k+4|0;s=cEb(c[r>>2]<<2)|0;c[k+32>>2]=s;if((c[m>>2]|0)==0){q=-12;i=d;return q|0}if((c[l>>2]|0)==0|(s|0)==0){q=-12;i=d;return q|0}if((c[n>>2]|0)>0){s=0;do{l=nBb(c[o>>2]|0,c[o+4>>2]|0,s)|0;k=c[m>>2]|0;t=k+(s*24|0)+16|0;c[t>>2]=l;c[t+4>>2]=F;c[k+(s*24|0)>>2]=-1;s=s+1|0;}while((s|0)<(c[n>>2]|0))}n=c[j>>2]|0;j=c[n+8>>2]|0;c[e>>2]=j;a:do{if((j|0)!=0){if((Vb(j|0,44)|0)==0){u=124}else{yDb(b,24,1907120,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=44}s=n+16|0;m=n+28|0;o=n+4|0;k=j;while(1){if((a[k]|0)==0){break a}t=Vb(k|0,u|0)|0;if((t|0)==0){v=0}else{a[t]=0;v=t+1|0}t=Vb(k|0,45)|0;if((t|0)==0){w=15;break}x=t+1|0;a[t]=0;t=fBb(x)|0;l=F;if((t|0)==0&(l|0)==0){w=17;break}if((hBb(t,l)|0)!=1){w=19;break}y=c[s>>2]|0;z=c[s+4>>2]|0;if((y&t|0)==0&(z&l|0)==0){w=21;break}A=kBb(y,z,t,l)|0;if((c[(c[m>>2]|0)+(A*24|0)>>2]|0)>-1){w=23;break}B=kb(k|0,e|0,0)|0;if((B|0)<0){w=26;break}if((B|0)>=(c[o>>2]|0)){w=26;break}l=c[e>>2]|0;if((a[l]|0)==0){C=l}else{t=l+1|0;c[e>>2]=t;C=t}t=kb(C|0,f|0,0)|0;if((c[f>>2]|0)==(C|0)){l=fBb(C)|0;z=F;if((l|0)==0&(z|0)==0){w=31;break}if((hBb(l,z)|0)!=1){w=33;break}y=c[m>>2]|0;c[y+(A*24|0)>>2]=B;D=y+(A*24|0)+8|0;c[D>>2]=l;c[D+4>>2]=z}else{z=c[m>>2]|0;c[z+(A*24|0)>>2]=B;c[z+(A*24|0)+4>>2]=t}c[e>>2]=v;if((v|0)==0){break a}else{k=v}}if((w|0)==15){yDb(b,16,1886472,(p=i,i=i+8|0,c[p>>2]=k,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==17){yDb(b,16,2344288,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==19){yDb(b,16,2322472,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==21){yDb(b,16,2299576,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==23){yDb(b,16,2282040,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==26){yDb(b,16,2266888,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==31){yDb(b,16,2251536,(p=i,i=i+8|0,c[p>>2]=C,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==33){yDb(b,16,2237760,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=d;return q|0}}}while(0);if((c[r>>2]|0)<=0){q=0;i=d;return q|0}w=h;C=g|0;g=h+4|0;B=h|0;x=h+36|0;v=h+52|0;e=b+24|0;f=b+12|0;u=b+16|0;j=b+20|0;b=0;while(1){TGb(w|0,0,60)|0;Lb(C|0,32,2086440,(p=i,i=i+8|0,c[p>>2]=b,p)|0)|0;i=p;c[g>>2]=1;c[B>>2]=eEb(C)|0;c[x>>2]=458;c[v>>2]=1;Hi(b,e,12,f,u,h)|0;c[j>>2]=c[e>>2];n=b+1|0;if((n|0)<(c[r>>2]|0)){b=n}else{q=0;break}}i=d;return q|0}function Pv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+44>>2]|0;d=a+24|0;if((c[d>>2]|0)==0){e=b+32|0;f=b+28|0;$Db(f);g=b+36|0;$Db(g);$Db(e);return}h=a+12|0;a=b+32|0;i=a;j=0;while(1){$Db((c[h>>2]|0)+(j*60|0)|0);JCb((c[i>>2]|0)+(j<<2)|0);k=j+1|0;if(k>>>0<(c[d>>2]|0)>>>0){j=k}else{e=a;break}}f=b+28|0;$Db(f);g=b+36|0;$Db(g);$Db(e);return}function Qv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=0;f=e+16|0;Ak(d,c[f>>2]|0,c[f+4>>2]|0)|0;Gk(c[d>>2]|0,(c[c[a+32>>2]>>2]|0)+80|0);d=a+24|0;if((c[d>>2]|0)==0){g=Ck()|0;Ok(a,g);h=Dk()|0;Nk(a,h);i=b;return 0}f=a+16|0;e=0;do{j=Ek()|0;Gk(j,(c[(c[f>>2]|0)+(e<<2)>>2]|0)+84|0);e=e+1|0;}while(e>>>0<(c[d>>2]|0)>>>0);g=Ck()|0;Ok(a,g);h=Dk()|0;Nk(a,h);i=b;return 0}function Rv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[a+8>>2]|0;f=c[e+44>>2]|0;g=e+16|0;h=c[e+24>>2]|0;e=0;while(1){if(!(e>>>0<h>>>0)){j=4;break}if((c[(c[g>>2]|0)+(e<<2)>>2]|0)==(a|0)){break}else{e=e+1|0}}if((j|0)==4){yDb(0,0,2035168,(k=i,i=i+24|0,c[k>>2]=1990488,c[k+8>>2]=1956624,c[k+16>>2]=90,k)|0);i=k;Cd();return 0}j=(c[f+32>>2]|0)+(e<<2)|0;if((c[j>>2]|0)==0){c[j>>2]=b;i=d;return 0}else{yDb(0,0,2035168,(k=i,i=i+24|0,c[k>>2]=1929232,c[k+8>>2]=1956624,c[k+16>>2]=91,k)|0);i=k;Cd();return 0}return 0}function Sv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=e+24|0;a:do{if((c[g>>2]|0)==0){h=0}else{j=e+16|0;k=f+32|0;l=0;m=0;while(1){if((c[(c[k>>2]|0)+(l<<2)>>2]|0)==0){n=Ni(c[(c[j>>2]|0)+(l<<2)>>2]|0)|0;if((n|0)<0){o=n;break}}do{if((l|0)==0){n=c[(c[c[k>>2]>>2]|0)+76>>2]|0;p=c[g>>2]|0;if(!(p>>>0>1>>>0)){q=n;r=p;break}p=c[j>>2]|0;s=1;while(1){c[(c[p+(s<<2)>>2]|0)+88>>2]=n;t=s+1|0;u=c[g>>2]|0;if(t>>>0<u>>>0){s=t}else{q=n;r=u;break}}}else{q=m;r=c[g>>2]|0}}while(0);n=l+1|0;if(n>>>0<r>>>0){l=n;m=q}else{h=q;break a}}i=b;return o|0}}while(0);q=ICb()|0;c[d>>2]=q;if((q|0)==0){o=-12;i=b;return o|0}r=f+24|0;e=c[r>>2]|0;do{if(e>>>0>8>>>0){m=cEb(e<<2)|0;c[(c[d>>2]|0)+64>>2]=m;m=c[d>>2]|0;if((c[m+64>>2]|0)==0){v=-12;break}w=c[r>>2]|0;x=m;y=15}else{w=e;x=q;y=15}}while(0);b:do{if((y|0)==15){do{if((w|0)>0){q=f+28|0;e=f+32|0;m=f+36|0;l=0;j=0;k=2147483647;n=x;while(1){s=c[q>>2]|0;p=c[(c[e>>2]|0)+(c[s+(l*24|0)>>2]<<2)>>2]|0;u=c[s+(l*24|0)+4>>2]|0;c[(c[n+64>>2]|0)+(l<<2)>>2]=c[(c[p+64>>2]|0)+(u<<2)>>2];s=c[p+32>>2]|0;z=(k|0)>(s|0)?s:k;s=UCb(p,u)|0;if((s|0)==0){v=-22;break b}u=s|0;p=0;while(1){if((p|0)>=(j|0)){break}if((c[c[(c[m>>2]|0)+(p<<2)>>2]>>2]|0)==(c[u>>2]|0)){break}else{p=p+1|0}}if((p|0)==(l|0)){c[(c[m>>2]|0)+(j<<2)>>2]=s;A=j+1|0}else{A=j}u=l+1|0;if((u|0)>=(c[r>>2]|0)){break}l=u;j=A;k=z;n=c[d>>2]|0}if(!(A>>>0>8>>>0)){B=z;C=A;break}n=A-8|0;c[(c[d>>2]|0)+396>>2]=n;k=cEb(n<<2)|0;c[(c[d>>2]|0)+392>>2]=k;k=c[d>>2]|0;if((c[k+392>>2]|0)!=0){B=z;C=A;break}c[k+396>>2]=0;v=-12;break b}else{B=2147483647;C=0}}while(0);k=C>>>0<8>>>0?C:8;n=f+36|0;j=0;while(1){if(!(j>>>0<k>>>0)){break}l=WAb(c[(c[n>>2]|0)+(j<<2)>>2]|0)|0;c[(c[d>>2]|0)+360+(j<<2)>>2]=l;if((c[(c[d>>2]|0)+360+(j<<2)>>2]|0)==0){v=-12;break b}else{j=j+1|0}}j=0;k=c[d>>2]|0;while(1){if((j|0)>=(c[k+396>>2]|0)){break}l=WAb(c[(c[n>>2]|0)+(j+8<<2)>>2]|0)|0;c[(c[(c[d>>2]|0)+392>>2]|0)+(j<<2)>>2]=l;l=c[d>>2]|0;if((c[(c[l+392>>2]|0)+(j<<2)>>2]|0)==0){v=-12;break b}else{j=j+1|0;k=l}}c[k+76>>2]=h;j=a+40|0;n=c[j+4>>2]|0;l=k+352|0;c[l>>2]=c[j>>2];c[l+4>>2]=n;wCb(k,c[a+148>>2]|0);n=c[d>>2]|0;c[n+80>>2]=c[a+52>>2];c[n+344>>2]=c[a+48>>2];l=f+32|0;j=(c[c[l>>2]>>2]|0)+136|0;m=c[j+4>>2]|0;e=n+136|0;c[e>>2]=c[j>>2];c[e+4>>2]=m;c[n+32>>2]=B;m=c[n+64>>2]|0;if((n|0)==(m|0)){D=n}else{e=c[r>>2]|0;UGb(n|0,m|0,e>>>0<8>>>0?e<<2:32)|0;D=c[d>>2]|0}e=cj(a,D)|0;if((c[g>>2]|0)==0){o=e;i=b;return o|0}else{E=0}while(1){JCb((c[l>>2]|0)+(E<<2)|0);m=E+1|0;if(m>>>0<(c[g>>2]|0)>>>0){E=m}else{o=e;break}}i=b;return o|0}}while(0);JCb(d);o=v;i=b;return o|0}function Tv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;a=c[e+44>>2]|0;f=e+24|0;g=cEb(c[f>>2]<<3)|0;h=g;c[d>>2]=h;if((g|0)==0){j=-12;i=b;return j|0}g=a+24|0;k=c[g>>2]|0;a:do{if((k|0)>0){l=a+28|0;m=e+16|0;n=0;o=h;p=k;while(1){q=c[l>>2]|0;r=q+(n*24|0)|0;s=c[r>>2]|0;if((s|0)<0){t=o;u=p}else{v=q+(n*24|0)+8|0;w=c[v>>2]|0;x=c[v+4>>2]|0;y=(c[(c[m>>2]|0)+(s<<2)>>2]|0)+40|0;if((w|0)==0&(x|0)==0){s=nBb(c[y>>2]|0,c[y+4>>2]|0,c[q+(n*24|0)+4>>2]|0)|0;q=F;c[v>>2]=s;c[v+4>>2]=q;z=q;A=s}else{z=x;A=w}if((c[y>>2]&A|0)==0&(c[y+4>>2]&z|0)==0){B=10;break}y=c[d>>2]|0;w=y+(c[r>>2]<<3)|0;x=c[w+4>>2]|z;c[w>>2]=c[w>>2]|A;c[w+4>>2]=x;t=y;u=c[g>>2]|0}y=n+1|0;if((y|0)<(u|0)){n=y;o=t;p=u}else{break}}if((B|0)==10){p=lBb(A,z)|0;o=c[r>>2]|0;yDb(e,16,2148560,(C=i,i=i+16|0,c[C>>2]=p,c[C+8>>2]=o,C)|0);i=C;D=-22;break}if((u|0)<=0){B=31;break}o=c[a+28>>2]|0;p=e+16|0;n=0;m=u;while(1){l=o+(n*24|0)|0;b:do{if((c[l>>2]|0)<0){y=c[f>>2]|0;if((y|0)==0){E=m;break}x=c[p>>2]|0;w=o+(n*24|0)+16|0;s=c[w>>2]|0;q=c[w+4>>2]|0;w=0;while(1){v=(c[x+(w<<2)>>2]|0)+40|0;if(!((c[v>>2]&s|0)==0&(c[v+4>>2]&q|0)==0)){G=t+(w<<3)|0;if((c[G>>2]&s|0)==0&(c[G+4>>2]&q|0)==0){break}}v=w+1|0;if(v>>>0<y>>>0){w=v}else{E=m;break b}}c[l>>2]=w;y=o+(n*24|0)+8|0;c[y>>2]=s;c[y+4>>2]=q;y=c[G+4>>2]|q;c[G>>2]=c[G>>2]|s;c[G+4>>2]=y;E=c[g>>2]|0}else{E=m}}while(0);l=n+1|0;if((l|0)<(E|0)){n=l;m=E}else{break}}if((E|0)<=0){B=31;break}m=a+28|0;n=e+16|0;o=0;while(1){H=c[m>>2]|0;p=H+(o*24|0)|0;l=c[p>>2]|0;if((l|0)<0){y=c[d>>2]|0;x=c[f>>2]|0;v=0;while(1){if(!(v>>>0<x>>>0)){I=l;break}J=y+(v<<3)|0;K=c[J>>2]|0;L=c[J+4>>2]|0;M=(c[(c[n>>2]|0)+(v<<2)>>2]|0)+40|0;N=c[M>>2]|0;O=c[M+4>>2]|0;if((N&K|0)==(N|0)&(O&L|0)==(O|0)){v=v+1|0}else{B=27;break}}if((B|0)==27){B=0;c[p>>2]=v;y=nBb(N&~K,O&~L,0)|0;x=F;M=H+(o*24|0)+8|0;c[M>>2]=y;c[M+4>>2]=x;M=c[J+4>>2]|x;c[J>>2]=c[J>>2]|y;c[J+4>>2]=M;I=c[p>>2]|0}if((I|0)<0){break}else{P=I}}else{P=l}M=(c[(c[n>>2]|0)+(P<<2)>>2]|0)+40|0;y=H+(o*24|0)+8|0;c[H+(o*24|0)+4>>2]=kBb(c[M>>2]|0,c[M+4>>2]|0,c[y>>2]|0,c[y+4>>2]|0)|0;y=o+1|0;if((y|0)<(c[g>>2]|0)){o=y}else{B=31;break a}}n=H+(o*24|0)+16|0;m=lBb(c[n>>2]|0,c[n+4>>2]|0)|0;yDb(e,16,2141992,(C=i,i=i+8|0,c[C>>2]=m,C)|0);i=C;D=0}else{B=31}}while(0);do{if((B|0)==31){H=e;yDb(H,40,2136304,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;if((c[g>>2]|0)>0){P=a+28|0;I=0;do{J=c[P>>2]|0;L=c[J+(I*24|0)>>2]|0;O=J+(I*24|0)+8|0;K=lBb(c[O>>2]|0,c[O+4>>2]|0)|0;O=J+(I*24|0)+16|0;J=lBb(c[O>>2]|0,c[O+4>>2]|0)|0;yDb(H,40,2130176,(C=i,i=i+24|0,c[C>>2]=L,c[C+8>>2]=K,c[C+16>>2]=J,C)|0);i=C;I=I+1|0;}while((I|0)<(c[g>>2]|0))}yDb(H,40,2123384,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;I=c[f>>2]|0;if((I|0)==0){D=0;break}else{Q=0;R=I}while(1){I=(c[d>>2]|0)+(Q<<3)|0;if((c[I>>2]|0)==0&(c[I+4>>2]|0)==0){yDb(H,24,2118208,(C=i,i=i+8|0,c[C>>2]=Q,C)|0);i=C;S=c[f>>2]|0}else{S=R}I=Q+1|0;if(I>>>0<S>>>0){Q=I;R=S}else{D=0;break}}}}while(0);$Db(d);j=D;i=b;return j|0}function Uv(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+72|0;e=d|0;f=d+8|0;g=d+16|0;j=d+24|0;k=d+32|0;l=d+40|0;m=d+48|0;n=d+56|0;o=d+64|0;p=o;q=i;i=i+8|0;r=c[b+44>>2]|0;s=r+4|0;t=eEb(c[s>>2]|0)|0;c[o>>2]=0;c[o+4>>2]=0;if((c[s>>2]|0)==0){yDb(b,16,2155648,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-22;i=d;return v|0}if((t|0)==0){v=-12;i=d;return v|0}s=xAb(t,2086288,j)|0;c[g>>2]=s;o=r+8|0;w=r+31780|0;x=b;b=Uk(o,w,s,x)|0;a:do{if((b|0)<0){y=b}else{s=xAb(0,2086288,j)|0;c[g>>2]=s;do{if((s|0)==0){z=0}else{A=r+31768|0;B=r+16|0;C=s;b:while(1){if((Xv(g,k,n)|0)!=0){D=9;break}if((c[n>>2]|0)==0){E=c[k>>2]|0}else{G=c[o>>2]|0;H=c[o+4>>2]|0;I=_Gb(1,0,c[k>>2]|0)|0;J=F;if((I&G|0)==0&(J&H|0)==0){D=12;break}K=YGb(I,J,-1,-1)|0;J=hBb(K&G,F&H)|0;c[k>>2]=J;E=J}if((E|0)<0){D=17;break}if((E|0)>=(c[w>>2]|0)){D=17;break}c[f>>2]=0;xd(c[g>>2]|0,2299568,(u=i,i=i+8|0,c[u>>2]=f,u)|0)|0;i=u;J=c[f>>2]|0;H=c[g>>2]|0;G=H+J|0;c[g>>2]=G;K=a[G]|0;if((K<<24>>24|0)==60){G=_Gb(1,0,E|0)|0;I=F|c[A+4>>2];c[A>>2]=G|c[A>>2];c[A+4>>2]=I}else if((K<<24>>24|0)!=61){D=21;break}K=H+(J+1)|0;while(1){c[g>>2]=K;h[q>>3]=1.0;J=xd(K|0,1907104,(u=i,i=i+24|0,c[u>>2]=q,c[u+8>>2]=m,c[u+16>>2]=m,u)|0)|0;i=u;if((J|0)!=0){c[g>>2]=K+(c[m>>2]|0)}if((Xv(g,l,n)|0)!=0){D=25;break b}J=c[n>>2]|0;H=p+(J<<2)|0;c[H>>2]=(c[H>>2]|0)+1;if((c[p+(((J|0)==0)<<2)>>2]|0)!=0){D=27;break b}h[B+(E*504|0)+(c[l>>2]<<3)>>3]=+h[q>>3];c[e>>2]=0;J=c[g>>2]|0;xd(J|0,2299568,(u=i,i=i+8|0,c[u>>2]=e,u)|0)|0;i=u;H=c[e>>2]|0;L=J+H|0;c[g>>2]=L;I=a[L]|0;if((I<<24>>24|0)==0){break}else if((I<<24>>24|0)!=43){D=29;break b}K=J+(H+1)|0}K=xAb(0,2086288,j)|0;c[g>>2]=K;if((K|0)==0){D=31;break}else{C=K}}if((D|0)==9){yDb(x,16,2035056,(u=i,i=i+8|0,c[u>>2]=c[g>>2],u)|0);i=u;y=-22;break a}else if((D|0)==12){yDb(x,16,1990264,(u=i,i=i+8|0,c[u>>2]=C,u)|0);i=u;y=-22;break a}else if((D|0)==17){yDb(x,16,1956560,(u=i,i=i+8|0,c[u>>2]=C,u)|0);i=u;y=-22;break a}else if((D|0)==21){yDb(x,16,1929184,(u=i,i=i+8|0,c[u>>2]=C,u)|0);i=u;y=-22;break a}else if((D|0)==25){yDb(x,16,1886432,(u=i,i=i+8|0,c[u>>2]=c[g>>2],u)|0);i=u;y=-22;break a}else if((D|0)==27){yDb(x,16,2344240,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;y=-22;break a}else if((D|0)==29){yDb(x,16,2322400,(u=i,i=i+8|0,c[u>>2]=L,u)|0);i=u;y=-22;break a}else if((D|0)==31){z=(c[p+4>>2]|0)!=0|0;break}}}while(0);c[r+31776>>2]=z;y=0}}while(0);ZDb(t);v=y;i=d;return v|0}function Vv(a){a=a|0;Tqb((c[a+44>>2]|0)+31916|0);return}function Wv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;f=e;g=c[c[a+16>>2]>>2]|0;j=c[c[a+32>>2]>>2]|0;k=0;a:while(1){l=0;m=0;while(1){n=+h[f+16+(k*504|0)+(l<<3)>>3];o=n!=0.0;if(o&n!=1.0){p=0;break a}if(o){if((m|0)==0){q=m+1|0}else{p=0;break a}}else{q=m}o=l+1|0;if((o|0)<63){l=o;m=q}else{break}}m=k+1|0;if((m|0)<63){k=m}else{p=1;break}}c[e+31784>>2]=p;Ok(a,Bk(1)|0);p=Dk()|0;if((p|0)==0){r=-12;i=b;return r|0}Nk(a,p);Gk(Fk()|0,g+84|0);c[d>>2]=0;g=e+8|0;p=c[g>>2]|0;a=c[g+4>>2]|0;if((p|0)==0&(a|0)==0){g=c[e+31780>>2]|0;s=((g|0)<0|0?-1:0)|-2147483648;t=g|0}else{s=a;t=p}Ak(d,t,s)|0;Gk(c[d>>2]|0,j+80|0);r=0;i=b;return r|0}function Xv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+32|0;f=e|0;g=e+16|0;h=e+24|0;c[h>>2]=0;c[f>>2]=0;xd(c[a>>2]|0,2299568,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;k=(c[a>>2]|0)+(c[f>>2]|0)|0;c[a>>2]=k;f=e+8|0;l=xd(k|0,2282024,(j=i,i=i+16|0,c[j>>2]=f,c[j+8>>2]=g,j)|0)|0;i=j;if((l|0)==0){l=xd(c[a>>2]|0,2266880,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;j=c[h>>2]|0;if(!((l|0)!=0&(j|0)>-1&(j|0)<63)){m=-22;i=e;return m|0}c[b>>2]=j;c[d>>2]=0;c[a>>2]=(c[a>>2]|0)+(c[g>>2]|0);m=0;i=e;return m|0}j=fBb(f)|0;f=F;l=1;if((f|0)<(l|0)|(f|0)==(l|0)&j>>>0<0>>>0){n=f;o=j}else{c[h>>2]=(c[h>>2]|0)+32;n=(f|0)<0|0?-1:0;o=f}l=0;if((n|0)<(l|0)|(n|0)==(l|0)&o>>>0<65536>>>0){p=n;q=o}else{c[h>>2]=(c[h>>2]|0)+16;p=n>>16|((n|0)<0|0?-1:0)<<16;q=o>>>16|n<<16}n=0;if((p|0)<(n|0)|(p|0)==(n|0)&q>>>0<256>>>0){r=p;s=q}else{c[h>>2]=(c[h>>2]|0)+8;r=p>>8|((p|0)<0|0?-1:0)<<24;s=q>>>8|p<<24}p=0;if((r|0)<(p|0)|(r|0)==(p|0)&s>>>0<16>>>0){t=r;u=s}else{c[h>>2]=(c[h>>2]|0)+4;t=r>>4|((r|0)<0|0?-1:0)<<28;u=s>>>4|r<<28}r=0;if((t|0)<(r|0)|(t|0)==(r|0)&u>>>0<4>>>0){v=t;w=u}else{c[h>>2]=(c[h>>2]|0)+2;v=t>>2|((t|0)<0|0?-1:0)<<30;w=u>>>2|t<<30}t=0;u=c[h>>2]|0;if((v|0)<(t|0)|(v|0)==(t|0)&w>>>0<2>>>0){x=u}else{w=u+1|0;c[h>>2]=w;x=w}if((x|0)>62){m=-22;i=e;return m|0}w=_Gb(1,0,x|0)|0;if(!((j|0)==(w|0)&(f|0)==(F|0))){m=-22;i=e;return m|0}c[b>>2]=x;c[d>>2]=1;c[a>>2]=(c[a>>2]|0)+(c[g>>2]|0);m=0;i=e;return m|0}function Yv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[b+76>>2]|0;g=a+8|0;a=c[c[(c[g>>2]|0)+32>>2]>>2]|0;h=fi(a,f)|0;if((h|0)==0){j=-12;i=d;return j|0}Xqb(c[(c[(c[g>>2]|0)+44>>2]|0)+31916>>2]|0,c[h+64>>2]|0,f,c[b+64>>2]|0,f)|0;NCb(h,b)|0;b=a+40|0;f=c[b+4>>2]|0;g=h+352|0;c[g>>2]=c[b>>2];c[g+4>>2]=f;wCb(h,c[a+148>>2]|0);f=cj(a,h)|0;JCb(e);j=f;i=d;return j|0}function Zv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0,E=0.0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+1024|0;d=b|0;e=c[a+8>>2]|0;f=c[e+44>>2]|0;if((c[f+31776>>2]|0)!=0){g=a+40|0;j=c[g>>2]|0;k=c[g+4>>2]|0;g=f+31780|0;l=f+16|0;m=0;n=0;while(1){o=_Gb(1,0,m|0)|0;if((j&o|0)==0&(k&F|0)==0){p=n}else{if((c[g>>2]|0)>0){o=0;do{h[l+(o*504|0)+(n<<3)>>3]=+h[l+(o*504|0)+(m<<3)>>3];o=o+1|0;}while((o|0)<(c[g>>2]|0))}p=n+1|0}o=m+1|0;if((o|0)<63){m=o;n=p}else{break}}}p=a+148|0;do{if((c[p>>2]|0)<=32){n=f+31780|0;if((c[n>>2]|0)>32){break}m=f+31916|0;g=f+8|0;l=c[a+52>>2]|0;k=c[a+48>>2]|0;j=a+40|0;o=e;q=Sqb(c[m>>2]|0,c[g>>2]|0,c[g+4>>2]|0,l,k,c[j>>2]|0,c[j+4>>2]|0,l,k,0,o)|0;c[m>>2]=q;if((q|0)==0){r=-12;i=b;return r|0}if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){k=c[p>>2]|0;vEb(q,2214984,k,(k|0)<0|0?-1:0,0)|0}if((c[g>>2]|0)==0&(c[g+4>>2]|0)==0){k=c[n>>2]|0;vEb(c[m>>2]|0,2205216,k,(k|0)<0|0?-1:0,0)|0}k=f+31784|0;q=(c[n>>2]|0)>0;if((c[k>>2]|0)==0){if(q){l=f+31768|0;s=f+16|0;t=s;u=0;while(1){v=c[l>>2]|0;w=c[l+4>>2]|0;x=_Gb(1,0,u|0)|0;do{if(!((v&x|0)==0&(w&F|0)==0)){y=c[p>>2]|0;z=(y|0)>0;if(z){A=0;B=0.0;while(1){C=B+ +h[t+(u*504|0)+(A<<3)>>3];D=A+1|0;if((D|0)<(y|0)){A=D;B=C}else{E=C;break}}}else{E=0.0}if(E>-1.0e-5&E<1.0e-5){if(!(E!=0.0)){break}yDb(o,24,2170504,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;break}else{if(z){H=0}else{break}do{A=t+(u*504|0)+(H<<3)|0;h[A>>3]=+h[A>>3]/E;H=H+1|0;}while((H|0)<(y|0))}}}while(0);w=u+1|0;if((w|0)<(c[n>>2]|0)){u=w}else{I=s;break}}}else{I=f+16|0}vEb(c[m>>2]|0,2197624,c[j>>2]|0,c[j+4>>2]|0,0)|0;vEb(c[m>>2]|0,2162072,c[g>>2]|0,c[g+4>>2]|0,0)|0;tqb(c[m>>2]|0,I,63)|0}else{if(q){s=f+16|0;u=f+31788|0;t=u;l=0;while(1){w=c[p>>2]|0;x=0;while(1){if((x|0)>=(w|0)){J=-1;break}if(+h[s+(l*504|0)+(x<<3)>>3]!=0.0){J=x;break}else{x=x+1|0}}c[t+(l<<2)>>2]=J;x=l+1|0;if((x|0)<(c[n>>2]|0)){l=x}else{K=u;break}}}else{K=f+31788|0}vEb(c[m>>2]|0,2197624,c[g>>2]|0,c[g+4>>2]|0,0)|0;u=c[n>>2]|0;vEb(c[m>>2]|0,2186368,u,(u|0)<0|0?-1:0,0)|0;Pqb(c[m>>2]|0,K)|0}u=Vqb(c[m>>2]|0)|0;if((u|0)<0){r=u;i=b;return r|0}if((c[n>>2]|0)>0){u=d|0;l=d+1024|0;t=f+16|0;s=0;do{if((c[p>>2]|0)>0){q=u;j=0;while(1){x=l-q|0;B=+h[t+(s*504|0)+(j<<3)>>3];w=Lb(q|0,x|0,2155528,(G=i,i=i+24|0,c[G>>2]=(j|0)!=0?2148536:9203344,h[G+8>>3]=B,c[G+16>>2]=j,G)|0)|0;i=G;v=j+1|0;if((v|0)<(c[p>>2]|0)){q=q+((x|0)>(w|0)?w:x)|0;j=v}else{break}}}yDb(o,40,2136280,(G=i,i=i+16|0,c[G>>2]=s,c[G+8>>2]=u,G)|0);i=G;s=s+1|0;}while((s|0)<(c[n>>2]|0))}if((c[k>>2]|0)==0){r=0;i=b;return r|0}yDb(o,32,2130088,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;if((c[n>>2]|0)>0){s=f+31788|0;u=0;do{t=c[s+(u<<2)>>2]|0;if((t|0)<0){yDb(o,32,2123368,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G}else{yDb(o,32,2118168,(G=i,i=i+8|0,c[G>>2]=t,G)|0);i=G}u=u+1|0;}while((u|0)<(c[n>>2]|0))}yDb(o,32,2109320,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;r=0;i=b;return r|0}}while(0);yDb(e,16,2225320,(G=i,i=i+8|0,c[G>>2]=32,G)|0);i=G;r=-1163346256;i=b;return r|0}function _v(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0;b=i;d=c[a+44>>2]|0;e=d;f=0;j=0;while(1){k=(c[e+(j<<2)>>2]|0)+f|0;l=j+1|0;if((l|0)<12e3){f=k;j=l}else{m=12e3;n=0;break}}while(1){o=m-1|0;if((m|0)==0){break}j=(c[e+(o<<2)>>2]|0)+n|0;if((j*20|0)>>>0<k>>>0){m=o;n=j}else{break}}p=64.54- +(o|0)/100.0;if(p<-24.0){q=-24.0}else{q=p>64.0?64.0:p}o=a;yDb(o,32,2155440,(a=i,i=i+8|0,h[a>>3]=q,a)|0);i=a;yDb(o,32,2086176,(a=i,i=i+8|0,h[a>>3]=+g[d+48e3>>2],a)|0);i=a;i=b;return}function $v(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[d>>2]=0;c[e>>2]=0;zk(d,3,0)|0;Ok(a,c[d>>2]|0);Ak(e,3,0)|0;Mk(a,c[e>>2]|0);c[d>>2]=0;e=0;do{f=c[1041144+(e*232|0)>>2]|0;zk(d,f,(f|0)<0|0?-1:0)|0;e=e+1|0;}while(e>>>0<20>>>0);Nk(a,c[d>>2]|0);i=b;return 0}function aw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0.0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0,pa=0.0,qa=0.0,ra=0,sa=0,ta=0.0,ua=0.0,va=0,wa=0,xa=0.0,ya=0.0,za=0,Aa=0,Ba=0.0,Ca=0.0,Da=0,Ea=0,Fa=0.0,Ga=0.0,Ha=0,Ia=0,Ja=0.0,Ka=0.0,La=0,Ma=0.0,Na=0,Oa=0,Pa=0,Qa=0.0,Ra=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;j=c[a+8>>2]|0;k=c[c[j+32>>2]>>2]|0;l=c[j+44>>2]|0;j=l;m=b+76|0;n=fi(a,c[m>>2]|0)|0;c[f>>2]=n;if((n|0)==0){JCb(e);o=-12;i=d;return o|0}a=c[m>>2]|0;m=l+48e3|0;p=c[b>>2]|0;if((a|0)==0){q=0.0}else{b=p;r=0.0;s=a;while(1){a=s-1|0;t=+g[b>>2];do{if(t>r){u=t}else{v=-0.0-t;if(!(r<v)){u=r;break}u=v}}while(0);t=+g[b+4>>2];do{if(t>u){w=t}else{v=-0.0-t;if(!(u<v)){w=u;break}w=v}}while(0);if((a|0)==0){q=w;break}else{b=b+8|0;r=w;s=a}}}w=+g[m>>2];g[m>>2]=q>w?q:w;m=p;p=n|0;s=c[p>>2]|0;b=n+76|0;n=c[b>>2]|0;x=c[l+48012>>2]|0;y=c[l+48016>>2]|0;z=l+48028|0;A=l+49052|0;B=l+48004|0;C=c[B>>2]|0;D=-20;while(1){if((D|0)>=0){break}E=D+C|0;if(+Q(+(+g[j+48028+(E<<2)>>2]))>1.0e-10){break}if(+Q(+(+g[j+49052+(E<<2)>>2]))>1.0e-10){break}else{D=D+1|0}}if((D|0)==0){TGb(z|0,0,2048)|0}if((n|0)==0){F=C}else{D=y+8|0;E=x+8|0;G=y+16|0;H=x+16|0;I=y+24|0;J=x+24|0;K=y+32|0;L=x+32|0;M=y+40|0;N=x+40|0;O=y+48|0;R=x+48|0;S=y+56|0;T=x+56|0;U=y+64|0;V=x+64|0;W=y+72|0;X=x+72|0;Y=y+80|0;Z=x+80|0;x=l+48972|0;_=l+49996|0;$=s;s=m;m=C;C=n;while(1){n=C-1|0;w=+g[s>>2];g[j+49052+(m<<2)>>2]=w;q=+h[y>>3];r=+g[s+4>>2];aa=m+1|0;g[j+49052+(aa<<2)>>2]=r;ba=m-2|0;u=+h[D>>3];t=+h[E>>3];ca=m-1|0;da=m-4|0;v=+h[G>>3];ea=+h[H>>3];fa=m-3|0;ga=m-6|0;ha=+h[I>>3];ia=+h[J>>3];ja=m-5|0;ka=m-8|0;la=+h[K>>3];ma=+h[L>>3];na=m-7|0;oa=m-10|0;pa=+h[M>>3];qa=+h[N>>3];ra=m-9|0;sa=m-12|0;ta=+h[O>>3];ua=+h[R>>3];va=m-11|0;wa=m-14|0;xa=+h[S>>3];ya=+h[T>>3];za=m-13|0;Aa=m-16|0;Ba=+h[U>>3];Ca=+h[V>>3];Da=m-15|0;Ea=m-18|0;Fa=+h[W>>3];Ga=+h[X>>3];Ha=m-17|0;Ia=m-20|0;Ja=+h[Y>>3];Ka=+h[Z>>3];La=m-19|0;Ma=q*r+(u*+g[j+49052+(ca<<2)>>2]-t*+g[j+48028+(ca<<2)>>2])+(v*+g[j+49052+(fa<<2)>>2]-ea*+g[j+48028+(fa<<2)>>2])+(ha*+g[j+49052+(ja<<2)>>2]-ia*+g[j+48028+(ja<<2)>>2])+(la*+g[j+49052+(na<<2)>>2]-ma*+g[j+48028+(na<<2)>>2])+(pa*+g[j+49052+(ra<<2)>>2]-qa*+g[j+48028+(ra<<2)>>2])+(ta*+g[j+49052+(va<<2)>>2]-ua*+g[j+48028+(va<<2)>>2])+(xa*+g[j+49052+(za<<2)>>2]-ya*+g[j+48028+(za<<2)>>2])+(Ba*+g[j+49052+(Da<<2)>>2]-Ca*+g[j+48028+(Da<<2)>>2])+(Fa*+g[j+49052+(Ha<<2)>>2]-Ga*+g[j+48028+(Ha<<2)>>2])+(Ja*+g[j+49052+(La<<2)>>2]-Ka*+g[j+48028+(La<<2)>>2]);r=w*q+(+g[j+49052+(ba<<2)>>2]*u- +g[j+48028+(ba<<2)>>2]*t)+(+g[j+49052+(da<<2)>>2]*v- +g[j+48028+(da<<2)>>2]*ea)+(+g[j+49052+(ga<<2)>>2]*ha- +g[j+48028+(ga<<2)>>2]*ia)+(+g[j+49052+(ka<<2)>>2]*la- +g[j+48028+(ka<<2)>>2]*ma)+(+g[j+49052+(oa<<2)>>2]*pa- +g[j+48028+(oa<<2)>>2]*qa)+(+g[j+49052+(sa<<2)>>2]*ta- +g[j+48028+(sa<<2)>>2]*ua)+(+g[j+49052+(wa<<2)>>2]*xa- +g[j+48028+(wa<<2)>>2]*ya)+(+g[j+49052+(Aa<<2)>>2]*Ba- +g[j+48028+(Aa<<2)>>2]*Ca)+(+g[j+49052+(Ea<<2)>>2]*Fa- +g[j+48028+(Ea<<2)>>2]*Ga)+(+g[j+49052+(Ia<<2)>>2]*Ja- +g[j+48028+(Ia<<2)>>2]*Ka);g[j+48028+(m<<2)>>2]=r;g[$>>2]=r;r=Ma;g[j+48028+(aa<<2)>>2]=r;g[$+4>>2]=r;aa=m+2|0;if((aa|0)==256){UGb(z|0,x|0,80)|0;UGb(A|0,_|0,80)|0;Na=20}else{Na=aa}if((n|0)==0){F=Na;break}else{$=$+8|0;s=s+8|0;m=Na;C=n}}}c[B>>2]=F;F=c[p>>2]|0;B=c[b>>2]|0;C=c[l+48020>>2]|0;Na=c[l+48024>>2]|0;m=l+50076|0;s=l+51100|0;$=l+48008|0;_=c[$>>2]|0;A=-4;while(1){if((A|0)>=0){break}x=A+_|0;if(+Q(+(+g[j+50076+(x<<2)>>2]))>1.0e-10){break}if(+Q(+(+g[j+51100+(x<<2)>>2]))>1.0e-10){break}else{A=A+1|0}}if((A|0)==0){TGb(m|0,0,2048)|0}if((B|0)==0){Oa=_}else{A=Na+8|0;x=C+8|0;z=Na+16|0;Z=C+16|0;C=l+51084|0;Y=l+52108|0;X=F;F=_;_=B;while(1){B=_-1|0;r=+g[X>>2];g[j+51100+(F<<2)>>2]=r;Ma=+h[Na>>3];W=X+4|0;Ka=+g[W>>2];V=F+1|0;g[j+51100+(V<<2)>>2]=Ka;U=F-2|0;Ja=+h[A>>3];Ga=+h[x>>3];T=F-1|0;S=F-4|0;Fa=+h[z>>3];Ca=+h[Z>>3];R=F-3|0;Ba=Ma*Ka+(Ja*+g[j+51100+(T<<2)>>2]-Ga*+g[j+50076+(T<<2)>>2])+(Fa*+g[j+51100+(R<<2)>>2]-Ca*+g[j+50076+(R<<2)>>2]);Ka=r*Ma+(+g[j+51100+(U<<2)>>2]*Ja- +g[j+50076+(U<<2)>>2]*Ga)+(+g[j+51100+(S<<2)>>2]*Fa- +g[j+50076+(S<<2)>>2]*Ca);g[j+50076+(F<<2)>>2]=Ka;g[X>>2]=Ka;Ka=Ba;g[j+50076+(V<<2)>>2]=Ka;g[W>>2]=Ka;W=F+2|0;if((W|0)==256){c[m>>2]=c[C>>2];c[m+4>>2]=c[C+4>>2];c[m+8>>2]=c[C+8>>2];c[m+12>>2]=c[C+12>>2];c[s>>2]=c[Y>>2];c[s+4>>2]=c[Y+4>>2];c[s+8>>2]=c[Y+8>>2];c[s+12>>2]=c[Y+12>>2];Pa=4}else{Pa=W}if((B|0)==0){Oa=Pa;break}else{X=X+8|0;F=Pa;_=B}}}c[$>>2]=Oa;Oa=c[b>>2]|0;if((Oa|0)==0){Qa=1.0e-16}else{b=c[p>>2]|0;p=Oa;Ka=1.0e-16;while(1){$=p-1|0;Ba=+g[b>>2];Ca=+g[b+4>>2];Fa=Ka+(Ba*Ba+Ca*Ca);if(($|0)==0){Qa=Fa;break}else{b=b+8|0;p=$;Ka=Fa}}}p=~~+P((+ad(+(Qa/+(Oa|0)))*10.0+90.0+-3.0)*100.0);if((p|0)<0){Ra=0}else{Ra=(p|0)>11999?11999:p}p=l+(Ra<<2)|0;c[p>>2]=(c[p>>2]|0)+1;JCb(f);o=cj(k,c[e>>2]|0)|0;i=d;return o|0}function bw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[(c[a+8>>2]|0)+44>>2]|0;e=a+48|0;f=0;while(1){if(!(f>>>0<20>>>0)){g=4;break}if((c[1041144+(f*232|0)>>2]|0)==(c[e>>2]|0)){g=5;break}else{f=f+1|0}}if((g|0)==4){yDb(0,0,1990208,(h=i,i=i+24|0,c[h>>2]=1956504,c[h+8>>2]=1929152,c[h+16>>2]=351,h)|0);i=h;Cd();return 0}else if((g|0)==5){c[d+48012>>2]=1041240+(f*232|0);c[d+48016>>2]=1041152+(f*232|0);c[d+48020>>2]=1041352+(f*232|0);c[d+48024>>2]=1041328+(f*232|0);c[d+48004>>2]=20;c[d+48008>>2]=4;d=(c[e>>2]|0)/20|0;c[a+136>>2]=d;c[a+132>>2]=d;c[a+128>>2]=d;i=b;return 0}return 0}function cw(a){a=a|0;var b=0,c=0,d=0;b=Ek()|0;do{if((b|0)==0){c=-12}else{Mk(a,b);d=xk(549824)|0;if((d|0)==0){c=-12;break}Ok(a,d);d=Dk()|0;if((d|0)==0){c=-12;break}Nk(a,d);c=0}}while(0);return c|0}function dw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0.0,k=0,l=0,m=0,n=0,o=0;d=a+8|0;e=c[(c[d>>2]|0)+44>>2]|0;f=c[a+148>>2]|0;g=c[a+48>>2]|0;i=ba(c[b+76>>2]|0,f)|0;j=+(f|0)*+(g|0)*+h[e+16>>3];f=(E=+j,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);k=e+40|0;l=c[k>>2]|0;if(!((l|0)==0|(l|0)==(g|0))){m=e+24|0;n=gHb(c[m>>2]|0,c[m+4>>2]|0,g,(g|0)<0|0?-1:0)|0;o=eHb(n,F,l,(l|0)<0|0?-1:0)|0;c[m>>2]=o;c[m+4>>2]=F}c[k>>2]=g;Se[c[e+44>>2]&511](e,b,i,~~+j>>>0,f,a+56|0);return cj(c[c[(c[d>>2]|0)+32>>2]>>2]|0,b)|0}function ew(a){a=a|0;var b=0,d=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=c[a+52>>2]|0;if((d|0)==3){c[b+44>>2]=64;return 0}else if((d|0)==1){a=b+8|0;h[a>>3]=+h[a>>3]*32767.0;c[b+44>>2]=198;return 0}else if((d|0)==2){a=b+8|0;h[a>>3]=+h[a>>3]*2147483647.0;c[b+44>>2]=212;return 0}else if((d|0)==4){c[b+44>>2]=290;return 0}else{return 0}return 0}function fw(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0.0,L=0;k=i;i=i+96|0;l=j;j=i;i=i+8|0;c[j>>2]=c[l>>2];c[j+4>>2]=c[l+4>>2];m=+h[b+8>>3];if((e|0)<=0){i=k;return}n=-0.0-m;l=j|0;o=j+4|0;j=k|0;p=k+32|0;q=k+64|0;r=b+32|0;s=d+440|0;t=d+136|0;u=b;v=b+24|0;w=v;x=b+16|0;b=c[d>>2]|0;d=0;while(1){y=+h[b>>3];if(y<m){z=y<=n}else{z=1}A=c[l>>2]|0;B=c[o>>2]|0;C=(c[r>>2]|0)!=0|(c[r+4>>2]|0)!=0;do{if(z){if(C){TGb(p|0,0,32)|0;a[p]=0;D=c[t>>2]|0;G=c[t+4>>2]|0;if((D|0)==0&(G|0)==(-2147483648|0)){Lb(p|0,32,2266872,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Lb(p|0,32,2251472,(H=i,i=i+8|0,h[H>>3]=(+(D>>>0)+ +(G|0)*4294967296.0)*(+(A|0)/+(B|0)),H)|0)|0;i=H}CBb(s,2322288,p,0)|0;TGb(q|0,0,32)|0;a[q]=0;G=ZGb(c[t>>2]|0,c[t+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0)|0;D=F;if((G|0)==0&(D|0)==(-2147483648|0)){Lb(q|0,32,2266872,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Lb(q|0,32,2251472,(H=i,i=i+8|0,h[H>>3]=(+(G>>>0)+ +(D|0)*4294967296.0)*(+(A|0)/+(B|0)),H)|0)|0;i=H}CBb(s,2299544,q,0)|0;D=BBb(c[s>>2]|0,2322288,0,0)|0;if((D|0)==0){I=0}else{I=c[D+4>>2]|0}D=BBb(c[s>>2]|0,2299544,0,0)|0;if((D|0)==0){J=0}else{J=c[D+4>>2]|0}yDb(u,32,2281944,(H=i,i=i+16|0,c[H>>2]=I,c[H+8>>2]=J,H)|0);i=H}TGb(w|0,0,16)|0}else{if(C){break}D=YGb(c[v>>2]|0,c[v+4>>2]|0,1,0)|0;G=F;c[v>>2]=D;c[v+4>>2]=G;if((G|0)<(g|0)|(G|0)==(g|0)&D>>>0<f>>>0){break}y=+(A|0)/+(B|0);K=+h[x>>3]/y+.5;D=ZGb(c[t>>2]|0,c[t+4>>2]|0,~~+K>>>0,(E=+K,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0))|0;G=F;c[r>>2]=D;c[r+4>>2]=G;TGb(j|0,0,32)|0;a[j]=0;if((D|0)==0&(G|0)==(-2147483648|0)){Lb(j|0,32,2266872,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Lb(j|0,32,2251472,(H=i,i=i+8|0,h[H>>3]=y*(+(D>>>0)+ +(G|0)*4294967296.0),H)|0)|0;i=H}CBb(s,1886408,j,0)|0;G=BBb(c[s>>2]|0,1886408,0,0)|0;if((G|0)==0){L=0}else{L=c[G+4>>2]|0}yDb(u,32,2344216,(H=i,i=i+8|0,c[H>>2]=L,H)|0);i=H}}while(0);B=d+1|0;if((B|0)<(e|0)){b=b+8|0;d=B}else{break}}i=k;return}function gw(b,d,e,f,j,k){b=b|0;d=d|0;e=e|0;f=f|0;j=j|0;k=k|0;var l=0,m=0,n=0.0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0;l=i;i=i+96|0;m=k;k=i;i=i+8|0;c[k>>2]=c[m>>2];c[k+4>>2]=c[m+4>>2];n=+h[b+8>>3];if((e|0)<=0){i=l;return}o=-0.0-n;m=k|0;p=k+4|0;k=l|0;q=l+32|0;r=l+64|0;s=b+32|0;t=d+440|0;u=d+136|0;v=b;w=b+24|0;x=w;y=b+16|0;b=c[d>>2]|0;d=0;while(1){z=+g[b>>2];if(z<n){A=z<=o}else{A=1}B=c[m>>2]|0;C=c[p>>2]|0;D=(c[s>>2]|0)!=0|(c[s+4>>2]|0)!=0;do{if(A){if(D){TGb(q|0,0,32)|0;a[q]=0;G=c[u>>2]|0;H=c[u+4>>2]|0;if((G|0)==0&(H|0)==(-2147483648|0)){Lb(q|0,32,2266872,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Lb(q|0,32,2251472,(I=i,i=i+8|0,h[I>>3]=(+(G>>>0)+ +(H|0)*4294967296.0)*(+(B|0)/+(C|0)),I)|0)|0;i=I}CBb(t,2322288,q,0)|0;TGb(r|0,0,32)|0;a[r]=0;H=ZGb(c[u>>2]|0,c[u+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;G=F;if((H|0)==0&(G|0)==(-2147483648|0)){Lb(r|0,32,2266872,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Lb(r|0,32,2251472,(I=i,i=i+8|0,h[I>>3]=(+(H>>>0)+ +(G|0)*4294967296.0)*(+(B|0)/+(C|0)),I)|0)|0;i=I}CBb(t,2299544,r,0)|0;G=BBb(c[t>>2]|0,2322288,0,0)|0;if((G|0)==0){J=0}else{J=c[G+4>>2]|0}G=BBb(c[t>>2]|0,2299544,0,0)|0;if((G|0)==0){K=0}else{K=c[G+4>>2]|0}yDb(v,32,2281944,(I=i,i=i+16|0,c[I>>2]=J,c[I+8>>2]=K,I)|0);i=I}TGb(x|0,0,16)|0}else{if(D){break}G=YGb(c[w>>2]|0,c[w+4>>2]|0,1,0)|0;H=F;c[w>>2]=G;c[w+4>>2]=H;if((H|0)<(j|0)|(H|0)==(j|0)&G>>>0<f>>>0){break}z=+(B|0)/+(C|0);L=+h[y>>3]/z+.5;G=ZGb(c[u>>2]|0,c[u+4>>2]|0,~~+L>>>0,(E=+L,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0))|0;H=F;c[s>>2]=G;c[s+4>>2]=H;TGb(k|0,0,32)|0;a[k]=0;if((G|0)==0&(H|0)==(-2147483648|0)){Lb(k|0,32,2266872,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Lb(k|0,32,2251472,(I=i,i=i+8|0,h[I>>3]=z*(+(G>>>0)+ +(H|0)*4294967296.0),I)|0)|0;i=I}CBb(t,1886408,k,0)|0;H=BBb(c[t>>2]|0,1886408,0,0)|0;if((H|0)==0){M=0}else{M=c[H+4>>2]|0}yDb(v,32,2344216,(I=i,i=i+8|0,c[I>>2]=M,I)|0);i=I}}while(0);C=d+1|0;if((C|0)<(e|0)){b=b+4|0;d=C}else{break}}i=l;return}function hw(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0;k=i;i=i+96|0;l=j;j=i;i=i+8|0;c[j>>2]=c[l>>2];c[j+4>>2]=c[l+4>>2];l=~~+h[b+8>>3];if((e|0)<=0){i=k;return}m=-l|0;n=j|0;o=j+4|0;j=k|0;p=k+32|0;q=k+64|0;r=b+32|0;s=d+440|0;t=d+136|0;u=b;v=b+24|0;w=v;x=b+16|0;b=c[d>>2]|0;d=0;while(1){y=c[b>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;B=(c[r>>2]|0)!=0|(c[r+4>>2]|0)!=0;do{if((y|0)<=(m|0)|(y|0)>=(l|0)){if(B){TGb(p|0,0,32)|0;a[p]=0;C=c[t>>2]|0;D=c[t+4>>2]|0;if((C|0)==0&(D|0)==(-2147483648|0)){Lb(p|0,32,2266872,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0)|0;i=G}else{Lb(p|0,32,2251472,(G=i,i=i+8|0,h[G>>3]=(+(C>>>0)+ +(D|0)*4294967296.0)*(+(z|0)/+(A|0)),G)|0)|0;i=G}CBb(s,2322288,p,0)|0;TGb(q|0,0,32)|0;a[q]=0;D=ZGb(c[t>>2]|0,c[t+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0)|0;C=F;if((D|0)==0&(C|0)==(-2147483648|0)){Lb(q|0,32,2266872,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0)|0;i=G}else{Lb(q|0,32,2251472,(G=i,i=i+8|0,h[G>>3]=(+(D>>>0)+ +(C|0)*4294967296.0)*(+(z|0)/+(A|0)),G)|0)|0;i=G}CBb(s,2299544,q,0)|0;C=BBb(c[s>>2]|0,2322288,0,0)|0;if((C|0)==0){H=0}else{H=c[C+4>>2]|0}C=BBb(c[s>>2]|0,2299544,0,0)|0;if((C|0)==0){I=0}else{I=c[C+4>>2]|0}yDb(u,32,2281944,(G=i,i=i+16|0,c[G>>2]=H,c[G+8>>2]=I,G)|0);i=G}TGb(w|0,0,16)|0}else{if(B){break}C=YGb(c[v>>2]|0,c[v+4>>2]|0,1,0)|0;D=F;c[v>>2]=C;c[v+4>>2]=D;if((D|0)<(g|0)|(D|0)==(g|0)&C>>>0<f>>>0){break}J=+(z|0)/+(A|0);K=+h[x>>3]/J+.5;C=ZGb(c[t>>2]|0,c[t+4>>2]|0,~~+K>>>0,(E=+K,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0))|0;D=F;c[r>>2]=C;c[r+4>>2]=D;TGb(j|0,0,32)|0;a[j]=0;if((C|0)==0&(D|0)==(-2147483648|0)){Lb(j|0,32,2266872,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0)|0;i=G}else{Lb(j|0,32,2251472,(G=i,i=i+8|0,h[G>>3]=J*(+(C>>>0)+ +(D|0)*4294967296.0),G)|0)|0;i=G}CBb(s,1886408,j,0)|0;D=BBb(c[s>>2]|0,1886408,0,0)|0;if((D|0)==0){L=0}else{L=c[D+4>>2]|0}yDb(u,32,2344216,(G=i,i=i+8|0,c[G>>2]=L,G)|0);i=G}}while(0);A=d+1|0;if((A|0)<(e|0)){b=b+4|0;d=A}else{break}}i=k;return}function iw(d,e,f,g,j,k){d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0;l=i;i=i+96|0;m=k;k=i;i=i+8|0;c[k>>2]=c[m>>2];c[k+4>>2]=c[m+4>>2];m=~~+h[d+8>>3];if((f|0)<=0){i=l;return}n=-(m<<16>>16)|0;o=k|0;p=k+4|0;k=l|0;q=l+32|0;r=l+64|0;s=d+32|0;t=e+440|0;u=e+136|0;v=d;w=d+24|0;x=w;y=d+16|0;d=c[e>>2]|0;e=0;while(1){z=b[d>>1]|0;if(z<<16>>16<m<<16>>16){A=(z<<16>>16|0)<=(n|0)}else{A=1}z=c[o>>2]|0;B=c[p>>2]|0;C=(c[s>>2]|0)!=0|(c[s+4>>2]|0)!=0;do{if(A){if(C){TGb(q|0,0,32)|0;a[q]=0;D=c[u>>2]|0;G=c[u+4>>2]|0;if((D|0)==0&(G|0)==(-2147483648|0)){Lb(q|0,32,2266872,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Lb(q|0,32,2251472,(H=i,i=i+8|0,h[H>>3]=(+(D>>>0)+ +(G|0)*4294967296.0)*(+(z|0)/+(B|0)),H)|0)|0;i=H}CBb(t,2322288,q,0)|0;TGb(r|0,0,32)|0;a[r]=0;G=ZGb(c[u>>2]|0,c[u+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;D=F;if((G|0)==0&(D|0)==(-2147483648|0)){Lb(r|0,32,2266872,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Lb(r|0,32,2251472,(H=i,i=i+8|0,h[H>>3]=(+(G>>>0)+ +(D|0)*4294967296.0)*(+(z|0)/+(B|0)),H)|0)|0;i=H}CBb(t,2299544,r,0)|0;D=BBb(c[t>>2]|0,2322288,0,0)|0;if((D|0)==0){I=0}else{I=c[D+4>>2]|0}D=BBb(c[t>>2]|0,2299544,0,0)|0;if((D|0)==0){J=0}else{J=c[D+4>>2]|0}yDb(v,32,2281944,(H=i,i=i+16|0,c[H>>2]=I,c[H+8>>2]=J,H)|0);i=H}TGb(x|0,0,16)|0}else{if(C){break}D=YGb(c[w>>2]|0,c[w+4>>2]|0,1,0)|0;G=F;c[w>>2]=D;c[w+4>>2]=G;if((G|0)<(j|0)|(G|0)==(j|0)&D>>>0<g>>>0){break}K=+(z|0)/+(B|0);L=+h[y>>3]/K+.5;D=ZGb(c[u>>2]|0,c[u+4>>2]|0,~~+L>>>0,(E=+L,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0))|0;G=F;c[s>>2]=D;c[s+4>>2]=G;TGb(k|0,0,32)|0;a[k]=0;if((D|0)==0&(G|0)==(-2147483648|0)){Lb(k|0,32,2266872,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Lb(k|0,32,2251472,(H=i,i=i+8|0,h[H>>3]=K*(+(D>>>0)+ +(G|0)*4294967296.0),H)|0)|0;i=H}CBb(t,1886408,k,0)|0;G=BBb(c[t>>2]|0,1886408,0,0)|0;if((G|0)==0){M=0}else{M=c[G+4>>2]|0}yDb(v,32,2344216,(H=i,i=i+8|0,c[H>>2]=M,H)|0);i=H}}while(0);B=e+1|0;if((B|0)<(f|0)){d=d+2|0;e=B}else{break}}i=l;return}function jw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;e=d+52|0;f=c[d+48>>2]|0;d=a;a=c[e>>2]|0;g=JBb(e,f,159824,0,0,0,0,0,d)|0;if((g|0)<0){yDb(d,16,2344136,(d=i,i=i+8|0,c[d>>2]=f,d)|0);i=d;c[e>>2]=a;h=g;i=b;return h|0}else{IBb(a);h=0;i=b;return h|0}return 0}function kw(a){a=a|0;var b=0;b=c[a+44>>2]|0;IBb(c[b+52>>2]|0);HEb(b);return}function lw(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;d=Fk()|0;if((d|0)==0){e=-12;return e|0}Mk(a,d);d=xk(549736+((c[b+40>>2]|0)*28|0)|0)|0;if((d|0)==0){e=-12;return e|0}Ok(a,d);d=Dk()|0;if((d|0)==0){e=-12;return e|0}Nk(a,d);e=0;return e|0}function mw(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;g=i;f=c[a+44>>2]|0;if((QGb(b,2033392)|0)!=0){h=-38;i=g;return h|0}b=f+52|0;e=a;j=c[b>>2]|0;k=JBb(b,d,159824,0,0,0,0,0,e)|0;if((k|0)<0){yDb(e,16,2344136,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;c[b>>2]=j;h=k;i=g;return h|0}IBb(j);if((c[f+44>>2]|0)!=0){h=0;i=g;return h|0}nw(a)|0;h=0;i=g;return h|0}function nw(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0,j=0,l=0,m=0,n=0,o=0.0,p=0,q=0;b=i;d=c[a+44>>2]|0;e=d+56|0;f=+MBb(c[d+52>>2]|0,e,0);g=d+152|0;h[g>>3]=f;h[k>>3]=f;j=c[k+4>>2]&2147483647;l=2146435072;do{if(j>>>0>l>>>0|j>>>0==l>>>0&(c[k>>2]|0)>>>0>0>>>0){m=a;if((c[d+44>>2]|0)!=0){yDb(m,24,2086048,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;h[g>>3]=0.0;o=0.0;p=m;break}yDb(m,16,2155304,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=-22;i=b;return q|0}else{o=f;p=a}}while(0);h[d+144>>3]=o;o=+h[d+128>>3];f=+h[d+96>>3];a=d+40|0;l=c[562560+(c[a>>2]<<2)>>2]|0;yDb(p,40,2034928,(n=i,i=i+32|0,h[n>>3]=+h[e>>3],h[n+8>>3]=o,h[n+16>>3]=f,c[n+24>>2]=l,n)|0);i=n;if((c[a>>2]|0)==0){a=~~(+h[g>>3]*256.0+.5);c[d+160>>2]=a;h[g>>3]=+(a|0)*.00390625;yDb(p,40,1990128,(n=i,i=i+8|0,c[n>>2]=a,n)|0);i=n}f=+h[g>>3];o=+$(f)*20.0/2.302585092994046;yDb(p,40,1956384,(n=i,i=i+16|0,h[n>>3]=f,h[n+8>>3]=o,n)|0);i=n;n=d+180|0;c[n>>2]=1;switch(yFb(c[d+172>>2]|0)|0){case 1:{p=d+176|0;if((c[d+160>>2]|0)<65536){c[p>>2]=94;q=0;i=b;return q|0}else{c[p>>2]=62;q=0;i=b;return q|0}break};case 3:{fCb(d+4|0,0);c[n>>2]=4;q=0;i=b;return q|0};case 2:{c[d+176>>2]=32;q=0;i=b;return q|0};case 4:{fCb(d+4|0,0);c[n>>2]=8;q=0;i=b;return q|0};case 0:{n=d+176|0;if((c[d+160>>2]|0)<16777216){c[n>>2]=732;q=0;i=b;return q|0}else{c[n>>2]=448;q=0;i=b;return q|0}break};default:{q=0;i=b;return q|0}}return 0}function ow(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)>0){g=0}else{return}do{h=(ba((d[c+g|0]|0)-128|0,f)|0)+128>>8;i=h+128|0;if(i>>>0>255>>>0){j=-128-h>>31&255}else{j=i&255}a[b+g|0]=j;g=g+1|0;}while((g|0)<(e|0));return}function pw(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((e|0)<=0){return}g=f;h=(f|0)<0|0?-1:0;f=0;do{i=YGb(d[c+f|0]|0,0,-128,-1)|0;j=gHb(i,F,g,h)|0;i=YGb(j,F,128,0)|0;j=F;k=YGb(i>>>8|j<<24,j>>>8|0<<24,128,0)|0;j=k;if(j>>>0>255>>>0){l=-j>>31&255}else{l=k&255}a[b+f|0]=l;f=f+1|0;}while((f|0)<(e|0));return}function qw(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=a;a=c;if((d|0)>0){g=0}else{return}do{c=(ba(b[a+(g<<1)>>1]|0,e)|0)+128|0;h=c>>8;if((h+32768|0)>>>0>65535>>>0){i=(c>>31^32767)&65535}else{i=h&65535}b[f+(g<<1)>>1]=i;g=g+1|0;}while((g|0)<(d|0));return}function rw(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=a;a=c;if((d|0)<=0){return}c=e;g=(e|0)<0|0?-1:0;e=0;do{h=b[a+(e<<1)>>1]|0;i=gHb(h<<16>>16,h<<16>>16<0|0?-1:0,c,g)|0;h=YGb(i,F,128,0)|0;i=h>>>8|F<<24;h=i;if((h+32768|0)>>>0>65535>>>0){j=(h>>31^32767)&65535}else{j=i&65535}b[f+(e<<1)>>1]=j;e=e+1|0;}while((e|0)<(d|0));return}function sw(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;a=b;if((d|0)<=0){return}b=e;g=(e|0)<0|0?-1:0;e=0;do{h=c[a+(e<<2)>>2]|0;i=gHb(h,(h|0)<0|0?-1:0,b,g)|0;h=YGb(i,F,128,0)|0;i=F;j=h>>>8|i<<24;h=YGb(j,i>>8|((i|0)<0|0?-1:0)<<24,-2147483648,0)|0;k=F;l=0;if(k>>>0>l>>>0|k>>>0==l>>>0&h>>>0>-1>>>0){((i|0)<0|0?-1:0)>>31|((i|0)<0|0?-1:0)<<1;m=(i>>31|((i|0)<0|0?-1:0)<<1)^2147483647}else{m=j}c[f+(e<<2)>>2]=m;e=e+1|0;}while((e|0)<(d|0));return}function tw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0.0,m=0.0,n=0.0;b=i;d=c[a>>2]|0;a=c[d+44>>2]|0;e=c[c[d+16>>2]>>2]|0;f=e+52|0;c[a+172>>2]=c[f>>2];g=e+148|0;j=a+164|0;c[j>>2]=c[g>>2];if((CFb(c[f>>2]|0)|0)==0){k=1}else{k=c[j>>2]|0}c[a+168>>2]=k;h[a+144>>3]=+q;h[a+128>>3]=+q;h[a+120>>3]=+q;h[a+112>>3]=+q;h[a+96>>3]=+q;h[a+88>>3]=+q;h[a+80>>3]=+q;h[a+72>>3]=+q;h[a+56>>3]=+q;l=+(c[g>>2]|0);h[a+64>>3]=l;m=+(c[e+56>>2]|0)/+(c[e+60>>2]|0);h[a+136>>3]=m;n=+(c[e+48>>2]|0);h[a+104>>3]=n;yDb(c[e>>2]|0,40,2075720,(e=i,i=i+24|0,h[e>>3]=m,h[e+8>>3]=n,h[e+16>>3]=l,e)|0);i=e;e=nw(d)|0;i=b;return e|0}function uw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0,A=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;j=c[g+44>>2]|0;k=c[c[g+32>>2]>>2]|0;l=c[b+76>>2]|0;m=j+56|0;n=j+112|0;o=c[n+4>>2]&2147483647;p=2146435072;r=b+136|0;s=c[r>>2]|0;t=c[r+4>>2]|0;if(o>>>0>p>>>0|o>>>0==p>>>0&(c[n>>2]|0)>>>0>0>>>0){if((s|0)==0&(t|0)==(-2147483648|0)){h[n>>3]=+q;u=+q}else{h[n>>3]=+(s>>>0)+ +(t|0)*4294967296.0;u=(+(s>>>0)+ +(t|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}h[j+120>>3]=u}if((s|0)==0&(t|0)==(-2147483648|0)){h[j+96>>3]=+q;v=+q}else{h[j+96>>3]=+(s>>>0)+ +(t|0)*4294967296.0;v=(+(s>>>0)+ +(t|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}h[j+128>>3]=v;t=a+160|0;h[m>>3]=+((c[t>>2]|0)>>>0)+ +(c[t+4>>2]|0)*4294967296.0;t=sCb(b)|0;b=F;if((t|0)==(-1|0)&(b|0)==(-1|0)){w=+q}else{w=+(t>>>0)+ +(b|0)*4294967296.0}h[j+88>>3]=w;if((c[j+44>>2]|0)==1){nw(g)|0}g=j+152|0;do{if(+h[g>>3]==1.0){x=15}else{b=j+160|0;if((c[b>>2]|0)==256){x=15;break}t=c[e>>2]|0;do{if((RCb(t)|0)==0){m=fi(a,l)|0;c[f>>2]=m;if((m|0)==0){y=-12;i=d;return y|0}s=NCb(m,c[e>>2]|0)|0;if((s|0)>=0){break}JCb(f);JCb(e);y=s;i=d;return y|0}else{c[f>>2]=t}}while(0);t=j+40|0;if((c[t>>2]|0)==0){if((c[b>>2]|0)>0){x=23}}else{x=23}a:do{if((x|0)==23){if((CFb(c[(c[e>>2]|0)+80>>2]|0)|0)==0){s=ba(c[j+164>>2]|0,l)|0;m=c[j+180>>2]|0;z=m-1+s&-m}else{m=c[j+180>>2]|0;z=l-1+m&-m}if((c[t>>2]|0)==0){m=j+168|0;if((c[m>>2]|0)<=0){break}s=j+176|0;n=0;while(1){cf[c[s>>2]&1023](c[(c[(c[f>>2]|0)+64>>2]|0)+(n<<2)>>2]|0,c[(c[(c[e>>2]|0)+64>>2]|0)+(n<<2)>>2]|0,z,c[b>>2]|0);n=n+1|0;if((n|0)>=(c[m>>2]|0)){break a}}}m=(yFb(c[j+172>>2]|0)|0)==3;n=j+168|0;s=(c[n>>2]|0)>0;if(m){if(!s){break}m=j+12|0;p=0;do{te[c[m>>2]&7](c[(c[(c[f>>2]|0)+64>>2]|0)+(p<<2)>>2]|0,c[(c[(c[e>>2]|0)+64>>2]|0)+(p<<2)>>2]|0,+h[g>>3],z);p=p+1|0;}while((p|0)<(c[n>>2]|0))}else{if(!s){break}p=j+16|0;m=0;do{ue[c[p>>2]&3](c[(c[(c[f>>2]|0)+64>>2]|0)+(m<<2)>>2]|0,c[(c[(c[e>>2]|0)+64>>2]|0)+(m<<2)>>2]|0,+h[g>>3],z);m=m+1|0;}while((m|0)<(c[n>>2]|0))}}}while(0);b=c[e>>2]|0;if((b|0)==(c[f>>2]|0)){A=b;break}JCb(e);A=c[f>>2]|0}}while(0);if((x|0)==15){x=c[e>>2]|0;c[f>>2]=x;A=x}x=j+72|0;h[x>>3]=+h[x>>3]+ +(c[A+76>>2]|0);y=cj(k,A)|0;i=d;return y|0}function vw(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;b=i;i=i+736|0;e=b|0;f=c[a+44>>2]|0;TGb(e|0,0,736)|0;g=f;f=0;j=0;k=0;do{l=g+(f<<3)|0;k=YGb(c[l>>2]|0,c[l+4>>2]|0,k,j)|0;j=F;f=f+1|0;}while((f|0)<65536);f=a;yDb(f,32,2155088,(a=i,i=i+16|0,c[a>>2]=k,c[a+8>>2]=j,a)|0);i=a;if((k|0)==0&(j|0)==0){i=b;return}l=j>>>1|0<<31;m=l>>>0>65535>>>0;n=m?j>>>17|0<<15:l;l=m?16:0;if((n&65280|0)==0){o=l;p=n}else{o=l|8;p=n>>>8}n=(d[1191992+p|0]|0)+o|0;o=0;p=0;l=0;m=0;q=0;do{r=g+(o<<3)|0;s=$Gb(c[r>>2]|0,c[r+4>>2]|0,n|0)|0;r=F;q=YGb(s,r,q,m)|0;m=F;t=o-32768|0;u=gHb(ba(t,t)|0,0,s,r)|0;l=YGb(u,F,l,p)|0;p=F;o=o+1|0;}while((o|0)<65536);if((q|0)==0&(m|0)==0){i=b;return}o=YGb(l,p,q>>>1|m<<31,m>>>1|0<<31)|0;p=hHb(o,F,q,m)|0;m=F;q=0;if(!(m>>>0<q>>>0|m>>>0==q>>>0&p>>>0<1073741825>>>0)){yDb(0,0,2085880,(a=i,i=i+24|0,c[a>>2]=2034776,c[a+8>>2]=1990024,c[a+16>>2]=111,a)|0);i=a;Cd()}if((p|0)==0&(m|0)==0){v=91.0}else{v=+$((+(p>>>0)+ +(m>>>0)*4294967296.0)*9.313225746154785e-10)*-4.342944819032518}yDb(f,32,1956336,(a=i,i=i+8|0,h[a>>3]=-0.0-v,a)|0);i=a;m=32768;while(1){if((m|0)<=0){break}p=g+(m+32768<<3)|0;if(!((c[p>>2]|0)==0&(c[p+4>>2]|0)==0)){break}p=g+(32768-m<<3)|0;if((c[p>>2]|0)==0&(c[p+4>>2]|0)==0){m=m-1|0}else{break}}p=ba(m,m)|0;if((p|0)==0){w=91.0}else{w=+$(+(p>>>0>>>0)*9.313225746154785e-10)*-4.342944819032518}yDb(f,32,1929072,(a=i,i=i+8|0,h[a>>3]=-0.0-w,a)|0);i=a;p=0;while(1){m=g+(p<<3)|0;q=p-32768|0;o=ba(q,q)|0;if((o|0)==0){x=91}else{x=~~(+$(+(o>>>0>>>0)*9.313225746154785e-10)*-4.342944819032518)}o=e+(x<<3)|0;q=YGb(c[o>>2]|0,c[o+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;c[o>>2]=q;c[o+4>>2]=F;o=p+1|0;if((o|0)<65536){p=o}else{y=0;break}}while(1){if((y|0)>=92){z=28;break}p=e+(y<<3)|0;A=c[p>>2]|0;B=c[p+4>>2]|0;if((A|0)==0&(B|0)==0){y=y+1|0}else{break}}if((z|0)==28){i=b;return}z=hHb(k,j,1e3,0)|0;p=F;x=0;if(j>>>0>x>>>0|j>>>0==x>>>0&k>>>0>999>>>0){C=y;D=0;E=0;G=B;H=A}else{i=b;return}while(1){yDb(f,32,1907e3,(a=i,i=i+24|0,c[a>>2]=C,c[a+8>>2]=H,c[a+16>>2]=G,a)|0);i=a;A=YGb(H,G,E,D)|0;B=F;y=C+1|0;if(!((y|0)<92&(B>>>0<p>>>0|B>>>0==p>>>0&A>>>0<z>>>0))){break}k=e+(y<<3)|0;C=y;D=B;E=A;G=c[k+4>>2]|0;H=c[k>>2]|0}i=b;return}function ww(a){a=a|0;var b=0,c=0;b=xk(549720)|0;if((b|0)==0){c=-12;return c|0}Ok(a,b);c=0;return c|0}function xw(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=a+8|0;a=c[(c[e>>2]|0)+44>>2]|0;f=d+352|0;g=c[d+76>>2]|0;h=hBb(c[f>>2]|0,c[f+4>>2]|0)|0;if((CFb(c[d+80>>2]|0)|0)==0){i=1;j=ba(h,g)|0;k=4}else{if((h|0)>0){i=h;j=g;k=4}}do{if((k|0)==4){g=c[d+64>>2]|0;h=a;if((j|0)>0){l=0}else{break}do{f=c[g+(l<<2)>>2]|0;m=0;do{n=h+((b[f+(m<<1)>>1]|0)+32768<<3)|0;o=YGb(c[n>>2]|0,c[n+4>>2]|0,1,0)|0;c[n>>2]=o;c[n+4>>2]=F;m=m+1|0;}while((m|0)<(j|0));l=l+1|0;}while((l|0)<(i|0))}}while(0);return cj(c[c[(c[e>>2]|0)+32>>2]>>2]|0,d)|0}function yw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a|0)==0){e=-22;i=d;return e|0}if((b|0)==0){yDb(0,0,2265696,(f=i,i=i+24|0,c[f>>2]=2155080,c[f+8>>2]=2085856,c[f+16>>2]=93,f)|0);i=f;Cd();return 0}UGb(a|0,b+4|0,32)|0;UGb(a+32|0,b+40|0,32)|0;g=b+80|0;h=c[g+4>>2]|0;j=a+136|0;c[j>>2]=c[g>>2];c[j+4>>2]=h;h=b+96|0;c[a+80>>2]=c[h>>2];j=b+88|0;tCb(a,c[j>>2]|0,c[j+4>>2]|0);j=c[b+104>>2]|0;if((j|0)==0){g=b+72|0;k=c[g>>2]|0;if((k|0)==0){yDb(0,0,2265696,(f=i,i=i+24|0,c[f>>2]=2034760,c[f+8>>2]=2085856,c[f+16>>2]=104,f)|0);i=f;Cd();return 0}c[a+68>>2]=c[k>>2];c[a+72>>2]=c[k+4>>2];l=k+8|0;k=a+124|0;m=c[l+4>>2]|0;c[k>>2]=c[l>>2];c[k+4>>2]=m;m=c[g>>2]|0;c[a+296>>2]=c[m+16>>2];c[a+300>>2]=c[m+20>>2];c[a+84>>2]=c[m+28>>2];c[a+88>>2]=c[m+24>>2];e=0;i=d;return e|0}else if((j|0)==1){j=b+76|0;m=c[j>>2]|0;if((m|0)==0){yDb(0,0,2265696,(f=i,i=i+24|0,c[f>>2]=199e4,c[f+8>>2]=2085856,c[f+16>>2]=114,f)|0);i=f;Cd();return 0}f=m|0;m=hBb(c[f>>2]|0,c[f+4>>2]|0)|0;f=(CFb(c[h>>2]|0)|0)!=0;h=f?m:1;do{if(h>>>0>8>>>0){m=h<<2;f=cEb(m)|0;c[a+64>>2]=f;if((f|0)==0){e=-12;i=d;return e|0}else{UGb(f|0,c[b+36>>2]|0,m)|0;break}}else{c[a+64>>2]=a}}while(0);b=c[j>>2]|0;c[a+76>>2]=c[b+8>>2];xCb(a,c[b+12>>2]|0);b=c[j>>2]|0;uCb(a,c[b>>2]|0,c[b+4>>2]|0);wCb(a,c[(c[j>>2]|0)+16>>2]|0);e=0;i=d;return e|0}else{e=-22;i=d;return e|0}return 0}function zw(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:do{if((f|0)>0){i=0;while(1){j=0;while(1){if((j|0)>=(g|0)){break}if((d[b+((ba(j,e)|0)+i)|0]|0|0)>(h|0)){k=i;break a}else{j=j+1|0}}j=i+1|0;if((j|0)<(f|0)){i=j}else{k=j;break}}}else{k=0}}while(0);if((k|0)==(f|0)){l=0;return l|0}i=f-1|0;b:do{if((i|0)<(k|0)){m=i}else{j=i;while(1){n=0;while(1){if((n|0)>=(g|0)){break}if((d[b+((ba(n,e)|0)+j)|0]|0|0)>(h|0)){m=j;break b}else{n=n+1|0}}n=j-1|0;if((n|0)<(k|0)){m=n;break}else{j=n}}}}while(0);c:do{if((g|0)>0){i=0;j=b;while(1){n=0;while(1){if((n|0)>=(f|0)){break}if((d[j+n|0]|0|0)>(h|0)){o=i;break c}else{n=n+1|0}}n=i+1|0;if((n|0)<(g|0)){i=n;j=j+e|0}else{o=n;break}}}else{o=0}}while(0);j=g-1|0;d:do{if((j|0)<(o|0)){p=j}else{g=-e|0;i=j;n=b+(ba(j,e)|0)|0;while(1){q=0;while(1){if((q|0)>=(f|0)){break}if((d[n+q|0]|0|0)>(h|0)){p=i;break d}else{q=q+1|0}}q=i-1|0;if((q|0)<(o|0)){p=q;break}else{i=q;n=n+g|0}}}}while(0);c[a>>2]=k;c[a+8>>2]=o;c[a+4>>2]=m;c[a+12>>2]=p;l=1;return l|0}function Aw(b,c){b=b|0;c=c|0;var d=0;switch(c|0){case 295:case 27:{a[b+3|0]=0;a[b]=1;a[b+1|0]=2;a[b+2|0]=3;d=0;return d|0};case 317:case 82:{a[b+1|0]=0;a[b+2|0]=1;a[b]=2;a[b+3|0]=3;d=0;return d|0};case 42:case 41:case 291:case 292:case 296:case 28:case 2:{a[b]=0;a[b+1|0]=1;a[b+2|0]=2;a[b+3|0]=3;d=0;return d|0};case 297:case 29:{a[b+3|0]=0;a[b+2|0]=1;a[b+1|0]=2;a[b]=3;d=0;return d|0};case 68:case 67:case 293:case 294:case 30:case 298:case 3:{a[b+2|0]=0;a[b+1|0]=1;a[b]=2;a[b+3|0]=3;d=0;return d|0};default:{d=-22;return d|0}}return 0}function Bw(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+16|0;h=g|0;j=bFb(f)|0;k=h;TGb(k|0,0,16)|0;if((c[j>>2]|0)==0){l=-22;i=g;return l|0}if(!((a[j+7|0]&15)==0)){l=-38;i=g;return l|0}m=j+4|0;n=a[m]|0;a:do{if(n<<24>>24==0){o=0}else{p=0;q=0;while(1){r=b[j+8+(p<<1)>>1]|0;if(!((r&30720)==14336)){l=-38;s=14;break}t=r&3;u=h+(t<<2)|0;v=c[u>>2]|0;w=((r&65535)>>>2&7)+1|0;if(!((v|0)==0|(v|0)==(w|0))){l=-38;s=14;break}c[u>>2]=w;if(w>>>0>7>>>0){l=-38;s=14;break}w=t+1|0;t=q>>>0>w>>>0?q:w;w=p+1|0;if(w>>>0<(n&255)>>>0){p=w;q=t}else{o=t;break a}}if((s|0)==14){i=g;return l|0}}}while(0);s=j+5|0;do{if((a[s]|0)==0){n=j+6|0;if((a[n]|0)!=0&o>>>0<3>>>0){l=-38}else{x=n;break}i=g;return l|0}else{if(o>>>0<3>>>0){l=-38;i=g;return l|0}else{x=j+6|0;break}}}while(0);TGb(e|0,0,44)|0;c[e>>2]=j;c[e+4>>2]=f;c[e+8>>2]=o;o=e+12|0;c[o>>2]=c[k>>2];c[o+4>>2]=c[k+4>>2];c[o+8>>2]=c[k+8>>2];c[o+12>>2]=c[k+12>>2];k=a[s]|0;a[e+40|0]=k;a[e+34|0]=k;a[e+33|0]=k;k=a[x]|0;a[e+41|0]=k;a[e+38|0]=k;a[e+37|0]=k;k=0;while(1){x=b[j+8+(k<<1)>>1]|0;s=(x&3)+(e+28)|0;a[s]=1<<((x&65535)>>>5&7)-1|d[s];s=k+1|0;if(s>>>0<((d[m]|0)-1|1)>>>0){k=s}else{l=0;break}}i=g;return l|0}function Cw(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=e|0;if((h|0)!=(f|0)){j=f;k=e;x=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x}k=c[b>>2]|0;a:do{if(!((a[k+7|0]&32)==0)){switch(c[b+4>>2]|0){case 68:case 67:case 293:case 294:case 30:case 298:case 3:{l=2;m=1;n=0;o=3;break};case 317:case 82:{l=2;m=0;n=1;o=3;break};case 297:case 29:{l=3;m=2;n=1;o=0;break};case 42:case 41:case 291:case 292:case 296:case 28:case 2:{l=0;m=1;n=2;o=3;break};case 295:case 27:{l=1;m=2;n=3;o=0;break};default:{break a}}if((c[b+8>>2]|0)==1){j=e+4|0;a[j+l|0]=a[f]|0;a[j+m|0]=a[f+1|0]|0;a[j+n|0]=a[f+2|0]|0;a[j+o|0]=a[f+3|0]|0;i=g;return}else{a[e+4+(l<<2)|0]=a[f]|0;a[e+4+(m<<2)|0]=a[f+1|0]|0;a[e+4+(n<<2)|0]=a[f+2|0]|0;a[e+4+(o<<2)|0]=a[f+3|0]|0;i=g;return}}}while(0);if(((c[b+8>>2]|0)-3|0)>>>0<2>>>0){o=f+1|0;n=f+2|0;a[e+4|0]=(((d[f]|0)*263|0)+16896+((d[o]|0)*516|0)+((d[n]|0)*100|0)|0)>>>10;a[e+8|0]=((((d[f]|0)*-152|0)+511+((d[o]|0)*-298|0)+((d[n]|0)*450|0)|0)>>>10)+128;a[e+12|0]=((((d[f]|0)*450|0)+511+((d[o]|0)*-377|0)+((d[n]|0)*-73|0)|0)>>>10)+128;a[e+16|0]=a[f+3|0]|0;i=g;return}n=c[b+4>>2]|0;if((n|0)==8|(n|0)==66){a[e+4|0]=(((d[f]|0)*263|0)+16896+((d[f+1|0]|0)*516|0)+((d[f+2|0]|0)*100|0)|0)>>>10;a[e+8|0]=a[f+3|0]|0;i=g;return}else{yDb(0,24,2029928,(f=i,i=i+8|0,c[f>>2]=c[k>>2],f)|0);i=f;TGb(h|0,-128|0,20)|0;i=g;return}}function Dw(a,b,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;n=a+8|0;o=c[n>>2]|0;if((o|0)==0){return}p=-l|0;l=-m|0;m=0;q=o;while(1){o=d[a+36+m|0]|0;r=g+(m<<2)|0;s=d[a+32+m|0]|0;t=c[a+12+(m<<2)>>2]|0;u=e+(m<<2)|0;v=ba(p>>s,-t|0)|0;w=l>>o;x=-w|0;if((w|0)<0){w=ba(j>>s,t)|0;y=ba(k>>o,c[r>>2]|0)|0;z=(ba(c[u>>2]|0,i>>o)|0)+(ba(h>>s,t)|0)|0;t=0;s=(c[f+(m<<2)>>2]|0)+(w+y)|0;y=(c[b+(m<<2)>>2]|0)+z|0;while(1){UGb(y|0,s|0,v)|0;z=t+1|0;if((z|0)<(x|0)){t=z;s=s+(c[r>>2]|0)|0;y=y+(c[u>>2]|0)|0}else{break}}A=c[n>>2]|0}else{A=q}u=m+1|0;if(u>>>0<A>>>0){m=u;q=A}else{break}}return}function Ew(a,b,e,f,g,h,i,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=a+8|0;if((c[k>>2]|0)==0){return}l=-i|0;i=-j|0;j=0;while(1){m=c[e+(j<<2)>>2]|0;n=d[a+36+j|0]|0;o=f+(j<<2)|0;p=ba(h>>n,c[o>>2]|0)|0;q=d[a+32+j|0]|0;r=a+12+(j<<2)|0;s=c[r>>2]|0;t=(ba(g>>q,s)|0)+p|0;p=m+t|0;u=l>>q;q=-u|0;v=i>>n;n=-v|0;if((v|0)==0){w=11;break}if((u|0)<0){u=b+4+(j<<2)|0;v=0;x=p;y=s;while(1){UGb(x|0,u|0,y)|0;z=c[r>>2]|0;A=v+1|0;if((A|0)<(q|0)){v=A;x=x+z|0;y=z}else{B=z;break}}}else{B=s}y=ba(B,q)|0;if((n|0)>1){x=1;v=m+((c[o>>2]|0)+t)|0;while(1){UGb(v|0,p|0,y)|0;r=x+1|0;if((r|0)<(n|0)){x=r;v=v+(c[o>>2]|0)|0}else{break}}}o=j+1|0;if(o>>>0<(c[k>>2]|0)>>>0){j=o}else{w=11;break}}if((w|0)==11){return}}function Fw(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=a[(c|0)==0?b+40|0:b+41|0]|0;b=f&255;if(f<<24>>24==0){g=e;return g|0}if((d|0)>-1){if((d|0)==0){h=1<<b-1}else{h=(1<<b)-1|0}i=h+e|0}else{i=e}g=i>>b<<b;return g|0}function Gw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;a=i;i=i+1384|0;b=a|0;d=a+1336|0;e=0;f=0;while(1){if((Bw(d,e,0)|0)>-1){c[b+(f<<2)>>2]=e;g=f+1|0}else{g=f}h=e+1|0;if((h|0)<333){e=h;f=g}else{break}}c[b+(g<<2)>>2]=-1;g=xk(b|0)|0;i=a;return g|0}function Hw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b|0;Mw(d,a,2);c[b+36>>2]=b;c[b+32>>2]=1776;e=a+16|0;a=(c[c[e>>2]>>2]|0)+56|0;f=b+196|0;g=c[a+4>>2]|0;c[f>>2]=c[a>>2];c[f+4>>2]=g;g=(c[(c[e>>2]|0)+4>>2]|0)+56|0;e=b+380|0;f=c[g+4>>2]|0;c[e>>2]=c[g>>2];c[e+4>>2]=f;c[b+236>>2]=2;c[b+188>>2]=0;f=b+192|0;c[f>>2]=2;e=b+420|0;c[e>>2]=1;c[b+372>>2]=1;g=b+376|0;c[g>>2]=2;if((c[b+428>>2]|0)!=0){c[g>>2]=0;c[f>>2]=0}if((c[b+432>>2]|0)!=0){h=Nw(d)|0;return h|0}c[g>>2]=1;c[e>>2]=0;h=Nw(d)|0;return h|0}function Iw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+4>>2]|0;g=f;h=c[a+36>>2]|0;c[d>>2]=0;c[e>>2]=0;a=h;j=Sw(a,0,d,1)|0;do{if((j|0)<0){k=j}else{l=Sw(a,1,e,0)|0;if((l|0)<0){k=l;break}l=c[d>>2]|0;if((l|0)==0){yDb(0,0,2029496,(m=i,i=i+24|0,c[m>>2]=2265176,c[m+8>>2]=2154960,c[m+16>>2]=34,m)|0);i=m;Cd();return 0}m=l+136|0;l=f+32|0;n=KDb(c[m>>2]|0,c[m+4>>2]|0,h+12|0,(c[c[l>>2]>>2]|0)+56|0)|0;m=c[d>>2]|0;o=m+136|0;c[o>>2]=n;c[o+4>>2]=F;o=c[e>>2]|0;do{if((o|0)==0){p=m}else{if((c[f+76>>2]|0)!=0){p=m;break}n=ze[c[h+424>>2]&511](g,m,o)|0;c[d>>2]=n;p=n}}while(0);q=cj(c[c[l>>2]>>2]|0,p)|0;i=b;return q|0}}while(0);JCb(d);q=k;i=b;return q|0}function Jw(a,b,c){a=a|0;b=b|0;c=c|0;return Uw(a|0,b,c)|0}function Kw(a,b){a=a|0;b=b|0;return Vw(a|0,b)|0}function Lw(a){a=a|0;Tw(a|0);return}function Mw(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=1045784;c[a+4>>2]=b;c[a+8>>2]=d;return}function Nw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;d=a+12|0;e=d|0;f=a+8|0;a:do{if((c[e>>2]|0)==0){g=c[f>>2]|0;do{if((g|0)==0){h=a}else{j=d;k=a+16|0;l=0;m=0;n=0;o=0;b:while(1){do{if((c[a+56+(l*184|0)+180>>2]|0)==0){p=m;q=n;r=o}else{if((n|0)==0){s=a+56+(l*184|0)+140|0;t=c[s>>2]|0;u=c[s+4>>2]|0;c[j>>2]=t;c[j+4>>2]=u;u=t;p=u;q=u;r=u;break}u=c[k>>2]|0;t=u;s=(u|0)<0|0?-1:0;u=c[a+56+(l*184|0)+144>>2]|0;v=u;w=(u|0)<0|0?-1:0;u=GDb(t,s,v,w)|0;x=eHb(t,s,u,F)|0;u=gHb(x,F,v,w)|0;w=F;v=0;if(!((w|0)<(v|0)|(w|0)==(v|0)&u>>>0<5e5>>>0)){y=9;break b}c[k>>2]=u;u=c[a+56+(l*184|0)+140>>2]|0;v=GDb(o,(o|0)<0|0?-1:0,u,(u|0)<0|0?-1:0)|0;u=v;c[e>>2]=u;p=u;q=u;r=u}}while(0);u=l+1|0;if(u>>>0<g>>>0){l=u;m=p;n=q;o=r}else{y=12;break}}if((y|0)==9){c[e>>2]=1;c[k>>2]=1e6;z=1;A=a}else if((y|0)==12){o=a;if((p|0)==0){h=o;break}else{z=p;A=o}}o=c[a+16>>2]|0;yDb(A,40,2265032,(B=i,i=i+16|0,c[B>>2]=z,c[B+8>>2]=o,B)|0);i=B;break a}}while(0);yDb(h,16,2029168,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-22;i=b;return C|0}}while(0);if((c[f>>2]|0)!=0){B=0;do{h=a+56+(B*184|0)+168|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=a+56+(B*184|0)+160|0;c[h>>2]=0;c[h+4>>2]=-2147483648;B=B+1|0;}while(B>>>0<(c[f>>2]|0)>>>0)}c[a+44>>2]=-1;Ow(a);C=0;i=b;return C|0}function Ow(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[b+8>>2]|0;do{if((e|0)==0){f=b+44|0;g=0;h=f;j=c[f>>2]|0}else{f=0;k=0;while(1){if((a[b+56+(f*184|0)+177|0]|0)==2){l=k}else{m=c[b+56+(f*184|0)+180>>2]|0;l=k>>>0>m>>>0?k:m}m=f+1|0;if(m>>>0<e>>>0){f=m;k=l}else{break}}k=b+44|0;f=c[k>>2]|0;if(!(l>>>0>f>>>0)){g=l;h=k;j=f;break}yDb(0,0,2154872,(n=i,i=i+24|0,c[n>>2]=2344040,c[n+8>>2]=2034712,c[n+16>>2]=63,n)|0);i=n;Cd()}}while(0);if(g>>>0<j>>>0){yDb(b,40,2322016,(n=i,i=i+8|0,c[n>>2]=g,n)|0);i=n}if((g|0)==0){a[b+49|0]=1;i=d;return}else{c[h>>2]=g;i=d;return}}function Pw(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;if((a[d+56+(f*184|0)+176|0]|0)==0){Qw(d,f,g);i=h;return 0}j=d+56+(f*184|0)+130|0;k=b[j>>1]|0;if(k<<16>>16==32){yDb(d,24,1906920,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;l=d+56+(f*184|0)+128|0;m=e[l>>1]|0;n=(b[j>>1]|0)-1&65535;b[j>>1]=n;JCb(d+56+(f*184|0)+(((n&65535)+m&31)<<2)|0);o=b[j>>1]|0;p=l}else{o=k;p=d+56+(f*184|0)+128|0}k=e[p>>1]|0;b[j>>1]=o+1;c[d+56+(f*184|0)+((k+(o&65535)&31)<<2)>>2]=g;i=h;return 0}function Qw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=b+56+(d*184|0)+176|0;if((a[g]|0)!=0){yDb(0,0,2154872,(h=i,i=i+24|0,c[h>>2]=1886312,c[h+8>>2]=2034712,c[h+16>>2]=182,h)|0);i=h;Cd()}if((e|0)!=0){h=e+136|0;j=KDb(c[h>>2]|0,c[h+4>>2]|0,b+56+(d*184|0)+140|0,b+12|0)|0;k=F;c[h>>2]=j;c[h+4>>2]=k;l=k;m=j;n=b+56+(d*184|0)+152|0;c[n>>2]=e;o=b+56+(d*184|0)+168|0;p=o|0;c[p>>2]=m;q=o+4|0;c[q>>2]=l;a[g]=1;i=f;return}do{if((a[b+56+(d*184|0)+177|0]|0)==1){if((c[b+56+(d*184|0)+136>>2]|0)==2){r=2147483647;s=-1;break}j=b+56+(d*184|0)+160|0;k=YGb(c[j>>2]|0,c[j+4>>2]|0,1,0)|0;r=F;s=k}else{r=2147483647;s=-1}}while(0);c[b+56+(d*184|0)+180>>2]=0;Ow(b);l=r;m=s;n=b+56+(d*184|0)+152|0;c[n>>2]=e;o=b+56+(d*184|0)+168|0;p=o|0;c[p>>2]=m;q=o+4|0;c[q>>2]=l;a[g]=1;i=f;return}function Rw(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;g=d+48|0;if((a[g]|0)!=0){yDb(0,0,2154872,(h=i,i=i+24|0,c[h>>2]=2085752,c[h+8>>2]=2034712,c[h+16>>2]=211,h)|0);i=h;Cd()}h=d+8|0;j=c[h>>2]|0;if((j|0)==0){k=0}else{l=0;m=j;while(1){do{if((a[d+56+(l*184|0)+176|0]|0)==0){j=d+56+(l*184|0)+130|0;n=b[j>>1]|0;if(n<<16>>16==0){o=m;break}p=d+56+(l*184|0)+128|0;q=d+56+(l*184|0)+(e[p>>1]<<2)|0;r=c[q>>2]|0;b[j>>1]=n-1;c[q>>2]=0;b[p>>1]=(b[p>>1]|0)+1&31;Qw(d,l,r);o=c[h>>2]|0}else{o=m}}while(0);r=l+1|0;if(r>>>0<o>>>0){l=r;m=o}else{k=o;break}}}a[g]=0;o=d+49|0;if((a[o]|0)!=0){i=f;return}m=d+224|0;l=d+24|0;r=d+44|0;p=k;q=0;n=k;j=k;s=k;a:while(1){do{if((p|0)==0){k=c[m>>2]|0;t=c[m+4>>2]|0;u=t;v=k;w=0;x=n;y=j;z=t;A=k}else{k=-1;t=0;while(1){do{if((a[d+56+(t*184|0)+176|0]|0)==0){if((k|0)>=0){B=d+56+(t*184|0)+160|0;C=c[B+4>>2]|0;D=d+56+(k*184|0)+160|0;E=c[D+4>>2]|0;if(!((C|0)<(E|0)|(C|0)==(E|0)&(c[B>>2]|0)>>>0<(c[D>>2]|0)>>>0)){F=k;break}}F=t}else{F=k}}while(0);D=t+1|0;if(D>>>0<s>>>0){k=F;t=D}else{break}}if((F|0)>-1){G=18;break a}t=c[m>>2]|0;k=c[m+4>>2]|0;if(s>>>0>1>>>0){H=1;I=k;J=t}else{u=k;v=t;w=s;x=s;y=s;z=k;A=t;break}while(1){D=d+56+(H*184|0)+168|0;B=c[D>>2]|0;E=c[D+4>>2]|0;D=(E|0)<(I|0)|(E|0)==(I|0)&B>>>0<J>>>0;C=D?B:J;B=D?E:I;E=H+1|0;if(E>>>0<s>>>0){H=E;I=B;J=C}else{u=B;v=C;w=s;x=s;y=s;z=k;A=t;break}}}}while(0);if((v|0)==(-1|0)&(u|0)==2147483647){G=23;break}if((w|0)==0){K=0;L=q;M=x;N=y;O=s}else{t=0;k=z;C=A;while(1){B=d+56+(t*184|0)+168|0;do{if((C|0)==(v|0)&(k|0)==(u|0)){P=d+56+(t*184|0)+177|0;G=28}else{if((c[d+56+(t*184|0)+132>>2]|0)!=2){break}E=d+56+(t*184|0)+177|0;if((a[E]|0)==0){P=E;G=28}}}while(0);do{if((G|0)==28){G=0;E=d+56+(t*184|0)+148|0;JCb(E);D=d+56+(t*184|0)+152|0;Q=c[D>>2]|0;c[E>>2]=Q;E=c[B+4>>2]|0;R=d+56+(t*184|0)+160|0;c[R>>2]=c[B>>2];c[R+4>>2]=E;c[D>>2]=0;c[B>>2]=0;c[B+4>>2]=-2147483648;a[d+56+(t*184|0)+176|0]=0;D=(Q|0)!=0;a[P]=D?1:2;if(!((c[d+56+(t*184|0)+180>>2]|0)!=(c[r>>2]|0)|(Q|0)==0)){a[g]=1}if(D){break}if((c[d+56+(t*184|0)+136>>2]|0)!=0){break}a[o]=1}}while(0);B=t+1|0;S=c[h>>2]|0;if(!(B>>>0<S>>>0)){break}D=d+56+(B*184|0)+168|0;t=B;k=c[D+4>>2]|0;C=c[D>>2]|0}K=S;L=a[o]|0;M=S;N=S;O=S}do{if(L<<24>>24==0){C=a[g]|0;if(C<<24>>24==0){break}if((M|0)==0){G=40;break a}else{T=0;U=C}while(1){do{if((a[d+56+(T*184|0)+177|0]|0)==0){if((c[d+56+(T*184|0)+132>>2]|0)!=0){V=U;break}a[g]=0;V=0}else{V=U}}while(0);C=T+1|0;if(C>>>0<N>>>0){T=C;U=V}else{break}}c[l>>2]=v;c[l+4>>2]=u;if(V<<24>>24==0){p=N;q=L;n=N;j=N;s=O;continue a}else{G=47;break a}}else{a[g]=0}}while(0);c[l>>2]=v;c[l+4>>2]=u;p=K;q=L;n=M;j=N;s=O}if((G|0)==18){c[d+40>>2]=F;i=f;return}else if((G|0)==23){a[o]=1;i=f;return}else if((G|0)==40){c[l>>2]=v;c[l+4>>2]=u;i=f;return}else if((G|0)==47){i=f;return}}function Sw(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+8|0;h=g|0;j=b+56+(d*184|0)+148|0;k=c[j>>2]|0;if((k|0)==0){c[e>>2]=0;l=0;i=g;return l|0}c[h>>2]=k;if((f|0)==0){m=k}else{if((a[b+56+(d*184|0)+176|0]|0)==0){n=2147483647;o=-1}else{f=b+56+(d*184|0)+168|0;n=c[f+4>>2]|0;o=c[f>>2]|0}f=c[b+8>>2]|0;a:do{if((f|0)==0){p=15}else{q=0;b:while(1){do{if((q|0)!=(d|0)){if((c[b+56+(q*184|0)+180>>2]|0)==0){break}if((a[b+56+(q*184|0)+176|0]|0)==0){break b}r=b+56+(q*184|0)+168|0;s=c[r+4>>2]|0;if((s|0)<(n|0)|(s|0)==(n|0)&(c[r>>2]|0)>>>0<o>>>0){break b}}}while(0);r=q+1|0;if(r>>>0<f>>>0){q=r}else{p=15;break a}}q=PCb(k)|0;c[h>>2]=q;if((q|0)==0){l=-12;i=g;return l|0}r=SCb(q)|0;if((r|0)>=0){t=q;break}JCb(h);l=r;i=g;return l|0}}while(0);if((p|0)==15){c[j>>2]=0;t=k}a[b+48|0]=0;m=t}c[e>>2]=m;l=0;i=g;return l|0}function Tw(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;f=d|0;g=a+8|0;if((c[g>>2]|0)==0){i=d;return}h=0;do{JCb(a+56+(h*184|0)+148|0);JCb(a+56+(h*184|0)+152|0);j=a+56+(h*184|0)+130|0;k=b[j>>1]|0;if(!(k<<16>>16==0)){l=a+56+(h*184|0)+128|0;m=k;do{k=a+56+(h*184|0)+((e[l>>1]|0)<<2)|0;n=c[k>>2]|0;b[j>>1]=m-1;c[k>>2]=0;b[l>>1]=(b[l>>1]|0)+1&31;c[f>>2]=n;JCb(f);m=b[j>>1]|0;}while(!(m<<16>>16==0))}h=h+1|0;}while(h>>>0<(c[g>>2]|0)>>>0);i=d;return}function Uw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=b+32|0;if((c[g>>2]|0)==0){yDb(0,0,2154872,(h=i,i=i+24|0,c[h>>2]=1989928,c[h+8>>2]=2034712,c[h+16>>2]=276,h)|0);i=h;Cd();return 0}j=b+49|0;k=b+48|0;Rw(b);if((a[j]|0)==0){l=0}else{m=-541478725;i=f;return m|0}while(1){if((a[k]|0)==0){n=l;o=0;break}p=re[c[g>>2]&4095](b)|0;if((p|0)<0){m=p;q=17;break}a[k]=0;p=l+1|0;Rw(b);r=a[j]|0;if(r<<24>>24==0){l=p}else{n=p;o=r;break}}if((q|0)==17){i=f;return m|0}do{if((n|0)==0){if(o<<24>>24==0){break}else{m=-541478725}i=f;return m|0}else{if((n|0)<0){m=n}else{break}i=f;return m|0}}while(0);Pw(b,((c[d+12>>2]|0)-(c[(c[d+8>>2]|0)+12>>2]|0)|0)/60|0,e)|0;if((c[g>>2]|0)==0){yDb(0,0,2154872,(h=i,i=i+24|0,c[h>>2]=1989928,c[h+8>>2]=2034712,c[h+16>>2]=276,h)|0);i=h;Cd();return 0}Rw(b);if((a[j]|0)!=0){s=-541478725;t=(s|0)<0;u=t?s:0;i=f;return u|0}if((a[k]|0)==0){s=0;t=(s|0)<0;u=t?s:0;i=f;return u|0}j=re[c[g>>2]&4095](b)|0;if((j|0)<0){s=j;t=(s|0)<0;u=t?s:0;i=f;return u|0}a[k]=0;s=1;t=(s|0)<0;u=t?s:0;i=f;return u|0}function Vw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=c[d>>2]|0;g=b+32|0;if((c[g>>2]|0)==0){yDb(0,0,2154872,(h=i,i=i+24|0,c[h>>2]=1989928,c[h+8>>2]=2034712,c[h+16>>2]=276,h)|0);i=h;Cd();return 0}j=b+49|0;k=b+48|0;Rw(b);if((a[j]|0)!=0){l=-541478725;i=e;return l|0}if((a[k]|0)!=0){m=re[c[g>>2]&4095](b)|0;if((m|0)<0){l=m;i=e;return l|0}a[k]=0;l=0;i=e;return l|0}m=d+156|0;c[m>>2]=c[m>>2]|1;m=c[b+40>>2]|0;d=Ni(c[(c[f+16>>2]|0)+(m<<2)>>2]|0)|0;if(!((d|0)==-541478725)){l=d;i=e;return l|0}Pw(b,m,0)|0;if((c[g>>2]|0)==0){yDb(0,0,2154872,(h=i,i=i+24|0,c[h>>2]=1989928,c[h+8>>2]=2034712,c[h+16>>2]=276,h)|0);i=h;Cd();return 0}Rw(b);if((a[j]|0)!=0){l=-541478725;i=e;return l|0}if((a[k]|0)==0){l=0;i=e;return l|0}j=re[c[g>>2]&4095](b)|0;if((j|0)<0){l=j;i=e;return l|0}a[k]=0;l=0;i=e;return l|0}function Ww(a){a=a|0;return 2299464}function Xw(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;i=i+104|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;c[k>>2]=0;vZ(n);cx();o=aT(k,g,WC(2027472)|0,0)|0;if((o|0)<0){yDb(h,16,2264696,(p=i,i=i+8|0,c[p>>2]=g,p)|0);i=p;q=o;i=j;return q|0}o=c[(c[c[(c[k>>2]|0)+28>>2]>>2]|0)+8>>2]|0;r=q0a(c[o+48>>2]|0)|0;do{if((r|0)==0){yDb(h,16,2154776,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=-22}else{t=m0a(o,r,0)|0;if((t|0)<0){yDb(h,16,2085640,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=t;break}t=ICb()|0;c[l>>2]=t;if((t|0)==0){yDb(h,16,2034624,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=-12;break}t=gT(c[k>>2]|0,n)|0;if((t|0)<0){yDb(h,16,1989848,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=t;break}t=x0a(o,c[l>>2]|0,m,n)|0;if((t|0)<0|(c[m>>2]|0)==0){yDb(h,16,1956256,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=t;break}t=c[l>>2]|0;c[d>>2]=c[t+68>>2];u=c[t+72>>2]|0;c[e>>2]=u;v=c[t+80>>2]|0;c[f>>2]=v;t=gDb(a,b,c[d>>2]|0,u,v,16)|0;if((t|0)<0){s=t;break}t=c[l>>2]|0;jDb(a,b,t|0,t+32|0,c[f>>2]|0,c[d>>2]|0,c[e>>2]|0);s=0}}while(0);BZ(n);E0a(o)|0;KT(k);$Db(l);if((s|0)>=0){q=s;i=j;return q|0}yDb(h,16,1929008,(p=i,i=i+8|0,c[p>>2]=g,p)|0);i=p;q=s;i=j;return q|0}function Yw(a,b,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0;n=i;o=Csb(j,k,l,d,e,f,0,0,0,0)|0;if((o|0)==0){p=ZEb(l)|0;l=ZEb(f)|0;yDb(m,16,2027032,(m=i,i=i+48|0,c[m>>2]=p,c[m+8>>2]=j,c[m+16>>2]=k,c[m+24>>2]=l,c[m+32>>2]=d,c[m+40>>2]=e,m)|0);i=m;q=-22;Dsb(o);i=n;return q|0}m=gDb(a,b,d,e,f,16)|0;if((m|0)<0){q=m;Dsb(o);i=n;return q|0}bsb(o,g,h,0,k,a,b)|0;q=0;Dsb(o);i=n;return q|0}function Zw(a,b,c,d,e){a=+a;b=+b;c=+c;d=+d;e=e|0;var f=0.0;f=c;c=d*+T(f);g[e>>2]=c;d=-0.0- +U(f);g[e+4>>2]=d;g[e+8>>2]=a;g[e+12>>2]=-0.0-d;g[e+16>>2]=c;g[e+20>>2]=b;g[e+24>>2]=0.0;g[e+28>>2]=0.0;g[e+32>>2]=1.0;return}function _w(b,c,d,e,f,h,i,j,k){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0,Q=0.0,R=0.0,S=0,T=0,U=0.0;if((j|0)==2){l=2}else if((j|0)==0){l=6}else if((j|0)==1){l=4}else{m=-22;return m|0}if((h|0)<=0){m=0;return m|0}j=(f|0)>0;n=i+4|0;o=i+8|0;p=i+12|0;q=i+16|0;r=i+20|0;s=h-1|0;t=+(s|0);u=f-1|0;v=+(u|0);w=u<<1;x=s<<1;y=(k|0)==1;z=0;A=0;while(1){a:do{if(j){B=+(z|0);C=ba(z,e)|0;D=ba(z,d)|0;if(y){E=0;while(1){F=+(E|0);G=a[b+(E+D)|0]|0;a[c+(E+C)|0]=Ae[l&7](+g[o>>2]+(F*+g[i>>2]+B*+g[n>>2]),+g[r>>2]+(F*+g[p>>2]+B*+g[q>>2]),b,f,h,d,G)|0;H=E+1|0;if((H|0)<(f|0)){E=H}else{I=G;break a}}}else{J=0;K=A}while(1){F=+(J|0);L=+g[o>>2]+(F*+g[i>>2]+B*+g[n>>2]);M=+g[r>>2]+(F*+g[p>>2]+B*+g[q>>2]);if((k|0)==2){if(M<0.0){N=0.0}else{N=M>t?t:M}if(L<0.0){O=0.0}else{O=L>v?v:L}P=a[b+(~~O+(ba(~~N,d)|0))|0]|0;Q=N;R=O}else if((k|0)==3){E=~~L;if(E>>>0>u>>>0){D=E;while(1){G=((D|0)>0?w:0)-D|0;if(G>>>0>u>>>0){D=G}else{S=G;break}}}else{S=E}F=+(S|0);D=~~M;if(D>>>0>s>>>0){G=D;while(1){H=((G|0)>0?x:0)-G|0;if(H>>>0>s>>>0){G=H}else{T=H;break}}}else{T=D}U=+(T|0);P=a[b+((ba(~~U,d)|0)+~~F)|0]|0;Q=U;R=F}else{P=K;Q=M;R=L}a[c+(J+C)|0]=Ae[l&7](R,Q,b,f,h,d,P)|0;G=J+1|0;if((G|0)<(f|0)){J=G;K=P}else{I=P;break}}}else{I=A}}while(0);C=z+1|0;if((C|0)<(h|0)){z=C;A=I}else{m=0;break}}return m|0}function $w(b,c,d,e,f,g,h){b=+b;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=~~(b+.5);do{if((i|0)<0){j=h}else{k=~~(c+.5);if((k|0)<0){j=h;break}if(!((i|0)<(e|0)&(k|0)<(f|0))){j=h;break}j=a[d+((ba(k,g)|0)+i)|0]|0}}while(0);return j|0}function ax(b,c,d,e,f,g,h){b=+b;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0;if(b<-1.0){i=h;return i|0}if(+(e|0)<b|c<-1.0){i=h;return i|0}if(+(f|0)<c){i=h;return i|0}j=~~b;k=j+1|0;l=~~c;m=l+1|0;do{if((m|k|0)<0){n=h}else{if(!((k|0)<(e|0)&(m|0)<(f|0))){n=h;break}n=a[d+((ba(m,g)|0)+k)|0]|0}}while(0);o=n&255;do{if((k|l|0)<0){p=h}else{if(!((k|0)<(e|0)&(l|0)<(f|0))){p=h;break}p=a[d+((ba(l,g)|0)+k)|0]|0}}while(0);n=p&255;do{if((m|j|0)<0){q=h}else{if(!((j|0)<(e|0)&(m|0)<(f|0))){q=h;break}q=a[d+((ba(m,g)|0)+j)|0]|0}}while(0);p=q&255;do{if((l|j|0)<0){r=h}else{if(!((j|0)<(e|0)&(l|0)<(f|0))){r=h;break}r=a[d+((ba(l,g)|0)+j)|0]|0}}while(0);s=b- +(j|0);t=c- +(l|0);u=+(m|0)-c;c=+(k|0)-b;i=~~(t*s*+(o|0)+s*u*+(n|0)+t*c*+(p|0)+c*u*+(r&255|0));return i|0}function bx(b,c,d,e,f,g,h){b=+b;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0;if(b<-1.0){i=h;return i|0}if(+(e|0)<b|c<-1.0){i=h;return i|0}if(+(f|0)<c){i=h;return i|0}j=~~b;k=j+1|0;l=~~c;m=l+1|0;do{if((m|k|0)<0){n=h}else{if(!((k|0)<(e|0)&(m|0)<(f|0))){n=h;break}n=a[d+((ba(m,g)|0)+k)|0]|0}}while(0);do{if((k|l|0)<0){o=h}else{if(!((k|0)<(e|0)&(l|0)<(f|0))){o=h;break}o=a[d+((ba(l,g)|0)+k)|0]|0}}while(0);do{if((m|j|0)<0){p=h}else{if(!((j|0)<(e|0)&(m|0)<(f|0))){p=h;break}p=a[d+((ba(m,g)|0)+j)|0]|0}}while(0);do{if((l|j|0)<0){q=h}else{if(!((j|0)<(e|0)&(l|0)<(f|0))){q=h;break}q=a[d+((ba(l,g)|0)+j)|0]|0}}while(0);r=+(k|0)-b;s=+(m|0)-c;t=1.0- +R(r*s);u=c- +(l|0);c=1.0- +R(r*u);r=b- +(j|0);b=1.0- +R(r*s);s=1.0- +R(r*u);i=~~((+(n&255|0)*t+ +(o&255|0)*c+ +(p&255|0)*b+ +(q&255|0)*s)/(t+c+b+s));return i|0}function cx(){if(a[1775688]|0){return}a[1775688]=1;LX();SC(1286424);RC(1285824);SC(1274944);RC(1276176);RC(1274040);RC(1273960);RC(1273880);SC(1268824);SC(1268656);RC(1268744);RC(1268576);RC(1265920);SC(1265616);RC(1265704);SC(1264712);RC(1264800);RC(1264112);RC(1263928);RC(1263744);RC(1263664);SC(1262992);RC(1263456);SC(1262056);RC(1262248);SC(1261888);RC(1261976);SC(1262856);SC(1260016);RC(1260104);SC(1259416);RC(1259504);SC(1259328);RC(1259248);RC(1258752);RC(1257792);RC(1257608);RC(1257032);RC(1257424);SC(1256864);RC(1256952);RC(1256472);RC(1256056);RC(1256288);RC(1255872);SC(1255704);RC(1255792);SC(1255384);RC(1255472);RC(1244536);RC(1244248);RC(1237776);SC(1237336);SC(1234640);RC(1234744);SC(1234440);RC(1234528);RC(1233968);SC(1233640);RC(1233728);SC(1230760);RC(1230952);RC(1230472);SC(1230096);RC(1230184);RC(1230016);SC(1228312);RC(1229936);RC(1225328);RC(1225064);RC(1225144);SC(1224200);RC(1224784);RC(1222584);SC(1222080);SC(1221816);RC(1221904);SC(1221648);RC(1221736);SC(1220784);RC(1220872);SC(1220304);RC(1220496);RC(1219080);SC(1218704);RC(1218896);RC(1218440);SC(1218352);SC(1218264);RC(1218080);SC(1217536);RC(1217792);SC(1217160);RC(1217352);RC(1216976);SC(1214256);RC(1214448);RC(1213416);SC(1212112);RC(1212200);SC(1211448);RC(1211792);SC(1210568);RC(1210968);SC(1207464);RC(1207600);SC(1207376);SC(1206640);RC(1207192);SC(1206448);RC(1206536);RC(1206264);SC(1205784);RC(1205872);RC(1204168);RC(1203984);RC(1203800);SC(1203528);RC(1203616);SC(1203360);RC(1203448);SC(1203192);RC(1203280);RC(1202576);RC(1199472);SC(1199384);SC(1199216);RC(1199304);SC(1199128);RC(1199048);RC(1198968);SC(1198800);RC(1198888);SC(1193744);RC(1193832);RC(1193144);SC(1192664);RC(1192752);RC(1192480);RC(1192400);RC(1191872);RC(1191792);SC(1191616);RC(1191704);SC(1190952);SC(1191152);RC(1191240);SC(1191320);RC(1188680);SC(1188408);RC(1188496);SC(1187928);RC(1188120);SC(1184752);RC(1185208);RC(1184624);SC(1184456);RC(1184544);SC(1184016);RC(1184104);SC(1183272);SC(1182792);RC(1182880);SC(1182184);RC(1180336);RC(1180416);SC(1178952);SC(1178864);SC(1178568);SC(1177832);SC(1177744);SC(1177448);SC(1177360);RC(1175704);SC(1175536);RC(1175624);RC(1175456);RC(1175272);SC(1175184);RC(1175e3);RC(1174920);RC(1173472);RC(1172664);RC(1172584);RC(1172208);SC(1171328);RC(1171416);SC(1171568);RC(1170912);RC(1170728);RC(1169712);RC(1169632);SC(1169544);SC(1168936);RC(1169224);RC(1167696);SC(1167512);RC(1167600);SC(1166944);RC(1167032);SC(1166800);RC(1166592);SC(1165696);RC(1165888);SC(1163504);RC(1163696);SC(1164360);RC(1164552);SC(1163984);RC(1164176);SC(1165112);RC(1165304);SC(1164736);RC(1164928);SC(1160792);RC(1160984);SC(1160416);RC(1160608);SC(1161960);RC(1162152);SC(1161376);RC(1161568);SC(1163128);RC(1163320);SC(1162544);RC(1162736);SC(1159832);RC(1160024);SC(1157744);RC(1157936);SC(1157368);RC(1157560);SC(1158496);RC(1158688);SC(1158120);RC(1158312);SC(1159248);RC(1159440);SC(1158872);RC(1159064);SC(1156992);RC(1157184);RC(1155864);RC(1155784);SC(1154376);RC(1154192);RC(1154112);RC(1153928);RC(1151824);SC(1149480);RC(1149672);RC(1149200);RC(1149120);RC(1148568);SC(1146536);RC(1146640);SC(1145952);RC(1146352);RC(1145872);RC(1145688);SC(1145520);RC(1145608);SC(1145432);RC(1144032);RC(1143848);RC(1139608);RC(1139016);SC(1138928);SC(1134864);RC(1138432);RC(1138352);RC(1137784);SC(1137512);RC(1137600);SC(1137424);RC(1137344);RC(1136952);SC(1136368);RC(1136456);SC(1136096);RC(1136184);SC(1135968);SC(1135272);RC(1135464);RC(1134984);RC(1134472);RC(1134288);SC(1130048);RC(1130136);RC(1124872);SC(1124344);RC(1124432);SC(1124152);SC(1124064);RC(1123736);RC(1123656);SC(1185392);RC(1110616);SC(1110296);RC(1110384);RC(1109592);RC(1108904);RC(1109232);SC(1108200);SC(1096160);RC(1098800);SC(1094136);RC(1094224);RC(1089664);RC(1089584);RC(1089192);SC(1088928);RC(1089040);RC(1084688);RC(1084504);SC(1083456);RC(1083640);SC(1083288);RC(1083376);RC(1083e3);SC(1082912);SC(1082536);RC(1082624);RC(1079536);RC(1079456);SC(1079272);RC(1079376);SC(1079104);RC(1079192);RC(1079024);RC(1078528);RC(1077704);RC(1077208);RC(1076816);SC(1076312);RC(1076400);yy(1220952)|0;return}function dx(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,2365752,5)|0)==0;return(b?100:0)|0}function ex(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+16|0;d=b|0;e=c[a+16>>2]|0;f=d|0;mz(e,f,6)|0;g=LT(a,0)|0;if((g|0)==0){h=-12;i=b;return h|0}do{if((PGb(f,2365752,6)|0)==0){a=c[g+8>>2]|0;c[a+52>>2]=1919770995;c[a+48>>2]=73728;c[a+412>>2]=8e3;j=a;k=8e3}else{mz(e,d+6|0,3)|0;if((PGb(f,2365760,9)|0)==0){a=c[g+8>>2]|0;c[a+52>>2]=1651990899;c[a+48>>2]=73729;c[a+412>>2]=16e3;j=a;k=16e3;break}else{h=-1;i=b;return h|0}}}while(0);c[j+416>>2]=1;f=j+448|0;c[f>>2]=4;c[f+4>>2]=0;c[j+8>>2]=1;MT(g,64,1,k);h=0;i=b;return h|0}function fx(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+28|0;g=c[(c[c[f>>2]>>2]|0)+8>>2]|0;h=b+16|0;b=Ty(c[h>>2]|0,0,0,1)|0;i=F;if((Xy(c[h>>2]|0)|0)!=0){j=-5;return j|0}k=lz(c[h>>2]|0)|0;l=k>>>3&15;m=g+48|0;g=c[m>>2]|0;do{if((g|0)==73728){n=(d[1795936+l|0]|0)+1|0}else if((g|0)==73729){if((l-11|0)>>>0<3>>>0){j=-5}else{n=d[1795920+l|0]|0;break}return j|0}else{j=-5;return j|0}}while(0);if((wZ(e,n)|0)!=0){j=-5;return j|0}c[(c[(c[c[f>>2]>>2]|0)+8>>2]|0)+72>>2]=n*400|0;c[e+32>>2]=0;f=e+64|0;c[f>>2]=b;c[f+4>>2]=i;i=e+24|0;a[c[i>>2]|0]=k;c[e+48>>2]=(c[m>>2]|0)==73728?160:320;m=n-1|0;if((mz(c[h>>2]|0,(c[i>>2]|0)+1|0,m)|0)==(m|0)){j=0;return j|0}BZ(e);j=-5;return j|0}function gx(a){a=a|0;var b=0,d=0,e=0;b=c[a+16>>2]|0;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;c[a+12>>2]=0;a=c[d+48>>2]|0;if((a|0)==73728){Ry(b,2365752,6)}else if((a|0)==73729){Ry(b,2365760,9)}else{e=-1;return e|0}Sy(b);e=0;return e|0}function hx(a,b){a=a|0;b=b|0;Ry(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function ix(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==541478988){e=b+16|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)!=1296649793){break}e=b+20|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}e=b+22|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}else{f=100}return f|0}}while(0);f=0;return f|0}function jx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=c[a+12>>2]|0;e=d;f=c[a+16>>2]|0;Vy(f,4,0)|0;if((pz(f)|0)!=256){DDb(a,2154672,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1163346256;i=b;return h|0}c[d>>2]=pz(f)|0;j=d+4|0;c[j>>2]=rz(f)|0;Vy(f,2,0)|0;k=d+8|0;c[k>>2]=pz(f)|0;if((rz(f)|0)!=1296649793){h=-1094995529;i=b;return h|0}l=LT(a,0)|0;if((l|0)==0){h=-12;i=b;return h|0}m=l+8|0;n=c[m>>2]|0;c[n+8>>2]=0;c[n+48>>2]=135;c[n+52>>2]=0;n=pz(f)|0;c[(c[m>>2]|0)+120>>2]=n;n=pz(f)|0;c[(c[m>>2]|0)+124>>2]=n;do{if((lz(f)|0)==0){Vy(f,1,0)|0;if((lz(f)|0)!=0){c[j>>2]=(c[j>>2]|0)-1}Vy(f,1,0)|0;if((lz(f)|0)!=0){break}if((lz(f)|0)!=1){break}Vy(f,1,0)|0;if((lz(f)|0)!=1){break}Vy(f,32,0)|0;n=l+64|0;c[n>>2]=rz(f)|0;c[n+4>>2]=0;MT(l,64,1,pz(f)|0);Vy(f,58,0)|0;c[(c[m>>2]|0)+100>>2]=1152;n=cEb(1168)|0;c[(c[m>>2]|0)+96>>2]=n;n=c[m>>2]|0;o=c[n+96>>2]|0;if((o|0)==0){h=-12;i=b;return h|0}p=mz(f,o,c[n+100>>2]|0)|0;if((p|0)<0){h=p;i=b;return h|0}p=c[k>>2]|0;n=Ty(f,p,(p|0)<0|0?-1:0,0)|0;p=n;if((p|0)<0){h=p;i=b;return h|0}p=d+12|0;n=0;do{c[p+(n*12|0)>>2]=pz(f)|0;c[p+(n*12|0)+4>>2]=pz(f)|0;c[p+(n*12|0)+8>>2]=pz(f)|0;n=n+1|0;}while((n|0)<256);a:do{if((c[j>>2]|0)==0){q=-541478725}else{n=0;b:while(1){p=c[e+12+(n*12|0)+4>>2]|0;do{if((p|0)!=0){o=c[e+12+(n*12|0)>>2]|0;if((o|0)>0){break}if((o|0)!=(-p|0)){break b}}}while(0);p=n+1|0;if((p|0)<256){n=p}else{q=-1094995529;break a}}c[d+3084>>2]=n;if((n|0)<0){h=n;i=b;return h|0}c[d+3088>>2]=-1;h=0;i=b;return h|0}}while(0);c[d+3084>>2]=q;h=q;i=b;return h|0}}while(0);DDb(a,2085536,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1163346256;i=b;return h|0}function kx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[a+12>>2]|0;e=d;f=a+16|0;a=c[f>>2]|0;if((Xy(a)|0)!=0){g=-5;return g|0}h=d+3084|0;i=c[h>>2]|0;if((i|0)<0){g=i;return g|0}j=d+12|0;k=d+3088|0;l=d+8|0;m=d+4|0;d=i;i=c[k>>2]|0;a:while(1){n=j+(d*12|0)|0;if((i|0)<0){o=(d<<16|1536)+(c[l>>2]|0)|0;Ty(a,o,(o|0)<0|0?-1:0,0)|0;o=j+(d*12|0)+4|0;Vy(a,(c[o>>2]<<1)+8|0,0)|0;c[k>>2]=0;p=0;q=o}else{p=i;q=j+(d*12|0)+4|0}o=c[q>>2]|0;if(p>>>0<o>>>0){r=16;break}s=(c[n>>2]|0)+o|0;if((c[m>>2]|0)>>>0>s>>>0){t=0}else{u=-541478725;r=13;break}b:while(1){o=c[e+12+(t*12|0)+4>>2]|0;do{if((o|0)!=0){v=c[e+12+(t*12|0)>>2]|0;if((v|0)>(s|0)){break}if((v+o|0)>>>0>s>>>0){break b}}}while(0);o=t+1|0;if((o|0)<256){t=o}else{u=-1094995529;r=13;break a}}c[h>>2]=t;if((t|0)<0){g=t;r=20;break}c[k>>2]=-1;d=t;i=-1}if((r|0)==13){c[h>>2]=u;g=u;return g|0}else if((r|0)==16){u=Ty(a,0,0,1)|0;i=(c[l>>2]|0)+1544+(c[h>>2]<<16)+(c[k>>2]<<1)|0;Ty(a,i,(i|0)<0|0?-1:0,0)|0;i=pz(a)|0;h=u;Ty(a,h,(h|0)<0|0?-1:0,0)|0;h=TS(c[f>>2]|0,b,i)|0;c[b+28>>2]=h;if((h|0)<0){g=h;return g|0}h=c[k>>2]|0;if((c[n>>2]|0)==(-h|0)){n=b+36|0;c[n>>2]=c[n>>2]|1;w=c[k>>2]|0}else{w=h}c[k>>2]=w+1;g=0;return g|0}else if((r|0)==20){return g|0}return 0}function lx(a){a=a|0;var b=0;b=(RGb(c[a+4>>2]|0,2154640,8)|0)==0;return(b?100:0)|0}function mx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+16>>2]|0;rz(b)|0;rz(b)|0;rz(b)|0;d=LT(a,0)|0;if((d|0)==0){e=-12;return e|0}a=d+8|0;d=c[a>>2]|0;c[d+8>>2]=1;c[d+48>>2]=69661;rz(b)|0;d=rz(b)|0;f=c[a>>2]|0;c[f+412>>2]=d;if((CT(f,b,8)|0)<0){e=-12;return e|0}f=(rz(b)|0)==0;b=c[a>>2]|0;a=b+416|0;if(f){c[a>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;g=4}else{c[a>>2]=2;a=b+448|0;c[a>>2]=3;c[a+4>>2]=0;g=8}c[b+792>>2]=4;c[b+72>>2]=ba(g,c[b+412>>2]|0)|0;c[b+432>>2]=1;e=0;return e|0}function nx(a,b){a=a|0;b=b|0;var d=0;if((TS(c[a+16>>2]|0,b,4096)|0)<1){d=-5;return d|0}a=b+36|0;c[a>>2]=c[a>>2]&-3;c[b+32>>2]=0;d=0;return d|0}function ox(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=541278541){e=0;return e|0}a=b+4|0;e=(((d[a]|d[a+1|0]<<8)<<16>>16)-3800&65535)>>>0>190>>>0?25:100;return e|0}function px(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;h=c[f+16>>2]|0;j=c[f+12>>2]|0;k=Ty(h,0,0,1)|0;l=j;c[l>>2]=k;if((rz(h)|0)!=541278541){m=-1094995529;i=g;return m|0}k=(pz(h)|0)&65535;n=j+24|0;b[n>>1]=k;if((k-3800&65535)>>>0>190>>>0){o=k<<16>>16;yDb(f,16,2034448,(p=i,i=i+16|0,c[p>>2]=(o|0)/1e3|0,c[p+8>>2]=((o|0)%1e3|0|0)/10|0,p)|0);i=p;m=-1163346256;i=g;return m|0}do{if(k<<16>>16>3979){b[j+26>>1]=pz(h)|0;o=j+28|0;c[o>>2]=rz(h)|0;c[j+32>>2]=rz(h)|0;c[j+36>>2]=rz(h)|0;c[j+40>>2]=rz(h)|0;c[j+44>>2]=rz(h)|0;c[j+48>>2]=rz(h)|0;c[j+52>>2]=rz(h)|0;mz(h,j+56|0,16)|0;q=c[o>>2]|0;if(q>>>0>52>>>0){Vy(h,q-52|0,0)|0;}b[j+72>>1]=pz(h)|0;b[j+74>>1]=pz(h)|0;c[j+76>>2]=rz(h)|0;c[j+80>>2]=rz(h)|0;c[j+84>>2]=rz(h)|0;b[j+88>>1]=pz(h)|0;b[j+90>>1]=pz(h)|0;c[j+92>>2]=rz(h)|0}else{c[j+28>>2]=0;q=j+32|0;c[q>>2]=32;o=j+72|0;b[o>>1]=pz(h)|0;r=j+74|0;b[r>>1]=pz(h)|0;b[j+90>>1]=pz(h)|0;c[j+92>>2]=rz(h)|0;s=j+40|0;c[s>>2]=rz(h)|0;c[j+52>>2]=rz(h)|0;t=j+84|0;c[t>>2]=rz(h)|0;c[j+80>>2]=rz(h)|0;u=b[r>>1]|0;if((u&4)==0){v=u}else{Vy(h,4,0)|0;c[q>>2]=(c[q>>2]|0)+4;v=b[r>>1]|0}if((v&16)==0){c[j+36>>2]=c[t>>2]<<2;w=v}else{t=rz(h)|0;c[q>>2]=(c[q>>2]|0)+4;c[j+36>>2]=t<<2;w=b[r>>1]|0}r=w&65535;do{if((r&1|0)==0){t=j+88|0;if((r&8|0)==0){b[t>>1]=16;break}else{b[t>>1]=24;break}}else{b[j+88>>1]=8}}while(0);r=b[n>>1]|0;a:do{if(r<<16>>16>3949){c[j+76>>2]=294912}else{do{if(!(r<<16>>16>3899)){if(r<<16>>16>3799){if((e[o>>1]|0)>>>0>3999>>>0){break}}c[j+76>>2]=9216;break a}}while(0);c[j+76>>2]=73728}}while(0);if(!((w&32)==0)){break}Vy(h,c[s>>2]|0,0)|0;}}while(0);w=j+84|0;v=c[w>>2]|0;if((v|0)==0){yDb(f,16,1989744,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;m=-22;i=g;return m|0}if(v>>>0>134217727>>>0){yDb(f,16,1956112,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;m=-1094995529;i=g;return m|0}k=j+36|0;o=(c[k>>2]|0)>>>2;if(o>>>0<v>>>0){yDb(f,16,1928864,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=v,p)|0);i=p;m=-1094995529;i=g;return m|0}o=WDb(v<<5)|0;v=j+16|0;c[v>>2]=o;if((o|0)==0){m=-12;i=g;return m|0}o=c[k>>2]|0;r=(c[j+28>>2]|0)+(c[l>>2]|0)+(c[j+32>>2]|0)+o+(c[j+40>>2]|0)|0;t=j+4|0;c[t>>2]=r;q=c[w>>2]|0;if((b[n>>1]|0)<3810){c[t>>2]=q+r}c[j+12>>2]=0;r=j+80|0;u=c[r>>2]|0;y=j+8|0;c[y>>2]=u;if(q>>>0>1>>>0){c[y>>2]=(ba(c[j+76>>2]|0,q-1|0)|0)+u}do{if((o|0)!=0){u=cEb(o)|0;q=j+96|0;c[q>>2]=u;if((u|0)==0){m=-12;i=g;return m|0}u=h+52|0;b:do{if((c[k>>2]|0)>>>0>3>>>0){y=0;do{if((c[u>>2]|0)!=0){break b}z=rz(h)|0;c[(c[q>>2]|0)+(y<<2)>>2]=z;y=y+1|0;}while(y>>>0<(c[k>>2]|0)>>>2>>>0)}}while(0);c:do{if((b[n>>1]|0)<3810){q=cEb(c[w>>2]|0)|0;s=j+100|0;c[s>>2]=q;if((q|0)==0){m=-12;i=g;return m|0}if((c[w>>2]|0)==0){A=48;break}else{B=0}while(1){if((c[u>>2]|0)!=0){break c}q=(lz(h)|0)&255;a[(c[s>>2]|0)+B|0]=q;q=B+1|0;if(q>>>0<(c[w>>2]|0)>>>0){B=q}else{A=48;break}}}else{A=48}}while(0);if((A|0)==48){if((c[u>>2]|0)==0){break}}yDb(f,24,1906888,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);B=c[t>>2]|0;t=c[v>>2]|0;k=t|0;c[k>>2]=B;c[k+4>>2]=0;o=j+76|0;c[t+8>>2]=c[o>>2];c[t+16>>2]=0;s=c[w>>2]|0;if(s>>>0>1>>>0){q=c[j+96>>2]|0;y=1;z=B;while(1){B=(c[l>>2]|0)+(c[q+(y<<2)>>2]|0)|0;C=B;D=0;E=t+(y<<5)|0;c[E>>2]=C;c[E+4>>2]=D;c[t+(y<<5)+8>>2]=c[o>>2];c[t+(y-1<<5)+12>>2]=B-z;E=ZGb(C,D,c[k>>2]|0,c[k+4>>2]|0)|0;c[t+(y<<5)+16>>2]=E&3;E=y+1|0;D=c[w>>2]|0;if(E>>>0<D>>>0){y=E;z=B}else{G=D;break}}}else{G=s}c[t+(G-1<<5)+8>>2]=c[r>>2];G=Wy(h)|0;t=F;s=0;z=c[w>>2]|0;if((t|0)>(s|0)|(t|0)==(s|0)&G>>>0>0>>>0){s=c[v>>2]|0;y=s+(z-1<<5)|0;k=ZGb(G,t,c[y>>2]|0,c[y+4>>2]|0)|0;y=ZGb(k,F,c[j+52>>2]|0,0)|0;k=y&-4;if((k|0)<1){H=s;A=56}else{I=k;J=s}}else{H=c[v>>2]|0;A=56}if((A|0)==56){I=c[r>>2]<<3;J=H}c[J+(z-1<<5)+12>>2]=I;if((c[w>>2]|0)==0){K=0}else{I=0;while(1){z=c[J+(I<<5)+16>>2]|0;if((z|0)==0){L=J+(I<<5)+12|0}else{H=J+(I<<5)|0;A=ZGb(c[H>>2]|0,c[H+4>>2]|0,z,(z|0)<0|0?-1:0)|0;c[H>>2]=A;c[H+4>>2]=F;H=J+(I<<5)+12|0;c[H>>2]=(c[H>>2]|0)+z;L=H}c[L>>2]=(c[L>>2]|0)+3&-4;H=I+1|0;z=c[w>>2]|0;if(H>>>0<z>>>0){I=H}else{K=z;break}}}I=b[n>>1]|0;if(!(I<<16>>16>3809|(K|0)==0)){L=j+100|0;z=0;H=K;while(1){do{if(z>>>0<(H-1|0)>>>0){K=z+1|0;A=c[L>>2]|0;if((a[A+K|0]|0)==0){M=A;N=K;break}s=J+(z<<5)+12|0;c[s>>2]=(c[s>>2]|0)+4;M=A;N=K}else{M=c[L>>2]|0;N=z+1|0}}while(0);u=J+(z<<5)+16|0;K=c[u>>2]<<3;c[u>>2]=K;c[u>>2]=K+(d[M+z|0]|0);K=c[w>>2]|0;if(N>>>0<K>>>0){z=N;H=K}else{break}}}H=I<<16>>16;I=j+72|0;N=e[I>>1]|0;yDb(f,48,1886240,(p=i,i=i+24|0,c[p>>2]=(H|0)/1e3|0,c[p+8>>2]=((H|0)%1e3|0|0)/10|0,c[p+16>>2]=N,p)|0);i=p;p=LT(f,0)|0;if((p|0)==0){m=-12;i=g;return m|0}N=c[w>>2]|0;if((N|0)==0){O=0;P=0}else{H=ba(c[o>>2]|0,N-1|0)|0;N=H+(c[r>>2]|0)|0;O=(N|0)<0|0?-1:0;P=N}N=p+8|0;r=c[N>>2]|0;c[r+8>>2]=1;c[r+48>>2]=86049;c[r+52>>2]=541413441;c[r+416>>2]=e[j+90>>1]|0;H=j+92|0;c[r+412>>2]=c[H>>2];c[r+792>>2]=e[j+88>>1]|0;r=p+64|0;c[r>>2]=c[w>>2];c[r+4>>2]=0;r=p+48|0;c[r>>2]=0;c[r+4>>2]=0;r=p+56|0;c[r>>2]=P;c[r+4>>2]=O;MT(p,64,1,c[H>>2]|0);if((BT(c[N>>2]|0,6)|0)!=0){m=-12;i=g;return m|0}H=c[(c[N>>2]|0)+96>>2]|0;x=b[n>>1]|0;a[H]=x;x=x>>8;a[H+1|0]=x;H=(c[(c[N>>2]|0)+96>>2]|0)+2|0;x=b[I>>1]|0;a[H]=x;x=x>>8;a[H+1|0]=x;H=(c[(c[N>>2]|0)+96>>2]|0)+4|0;x=b[j+74>>1]|0;a[H]=x;x=x>>8;a[H+1|0]=x;if((c[w>>2]|0)!=0){H=0;j=0;N=0;while(1){I=c[v>>2]|0;n=I+(H<<5)+24|0;c[n>>2]=N;c[n+4>>2]=j;n=I+(H<<5)|0;jT(p,c[n>>2]|0,c[n+4>>2]|0,N,j,0,0,1)|0;n=YGb(c[o>>2]|0,0,N,j)|0;I=H+1|0;if(I>>>0<(c[w>>2]|0)>>>0){H=I;j=F;N=n}else{break}}}if((c[h+88>>2]|0)==0){m=0;i=g;return m|0}tx(f)|0;Ty(h,0,0,0)|0;m=0;i=g;return m|0}function qx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[b+12>>2]|0;g=b+16|0;if((Xy(c[g>>2]|0)|0)!=0){h=-541478725;i=e;return h|0}j=f+12|0;k=c[j>>2]|0;l=f+84|0;if(!(k>>>0<(c[l>>2]|0)>>>0)){h=-541478725;i=e;return h|0}m=f+16|0;n=(c[m>>2]|0)+(k<<5)|0;k=Ty(c[g>>2]|0,c[n>>2]|0,c[n+4>>2]|0,0)|0;n=F;o=0;if((n|0)<(o|0)|(n|0)==(o|0)&k>>>0<0>>>0){h=-5;i=e;return h|0}k=c[j>>2]|0;o=c[((k|0)==((c[l>>2]|0)-1|0)?f+80|0:f+76|0)>>2]|0;f=c[(c[m>>2]|0)+(k<<5)+12>>2]|0;if((f|0)<1|f>>>0>2147483639>>>0){yDb(b,16,2085496,(b=i,i=i+8|0,c[b>>2]=f,b)|0);i=b;c[j>>2]=(c[j>>2]|0)+1;h=-5;i=e;return h|0}if((wZ(d,f+8|0)|0)<0){h=-12;i=e;return h|0}f=d+24|0;b=c[f>>2]|0;x=o;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=(c[f>>2]|0)+4|0;x=c[(c[m>>2]|0)+(c[j>>2]<<5)+16>>2]|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=mz(c[g>>2]|0,(c[f>>2]|0)+8|0,c[(c[m>>2]|0)+(c[j>>2]<<5)+12>>2]|0)|0;if((b|0)<0){BZ(d);h=b;i=e;return h|0}else{f=(c[m>>2]|0)+(c[j>>2]<<5)+24|0;m=c[f+4>>2]|0;g=d+8|0;c[g>>2]=c[f>>2];c[g+4>>2]=m;c[d+32>>2]=0;c[d+28>>2]=b+8;c[j>>2]=(c[j>>2]|0)+1;h=0;i=e;return h|0}return 0}function rx(a){a=a|0;var b=0;b=c[a+12>>2]|0;$Db(b+16|0);$Db(b+96|0);$Db(b+100|0);return 0}function sx(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[a+12>>2]|0;h=oT(g,d,e,f)|0;if((h|0)<0){i=-1;return i|0}f=(c[g+400>>2]|0)+(h*24|0)|0;g=Ty(c[a+16>>2]|0,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=F;a=0;if((f|0)<(a|0)|(f|0)==(a|0)&g>>>0<0>>>0){i=-1;return i|0}c[b+12>>2]=h;i=0;return i|0}function tx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+2136|0;e=d|0;f=d+2048|0;g=b+16|0;h=c[g>>2]|0;j=Wy(h)|0;k=F;l=0;if((k|0)<(l|0)|(k|0)==(l|0)&j>>>0<32>>>0){m=0;n=0;i=d;return(F=m,n)|0}l=YGb(j,k,-32,-1)|0;o=F;Ty(h,l,o,0)|0;p=d+2128|0;mz(h,p,8)|0;if((RGb(p,2026080,8)|0)!=0){m=0;n=0;i=d;return(F=m,n)|0}if((rz(h)|0)>>>0>2e3>>>0){yDb(b,16,2264200,(q=i,i=i+8|0,c[q>>2]=2e3,q)|0);i=q;m=0;n=0;i=d;return(F=m,n)|0}p=rz(h)|0;if((p-32|0)>>>0>16777216>>>0){yDb(b,16,2154592,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;m=0;n=0;i=d;return(F=m,n)|0}r=p;s=0;if((s|0)>(o|0)|(s|0)==(o|0)&r>>>0>l>>>0){yDb(b,16,2085448,(q=i,i=i+8|0,c[q>>2]=p,q)|0);i=q;m=0;n=0;i=d;return(F=m,n)|0}p=ZGb(j,k,r,s)|0;s=F;r=YGb(p,s,-32,-1)|0;k=F;j=rz(h)|0;if(j>>>0>65536>>>0){yDb(b,16,2034400,(q=i,i=i+8|0,c[q>>2]=j,q)|0);i=q;m=0;n=0;i=d;return(F=m,n)|0}if(((rz(h)|0)&536870912|0)!=0){yDb(b,16,1989704,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;m=0;n=0;i=d;return(F=m,n)|0}Ty(h,p,s,0)|0;s=e|0;p=d+1024|0;h=f;l=b+1140|0;o=b;t=0;while(1){if(!(t>>>0<j>>>0)){m=k;n=r;u=36;break}v=c[g>>2]|0;w=rz(v)|0;x=rz(v)|0;y=0;while(1){z=lz(v)|0;if((z-32|0)>>>0>94>>>0){A=y;break}a[e+y|0]=z;B=y+1|0;if(B>>>0<1023>>>0){y=B}else{A=B;break}}a[e+A|0]=0;do{if((z|0)==0){if((w|0)==-1){C=-1;break}if((x&2|0)==0){y=WDb(w+1|0)|0;if((y|0)==0){C=-12;break}B=mz(v,y,w)|0;if((B|0)<0){ZDb(y);C=B;break}else{a[y+B|0]=0;CBb(l,s,y,8)|0;C=0;break}}y=LT(b,0)|0;if((y|0)==0){C=-12;break}B=xz(v,w,p,1024)|0;D=w-B|0;if((w|0)==(B|0)){yDb(o,24,1886144,(q=i,i=i+8|0,c[q>>2]=s,q)|0);i=q;C=0;break}CBb(y+88|0,s,p,0)|0;B=$E(p)|0;if((B|0)==0){E=y+8|0;if((CT(c[E>>2]|0,c[g>>2]|0,D)|0)<0){C=-12;break}c[(c[E>>2]|0)+8>>2]=4;C=0;break}E=TS(c[g>>2]|0,f,D)|0;if((E|0)<0){yDb(o,16,2343960,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=E;break}else{E=y+72|0;c[E>>2]=c[E>>2]|1024;E=c[y+8>>2]|0;c[E+8>>2]=0;c[E+48>>2]=B;UGb(y+104|0,h|0,80)|0;c[y+136>>2]=c[y>>2];B=y+140|0;c[B>>2]=c[B>>2]|1;C=0;break}}else{yDb(o,24,1906848,(q=i,i=i+8|0,c[q>>2]=s,q)|0);i=q;C=-1}}while(0);if((C|0)<0){m=k;n=r;u=36;break}else{t=t+1|0}}if((u|0)==36){i=d;return(F=m,n)|0}return 0}function ux(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=0;c[f>>2]=0;g=Mz(e)|0;do{if((g|0)>=0){Yy(c[e>>2]|0,-536870912);Qy(c[e>>2]|0,0,8);h=b+1140|0;j=BBb(c[h>>2]|0,9203152,0,2)|0;if((j|0)==0){break}k=b;l=0;m=j;a:while(1){j=m;while(1){n=j|0;o=c[n>>2]|0;while(1){p=a[o]|0;if((p-32&255)>>>0<95>>>0){o=o+1|0}else{break}}if(p<<24>>24==0){break}yDb(k,24,1928792,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;o=BBb(c[h>>2]|0,9203152,j,2)|0;if((o|0)==0){q=l;break a}else{j=o}}o=j+4|0;r=SGb(c[o>>2]|0)|0;Yy(c[e>>2]|0,r);Yy(c[e>>2]|0,0);_y(c[e>>2]|0,c[n>>2]|0)|0;Ry(c[e>>2]|0,c[o>>2]|0,r);r=l+1|0;o=BBb(c[h>>2]|0,9203152,j,2)|0;if((o|0)==0){q=r;break}else{l=r;m=o}}if((q|0)==0){break}m=Oz(c[e>>2]|0,f)|0;if((m|0)<1){break}l=m+20|0;h=b+16|0;Ry(c[h>>2]|0,2026080,8);Yy(c[h>>2]|0,2e3);Yy(c[h>>2]|0,l);Yy(c[h>>2]|0,q);Ry(c[h>>2]|0,c[f>>2]|0,m);Ry(c[h>>2]|0,2026080,8);Yy(c[h>>2]|0,2e3);Yy(c[h>>2]|0,l);Yy(c[h>>2]|0,q);Yy(c[h>>2]|0,-1073741824);Qy(c[h>>2]|0,0,8)}}while(0);q=c[e>>2]|0;if((q|0)==0){s=f;$Db(s);i=d;return g|0}if((c[f>>2]|0)!=0){s=f;$Db(s);i=d;return g|0}Oz(q,f)|0;s=f;$Db(s);i=d;return g|0}function vx(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=xd(c[a+4>>2]|0,1956088,(a=i,i=i+8|0,c[a>>2]=b,a)|0)|0;i=a;i=b;return((d|0)==1?50:0)|0}function wx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+4104|0;e=d|0;f=d+8|0;g=c[b+12>>2]|0;h=LT(b,0)|0;c[e>>2]=0;c[e+4>>2]=-2147483648;if((h|0)==0){j=-12;i=d;return j|0}MT(h,64,c[g+28>>2]|0,c[g+24>>2]|0);k=c[h+8>>2]|0;c[k+8>>2]=3;c[k+48>>2]=94210;k=b+16|0;b=f|0;h=g+4|0;g=0;l=0;a:while(1){m=0;n=1;b:while(1){do{if((Xy(c[k>>2]|0)|0)!=0){o=16;break a}if((wz(c[k>>2]|0,b,4096)|0)==0){o=16;break a}a[f+(hc(b|0,2085440)|0)|0]=0;p=xd(b|0,2034384,(q=i,i=i+8|0,c[q>>2]=e,q)|0)|0;i=q;if((p|0)==1){break b}}while((a[b]|0)==0);p=(n|0)!=0;if(!p){if((uR(h,1989696,1,1)|0)==0){j=-12;o=17;break a}}q=uR(h,b,SGb(b|0)|0,n^1)|0;if((q|0)==0){j=-12;o=17;break a}if(!p){m=q;n=0;continue}p=c[e+4>>2]|0;r=q+8|0;c[r>>2]=c[e>>2];c[r+4>>2]=p;c[q+48>>2]=-1;p=q+64|0;c[p>>2]=l;c[p+4>>2]=g;m=q;n=0}n=Ty(c[k>>2]|0,0,0,1)|0;q=F;if((m|0)==0){g=q;l=n;continue}p=m+8|0;r=ZGb(c[e>>2]|0,c[e+4>>2]|0,c[p>>2]|0,c[p+4>>2]|0)|0;c[m+48>>2]=r;g=q;l=n}if((o|0)==16){vR(h);j=0;i=d;return j|0}else if((o|0)==17){i=d;return j|0}return 0}function xx(a,b){a=a|0;b=b|0;return yR((c[a+12>>2]|0)+4|0,b)|0}function yx(a){a=a|0;AR((c[a+12>>2]|0)+4|0);return 0}function zx(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR((c[a+12>>2]|0)+4|0,a,b,d,e,f,g,h,i,j)|0}function Ax(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,1263296,16)|0)==0;return(b?100:0)|0}function Bx(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;f=i;i=i+1160|0;g=f|0;h=f+8|0;j=f+1032|0;k=f+1040|0;l=f+1056|0;m=f+1072|0;n=f+1152|0;o=e+12|0;p=c[o>>2]|0;q=e+16|0;r=c[q>>2]|0;yO(r,l)|0;s=l|0;if((PGb(s,1263296,16)|0)!=0){t=-1094995529;i=f;return t|0}sz(r)|0;rz(r)|0;lz(r)|0;lz(r)|0;u=p+4|0;TGb(u|0,-1|0,512)|0;v=p+520|0;w=0;do{b[v+(w*1216|0)+144>>1]=128;w=w+1|0;}while((w|0)<128);w=u;u=Ty(r,0,0,1)|0;x=F;yO(r,l)|0;y=sz(r)|0;z=F;a:do{if((PGb(s,1263536,16)|0)==0){A=z;B=y}else{C=e+1076|0;D=e;E=k|0;G=e+24|0;H=j|0;I=h|0;J=g|0;K=g+4|0;L=e+1100|0;M=m+24|0;N=m+28|0;O=e+1140|0;P=x;Q=u;R=z;S=y;b:while(1){T=0;if((R|0)<(T|0)|(R|0)==(T|0)&S>>>0<24>>>0){t=-1094995529;U=147;break}c:do{if((PGb(s,1263344,16)|0)==0){T=c[o>>2]|0;V=c[q>>2]|0;yO(V,T+158512|0)|0;W=sz(V)|0;X=T+158528|0;c[X>>2]=W;c[X+4>>2]=F;X=sz(V)|0;W=T+158536|0;c[W>>2]=X;c[W+4>>2]=F;sz(V)|0;W=sz(V)|0;X=T+158544|0;c[X>>2]=W;c[X+4>>2]=F;X=sz(V)|0;W=T+158552|0;c[W>>2]=X;c[W+4>>2]=F;c[T+158560>>2]=rz(V)|0;c[T+158564>>2]=rz(V)|0;c[T+158568>>2]=rz(V)|0;W=T+158572|0;c[W>>2]=rz(V)|0;X=T+158576|0;c[X>>2]=rz(V)|0;if((c[W>>2]|0)>>>0>536870911>>>0){t=-1094995529;U=147;break b}c[T+158580>>2]=rz(V)|0;c[C>>2]=c[X>>2];U=125}else{if((PGb(s,1262944,16)|0)==0){X=c[o>>2]|0;V=c[q>>2]|0;if((c[G>>2]|0)==127){U=15;break b}T=Ty(V,0,0,1)|0;W=F;Y=LT(e,0)|0;if((Y|0)==0){t=-12;U=147;break b}MT(Y,32,1,1e3);Z=c[X+158560>>2]|0;_=0;d:do{if((c[X+158568>>2]&1|0)==0){$=Wy(V)|0;aa=F;ba=0;do{if(!((aa|0)<(ba|0)|(aa|0)==(ba|0)&$>>>0<1>>>0)){ca=X+158528|0;da=c[ca>>2]|0;ea=c[ca+4>>2]|0;ca=0;if((ea|0)<(ca|0)|(ea|0)==(ca|0)&da>>>0<1>>>0){break}ca=ZGb($,aa,da,ea)|0;ea=F;da=-1;fa=(ea|0)>(da|0)|(ea|0)==(da|0)&ca>>>0>-1>>>0;da=ZGb(0,0,ca,ea)|0;ga=fa?ea:F;ea=0;if(!((ga|0)<(ea|0)|(ga|0)==(ea|0)&(fa?ca:da)>>>0<1e4>>>0)){break d}}}while(0);aa=X+158544|0;$=hHb(c[aa>>2]|0,c[aa+4>>2]|0,1e4,0)|0;aa=ZGb($,F,Z,_)|0;$=Y+56|0;c[$>>2]=aa;c[$+4>>2]=F}}while(0);yO(V,k)|0;do{if((PGb(E,1263632,16)|0)==0){ha=1;ia=0}else{if((PGb(E,1262824,16)|0)==0){ha=0;ia=0;break}if((PGb(E,1263280,16)|0)==0){c[(c[Y+8>>2]|0)+48>>2]=8;ha=0;ia=0;break}if((PGb(E,1263584,16)|0)==0){ha=2;ia=0;break}if((PGb(E,1263392,16)|0)==0){ha=-1;ia=1}else{t=-1;U=147;break b}}}while(0);yO(V,k)|0;Vy(V,8,0)|0;_=rz(V)|0;rz(V)|0;Z=(pz(V)|0)&127;$=Y+4|0;c[$>>2]=Z;c[X+4+(Z<<2)>>2]=(c[G>>2]|0)-1;Z=c[$>>2]|0;$=X+520|0;rz(V)|0;do{if(ia){yO(V,k)|0;if((PGb(E,1263408,16)|0)!=0){U=31;break}yO(V,k)|0;rz(V)|0;rz(V)|0;rz(V)|0;yO(V,k)|0;rz(V)|0;aa=Y+8|0;ba=c[aa>>2]|0;c[ba+8>>2]=1;ja=1;ka=aa;la=ba;U=32}else{U=31}}while(0);do{if((U|0)==31){U=0;X=Y+8|0;ba=c[X>>2]|0;c[ba+8>>2]=ha;if((ha|0)==1){ja=0;ka=X;la=ba;U=32;break}else if((ha|0)!=0){break}ba=Ty(V,0,0,1)|0;aa=F;da=YGb(S,R,-24,-1)|0;ca=YGb(da,F,T,W)|0;da=ZGb(ca,F,ba,aa)|0;aa=F;ba=0;if(!((aa|0)>(ba|0)|(aa|0)==(ba|0)&da>>>0>50>>>0)){break}rz(V)|0;rz(V)|0;lz(V)|0;pz(V)|0;da=rz(V)|0;ba=rz(V)|0;c[(c[X>>2]|0)+120>>2]=ba;ba=rz(V)|0;c[(c[X>>2]|0)+124>>2]=ba;pz(V)|0;ba=pz(V)|0;c[(c[X>>2]|0)+792>>2]=ba;ba=rz(V)|0;Vy(V,20,0)|0;if((da|0)>40){aa=SS(V,da-40|0)|0;c[(c[X>>2]|0)+100>>2]=aa;da=cEb(aa+16|0)|0;c[(c[X>>2]|0)+96>>2]=da;da=c[X>>2]|0;aa=c[da+96>>2]|0;if((aa|0)==0){t=-12;U=147;break b}mz(V,aa,c[da+100>>2]|0)|0}da=c[X>>2]|0;aa=c[da+100>>2]|0;do{if((aa|0)==0){ma=da}else{if((c[da+792>>2]|0)>=9){ma=da;break}UGb($+(Z*1216|0)+152|0,c[da+96>>2]|0,(aa|0)>1024?1024:aa)|0;c[$+(Z*1216|0)+148>>2]=1;ma=c[X>>2]|0}}while(0);c[ma+52>>2]=ba;aa=vT(1240808,ba)|0;da=c[X>>2]|0;c[da+48>>2]=aa;if((ba|0)==542266948){c[Y+236>>2]=1;c[da+124>>2]=0;c[da+120>>2]=0;$Db(da+96|0);da=c[X>>2]|0;c[da+100>>2]=0;na=c[da+48>>2]|0}else{na=aa}if((na|0)!=28){break}c[Y+236>>2]=4}}while(0);e:do{if((U|0)==32){U=0;aa=AO(V,la,_)|0;if((aa|0)<0){t=aa;U=147;break b}if((ja|0)==0){oa=c[ka>>2]|0}else{c[Y+440>>2]=1;aa=c[ka>>2]|0;c[aa+52>>2]=0;oa=aa}c[Y+236>>2]=(c[oa+48>>2]|0)!=86018;aa=Ty(V,0,0,1)|0;da=F;ca=ZGb(32,0,T,W)|0;fa=YGb(ca,F,aa,da)|0;da=F;if((da|0)>(R|0)|(da|0)==(R|0)&fa>>>0>S>>>0){pa=$+(Z*1216|0)+120|0}else{fa=$+(Z*1216|0)+120|0;c[fa>>2]=lz(V)|0;c[$+(Z*1216|0)+124>>2]=pz(V)|0;c[$+(Z*1216|0)+128>>2]=pz(V)|0;pz(V)|0;lz(V)|0;pa=fa}if((c[pa>>2]|0)<=1){break}fa=c[$+(Z*1216|0)+128>>2]|0;do{if((fa|0)!=0){da=c[$+(Z*1216|0)+124>>2]|0;if(((da|0)/(fa|0)|0|0)<2){break}if(((da|0)%(fa|0)|0|0)==0){break e}}}while(0);c[pa>>2]=0}}while(0);Z=Ty(V,0,0,1)|0;$=F;Y=YGb(S,R,-24,-1)|0;_=YGb(Y,F,T,W)|0;Y=ZGb(_,F,Z,$)|0;Vy(V,Y,F)|0;U=125;break}if((PGb(s,1263568,16)|0)==0){Y=c[q>>2]|0;$=pz(Y)|0;Z=pz(Y)|0;_=pz(Y)|0;fa=pz(Y)|0;X=pz(Y)|0;Hx(e,2005448,0,$,32);Hx(e,1982856,0,Z,32);Hx(e,1979824,0,_,32);Hx(e,1997008,0,fa,32);Vy(Y,X,(X|0)<0|0?-1:0)|0;U=125;break}if((PGb(s,1263264,16)|0)==0){X=c[o>>2]|0;Y=c[q>>2]|0;fa=pz(Y)|0;if((fa|0)<=0){U=125;break}_=X+157704|0;X=0;while(1){Z=lz(Y)|0;$=yz(Y,Z,H,6)|0;if($>>>0<Z>>>0){Vy(Y,Z-$|0,0)|0;}if((X|0)<128){sAb(_+(X*6|0)|0,H,6)|0}$=X+1|0;if(($|0)<(fa|0)){X=$}else{U=125;break c}}}if((PGb(s,1263360,16)|0)==0){X=c[q>>2]|0;fa=c[o>>2]|0;_=pz(X)|0;if((_|0)<=0){U=125;break}Y=fa+156680|0;V=fa+156684|0;fa=0;while(1){W=pz(X)|0;T=(W&1)+W|0;W=yz(X,T,I,1024)|0;if((W|0)<(T|0)){$=T-W|0;Vy(X,$,($|0)<0|0?-1:0)|0;}$=pz(X)|0;W=pz(X)|0;if(($|0)==0){qa=(W&1)+W|0}else{qa=W}do{if((QGb(I,1990192)|0)==0){W=c[q>>2]|0;if(($|0)==2){ra=rz(W)|0}else if(($|0)==3){ra=rz(W)|0}else if(($|0)==4){T=sz(W)|0;ra=T}else if(($|0)==5){ra=pz(W)|0}else{ra=-2147483648}c[Y>>2]=ra}else{if((QGb(I,1986712)|0)!=0){Hx(e,I,$,qa,32);break}W=c[q>>2]|0;if(($|0)==2){sa=rz(W)|0}else if(($|0)==3){sa=rz(W)|0}else if(($|0)==4){T=sz(W)|0;sa=T}else if(($|0)==5){sa=pz(W)|0}else{sa=-2147483648}c[V>>2]=sa}}while(0);$=fa+1|0;if(($|0)<(_|0)){fa=$}else{U=125;break c}}}if((PGb(s,1263096,16)|0)==0){Gx(e);U=125;break}if((PGb(s,1263080,16)|0)==0){Gx(e);U=125;break}if((PGb(s,1263376,16)|0)==0){fa=c[o>>2]|0;_=c[q>>2]|0;sz(_)|0;sz(_)|0;V=rz(_)|0;rz(_)|0;rz(_)|0;rz(_)|0;rz(_)|0;rz(_)|0;rz(_)|0;rz(_)|0;Y=pz(_)|0;X=pz(_)|0;$=Y>>>0<128>>>0;if($){b[fa+520+(Y*1216|0)+144>>1]=X}sz(_)|0;X=pz(_)|0;W=pz(_)|0;if($){c[fa+156168+(Y<<2)>>2]=V;c[fa+520+(Y*1216|0)+1176>>2]=0}if((X|0)>0){V=0;do{pz(_)|0;T=pz(_)|0;Vy(_,T,(T|0)<0|0?-1:0)|0;V=V+1|0;}while((V|0)<(X|0))}if((W|0)<=0){break}X=fa+520|0;V=X+(Y*1216|0)+1176|0;if($){ta=0}else{T=0;while(1){yO(_,k)|0;pz(_)|0;Z=rz(_)|0;Vy(_,Z,(Z|0)<0|0?-1:0)|0;T=T+1|0;if((T|0)>=(W|0)){break c}}}while(1){yO(_,k)|0;T=pz(_)|0;$=rz(_)|0;Vy(_,$,($|0)<0|0?-1:0)|0;if(ta>>>0<8>>>0){a[X+(Y*1216|0)+1180+(ta<<2)|0]=a[E]|0;b[X+(Y*1216|0)+1180+(ta<<2)+2>>1]=T;yDb(D,48,1993728,(ua=i,i=i+16|0,c[ua>>2]=d[E]|0,c[ua+8>>2]=T&65535,ua)|0);i=ua;c[V>>2]=(c[V>>2]|0)+1}ta=ta+1|0;if((ta|0)>=(W|0)){break c}}}if((PGb(s,1263328,16)|0)==0){yO(r,l)|0;Vy(r,6,0)|0;break}if((PGb(s,1263248,16)|0)==0){W=c[q>>2]|0;V=c[o>>2]|0;sz(W)|0;sz(W)|0;Y=rz(W)|0;pz(W)|0;X=pz(W)|0;if((X|0)>0){_=0;do{lz(W)|0;_=_+1|0;}while((_|0)<(X|0))}if((Y|0)<=0){U=125;break}X=V+158560|0;_=0;while(1){sz(W)|0;T=sz(W)|0;$=ZGb(T,F,(c[X>>2]|0)*1e4|0,0)|0;T=F;pz(W)|0;rz(W)|0;rz(W)|0;fa=rz(W)|0;Z=yz(W,fa<<1,I,1024)|0;if((Z|0)<(fa|0)){ba=fa-Z|0;Vy(W,ba,(ba|0)<0|0?-1:0)|0;}c[J>>2]=1;c[K>>2]=1e7;OT(e,_,g,$,T,0,-2147483648,I)|0;T=_+1|0;if((T|0)<(Y|0)){_=T}else{U=125;break c}}}if((Xy(r)|0)!=0){t=-541478725;U=147;break b}if((c[L>>2]|0)!=0){U=125;break}if((PGb(s,1263552,16)|0)==0){yDb(D,24,2118048,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;_=rz(r)|0;yDb(D,48,2108760,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;TS(r,m,_)|0;VT(D,48,c[M>>2]|0,c[N>>2]|0);BZ(m);Hx(e,2096784,-1,rz(r)|0,32);Hx(e,2091160,-1,rz(r)|0,32);Hx(e,2086160,-1,rz(r)|0,32);U=125;break}if((PGb(s,1263424,16)|0)==0){yDb(D,24,2081096,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;CBb(O,2075696,2071136,0)|0;U=125;break}if((PGb(s,1263440,16)|0)!=0){U=125;break}yDb(D,32,2066600,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;U=125}}while(0);if((U|0)==125){U=0;_=Ty(r,0,0,1)|0;Y=F;W=YGb(S,R,Q,P)|0;X=F;if(!((_|0)==(W|0)&(Y|0)==(X|0))){Y=Ty(r,0,0,1)|0;_=ZGb(Y,F,Q,P)|0;Y=F;yDb(D,48,2062360,(ua=i,i=i+32|0,c[ua>>2]=_,c[ua+8>>2]=Y,c[ua+16>>2]=S,c[ua+24>>2]=R,ua)|0);i=ua}Ty(r,W,X,0)|0;}X=Ty(r,0,0,1)|0;W=F;yO(r,l)|0;Y=sz(r)|0;_=F;if((PGb(s,1263536,16)|0)==0){A=_;B=Y;break a}else{P=W;Q=X;R=_;S=Y}}if((U|0)==15){yDb(D,16,1977176,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;t=-22;i=f;return t|0}else if((U|0)==147){i=f;return t|0}}}while(0);ua=Ty(r,0,0,1)|0;s=p+158488|0;c[s>>2]=ua;c[s+4>>2]=F;s=0;if((c[p+158568>>2]&1|0)==0&((A|0)>(s|0)|(A|0)==(s|0)&B>>>0>99>>>0)){s=YGb(B,A,-24,-1)|0;A=p+158496|0;c[A>>2]=s;c[A+4>>2]=F}else{A=p+158496|0;c[A>>2]=-1;c[A+4>>2]=-1}yO(r,l)|0;sz(r)|0;lz(r)|0;lz(r)|0;if((Xy(r)|0)!=0){t=-541478725;i=f;return t|0}l=Ty(r,0,0,1)|0;r=p+158480|0;c[r>>2]=l;c[r+4>>2]=F;c[p+158472>>2]=0;r=e+28|0;l=p+156168|0;A=p+156680|0;s=A;B=p+157704|0;ua=n|0;m=n+1|0;g=n+2|0;n=A;A=p+156684|0;p=0;do{o=c[w+(p<<2)>>2]|0;do{if((o|0)>-1){q=c[(c[r>>2]|0)+(o<<2)>>2]|0;ta=c[q+8>>2]|0;k=ta+72|0;if((c[k>>2]|0)==0){c[k>>2]=c[l+(p<<2)>>2]}k=c[s+(p<<3)>>2]|0;do{if((k|0)>0){sa=c[s+(p<<3)+4>>2]|0;if((sa|0)<=0){U=136;break}iFb(q+80|0,q+84|0,k,(k|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0,2147483647,0)|0}else{U=136}}while(0);do{if((U|0)==136){U=0;k=c[n>>2]|0;if((k|0)<=0){break}sa=c[A>>2]|0;if((sa|0)<=0){break}if((c[ta+8>>2]|0)!=0){break}iFb(q+80|0,q+84|0,k,(k|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0,2147483647,0)|0}}while(0);ta=b[v+(p*1216|0)+144>>1]|0;if(!((ta&65535)>>>0<128>>>0)){break}sa=ta&65535;ta=B+(sa*6|0)|0;if((ta|0)==0){break}if(!((SGb(ta|0)|0)>>>0>1>>>0)){break}a[ua]=a[ta]|0;a[m]=a[B+(sa*6|0)+1|0]|0;a[g]=0;sa=Vz(ua,0)|0;if((sa|0)==0){break}CBb(q+88|0,2058784,sa,0)|0}}while(0);p=p+1|0;}while((p|0)<128);QG(e+1140|0,0,1263112);t=0;i=f;return t|0}function Cx(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;g=i;h=e+12|0;j=c[h>>2]|0;k=e+16|0;l=c[k>>2]|0;if((Xy(l)|0)!=0){m=-541478725;i=g;return m|0}n=e;o=e+28|0;p=e+1096|0;q=e+1100|0;r=e+1076|0;s=e+1248|0;e=j+158472|0;t=j+158600|0;u=j+158648|0;v=l;l=j;a:while(1){j=l+158472|0;w=l+158648|0;x=l+158600|0;y=l+158664|0;z=l+158624|0;A=l+158612|0;B=l+520|0;C=l+158668|0;D=l+158620|0;E=l+158608|0;G=l+158632|0;H=l+158644|0;I=l+158640|0;J=l+158604|0;K=l+158560|0;L=l+158656|0;while(1){M=c[j>>2]|0;if((M|0)<16){break}b:do{if((c[w>>2]|0)==0){N=c[h>>2]|0;O=lz(v)|0;P=N+158600|0;c[P>>2]=(c[P>>2]|0)-1;c[N+158612>>2]=O>>7;P=O&127;O=N+158664|0;c[O>>2]=c[N+4+(P<<2)>>2];Q=N+520|0;R=N+158588|0;S=(c[R>>2]|0)>>>4&3;if((S|0)==1){c[N+158604>>2]=lz(v)|0;T=2}else if((S|0)==2){c[N+158604>>2]=pz(v)|0;T=3}else if((S|0)==3){c[N+158604>>2]=rz(v)|0;T=5}else{c[N+158604>>2]=0;T=1}S=(c[R>>2]|0)>>>2&3;if((S|0)==1){c[N+158620>>2]=lz(v)|0;U=T+1|0}else if((S|0)==2){c[N+158620>>2]=pz(v)|0;U=T+2|0}else if((S|0)==3){c[N+158620>>2]=rz(v)|0;U=T+4|0}else{c[N+158620>>2]=0;U=T}S=c[R>>2]&3;if((S|0)==1){R=lz(v)|0;c[N+158608>>2]=R;V=U+1|0;W=R}else if((S|0)==3){R=rz(v)|0;c[N+158608>>2]=R;V=U+4|0;W=R}else if((S|0)==2){S=pz(v)|0;c[N+158608>>2]=S;V=U+2|0;W=S}else{c[N+158608>>2]=0;V=U;W=0}S=N+158608|0;R=YGb(V,(V|0)<0|0?-1:0,W,(W|0)<0|0?-1:0)|0;X=F;Y=N+158472|0;Z=c[Y>>2]|0;_=(Z|0)<0|0?-1:0;c:do{if((X|0)>(_|0)|(X|0)==(_|0)&R>>>0>Z>>>0){yDb(n,16,2155400,($=i,i=i+8|0,c[$>>2]=W,$)|0);i=$}else{do{if((W|0)>7){aa=Ty(v,0,0,1)|0;ca=c[S>>2]|0;da=YGb(ca,(ca|0)<0|0?-1:0,aa,F)|0;aa=F;ca=rz(v)|0;ea=Q+(P*1216|0)+92|0;c[ea>>2]=ca;if((ca-1|0)>>>0>16777214>>>0){yDb(n,16,2148360,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;c[ea>>2]=0;break c}ea=N+158632|0;c[ea>>2]=rz(v)|0;c[ea+4>>2]=0;ca=Q+(P*1216|0)+1176|0;d:do{if((c[ca>>2]|0)>0){fa=0;while(1){ga=b[Q+(P*1216|0)+1180+(fa<<2)+2>>1]|0;if(ga<<16>>16==-1){ha=pz(v)|0}else{ha=ga&65535}ga=Ty(v,0,0,1)|0;ia=YGb(ga,F,ha,(ha|0)<0|0?-1:0)|0;ga=F;if((ga|0)>(aa|0)|(ga|0)==(aa|0)&ia>>>0>da>>>0){break}ja=d[Q+(P*1216|0)+1180+(fa<<2)|0]|0;do{if((ja|0)==84){ka=lz(v)|0;la=lz(v)|0;if(!((ka|0)>0&(la|0)>0)){break}ma=c[O>>2]|0;if(!((ma|0)>-1)){break}na=c[(c[o>>2]|0)+(ma<<2)>>2]|0;c[na+80>>2]=ka;c[na+84>>2]=la}else if((ja|0)==42){Vy(v,8,0)|0;la=sz(v)|0;na=F;sz(v)|0;if((la|0)==(-1|0)&(na|0)==(-1|0)){c[ea>>2]=0;c[ea+4>>2]=-2147483648;break}else{ka=eHb(la,na,1e4,0)|0;c[ea>>2]=ka;c[ea+4>>2]=F;break}}}while(0);Ty(v,ia,ga,0)|0;fa=fa+1|0;if((fa|0)>=(c[ca>>2]|0)){break d}}yDb(n,16,2141912,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$}}while(0);Ty(v,da,aa,0)|0;oa=(c[S>>2]|0)+V|0}else{if((W|0)==1){ca=N+158620|0;c[N+158648>>2]=c[ca>>2];c[ca>>2]=0;ca=c[N+158592>>2]|0;ea=N+158632|0;c[ea>>2]=ca;c[ea+4>>2]=(ca|0)<0|0?-1:0;c[N+158644>>2]=lz(v)|0;oa=V+1|0;break}else if((W|0)==0){oa=V;break}else{yDb(n,16,2136032,($=i,i=i+8|0,c[$>>2]=W,$)|0);i=$;break c}}}while(0);do{if((c[N+158584>>2]&1|0)==0){ca=c[Y>>2]|0;ea=ca-oa|0;c[N+158624>>2]=ea;pa=oa;qa=ea;ra=ca}else{ca=(c[N+158596>>2]|0)>>>6&3;if((ca|0)==3){ea=rz(v)|0;c[N+158624>>2]=ea;sa=oa+4|0;ta=ea}else if((ca|0)==2){ea=pz(v)|0;c[N+158624>>2]=ea;sa=oa+2|0;ta=ea}else if((ca|0)==1){ca=lz(v)|0;c[N+158624>>2]=ca;sa=oa+1|0;ta=ca}else{c[N+158624>>2]=0;sa=oa;ta=0}ca=c[Y>>2]|0;if((sa|0)>(ca|0)){yDb(n,16,2129976,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;break c}ea=ca-sa|0;if(!(ta>>>0>ea>>>0)){pa=sa;qa=ta;ra=ca;break}fa=N+158616|0;ja=c[fa>>2]|0;if(ta>>>0>(ja+ea|0)>>>0){yDb(n,16,2123280,($=i,i=i+16|0,c[$>>2]=ca,c[$+8>>2]=sa,$)|0);i=$;break c}else{ka=ta-ea|0;ea=ka+ca|0;c[Y>>2]=ea;c[fa>>2]=ja-ka;pa=sa;qa=ta;ra=ea;break}}}while(0);if((c[S>>2]|0)==1){c[N+158640>>2]=qa;if((qa|0)>(ra|0)){break}}c[Y>>2]=ra-pa;ea=c[y>>2]|0;do{if((ea|0)>=0){ka=c[(c[o>>2]|0)+(ea<<2)>>2]|0;ja=c[ka+76>>2]|0;if((ja|0)>47){break}if((c[A>>2]|0)==0){if((ja|0)>31){break}ja=c[ka+4>>2]|0;if((c[B+(ja*1216|0)+112>>2]|0)==0){ua=ja}else{break}}else{ua=c[ka+4>>2]|0}ka=B+(ua*1216|0)|0;c[C>>2]=ka;c[B+(ua*1216|0)+112>>2]=0;va=ka;wa=74;break b}}while(0);c[w>>2]=0;Vy(v,c[z>>2]|0,0)|0;ea=c[z>>2]|0;c[j>>2]=(c[j>>2]|0)-ea;if((c[y>>2]|0)>=0){break b}yDb(n,16,2266664,($=i,i=i+8|0,c[$>>2]=ea,$)|0);i=$;break b}}while(0);c[x>>2]=0;c[w>>2]=0}else{va=c[C>>2]|0;wa=74}}while(0);e:do{if((wa|0)==74){wa=0;if((va|0)==0){wa=75;break a}xa=va+88|0;do{if((c[xa>>2]|0)==0){if((c[D>>2]|0)==0){break}Vy(v,c[z>>2]|0,0)|0;c[j>>2]=(c[j>>2]|0)-(c[z>>2]|0);break e}}while(0);do{if((c[E>>2]|0)==1){Y=c[w>>2]|0;c[G>>2]=Y;c[G+4>>2]=(Y|0)<0|0?-1:0;c[w>>2]=(c[H>>2]|0)+Y;Y=lz(v)|0;c[z>>2]=Y;N=va+92|0;c[N>>2]=Y;c[j>>2]=(c[j>>2]|0)-1;Y=(c[I>>2]|0)-1|0;c[I>>2]=Y;S=c[N>>2]|0;if((Y|0)<(S|0)){c[w>>2]=0;Vy(v,Y,(Y|0)<0|0?-1:0)|0;c[j>>2]=(c[j>>2]|0)-(c[I>>2]|0);break e}else{c[I>>2]=Y-S;ya=N;break}}else{ya=va+92|0}}while(0);za=va+8|0;Aa=va+36|0;N=c[Aa>>2]|0;S=c[ya>>2]|0;if((N|0)==(S|0)){if(((c[z>>2]|0)+(c[xa>>2]|0)|0)>>>0>N>>>0){wa=86}}else{wa=86}do{if((wa|0)==86){wa=0;Y=va+32|0;if((c[Y>>2]|0)==0){Ba=S}else{yDb(n,32,2225096,($=i,i=i+16|0,c[$>>2]=N,c[$+8>>2]=S,$)|0);i=$;c[xa>>2]=0;BZ(za);Ba=c[ya>>2]|0}wZ(za,Ba)|0;a[va+4|0]=c[J>>2];O=ZGb(c[G>>2]|0,c[G+4>>2]|0,c[K>>2]|0,0)|0;P=va+24|0;c[P>>2]=O;c[P+4>>2]=F;c[va+40>>2]=c[y>>2];P=c[L>>2]|0;O=c[L+4>>2]|0;Q=va+136|0;c[Q>>2]=P;c[Q+4>>2]=O;Q=va+72|0;c[Q>>2]=P;c[Q+4>>2]=O;c[va+116>>2]=0;do{if((c[Y>>2]|0)!=0){O=va+148|0;if((c[O>>2]|0)==0){break}Q=GZ(za,0,1024)|0;if((Q|0)==0){yDb(n,16,2214880,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;break}else{UGb(Q|0,va+152|0,1024)|0;c[O>>2]=0;break}}}while(0);if((c[(c[(c[(c[o>>2]|0)+(c[y>>2]<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==1){c[A>>2]=1}else{if((c[A>>2]|0)==0){break}}Y=va+44|0;c[Y>>2]=c[Y>>2]|1}}while(0);S=c[z>>2]|0;N=(c[j>>2]|0)-S|0;c[j>>2]=N;if((N|0)<0){break}N=c[D>>2]|0;Y=c[Aa>>2]|0;if(N>>>0>=Y>>>0|S>>>0>(Y-N|0)>>>0){yDb(n,16,2205152,($=i,i=i+24|0,c[$>>2]=N,c[$+8>>2]=S,c[$+16>>2]=Y,$)|0);i=$;break}O=c[xa>>2]|0;do{if((N|0)==(O|0)){Ca=N;Da=S}else{Q=va+116|0;if((c[Q>>2]|0)!=0){Ca=N;Da=S;break}TGb((c[va+32>>2]|0)+O|0,0,Y-O|0)|0;c[Q>>2]=1;Ca=c[D>>2]|0;Da=c[z>>2]|0}}while(0);Ea=va+32|0;O=mz(v,(c[Ea>>2]|0)+Ca|0,Da)|0;Y=c[z>>2]|0;do{if((O|0)==(Y|0)){Fa=O}else{if((O|0)<0){m=O;wa=131;break a}S=(c[D>>2]|0)+O|0;if((S|0)==0){m=-541478725;wa=131;break a}if((c[va+120>>2]|0)>1){TGb((c[Ea>>2]|0)+S|0,0,Y-O|0)|0;Fa=c[z>>2]|0;break}else{yZ(za,S);Fa=O;break}}}while(0);O=c[p>>2]|0;do{if((O|0)!=0){if((c[q>>2]|0)!=20){break}XW(O,(c[Ea>>2]|0)+(c[D>>2]|0)|0,Fa)}}while(0);Ga=(c[xa>>2]|0)+Fa|0;c[xa>>2]=Ga;if((Ga|0)!=(c[Aa>>2]|0)){break}if((c[(c[(c[(c[o>>2]|0)+(c[y>>2]<<2)>>2]|0)+8>>2]|0)+48>>2]|0)==2&(Ga|0)>100){Ha=0}else{wa=118;break a}while(1){if((Ha|0)>=(Ga|0)){break}if((a[(c[Ea>>2]|0)+Ha|0]|0)==0){Ha=Ha+1|0}else{break}}if((Ha|0)!=(Ga|0)){wa=118;break a}yDb(n,48,2197584,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;c[xa>>2]=0;BZ(za)}}while(0);if((Xy(v)|0)!=0){m=-541478725;wa=131;break a}}y=(c[l+158616>>2]|0)+M|0;if(!((y|0)>-1)){wa=6;break}Vy(v,y,(y|0)<0|0?-1:0)|0;y=Ty(v,0,0,1)|0;D=F;c[L>>2]=y;c[L+4>>2]=D;z=l+158496|0;j=c[z>>2]|0;A=c[z+4>>2]|0;if(!((j|0)==(-1|0)&(A|0)==(-1|0))){z=l+158488|0;K=ZGb(y,D,c[z>>2]|0,c[z+4>>2]|0)|0;z=F;if(!(z>>>0<A>>>0|z>>>0==A>>>0&K>>>0<j>>>0)){m=-541478725;wa=131;break}}j=c[k>>2]|0;K=c[h>>2]|0;do{if((c[K+158672>>2]|0)==0){if((c[r>>2]|0)==0){Ia=32768;Ja=-1;Ka=-1;La=-1;break}A=Ty(j,0,0,1)|0;z=ZGb(A,F,c[s>>2]|0,c[s+4>>2]|0)|0;A=fHb(z,F,c[r>>2]|0,0)|0;z=YGb(A,F,3,0)|0;Ia=z;Ja=-1;Ka=-1;La=-1}else{Ia=3;Ja=-1;Ka=-1;La=-1}}while(0);while(1){if((Ia|0)<=0){wa=137;break}L=lz(j)|0;if((Ka|0)==130&(Ja|0)==0&(L|0)==0){Ma=0;Na=0;wa=142;break}else{Ia=Ia-1|0;La=Ka;Ka=Ja;Ja=L}}do{if((wa|0)==137){wa=0;if((La|0)==130){Ma=Ka;Na=Ja;wa=142;break}if((c[j+76>>2]|0)==-11){wa=173;break}if((Xy(j)|0)==0){L=Ty(j,0,0,1)|0;z=F;yDb(n,16,1906728,($=i,i=i+24|0,c[$>>2]=La,c[$+8>>2]=L,c[$+16>>2]=z,$)|0);i=$}if((La&143|0)==130){Ma=Ka;Na=Ja;wa=142;break}if((Xy(j)|0)!=0){Oa=Ka;Pa=La;Qa=8;wa=148;break}Ty(j,-1,-1,1)|0;Oa=Ka;Pa=La;Qa=8;wa=148}}while(0);do{if((wa|0)==142){wa=0;if((Ma|Na|0)==0){z=lz(j)|0;Oa=lz(j)|0;Pa=z;Qa=11;wa=148;break}if((Xy(j)|0)!=0){wa=173;break}yDb(n,16,1885968,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;wa=173}}while(0);do{if((wa|0)==148){wa=0;z=K+158584|0;c[z>>2]=Pa;c[K+158588>>2]=Oa;L=Pa>>>5&3;if((L|0)==3){Ra=Qa|4;Sa=rz(j)|0}else if((L|0)==2){Ra=Qa+2|0;Sa=pz(j)|0}else if((L|0)==1){Ra=Qa+1|0;Sa=lz(j)|0}else{Ra=Qa;Sa=c[r>>2]|0}L=(c[z>>2]|0)>>>1&3;if((L|0)==3){rz(j)|0;Ta=Ra+4|0}else if((L|0)==2){pz(j)|0;Ta=Ra+2|0}else if((L|0)==1){lz(j)|0;Ta=Ra+1|0}else{Ta=Ra}L=(c[z>>2]|0)>>>3&3;if((L|0)==1){Ua=Ta+1|0;Va=lz(j)|0}else if((L|0)==3){Ua=Ta+4|0;Va=rz(j)|0}else if((L|0)==2){Ua=Ta+2|0;Va=pz(j)|0}else{Ua=Ta;Va=0}if((Sa|0)==0|Sa>>>0>536870911>>>0){L=Ty(j,0,0,1)|0;A=F;yDb(n,16,2343840,($=i,i=i+24|0,c[$>>2]=Sa,c[$+8>>2]=L,c[$+16>>2]=A,$)|0);i=$;wa=173;break}if(!(Va>>>0<Sa>>>0)){A=Ty(j,0,0,1)|0;L=F;yDb(n,16,2321640,($=i,i=i+24|0,c[$>>2]=Va,c[$+8>>2]=A,c[$+16>>2]=L,$)|0);i=$;wa=173;break}c[K+158592>>2]=rz(j)|0;pz(j)|0;if((c[z>>2]&1|0)==0){c[K+158600>>2]=1;c[K+158596>>2]=128;Wa=Ua}else{z=lz(j)|0;c[K+158596>>2]=z;c[K+158600>>2]=z&63;Wa=Ua+1|0}z=Sa-Va|0;if(Wa>>>0>z>>>0){c[K+158472>>2]=0;L=Ty(j,0,0,1)|0;A=F;yDb(n,16,2299368,($=i,i=i+40|0,c[$>>2]=Wa,c[$+8>>2]=Sa,c[$+16>>2]=Va,c[$+24>>2]=L,c[$+32>>2]=A,$)|0);i=$;wa=173;break}c[K+158472>>2]=z-Wa;z=c[K+158572>>2]|0;if(Sa>>>0<z>>>0){Xa=Va-Sa+z|0}else{Xa=Va}c[K+158616>>2]=Xa}}while(0);do{if((wa|0)==173){wa=0;if((c[e>>2]|0)<16){break}if((c[t>>2]|0)>=1){wa=175;break a}}}while(0);c[u>>2]=0;K=c[k>>2]|0;j=c[h>>2]|0;if((Xy(K)|0)==0){v=K;l=j}else{m=-541478725;wa=131;break}}if((wa|0)==6){yd(2281808,1928736,1128,2360040);return 0}else if((wa|0)==75){yDb(0,0,2251304,($=i,i=i+24|0,c[$>>2]=2237656,c[$+8>>2]=1928736,c[$+16>>2]=1160,$)|0);i=$;Cd();return 0}else if((wa|0)==118){l=va+120|0;v=c[l>>2]|0;do{if((v|0)>1){h=va+124|0;k=c[h>>2]|0;if((Ga|0)!=(ba(k,v)|0)){yDb(n,16,2185848,($=i,i=i+24|0,c[$>>2]=Ga,c[$+8>>2]=k,c[$+16>>2]=v,$)|0);i=$;break}k=UAb(Ga+16|0)|0;if((k|0)==0){break}u=k+4|0;t=c[u>>2]|0;TGb(t+(c[Aa>>2]|0)|0,0,16)|0;e=c[Aa>>2]|0;f:do{if((e|0)>0){Xa=va+128|0;Va=0;Sa=e;Wa=c[Xa>>2]|0;while(1){Ua=(Va|0)/(Wa|0)|0;Ta=c[l>>2]|0;Ra=((ba(c[h>>2]|0,(Ua|0)%(Ta|0)|0)|0)/(Wa|0)|0)+((Ua|0)/(Ta|0)|0)|0;if((Va+Wa|0)>(Sa|0)){wa=125;break}if((Ra+1|0)>((Sa|0)/(Wa|0)|0|0)){wa=127;break}UGb(t+Va|0,(c[Ea>>2]|0)+(ba(Ra,Wa)|0)|0,Wa)|0;Wa=c[Xa>>2]|0;Va=Wa+Va|0;Sa=c[Aa>>2]|0;if((Va|0)>=(Sa|0)){break f}}if((wa|0)==125){yd(2170408,1928736,1309,2360040);return 0}else if((wa|0)==127){yd(2161968,1928736,1310,2360040);return 0}}}while(0);t=za|0;XAb(t);c[t>>2]=k;c[Ea>>2]=c[u>>2]}}while(0);c[xa>>2]=0;UGb(f|0,za|0,80)|0;c[va+60>>2]=0;c[za>>2]=0;c[Aa>>2]=0;c[Ea>>2]=0;c[va+52>>2]=0;c[va+48>>2]=0;m=0;i=g;return m|0}else if((wa|0)==131){i=g;return m|0}else if((wa|0)==175){yd(1956008,1928736,1352,2360024);return 0}return 0}function Dx(b){b=b|0;var d=0,e=0;d=c[b+12>>2]|0;c[d+158472>>2]=0;b=d+520|0;TGb(d+158584|0,0,44)|0;TGb(d+158632|0,0,20)|0;e=0;do{BZ(b+(e*1216|0)+8|0);c[b+(e*1216|0)+92>>2]=0;c[b+(e*1216|0)+88>>2]=0;a[b+(e*1216|0)+4|0]=0;e=e+1|0;}while((e|0)<128);c[d+158668>>2]=0;return 0}function Ex(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+16|0;j=h|0;k=b+12|0;l=c[k>>2]|0;m=b+28|0;n=c[(c[m>>2]|0)+(d<<2)>>2]|0;o=b+1076|0;if((c[o>>2]|0)==0){p=-1;i=h;return p|0}q=b+16|0;r=c[q>>2]|0;do{if((r|0)!=0){s=Lz(r,d,e,f,g)|0;t=s;if((t|0)>-1){s=c[k>>2]|0;c[s+158472>>2]=0;u=s+520|0;TGb(s+158584|0,0,44)|0;TGb(s+158632|0,0,20)|0;v=0;do{BZ(u+(v*1216|0)+8|0);c[u+(v*1216|0)+92>>2]=0;c[u+(v*1216|0)+88>>2]=0;a[u+(v*1216|0)+4|0]=0;v=v+1|0;}while((v|0)<128);c[s+158668>>2]=0}if((t|0)==-38){break}else{p=t}i=h;return p|0}}while(0);if((e|0)==0&(f|0)==0){r=c[k>>2]|0;c[r+158472>>2]=0;v=r+520|0;TGb(r+158584|0,0,44)|0;TGb(r+158632|0,0,20)|0;u=0;do{BZ(v+(u*1216|0)+8|0);c[v+(u*1216|0)+92>>2]=0;c[v+(u*1216|0)+88>>2]=0;a[v+(u*1216|0)+4|0]=0;u=u+1|0;}while((u|0)<128);c[r+158668>>2]=0;r=b+1248|0;Ty(c[q>>2]|0,c[r>>2]|0,c[r+4>>2]|0,0)|0;p=0;i=h;return p|0}r=l+158504|0;l=c[r>>2]|0;a:do{if((l|0)==0){u=j|0;v=c[k>>2]|0;w=Ty(c[q>>2]|0,0,0,1)|0;x=F;y=c[q>>2]|0;z=v+158488|0;A=v+158496|0;B=YGb(c[A>>2]|0,c[A+4>>2]|0,c[z>>2]|0,c[z+4>>2]|0)|0;z=Ty(y,B,F,0)|0;do{if((z|0)>=0){B=yO(c[q>>2]|0,j)|0;b:do{if((B|0)<0){C=B}else{y=B;while(1){A=(PGb(u,1262960,16)|0)==0;D=sz(c[q>>2]|0)|0;E=F;if(A){break}A=0;if((E|0)<(A|0)|(E|0)==(A|0)&D>>>0<24>>>0){C=y;break b}if((Xy(c[q>>2]|0)|0)!=0){C=y;break b}A=c[q>>2]|0;G=YGb(D,E,-24,-1)|0;Vy(A,G,F)|0;G=yO(c[q>>2]|0,j)|0;if((G|0)<0){C=G;break b}else{y=G}}y=yO(c[q>>2]|0,j)|0;if((y|0)<0){C=y;break}G=sz(c[q>>2]|0)|0;A=F;E=rz(c[q>>2]|0)|0;D=rz(c[q>>2]|0)|0;H=b;yDb(H,48,2034344,(I=i,i=i+32|0,c[I>>2]=G,c[I+8>>2]=A,c[I+16>>2]=E,c[I+24>>2]=D,I)|0);i=I;if((D|0)>0){E=b+1248|0;J=v+158560|0;K=0;L=-1;M=-1;while(1){N=rz(c[q>>2]|0)|0;O=pz(c[q>>2]|0)|0;P=c[E>>2]|0;Q=c[E+4>>2]|0;R=gHb(c[o>>2]|0,0,N,(N|0)<0|0?-1:0)|0;S=YGb(R,F,P,Q)|0;Q=F;P=IDb(G,A,K,(K|0)<0|0?-1:0,1e4,0)|0;R=ZGb(P,F,c[J>>2]|0,0)|0;P=F;T=0;U=(P|0)>(T|0)|(P|0)==(T|0)&R>>>0>0>>>0;T=U?R:0;R=U?P:0;if((S|0)==(M|0)&(Q|0)==(L|0)){V=L;W=M}else{yDb(H,48,1989624,(I=i,i=i+32|0,c[I>>2]=N,c[I+8>>2]=O,c[I+16>>2]=T,c[I+24>>2]=R,I)|0);i=I;jT(c[(c[m>>2]|0)+(d<<2)>>2]|0,S,Q,T,R,c[o>>2]|0,0,1)|0;V=Q;W=S}S=K+1|0;if((S|0)<(D|0)){K=S;L=V;M=W}else{break}}}c[v+158504>>2]=(D|0)>1;C=y}}while(0);Ty(c[q>>2]|0,w,x,0)|0;if((C|0)<0){break}X=c[r>>2]|0;Y=29;break a}}while(0);c[r>>2]=-1}else{X=l;Y=29}}while(0);do{if((Y|0)==29){if((X|0)<=0){break}l=n+400|0;if((c[l>>2]|0)==0){break}r=oT(n,e,f,g)|0;if(!((r|0)>-1)){break}C=(c[l>>2]|0)+(r*24|0)|0;r=c[C>>2]|0;l=c[C+4>>2]|0;yDb(b,48,2085400,(I=i,i=i+16|0,c[I>>2]=r,c[I+8>>2]=l,I)|0);i=I;C=Ty(c[q>>2]|0,r,l,0)|0;l=F;r=0;if((l|0)<(r|0)|(l|0)==(r|0)&C>>>0<0>>>0){p=-1;i=h;return p|0}C=c[k>>2]|0;c[C+158472>>2]=0;r=C+520|0;TGb(C+158584|0,0,44)|0;TGb(C+158632|0,0,20)|0;l=0;do{BZ(r+(l*1216|0)+8|0);c[r+(l*1216|0)+92>>2]=0;c[r+(l*1216|0)+88>>2]=0;a[r+(l*1216|0)+4|0]=0;l=l+1|0;}while((l|0)<128);c[C+158668>>2]=0;l=c[k>>2]|0;r=l+4|0;W=l+520|0;l=0;while(1){V=c[r+(l<<2)>>2]|0;do{if((V|0)>=0){if((c[(c[(c[(c[m>>2]|0)+(V<<2)>>2]|0)+8>>2]|0)+8>>2]|0)!=0){break}c[W+(l*1216|0)+112>>2]=1}}while(0);V=l+1|0;if((V|0)<128){l=V}else{p=0;break}}i=h;return p|0}}while(0);if((pT(b,d,e,f,g)|0)<0){p=-1;i=h;return p|0}g=c[k>>2]|0;c[g+158472>>2]=0;f=g+520|0;TGb(g+158584|0,0,44)|0;TGb(g+158632|0,0,20)|0;e=0;do{BZ(f+(e*1216|0)+8|0);c[f+(e*1216|0)+92>>2]=0;c[f+(e*1216|0)+88>>2]=0;a[f+(e*1216|0)+4|0]=0;e=e+1|0;}while((e|0)<128);c[g+158668>>2]=0;g=c[k>>2]|0;k=g+4|0;e=g+520|0;g=0;while(1){f=c[k+(g<<2)>>2]|0;do{if((f|0)>=0){if((c[(c[(c[(c[m>>2]|0)+(f<<2)>>2]|0)+8>>2]|0)+8>>2]|0)!=0){break}c[e+(g*1216|0)+112>>2]=1}}while(0);f=g+1|0;if((f|0)<128){g=f}else{p=0;break}}i=h;return p|0}function Fx(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;i=i+1096|0;f=g|0;h=g+80|0;j=b+12|0;k=c[j>>2]|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[b+24>>2]|0;if((n|0)!=0){o=0;do{p=h+(o<<3)|0;c[p>>2]=l;c[p+4>>2]=m;o=o+1|0;}while(o>>>0<n>>>0)}n=c[b+1076>>2]|0;if((n|0)==0){q=m;r=l}else{o=n;n=0;p=b+1248|0;s=c[p>>2]|0;t=c[p+4>>2]|0;p=YGb(l,m,-1,-1)|0;m=YGb(p,F,o,n)|0;p=ZGb(m,F,s,t)|0;m=F;l=fHb(p,m,o,n)|0;n=ZGb(s,t,l,F)|0;l=YGb(n,F,p,m)|0;q=F;r=l}c[e>>2]=r;c[e+4>>2]=q;l=Ty(c[b+16>>2]|0,r,q,0)|0;q=F;r=0;if((q|0)<(r|0)|(q|0)==(r|0)&l>>>0<0>>>0){u=-2147483648;v=0;i=g;return(F=u,v)|0}kT(b);l=c[j>>2]|0;c[l+158472>>2]=0;j=l+520|0;TGb(l+158584|0,0,44)|0;TGb(l+158632|0,0,20)|0;r=0;do{BZ(j+(r*1216|0)+8|0);c[j+(r*1216|0)+92>>2]=0;c[j+(r*1216|0)+88>>2]=0;a[j+(r*1216|0)+4|0]=0;r=r+1|0;}while((r|0)<128);c[l+158668>>2]=0;a:do{if((gT(b,f)|0)>=0){l=f+16|0;r=f+36|0;j=f+32|0;q=b+28|0;m=k+520|0;p=f+28|0;while(1){w=c[l>>2]|0;x=c[l+4>>2]|0;BZ(f);if((c[r>>2]&1|0)!=0){n=c[j>>2]|0;t=c[(c[q>>2]|0)+(n<<2)>>2]|0;s=m+((c[t+4>>2]|0)*1216|0)+136|0;y=c[s>>2]|0;z=c[s+4>>2]|0;o=c[p>>2]|0;A=h+(n<<3)|0;n=c[A>>2]|0;B=c[A+4>>2]|0;C=YGb(y,z,1,0)|0;D=ZGb(C,F,n,B)|0;jT(t,y,z,w,x,o,D,1)|0;D=YGb(c[s>>2]|0,c[s+4>>2]|0,1,0)|0;c[A>>2]=D;c[A+4>>2]=F;if((c[j>>2]|0)==(d|0)){break}}if((gT(b,f)|0)<0){break a}}c[e>>2]=y;c[e+4>>2]=z;u=x;v=w;i=g;return(F=u,v)|0}}while(0);yDb(b,32,2154496,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;u=-2147483648;v=0;i=g;return(F=u,v)|0}function Gx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+1024|0;d=a+16|0;e=c[d>>2]|0;f=c[a+12>>2]|0;g=pz(e)|0;if((g|0)<=0){i=b;return}h=b|0;j=f+156680|0;f=0;do{pz(e)|0;k=pz(e)|0;l=pz(e)|0;m=pz(e)|0;n=rz(e)|0;o=yz(e,l,h,1024)|0;if((o|0)<(l|0)){p=l-o|0;Vy(e,p,(p|0)<0|0?-1:0)|0;}do{if((QGb(h,1990192)|0)==0){p=c[d>>2]|0;if((m|0)==4){o=sz(p)|0;q=o}else if((m|0)==2){q=pz(p)|0}else if((m|0)==3){q=rz(p)|0}else if((m|0)==5){q=pz(p)|0}else{q=-2147483648}if((k|0)>=128){break}c[j+(k<<3)>>2]=q}else{if((QGb(h,1986712)|0)!=0){Hx(a,h,m,n,16);break}p=c[d>>2]|0;if((m|0)==5){r=pz(p)|0}else if((m|0)==3){r=rz(p)|0}else if((m|0)==4){o=sz(p)|0;r=o}else if((m|0)==2){r=pz(p)|0}else{r=-2147483648}if((k|0)>=128){break}c[j+(k<<3)+4>>2]=r}}while(0);f=f+1|0;}while((f|0)<(g|0));i=b;return}function Hx(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;h=i;i=i+168|0;j=h|0;k=h+8|0;l=h+88|0;m=h+152|0;n=h+160|0;o=b+16|0;p=Ty(c[o>>2]|0,0,0,1)|0;q=F;if(f>>>0>2147483635>>>0){i=h;return}r=f<<1;s=WDb(r+22|0)|0;c[n>>2]=s;a:do{if((s|0)!=0){if((e|0)==(-1|0)){mz(c[o>>2]|0,s,f)|0;a[(c[n>>2]|0)+f|0]=0}else if((e|0)==0){yz(c[o>>2]|0,f,s,r|1)|0}else if((e|0)==1){if((QGb(d,2050976)|0)!=0){if((QGb(d,2041760)|0)!=0){yDb(b,40,2038160,(t=i,i=i+8|0,c[t>>2]=d,t)|0);i=t;break}c[j>>2]=0;yE(b,2041760,j);if((c[j>>2]|0)!=0){BE(b,j)|0}zE(j);break}u=k;v=l|0;w=m;TGb(u|0,0,80)|0;c[m>>2]=0;if((f|0)<9){yDb(b,16,2023304,(t=i,i=i+8|0,c[t>>2]=f,t)|0);i=t;break}x=lz(c[o>>2]|0)|0;if(x>>>0>20>>>0|(x|0)<0){yDb(b,24,2020072,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;y=0}else{y=x}x=rz(c[o>>2]|0)|0;z=f-5|0;A=z-(yz(c[o>>2]|0,z,v,64)|0)|0;z=1204600;while(1){B=c[z+32>>2]|0;if((B|0)==0){C=14;break}if((RGb(z|0,v,64)|0)==0){break}else{z=z+36|0}}if((C|0)==14){yDb(b,16,2016120,(t=i,i=i+8|0,c[t>>2]=v,t)|0);i=t;break}if((x|0)>=(A|0)){yDb(b,16,2012376,(t=i,i=i+16|0,c[t>>2]=x,c[t+8>>2]=A,t)|0);i=t;break}z=A-x|0;D=z<<1|1;E=WDb(D)|0;c[m>>2]=E;if((E|0)==0){break}yz(c[o>>2]|0,z,E,D)|0;do{if((TS(c[o>>2]|0,k,x)|0)>=0){D=LT(b,0)|0;if((D|0)==0){break}E=D+72|0;c[E>>2]=c[E>>2]|1024;E=c[D+8>>2]|0;c[E+8>>2]=0;c[E+48>>2]=B;UGb(D+104|0,u|0,80)|0;c[D+136>>2]=c[D>>2];E=D+140|0;c[E>>2]=c[E>>2]|1;E=c[m>>2]|0;if((a[E]|0)==0){$Db(w);G=D+88|0}else{z=D+88|0;CBb(z,2005448,E,8)|0;G=z}CBb(G,1997008,c[1204512+(y<<2)>>2]|0,0)|0;break a}}while(0);$Db(w);BZ(k);break}else{if(!((e-2|0)>>>0<4>>>0)){u=b;if((e|0)==6){yDb(u,48,2030864,(t=i,i=i+8|0,c[t>>2]=d,t)|0);i=t;break}else{yDb(u,48,2026808,(t=i,i=i+16|0,c[t>>2]=e,c[t+8>>2]=d,t)|0);i=t;break}}u=c[o>>2]|0;do{if((e|0)==3){H=rz(u)|0}else if((e|0)==4){x=sz(u)|0;H=x}else if((e|0)==5){H=pz(u)|0}else if((e|0)==2){if((g|0)==32){H=rz(u)|0;break}else{H=pz(u)|0;break}}else{H=-2147483648}}while(0);Lb(c[n>>2]|0,22,2035e3,(t=i,i=i+16|0,c[t>>2]=H,c[t+8>>2]=(H|0)<0|0?-1:0,t)|0)|0;i=t}u=c[n>>2]|0;if((a[u]|0)==0){break}CBb(b+1140|0,d,u,0)|0}}while(0);$Db(n);n=c[o>>2]|0;o=YGb(p,q,f,(f|0)<0|0?-1:0)|0;Ty(n,o,F,0)|0;i=h;return}function Ix(a){a=a|0;var d=0,e=0,f=0,g=0;d=c[a+12>>2]|0;e=a+1076|0;c[e>>2]=3200;f=d+155656|0;c[f>>2]=0;c[f+4>>2]=0;c[d+159040>>2]=WDb(12288)|0;c[d+159044>>2]=512;b[d+159048>>1]=0;if((Ox(a,0,0,50,0)|0)<0){g=-1;return g|0}Sy(c[a+16>>2]|0);c[d+155696>>2]=0;TGb(d+155680|0,-1|0,16)|0;Ny(d+158904|0,d+155700|0,c[e>>2]|0,1,0,0,0,0)|0;e=a+1204|0;if((c[e>>2]|0)>=0){g=0;return g|0}c[e>>2]=1;g=0;return g|0}function Jx(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;g=b+12|0;h=c[g>>2]|0;j=c[e+36>>2]|0;k=Ty(c[b+16>>2]|0,0,0,1)|0;l=F;m=c[e+32>>2]|0;n=(c[(c[b+28>>2]|0)+(m<<2)>>2]|0)+8|0;o=h+8|0;p=(c[(c[n>>2]|0)+8>>2]|0)==1?j&-2:j;j=e+8|0;q=c[j>>2]|0;r=c[j+4>>2]|0;j=e+16|0;do{if((q|0)==0&(r|0)==(-2147483648|0)){s=c[j>>2]|0;t=c[j+4>>2]|0;if(!((s|0)==0&(t|0)==(-2147483648|0))){u=t;v=s;break}yDb(0,0,2281768,(s=i,i=i+24|0,c[s>>2]=2214824,c[s+8>>2]=2251272,c[s+16>>2]=886,s)|0);i=s;Cd();return 0}else{u=r;v=q}}while(0);q=gHb(v,u,1e4,0)|0;u=F;v=h+155664|0;r=c[v>>2]|0;s=c[v+4>>2]|0;t=(c[e+48>>2]|0)*1e4|0;w=YGb(t,(t|0)<0|0?-1:0,q,u)|0;t=F;x=(s|0)>(t|0)|(s|0)==(t|0)&r>>>0>w>>>0;c[v>>2]=x?r:w;c[v+4>>2]=x?s:t;t=h+155656|0;s=c[t>>2]|0;x=c[t+4>>2]|0;v=s;w=c[j>>2]|0;r=c[j+4>>2]|0;j=c[e+28>>2]|0;y=c[g>>2]|0;if((j|0)>0){z=c[e+24>>2]|0;e=y+155680|0;A=y+155676|0;B=y+155672|0;C=YGb(w,r,3100,0)|0;D=o+(m*1216|0)|0;E=(p&1|0)==0;G=o+(m*1216|0)+4|0;H=C;C=y+158904|0;I=y+155688|0;J=y+155696|0;y=z;z=0;while(1){K=j-z|0;a:do{if((c[e>>2]|0)==(-1|0)&(c[e+4>>2]|0)==(-1|0)){L=11}else{while(1){M=c[A>>2]|0;N=M-29|0;if((N|0)>=(K|0)){break}if((c[(c[n>>2]|0)+8>>2]|0)!=1){break}Mx(b);if((c[e>>2]|0)==(-1|0)&(c[e+4>>2]|0)==(-1|0)){L=11;break a}}if((N|0)>0){O=N;L=14;break}P=0;Q=M;R=a[B]|0}}while(0);if((L|0)==11){L=0;S=(K|0)<3154;a[B]=S&1;c[A>>2]=3200;c[e>>2]=w;c[e+4>>2]=r;O=S?3153:3174;L=14}if((L|0)==14){L=0;if((K|0)>(O|0)){T=O}else{T=(K|0)==(O-1|0)?O-2|0:K}S=c[g>>2]|0;U=S+158904|0;V=c[D>>2]|0;Py(U,E?V:V|128);Py(U,d[G]|0);Yy(U,z);Py(U,8);Yy(U,j);Yy(U,H);if((a[S+155672|0]|0)!=0){az(U,T)}Ry(C,y,T);U=a[B]|0;S=(U<<24>>24==0?-15:-17)-T+(c[A>>2]|0)|0;c[A>>2]=S;c[I>>2]=w;c[I+4>>2]=r;c[J>>2]=(c[J>>2]|0)+1;P=T;Q=S;R=U}U=P+z|0;S=y+P|0;do{if(R<<24>>24==0){Mx(b)}else{if((Q|0)>=30){break}Mx(b)}}while(0);if((U|0)<(j|0)){y=S;z=U}else{W=G;break}}}else{W=o+(m*1216|0)+4|0}a[W]=(a[W]|0)+1;W=YGb(q,u,40999999,0)|0;u=eHb(W,F,1e7,0)|0;W=u;do{if((c[h+4>>2]|0)==0){if((p&1|0)==0){break}u=ZGb(c[t>>2]|0,c[t+4>>2]|0,s,x)|0;q=Nx(c[g>>2]|0,W,v,u&65535,k,l)|0;if((q|0)<0){X=q}else{break}i=f;return X|0}}while(0);c[h+159076>>2]=W;X=0;i=f;return X|0}function Kx(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a+12|0;f=c[d>>2]|0;if((c[f+158916>>2]|0)>>>0>(c[f+158908>>2]|0)>>>0){Mx(a)}g=a+16|0;h=Ty(c[g>>2]|0,0,0,1)|0;i=F;j=f+4|0;do{if((c[j>>2]|0)==0){k=f+159072|0;if((c[k>>2]|0)==0){break}l=Nx(c[d>>2]|0,(c[f+159076>>2]|0)+1|0,0,0,0,0)|0;if((l|0)<0){m=l;return m|0}l=c[f+159040>>2]|0;n=b[f+159048>>1]|0;o=c[k>>2]|0;k=c[g>>2]|0;HO(k,1262960);dz(k,(o*6|0)+56|0,0);HO(k,7959480);dz(k,1e7,0);Yy(k,n&65535);Yy(k,o);if((o|0)==0){break}else{p=0}do{Yy(k,c[l+(p*24|0)>>2]|0);az(k,e[l+(p*24|0)+4>>1]|0);p=p+1|0;}while(p>>>0<o>>>0)}}while(0);Sy(c[g>>2]|0);p=c[g>>2]|0;do{if((c[j>>2]|0)==0){if((c[p+88>>2]|0)==0){q=10;break}o=Ty(p,0,0,1)|0;l=F;Ty(c[g>>2]|0,0,0,0)|0;k=f+159032|0;n=ZGb(h,i,c[k>>2]|0,c[k+4>>2]|0)|0;Ox(a,o,l,n,F)|0}else{q=10}}while(0);if((q|0)==10){q=c[d>>2]|0;az(p,17700);az(p,8);d=q;Yy(p,c[d>>2]|0);az(p,0);az(p,8);c[d>>2]=(c[d>>2]|0)+1}$Db(f+159040|0);m=0;return m|0}function Lx(a){a=a|0;var d=0,e=0,f=0,g=0;d=c[a+12>>2]|0;c[d+4>>2]=1;e=a+1076|0;c[e>>2]=3200;f=d+155656|0;c[f>>2]=0;c[f+4>>2]=0;c[d+159040>>2]=WDb(12288)|0;c[d+159044>>2]=512;b[d+159048>>1]=0;if((Ox(a,0,0,50,0)|0)<0){g=-1;return g|0}Sy(c[a+16>>2]|0);c[d+155696>>2]=0;TGb(d+155680|0,-1|0,16)|0;Ny(d+158904|0,d+155700|0,c[e>>2]|0,1,0,0,0,0)|0;e=a+1204|0;if((c[e>>2]|0)>=0){g=0;return g|0}c[e>>2]=1;g=0;return g|0}function Mx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=b+12|0;f=c[e>>2]|0;g=f+155688|0;h=c[g>>2]|0;j=c[g+4>>2]|0;k=f+155680|0;l=k;m=c[l>>2]|0;n=c[l+4>>2]|0;if((j|0)<(n|0)|(j|0)==(n|0)&h>>>0<m>>>0){yDb(0,0,2281768,(o=i,i=i+24|0,c[o>>2]=2266416,c[o+8>>2]=2251272,c[o+16>>2]=704,o)|0);i=o;Cd()}if((c[f+4>>2]|0)==0){p=n;q=m;r=j;s=h;t=f;u=b+16|0}else{h=b+16|0;j=c[h>>2]|0;m=(c[b+1076>>2]|0)+8|0;az(j,17444);az(j,m);n=f;Yy(j,c[n>>2]|0);az(j,0);az(j,m);c[n>>2]=(c[n>>2]|0)+1;p=c[l+4>>2]|0;q=c[l>>2]|0;r=c[g+4>>2]|0;s=c[g>>2]|0;t=c[e>>2]|0;u=h}h=q;e=ZGb(s,r,q,p)|0;p=e;e=f+155696|0;q=c[e>>2]|0;r=f+155676|0;s=c[r>>2]|0;g=c[u>>2]|0;l=Ty(g,0,0,1)|0;n=F;m=t+155672|0;t=((a[m]|0)==0?-11:-12)+s|0;if(!((t|0)>-1)){yDb(0,0,2281768,(o=i,i=i+24|0,c[o>>2]=2225064,c[o+8>>2]=2251272,c[o+16>>2]=665,o)|0);i=o;Cd()}Py(g,130);Py(g,0);Py(g,0);s=(a[m]|0)!=0|0;do{if((t|0)>0){if((t|0)<256){v=s|8;break}else{v=s|16;break}}else{v=s}}while(0);Py(g,v);Py(g,93);if((v&16|0)!=0){az(g,t-2|0)}if((v&8|0)!=0){Py(g,t-1|0)}Yy(g,h);az(g,p);if((a[m]|0)!=0){Py(g,q|128)}q=Ty(g,0,0,1)|0;g=ZGb(q,F,l,n)|0;n=g;g=c[r>>2]|0;if((n|0)>(g|0)){yDb(0,0,2281768,(o=i,i=i+24|0,c[o>>2]=2237568,c[o+8>>2]=2251272,c[o+16>>2]=716,o)|0);i=o;Cd()}else{o=f+155700|0;TGb(f+(158900-g)|0,0,g|0)|0;g=b+1076|0;Ry(c[u>>2]|0,o,(c[g>>2]|0)-n|0);Sy(c[u>>2]|0);u=f+155656|0;n=YGb(c[u>>2]|0,c[u+4>>2]|0,1,0)|0;c[u>>2]=n;c[u+4>>2]=F;c[e>>2]=0;TGb(k|0,-1|0,16)|0;Ny(f+158904|0,o,c[g>>2]|0,1,0,0,0,0)|0;i=d;return}}function Nx(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=a+159072|0;j=c[i>>2]|0;do{if((j|0)<(d|0)){if((j|0)==0){c[a+159052>>2]=e;b[a+159056>>1]=f;k=a+159064|0;c[k>>2]=g;c[k+4>>2]=h}k=a+159044|0;do{if((c[k>>2]|0)>>>0<d>>>0){l=d+512&-512;c[k>>2]=l;m=bEb(a+159040|0,l,24)|0;if((m|0)>=0){n=c[i>>2]|0;break}c[k>>2]=0;o=m;return o|0}else{n=j}}while(0);if((n|0)>=(d|0)){break}k=a+159052|0;m=c[a+159040>>2]|0;l=a+159056|0;p=a+159064|0;q=n;do{c[m+(q*24|0)>>2]=c[k>>2];b[m+(q*24|0)+4>>1]=b[l>>1]|0;r=c[i>>2]|0;s=gHb(r,(r|0)<0|0?-1:0,1e7,0)|0;r=m+(q*24|0)+8|0;c[r>>2]=s;c[r+4>>2]=F;r=c[p+4>>2]|0;s=m+(q*24|0)+16|0;c[s>>2]=c[p>>2];c[s+4>>2]=r;q=q+1|0;}while((q|0)<(d|0))}}while(0);n=a+159048|0;j=b[n>>1]|0;b[n>>1]=(j&65535)>>>0>(f&65535)>>>0?j:f;c[a+159052>>2]=e;b[a+159056>>1]=f;f=a+159064|0;c[f>>2]=g;c[f+4>>2]=h;c[i>>2]=d;o=0;return o|0}function Ox(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;h=i;i=i+80|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;r=h+64|0;s=h+72|0;t=b+12|0;u=c[t>>2]|0;v=b+16|0;w=c[v>>2]|0;x=b+1140|0;QG(x,1263112,0);y=BBb(c[x>>2]|0,1955912,0,0)|0;z=BBb(c[x>>2]|0,1928712,0,0)|0;A=BBb(c[x>>2]|0,1906672,0,0)|0;B=BBb(c[x>>2]|0,1885960,0,0)|0;C=BBb(c[x>>2]|0,2343832,0,0)|0;D=u+155664|0;E=YGb(c[D>>2]|0,c[D+4>>2]|0,31e6,0)|0;G=F;H=(y|0)==0;if(H&(z|0)==0&(A|0)==0){I=(C|0)!=0|(B|0)!=0}else{I=1}J=ABb(c[x>>2]|0)|0;K=b+24|0;if((c[K>>2]|0)==0){L=0}else{M=b+28|0;N=0;O=0;while(1){P=c[(c[M>>2]|0)+(O<<2)>>2]|0;Q=c[P+8>>2]|0;MT(P,32,1,1e3);P=(c[Q+72>>2]|0)+N|0;Q=O+1|0;if(Q>>>0<(c[K>>2]|0)>>>0){N=P;O=Q}else{L=P;break}}}O=u+4|0;if((c[O>>2]|0)!=0){N=c[t>>2]|0;M=c[v>>2]|0;az(M,18468);az(M,8);P=N;Yy(M,c[P>>2]|0);az(M,3072);az(M,8);c[P>>2]=(c[P>>2]|0)+1}HO(w,1263296);dz(w,-1,-1);P=(J|0)!=0;Yy(w,(P&1)+(I?4:3)+(c[K>>2]|0)|0);Py(w,1);Py(w,2);M=Ty(w,0,0,1)|0;N=F;Q=Ty(w,0,0,1)|0;R=F;HO(w,1263344);dz(w,24,0);HO(w,7959480);dz(w,d,e);dz(w,-717324288,27111902);e=u+155656|0;dz(w,c[e>>2]|0,c[e+4>>2]|0);dz(w,E,G);dz(w,c[D>>2]|0,c[D+4>>2]|0);dz(w,3100,0);if((c[O>>2]|0)==0){S=(c[w+88>>2]|0)==0?3:2}else{S=3}Yy(w,S);S=b+1076|0;Yy(w,c[S>>2]|0);Yy(w,c[S>>2]|0);Yy(w,L);L=Ty(w,0,0,1)|0;S=F;D=YGb(Q,R,16,0)|0;Ty(w,D,F,0)|0;D=ZGb(L,S,Q,R)|0;dz(w,D,F);Ty(w,L,S,0)|0;S=Ty(w,0,0,1)|0;L=F;HO(w,1263328);dz(w,24,0);HO(w,1263312);Yy(w,6);az(w,0);D=Ty(w,0,0,1)|0;R=F;Q=YGb(S,L,16,0)|0;Ty(w,Q,F,0)|0;Q=ZGb(D,R,S,L)|0;dz(w,Q,F);Ty(w,D,R,0)|0;if(I){if((Mz(q)|0)<0){T=-12;i=h;return T|0}I=Ty(w,0,0,1)|0;R=F;HO(w,1263568);dz(w,24,0);if(H){U=0}else{U=$y(c[q>>2]|0,c[y+4>>2]|0)|0}az(w,U);if((z|0)==0){V=0}else{V=$y(c[q>>2]|0,c[z+4>>2]|0)|0}az(w,V);if((A|0)==0){W=0}else{W=$y(c[q>>2]|0,c[A+4>>2]|0)|0}az(w,W);if((B|0)==0){X=0}else{X=$y(c[q>>2]|0,c[B+4>>2]|0)|0}az(w,X);if((C|0)==0){Y=0}else{Y=$y(c[q>>2]|0,c[C+4>>2]|0)|0}az(w,Y);Y=Oz(c[q>>2]|0,p)|0;Ry(w,c[p>>2]|0,Y);$Db(p);p=Ty(w,0,0,1)|0;Y=F;q=YGb(I,R,16,0)|0;Ty(w,q,F,0)|0;q=ZGb(p,Y,I,R)|0;dz(w,q,F);Ty(w,p,Y,0)|0;}if(P){P=Ty(w,0,0,1)|0;Y=F;HO(w,1263360);dz(w,24,0);az(w,J);J=BBb(c[x>>2]|0,9203616,0,2)|0;if((J|0)!=0){p=n;q=l;R=J;do{J=c[R>>2]|0;if((Mz(o)|0)>=0){$y(c[o>>2]|0,J)|0;J=Oz(c[o>>2]|0,n)|0;az(w,J);Ry(w,c[n>>2]|0,J);$Db(p)}az(w,0);J=c[R+4>>2]|0;if((Mz(m)|0)>=0){$y(c[m>>2]|0,J)|0;J=Oz(c[m>>2]|0,l)|0;az(w,J);Ry(w,c[l>>2]|0,J);$Db(q)}R=BBb(c[x>>2]|0,9203616,R,2)|0;}while((R|0)!=0)}R=Ty(w,0,0,1)|0;x=F;q=YGb(P,Y,16,0)|0;Ty(w,q,F,0)|0;q=ZGb(R,x,P,Y)|0;dz(w,q,F);Ty(w,R,x,0)|0;}do{if((c[O>>2]|0)==0){x=b+1132|0;if((c[x>>2]|0)==0){break}R=j;q=c[t>>2]|0;Y=c[v>>2]|0;P=Ty(Y,0,0,1)|0;l=F;HO(Y,1263248);dz(Y,24,0);HO(Y,1262976);Yy(Y,c[x>>2]|0);az(Y,0);az(Y,0);a:do{if((c[x>>2]|0)!=0){m=b+1136|0;p=q+159032|0;n=q+159072|0;o=q+159040|0;J=0;while(1){I=c[(c[m>>2]|0)+(J<<2)>>2]|0;C=BBb(c[I+32>>2]|0,1955912,0,0)|0;X=I+16|0;B=KDb(c[X>>2]|0,c[X+4>>2]|0,I+4|0,1790688)|0;I=F;X=YGb(c[p>>2]|0,c[p+4>>2]|0,50,0)|0;W=F;A=c[n>>2]|0;b:do{if((A|0)>0){V=c[o>>2]|0;z=0;U=0;y=W;H=X;while(1){D=V+(z*24|0)+8|0;Q=c[D>>2]|0;L=c[D+4>>2]|0;if(!(L>>>0<I>>>0|L>>>0==I>>>0&Q>>>0<B>>>0)){Z=U;_=y;$=H;break b}L=V+(z*24|0)+16|0;D=c[L>>2]|0;S=c[L+4>>2]|0;L=z+1|0;G=(Q|0)/1e4|0;if((L|0)<(A|0)){z=L;U=G;y=S;H=D}else{Z=G;_=S;$=D;break}}}else{Z=0;_=W;$=X}}while(0);X=(C|0)!=0;if(X){if((Mz(k)|0)<0){T=-12;break}$y(c[k>>2]|0,c[C+4>>2]|0)|0;aa=Oz(c[k>>2]|0,j)|0}else{aa=0}dz(Y,$,_);W=YGb(B,I,31e6,0)|0;dz(Y,W,F);az(Y,aa+12|0);Yy(Y,Z);Yy(Y,0);Yy(Y,(aa|0)/2|0);if(X){Ry(Y,c[j>>2]|0,aa);$Db(R)}J=J+1|0;if(!(J>>>0<(c[x>>2]|0)>>>0)){break a}}i=h;return T|0}}while(0);x=Ty(Y,0,0,1)|0;R=F;q=YGb(P,l,16,0)|0;Ty(Y,q,F,0)|0;q=ZGb(x,R,P,l)|0;dz(Y,q,F);Ty(Y,x,R,0)|0;}}while(0);aa=b+28|0;c:do{if((c[K>>2]|0)!=0){b=u+8|0;j=0;while(1){Z=c[(c[(c[aa>>2]|0)+(j<<2)>>2]|0)+8>>2]|0;_=j+1|0;c[b+(j*1216|0)>>2]=_;a[b+(j*1216|0)+4|0]=1;$=Z+8|0;if((c[$>>2]|0)==1){ba=18;ca=8}else{ba=(c[Z+100>>2]|0)+51|0;ca=0}k=Ty(w,0,0,1)|0;v=F;HO(w,1262944);dz(w,24,0);if((c[$>>2]|0)==1){HO(w,1263632);HO(w,1263648)}else{HO(w,1262824);HO(w,1262840)}dz(w,0,0);t=Ty(w,0,0,1)|0;R=F;Yy(w,ba);Yy(w,ca);az(w,_);Yy(w,0);if((c[$>>2]|0)==1){$=GO(w,Z)|0;if(($|0)<0){T=-1;break}if(($|0)!=(ba|0)){x=Ty(w,0,0,1)|0;q=F;Ty(w,t,R,0)|0;Yy(w,$);Ty(w,x,q,0)|0;}Py(w,1);do{if((c[Z+48>>2]|0)==69643){da=52}else{q=Z+432|0;x=c[q>>2]|0;if((x|0)==0){da=52;break}az(w,x);az(w,c[q>>2]|0)}}while(0);if((da|0)==52){da=0;az(w,400);az(w,400)}az(w,1);Py(w,0)}else{Yy(w,c[Z+120>>2]|0);Yy(w,c[Z+124>>2]|0);Py(w,2);az(w,(c[Z+100>>2]|0)+40|0);JO(w,Z,1240808,1,0)}q=Ty(w,0,0,1)|0;x=F;$=YGb(k,v,16,0)|0;Ty(w,$,F,0)|0;$=ZGb(q,x,k,v)|0;dz(w,$,F);Ty(w,q,x,0)|0;if(_>>>0<(c[K>>2]|0)>>>0){j=_}else{break c}}i=h;return T|0}}while(0);ba=Ty(w,0,0,1)|0;ca=F;HO(w,1263600);dz(w,24,0);HO(w,1263616);Yy(w,c[K>>2]|0);j=r;b=0;while(1){if(!(b>>>0<(c[K>>2]|0)>>>0)){da=72;break}Y=c[(c[(c[aa>>2]|0)+(b<<2)>>2]|0)+8>>2]|0;l=Y+48|0;P=p0a(c[l>>2]|0)|0;x=Y+8|0;q=c[x>>2]|0;if((q|0)==1){az(w,2)}else if((q|0)==0){az(w,1)}else{az(w,-1)}do{if((c[l>>2]|0)==86024){ea=2299264}else{if((P|0)==0){ea=Y+16|0;break}else{ea=c[P>>2]|0;break}}}while(0);if((Mz(s)|0)<0){T=-12;da=75;break}$y(c[s>>2]|0,ea)|0;P=Oz(c[s>>2]|0,r)|0;az(w,(P|0)/2|0);Ry(w,c[r>>2]|0,P);$Db(j);az(w,0);if((c[x>>2]|0)==1){az(w,2);az(w,c[Y+52>>2]|0)}else{az(w,4);Yy(w,c[Y+52>>2]|0)}if((c[Y+52>>2]|0)==0){T=-1;da=75;break}else{b=b+1|0}}if((da|0)==72){b=Ty(w,0,0,1)|0;j=F;r=YGb(ba,ca,16,0)|0;Ty(w,r,F,0)|0;r=ZGb(b,j,ba,ca)|0;dz(w,r,F);Ty(w,b,j,0)|0;j=Ty(w,0,0,1)|0;b=F;r=ZGb(j,b,M,N)|0;ca=r;if((c[O>>2]|0)!=0){O=ca+88|0;r=YGb(M,N,-40,-1)|0;Ty(w,r,F,0)|0;az(w,O);r=YGb(M,N,-32,-1)|0;Ty(w,r,F,0)|0;az(w,O)}O=ca+30|0;ca=YGb(M,N,-14,-1)|0;Ty(w,ca,F,0)|0;dz(w,O,(O|0)<0|0?-1:0);Ty(w,j,b,0)|0;O=u+159032|0;c[O>>2]=j;c[O+4>>2]=b;HO(w,1263536);dz(w,f,g);HO(w,7959480);dz(w,c[e>>2]|0,c[e+4>>2]|0);Py(w,1);Py(w,1);T=0;i=h;return T|0}else if((da|0)==75){i=h;return T|0}return 0}function Px(a){a=a|0;var b=0;b=c[a+4>>2]|0;if((PGb(b,1989400,13)|0)==0){return 100}else{a=(PGb(b+3|0,1989400,13)|0)==0;return(a?100:0)|0}return 0}function Qx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+2112|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+1088|0;p=c[b+12>>2]|0;q=LT(b,0)|0;if((q|0)==0){r=-12;i=d;return r|0}MT(q,64,1,100);s=q+8|0;q=c[s>>2]|0;c[q+8>>2]=3;c[q+48>>2]=94212;IAb(n,0,-1);IAb(o,0,-1);q=b+16|0;b=o|0;t=p;p=o+4|0;u=2147483647;a:while(1){v=c[q>>2]|0;w=Ty(v,0,0,1)|0;x=F;PAb(o);do{y=(lz(v)|0)&255;if(y<<24>>24==0){break}MAb(o,y,1);}while(!(y<<24>>24==10));v=c[b>>2]|0;y=a[v]|0;if(y<<24>>24==0){break}do{if((PGb(v,2154080,8)|0)==0){z=2}else{A=y<<24>>24==91?2147483647:u;if((A|0)!=0){z=A;break}A=xd(v|0,2034120,(B=i,i=i+64|0,c[B>>2]=e,c[B+8>>2]=f,c[B+16>>2]=g,c[B+24>>2]=h,c[B+32>>2]=j,c[B+40>>2]=k,c[B+48>>2]=l,c[B+56>>2]=m,B)|0)|0;i=B;if((A|0)==8){A=c[j>>2]|0;C=gHb(A,(A|0)<0|0?-1:0,3600,0)|0;A=F;D=c[k>>2]|0;E=gHb(D,(D|0)<0|0?-1:0,60,0)|0;D=YGb(E,F,C,A)|0;A=c[l>>2]|0;C=YGb(D,F,A,(A|0)<0|0?-1:0)|0;A=gHb(C,F,100,0)|0;C=YGb(A,F,c[m>>2]|0,0)|0;A=F;D=c[e>>2]|0;E=gHb(D,(D|0)<0|0?-1:0,3600,0)|0;D=F;G=c[f>>2]|0;H=gHb(G,(G|0)<0|0?-1:0,60,0)|0;G=YGb(H,F,E,D)|0;D=c[g>>2]|0;E=YGb(G,F,D,(D|0)<0|0?-1:0)|0;D=gHb(E,F,100,0)|0;E=c[h>>2]|0;G=YGb(D,F,E,(E|0)<0|0?-1:0)|0;E=F;D=ZGb(C,A,G,E)|0;I=0;J=D;K=E;L=G}else{I=1;J=-1;K=-2147483648;L=0}if(I){u=0;continue a}G=uR(t,c[b>>2]|0,c[p>>2]|0,0)|0;if((G|0)==0){r=-12;M=17;break a}E=G+64|0;c[E>>2]=w;c[E+4>>2]=x;E=G+8|0;c[E>>2]=L;c[E+4>>2]=K;c[G+48>>2]=J;u=0;continue a}}while(0);KAb(n,2085056,(B=i,i=i+8|0,c[B>>2]=v,B)|0);i=B;u=z-1|0}if((M|0)==17){i=d;return r|0}QAb(o,0)|0;o=e1a(c[s>>2]|0,n)|0;if((o|0)<0){r=o;i=d;return r|0}vR(t);r=o;i=d;return r|0}function Rx(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function Sx(a){a=a|0;AR(c[a+12>>2]|0);return 0}function Tx(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function Ux(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;d=c[a+12>>2]|0;e=c[c[a+28>>2]>>2]|0;f=c[e+8>>2]|0;do{if((c[a+24>>2]|0)==1){g=c[f+48>>2]|0;if(!((g|0)==94212|(g|0)==1095979808)){break}c[d+4>>2]=(g|0)==1095979808;MT(e,64,1,100);g=d;h=c[g>>2]|0;j=f+100|0;k=c[j>>2]|0;a:do{if(h>>>0<k>>>0){l=f+96|0;m=a+16|0;n=0;o=h;p=k;while(1){q=c[l>>2]|0;r=q+o|0;s=Vb(r|0,10)|0;if((s|0)==0){t=q+p|0}else{t=s+1|0}s=t-r|0;Ry(c[m>>2]|0,r,s);q=(c[g>>2]|0)+s|0;c[g>>2]=q;if((n|0)!=0){if((PGb(n,1928648,8)|0)==0){u=m;break a}}s=c[j>>2]|0;if(q>>>0<s>>>0){n=r;o=q;p=s}else{u=m;break}}}else{u=a+16|0}}while(0);Sy(c[u>>2]|0);v=0;i=b;return v|0}}while(0);yDb(a,16,1955856,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;v=-1;i=b;return v|0}function Vx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+8|0;f=e|0;if((c[(c[b+12>>2]|0)+4>>2]|0)==0){Ry(c[b+16>>2]|0,c[d+24>>2]|0,c[d+28>>2]|0);i=e;return 0}g=d+8|0;h=c[g>>2]|0;j=c[g+4>>2]|0;g=c[d+48>>2]|0;k=YGb(g,(g|0)<0|0?-1:0,h,j)|0;g=F;l=c[d+24>>2]|0;d=l+((hc(l|0,2034104)|0)+1)|0;c[f>>2]=d;l=kb(d|0,f|0,10)|0;d=c[f>>2]|0;if((a[d]|0)==44){m=d+1|0;c[f>>2]=m;n=m}else{n=d}d=eHb(h,j,36e4,0)|0;m=d;d=eHb(h,j,6e3,0)|0;f=eHb(k,g,36e4,0)|0;o=f;f=eHb(k,g,6e3,0)|0;p=eHb(h,j,100,0)|0;q=fHb(h,j,100,0)|0;j=eHb(k,g,100,0)|0;h=fHb(k,g,100,0)|0;g=(m|0)>9;k=(o|0)>9;Kz(c[b+16>>2]|0,1989296,(b=i,i=i+80|0,c[b>>2]=l,c[b+8>>2]=g?9:m,c[b+16>>2]=g?59:(d|0)%60|0,c[b+24>>2]=g?59:(p|0)%60|0,c[b+32>>2]=g?99:q,c[b+40>>2]=k?9:o,c[b+48>>2]=k?59:(f|0)%60|0,c[b+56>>2]=k?59:(j|0)%60|0,c[b+64>>2]=k?99:h,c[b+72>>2]=n,b)|0)|0;i=b;i=e;return 0}function Wx(a){a=a|0;var b=0,d=0;b=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;d=c[c[a+12>>2]>>2]|0;Ry(c[a+16>>2]|0,(c[b+96>>2]|0)+d|0,(c[b+100>>2]|0)-d|0);return 0}function Xx(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1297241171){e=0;return e|0}a=b+10|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){e=12;return e|0}a=b+12|0;f=(d[a]|d[a+1|0]<<8)<<16>>16;if(f<<16>>16==0|((de(f|0)|0)&65535)>>>0>256>>>0){e=12;return e|0}else{e=b+16|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=(b|0)==0|(fe(b|0)|0)>>>0>384e3>>>0;return(e?12:66)|0}return 0}function Yx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=LT(a,0)|0;if((d|0)==0){e=-12;i=b;return e|0}f=a+16|0;Vy(c[f>>2]|0,8,0)|0;g=d+8|0;c[(c[g>>2]|0)+8>>2]=1;h=vT(1243248,tz(c[f>>2]|0)|0)|0;c[(c[g>>2]|0)+48>>2]=h;h=tz(c[f>>2]|0)|0;if((h|0)!=16){DDb(a,2084944,(a=i,i=i+8|0,c[a>>2]=h,a)|0);i=a;e=-1094995529;i=b;return e|0}a=tz(c[f>>2]|0)|0;h=c[g>>2]|0;c[h+416>>2]=a;if((a|0)==4){j=h+448|0;c[j>>2]=263;c[j+4>>2]=0}else if((a|0)==2){j=h+448|0;c[j>>2]=3;c[j+4>>2]=0}else if((a|0)==0){e=-1094995529;i=b;return e|0}Vy(c[f>>2]|0,2,0)|0;a=vz(c[f>>2]|0)|0;c[(c[g>>2]|0)+412>>2]=a;if((a|0)<1){e=-1094995529;i=b;return e|0}a=d+48|0;c[a>>2]=0;c[a+4>>2]=0;a=d+56|0;c[a>>2]=vz(c[f>>2]|0)|0;c[a+4>>2]=0;Vy(c[f>>2]|0,40,0)|0;MT(d,64,1,c[(c[g>>2]|0)+412>>2]|0);e=0;i=b;return e|0}function Zx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=a+16|0;if((Xy(c[e>>2]|0)|0)!=0){f=-541478725;i=d;return f|0}g=Ty(c[e>>2]|0,0,0,1)|0;h=F;j=rz(c[e>>2]|0)|0;k=vz(c[e>>2]|0)|0;l=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+416>>2]|0;if(k>>>0>(2147483647/(l|0)|0)>>>0){f=-1094995529;i=d;return f|0}m=ba(l,k)|0;k=Vy(c[e>>2]|0,24,0)|0;l=k;if((l|0)<0){f=l;i=d;return f|0}if((j|0)==1262701634){l=TS(c[e>>2]|0,b,m)|0;c[b+32>>2]=0;k=b+64|0;c[k>>2]=g;c[k+4>>2]=h;f=l;i=d;return f|0}else{yDb(a,16,2153984,(a=i,i=i+8|0,c[a>>2]=j,a)|0);i=a;Vy(c[e>>2]|0,m,0)|0;f=-1094995529;i=d;return f|0}return 0}function _x(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((c[a+24>>2]|0)!=1){yDb(a,16,1955784,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}h=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;j=c[h+48>>2]|0;if((j|0)==1095123744){yDb(a,16,1928608,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1163346256;i=b;return g|0}k=uT(1243248,j)|0;if((k|0)==0){yDb(a,16,1906552,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}j=d+32|0;l=c[j>>2]|0;m=c[j+4>>2]|0;n=0;o=(m|0)>(n|0)|(m|0)==(n|0)&l>>>0>0>>>0;n=d+24|0;p=c[n>>2]|0;q=c[n+4>>2]|0;if(!((q|0)<(m|0)|(q|0)==(m|0)&p>>>0<l>>>0|o^1)){yDb(a,16,1885880,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}n=0;do{if((q|0)>(n|0)|(q|0)==(n|0)&p>>>0>0>>>0){r=d+24|0;s=c[h+412>>2]|0;t=HDb(p,q,s,(s|0)<0|0?-1:0,1e3,0,2)|0;s=F;c[r>>2]=t;c[r+4>>2]=s;r=0;if(!(s>>>0>r>>>0|s>>>0==r>>>0&t>>>0>-1>>>0)){break}yDb(a,16,2343768,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}}while(0);q=h+412|0;do{if(o){p=c[q>>2]|0;n=HDb(l,m,p,(p|0)<0|0?-1:0,1e3,0,2)|0;p=F;c[j>>2]=n;c[j+4>>2]=p;t=0;if(!(p>>>0>t>>>0|p>>>0==t>>>0&n>>>0>-1>>>0)){break}yDb(a,16,2321432,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}}while(0);Yy(e,1297241171);f=Ty(e,0,0,1)|0;a=d+8|0;c[a>>2]=f;c[a+4>>2]=F;Zy(e,0);fz(e,k);fz(e,16);fz(e,c[h+416>>2]|0);fz(e,0);Zy(e,c[q>>2]|0);q=Ty(e,0,0,1)|0;h=d+16|0;c[h>>2]=q;c[h+4>>2]=F;Zy(e,0);Zy(e,0);Zy(e,0);Zy(e,0);Zy(e,0);Yy(e,127);ez(e,0,0);ez(e,0,0);Zy(e,0);Sy(e);g=0;i=b;return g|0}function $x(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;f=b+28|0;g=(c[f>>2]|0)/(c[e+416>>2]|0)|0;if((c[e+428>>2]|0)==1){c[(c[a+12>>2]|0)+40>>2]=g}Yy(d,1262701634);Zy(d,g);ez(d,0,0);ez(d,0,0);ez(d,0,0);Ry(d,c[b+24>>2]|0,c[f>>2]|0);return 0}function ay(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;d=a+16|0;e=c[d>>2]|0;f=c[a+12>>2]|0;g=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;h=Ty(e,0,0,1)|0;j=F;k=YGb(h,j,-64,-1)|0;l=c[g+428>>2]<<5;m=ZGb(k,F,l,(l|0)<0|0?-1:0)|0;l=c[g+432>>2]|0;g=eHb(m,F,l,(l|0)<0|0?-1:0)|0;l=F;m=a;yDb(m,48,2153912,(a=i,i=i+16|0,c[a>>2]=g,c[a+8>>2]=l,a)|0);i=a;if((c[(c[d>>2]|0)+88>>2]|0)==0){i=b;return 0}d=f+16|0;Ty(e,c[d>>2]|0,c[d+4>>2]|0,0)|0;d=g;Zy(e,d);n=f+24|0;o=c[n>>2]|0;p=c[n+4>>2]|0;q=0;do{if((p|0)>(q|0)|(p|0)==(q|0)&o>>>0>0>>>0){if((p|0)<(l|0)|(p|0)==(l|0)&o>>>0<g>>>0){Zy(e,o);break}else{yDb(m,24,2084800,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;c[n>>2]=-1;c[n+4>>2]=-1;Vy(e,4,0)|0;break}}else{Vy(e,4,0)|0;}}while(0);o=f+32|0;p=c[o>>2]|0;q=c[o+4>>2]|0;do{if((p|0)==0&(q|0)==0){r=12}else{s=c[n+4>>2]|0;t=-1;if(!((s|0)>(t|0)|(s|0)==(t|0)&(c[n>>2]|0)>>>0>-1>>>0)){r=12;break}if((q|0)>(l|0)|(q|0)==(l|0)&p>>>0>g>>>0){yDb(m,24,2033952,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;c[o>>2]=g;c[o+4>>2]=l;u=g}else{u=p}Zy(e,u)}}while(0);if((r|0)==12){Zy(e,d)}Zy(e,c[f+40>>2]|0);d=f+8|0;Ty(e,c[d>>2]|0,c[d+4>>2]|0,0)|0;Zy(e,k);k=c[n+4>>2]|0;d=-1;if((k|0)>(d|0)|(k|0)==(d|0)&(c[n>>2]|0)>>>0>-1>>>0){Vy(e,6,0)|0;fz(e,65535)}Ty(e,h,j,0)|0;Sy(e);i=b;return 0}function by(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==46){if((a[d+1|0]|0)!=115){break}if((a[d+2|0]|0)!=110){break}if((a[d+3|0]|0)==100){e=100}else{break}return e|0}}while(0);e=0;return e|0}function cy(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;e=c[a+16>>2]|0;if((rz(e)|0)!=1684960046){f=-1094995529;i=b;return f|0}g=vz(e)|0;h=vz(e)|0;j=(h|0)==-1;if((h|0)<-1){yDb(a,16,1928568,(k=i,i=i+8|0,c[k>>2]=h,k)|0);i=k;f=-1094995529;i=b;return f|0}l=vz(e)|0;m=vz(e)|0;n=vz(e)|0;if((g|0)>24){o=g-24|0;Vy(e,o,(o|0)<0|0?-1:0)|0;}o=vT(1470312,l)|0;if((o|0)==0){DDb(a,1906504,(k=i,i=i+8|0,c[k>>2]=l,k)|0);i=k;f=-1163346256;i=b;return f|0}e=u0a(o)|0;do{if((o|0)==909260615){if((l|0)==926037554){p=2;break}g=l-23|0;if(g>>>0<4>>>0){p=d[1781872+g|0]|0;break}else{yDb(0,0,1885848,(k=i,i=i+24|0,c[k>>2]=2343744,c[k+8>>2]=2321376,c[k+16>>2]=114,k)|0);i=k;Cd();return 0}}else{if((e|0)!=0){p=e;break}DDb(a,2299184,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;f=-1163346256;i=b;return f|0}}while(0);do{if((n|0)!=0){if(!(n>>>0<(2147483647/(p<<7|0)|0)>>>0)){break}if((m|0)<1){yDb(a,16,2266312,(k=i,i=i+8|0,c[k>>2]=m,k)|0);i=k;f=-1094995529;i=b;return f|0}e=LT(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=c[e+8>>2]|0;c[g+8>>2]=1;c[g+52>>2]=l;c[g+48>>2]=o;c[g+416>>2]=n;c[g+412>>2]=m;c[g+792>>2]=p;c[g+72>>2]=ba(ba(n,m)|0,p)|0;q=ba(n,p)|0;if((q|0)>15){r=(q|0)/8|0}else{r=1}c[g+432>>2]=r;if(!j){g=h;q=gHb(n,(n|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;s=eHb(g<<3|0>>>29,((h|0)<0|0?-1:0)<<3|g>>>29,q,F)|0;q=e+56|0;c[q>>2]=s;c[q+4>>2]=F}q=e+48|0;c[q>>2]=0;c[q+4>>2]=0;MT(e,64,1,m);f=0;i=b;return f|0}}while(0);yDb(a,16,2281696,(k=i,i=i+8|0,c[k>>2]=n,k)|0);i=k;f=-1094995529;i=b;return f|0}function dy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[a+24>>2]|0)!=1){yDb(a,16,2033912,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}h=uT(1470312,c[e+48>>2]|0)|0;j=e+52|0;c[j>>2]=h;if((h|0)==0){yDb(a,16,1989184,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else{Yy(d,1684960046);Zy(d,32);Zy(d,-1);Zy(d,c[j>>2]|0);Zy(d,c[e+412>>2]|0);Zy(d,c[e+416>>2]|0);ez(d,0,0);Sy(d);g=0;i=b;return g|0}return 0}function ey(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+16|0;a=c[b>>2]|0;d=Ty(a,0,0,1)|0;e=F;f=0;if(!((c[(c[b>>2]|0)+88>>2]|0)!=0&((e|0)<(f|0)|(e|0)==(f|0)&d>>>0<2147483647>>>0))){return 0}Ty(a,8,0,0)|0;f=YGb(d,e,-32,0)|0;Zy(a,f);Ty(a,d,e,0)|0;Sy(a);return 0}function fy(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;a=b+8|0;do{if((PGb(b,1746416,4)|0)==0){if((PGb(a,1746420,4)|0)==0){d=100}else{break}return d|0}}while(0);do{if((PGb(b,1746424,4)|0)==0){if((PGb(a,1746428,4)|0)==0){d=100}else{break}return d|0}}while(0);do{if((PGb(b,1746432,4)|0)==0){if((PGb(a,1746436,4)|0)==0){d=100}else{break}return d|0}}while(0);do{if((PGb(b,1746440,4)|0)==0){if((PGb(a,1746444,4)|0)==0){d=100}else{break}return d|0}}while(0);do{if((PGb(b,1746448,4)|0)==0){if((PGb(a,1746452,4)|0)==0){d=100}else{break}return d|0}}while(0);d=0;return d|0}function gy(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Mb=0,Nb=0,Ob=0,Pb=0;e=i;i=i+248|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+64|0;o=e+72|0;p=e+80|0;q=e+144|0;r=e+152|0;s=e+216|0;t=e+224|0;u=e+232|0;v=e+240|0;w=v;x=c[b+12>>2]|0;y=b+16|0;z=c[y>>2]|0;c[x+68>>2]=-1;A=q|0;mz(z,A,4)|0;B=x+8|0;c[B>>2]=rz(z)|0;c[B+4>>2]=0;C=Ty(z,0,0,1)|0;D=YGb(c[B>>2]|0,c[B+4>>2]|0,C,F)|0;c[B>>2]=D;c[B+4>>2]=F;mz(z,q+4|0,4)|0;D=0;while(1){if((D|0)==5){E=-1094995529;G=225;break}if((PGb(A,1746416+(D<<3)|0,8)|0)==0){break}else{D=D+1|0}}if((G|0)==225){i=e;return E|0}if((a[q+7|0]|0)==25){yDb(b,32,2041688,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}q=x+80|0;yDb(x,48,2224840,(H=i,i=i+8|0,c[H>>2]=c[q>>2],H)|0);i=H;D=Wy(z)|0;A=F;C=x+24|0;c[C>>2]=D;c[C+4>>2]=A;I=x+32|0;c[I>>2]=D;c[I+4>>2]=A;J=0;K=c[B>>2]|0;L=c[B+4>>2]|0;if((A|0)<(J|0)|(A|0)==(J|0)&D>>>0<1>>>0|((A|0)<(L|0)|(A|0)==(L|0)&D>>>0<K>>>0)){D=(K|0)==8&(L|0)==0;c[C>>2]=D?-1:K;c[C+4>>2]=D?2147483647:L}if((Xy(z)|0)!=0){E=-1094995529;i=e;return E|0}L=p|0;D=b+1140|0;K=p+4|0;A=p+7|0;p=r|0;J=l|0;l=m|0;m=r+4|0;M=r+7|0;r=x+60|0;N=x+64|0;O=b+24|0;P=b;Q=b+28|0;R=x+72|0;S=b+1064|0;T=z+88|0;U=b+1084|0;V=b+1156|0;W=u+4|0;X=u|0;Y=t|0;Z=t+4|0;_=k|0;$=k;k=0;aa=0;ba=0;ca=0;da=0;ea=0;fa=0;ga=-1;ha=-1;a:while(1){ia=rz(z)|0;ja=rz(z)|0;b:do{if((ia|0)==1414087753){TGb(p|0,0,64)|0;ka=(ja&1)+ja|0;Vy(z,ka-(mz(z,p,ka>>>0>63>>>0?63:ka)|0)|0,0)|0;ka=xd(p|0,2071096,(H=i,i=i+32|0,c[H>>2]=J,c[H+8>>2]=n,c[H+16>>2]=l,c[H+24>>2]=o,H)|0)|0;i=H;if((ka|0)==4){la=0}else{if((a[m]|0)!=47){ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break}if((a[M]|0)!=47){ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break}a[M]=45;a[m]=45;CBb(D,2062336,p,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break}while(1){if((yAb(J,676576+(la<<2)|0)|0)==0){ka=la+1|0;va=c[n>>2]|0;Lb(L|0,64,2066568,(H=i,i=i+32|0,c[H>>2]=c[o>>2],c[H+8>>2]=ka,c[H+16>>2]=va,c[H+24>>2]=l,H)|0)|0;i=H;CBb(D,2062336,L,0)|0;wa=ka}else{wa=la+1|0}if((wa|0)<12){la=wa}else{ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break}}}else if((ia|0)==2019847785){ka=Ty(z,0,0,1)|0;va=ka;do{if((c[T>>2]|0)!=0){if((c[U>>2]&2|0)!=0){break}if((c[q>>2]|0)==0){break}if((my(b,0)|0)>=0){break}if((c[V>>2]&8|0)!=0){E=-1094995529;G=225;break a}}}while(0);Ty(z,va+ja|0,0,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k}else if((ia|0)==1685222515){do{if(ga>>>0<(c[O>>2]|0)>>>0){ka=c[(c[(c[Q>>2]|0)+(ga<<2)>>2]|0)+8>>2]|0;if((c[ka+100>>2]|0)!=0){break}if((c[ka+52>>2]|0)==875967048){break}ka=Ty(z,0,0,1)|0;xa=F;if(xa>>>0<da>>>0|xa>>>0==da>>>0&ka>>>0<ea>>>0){ya=0;za=ZGb(ea,da,ka,xa)|0;xa=F;Aa=ya>>>0>xa>>>0|ya>>>0==xa>>>0&ja>>>0>za>>>0?za:ja}else{Aa=ja}za=(c[(c[Q>>2]|0)+(ga<<2)>>2]|0)+8|0;if(Aa>>>0<1073741824>>>0){if((CT(c[za>>2]|0,z,Aa)|0)<0){E=-12;G=225;break a}}if((c[(c[za>>2]|0)+100>>2]&1|0)==0){ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}lz(z)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}}while(0);Vy(z,ja,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k}else if((ia|0)==1751936356){c[r>>2]=1;Vy(z,(ja&1)+ja|0,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k}else if((ia|0)==1752331379){va=rz(z)|0;za=rz(z)|0;if((va|0)==1935958384){Vy(z,ja-8|0,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break}xa=ga+1|0;ya=LT(b,0)|0;if((ya|0)==0){E=-1094995529;G=225;break a}c[ya+4>>2]=xa;ka=cEb(1184)|0;Ba=ka;if((ka|0)==0){E=-1094995529;G=225;break a}c[ya+12>>2]=ka;if((ca|0)==0){Ca=va}else{Ca=(xa|0)!=0?1935963489:1935960438}if((Ca|0)==1937138025|(Ca|0)==1935767145){if((c[O>>2]|0)!=1){E=-1094995529;G=225;break a}if(!((za|0)==1819506276|(za|0)==1685288548|(za|0)==1684567652)){E=-1094995529;G=225;break a}va=c[c[Q>>2]>>2]|0;Da=c[va+12>>2]|0;Ea=Da;$Db((c[va+8>>2]|0)+96|0);$Db((c[c[Q>>2]>>2]|0)+8|0);va=c[c[Q>>2]>>2]|0;Fa=c[va+184>>2]|0;if((Fa|0)==0){Ga=va}else{$Db(Fa+32|0);Ga=c[c[Q>>2]>>2]|0}$Db(Ga+184|0);$Db(c[Q>>2]|0);c[O>>2]=0;Fa=wB(b)|0;c[R>>2]=Fa;if((Fa|0)==0){E=-1094995529;G=225;break a}c[(c[c[Q>>2]>>2]|0)+12>>2]=Da;Vy(z,12,0)|0;Fa=Da+16|0;c[Fa>>2]=rz(z)|0;va=Da+20|0;c[va>>2]=rz(z)|0;Vy(z,4,0)|0;Da=rz(z)|0;Ha=Da;Ia=0;Ja=c[Fa>>2]|0;do{if((Ja|0)!=0){Fa=c[va>>2]|0;if((Fa|0)==0|(Da|0)==0){break}Ka=gHb(Ha,Ia,1e6,0)|0;La=IDb(Ka,F,Ja,0,Fa,0)|0;c[S>>2]=La;c[S+4>>2]=F}}while(0);Ja=(c[O>>2]|0)-1|0;Vy(z,ja-36|0,0)|0;ma=ha;na=Ja;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=Ea;break}if(!(xa>>>0<(c[O>>2]|0)>>>0)){G=59;break a}c[(c[ya+8>>2]|0)+56>>2]=za;rz(z)|0;pz(z)|0;pz(z)|0;rz(z)|0;Ja=ka+16|0;c[Ja>>2]=rz(z)|0;Ia=rz(z)|0;Ha=ka+20|0;c[Ha>>2]=Ia;Da=c[Ja>>2]|0;do{if((Da|0)==0|(Ia|0)==0){yDb(P,24,2205056,(H=i,i=i+16|0,c[H>>2]=Da,c[H+8>>2]=Ia,H)|0);i=H;if((fa|0)==0){c[Ha>>2]=25;c[Ja>>2]=1;Ma=1;Na=25;break}else{c[Ha>>2]=1e6;c[Ja>>2]=fa;Ma=fa;Na=1e6;break}}else{Ma=Da;Na=Ia}}while(0);MT(ya,64,Ma,Na);Ia=ka+32|0;c[Ia>>2]=rz(z)|0;c[Ia+4>>2]=0;Da=ya+64|0;c[Da>>2]=rz(z)|0;c[Da+4>>2]=0;za=ya+48|0;c[za>>2]=0;c[za+4>>2]=0;rz(z)|0;rz(z)|0;za=gHb(c[Ja>>2]|0,0,c[Ia>>2]|0,c[Ia+4>>2]|0)|0;Ea=eHb(za,F,c[Ha>>2]|0,0)|0;za=F;va=0;if((za|0)>(va|0)|(za|0)==(va|0)&Ea>>>0>3600>>>0){G=65;break a}Ea=rz(z)|0;va=ka+24|0;c[va>>2]=Ea;za=(Ea|0)<1;La=gHb(za?1:Ea,za?0:(Ea|0)<0|0?-1:0,c[Ia>>2]|0,c[Ia+4>>2]|0)|0;c[Ia>>2]=La;c[Ia+4>>2]=F;if((Ca|0)==1935963489){Oa=1;Pa=Ea;G=71}else if((Ca|0)==1937006948){Oa=2;Pa=Ea;G=71}else if((Ca|0)==1935960438){c[va>>2]=0;Qa=0;G=72}else if((Ca|0)==1937012852){Oa=3;Pa=Ea;G=71}else{yDb(P,32,2185672,(H=i,i=i+8|0,c[H>>2]=Ca,H)|0);i=H;Oa=ha;Pa=c[va>>2]|0;G=71}if((G|0)==71){G=0;if((Pa|0)==0){Qa=Oa;G=72}else{Ra=Oa}}do{if((G|0)==72){G=0;va=c[Da>>2]|0;Ea=c[Da+4>>2]|0;La=ya+56|0;c[La>>2]=va;c[La+4>>2]=Ea;za=0;if(!((Ea|0)>(za|0)|(Ea|0)==(za|0)&va>>>0>0>>>0)){Ra=Qa;break}va=c[I>>2]|0;za=c[I+4>>2]|0;Ea=0;if(!((za|0)>(Ea|0)|(za|0)==(Ea|0)&va>>>0>0>>>0)){Ra=Qa;break}Ea=c[B+4>>2]|0;if(!((Ea|0)>(za|0)|(Ea|0)==(za|0)&(c[B>>2]|0)>>>0>va>>>0)){Ra=Qa;break}yDb(P,48,2170360,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;va=IDb(c[La>>2]|0,c[La+4>>2]|0,c[I>>2]|0,c[I+4>>2]|0,c[B>>2]|0,c[B+4>>2]|0)|0;c[La>>2]=va;c[La+4>>2]=F;Ra=Qa}}while(0);ya=c[Ia+4>>2]|0;Da=ka;c[Da>>2]=c[Ia>>2];c[Da+4>>2]=ya;Vy(z,ja-48|0,0)|0;ma=Ra;na=xa;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=Ba}else if((ia|0)==1718776947){if((ja|0)==0){ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break}do{if(ga>>>0<(c[O>>2]|0)>>>0){if((c[R>>2]|0)!=0){break}ya=Ty(z,0,0,1)|0;Da=F;if(Da>>>0<da>>>0|Da>>>0==da>>>0&ya>>>0<ea>>>0){Ha=0;Ja=ZGb(ea,da,ya,Da)|0;Da=F;Sa=Ha>>>0>Da>>>0|Ha>>>0==Da>>>0&ja>>>0>Ja>>>0?Ja:ja}else{Sa=ja}Ja=c[(c[Q>>2]|0)+(ga<<2)>>2]|0;Da=Ja+8|0;Ha=c[Da>>2]|0;ya=Ha+8|0;if(!((c[ya>>2]|0)==-1)){Vy(z,Sa,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}if((ha|0)==1){La=AO(z,Ha,Sa)|0;if((La|0)<0){E=La;G=225;break a}La=c[Da>>2]|0;va=La+432|0;za=k+1076|0;c[za>>2]=c[va>>2];Ea=k+24|0;Fa=c[Ea>>2]|0;do{if((Fa|0)==0){Ta=La}else{Ka=c[va>>2]|0;if((Ka|0)==0|(Fa|0)==(Ka|0)){Ta=La;break}yDb(P,24,2155352,(H=i,i=i+16|0,c[H>>2]=Fa,c[H+8>>2]=Ka,H)|0);i=H;Ka=c[Da>>2]|0;c[Ea>>2]=c[Ka+432>>2];Ta=Ka}}while(0);if((Sa&1|0)==0){Ua=Ta}else{Vy(z,1,0)|0;Ua=c[Da>>2]|0}Fa=Ja+236|0;c[Fa>>2]=3;La=Ua+48|0;va=c[La>>2]|0;do{if((va|0)==86018){if((c[Ua+100>>2]|0)==0){break}c[Fa>>2]=0}}while(0);if((c[Ua+56>>2]|0)==1851881537){c[La>>2]=81922;c[Ua+52>>2]=0;c[za>>2]=0;Va=81922}else{Va=va}if((ca|0)!=0){c[La>>2]=69651;c[za>>2]=0;ma=1;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}c:do{if((Va|0)==86018){Fa=c[za>>2]|0;do{if((Fa|0)>4|(Fa|0)==0){Ka=c[za>>2]|0;if((Ka|0)!=1024){Wa=Ka;break}if((c[Ea>>2]|0)==1024){break c}else{G=129}}else{yDb(P,48,2141848,(H=i,i=i+8|0,c[H>>2]=Fa,H)|0);i=H;c[za>>2]=0;Ka=c[(c[Da>>2]|0)+48>>2]|0;if((Ka|0)==86018){G=129}else{Xa=Ka;G=132;break c}}}while(0);if((G|0)==129){G=0;Wa=c[za>>2]|0}if((Wa|0)!=4096){Xa=86018;G=132;break}if((c[Ea>>2]|0)!=4096){Xa=86018;G=132}}else{Xa=Va;G=132}}while(0);if((G|0)==132){G=0;if((Xa|0)!=86017){ma=1;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}if((c[za>>2]|0)!=1152){ma=1;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}if((c[Ea>>2]|0)!=1152){ma=1;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}}yDb(P,48,2136008,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[Ea>>2]=0;ma=1;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}else if((ha|0)==3){c[ya>>2]=3;c[Ja+440>>2]=1;Vy(z,Sa,0)|0;ma=3;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}else if((ha|0)==0){if((ca|0)!=0){c[Ha+120>>2]=aa;c[Ha+124>>2]=ba;c[ya>>2]=0;c[Ha+48>>2]=108;Vy(z,Sa,0)|0;ma=0;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}La=CO(z,Ja,s)|0;if((La|0)==1112758340|(La|0)==1095981124){va=c[Da>>2]|0;c[va+8>>2]=3;c[va+52>>2]=La;c[va+48>>2]=94211;ma=0;na=ga;oa=fa;pa=da;qa=ea;ra=0;sa=ba;ta=aa;ua=k;break b}do{if((Sa-41|0)>>>0<1073741783>>>0){va=0;Fa=c[C+4>>2]|0;if(!((va|0)<(Fa|0)|(va|0)==(Fa|0)&Sa>>>0<(c[C>>2]|0)>>>0)){break}Fa=c[s>>2]|0;if((Fa|0)!=(Sa-1|0)|(Fa&1|0)==0){va=Sa-40|0;Ka=c[Da>>2]|0;c[Ka+100>>2]=va;Ya=Ka;Za=va}else{va=Fa-40|0;Fa=c[Da>>2]|0;c[Fa+100>>2]=va;Ya=Fa;Za=va}if((CT(Ya,z,Za)|0)<0){E=-12;G=225;break a}}}while(0);Ea=c[Da>>2]|0;za=c[Ea+100>>2]|0;if((za&1|0)==0){_a=Ea;$a=za}else{lz(z)|0;za=c[Da>>2]|0;_a=za;$a=c[za+100>>2]|0}do{if(($a|0)!=0){za=c[_a+792>>2]|0;if((za|0)>=9){break}Ea=4<<za;za=(Ea|0)>($a|0)?$a:Ea;Ea=c[_a+96>>2]|0;va=$a-za|0;Fa=(za|0)/4|0;if((za|0)>3){za=0;do{Ka=Ea+(va+(za<<2))|0;c[k+48+(za<<2)>>2]=d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|-16777216;za=za+1|0;}while((za|0)<(Fa|0))}c[k+1072>>2]=1}}while(0);c[_a+8>>2]=0;c[_a+52>>2]=La;Fa=vT(1240808,La)|0;za=c[Da>>2]|0;c[za+48>>2]=Fa;Fa=Ja+236|0;c[Fa>>2]=2;va=c[za+52>>2]|0;do{if((va|0)==1213420374){c[Fa>>2]=1;ab=za}else if((va|0)==0){if((c[za+124>>2]|0)<=0){ab=za;break}Ea=za+100|0;Ka=c[Ea>>2]|0;if(!(Ka>>>0<1073741824>>>0)){ab=za;break}c[Ea>>2]=Ka+9;bb=_Db(za+96|0,Ka+25|0)|0;cb=c[Da>>2]|0;if((bb|0)<0){G=108;break a}UGb((c[cb+96>>2]|0)+((c[cb+100>>2]|0)-9)|0,2161952,9)|0;ab=c[Da>>2]|0}else{ab=za}}while(0);za=ab+124|0;Da=c[za>>2]|0;c[za>>2]=(Da|0)>-1?Da:-Da|0;ma=0;na=ga;oa=fa;pa=da;qa=ea;ra=0;sa=ba;ta=aa;ua=k;break b}else{c[ya>>2]=2;c[Ha+48>>2]=0;c[Ha+52>>2]=0;Vy(z,Sa,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k;break b}}}while(0);Vy(z,ja,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k}else if((ia|0)==1886548086){if(ga>>>0<(c[O>>2]|0)>>>0&ja>>>0>36>>>0){Ba=c[(c[Q>>2]|0)+(ga<<2)>>2]|0;rz(z)|0;rz(z)|0;rz(z)|0;rz(z)|0;rz(z)|0;xa=pz(z)|0;c[W>>2]=xa;Ia=pz(z)|0;c[X>>2]=Ia;ka=rz(z)|0;c[Y>>2]=ka;Da=rz(z)|0;c[Z>>2]=Da;rz(z)|0;if(!((Ia|0)==0|(xa|0)==0|(ka|0)==0|(Da|0)==0)){kFb(w,u,t);Da=Ba+80|0;Ba=c[v+4>>2]|0;c[Da>>2]=c[v>>2];c[Da+4>>2]=Ba}db=ja-36|0}else{db=ja}Vy(z,db,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k}else if((ia|0)==1852994675){Ba=c[O>>2]|0;if((Ba|0)==0){G=164;break}Da=c[(c[Q>>2]|0)+(Ba-1<<2)>>2]|0;Ba=c[y>>2]|0;TGb(_|0,0,5)|0;ka=(ja&1)+ja|0;if((ka|0)==-1){E=-22;G=225;break a}xa=WDb(ka+1|0)|0;if((xa|0)==0){E=-12;G=225;break a}mz(Ba,xa,ka)|0;a[xa+ka|0]=0;c[$>>2]=1852994675;ka=CBb((Da|0)==0?D:Da+88|0,_,xa,8)|0;if((ka|0)<0){E=ka;G=225;break a}else{ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k}}else if((ia|0)==1414744396){ka=Ty(z,0,0,1)|0;eb=ja;fb=0;xa=YGb(ka,F,eb,fb)|0;ka=F;Da=rz(z)|0;if((Da|0)==1330007625){DO(b,ja-4|0,0)|0;ma=ha;na=ga;oa=fa;pa=ka;qa=xa;ra=ca;sa=ba;ta=aa;ua=k;break}else if((Da|0)==1769369453){G=12;break a}else if((Da|0)!=1952736110){ma=ha;na=ga;oa=fa;pa=ka;qa=xa;ra=ca;sa=ba;ta=aa;ua=k;break}Da=Ty(c[y>>2]|0,0,0,1)|0;Ba=F;if(!(Ba>>>0<ka>>>0|Ba>>>0==ka>>>0&Da>>>0<xa>>>0)){ma=ha;na=ga;oa=fa;pa=ka;qa=xa;ra=ca;sa=ba;ta=aa;ua=k;break}while(1){Da=rz(c[y>>2]|0)|0;Ba=rz(c[y>>2]|0)|0;Ia=c[y>>2]|0;do{if((Da|0)==1735680878){za=Ty(Ia,0,0,1)|0;va=YGb(za,F,Ba,0)|0;za=F;Fa=Ty(c[y>>2]|0,0,0,1)|0;Ja=F;if(!(Ja>>>0<za>>>0|Ja>>>0==za>>>0&Fa>>>0<va>>>0)){break}do{Fa=pz(c[y>>2]|0)|0;Ja=pz(c[y>>2]|0)|0;TGb(L|0,0,64)|0;La=0;Ka=Ty(c[y>>2]|0,0,0,1)|0;Ea=ZGb(va,za,Ka,F)|0;Ka=F;if(La>>>0>Ka>>>0|La>>>0==Ka>>>0&(Ja&65535)>>>0>Ea>>>0){Ea=Ty(c[y>>2]|0,0,0,1)|0;Ka=ZGb(va,za,Ea,F)|0;gb=Ka&65535}else{gb=Ja&65535}Ja=gb&65535;Ka=Ja-(mz(c[y>>2]|0,L,(gb&65535)>>>0>63>>>0?63:Ja)|0)|0;Ja=Fa&65535;do{if((Ja|0)==3){hb=2058776;G=27}else if((Ja|0)==4){hb=2050840;G=27}else if((Ja|0)==19){if((a[K]|0)!=58){hb=2062336;G=27;break}if((a[A]|0)!=58){hb=2062336;G=27;break}a[A]=45;a[K]=45;hb=2062336;G=27}}while(0);if((G|0)==27){G=0;CBb(D,hb,L,0)|0}Vy(c[y>>2]|0,Ka&65535,0)|0;Ja=Ty(c[y>>2]|0,0,0,1)|0;Fa=F;}while(Fa>>>0<za>>>0|Fa>>>0==za>>>0&Ja>>>0<va>>>0)}else{Vy(Ia,Ba,0)|0;}}while(0);Ba=Ty(c[y>>2]|0,0,0,1)|0;Ia=F;if(!(Ia>>>0<ka>>>0|Ia>>>0==ka>>>0&Ba>>>0<xa>>>0)){ma=ha;na=ga;oa=fa;pa=ka;qa=xa;ra=ca;sa=ba;ta=aa;ua=k;break}}}else if((ia|0)==1752591713){ib=1;G=41}else if((ia|0)==1751742049){ib=ca;G=41}else{G=164}}while(0);if((G|0)==41){G=0;ia=rz(z)|0;rz(z)|0;rz(z)|0;xa=(rz(z)|0)&32;c[N>>2]=c[N>>2]|xa;Vy(z,8,0)|0;rz(z)|0;rz(z)|0;xa=rz(z)|0;ka=rz(z)|0;Vy(z,ja-40|0,0)|0;ma=ha;na=ga;oa=ia;pa=da;qa=ea;ra=ib;sa=ka;ta=xa;ua=k}else if((G|0)==164){G=0;if(ja>>>0>1e6>>>0){G=165;break}Vy(z,(ja&1)+ja|0,0)|0;ma=ha;na=ga;oa=fa;pa=da;qa=ea;ra=ca;sa=ba;ta=aa;ua=k}if((Xy(z)|0)==0){k=ua;aa=ta;ba=sa;ca=ra;da=pa;ea=qa;fa=oa;ga=na;ha=ma}else{E=-1094995529;G=225;break}}do{if((G|0)==12){ma=Ty(z,0,0,1)|0;ha=YGb(ma,F,-4,-1)|0;ma=F;na=x+40|0;c[na>>2]=ha;c[na+4>>2]=ma;if((ja|0)==0){na=c[C+4>>2]|0;oa=x+16|0;c[oa>>2]=c[C>>2];c[oa+4>>2]=na;break}else{na=YGb(ja&1,0,eb,fb)|0;oa=YGb(na,F,ha,ma)|0;ma=x+16|0;c[ma>>2]=oa;c[ma+4>>2]=F;break}}else if((G|0)==59){yDb(0,0,2153808,(H=i,i=i+24|0,c[H>>2]=2214792,c[H+8>>2]=2033888,c[H+16>>2]=549,H)|0);i=H;Cd();return 0}else if((G|0)==65){yDb(P,16,2197536,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;E=-1094995529;i=e;return E|0}else if((G|0)==108){c[cb+100>>2]=0;E=bb;i=e;return E|0}else if((G|0)==165){yDb(P,16,2129880,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;if((c[V>>2]&8|0)==0){ma=Ty(z,0,0,1)|0;oa=YGb(ma,F,-4,-1)|0;ma=x+40|0;c[ma>>2]=oa;c[ma+4>>2]=F;ma=c[C+4>>2]|0;oa=x+16|0;c[oa>>2]=c[C>>2];c[oa+4>>2]=ma;break}else{E=-1094995529;i=e;return E|0}}else if((G|0)==225){i=e;return E|0}}while(0);if((ga|0)!=((c[O>>2]|0)-1|0)){E=-1094995529;i=e;return E|0}ga=x+56|0;x=c[ga>>2]|0;do{if((x|0)==0){if((c[T>>2]|0)==0){jb=0;break}ky(b);jb=c[ga>>2]|0}else{jb=x}}while(0);c[ga>>2]=jb|1;jb=Ty(c[y>>2]|0,0,0,1)|0;ga=F;x=c[O>>2]|0;if((x|0)==0){Ty(c[y>>2]|0,jb,ga,0)|0;G=180}else{T=2147483647;C=-1;z=0;V=0;bb=0;cb=x;while(1){x=c[(c[Q>>2]|0)+(bb<<2)>>2]|0;fb=c[x+404>>2]|0;if((fb|0)<1){kb=z;lb=V;mb=T;nb=C;ob=cb}else{eb=x+400|0;x=c[eb>>2]|0;if((fb|0)>1){ja=x|0;ma=c[ja>>2]|0;oa=c[ja+4>>2]|0;ja=c[y>>2]|0;ha=YGb(ma,oa,4,0)|0;Ty(ja,ha,F,0)|0;ha=YGb(rz(c[y>>2]|0)|0,0,ma,oa)|0;oa=F;ma=c[eb>>2]|0;eb=ma+24|0;ja=c[eb+4>>2]|0;na=(oa|0)>(ja|0)|(oa|0)==(ja|0)&ha>>>0>(c[eb>>2]|0)>>>0;pb=na?2147483647:z;qb=na?-1:V;rb=c[O>>2]|0;sb=ma}else{pb=z;qb=V;rb=cb;sb=x}x=sb|0;ma=c[x>>2]|0;na=c[x+4>>2]|0;x=(na|0)>(pb|0)|(na|0)==(pb|0)&ma>>>0>qb>>>0;eb=sb+((fb-1|0)*24|0)|0;fb=c[eb>>2]|0;ha=c[eb+4>>2]|0;eb=(ha|0)<(T|0)|(ha|0)==(T|0)&fb>>>0<C>>>0;kb=x?na:pb;lb=x?ma:qb;mb=eb?ha:T;nb=eb?fb:C;ob=rb}fb=bb+1|0;if(fb>>>0<ob>>>0){T=mb;C=nb;z=kb;V=lb;bb=fb;cb=ob}else{break}}Ty(c[y>>2]|0,jb,ga,0)|0;if((kb|0)>(mb|0)|(kb|0)==(mb|0)&lb>>>0>nb>>>0){tb=1}else{G=180}}do{if((G|0)==180){nb=dEb(c[O>>2]|0,4)|0;lb=nb;if((nb|0)==0){tb=0;break}mb=f|0;kb=f+4|0;ga=g|0;jb=g+4|0;y=h|0;ob=h+4|0;cb=j|0;bb=j+4|0;V=0;z=0;C=0;T=0;while(1){if((z|0)==(-1|0)&(V|0)==2147483647){G=198;break}if((c[O>>2]|0)==0){ub=2147483647;vb=-1;wb=-1073741824;xb=0;yb=1073741823;zb=-1}else{rb=2147483647;qb=-1;pb=-1073741824;sb=0;fb=1073741823;eb=-1;ha=0;while(1){ma=c[(c[Q>>2]|0)+(ha<<2)>>2]|0;x=c[ma+12>>2]|0;na=c[ma+404>>2]|0;ja=lb+(ha<<2)|0;oa=c[ja>>2]|0;d:do{if((oa|0)<(na|0)){fa=c[ma+400>>2]|0;qa=oa;while(1){ea=fa+(qa*24|0)|0;pa=c[ea+4>>2]|0;if(!((pa|0)<(C|0)|(pa|0)==(C|0)&(c[ea>>2]|0)>>>0<T>>>0)){Ab=qa;break d}ea=qa+1|0;c[ja>>2]=ea;if((ea|0)<(na|0)){qa=ea}else{Ab=ea;break}}}else{Ab=oa}}while(0);if((Ab|0)<(na|0)){oa=ma+400|0;qa=(c[oa>>2]|0)+(Ab*24|0)+8|0;fa=x+24|0;ea=c[fa>>2]|0;pa=(ea|0)>1;da=eHb(c[qa>>2]|0,c[qa+4>>2]|0,pa?ea:1,pa?(ea|0)<0|0?-1:0:0)|0;ea=ma+40|0;c[mb>>2]=1;c[kb>>2]=1e6;pa=KDb(da,F,ea,f)|0;da=F;if((fb|0)>(da|0)|(fb|0)==(da|0)&eb>>>0>pa>>>0){pa=(c[oa>>2]|0)+((c[ja>>2]|0)*24|0)+8|0;da=c[fa>>2]|0;fa=(da|0)>1;qa=eHb(c[pa>>2]|0,c[pa+4>>2]|0,fa?da:1,fa?(da|0)<0|0?-1:0:0)|0;c[ga>>2]=1;c[jb>>2]=1e6;da=KDb(qa,F,ea,g)|0;Bb=F;Cb=da}else{Bb=fb;Cb=eb}da=c[ja>>2]|0;ea=(c[oa>>2]|0)+(da*24|0)|0;oa=c[ea>>2]|0;qa=c[ea+4>>2]|0;ea=(rb|0)>(qa|0)|(rb|0)==(qa|0)&qb>>>0>oa>>>0;Db=Bb;Eb=Cb;Fb=ea?qa:rb;Gb=ea?oa:qb;Hb=da}else{Db=fb;Eb=eb;Fb=rb;Gb=qb;Hb=Ab}do{if((Hb|0)==0){Ib=pb;Jb=sb}else{da=ma+400|0;oa=(c[da>>2]|0)+((Hb-1|0)*24|0)+8|0;ea=x+24|0;qa=c[ea>>2]|0;fa=(qa|0)>1;pa=eHb(c[oa>>2]|0,c[oa+4>>2]|0,fa?qa:1,fa?(qa|0)<0|0?-1:0:0)|0;qa=ma+40|0;c[y>>2]=1;c[ob>>2]=1e6;fa=KDb(pa,F,qa,h)|0;pa=F;if((pb|0)>(pa|0)|(pb|0)==(pa|0)&sb>>>0>fa>>>0){Ib=pb;Jb=sb;break}fa=(c[da>>2]|0)+(((c[ja>>2]|0)-1|0)*24|0)+8|0;da=c[ea>>2]|0;ea=(da|0)>1;pa=eHb(c[fa>>2]|0,c[fa+4>>2]|0,ea?da:1,ea?(da|0)<0|0?-1:0:0)|0;c[cb>>2]=1;c[bb>>2]=1e6;da=KDb(pa,F,qa,j)|0;Ib=F;Jb=da}}while(0);ja=ha+1|0;if(ja>>>0<(c[O>>2]|0)>>>0){rb=Fb;qb=Gb;pb=Ib;sb=Jb;fb=Db;eb=Eb;ha=ja}else{ub=Fb;vb=Gb;wb=Ib;xb=Jb;yb=Db;zb=Eb;break}}}ha=ZGb(xb,wb,zb,yb)|0;eb=F;fb=0;sb=YGb(vb,ub,1,0)|0;if((eb|0)>(fb|0)|(eb|0)==(fb|0)&ha>>>0>2e6>>>0){G=197;break}else{V=ub;z=vb;C=F;T=sb}}if((G|0)==197){ZDb(nb);tb=1;break}else if((G|0)==198){ZDb(nb);tb=0;break}}}while(0);c[N>>2]=c[U>>2]&65536|tb|c[N>>2];tb=BBb(c[D>>2]|0,2123272,0,0)|0;do{if((tb|0)!=0){if((QGb(c[tb+4>>2]|0,2118032)|0)!=0){break}D=c[O>>2]|0;if((D|0)==0){break}U=c[Q>>2]|0;G=0;do{vb=c[U+(G<<2)>>2]|0;if(((c[(c[vb+8>>2]|0)+48>>2]|0)-1|0)>>>0<2>>>0){c[vb+236>>2]=1}G=G+1|0;}while(G>>>0<D>>>0)}}while(0);tb=c[O>>2]|0;D=0;while(1){if(!(D>>>0<tb>>>0)){break}if((c[(c[(c[Q>>2]|0)+(D<<2)>>2]|0)+404>>2]|0)==0){D=D+1|0}else{break}}if((c[R>>2]|0)==0){Kb=tb;Mb=(c[N>>2]|0)==0}else{c[N>>2]=0;Kb=c[O>>2]|0;Mb=1}do{if((D|0)==(Kb|0)){if(Mb){break}yDb(P,24,2108504,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[N>>2]=0}else{if(Mb){break}yDb(P,32,2096736,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;tb=c[O>>2]|0;if((tb|0)==0){break}else{Nb=0;Ob=tb}while(1){tb=c[(c[Q>>2]|0)+(Nb<<2)>>2]|0;R=c[(c[tb+12>>2]|0)+24>>2]|0;do{if((c[tb+404>>2]|0)!=1|(R|0)==0){Pb=Ob}else{G=R;while(1){if((G|0)<1024){G=G<<1}else{break}}U=c[tb+400>>2]|0;nb=U|0;vb=c[nb>>2]|0;ub=c[nb+4>>2]|0;nb=c[U+16>>2]>>2;yb=nb;zb=(nb|0)<0|0?-1:0;wb=U+8|0;U=c[wb>>2]|0;xb=c[wb+4>>2]|0;if((nb|0)<=0){Pb=Ob;break}nb=G;wb=(G|0)<0|0?-1:0;Eb=0;Db=0;do{Jb=YGb(Db,Eb,vb,ub)|0;Ib=F;Gb=YGb(Db,Eb,U,xb)|0;Fb=F;j=ZGb(yb,zb,Db,Eb)|0;h=F;jT(tb,Jb,Ib,Gb,Fb,(wb|0)>(h|0)|(wb|0)==(h|0)&nb>>>0>j>>>0?j:G,0,1)|0;Db=YGb(Db,Eb,nb,wb)|0;Eb=F;}while((Eb|0)<(zb|0)|(Eb|0)==(zb|0)&Db>>>0<yb>>>0);Pb=c[O>>2]|0}}while(0);tb=Nb+1|0;if(tb>>>0<Pb>>>0){Nb=tb;Ob=Pb}else{break}}}}while(0);RG(b,0,1746400);RG(b,0,1148752);E=0;i=e;return E|0}function hy(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;f=i;i=i+320|0;g=f|0;h=f+256|0;j=f+264|0;k=f+272|0;l=f+288|0;m=f+296|0;n=f+304|0;o=f+312|0;p=c[b+12>>2]|0;q=b+16|0;r=c[q>>2]|0;s=p+72|0;t=c[s>>2]|0;do{if((t|0)==0){u=p+64|0;if((c[u>>2]|0)==0){v=u;break}w=b+24|0;x=c[w>>2]|0;if((x|0)==0){y=-541478725;i=f;return y|0}z=b+28|0;A=n|0;B=n+4|0;C=0;D=2147483647;E=-1;G=0;H=0;I=x;while(1){x=c[(c[z>>2]|0)+(C<<2)>>2]|0;J=c[x+12>>2]|0;K=J;L=c[K>>2]|0;M=c[K+4>>2]|0;K=c[x+404>>2]|0;do{if((K|0)==0){N=H;O=G;P=D;Q=E;R=I}else{if((c[J+8>>2]|0)==0){S=(c[x+400>>2]|0)+((K-1|0)*24|0)+8|0;T=c[S+4>>2]|0;if((M|0)>(T|0)|(M|0)==(T|0)&L>>>0>(c[S>>2]|0)>>>0){N=H;O=G;P=D;Q=E;R=I;break}}S=c[J+24>>2]|0;c[A>>2]=(S|0)<1?1:S;c[B>>2]=1e6;S=KDb(L,M,x+40|0,n)|0;T=F;U=(T|0)<(D|0)|(T|0)==(D|0)&S>>>0<E>>>0;N=U?C:H;O=U?x:G;P=U?T:D;Q=U?S:E;R=c[w>>2]|0}}while(0);x=C+1|0;if(x>>>0<R>>>0){C=x;D=P;E=Q;G=O;H=N;I=R}else{break}}if((O|0)==0){y=-541478725;i=f;return y|0}I=c[O+12>>2]|0;H=I;G=c[H>>2]|0;E=c[H+4>>2]|0;D=I+8|0;do{if((c[D>>2]|0)==0){C=oT(O,G,E,4)|0;if((C|0)>-1){w=c[O+400>>2]|0;B=w+(C*24|0)+8|0;A=c[B+4>>2]|0;c[H>>2]=c[B>>2];c[H+4>>2]=A;V=C;W=w;break}else{y=-541478725;i=f;return y|0}}else{w=oT(O,G,E,5)|0;if((w|0)>-1){V=w;W=c[O+400>>2]|0;break}else{y=-541478725;i=f;return y|0}}}while(0);E=W+(V*24|0)|0;G=I+12|0;H=(c[G>>2]|0)-(c[D>>2]|0)|0;w=c[q>>2]|0;C=YGb(c[E>>2]|0,c[E+4>>2]|0,8,0)|0;E=YGb(C,F,H,(H|0)<0|0?-1:0)|0;H=Ty(w,E,F,0)|0;E=F;w=0;if((E|0)<(w|0)|(E|0)==(w|0)&H>>>0<0>>>0){y=-541478725;i=f;return y|0}if((c[D>>2]|0)>(c[G>>2]|0)){yDb(0,0,2153808,(X=i,i=i+24|0,c[X>>2]=2321328,c[X+8>>2]=2033888,c[X+16>>2]=1220,X)|0);i=X;Cd();return 0}c[p+68>>2]=N;if((c[D>>2]|0)!=0){v=u;break}H=c[(c[O+400>>2]|0)+(V*24|0)+16>>2]>>2;c[D>>2]=H;c[G>>2]=H;v=u}else{H=xB(t,e)|0;if((H|0)>-1){y=H;i=f;return y|0}else{v=p+64|0;break}}}while(0);t=p+68|0;V=b+28|0;O=l|0;N=l+4|0;q=b+24|0;W=p+48|0;R=g|0;g=j;Q=e+28|0;P=e+24|0;n=k|0;H=k+4|0;G=k+8|0;w=e;E=e+16|0;C=e+32|0;A=e+36|0;B=e+64|0;z=e|0;x=e+52|0;M=b;L=m|0;J=m+4|0;a:while(1){K=c[t>>2]|0;if(!((K|0)>-1)){S=ly(b,0)|0;if((S|0)<0){y=S;Y=94;break}else{continue}}Z=c[(c[V>>2]|0)+(K<<2)>>2]|0;K=Z+12|0;_=c[K>>2]|0;S=_;U=c[S>>2]|0;T=c[S+4>>2]|0;$=Z+40|0;c[O>>2]=1;c[N>>2]=1e6;aa=KDb(U,T,$,l)|0;T=F;U=c[q>>2]|0;if((U|0)!=0){ba=2147483647;ca=-1;da=0;ea=0;fa=U;while(1){U=c[(c[V>>2]|0)+(ea<<2)>>2]|0;ga=c[U+12>>2]|0;do{if((c[U+76>>2]|0)>47|(ga|0)==0){ha=da;ia=ba;ja=ca;ka=fa}else{if((c[ga+1112>>2]|0)==0){ha=da;ia=ba;ja=ca;ka=fa;break}la=ga+1104|0;ma=c[la>>2]|0;na=c[la+4>>2]|0;c[L>>2]=1;c[J>>2]=1e6;la=KDb(ma,na,U+40|0,m)|0;na=F;ma=(na|0)<=(T|0)&((na|0)<(T|0)|la>>>0<=aa>>>0)&((na|0)<(ba|0)|(na|0)==(ba|0)&la>>>0<ca>>>0);ha=ma?U:da;ia=ma?na:ba;ja=ma?la:ca;ka=c[q>>2]|0}}while(0);U=ea+1|0;if(U>>>0<ka>>>0){ba=ia;ca=ja;da=ha;ea=U;fa=ka}else{break}}if((ha|0)!=0){Y=31;break}}fa=_+24|0;ea=c[fa>>2]|0;if((ea|0)<2){oa=2147483647}else{oa=(ea|0)<32?ea<<10:ea}ea=_+8|0;da=c[ea>>2]|0;ca=Ty(r,0,0,1)|0;c[W>>2]=ca;c[W+4>>2]=F;ca=TS(r,e,(oa|0)>(da|0)?da:oa)|0;if((ca|0)<0){y=ca;Y=94;break}da=_+1072|0;do{if((c[da>>2]|0)!=0){if(!((c[Q>>2]|0)>>>0<1073741823>>>0)){break}ba=GZ(e,0,1024)|0;if((ba|0)==0){yDb(M,16,2299136,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;break}else{UGb(ba|0,_+48|0,1024)|0;c[da>>2]=0;break}}}while(0);da=c[s>>2]|0;do{if((da|0)==0){ba=Z+8|0;aa=c[ba>>2]|0;do{if((c[aa+8>>2]|0)==3){if((c[aa+52>>2]|0)!=0){break}T=c[Q>>2]|0;if((T|0)<=6){break}u=c[P>>2]|0;if((QGb(u,2266304)|0)!=0){break}D=u+5|0;if(!((d[D]|d[D+1|0]<<8)<<16>>16<<16>>16==2)){break}c[h>>2]=50;D=c[K>>2]|0;I=Oy(u+7|0,T-7|0,0,0,0,0,0)|0;c[j>>2]=I;T=rz(I)|0;do{if(!(T>>>0>((c[I+16>>2]|0)-(c[I+12>>2]|0)|0)>>>0)){u=yz(I,T,R,256)|0;Vy(c[j>>2]|0,T-u|0,0)|0;if((a[R]|0)!=0){CBb(Z+88|0,2251192,R,0)|0}pz(c[j>>2]|0)|0;rz(c[j>>2]|0)|0;u=c[j>>2]|0;U=c[u+12>>2]|0;ga=(c[u+16>>2]|0)-U|0;c[n>>2]=0;c[H>>2]=U;c[G>>2]=ga;ga=ZS(k,1,h)|0;if((ga|0)==0){break}U=tN()|0;u=D+1080|0;c[u>>2]=U;if((U|0)==0){break}c[U+16>>2]=c[j>>2];if((aT(u,9203520,ga,0)|0)==0){cT(c[u>>2]|0,D+1088|0)|0;UGb(c[ba>>2]|0,c[(c[c[(c[u>>2]|0)+28>>2]>>2]|0)+8>>2]|0,960)|0;c[(c[(c[c[(c[u>>2]|0)+28>>2]>>2]|0)+8>>2]|0)+96>>2]=0;ga=c[c[(c[u>>2]|0)+28>>2]>>2]|0;MT(Z,64,c[ga+40>>2]|0,c[ga+44>>2]|0)}c[D+1168>>2]=c[P>>2];TGb(w|0,0,80)|0;ga=YGb(c[S>>2]|0,c[S+4>>2]|0,1,0)|0;c[S>>2]=ga;c[S+4>>2]=F;c[t>>2]=-1;c[ea>>2]=0;continue a}}while(0);$Db(g)}}while(0);aa=c[S>>2]|0;D=c[S+4>>2]|0;c[E>>2]=aa;c[E+4>>2]=D;T=c[fa>>2]|0;if((T|0)!=0){I=eHb(aa,D,T,(T|0)<0|0?-1:0)|0;c[E>>2]=I;c[E+4>>2]=F}c[C>>2]=c[t>>2];do{if((c[(c[ba>>2]|0)+8>>2]|0)==0){I=Z+400|0;if((c[I>>2]|0)==0){Y=73;break}T=oT(Z,c[S>>2]|0,c[S+4>>2]|0,0)|0;D=c[I>>2]|0;if(!((T|0)>-1)){break}I=D+(T*24|0)+8|0;if(!((c[I>>2]|0)==(c[S>>2]|0)&(c[I+4>>2]|0)==(c[S+4>>2]|0))){break}b:do{if((T|0)==((c[Z+404>>2]|0)-1|0)){I=(ca|0)>256?256:ca;if((I|0)<=0){break}if((c[(c[ba>>2]|0)+48>>2]|0)==13){pa=0;qa=-1}else{break}while(1){if((qa|0)==438){break}aa=d[(c[P>>2]|0)+pa|0]|qa<<8;ga=pa+1|0;if((ga|0)<(I|0)){pa=ga;qa=aa}else{break b}}if((d[(c[P>>2]|0)+pa|0]|0)>>>0<64>>>0){break}I=D+(T*24|0)+16|0;c[I>>2]=c[I>>2]&-2}}while(0);if((c[D+(T*24|0)+16>>2]&1|0)==0){break}c[A>>2]=c[A>>2]|1}else{Y=73}}while(0);if((Y|0)==73){Y=0;c[A>>2]=c[A>>2]|1}ba=c[Q>>2]|0;do{if((c[fa>>2]|0)==0){I=c[_+1076>>2]|0;if((I|0)==0){ra=1;break}ra=(ba-1+I|0)/(I|0)|0}else{ra=ba}}while(0);ba=YGb(c[S>>2]|0,c[S+4>>2]|0,ra,(ra|0)<0|0?-1:0)|0;c[S>>2]=ba;c[S+4>>2]=F}else{ba=c[z>>2]|0;I=c[x>>2]|0;aa=yB(da,e,c[P>>2]|0,c[Q>>2]|0,c[B>>2]|0,c[B+4>>2]|0)|0;c[x>>2]=I;c[z>>2]=ba;c[A>>2]=c[A>>2]|1;if((aa|0)>=0){break}BZ(e)}}while(0);da=c[ea>>2]|0;c[ea>>2]=da-ca;if((da|0)==(ca|0)){c[t>>2]=-1;c[_+12>>2]=0}sa=(c[v>>2]|0)==0;if(!sa){Y=81;break}da=c[B>>2]|0;S=c[B+4>>2]|0;fa=-1;ta=_+1176|0;if(!((S|0)>(fa|0)|(S|0)==(fa|0)&da>>>0>-1>>>0)){Y=83;break}fa=c[ta+4>>2]|0;if(!((fa|0)>(S|0)|(fa|0)==(S|0)&(c[ta>>2]|0)>>>0>da>>>0)){Y=86;break}BZ(e)}do{if((Y|0)==31){e=c[ha+12>>2]|0;B=e+1088|0;UGb(w|0,B|0,80)|0;c[C>>2]=c[ha>>2];if((cT(c[e+1080>>2]|0,B)|0)>=0){y=0;i=f;return y|0}c[e+1112>>2]=0;y=0;i=f;return y|0}else if((Y|0)==81){e=_+1176|0;c[e>>2]=0;c[e+4>>2]=0;y=0;i=f;return y|0}else if((Y|0)==83){c[ta>>2]=0;c[ta+4>>2]=0}else if((Y|0)==86){e=_+1176|0;c[e>>2]=0;c[e+4>>2]=0;if(sa){break}else{y=0}i=f;return y|0}else if((Y|0)==94){i=f;return y|0}}while(0);if((c[Z+404>>2]|0)<=1){y=0;i=f;return y|0}if((c[p+56>>2]|0)<=1){y=0;i=f;return y|0}Z=c[E>>2]|0;Y=c[E+4>>2]|0;c[o>>2]=1;c[o+4>>2]=1e6;E=KDb(Z,Y,$,o)|0;o=F;$=p+88|0;p=c[$>>2]|0;Y=c[$+4>>2]|0;Z=ZGb(p,Y,E,o)|0;sa=F;_=0;if((sa|0)>(_|0)|(sa|0)==(_|0)&Z>>>0>2e6>>>0){c[v>>2]=1;yDb(M,32,2281648,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;y=0;i=f;return y|0}if(!((Y|0)<(o|0)|(Y|0)==(o|0)&p>>>0<E>>>0)){y=0;i=f;return y|0}c[$>>2]=E;c[$+4>>2]=o;y=0;i=f;return y|0}function iy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[a+12>>2]|0;d=a+24|0;e=c[d>>2]|0;if((e|0)==0){f=b+72|0;g=f;h=c[g>>2]|0;i=h;ZDb(i);return 0}j=a+28|0;a=0;k=e;while(1){e=c[(c[(c[j>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;if((e|0)==0){l=k}else{m=e+1080|0;n=c[m>>2]|0;if((n|0)!=0){$Db(n+16|0);KT(m)}ZDb(c[e+1168>>2]|0);BZ(e+1088|0);l=c[d>>2]|0}e=a+1|0;if(e>>>0<l>>>0){a=e;k=l}else{break}}f=b+72|0;g=f;h=c[g>>2]|0;i=h;ZDb(i);return 0}function jy(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;g=i;h=c[a+12>>2]|0;j=h+72|0;k=(c[j>>2]|0)==0?b:0;b=h+56|0;if((c[b>>2]|0)==0){ky(a);c[b>>2]=c[b>>2]|1}if(!((k|0)>-1)){yDb(0,0,2153808,(l=i,i=i+24|0,c[l>>2]=2084768,c[l+8>>2]=2033888,c[l+16>>2]=1597,l)|0);i=l;Cd();return 0}b=a+28|0;m=c[(c[b>>2]|0)+(k<<2)>>2]|0;k=(c[m+12>>2]|0)+24|0;n=c[k>>2]|0;o=(n|0)>1;p=gHb(o?n:1,o?(n|0)<0|0?-1:0:0,d,e)|0;n=oT(m,p,F,f)|0;if((n|0)<0){p=c[m+404>>2]|0;if((p|0)<=0){q=-1094995529;i=g;return q|0}o=c[k>>2]|0;r=(o|0)>1;s=gHb(r?o:1,r?(o|0)<0|0?-1:0:0,d,e)|0;e=F;d=c[m+400>>2]|0;o=d+8|0;r=c[o>>2]|0;t=c[o+4>>2]|0;o=d+((p-1|0)*24|0)+8|0;p=c[o>>2]|0;d=c[o+4>>2]|0;yDb(a,48,1989128,(l=i,i=i+48|0,c[l>>2]=s,c[l+8>>2]=e,c[l+16>>2]=r,c[l+24>>2]=t,c[l+32>>2]=p,c[l+40>>2]=d,l)|0);i=l;q=-1094995529;i=g;return q|0}d=c[m+400>>2]|0;p=d+(n*24|0)|0;t=c[p>>2]|0;r=c[p+4>>2]|0;p=d+(n*24|0)+8|0;n=c[k>>2]|0;k=(n|0)>1;d=eHb(c[p>>2]|0,c[p+4>>2]|0,k?n:1,k?(n|0)<0|0?-1:0:0)|0;n=F;if((c[j>>2]|0)!=0){k=Ty(c[a+16>>2]|0,t,r,0)|0;p=F;e=0;if((p|0)<(e|0)|(p|0)==(e|0)&k>>>0<0>>>0){q=-1;i=g;return q|0}zB(c[j>>2]|0,d,n);c[h+68>>2]=-1;q=0;i=g;return q|0}j=a+24|0;do{if((c[j>>2]|0)==0){u=r;v=t}else{k=m+40|0;e=r;p=t;s=0;a:while(1){o=c[(c[b>>2]|0)+(s<<2)>>2]|0;w=c[o+12>>2]|0;c[w+8>>2]=0;c[w+12>>2]=0;x=w+1080|0;do{if((c[x>>2]|0)==0){if((c[o+404>>2]|0)<1){y=e;z=p;break}A=o+40|0;B=c[A>>2]|0;C=gHb(c[w+20>>2]|0,0,B,(B|0)<0|0?-1:0)|0;B=F;D=c[o+44>>2]|0;E=gHb(c[w+16>>2]|0,0,D,(D|0)<0|0?-1:0)|0;if(!((C|0)==(E|0)&(B|0)==(F|0))){G=21;break a}B=KDb(d,n,k,A)|0;A=c[w+24>>2]|0;E=(A|0)>1;C=gHb(E?A:1,E?(A|0)<0|0?-1:0:0,B,F)|0;B=oT(o,C,F,((c[(c[o+8>>2]|0)+8>>2]|0)!=0?4:0)|f|1)|0;C=(c[o+400>>2]|0)+(((B|0)<0?0:B)*24|0)|0;B=c[C>>2]|0;A=c[C+4>>2]|0;C=w+1176|0;c[C>>2]=B;c[C+4>>2]=A;C=(e|0)>(A|0)|(e|0)==(A|0)&p>>>0>B>>>0;y=C?A:e;z=C?B:p}else{B=KDb(d,n,k,o+40|0)|0;C=F;A=w+1088|0;BZ(A);if(!((tT(c[x>>2]|0,0,0,-2147483648,B,C,B,C,0)|0)>-1)){if(!((tT(c[x>>2]|0,0,B,C,B,C,-1,2147483647,0)|0)>-1)){y=e;z=p;break}}cT(c[x>>2]|0,A)|0;y=e;z=p}}while(0);x=s+1|0;H=c[j>>2]|0;if(x>>>0<H>>>0){e=y;p=z;s=x}else{break}}if((G|0)==21){yDb(0,0,2153808,(l=i,i=i+24|0,c[l>>2]=1955696,c[l+8>>2]=2033888,c[l+16>>2]=1654,l)|0);i=l;Cd();return 0}if((H|0)==0){u=y;v=z;break}s=m+40|0;p=h+64|0;e=0;k=H;while(1){x=c[(c[b>>2]|0)+(e<<2)>>2]|0;w=c[x+12>>2]|0;do{if((c[w+1080>>2]|0)==0){if((c[x+404>>2]|0)<1){I=k;break}o=KDb(d,n,s,x+40|0)|0;A=c[w+24>>2]|0;C=(A|0)>1;B=gHb(C?A:1,C?(A|0)<0|0?-1:0:0,o,F)|0;o=oT(x,B,F,((c[(c[x+8>>2]|0)+8>>2]|0)!=0?4:0)|f|1)|0;B=(o|0)<0?0:o;o=x+400|0;b:do{if((c[p>>2]|0)==0){A=B;while(1){if((A|0)<=0){J=A;break b}C=A-1|0;E=(c[o>>2]|0)+(C*24|0)|0;D=c[E+4>>2]|0;if((D|0)<(y|0)|(D|0)==(y|0)&(c[E>>2]|0)>>>0<z>>>0){J=A;break}else{A=C}}}else{J=B}}while(0);B=(c[o>>2]|0)+(J*24|0)+8|0;A=c[B+4>>2]|0;C=w;c[C>>2]=c[B>>2];c[C+4>>2]=A;I=c[j>>2]|0}else{I=k}}while(0);w=e+1|0;if(w>>>0<I>>>0){e=w;k=I}else{u=y;v=z;break}}}}while(0);z=Ty(c[a+16>>2]|0,v,u,0)|0;u=F;v=0;if((u|0)<(v|0)|(u|0)==(v|0)&z>>>0<0>>>0){yDb(a,16,1928552,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;q=-1;i=g;return q|0}else{c[h+68>>2]=-1;l=h+88|0;c[l>>2]=-2147483648;c[l+4>>2]=-1;q=0;i=g;return q|0}return 0}function ky(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;g=Ty(f,0,0,1)|0;h=F;i=d+16|0;j=Ty(f,c[i>>2]|0,c[i+4>>2]|0,0)|0;i=F;k=0;if((i|0)<(k|0)|(i|0)==(k|0)&j>>>0<0>>>0){l=Ty(f,g,h,0)|0;m=F;return}j=a+24|0;k=a+28|0;i=d+56|0;d=-1;while(1){n=rz(f)|0;o=rz(f)|0;if((Xy(f)|0)!=0){p=35;break}q=Ty(f,0,0,1)|0;r=F;s=YGb(o&1,0,o,0)|0;t=YGb(s,F,q,r)|0;r=F;a:do{if((n|0)==829973609){q=c[b>>2]|0;s=c[e>>2]|0;u=(o|0)/16|0;if((o|0)<16){p=33;break}v=Ty(s,0,0,1)|0;w=F;x=q+40|0;y=YGb(c[x>>2]|0,c[x+4>>2]|0,4,0)|0;Ty(s,y,F,0)|0;if((ly(a,1)|0)==0){y=Ty(s,0,0,1)|0;z=YGb(y,F,-8,-1)|0;A=F;B=z}else{A=0;B=0}c[q+68>>2]=-1;Ty(s,v,w,0)|0;w=c[j>>2]|0;do{if((w|0)==1){if((c[(c[(c[c[k>>2]>>2]|0)+8>>2]|0)+52>>2]|0)!=1397050701){C=0;D=0;E=A;G=B;break}C=c[x+4>>2]|0;D=c[x>>2]|0;E=0;G=0}else{C=0;D=0;E=A;G=B}}while(0);do{if((o|0)>15){x=(G|0)==0&(E|0)==0;v=q+64|0;z=0;y=1;H=-1;I=-1;J=C;K=D;L=0;while(1){if((Xy(s)|0)!=0){p=33;break a}M=rz(s)|0;N=rz(s)|0;O=rz(s)|0;P=rz(s)|0;Q=(M>>>8&255)-528+((M&255)*10|0)|0;if(Q>>>0<(c[j>>2]|0)>>>0){M=c[(c[k>>2]|0)+(Q<<2)>>2]|0;Q=c[M+12>>2]|0;R=(y|0)==0|x;S=O;O=0;T=ZGb(G,E,S,O)|0;U=R?y:0;V=R?K:T;T=R?J:F;R=YGb(V,T,S,O)|0;O=R;if((H|0)==(O|0)){c[v>>2]=1}if((I|0)==(O|0)|(P|0)==0){W=I}else{S=Q+32|0;jT(M,R|0,F&0,c[S>>2]|0,c[S+4>>2]|0,P,0,N>>>4&1)|0;W=O}do{if((c[Q+24>>2]|0)==0){S=c[Q+1076>>2]|0;if((S|0)==0){X=1;break}X=(P-1+S|0)/(S|0)|0}else{X=P}}while(0);P=Q+32|0;S=YGb(c[P>>2]|0,c[P+4>>2]|0,X,(X|0)<0|0?-1:0)|0;c[P>>2]=S;c[P+4>>2]=F;Y=N&16|L;Z=T;_=V;$=W;aa=O;ba=U}else{Y=L;Z=J;_=K;$=I;aa=H;ba=y}P=z+1|0;if((P|0)<(u|0)){z=P;y=ba;H=aa;I=$;J=Z;K=_;L=Y}else{break}}if((Y|0)!=0){break}ca=c[j>>2]|0;p=26}else{ca=w;p=26}}while(0);do{if((p|0)==26){p=0;if((ca|0)==0){break}else{da=0;ea=ca}while(1){w=c[(c[k>>2]|0)+(da<<2)>>2]|0;if((c[w+404>>2]|0)==0){fa=ea}else{u=(c[w+400>>2]|0)+16|0;c[u>>2]=c[u>>2]|1;fa=c[j>>2]|0}u=da+1|0;if(u>>>0<fa>>>0){da=u;ea=fa}else{break}}}}while(0);c[i>>2]=2;ga=0}else if((n|0)==1414744396){if((rz(f)|0)!=1330007625){ga=d;break}DO(a,o-4|0,0)|0;ga=d}else{p=33}}while(0);if((p|0)==33){p=0;if((d|0)==0){p=35;break}else{ga=d}}o=Ty(f,t,r,0)|0;n=F;u=0;if((n|0)<(u|0)|(n|0)==(u|0)&o>>>0<0>>>0){p=35;break}else{d=ga}}if((p|0)==35){l=Ty(f,g,h,0)|0;m=F;return}}function ly(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=Ty(f,0,0,1)|0;h=F;a:do{if((Xy(f)|0)==0){j=e+32|0;k=e+24|0;l=a+24|0;m=e+72|0;n=e+48|0;o=a+28|0;p=a;q=(b|0)==0;r=h;s=g;b:while(1){t=YGb(s,r,9,0)|0;u=F;v=r;w=s;x=-1;y=-1;z=-1;A=-1;B=-1;C=-1;D=-1;c:while(1){E=lz(f)|0;G=(E<<24)+z+(A<<8)+(B<<16)|0;H=(x-48|0)>>>0<10>>>0;do{if(H){if(!((y-48|0)>>>0<10>>>0)){I=100;break}I=(x*10|0)-528+y|0}else{I=100}}while(0);J=c[j+4>>2]|0;K=0;L=ZGb(0,0,((J|0)>(K|0)|(J|0)==(K|0)&(c[j>>2]|0)>>>0>0>>>0)&1,0)|0;M=G;N=0;K=YGb(w&L,v&F,M,N)|0;L=F;J=c[k+4>>2]|0;do{if(L>>>0>J>>>0|L>>>0==J>>>0&K>>>0>(c[k>>2]|0)>>>0|C>>>0>127>>>0){O=y}else{P=(C|0)==105;do{if(P){if((D|0)==120){if(I>>>0<(c[l>>2]|0)>>>0){Q=14;break c}else{Q=11;break}}else if((D|0)==100){if((x|0)==120&(y|0)==49){Q=14;break c}else{break}}else{break}}else{Q=11}}while(0);if((Q|0)==11){Q=0;if((C|0)==74&(D|0)==85&(x|0)==78&(y|0)==75){Q=14;break c}if(P&(D|0)==100&(x|0)==120&(y|0)==49){Q=14;break c}}if((C|0)==76&(D|0)==73&(x|0)==83&(y|0)==84){Q=17;break c}R=c[m>>2]|0;do{if((R|0)==0){if(!((C-48|0)>>>0<10>>>0&(D-48|0)>>>0<10>>>0)){S=100;break}S=(C*10|0)-528+D|0}else{S=0}}while(0);P=ZGb(w,v,c[n>>2]|0,c[n+4>>2]|0)|0;if((P&1|0)==0&(F&0|0)==0){if((D-48|0)>>>0>9>>>0|H^1){T=100}else{T=(D*10|0)-528+x|0}if(T>>>0<(c[l>>2]|0)>>>0){O=y;break}}P=c[l>>2]|0;if((x|0)==105&(y|0)==120){if(S>>>0<P>>>0){Q=27;break c}else{U=120}}else{U=y}if(!(S>>>0<P>>>0)){O=U;break}V=c[o>>2]|0;W=c[V+(S<<2)>>2]|0;X=c[W+12>>2]|0;Y=X;if((X|0)==0){yDb(p,24,1885808,(Z=i,i=i+8|0,c[Z>>2]=S,Z)|0);i=Z;O=U;break}do{if(P>>>0>1>>>0){_=c[V+4>>2]|0;$=c[_+12>>2]|0;aa=$;if((x|0)!=119){ba=S;ca=Y;da=W;ea=R;break}if(!((y|0)==98&(S|0)==0)){ba=S;ca=Y;da=W;ea=R;break}if((c[(c[W+8>>2]|0)+8>>2]|0)!=0){ba=0;ca=Y;da=W;ea=R;break}if((c[(c[_+8>>2]|0)+8>>2]|0)!=1){ba=0;ca=Y;da=W;ea=R;break}if((c[X+40>>2]|0)!=25699){ba=0;ca=Y;da=W;ea=R;break}if((c[$+40>>2]|0)!=30562){if((c[$+44>>2]|0)!=0){ba=0;ca=Y;da=W;ea=R;break}}yDb(p,24,2343688,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;ba=1;ca=aa;da=_;ea=c[m>>2]|0}else{ba=S;ca=Y;da=W;ea=R}}while(0);do{if((ea|0)==0){R=c[da+76>>2]|0;if((R|0)>-1&(G|0)==0){if(q){fa=0;Q=44;break c}else{break}}else{if((R|0)>47&q){fa=G;Q=44;break c}else{break}}}}while(0);if((x|0)==112){if((y|0)==99&G>>>0<1029>>>0){Q=50;break c}}ga=ca+44|0;ha=c[ga>>2]|0;if(((ha|0)<5|((u|0)>(v|0)|(u|0)==(v|0)&t>>>0>w>>>0))&x>>>0<128>>>0&y>>>0<128>>>0){break b}if(((x<<8)+y|0)==(c[ca+40>>2]|0)){break b}else{O=y}}}while(0);H=YGb(w,v,1,0)|0;K=F;if((Xy(f)|0)==0){v=K;w=H;C=D;D=x;x=O;y=z;z=A;A=B;B=E}else{break a}}if((Q|0)==14){Q=0;Vy(f,M,N)|0;}else if((Q|0)==17){Q=0;Vy(f,4,0)|0;}else if((Q|0)==27){Q=0;Vy(f,M,N)|0;}else if((Q|0)==44){Q=0;do{if((c[ca+24>>2]|0)==0){B=c[ca+1076>>2]|0;if((B|0)==0){ia=1;break}ia=(fa-1+B|0)/(B|0)|0}else{ia=fa}}while(0);B=ca|0;A=YGb(c[B>>2]|0,c[B+4>>2]|0,ia,(ia|0)<0|0?-1:0)|0;c[B>>2]=A;c[B+4>>2]=F;Vy(f,M,N)|0;}else if((Q|0)==50){Q=0;B=lz(f)|0;A=B+255+(lz(f)|0)&255;pz(f)|0;if((B|0)<=(A|0)){z=B;do{c[ca+48+(z<<2)>>2]=(vz(f)|0)>>>8|-16777216;z=z+1|0;}while((z|0)<=(A|0))}c[ca+1072>>2]=1}s=Ty(f,0,0,1)|0;r=F;if((Xy(f)|0)!=0){break a}}if(!q){ja=0;i=d;return ja|0}r=(x<<8)+y|0;s=ca+40|0;if((r|0)==(c[s>>2]|0)){ka=ha+1|0}else{c[s>>2]=r;ka=0}c[ga>>2]=ka;c[e+68>>2]=ba;c[ca+12>>2]=G+8;c[ca+8>>2]=G;do{if((G|0)==0){if((c[ca+24>>2]|0)==0){break}else{ja=0}i=d;return ja|0}}while(0);q=Ty(f,0,0,1)|0;r=YGb(q,F,-8,-1)|0;q=F;s=c[da+400>>2]|0;do{if((s|0)!=0){m=c[da+404>>2]|0;if((m|0)==0){break}p=s+((m-1|0)*24|0)|0;m=c[p+4>>2]|0;if(m>>>0<q>>>0|m>>>0==q>>>0&(c[p>>2]|0)>>>0<r>>>0){break}else{ja=0}i=d;return ja|0}}while(0);s=ca|0;jT(da,r,q,c[s>>2]|0,c[s+4>>2]|0,G,0,1)|0;ja=0;i=d;return ja|0}}while(0);G=c[f+76>>2]|0;ja=(G|0)==0?-541478725:G;i=d;return ja|0}function my(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=pz(f)|0;h=lz(f)|0;j=lz(f)|0;k=rz(f)|0;l=rz(f)|0;m=sz(f)|0;n=F;o=(l>>>8&255)-528+((l&255)*10|0)|0;l=e+24|0;p=c[l>>2]|0;q=c[l+4>>2]|0;if(o>>>0>=(c[a+24>>2]|0)>>>0|(o|0)<0){r=-1094995529;i=d;return r|0}l=c[(c[a+28>>2]|0)+(o<<2)>>2]|0;o=c[l+12>>2]|0;if((h|0)!=0){r=-1094995529;i=d;return r|0}rz(f)|0;h=(j|0)!=0;if(h&(g|0)!=2|(j|0)>1){r=-1094995529;i=d;return r|0}j=0;do{if((q|0)<(j|0)|(q|0)==(j|0)&p>>>0<1>>>0|((n|0)<(q|0)|(n|0)==(q|0)&m>>>0<p>>>0)){s=n;t=m}else{yDb(a,16,2086112,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;g=n;v=(n|0)<0|0?-1:0;if(!((g|0)==(m|0|0)&(v|0)==(n&0|0))){r=-1094995529;i=d;return r|0}w=1;if(((v|0)<(q|0)|(v|0)==(q|0)&g>>>0<p>>>0)&((q|0)<(w|0)|(q|0)==(w|0)&p>>>0<0>>>0)){s=v;t=g;break}else{r=-1094995529}i=d;return r|0}}while(0);a:do{if((k|0)>0){p=YGb(t,s,-8,-1)|0;q=F;n=e+64|0;m=o+24|0;j=o+1076|0;g=o+32|0;v=e+76|0;if(h){x=-1;y=-1;z=0}else{w=0;A=b;while(1){B=sz(f)|0;C=F;rz(f)|0;D=rz(f)|0;if((Xy(f)|0)!=0){r=-1094995529;E=28;break}G=Ty(f,0,0,1)|0;H=F;if((c[v>>2]|0)>1e3){E=22;break}I=YGb(B,C,8,0)|0;C=Ty(f,I,F,0)|0;I=F;B=0;if((I|0)<(B|0)|(I|0)==(B|0)&C>>>0<0>>>0){r=-1;E=28;break}c[v>>2]=(c[v>>2]|0)+1;my(a,A)|0;c[v>>2]=(c[v>>2]|0)-1;C=Ty(f,G,H,0)|0;H=F;G=0;if((H|0)<(G|0)|(H|0)==(G|0)&C>>>0<0>>>0){E=25;break}C=w+1|0;if((C|0)<(k|0)){w=C;A=D+A|0}else{break a}}if((E|0)==22){yDb(a,16,2081064,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;r=-1094995529;i=d;return r|0}else if((E|0)==25){yDb(a,16,2075624,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;r=-1;i=d;return r|0}else if((E|0)==28){i=d;return r|0}}while(1){A=rz(f)|0;w=YGb(p,q,A,0)|0;v=F;D=rz(f)|0;C=D&2147483647;if((Xy(f)|0)!=0){r=-1094995529;break}G=(y|0)==(w|0)&(x|0)==(v|0);if(G|(A|0)==0){c[n>>2]=1}do{if(G){E=16}else{if((C|0)==0){if((c[m>>2]|0)!=0){J=0;break}}jT(l,w,v,c[g>>2]|0,c[g+4>>2]|0,C,0,D>>>31^1)|0;E=16}}while(0);do{if((E|0)==16){E=0;if((c[m>>2]|0)!=0){J=C;break}D=c[j>>2]|0;if((D|0)==0){J=1;break}J=(C-1+D|0)/(D|0)|0}}while(0);C=YGb(c[g>>2]|0,c[g+4>>2]|0,J,(J|0)<0|0?-1:0)|0;c[g>>2]=C;c[g+4>>2]=F;C=z+1|0;if((C|0)<(k|0)){x=v;y=w;z=C}else{break a}}i=d;return r|0}}while(0);c[e+56>>2]=2;r=0;i=d;return r|0}function ny(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;b=i;i=i+56|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=b+32|0;j=b+40|0;k=b+48|0;l=c[a+12>>2]|0;m=a+16|0;n=c[m>>2]|0;o=a+24|0;p=c[o>>2]|0;if(p>>>0>100>>>0){yDb(a,16,2237472,(q=i,i=i+8|0,c[q>>2]=100,q)|0);i=q;r=-22;i=b;return r|0}s=a+28|0;t=0;u=p;while(1){if(!(t>>>0<u>>>0)){break}p=cEb(48)|0;c[(c[(c[s>>2]|0)+(t<<2)>>2]|0)+12>>2]=p;if((c[(c[(c[s>>2]|0)+(t<<2)>>2]|0)+12>>2]|0)==0){r=-12;v=77;break}t=t+1|0;u=c[o>>2]|0}if((v|0)==77){i=b;return r|0}c[l+32>>2]=0;u=ty(a,n,2224792,2214776)|0;t=F;Yy(n,1751742049);Yy(n,56);p=c[o>>2]|0;do{if((p|0)==0){w=0;x=0;v=12}else{y=c[s>>2]|0;z=p>>>0>1>>>0;A=0;B=0;C=0;do{D=c[(c[y+(B<<2)>>2]|0)+8>>2]|0;C=(c[D+72>>2]|0)+C|0;A=(c[D+8>>2]|0)==0?D:A;B=B+1|0;}while(B>>>0<p>>>0);B=z?p:1;y=(C|0)/8|0;if((A|0)==0){w=y;x=B;v=12;break}D=c[A+104>>2]|0;E=gHb(D,(D|0)<0|0?-1:0,1e6,0)|0;D=c[A+108>>2]|0;G=eHb(E,F,D,(D|0)<0|0?-1:0)|0;Yy(n,G);H=y;I=B;J=A;K=1}}while(0);if((v|0)==12){Yy(n,0);H=w;I=x;J=0;K=0}Yy(n,H);Yy(n,0);H=n+88|0;if((c[H>>2]|0)==0){Yy(n,2304)}else{Yy(n,2320)}x=Ty(n,0,0,1)|0;w=l+24|0;c[w>>2]=x;c[w+4>>2]=F;Yy(n,0);Yy(n,0);Yy(n,c[o>>2]|0);Yy(n,1048576);if(K){Yy(n,c[J+120>>2]|0);Yy(n,c[J+124>>2]|0)}else{Yy(n,0);Yy(n,0)}Yy(n,0);Yy(n,0);Yy(n,0);Yy(n,0);a:do{if((I|0)>0){J=h|0;K=h+4|0;o=g|0;w=g+4|0;x=0;b:while(1){p=c[(c[(c[s>>2]|0)+(x<<2)>>2]|0)+12>>2]|0;B=EO(n,2084664)|0;y=F;Yy(n,1819440243);G=c[(c[(c[s>>2]|0)+(x<<2)>>2]|0)+8>>2]|0;D=EO(n,2185664)|0;E=F;L=G+8|0;M=c[L>>2]|0;if((M|0)==2){Yy(n,1937006948);v=27}else if((M|0)==3){if((c[G+48>>2]|0)==94211){v=24}else{v=23;break}}else if((M|0)==0){v=24}else if((M|0)==1){Yy(n,1935963489);v=27}else{v=28}if((v|0)==24){v=0;Yy(n,1935960438);v=27}if((v|0)==27){v=0;if((c[L>>2]|0)==0){v=29}else{v=28}}do{if((v|0)==28){v=0;if((c[G+48>>2]|0)==94211){v=29;break}Yy(n,1)}}while(0);if((v|0)==29){v=0;Yy(n,c[G+52>>2]|0)}Yy(n,0);az(n,0);az(n,0);Yy(n,0);KO(G,d,e,f);M=G+48|0;do{if((c[L>>2]|0)==0){if((c[M>>2]|0)==94211){break}N=c[d>>2]|0;O=(N|0)<0|0?-1:0;P=c[f>>2]|0;Q=gHb(P,(P|0)<0|0?-1:0,1e3,0)|0;P=F;if(!((O|0)>(P|0)|(O|0)==(P|0)&N>>>0>Q>>>0)){break}c[d>>2]=600;c[f>>2]=1}}while(0);MT(c[(c[s>>2]|0)+(x<<2)>>2]|0,64,c[f>>2]|0,c[d>>2]|0);if((c[M>>2]|0)==94211){c[d>>2]=0;c[f>>2]=0;R=0}else{R=c[f>>2]|0}Yy(n,R);Yy(n,c[d>>2]|0);Yy(n,0);Q=Ty(n,0,0,1)|0;N=p;c[N>>2]=Q;c[N+4>>2]=F;if((c[H>>2]|0)==0){Yy(n,1073741824)}else{Yy(n,0)}N=c[L>>2]|0;if((N|0)==1){Yy(n,12288)}else if((N|0)==0){Yy(n,1048576)}else{Yy(n,0)}Yy(n,-1);Yy(n,c[e>>2]|0);Yy(n,0);N=G+120|0;az(n,c[N>>2]|0);Q=G+124|0;az(n,c[Q>>2]|0);FO(n,D,E);do{if((c[L>>2]|0)!=2){P=EO(n,2141840)|0;O=F;S=c[L>>2]|0;if((S|0)==3){if((c[M>>2]|0)==94211){v=48}}else if((S|0)==0){v=48}else if((S|0)==1){T=GO(n,G)|0;if((T|0)<0){r=T;v=77;break b}}else{v=50;break b}if((v|0)==48){v=0;JO(n,G,1240808,0,0)}FO(n,P,O);O=BBb(c[(c[(c[s>>2]|0)+(x<<2)>>2]|0)+88>>2]|0,2123264,0,0)|0;if((O|0)!=0){LO(c[m>>2]|0,2118024,c[O+4>>2]|0)}if((c[M>>2]|0)!=94211){break}O=BBb(c[(c[(c[s>>2]|0)+(x<<2)>>2]|0)+88>>2]|0,2108488,0,0)|0;if((O|0)==0){break}P=Vz(c[O+4>>2]|0,2)|0;if((P|0)==0){break}O=vAb(2096712,(q=i,i=i+8|0,c[q>>2]=P,q)|0)|0;i=q;LO(c[m>>2]|0,2118024,O);ZDb(O)}}while(0);if((c[H>>2]|0)!=0){c[p+36>>2]=0;c[p+32>>2]=0;M=EO(n,2091144)|0;E=p+24|0;c[E>>2]=M;c[E+4>>2]=F;az(n,4);Py(n,0);Py(n,0);Yy(n,0);M=c[L>>2]|0;if((M|0)==0){U=6553600;V=1660944384}else{U=(M|0)==3?7536640:7798784;V=1644167168}Yy(n,(((x|0)%10|0)<<8)+12288&65280|((x|0)/10|0)+48&255|V|U);dz(n,0,0);M=0;do{dz(n,0,0);M=M+1|0;}while((M|0)<512);FO(n,c[E>>2]|0,c[E+4>>2]|0)}do{if((c[L>>2]|0)==0){M=c[(c[s>>2]|0)+(x<<2)>>2]|0;if((c[M+80>>2]|0)<=0){break}if((c[M+84>>2]|0)<=0){break}M=EO(n,2086104)|0;p=(c[(c[s>>2]|0)+(x<<2)>>2]|0)+80|0;c[J>>2]=c[N>>2];c[K>>2]=c[Q>>2];jFb(g,p,h);p=c[o>>2]|0;D=c[w>>2]|0;iFb(j,k,p,(p|0)<0|0?-1:0,D,(D|0)<0|0?-1:0,65535,0)|0;Yy(n,0);Yy(n,0);Yy(n,Gc(+(1.0/(+(c[G+104>>2]|0)/+(c[G+108>>2]|0))))|0);Yy(n,c[N>>2]|0);Yy(n,c[Q>>2]|0);az(n,c[k>>2]|0);az(n,c[j>>2]|0);Yy(n,c[N>>2]|0);Yy(n,c[Q>>2]|0);Yy(n,1);Yy(n,c[Q>>2]|0);Yy(n,c[N>>2]|0);Yy(n,c[Q>>2]|0);Yy(n,c[N>>2]|0);Yy(n,0);Yy(n,0);Yy(n,0);Yy(n,0);D=M;FO(n,D,(D|0)<0|0?-1:0)}}while(0);FO(n,B,y);x=x+1|0;if((x|0)>=(I|0)){break a}}if((v|0)==23){yDb(a,16,2170232,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1163346256;i=b;return r|0}else if((v|0)==50){x=lGb(S)|0;yDb(a,16,2135944,(q=i,i=i+8|0,c[q>>2]=(x|0)!=0?x:2129872,q)|0);i=q;r=-22;i=b;return r|0}else if((v|0)==77){i=b;return r|0}}}while(0);if((c[H>>2]|0)!=0){H=EO(n,2091144)|0;v=l+16|0;c[v>>2]=H;c[v+4>>2]=F;Yy(n,1819108463);Yy(n,1751936356);Yy(n,248);H=0;do{Yy(n,0);H=H+4|0;}while((H|0)<248);FO(n,c[v>>2]|0,c[v+4>>2]|0)}FO(n,u,t);MO(a);t=c[a+1316>>2]|0;a=(t|0)<0?1016:t;if((a|0)!=0){t=EO(n,2091144)|0;u=F;if((a|0)>0){v=a;do{Yy(n,0);v=v-4|0;}while((v|0)>0)}FO(n,t,u)}u=EO(n,2084664)|0;t=l+8|0;c[t>>2]=u;c[t+4>>2]=F;Yy(n,1769369453);Sy(n);r=0;i=b;return r|0}function oy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;e=i;i=i+88|0;f=e|0;g=e+8|0;h=c[b+12>>2]|0;j=b+16|0;k=c[j>>2]|0;l=c[d+32>>2]|0;m=c[(c[b+28>>2]|0)+(l<<2)>>2]|0;n=c[m+12>>2]|0;o=c[m+8>>2]|0;m=c[d+28>>2]|0;p=o+432|0;a:do{if((c[p>>2]|0)==0){q=d+16|0;r=n+16|0;s=o+48|0;t=g+28|0;u=g+24|0;v=g+32|0;while(1){w=c[q>>2]|0;x=c[q+4>>2]|0;if((w|0)==0&(x|0)==(-2147483648|0)){y=r;break a}z=c[r>>2]|0;A=z;B=(z|0)<0|0?-1:0;if(!((x|0)>(B|0)|(x|0)==(B|0)&w>>>0>A>>>0)){y=r;break a}if((c[s>>2]|0)==94211|(z|0)==0){y=r;break a}C=ZGb(w,x,A,B)|0;D=F;B=0;if((D|0)>(B|0)|(D|0)==(B|0)&C>>>0>6e4>>>0){break}vZ(g);c[t>>2]=0;c[u>>2]=0;c[v>>2]=l;oy(b,g)|0;if((c[p>>2]|0)!=0){y=r;break a}}yDb(b,16,2299048,(r=i,i=i+16|0,c[r>>2]=C,c[r+8>>2]=D,r)|0);i=r;E=-22;i=e;return E|0}else{y=n+16|0}}while(0);c[y>>2]=(c[y>>2]|0)+1;do{if((c[k+88>>2]|0)!=0){y=Ty(k,0,0,1)|0;D=h;C=ZGb(y,F,c[D>>2]|0,c[D+4>>2]|0)|0;y=F;p=0;if(!((y|0)>(p|0)|(y|0)==(p|0)&C>>>0>1073741824>>>0)){break}ry(b);C=h+8|0;FO(k,c[C>>2]|0,c[C+4>>2]|0);if((c[h+32>>2]|0)==1){qy(b)}FO(k,c[D>>2]|0,c[D+4>>2]|0);D=ty(b,k,2281616,2266264)|0;c[C>>2]=D;c[C+4>>2]=F}}while(0);b=f|0;C=o+8|0;o=c[C>>2]|0;a[b]=((l|0)/10|0)+48;a[f+1|0]=((l|0)%10|0)+48;do{if((o|0)==0){a[f+2|0]=100;a[f+3|0]=99}else{l=f+2|0;if((o|0)==3){a[l]=115;a[f+3|0]=98;break}else{a[l]=119;a[f+3|0]=98;break}}}while(0);a[f+4|0]=0;f=c[d+36>>2]<<4&16;if((c[C>>2]|0)==1){C=n+8|0;o=YGb(c[C>>2]|0,c[C+4>>2]|0,m,(m|0)<0|0?-1:0)|0;c[C>>2]=o;c[C+4>>2]=F}if((c[(c[j>>2]|0)+88>>2]|0)!=0){j=n+32|0;C=c[j>>2]|0;o=(C|0)/16384|0;l=(C|0)%16384|0;D=n+36|0;p=n+40|0;y=c[p>>2]|0;do{if((c[D>>2]|0)>(C|0)){G=c[y+(o<<2)>>2]|0}else{g=YDb(y,4,o+1|0)|0;c[p>>2]=g;if((g|0)==0){c[D>>2]=0;c[j>>2]=0;E=-12;i=e;return E|0}g=WDb(196608)|0;c[(c[p>>2]|0)+(o<<2)>>2]=g;g=c[(c[p>>2]|0)+(o<<2)>>2]|0;if((g|0)==0){E=-12;i=e;return E|0}else{c[D>>2]=(c[D>>2]|0)+16384;G=g;break}}}while(0);c[G+(l*12|0)>>2]=f;f=Ty(k,0,0,1)|0;G=h+8|0;h=ZGb(f,F,c[G>>2]|0,c[G+4>>2]|0)|0;G=c[(c[n+40>>2]|0)+(o<<2)>>2]|0;c[G+(l*12|0)+4>>2]=h;c[G+(l*12|0)+8>>2]=m;c[j>>2]=(c[j>>2]|0)+1}Ry(k,b,4);Yy(k,m);Ry(k,c[d+24>>2]|0,m);if((m&1|0)==0){E=0;i=e;return E|0}Py(k,0);E=0;i=e;return E|0}function py(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;do{if((c[d+88>>2]|0)!=0){e=b+32|0;if((c[e>>2]|0)==1){f=b+8|0;FO(d,c[f>>2]|0,c[f+4>>2]|0);qy(a);f=b;FO(d,c[f>>2]|0,c[f+4>>2]|0);break}ry(a);f=b+8|0;FO(d,c[f>>2]|0,c[f+4>>2]|0);f=b;FO(d,c[f>>2]|0,c[f+4>>2]|0);f=Ty(d,0,0,1)|0;g=F;h=b+16|0;i=YGb(c[h>>2]|0,c[h+4>>2]|0,-8,-1)|0;Ty(d,i,F,0)|0;Yy(d,1414744396);Vy(d,16,0)|0;i=c[a+24>>2]|0;if((i|0)==0){j=0}else{h=c[a+28>>2]|0;k=0;l=0;while(1){m=c[h+(l<<2)>>2]|0;n=c[m+8>>2]|0;o=c[m+12>>2]|0;do{if((c[n+8>>2]|0)==0){m=c[o+16>>2]|0;p=(k|0)<(m|0)?m:k}else{if(!(((c[n+48>>2]|0)-86016|0)>>>0<2>>>0)){p=k;break}p=(c[o+16>>2]|0)+k|0}}while(0);o=l+1|0;if(o>>>0<i>>>0){k=p;l=o}else{j=p;break}}}Yy(d,j);Ty(d,f,g,0)|0;sy(a,c[e>>2]|0)}}while(0);d=a+24|0;if((c[d>>2]|0)==0){return 0}j=a+28|0;a=0;do{p=c[(c[(c[j>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;b=p+36|0;l=p+40|0;if((c[b>>2]|0)>16383){k=l;i=0;do{$Db((c[k>>2]|0)+(i<<2)|0);i=i+1|0;}while((i|0)<((c[b>>2]|0)/16384|0|0))}$Db(l);c[p+32>>2]=0;c[b>>2]=0;a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0);return 0}function qy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[a+16>>2]|0;d=c[a+12>>2]|0;if((c[b+88>>2]|0)==0){return}e=EO(b,2321296)|0;f=F;g=a+24|0;h=a+28|0;if((c[g>>2]|0)==0){i=0}else{j=c[h>>2]|0;k=0;while(1){c[(c[(c[j+(k<<2)>>2]|0)+12>>2]|0)+20>>2]=0;l=k+1|0;m=c[g>>2]|0;if(l>>>0<m>>>0){k=l}else{i=m;break}}}k=-1;j=1;m=0;l=0;n=i;a:while(1){if(m>>>0<n>>>0){o=m;p=j;q=n}else{i=(((k|0)%10|0)<<8)+12288&65280|((k|0)/10|0)+48&255;r=l|0;s=l+4|0;t=l+8|0;u=j;while(1){if((u|0)!=0){break a}v=c[(c[h>>2]|0)+(k<<2)>>2]|0;w=c[v+12>>2]|0;x=c[(c[v+8>>2]|0)+8>>2]|0;if((x|0)==0){y=6553600;z=1660944384}else{y=(x|0)==3?7536640:7798784;z=1644167168}Yy(b,i|z|y);Yy(b,c[r>>2]|0);Yy(b,c[s>>2]|0);Yy(b,c[t>>2]|0);x=w+20|0;c[x>>2]=(c[x>>2]|0)+1;x=c[g>>2]|0;if((x|0)==0){u=1}else{o=0;p=1;q=x;break}}}u=c[(c[(c[h>>2]|0)+(o<<2)>>2]|0)+12>>2]|0;t=c[u+20>>2]|0;do{if((c[u+32>>2]|0)>(t|0)){s=(t|0)%16384|0;r=c[(c[u+40>>2]|0)+(((t|0)/16384|0)<<2)>>2]|0;i=r+(s*12|0)|0;if((p|0)==0){if(!((c[r+(s*12|0)+4>>2]|0)>>>0<(c[l+4>>2]|0)>>>0)){A=k;B=0;C=l;break}}A=o;B=0;C=i}else{A=k;B=p;C=l}}while(0);k=A;j=B;m=o+1|0;l=C;n=q}FO(b,e,f);sy(a,c[d+32>>2]|0);return}function ry(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;d=c[a+16>>2]|0;e=c[a+12>>2]|0;if((c[d+88>>2]|0)==0){yDb(0,0,2033696,(f=i,i=i+24|0,c[f>>2]=1906416,c[f+8>>2]=1955616,c[f+16>>2]=430,f)|0);i=f;Cd()}g=e+32|0;h=c[g>>2]|0;if((h|0)>256){yDb(a,16,1885696,(f=i,i=i+16|0,c[f>>2]=h,c[f+8>>2]=256,f)|0);i=f;i=b;return}f=a+24|0;if((c[f>>2]|0)==0){i=b;return}h=a+28|0;a=e+8|0;e=0;do{j=c[(c[h>>2]|0)+(e<<2)>>2]|0;k=c[j+12>>2]|0;l=c[(c[j+8>>2]|0)+8>>2]|0;if((l|0)==0){m=6553600;n=1660944384}else{m=(l|0)==3?7536640:7798784;n=1644167168}l=Ty(d,0,0,1)|0;j=F;Yy(d,(e<<24)+805306368|3176553);o=k+24|0;p=k+32|0;Yy(d,(c[p>>2]<<3)+24|0);az(d,2);Py(d,0);Py(d,1);Yy(d,c[p>>2]|0);Yy(d,(((e|0)%10|0)<<8)+12288&65280|((e|0)/10|0)+48&255|n|m);dz(d,c[a>>2]|0,c[a+4>>2]|0);Yy(d,0);if((c[p>>2]|0)>0){q=k+40|0;k=0;do{r=(k|0)%16384|0;s=c[(c[q>>2]|0)+(((k|0)/16384|0)<<2)>>2]|0;Yy(d,(c[s+(r*12|0)+4>>2]|0)+8|0);Yy(d,(c[s+(r*12|0)>>2]<<27&-2147483648|c[s+(r*12|0)+8>>2]&2147483647)^-2147483648);k=k+1|0;}while((k|0)<(c[p>>2]|0))}Sy(d);k=Ty(d,0,0,1)|0;q=F;r=o;s=YGb(c[r>>2]|0,c[r+4>>2]|0,-8,-1)|0;Ty(d,s,F,0)|0;Yy(d,2019847785);Vy(d,8,0)|0;Yy(d,c[g>>2]|0);s=c[g>>2]<<4;Vy(d,s,(s|0)<0|0?-1:0)|0;dz(d,l,j);s=ZGb(k,q,l,j)|0;Yy(d,s);Yy(d,c[p>>2]|0);Ty(d,k,q,0)|0;e=e+1|0;}while(e>>>0<(c[f>>2]|0)>>>0);i=b;return}function sy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[a+16>>2]|0;j=c[a+12>>2]|0;k=Ty(h,0,0,1)|0;l=F;m=a+24|0;a:do{if((c[m>>2]|0)==0){n=0}else{o=a+28|0;p=0;q=0;while(1){r=c[(c[o>>2]|0)+(q<<2)>>2]|0;s=c[r+12>>2]|0;t=s;u=c[t>>2]|0;v=c[t+4>>2]|0;if((u|0)==0&(v|0)==0){break}t=c[r+8>>2]|0;Ty(h,u,v,0)|0;KO(t,e,f,g);v=c[f>>2]|0;if((v|0)==0){Yy(h,c[s+16>>2]|0)}else{u=s+8|0;r=eHb(c[u>>2]|0,c[u+4>>2]|0,v,(v|0)<0|0?-1:0)|0;Yy(h,r)}if((c[t+8>>2]|0)==0){t=c[s+16>>2]|0;w=(p|0)>(t|0)?p:t}else{w=p}t=q+1|0;if(t>>>0<(c[m>>2]|0)>>>0){p=w;q=t}else{n=w;break a}}yDb(0,0,2033696,(x=i,i=i+24|0,c[x>>2]=1989e3,c[x+8>>2]=1955616,c[x+16>>2]=127,x)|0);i=x;Cd()}}while(0);if((b|0)!=1){y=Ty(h,k,l,0)|0;z=F;i=d;return}b=j+24|0;j=c[b>>2]|0;w=c[b+4>>2]|0;if((j|0)==0&(w|0)==0){yDb(0,0,2033696,(x=i,i=i+24|0,c[x>>2]=1928496,c[x+8>>2]=1955616,c[x+16>>2]=140,x)|0);i=x;Cd()}Ty(h,j,w,0)|0;Yy(h,n);y=Ty(h,k,l,0)|0;z=F;i=d;return}function ty(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[a+12>>2]|0;h=g+32|0;c[h>>2]=(c[h>>2]|0)+1;h=a+24|0;if((c[h>>2]|0)!=0){i=c[a+28>>2]|0;a=0;do{c[(c[(c[i+(a<<2)>>2]|0)+12>>2]|0)+32>>2]=0;a=a+1|0;}while(a>>>0<(c[h>>2]|0)>>>0)}h=EO(b,2251152)|0;a=g;c[a>>2]=h;c[a+4>>2]=F;Yy(b,(d[e+1|0]|0)<<8|(d[e]|0)|(d[e+2|0]|0)<<16|(d[e+3|0]|0)<<24);e=EO(b,2084664)|0;a=F;Yy(b,(d[f+1|0]|0)<<8|(d[f]|0)|(d[f+2|0]|0)<<16|(d[f+3|0]|0)<<24);return(F=a,e)|0}function uy(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;if((b|0)==0){d=2343600;return d|0}d=c[b>>2]|0;return d|0}function vy(a,b){a=a|0;b=b|0;var d=0,e=0;do{if((b|0)==0){d=c[a+8>>2]|0;if((d|0)==0){break}if((c[(c[a+4>>2]|0)+56>>2]|0)==0){break}else{e=d}return e|0}}while(0);e=0;return e|0}function wy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;a:do{if((a|0)==0){b=0}else{d=0;while(1){e=c[((d|0)==0?5221464:d+28|0)>>2]|0;if((e|0)==0){b=0;break a}if((c[e+56>>2]|0)==(a|0)){b=e;break}else{d=e}}}}while(0);while(1){a=c[((b|0)==0?5221464:b+28|0)>>2]|0;if((a|0)==0){f=0;g=6;break}d=c[a+56>>2]|0;if((d|0)==0){b=a}else{f=d;g=6;break}}if((g|0)==6){return f|0}return 0}function xy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a>>2]|0;e=c[((d|0)==0?5221464:d+28|0)>>2]|0;d=e;c[a>>2]=d;if((e|0)==0){f=0;return f|0}a:do{if((b|0)==0){g=e;h=d;while(1){if((c[g+12>>2]|0)!=0){i=g;break a}j=c[((h|0)==0?5221464:h+28|0)>>2]|0;k=j;c[a>>2]=k;if((j|0)==0){f=0;break}else{g=j;h=k}}return f|0}else{h=e;g=d;while(1){if((c[h+16>>2]|0)!=0){i=h;break a}k=c[((g|0)==0?5221464:g+28|0)>>2]|0;j=k;c[a>>2]=j;if((k|0)==0){f=0;break}else{h=k;g=j}}return f|0}}while(0);f=c[i>>2]|0;return f|0}function yy(a){a=a|0;var b=0,d=0;b=5221464;while(1){d=c[b>>2]|0;if((d|0)==0){break}else{b=d+28|0}}c[b>>2]=a;c[a+28>>2]=0;return 0}function zy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+4|0;e=c[d>>2]|0;f=c[e+8>>2]|0;if((f|0)==0){g=ze[c[e+4>>2]&511](a,c[a+12>>2]|0,c[a+16>>2]|0)|0}else{g=_e[f&1023](a,c[a+12>>2]|0,c[a+16>>2]|0,b)|0}if((g|0)!=0){h=g;return h|0}c[a+28>>2]=1;do{if((c[a+16>>2]&2|0)==0){if((QGb(c[c[d>>2]>>2]|0,2261072)|0)==0){break}else{h=0}return h|0}}while(0);g=a+24|0;if((c[g>>2]|0)!=0){h=0;return h|0}b=c[(c[d>>2]|0)+20>>2]|0;do{if((b|0)!=0){d=_e[b&1023](a,0,0,0)|0;f=F;e=0;if((f|0)<(e|0)|(f|0)==(e|0)&d>>>0<0>>>0){break}else{h=0}return h|0}}while(0);c[g>>2]=1;h=0;return h|0}function Ay(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[(c[a+4>>2]|0)+20>>2]|0;if((f|0)==0){g=-1;h=-38;return(F=g,h)|0}i=_e[f&1023](a,b,d,e&-131073)|0;g=F;h=i;return(F=g,h)|0}function By(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+8|0;h=g|0;if((c[1305366]|0)==0){yDb(0,24,2153384,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}k=Cy(d)|0;if((k|0)==0){c[b>>2]=0;if((qAb(2084568,d,0)|0)==0){l=-1330794744;i=g;return l|0}yDb(0,24,2033536,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;l=-1330794744;i=g;return l|0}m=h;do{if((e&1|0)!=0){if((c[k+12>>2]|0)!=0){break}yDb(0,16,1988832,(j=i,i=i+8|0,c[j>>2]=c[k>>2],j)|0);i=j;l=-5;i=g;return l|0}}while(0);do{if((e&2|0)!=0){if((c[k+16>>2]|0)!=0){break}yDb(0,16,1955536,(j=i,i=i+8|0,c[j>>2]=c[k>>2],j)|0);i=j;l=-5;i=g;return l|0}}while(0);n=cEb((SGb(d|0)|0)+49|0)|0;o=n;c[h>>2]=o;a:do{if((n|0)==0){p=-12;q=o}else{c[n>>2]=1071968;r=n+48|0;c[n+12>>2]=r;WGb(r|0,d|0)|0;c[(c[h>>2]|0)+4>>2]=k;r=c[h>>2]|0;c[r+16>>2]=e;c[r+24>>2]=0;c[r+20>>2]=0;s=c[k+52>>2]|0;b:do{if((s|0)==0){t=r}else{u=cEb(s)|0;c[(c[h>>2]|0)+8>>2]=u;u=c[h>>2]|0;v=c[u+8>>2]|0;if((v|0)==0){p=-12;q=u;break a}w=c[k+56>>2]|0;if((w|0)==0){t=u;break}x=k|0;y=SGb(c[x>>2]|0)|0;z=Vb(c[u+12>>2]|0,44)|0;c[v>>2]=w;DEb(c[(c[h>>2]|0)+8>>2]|0);w=c[h>>2]|0;v=c[w+12>>2]|0;if(!((RGb(c[x>>2]|0,v,y)|0)==0&(v+y|0)==(z|0))){t=w;break}w=a[z+1|0]|0;y=w<<24>>24;v=z+2|0;while(1){A=Vb(v|0,y|0)|0;if(!((A|0)!=0&v>>>0<A>>>0)){B=21;break}x=A+1|0;C=Vb(x|0,y|0)|0;if((C|0)==0){B=21;break}a[A]=0;a[C]=0;u=rEb(c[(c[h>>2]|0)+8>>2]|0,v,x,0)|0;if((u|0)==-1414549496){B=19;break}a[A]=w;a[C]=w;if((u|0)>-1){v=C+1|0}else{break}}do{if((B|0)==19){yDb(c[h>>2]|0,16,1928472,(j=i,i=i+8|0,c[j>>2]=v,j)|0);i=j;a[A]=w;a[C]=w}else if((B|0)==21){if((v|0)!=(A|0)){break}VGb(z|0,v+1|0,SGb(v|0)|0)|0;t=c[h>>2]|0;break b}}while(0);yDb(c[h>>2]|0,16,1906352,(j=i,i=i+8|0,c[j>>2]=z,j)|0);i=j;$Db((c[h>>2]|0)+8|0);$Db(m);p=-22;q=c[h>>2]|0;break a}}while(0);if((f|0)!=0){s=f;r=t+32|0;v=c[s+4>>2]|0;c[r>>2]=c[s>>2];c[r+4>>2]=v}c[b>>2]=t;l=0;i=g;return l|0}}while(0);c[b>>2]=0;if((q|0)!=0){$Db(q+8|0)}$Db(m);l=p;i=g;return l|0}function Cy(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+256|0;e=d|0;f=d+128|0;g=qd(b|0,1885600)|0;h=a[b+g|0]|0;if((h<<24>>24|0)==44){j=g+1|0;if((Vb(b+j|0,58)|0)==0){k=5}else{l=j;k=4}}else if((h<<24>>24|0)==58){l=g+1|0;k=4}else{k=5}if((k|0)==4){sAb(e|0,b,l>>>0>128>>>0?128:l)|0}else if((k|0)==5){l=e|0;a[l]=a[2261072]|0;a[l+1|0]=a[2261073]|0;a[l+2|0]=a[2261074]|0;a[l+3|0]=a[2261075]|0;a[l+4|0]=a[2261076]|0}l=e|0;e=Vb(l|0,44)|0;if((e|0)!=0){a[e]=0}e=f|0;sAb(e,l,128)|0;f=Vb(e|0,43)|0;if((f|0)!=0){a[f]=0}f=c[1305366]|0;if((f|0)==0){m=0;i=d;return m|0}else{n=f}while(1){f=c[n>>2]|0;if((QGb(l,f)|0)==0){m=n;k=15;break}if((c[n+60>>2]&1|0)!=0){if((QGb(e,f)|0)==0){m=n;k=15;break}}f=c[((n|0)==0?5221464:n+28|0)>>2]|0;if((f|0)==0){m=0;k=15;break}else{n=f}}if((k|0)==15){i=d;return m|0}return 0}function Dy(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+8|0;h=g|0;j=By(a,b,d,e)|0;if((j|0)!=0){k=j;i=g;return k|0}do{if((f|0)==0){l=5}else{j=c[a>>2]|0;if((c[(c[j+4>>2]|0)+56>>2]|0)==0){l=5;break}e=IEb(c[j+8>>2]|0,f)|0;if((e|0)<0){m=e}else{l=5}}}while(0);do{if((l|0)==5){e=c[a>>2]|0;j=e+4|0;d=c[j>>2]|0;b=c[d+8>>2]|0;if((b|0)==0){n=ze[c[d+4>>2]&511](e,c[e+12>>2]|0,c[e+16>>2]|0)|0}else{n=_e[b&1023](e,c[e+12>>2]|0,c[e+16>>2]|0,f)|0}if((n|0)!=0){m=n;break}c[e+28>>2]=1;do{if((c[e+16>>2]&2|0)==0){if((QGb(c[c[j>>2]>>2]|0,2261072)|0)==0){break}else{k=0}i=g;return k|0}}while(0);b=e+24|0;if((c[b>>2]|0)!=0){k=0;i=g;return k|0}d=c[(c[j>>2]|0)+20>>2]|0;do{if((d|0)!=0){o=_e[d&1023](e,0,0,0)|0;p=F;q=0;if((p|0)<(q|0)|(p|0)==(q|0)&o>>>0<0>>>0){break}else{k=0}i=g;return k|0}}while(0);c[b>>2]=1;k=0;i=g;return k|0}}while(0);n=c[a>>2]|0;f=h;c[h>>2]=n;if((n|0)!=0){h=n+4|0;do{if((c[n+28>>2]|0)!=0){l=c[(c[h>>2]|0)+24>>2]|0;if((l|0)==0){break}re[l&4095](n)|0}}while(0);l=c[h>>2]|0;if((c[l+52>>2]|0)!=0){h=n+8|0;if((c[l+56>>2]|0)!=0){HEb(c[h>>2]|0)}$Db(h)}$Db(f)}c[a>>2]=0;k=m;i=g;return k|0}function Ey(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;if((a|0)==0){e=0;i=b;return e|0}f=a+4|0;do{if((c[a+28>>2]|0)==0){g=0}else{h=c[(c[f>>2]|0)+24>>2]|0;if((h|0)==0){g=0;break}g=re[h&4095](a)|0}}while(0);h=c[f>>2]|0;if((c[h+52>>2]|0)!=0){f=a+8|0;if((c[h+56>>2]|0)!=0){HEb(c[f>>2]|0)}$Db(f)}$Db(d);e=g;i=b;return e|0}function Fy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=a+16|0;if((c[e>>2]&1|0)==0){f=-5;return f|0}g=c[(c[a+4>>2]|0)+12>>2]|0;h=a+32|0;i=a+40|0;j=(h|0)==0;k=h|0;h=a+36|0;l=0;m=5;n=0;o=0;p=b;q=d;a:while(1){if(j){while(1){r=ze[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}else{while(1){r=c[k>>2]|0;if((r|0)!=0){if((re[r&4095](c[h>>2]|0)|0)!=0){f=-1414092869;t=20;break a}}r=ze[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}if((c[e>>2]&8|0)!=0){f=s;t=20;break}do{if((s|0)==-11){if((m|0)!=0){u=m-1|0;v=0;w=n;x=o;break}do{if((c[i>>2]|0)==0&(c[i+4>>2]|0)==0){y=n;z=o}else{r=WFb()|0;A=F;if((o|0)==0&(n|0)==0){y=A;z=r;break}B=YGb(c[i>>2]|0,c[i+4>>2]|0,o,n)|0;C=F;if((A|0)>(C|0)|(A|0)==(C|0)&r>>>0>B>>>0){f=-5;t=20;break a}else{y=n;z=o}}}while(0);XFb(1e3)|0;u=0;v=0;w=y;x=z}else{if((s|0)<1){t=17;break a}u=(m|0)>2?m:2;v=s;w=n;x=o}}while(0);B=v+l|0;if((B|0)<1){l=B;m=u;n=w;o=x;p=b+B|0;q=d-B|0}else{f=B;t=20;break}}if((t|0)==17){f=(s|0)<0&(s|0)!=-541478725?s:l;return f|0}else if((t|0)==20){return f|0}return 0}function Gy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=a+16|0;if((c[e>>2]&1|0)==0){f=-5;return f|0}g=c[(c[a+4>>2]|0)+12>>2]|0;h=a+32|0;i=a+40|0;if((d|0)<=0){f=0;return f|0}j=(h|0)==0;k=h|0;h=a+36|0;l=0;m=5;n=0;o=0;p=b;q=d;a:while(1){if(j){while(1){r=ze[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}else{while(1){r=c[k>>2]|0;if((r|0)!=0){if((re[r&4095](c[h>>2]|0)|0)!=0){f=-1414092869;t=21;break a}}r=ze[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}if((c[e>>2]&8|0)!=0){f=s;t=21;break}do{if((s|0)==-11){if((m|0)!=0){u=m-1|0;v=0;w=n;x=o;break}do{if((c[i>>2]|0)==0&(c[i+4>>2]|0)==0){y=n;z=o}else{r=WFb()|0;A=F;if((o|0)==0&(n|0)==0){y=A;z=r;break}B=YGb(c[i>>2]|0,c[i+4>>2]|0,o,n)|0;C=F;if((A|0)>(C|0)|(A|0)==(C|0)&r>>>0>B>>>0){f=-5;t=21;break a}else{y=n;z=o}}}while(0);XFb(1e3)|0;u=0;v=0;w=y;x=z}else{if((s|0)<1){t=18;break a}u=(m|0)>2?m:2;v=s;w=n;x=o}}while(0);B=v+l|0;if((B|0)<(d|0)){l=B;m=u;n=w;o=x;p=b+B|0;q=d-B|0}else{f=B;t=21;break}}if((t|0)==18){f=(s|0)<0&(s|0)!=-541478725?s:l;return f|0}else if((t|0)==21){return f|0}return 0}function Hy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=a+16|0;if((c[e>>2]&2|0)==0){f=-5;return f|0}g=c[a+20>>2]|0;if((g|0)!=0&(g|0)<(d|0)){f=-5;return f|0}g=c[(c[a+4>>2]|0)+16>>2]|0;h=a+32|0;i=a+40|0;if((d|0)<=0){f=0;return f|0}j=(h|0)==0;k=h|0;h=a+36|0;l=0;m=5;n=0;o=0;p=b;q=d;a:while(1){if(j){while(1){r=ze[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}else{while(1){r=c[k>>2]|0;if((r|0)!=0){if((re[r&4095](c[h>>2]|0)|0)!=0){f=-1414092869;t=22;break a}}r=ze[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}if((c[e>>2]&8|0)!=0){f=s;t=22;break}do{if((s|0)==-11){if((m|0)!=0){u=m-1|0;v=0;w=n;x=o;break}do{if((c[i>>2]|0)==0&(c[i+4>>2]|0)==0){y=n;z=o}else{r=WFb()|0;A=F;if((o|0)==0&(n|0)==0){y=A;z=r;break}B=YGb(c[i>>2]|0,c[i+4>>2]|0,o,n)|0;C=F;if((A|0)>(C|0)|(A|0)==(C|0)&r>>>0>B>>>0){f=-5;t=22;break a}else{y=n;z=o}}}while(0);XFb(1e3)|0;u=0;v=0;w=y;x=z}else{if((s|0)<1){t=19;break a}u=(m|0)>2?m:2;v=s;w=n;x=o}}while(0);B=v+l|0;if((B|0)<(d|0)){l=B;m=u;n=w;o=x;p=b+B|0;q=d-B|0}else{f=B;t=22;break}}if((t|0)==19){f=(s|0)<0&(s|0)!=-541478725?s:l;return f|0}else if((t|0)==22){return f|0}return 0}function Iy(a){a=a|0;var b=0,d=0;b=Cy(a)|0;if((b|0)==0){d=0;return d|0}d=c[b>>2]|0;return d|0}function Jy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=By(f,a,b,0)|0;if((g|0)!=0){h=g;i=d;return h|0}g=c[f>>2]|0;f=g+4|0;a=c[f>>2]|0;j=c[a+64>>2]|0;if((j|0)==0){k=c[a+8>>2]|0;if((k|0)==0){l=ze[c[a+4>>2]&511](g,c[g+12>>2]|0,c[g+16>>2]|0)|0}else{l=_e[k&1023](g,c[g+12>>2]|0,c[g+16>>2]|0,0)|0}do{if((l|0)==0){c[g+28>>2]=1;if((c[g+16>>2]&2|0)==0){if((QGb(c[c[f>>2]>>2]|0,2261072)|0)!=0){m=0;break}}k=g+24|0;if((c[k>>2]|0)!=0){m=0;break}a=c[(c[f>>2]|0)+20>>2]|0;if((a|0)!=0){n=_e[a&1023](g,0,0,0)|0;a=F;o=0;if(!((a|0)<(o|0)|(a|0)==(o|0)&n>>>0<0>>>0)){m=0;break}}c[k>>2]=1;m=0}else{m=l}}while(0);p=(m|0)>-1?b:m}else{p=Oe[j&1023](g,b)|0}b=e;c[e>>2]=g;if((g|0)==0){h=p;i=d;return h|0}do{if((c[g+28>>2]|0)!=0){e=c[(c[f>>2]|0)+24>>2]|0;if((e|0)==0){break}re[e&4095](g)|0}}while(0);e=c[f>>2]|0;if((c[e+52>>2]|0)!=0){f=g+8|0;if((c[e+56>>2]|0)!=0){HEb(c[f>>2]|0)}$Db(f)}$Db(b);h=p;i=d;return h|0}function Ky(a){a=a|0;var b=0,d=0,e=0;do{if((a|0)!=0){b=c[a>>2]|0;if((b|0)==0){break}d=re[b&4095](c[a+4>>2]|0)|0;if((d|0)==0){break}else{e=d}return e|0}}while(0);e=0;return e|0}function Ly(a,b){a=a|0;b=b|0;var d=0;if((b|0)==0){d=c[a+20>>2]|0}else{d=0}return d|0}function My(a){a=a|0;return((a|0)!=0?0:1071968)|0}function Ny(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;c[a+4>>2]=b;c[a+8>>2]=d;c[a+12>>2]=b;c[a+20>>2]=f;c[a+104>>2]=0;f=(e|0)!=0;if(f){c[a+16>>2]=b+d;c[a+56>>2]=1}else{c[a+16>>2]=b;c[a+56>>2]=0}c[a+28>>2]=h;c[a+24>>2]=g;c[a+32>>2]=i;h=a+40|0;c[a+76>>2]=0;TGb(h|0,0,16)|0;c[a+88>>2]=(i|0)!=0;c[a+60>>2]=0;c[a+72>>2]=0;if((g|0)!=0|f){j=a+80|0;c[j>>2]=0;k=a+84|0;c[k>>2]=0;return 0}c[h>>2]=d;c[h+4>>2]=(d|0)<0|0?-1:0;c[a+16>>2]=b+d;j=a+80|0;c[j>>2]=0;k=a+84|0;c[k>>2]=0;return 0}function Oy(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=cEb(128)|0;if((i|0)==0){j=0;return j|0}c[i+4>>2]=a;c[i+8>>2]=b;c[i+12>>2]=a;c[i+20>>2]=e;c[i+104>>2]=0;e=(d|0)!=0;if(e){c[i+16>>2]=a+b;c[i+56>>2]=1}else{c[i+16>>2]=a;c[i+56>>2]=0}c[i+28>>2]=g;c[i+24>>2]=f;c[i+32>>2]=h;g=i+40|0;c[i+76>>2]=0;TGb(g|0,0,16)|0;c[i+88>>2]=(h|0)!=0;c[i+60>>2]=0;c[i+72>>2]=0;if(!((f|0)!=0|e)){e=g;c[e>>2]=b;c[e+4>>2]=(b|0)<0|0?-1:0;c[i+16>>2]=a+b}c[i+80>>2]=0;c[i+84>>2]=0;j=i;return j|0}function Py(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b+12|0;f=c[e>>2]|0;c[e>>2]=f+1;a[f]=d;d=c[e>>2]|0;if(d>>>0<(c[b+16>>2]|0)>>>0){return}f=b+4|0;g=c[f>>2]|0;do{if(d>>>0>g>>>0){h=d-g|0;i=c[b+28>>2]|0;do{if((i|0)!=0){j=b+76|0;if((c[j>>2]|0)!=0){break}k=ze[i&511](c[b+20>>2]|0,g,h)|0;if((k|0)>=0){break}c[j>>2]=k}}while(0);i=b+124|0;c[i>>2]=(c[i>>2]|0)+1;i=b+40|0;k=YGb(c[i>>2]|0,c[i+4>>2]|0,h,(h|0)<0|0?-1:0)|0;c[i>>2]=k;c[i+4>>2]=F;i=c[b+72>>2]|0;if((i|0)==0){l=c[f>>2]|0;break}else{k=b+64|0;j=b+68|0;m=c[j>>2]|0;c[k>>2]=ze[i&511](c[k>>2]|0,m,(c[e>>2]|0)-m|0)|0;m=c[f>>2]|0;c[j>>2]=m;l=m;break}}else{l=g}}while(0);c[e>>2]=l;return}function Qy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((d|0)<=0){return}e=a+16|0;f=a+12|0;g=b&255;b=a+4|0;h=a+28|0;i=a+124|0;j=a+40|0;k=a+72|0;l=a+64|0;m=a+68|0;n=a+76|0;o=a+20|0;a=d;d=c[f>>2]|0;while(1){p=(c[e>>2]|0)-d|0;q=(p|0)>(a|0)?a:p;TGb(d|0,g|0,q|0)|0;p=(c[f>>2]|0)+q|0;c[f>>2]=p;if(p>>>0<(c[e>>2]|0)>>>0){r=p}else{s=c[b>>2]|0;do{if(p>>>0>s>>>0){t=p-s|0;u=c[h>>2]|0;do{if((u|0)!=0){if((c[n>>2]|0)!=0){break}v=ze[u&511](c[o>>2]|0,s,t)|0;if((v|0)>=0){break}c[n>>2]=v}}while(0);c[i>>2]=(c[i>>2]|0)+1;u=YGb(c[j>>2]|0,c[j+4>>2]|0,t,(t|0)<0|0?-1:0)|0;c[j>>2]=u;c[j+4>>2]=F;u=c[k>>2]|0;if((u|0)==0){w=c[b>>2]|0;break}else{v=c[m>>2]|0;c[l>>2]=ze[u&511](c[l>>2]|0,v,(c[f>>2]|0)-v|0)|0;v=c[b>>2]|0;c[m>>2]=v;w=v;break}}else{w=s}}while(0);c[f>>2]=w;r=w}s=a-q|0;if((s|0)>0){a=s;d=r}else{break}}return}function Ry(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;do{if((c[a+104>>2]|0)!=0){e=a+72|0;if((c[e>>2]|0)!=0){break}f=a+12|0;g=c[f>>2]|0;h=a+4|0;i=c[h>>2]|0;do{if(g>>>0>i>>>0){j=g-i|0;k=a+28|0;l=c[k>>2]|0;do{if((l|0)!=0){m=a+76|0;if((c[m>>2]|0)!=0){break}n=ze[l&511](c[a+20>>2]|0,i,j)|0;if((n|0)>=0){break}c[m>>2]=n}}while(0);l=a+124|0;c[l>>2]=(c[l>>2]|0)+1;l=a+40|0;n=YGb(c[l>>2]|0,c[l+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[l>>2]=n;c[l+4>>2]=F;l=c[e>>2]|0;if((l|0)==0){o=c[h>>2]|0;p=k;break}else{n=a+64|0;m=a+68|0;q=c[m>>2]|0;c[n>>2]=ze[l&511](c[n>>2]|0,q,(c[f>>2]|0)-q|0)|0;q=c[h>>2]|0;c[m>>2]=q;o=q;p=k;break}}else{o=i;p=a+28|0}}while(0);c[f>>2]=o;c[a+48>>2]=0;i=c[p>>2]|0;do{if((i|0)!=0){h=a+76|0;if((c[h>>2]|0)!=0){break}e=ze[i&511](c[a+20>>2]|0,b,d)|0;if((e|0)>=0){break}c[h>>2]=e}}while(0);i=a+124|0;c[i>>2]=(c[i>>2]|0)+1;i=a+40|0;f=YGb(c[i>>2]|0,c[i+4>>2]|0,d,(d|0)<0|0?-1:0)|0;c[i>>2]=f;c[i+4>>2]=F;return}}while(0);if((d|0)<=0){return}p=a+16|0;o=a+12|0;i=a+4|0;f=a+28|0;e=a+124|0;h=a+40|0;g=a+72|0;q=a+64|0;m=a+68|0;n=a+76|0;l=a+20|0;a=d;d=b;b=c[o>>2]|0;while(1){r=(c[p>>2]|0)-b|0;s=(r|0)>(a|0)?a:r;UGb(b|0,d|0,s)|0;r=(c[o>>2]|0)+s|0;c[o>>2]=r;if(r>>>0<(c[p>>2]|0)>>>0){t=r}else{u=c[i>>2]|0;do{if(r>>>0>u>>>0){v=r-u|0;w=c[f>>2]|0;do{if((w|0)!=0){if((c[n>>2]|0)!=0){break}x=ze[w&511](c[l>>2]|0,u,v)|0;if((x|0)>=0){break}c[n>>2]=x}}while(0);c[e>>2]=(c[e>>2]|0)+1;w=YGb(c[h>>2]|0,c[h+4>>2]|0,v,(v|0)<0|0?-1:0)|0;c[h>>2]=w;c[h+4>>2]=F;w=c[g>>2]|0;if((w|0)==0){y=c[i>>2]|0;break}else{k=c[m>>2]|0;c[q>>2]=ze[w&511](c[q>>2]|0,k,(c[o>>2]|0)-k|0)|0;k=c[i>>2]|0;c[m>>2]=k;y=k;break}}else{y=u}}while(0);c[o>>2]=y;t=y}u=a-s|0;if((u|0)<=0){break}a=u;d=d+s|0;b=t}return}function Sy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+12|0;d=c[b>>2]|0;e=a+4|0;f=c[e>>2]|0;if(!(d>>>0>f>>>0)){g=f;c[b>>2]=g;h=a+48|0;c[h>>2]=0;return}i=d-f|0;d=c[a+28>>2]|0;do{if((d|0)!=0){j=a+76|0;if((c[j>>2]|0)!=0){break}k=ze[d&511](c[a+20>>2]|0,f,i)|0;if((k|0)>=0){break}c[j>>2]=k}}while(0);f=a+124|0;c[f>>2]=(c[f>>2]|0)+1;f=a+40|0;d=YGb(c[f>>2]|0,c[f+4>>2]|0,i,(i|0)<0|0?-1:0)|0;c[f>>2]=d;c[f+4>>2]=F;f=c[a+72>>2]|0;if((f|0)==0){g=c[e>>2]|0;c[b>>2]=g;h=a+48|0;c[h>>2]=0;return}else{d=a+64|0;i=a+68|0;k=c[i>>2]|0;c[d>>2]=ze[f&511](c[d>>2]|0,k,(c[b>>2]|0)-k|0)|0;k=c[e>>2]|0;c[i>>2]=k;g=k;c[b>>2]=g;h=a+48|0;c[h>>2]=0;return}}function Ty(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=e&131072;if((a|0)==0){g=-1;h=-22;return(F=g,h)|0}i=a+16|0;j=a+4|0;k=a+40|0;l=a+56|0;m=a+12|0;n=a+48|0;o=a+104|0;p=a+32|0;q=a+88|0;r=a+20|0;s=a+52|0;t=d;d=b;b=e;u=e&-131073;a:while(1){e=c[i>>2]|0;v=c[j>>2]|0;w=v;x=e-w|0;y=c[k>>2]|0;z=c[k+4>>2]|0;A=c[l>>2]|0;B=(A|0)!=0;C=x;D=(x|0)<0|0?-1:0;E=ZGb(y,z,B?0:C,B?0:D)|0;B=F;if(u>>>0>1>>>0){g=-1;h=-22;G=45;break}if((u|0)==1){H=(c[m>>2]|0)-w|0;I=YGb(H,(H|0)<0|0?-1:0,E,B)|0;H=F;if((d|0)==0&(t|0)==0){g=H;h=I;G=45;break}J=YGb(I,H,d,t)|0;K=F;L=J}else{K=t;L=d}M=ZGb(L,K,E,B)|0;J=F;do{if((c[n>>2]|0)==0){if((c[o>>2]|0)==0){H=0;if((J|0)<(H|0)|(J|0)==(H|0)&M>>>0<0>>>0|((J|0)>(D|0)|(J|0)==(D|0)&M>>>0>C>>>0)){break}else{G=11;break a}}else{H=0;if((J|0)<(H|0)|(J|0)==(H|0)&M>>>0<0>>>0|(c[p>>2]|0)!=0|((J|0)>(D|0)|(J|0)==(D|0)&M>>>0>C>>>0)){break}else{G=11;break a}}}}while(0);if((c[q>>2]|0)==0){G=14}else{C=e+4096-w|0;D=(C|0)<0|0?-1:0;if(!((J|0)>(D|0)|(J|0)==(D|0)&M>>>0>C>>>0)){G=14}}do{if((G|0)==14){G=0;C=-1;if(!((A|0)==0&((J|0)>(C|0)|(J|0)==(C|0)&M>>>0>-1>>>0))){break}if((c[o>>2]|0)==0){if((b|0)==2){break}else{G=18;break a}}else{if((c[p>>2]|0)!=0|(b|0)==2){break}else{G=18;break a}}}}while(0);w=0;if(!((A|0)==0&((J|0)<(w|0)|(J|0)==(w|0)&M>>>0<0>>>0))){G=28;break}w=ZGb(0,0,M,J)|0;e=F;C=x>>1;D=C;H=(C|0)<0|0?-1:0;if(!((H|0)>(e|0)|(H|0)==(e|0)&D>>>0>w>>>0)){G=38;break}w=c[p>>2]|0;e=0;if(!((w|0)!=0&((K|0)>(e|0)|(K|0)==(e|0)&L>>>0>0>>>0))){N=w;G=39;break}e=(H|0)>(B|0)|(H|0)==(B|0)&D>>>0>E>>>0;C=ZGb(E,B,e?E:D,e?B:H)|0;H=F;e=_e[w&1023](c[r>>2]|0,C,H,0)|0;w=F;D=0;if((w|0)<(D|0)|(w|0)==(D|0)&e>>>0<0>>>0){g=w;h=e;G=45;break}e=c[j>>2]|0;c[m>>2]=e;c[i>>2]=e;c[k>>2]=C;c[k+4>>2]=H;c[s>>2]=0;Uy(a);t=K;d=L;b=f;u=0}do{if((G|0)==11){c[m>>2]=v+M}else if((G|0)==18){u=y;b:do{if((z|0)<(K|0)|(z|0)==(K|0)&y>>>0<L>>>0){while(1){if((c[s>>2]|0)!=0){g=-1;h=-541478725;break}Uy(a);f=c[k>>2]|0;b=c[k+4>>2]|0;if(!((b|0)<(K|0)|(b|0)==(K|0)&f>>>0<L>>>0)){O=f;break b}}return(F=g,h)|0}else{O=u}}while(0);if((c[s>>2]|0)==0){c[m>>2]=(c[i>>2]|0)+(L-O);break}else{g=-1;h=-541478725;return(F=g,h)|0}}else if((G|0)==28){if((A|0)==0){G=38;break}u=c[m>>2]|0;do{if(u>>>0>v>>>0){B=u-v|0;E=c[a+28>>2]|0;do{if((E|0)!=0){x=a+76|0;if((c[x>>2]|0)!=0){break}J=ze[E&511](c[r>>2]|0,v,B)|0;if((J|0)>=0){break}c[x>>2]=J}}while(0);E=a+124|0;c[E>>2]=(c[E>>2]|0)+1;E=YGb(c[k>>2]|0,c[k+4>>2]|0,B,(B|0)<0|0?-1:0)|0;c[k>>2]=E;c[k+4>>2]=F;E=c[a+72>>2]|0;if((E|0)==0){P=c[j>>2]|0;break}else{J=a+64|0;x=a+68|0;f=c[x>>2]|0;c[J>>2]=ze[E&511](c[J>>2]|0,f,(c[m>>2]|0)-f|0)|0;f=c[j>>2]|0;c[x>>2]=f;P=f;break}}else{P=v}}while(0);c[m>>2]=P;c[n>>2]=1;G=38}else if((G|0)==45){return(F=g,h)|0}}while(0);if((G|0)==38){N=c[p>>2]|0;G=39}if((G|0)==39){if((N|0)==0){g=-1;h=-32;return(F=g,h)|0}G=_e[N&1023](c[r>>2]|0,L,K,0)|0;r=F;N=0;if((r|0)<(N|0)|(r|0)==(N|0)&G>>>0<0>>>0){g=r;h=G;return(F=g,h)|0}G=a+120|0;c[G>>2]=(c[G>>2]|0)+1;G=c[j>>2]|0;if((c[l>>2]|0)==0){c[i>>2]=G}c[m>>2]=G;c[k>>2]=L;c[k+4>>2]=K}c[s>>2]=0;g=K;h=L;return(F=g,h)|0}function Uy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;d=c[a+60>>2]|0;e=(d|0)==0?32768:d;d=a+16|0;f=c[d>>2]|0;g=a+4|0;h=c[g>>2]|0;j=f;k=h;l=a+8|0;m=c[l>>2]|0;n=(e+j-k|0)<(m|0)?f:h;o=k-n+m|0;m=a+24|0;k=c[m>>2]|0;do{if((k|0)==0){if((c[a+12>>2]|0)>>>0<f>>>0){break}c[a+52>>2]=1}}while(0);p=a+52|0;if((c[p>>2]|0)!=0){i=b;return}q=c[a+72>>2]|0;if((q|0)!=0&(n|0)==(h|0)){r=a+68|0;s=c[r>>2]|0;if(f>>>0>s>>>0){f=a+64|0;c[f>>2]=ze[q&511](c[f>>2]|0,s,j-s|0)|0;t=c[g>>2]|0;u=c[m>>2]|0}else{t=h;u=k}c[r>>2]=t;v=u;w=t}else{v=k;w=h}a:do{if((v|0)!=0){do{if((c[l>>2]|0)>(e|0)){if((n|0)==(w|0)){h=WDb(e)|0;k=c[g>>2]|0;do{if((h|0)==0){x=k}else{ZDb(k);c[g>>2]=h;c[l>>2]=e;c[a+12>>2]=h;t=a+56|0;if((c[t>>2]|0)==0){c[d>>2]=h;c[t>>2]=0;x=h;break}else{c[d>>2]=h+e;c[t>>2]=1;x=h;break}}}while(0);c[a+68>>2]=x;y=x}else{y=n}if((o|0)<(e|0)){yDb(0,0,2153312,(h=i,i=i+24|0,c[h>>2]=1928432,c[h+8>>2]=2033504,c[h+16>>2]=443,h)|0);i=h;Cd()}else{h=c[m>>2]|0;if((h|0)==0){break a}else{z=h;A=y;B=e;break}}}else{z=v;A=n;B=o}}while(0);h=ze[z&511](c[a+20>>2]|0,A,B)|0;if((h|0)>=1){k=h;t=(h|0)<0|0?-1:0;u=a+40|0;r=YGb(c[u>>2]|0,c[u+4>>2]|0,k,t)|0;c[u>>2]=r;c[u+4>>2]=F;c[a+12>>2]=A;c[d>>2]=A+h;u=a+112|0;r=YGb(c[u>>2]|0,c[u+4>>2]|0,k,t)|0;c[u>>2]=r;c[u+4>>2]=F;i=b;return}c[p>>2]=1;if((h|0)>=0){i=b;return}c[a+76>>2]=h;i=b;return}}while(0);c[p>>2]=1;i=b;return}function Vy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ty(a,b,c,1)|0;return(F=F,d)|0}function Wy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)==0){b=-1;d=-22;return(F=b,d)|0}e=a+32|0;f=c[e>>2]|0;if((f|0)==0){b=-1;d=-38;return(F=b,d)|0}g=a+20|0;h=_e[f&1023](c[g>>2]|0,0,0,65536)|0;f=F;i=0;if(!((f|0)<(i|0)|(f|0)==(i|0)&h>>>0<0>>>0)){b=f;d=h;return(F=b,d)|0}h=_e[c[e>>2]&1023](c[g>>2]|0,-1,-1,2)|0;f=F;i=0;if((f|0)<(i|0)|(f|0)==(i|0)&h>>>0<0>>>0){b=f;d=h;return(F=b,d)|0}i=YGb(h,f,1,0)|0;f=F;h=a+40|0;_e[c[e>>2]&1023](c[g>>2]|0,c[h>>2]|0,c[h+4>>2]|0,0)|0;b=f;d=i;return(F=b,d)|0}function Xy(a){a=a|0;var b=0,d=0;do{if((a|0)==0){b=0}else{d=a+52|0;if((c[d>>2]|0)==0){b=0;break}c[d>>2]=0;Uy(a);b=c[d>>2]|0}}while(0);return b|0}function Yy(a,b){a=a|0;b=b|0;Py(a,b&255);Py(a,b>>>8&255);Py(a,b>>>16&255);Py(a,b>>>24);return}function Zy(a,b){a=a|0;b=b|0;Py(a,b>>>24);Py(a,b>>>16&255);Py(a,b>>>8&255);Py(a,b&255);return}function _y(a,b){a=a|0;b=b|0;var c=0,d=0;if((b|0)==0){Py(a,0);c=1;return c|0}else{d=(SGb(b|0)|0)+1|0;Ry(a,b,d);c=d;return c|0}return 0}function $y(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;g=a[e]|0;a:do{if(g<<24>>24==0){h=0;j=0}else{k=b;l=0;m=0;n=e;o=g;while(1){p=m;q=n;r=o;b:while(1){s=q+1|0;t=r&255;u=t>>>1&64;c:do{if((t&192|0)==128|(r&255)>>>0>253>>>0){v=s}else{if((u&t|0)==0){w=t;x=u;y=s;break b}else{z=t;A=u;B=s}while(1){C=B+1|0;D=(d[B]|0)-128|0;if(D>>>0>63>>>0){v=C;break c}E=D+(z<<6)|0;D=A<<5;if((D&E|0)==0){w=E;x=D;y=C;break b}else{z=E;A=D;B=C}}}}while(0);yDb(k,16,2260840,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;s=a[v]|0;if(s<<24>>24==0){h=-22;j=l;break a}else{p=-22;q=v;r=s}}r=(x<<1)-1&w;if(r>>>0<65536>>>0){Py(b,r&255);Py(b,r>>>8&255);F=l+2|0}else{q=r-65536|0;Py(b,q>>>10&255);Py(b,q>>>18&39|216);Py(b,q&255);Py(b,q>>>8&3|220);F=l+4|0}q=a[y]|0;if(q<<24>>24==0){h=p;j=F;break}else{l=F;m=p;n=y;o=q}}}}while(0);Py(b,0);Py(b,0);i=f;return((h|0)==0?j+2|0:h)|0}function az(a,b){a=a|0;b=b|0;Py(a,b&255);Py(a,b>>8);return}function bz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=1;d=b;b=a;while(1){a=b>>>7|d<<25;e=d>>>7|0<<25;if((a|0)==0&(e|0)==0){break}else{c=c+1|0;d=e;b=a}}return c|0}function cz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=1;e=c;f=b;while(1){g=f>>>7|e<<25;h=e>>>7|0<<25;if((g|0)==0&(h|0)==0){break}else{d=d+1|0;e=h;f=g}}f=d-1|0;if((f|0)>0){i=f}else{j=b;k=j;l=k&127;Py(a,l);return}do{f=$Gb(b|0,c|0,i*7|0|0)|0;Py(a,f&127|128);i=i-1|0;}while((i|0)>0);j=b;k=j;l=k&127;Py(a,l);return}function dz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b;Py(a,d&255);Py(a,d>>>8&255);Py(a,d>>>16&255);Py(a,d>>>24);Py(a,c&255);Py(a,(c>>>8|0<<24)&255);Py(a,(c>>>16|0<<16)&255);Py(a,c>>>24|0<<8);return}function ez(a,b,c){a=a|0;b=b|0;c=c|0;Py(a,c>>>24|0<<8);Py(a,(c>>>16|0<<16)&255);Py(a,(c>>>8|0<<24)&255);Py(a,c&255);c=b;Py(a,c>>>24);Py(a,c>>>16&255);Py(a,c>>>8&255);Py(a,c&255);return}function fz(a,b){a=a|0;b=b|0;Py(a,b>>8);Py(a,b&255);return}function gz(a,b){a=a|0;b=b|0;Py(a,b&255);Py(a,b>>>8&255);Py(a,b>>16);return}function hz(a,b){a=a|0;b=b|0;Py(a,b>>16);Py(a,b>>>8&255);Py(a,b&255);return}function iz(a,b,c){a=a|0;b=b|0;c=c|0;return uBb(tBb(3)|0,a,b,c)|0}function jz(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+72|0;d=a+64|0;e=c[a+68>>2]|0;f=ze[c[b>>2]&511](c[d>>2]|0,e,(c[a+12>>2]|0)-e|0)|0;c[d>>2]=f;c[b>>2]=0;return f|0}function kz(a,b,d){a=a|0;b=b|0;d=d|0;c[a+72>>2]=b;if((b|0)==0){return}c[a+64>>2]=d;c[a+68>>2]=c[a+12>>2];return}function lz(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{Uy(a);h=c[b>>2]|0;i=c[f>>2]|0}if(!(h>>>0<i>>>0)){j=0;return j|0}c[b>>2]=h+1;j=d[h]|0;return j|0}function mz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=a+16|0;f=a+12|0;g=a+104|0;h=a+8|0;i=a+72|0;j=a+56|0;k=a+24|0;l=a+40|0;m=a+112|0;n=a+4|0;o=a+20|0;p=d;q=b;a:while(1){b=(p|0)>0;if(!b){break}while(1){r=c[f>>2]|0;s=(c[e>>2]|0)-r|0;t=(s|0)>(p|0)?p:s;if((t|0)!=0){if((c[j>>2]|0)==0){u=16;break}}if((c[g>>2]|0)==0){if((p|0)>(c[h>>2]|0)){u=7}}else{u=7}if((u|0)==7){u=0;if((c[i>>2]|0)==0){u=8;break}}Uy(a);if((c[e>>2]|0)==(c[f>>2]|0)|b^1){break a}}if((u|0)==8){u=0;b=c[k>>2]|0;if((b|0)==0){v=t}else{v=ze[b&511](c[o>>2]|0,q,p)|0}if((v|0)<1){u=11;break}b=v;s=(v|0)<0|0?-1:0;w=YGb(c[l>>2]|0,c[l+4>>2]|0,b,s)|0;c[l>>2]=w;c[l+4>>2]=F;w=YGb(c[m>>2]|0,c[m+4>>2]|0,b,s)|0;c[m>>2]=w;c[m+4>>2]=F;w=c[n>>2]|0;c[f>>2]=w;c[e>>2]=w;x=v}else if((u|0)==16){u=0;UGb(q|0,r|0,t)|0;c[f>>2]=(c[f>>2]|0)+t;x=t}p=p-x|0;q=q+x|0}do{if((u|0)==11){c[a+52>>2]=1;if((v|0)>=0){break}c[a+76>>2]=v}}while(0);do{if((p|0)==(d|0)){v=c[a+76>>2]|0;if((v|0)!=0){y=v;return y|0}if((a|0)==0){break}v=a+52|0;if((c[v>>2]|0)==0){break}c[v>>2]=0;Uy(a);if((c[v>>2]|0)==0){break}else{y=-541478725}return y|0}}while(0);y=d-p|0;return y|0}function nz(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=a+12|0;g=c[f>>2]|0;do{if(((c[a+16>>2]|0)-g|0)>=(d|0)){if((c[a+56>>2]|0)!=0){break}c[e>>2]=g;c[f>>2]=(c[f>>2]|0)+d;h=d;return h|0}}while(0);c[e>>2]=b;h=mz(a,b,d)|0;return h|0}function oz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)<0){e=-1;return e|0}f=c[a+24>>2]|0;do{if((f|0)!=0){if((c[a+56>>2]|0)==0){break}g=ze[f&511](c[a+20>>2]|0,b,d)|0;if((g|0)<=0){e=g;return e|0}h=a+40|0;i=YGb(c[h>>2]|0,c[h+4>>2]|0,g,(g|0)<0|0?-1:0)|0;c[h>>2]=i;c[h+4>>2]=F;e=g;return e|0}}while(0);f=a+16|0;g=c[f>>2]|0;h=a+12|0;i=c[h>>2]|0;if((g|0)==(i|0)){j=c[a+4>>2]|0;c[h>>2]=j;c[f>>2]=j;Uy(a);j=c[h>>2]|0;k=(c[f>>2]|0)-j|0;l=j}else{k=g-i|0;l=i}i=(k|0)>(d|0)?d:k;UGb(b|0,l|0,i)|0;c[h>>2]=(c[h>>2]|0)+i;do{if((i|0)==0){h=c[a+76>>2]|0;if((h|0)!=0){e=h;return e|0}if((a|0)==0){break}h=a+52|0;if((c[h>>2]|0)==0){break}c[h>>2]=0;Uy(a);if((c[h>>2]|0)==0){break}else{e=-541478725}return e|0}}while(0);e=i;return e|0}function pz(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{Uy(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=d[h]|0;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{Uy(a);l=c[b>>2]|0;m=c[f>>2]|0}if(!(l>>>0<m>>>0)){n=0;o=n|j;return o|0}c[b>>2]=l+1;n=(d[l]|0)<<8;o=n|j;return o|0}function qz(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{Uy(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=d[h]|0;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{Uy(a);l=c[b>>2]|0;m=c[f>>2]|0}if(l>>>0<m>>>0){i=l+1|0;c[b>>2]=i;n=(d[l]|0)<<8;o=i}else{n=0;o=l}l=n|j;if(o>>>0<m>>>0){p=o;q=m}else{Uy(a);p=c[b>>2]|0;q=c[f>>2]|0}if(!(p>>>0<q>>>0)){r=0;s=l|r;return s|0}c[b>>2]=p+1;r=(d[p]|0)<<16;s=l|r;return s|0}function rz(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{Uy(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=d[h]|0;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{Uy(a);l=c[b>>2]|0;m=c[f>>2]|0}if(l>>>0<m>>>0){i=l+1|0;c[b>>2]=i;n=(d[l]|0)<<8;o=i}else{n=0;o=l}l=n|j;if(o>>>0<m>>>0){p=o;q=m}else{Uy(a);p=c[b>>2]|0;q=c[f>>2]|0}if(p>>>0<q>>>0){m=p+1|0;c[b>>2]=m;r=d[p]|0;s=m}else{r=0;s=p}if(s>>>0<q>>>0){t=s;u=q}else{Uy(a);t=c[b>>2]|0;u=c[f>>2]|0}if(!(t>>>0<u>>>0)){v=0;w=v|r;x=w<<16;y=l|x;return y|0}c[b>>2]=t+1;v=(d[t]|0)<<8;w=v|r;x=w<<16;y=l|x;return y|0}function sz(a){a=a|0;var b=0;b=rz(a)|0;return(F=rz(a)|0,b|0)|0}function tz(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{Uy(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=(d[h]|0)<<8;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{Uy(a);l=c[b>>2]|0;m=c[f>>2]|0}if(!(l>>>0<m>>>0)){n=0;o=n|j;return o|0}c[b>>2]=l+1;n=d[l]|0;o=n|j;return o|0}function uz(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{Uy(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=(d[h]|0)<<8;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{Uy(a);l=c[b>>2]|0;m=c[f>>2]|0}if(l>>>0<m>>>0){i=l+1|0;c[b>>2]=i;n=d[l]|0;o=i}else{n=0;o=l}l=(n|j)<<8;if(o>>>0<m>>>0){p=o;q=m}else{Uy(a);p=c[b>>2]|0;q=c[f>>2]|0}if(!(p>>>0<q>>>0)){r=0;s=r|l;return s|0}c[b>>2]=p+1;r=d[p]|0;s=r|l;return s|0}function vz(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{Uy(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=(d[h]|0)<<8;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{Uy(a);l=c[b>>2]|0;m=c[f>>2]|0}if(l>>>0<m>>>0){i=l+1|0;c[b>>2]=i;n=d[l]|0;o=i}else{n=0;o=l}l=(n|j)<<16;if(o>>>0<m>>>0){p=o;q=m}else{Uy(a);p=c[b>>2]|0;q=c[f>>2]|0}if(p>>>0<q>>>0){m=p+1|0;c[b>>2]=m;r=(d[p]|0)<<8;s=m}else{r=0;s=p}if(s>>>0<q>>>0){t=s;u=q}else{Uy(a);t=c[b>>2]|0;u=c[f>>2]|0}if(!(t>>>0<u>>>0)){v=0;w=r|l;x=w|v;return x|0}c[b>>2]=t+1;v=d[t]|0;w=r|l;x=w|v;return x|0}function wz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+12|0;g=b+16|0;h=e-1|0;e=0;while(1){i=c[f>>2]|0;j=c[g>>2]|0;if(i>>>0<j>>>0){k=i;l=j}else{Uy(b);k=c[f>>2]|0;l=c[g>>2]|0}if(!(k>>>0<l>>>0)){m=e;break}c[f>>2]=k+1;j=a[k]|0;if(j<<24>>24==0){m=e;break}if((e|0)<(h|0)){a[d+e|0]=j;n=e+1|0}else{n=e}if(j<<24>>24==10){m=n;break}else{e=n}}a[d+m|0]=0;return m|0}function xz(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f|0)<1){g=-22;return g|0}h=f-1|0;f=(h|0)>(d|0)?d:h;h=b+12|0;i=b+16|0;j=0;while(1){if((j|0)>=(f|0)){k=9;break}l=c[h>>2]|0;m=c[i>>2]|0;if(l>>>0<m>>>0){n=l;o=m}else{Uy(b);n=c[h>>2]|0;o=c[i>>2]|0}if(!(n>>>0<o>>>0)){k=7;break}c[h>>2]=n+1;m=a[n]|0;a[e+j|0]=m;l=j+1|0;if(m<<24>>24==0){g=l;k=16;break}else{j=l}}if((k|0)==7){a[e+j|0]=0;g=j+1|0;return g|0}else if((k|0)==9){a[e+j|0]=0;e=j;while(1){if((e|0)>=(d|0)){g=d;k=16;break}j=c[h>>2]|0;n=c[i>>2]|0;if(j>>>0<n>>>0){p=j;q=n}else{Uy(b);p=c[h>>2]|0;q=c[i>>2]|0}if(!(p>>>0<q>>>0)){k=14;break}c[h>>2]=p+1;n=e+1|0;if((a[p]|0)==0){g=n;k=16;break}else{e=n}}if((k|0)==14){g=e+1|0;return g|0}else if((k|0)==16){return g|0}}else if((k|0)==16){return g|0}return 0}function yz(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((g|0)<1){h=-22;return h|0}i=b+12|0;j=b+16|0;k=f;l=g-1|0;g=f;f=0;a:while(1){m=(g-k|0)<(l|0);n=f;while(1){if((n+1|0)>=(e|0)){o=n;break a}p=n+2|0;if((p|0)>(e|0)){o=p;break a}q=c[i>>2]|0;r=c[j>>2]|0;if(q>>>0<r>>>0){s=q;t=r}else{Uy(b);s=c[i>>2]|0;t=c[j>>2]|0}if(s>>>0<t>>>0){r=s+1|0;c[i>>2]=r;u=d[s]|0;v=r}else{u=0;v=s}if(v>>>0<t>>>0){w=v;x=t}else{Uy(b);w=c[i>>2]|0;x=c[j>>2]|0}if(w>>>0<x>>>0){r=w+1|0;c[i>>2]=r;y=(d[w]|0)<<8;z=r}else{y=0;z=w}r=y|u;q=r-55296|0;if(q>>>0<2048>>>0){A=n+4|0;if((A|0)>(e|0)){o=A;break a}if(z>>>0<x>>>0){B=z;C=x}else{Uy(b);B=c[i>>2]|0;C=c[j>>2]|0}if(B>>>0<C>>>0){D=B+1|0;c[i>>2]=D;E=d[B]|0;F=D}else{E=0;F=B}if(F>>>0<C>>>0){G=F;H=C}else{Uy(b);G=c[i>>2]|0;H=c[j>>2]|0}if(G>>>0<H>>>0){c[i>>2]=G+1;I=(d[G]|0)<<8}else{I=0}D=I|E;if(D>>>0>1023>>>0|q>>>0>1023>>>0){o=A;break a}J=A;K=(q<<10)+65536+D|0}else{J=p;K=r}if((K|0)==0){o=J;break a}if(!(K>>>0<128>>>0)){break}if(m){L=29;break}else{n=J}}if((L|0)==29){L=0;a[g]=K;g=g+1|0;f=J;continue}n=K>>>0>65535>>>0;r=n?K>>>16:K;p=n?16:0;if((r&65280|0)==0){M=p;N=r}else{M=p|8;N=r>>>8}r=(M+4+(d[1191992+N|0]|0)|0)/5|0;p=(r*6|0)-6|0;if(m){a[g]=K>>>(p>>>0)|256-(256>>>(r>>>0));O=p;P=g+1|0}else{O=p;P=g}while(1){if((P-k|0)>=(l|0)){Q=O;break}if((O|0)<=5){g=P;f=J;continue a}p=O-6|0;a[P]=K>>>(p>>>0)&63|128;O=p;P=P+1|0}while(1){if((Q|0)<=5){g=P;f=J;continue a}Q=Q-6|0}}a[g]=0;h=o;return h|0}function zz(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;if((g|0)<1){h=-22;return h|0}i=b+12|0;j=b+16|0;k=f;l=g-1|0;g=f;f=0;a:while(1){m=(g-k|0)<(l|0);n=f;while(1){if((n+1|0)>=(e|0)){o=n;break a}p=n+2|0;if((p|0)>(e|0)){o=p;break a}q=c[i>>2]|0;r=c[j>>2]|0;if(q>>>0<r>>>0){s=q;t=r}else{Uy(b);s=c[i>>2]|0;t=c[j>>2]|0}if(s>>>0<t>>>0){r=s+1|0;c[i>>2]=r;u=(d[s]|0)<<8;v=r}else{u=0;v=s}if(v>>>0<t>>>0){w=v;x=t}else{Uy(b);w=c[i>>2]|0;x=c[j>>2]|0}if(w>>>0<x>>>0){r=w+1|0;c[i>>2]=r;y=d[w]|0;z=r}else{y=0;z=w}r=y|u;q=r-55296|0;if(q>>>0<2048>>>0){A=n+4|0;if((A|0)>(e|0)){o=A;break a}if(z>>>0<x>>>0){B=z;C=x}else{Uy(b);B=c[i>>2]|0;C=c[j>>2]|0}if(B>>>0<C>>>0){D=B+1|0;c[i>>2]=D;E=(d[B]|0)<<8;F=D}else{E=0;F=B}if(F>>>0<C>>>0){G=F;H=C}else{Uy(b);G=c[i>>2]|0;H=c[j>>2]|0}if(G>>>0<H>>>0){c[i>>2]=G+1;I=d[G]|0}else{I=0}D=I|E;if(D>>>0>1023>>>0|q>>>0>1023>>>0){o=A;break a}J=A;K=(q<<10)+65536+D|0}else{J=p;K=r}if((K|0)==0){o=J;break a}if(!(K>>>0<128>>>0)){break}if(m){L=29;break}else{n=J}}if((L|0)==29){L=0;a[g]=K;g=g+1|0;f=J;continue}n=K>>>0>65535>>>0;r=n?K>>>16:K;p=n?16:0;if((r&65280|0)==0){M=p;N=r}else{M=p|8;N=r>>>8}r=(M+4+(d[1191992+N|0]|0)|0)/5|0;p=(r*6|0)-6|0;if(m){a[g]=K>>>(p>>>0)|256-(256>>>(r>>>0));O=p;P=g+1|0}else{O=p;P=g}while(1){p=(P-k|0)<(l|0);r=O;while(1){if((r|0)<=5){g=P;f=J;continue a}r=r-6|0;if(p){break}}a[P]=K>>>(r>>>0)&63|128;O=r;P=P+1|0}}a[g]=0;h=o;return h|0}function Az(a){a=a|0;var b=0,c=0;b=vz(a)|0;c=vz(a)|0;return(F=b|0,c)|0}function Bz(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a+12|0;e=a+16|0;f=0;g=0;h=c[b>>2]|0;i=c[e>>2]|0;while(1){if(h>>>0<i>>>0){j=h;k=i}else{Uy(a);j=c[b>>2]|0;k=c[e>>2]|0}if(!(j>>>0<k>>>0)){break}l=j+1|0;c[b>>2]=l;m=d[j]|0;n=m&127|(g<<7|0>>>25);o=f<<7|g>>>25|0;if((m&128|0)==0){p=o;q=n;r=7;break}else{f=o;g=n;h=l;i=k}}if((r|0)==7){return(F=p,q)|0}p=f<<7|g>>>25;q=g<<7|0>>>25;return(F=p,q)|0}function Cz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[b+20>>2]|0;e=(d|0)==0?32768:d;f=WDb(e)|0;if((f|0)==0){g=-12;return g|0}h=b+16|0;i=c[h>>2]|0;j=cEb(128)|0;if((j|0)==0){c[a>>2]=0;ZDb(f);g=-12;return g|0}c[j+4>>2]=f;c[j+8>>2]=e;c[j+12>>2]=f;c[j+20>>2]=b;k=j+104|0;c[k>>2]=0;if((i&2|0)==0){c[j+16>>2]=f;c[j+56>>2]=0}else{c[j+16>>2]=f+e;c[j+56>>2]=1}c[j+28>>2]=132;c[j+24>>2]=306;c[j+32>>2]=614;c[j+76>>2]=0;TGb(j+40|0,0,16)|0;c[j+72>>2]=0;c[j+80>>2]=0;c[j+84>>2]=0;c[a>>2]=j;c[k>>2]=c[h>>2]&32768;c[j+88>>2]=(c[b+24>>2]|0)==0;c[j+60>>2]=d;d=c[b+4>>2]|0;if((d|0)!=0){c[j+80>>2]=c[d+32>>2];c[j+84>>2]=c[d+36>>2]}c[j>>2]=1075176;g=0;return g|0}function Dz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[a+60>>2]|0;f=a+12|0;g=a+4|0;h=(c[f>>2]|0)+b+((e|0)==0?32768:e)-(c[g>>2]|0)|0;e=a+8|0;if((h|0)<(c[e>>2]|0)){j=0;i=d;return j|0}if((c[a+88>>2]|0)!=0){j=0;i=d;return j|0}if((c[a+56>>2]|0)!=0){yDb(0,0,2153312,(b=i,i=i+24|0,c[b>>2]=2084544,c[b+8>>2]=2033504,c[b+16>>2]=770,b)|0);i=b;Cd();return 0}b=WDb(h)|0;if((b|0)==0){j=-12;i=d;return j|0}k=c[g>>2]|0;UGb(b|0,k|0,c[e>>2]|0)|0;ZDb(k);k=c[g>>2]|0;c[f>>2]=b+((c[f>>2]|0)-k);f=a+16|0;c[f>>2]=b+((c[f>>2]|0)-k);c[g>>2]=b;c[e>>2]=h;j=0;i=d;return j|0}function Ez(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=WDb(b)|0;if((d|0)==0){e=-12;return e|0}f=a+4|0;ZDb(c[f>>2]|0);c[f>>2]=d;c[a+8>>2]=b;c[a+12>>2]=d;f=a+56|0;if((c[f>>2]|0)==0){c[a+16>>2]=d;c[f>>2]=0;e=0;return e|0}else{c[a+16>>2]=d+b;c[f>>2]=1;e=0;return e|0}return 0}function Fz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[b>>2]|0;if((c[a+56>>2]|0)!=0){$Db(b);f=-22;return f|0}g=a+16|0;h=a+4|0;i=(c[g>>2]|0)-(c[h>>2]|0)|0;j=a+40|0;k=ZGb(c[j>>2]|0,c[j+4>>2]|0,i,(i|0)<0|0?-1:0)|0;l=F;m=d;n=(d|0)<0|0?-1:0;if((l|0)>(n|0)|(l|0)==(n|0)&k>>>0>m>>>0){$Db(b);f=-22;return f|0}o=ZGb(m,n,k,l)|0;l=o;o=i+d-l|0;k=a+8|0;n=c[k>>2]|0;m=(n|0)>(o|0)?n:o;do{if((m|0)>(d|0)){n=YDb(e,1,m)|0;c[b>>2]=n;if((n|0)==0){f=-12}else{p=n;break}return f|0}else{p=e}}while(0);if((o|0)>(d|0)){UGb(p+d|0,(c[h>>2]|0)+l|0,i-l|0)|0;q=o}else{q=d}ZDb(c[h>>2]|0);c[h>>2]=p;c[a+12>>2]=p;c[k>>2]=m;c[j>>2]=q;c[j+4>>2]=(q|0)<0|0?-1:0;c[g>>2]=p+q;c[a+52>>2]=0;c[a+48>>2]=0;f=0;return f|0}function Gz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;g=Dy(f,b,d,0,0)|0;do{if((g|0)<0){h=g}else{d=Cz(a,c[f>>2]|0)|0;if((d|0)>=0){h=0;break}Ey(c[f>>2]|0)|0;h=d}}while(0);i=e;return h|0}function Hz(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+8|0;h=g|0;j=Dy(h,b,d,e,f)|0;do{if((j|0)<0){k=j}else{f=Cz(a,c[h>>2]|0)|0;if((f|0)>=0){k=0;break}Ey(c[h>>2]|0)|0;k=f}}while(0);i=g;return k|0}function Iz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;if((a|0)==0){d=0;i=b;return d|0}e=a+12|0;f=c[e>>2]|0;g=a+4|0;h=c[g>>2]|0;do{if(f>>>0>h>>>0){j=f-h|0;k=c[a+28>>2]|0;do{if((k|0)!=0){l=a+76|0;if((c[l>>2]|0)!=0){break}m=ze[k&511](c[a+20>>2]|0,h,j)|0;if((m|0)>=0){break}c[l>>2]=m}}while(0);k=a+124|0;c[k>>2]=(c[k>>2]|0)+1;k=a+40|0;m=YGb(c[k>>2]|0,c[k+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[k>>2]=m;c[k+4>>2]=F;k=c[a+72>>2]|0;if((k|0)==0){n=c[g>>2]|0;break}else{m=a+64|0;l=a+68|0;o=c[l>>2]|0;c[m>>2]=ze[k&511](c[m>>2]|0,o,(c[e>>2]|0)-o|0)|0;o=c[g>>2]|0;c[l>>2]=o;n=o;break}}else{n=h}}while(0);c[e>>2]=n;c[a+48>>2]=0;n=c[a+20>>2]|0;$Db(g);g=a;if((c[a+56>>2]|0)==0){e=a+112|0;h=c[e+4>>2]|0;f=c[a+120>>2]|0;yDb(g,48,1955488,(p=i,i=i+24|0,c[p>>2]=c[e>>2],c[p+8>>2]=h,c[p+16>>2]=f,p)|0);i=p}else{f=c[a+124>>2]|0;yDb(g,48,1988784,(p=i,i=i+16|0,c[p>>2]=c[a+120>>2],c[p+8>>2]=f,p)|0);i=p}ZDb(g);d=Ey(n)|0;i=b;return d|0}function Jz(a){a=a|0;var b=0;b=Iz(c[a>>2]|0)|0;c[a>>2]=0;return b|0}function Kz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+4112|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=e+16|0;d=wd(g|0,4096,b|0,f|0)|0;Ry(a,g,SGb(g|0)|0);i=e;return d|0}function Lz(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=c[a+84>>2]|0;if((g|0)==0){h=-1;i=-38;return(F=h,i)|0}j=c[a+20>>2]|0;k=Pe[g&255](j,b,d,e,f)|0;f=F;e=-1;if(!((f|0)>(e|0)|(f|0)==(e|0)&k>>>0>-1>>>0)){h=f;i=k;return(F=h,i)|0}c[a+12>>2]=c[a+16>>2];e=_e[c[a+32>>2]&1023](j,0,0,1)|0;j=F;d=-1;if(!((j|0)>(d|0)|(j|0)==(d|0)&e>>>0>-1>>>0)){d=(e|0)==(-38|0)&(j|0)==(-1|0);return(F=d?f:j,d?k:e)|0}d=a+40|0;c[d>>2]=e;c[d+4>>2]=j;h=f;i=k;return(F=h,i)|0}function Mz(a){a=a|0;var b=0,d=0,e=0,f=0;b=cEb(1048)|0;if((b|0)==0){d=-12;return d|0}c[b+16>>2]=1024;e=b+20|0;f=cEb(128)|0;if((f|0)==0){c[a>>2]=0;ZDb(b);d=-12;return d|0}else{c[f+4>>2]=e;c[f+8>>2]=1024;c[f+12>>2]=e;c[f+20>>2]=b;c[f+104>>2]=0;c[f+16>>2]=b+1044;c[f+56>>2]=1;c[f+28>>2]=30;c[f+24>>2]=0;c[f+32>>2]=696;c[f+76>>2]=0;TGb(f+40|0,0,16)|0;c[f+88>>2]=1;c[f+72>>2]=0;c[f+80>>2]=0;c[f+84>>2]=0;c[a>>2]=f;c[f+60>>2]=0;d=0;return d|0}return 0}function Nz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((b|0)<1){d=-1;return d|0}e=lc(b|0,24)|0;if(F){d=-1;return d|0}f=cEb(e)|0;if((f|0)==0){d=-12;return d|0}c[f+16>>2]=b;e=f+20|0;g=cEb(128)|0;if((g|0)==0){c[a>>2]=0;ZDb(f);d=-12;return d|0}else{c[g+4>>2]=e;c[g+8>>2]=b;c[g+12>>2]=e;c[g+20>>2]=f;c[g+104>>2]=0;c[g+16>>2]=f+(b+20);c[g+56>>2]=1;c[g+28>>2]=224;c[g+24>>2]=0;c[g+32>>2]=0;TGb(g+40|0,0,16)|0;TGb(g+72|0,0,20)|0;c[a>>2]=g;c[g+60>>2]=b;d=0;return d|0}return 0}function Oz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a|0)==0){c[b>>2]=0;d=0;return d|0}e=a+20|0;f=c[e>>2]|0;if((c[a+60>>2]|0)==0){Ry(a,8882096,16);g=16}else{g=0}h=a+12|0;i=c[h>>2]|0;j=a+4|0;k=c[j>>2]|0;do{if(i>>>0>k>>>0){l=i-k|0;m=c[a+28>>2]|0;do{if((m|0)!=0){n=a+76|0;if((c[n>>2]|0)!=0){break}o=ze[m&511](c[e>>2]|0,k,l)|0;if((o|0)>=0){break}c[n>>2]=o}}while(0);m=a+124|0;c[m>>2]=(c[m>>2]|0)+1;m=a+40|0;o=YGb(c[m>>2]|0,c[m+4>>2]|0,l,(l|0)<0|0?-1:0)|0;c[m>>2]=o;c[m+4>>2]=F;m=c[a+72>>2]|0;if((m|0)==0){p=c[j>>2]|0;break}else{o=a+64|0;n=a+68|0;q=c[n>>2]|0;c[o>>2]=ze[m&511](c[o>>2]|0,q,(c[h>>2]|0)-q|0)|0;q=c[j>>2]|0;c[n>>2]=q;p=q;break}}else{p=k}}while(0);c[h>>2]=p;c[a+48>>2]=0;c[b>>2]=c[f+12>>2];b=c[f+4>>2]|0;ZDb(f);ZDb(a);d=b-g|0;return d|0}function Pz(a){a=a|0;var b=0,d=0,e=0,f=0;b=cEb(1048)|0;if((b|0)==0){d=-12;return d|0}c[b+16>>2]=1024;e=b+20|0;f=cEb(128)|0;if((f|0)==0){c[a>>2]=0;ZDb(b);d=-12;return d|0}else{c[f+4>>2]=e;c[f+8>>2]=1024;c[f+12>>2]=e;c[f+20>>2]=b;c[f+104>>2]=0;c[f+16>>2]=b+1044;c[f+56>>2]=1;c[f+24>>2]=0;c[f+32>>2]=696;c[f+76>>2]=0;TGb(f+40|0,0,16)|0;c[f+88>>2]=1;c[f+72>>2]=0;c[f+80>>2]=0;c[f+84>>2]=0;c[a>>2]=f;c[f+60>>2]=0;c[f+28>>2]=150;d=0;return d|0}return 0}function Qz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=(c[b>>2]|0)+d|0;c[b>>2]=e;b=a+4|0;if((e|0)<=(c[b>>2]|0)){return d|0}c[b>>2]=e;return d|0}function Rz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+20>>2]|0;d=a+12|0;e=c[d>>2]|0;f=a+4|0;g=c[f>>2]|0;do{if(e>>>0>g>>>0){h=e-g|0;i=c[a+28>>2]|0;do{if((i|0)!=0){j=a+76|0;if((c[j>>2]|0)!=0){break}k=ze[i&511](b,g,h)|0;if((k|0)>=0){break}c[j>>2]=k}}while(0);i=a+124|0;c[i>>2]=(c[i>>2]|0)+1;i=a+40|0;k=YGb(c[i>>2]|0,c[i+4>>2]|0,h,(h|0)<0|0?-1:0)|0;c[i>>2]=k;c[i+4>>2]=F;i=c[a+72>>2]|0;if((i|0)==0){l=c[f>>2]|0;break}else{k=a+64|0;j=a+68|0;m=c[j>>2]|0;c[k>>2]=ze[i&511](c[k>>2]|0,m,(c[d>>2]|0)-m|0)|0;m=c[f>>2]|0;c[j>>2]=m;l=m;break}}else{l=g}}while(0);c[d>>2]=l;c[a+48>>2]=0;l=c[b+4>>2]|0;ZDb(b);ZDb(a);return l|0}function Sz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=fe(e|0)|0;g=b;h=c[g>>2]|0;i=lc(h|0,4)|0;j=i;i=b+8|0;k=c[i>>2]|0;if(F|j>>>0>1073741823>>>0){l=-1;return l|0}do{if(j>>>0>k>>>0){m=k;while(1){if((m|0)==0){n=j}else{n=m+1+(m>>>1)|0}if(j>>>0>n>>>0){m=n}else{break}}if(!(n>>>0>k>>>0)){o=7;break}m=b+12|0;p=_Db(m,n)|0;if((p|0)>=0){c[i>>2]=n;q=c[g>>2]|0;r=m;break}c[i>>2]=0;c[b+4>>2]=0;l=p;return l|0}else{o=7}}while(0);if((o|0)==7){q=h;r=b+12|0}h=(c[r>>2]|0)+q|0;x=f;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[g>>2]=j;h=b+4|0;if((j|0)>(c[h>>2]|0)){c[h>>2]=j}f=lc(j|0,e|0)|0;q=f;f=c[i>>2]|0;if(F|q>>>0>1073741823>>>0){l=-1;return l|0}do{if(q>>>0>f>>>0){r=f;while(1){if((r|0)==0){s=q}else{s=r+1+(r>>>1)|0}if(q>>>0>s>>>0){r=s}else{break}}if(!(s>>>0>f>>>0)){o=19;break}r=b+12|0;n=_Db(r,s)|0;if((n|0)>=0){c[i>>2]=s;t=c[g>>2]|0;u=r;break}c[i>>2]=0;c[h>>2]=0;l=n;return l|0}else{o=19}}while(0);if((o|0)==19){t=j;u=b+12|0}UGb((c[u>>2]|0)+t|0,d|0,e)|0;c[g>>2]=q;if((q|0)<=(c[h>>2]|0)){l=e;return l|0}c[h>>2]=q;l=e;return l|0}function Tz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=a;f=c[e>>2]|0;g=lc(f|0,d|0)|0;h=g;g=a+8|0;i=c[g>>2]|0;if(F|h>>>0>1073741823>>>0){j=-1;return j|0}do{if(h>>>0>i>>>0){k=i;while(1){if((k|0)==0){l=h}else{l=k+1+(k>>>1)|0}if(h>>>0>l>>>0){k=l}else{break}}if(!(l>>>0>i>>>0)){m=7;break}k=a+12|0;n=_Db(k,l)|0;if((n|0)>=0){c[g>>2]=l;o=c[e>>2]|0;p=k;break}c[g>>2]=0;c[a+4>>2]=0;j=n;return j|0}else{m=7}}while(0);if((m|0)==7){o=f;p=a+12|0}UGb((c[p>>2]|0)+o|0,b|0,d)|0;c[e>>2]=h;e=a+4|0;if((h|0)<=(c[e>>2]|0)){j=d;return j|0}c[e>>2]=h;j=d;return j|0}function Uz(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==2){f=c[a+4>>2]|0;g=YGb(f,(f|0)<0|0?-1:0,b,d)|0;h=F;i=g}else if((e|0)==1){e=c[a>>2]|0;g=YGb(e,(e|0)<0|0?-1:0,b,d)|0;h=F;i=g}else{h=d;i=b}b=0;if(h>>>0>b>>>0|h>>>0==b>>>0&i>>>0>2147483647>>>0){j=-1;k=-1;return(F=j,k)|0}c[a>>2]=i;j=0;k=0;return(F=j,k)|0}function Vz(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if(c>>>0>2>>>0){d=0;return d|0}else{f=0}do{g=wc(a|0,858144+((e[858128+(f<<1)>>1]|0)*6|0)|0,e[858136+(f<<1)>>1]|0|0,6,294)|0;h=g;f=f+1|0;i=(g|0)!=0;}while((f|0)<3&(i^1));if(!i){d=0;return d|0}i=b[858128+(c<<1)>>1]|0;f=i&65535;j=858136+(c<<1)|0;if(h>>>0<(858144+(f*6|0)|0)>>>0){k=7}else{if(h>>>0<(858144+(((e[j>>1]|0)+f|0)*6|0)|0)>>>0){l=h}else{k=7}}do{if((k|0)==7){h=b[g+4>>1]|0;m=h&65535;if(!((h&65535)>>>0<(i&65535)>>>0)){if((m|0)<((e[j>>1]|0)+f|0)){l=858144+(m*6|0)|0;break}}h=b[858148+(m*6|0)>>1]|0;m=h&65535;if(!((h&65535)>>>0<(i&65535)>>>0)){if((m|0)<((e[j>>1]|0)+f|0)){l=858144+(m*6|0)|0;break}}if((c|0)==1){n=0}else{d=0;return d|0}do{o=wc(a|0,858144+((e[858128+(n<<1)>>1]|0)*6|0)|0,e[858136+(n<<1)>>1]|0|0,6,294)|0;p=o;n=n+1|0;q=(o|0)!=0;}while((n|0)<3&(q^1));if(!q){d=0;return d|0}do{if(o>>>0>=858144>>>0&o>>>0<861048>>>0){r=p}else{m=b[o+4>>1]|0;h=m&65535;if((m&65535)>>>0<484>>>0){r=858144+(h*6|0)|0;break}m=b[858148+(h*6|0)>>1]|0;if((m&65535)>>>0<484>>>0){r=858144+((m&65535)*6|0)|0;break}else{d=0}return d|0}}while(0);d=r|0;return d|0}}while(0);d=l|0;return d|0}function Wz(a,b){a=a|0;b=b|0;return QGb(a,b)|0}function Xz(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1414087218){e=0;return e|0}a=b+12|0;f=(d[a]|d[a+1|0]<<8)<<16>>16;if(f<<16>>16==0|((de(f|0)|0)&65535)>>>0>256>>>0){e=25;return e|0}f=b+14|0;b=((de((d[f]|d[f+1|0]<<8)<<16>>16|0)|0)&65535)>>>0>256>>>0;e=b?25:50;return e|0}function Yz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=LT(a,0)|0;if((d|0)==0){e=-12;i=b;return e|0}f=d+8|0;c[(c[f>>2]|0)+8>>2]=1;g=a+16|0;Vy(c[g>>2]|0,4,0)|0;Vy(c[g>>2]|0,8,0)|0;h=tz(c[g>>2]|0)|0;do{if((h&65535)<<16>>16==0){c[(c[f>>2]|0)+416>>2]=1}else{j=h&65535;if((j|0)==65535){c[(c[f>>2]|0)+416>>2]=2;break}DDb(a,2153064,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;e=-1163346256;i=b;return e|0}}while(0);h=(tz(c[g>>2]|0)|0)&65535;c[(c[f>>2]|0)+792>>2]=h;j=tz(c[g>>2]|0)|0;Vy(c[g>>2]|0,2,0)|0;Vy(c[g>>2]|0,2,0)|0;Vy(c[g>>2]|0,1,0)|0;l=uz(c[g>>2]|0)|0;c[(c[f>>2]|0)+412>>2]=l;Vy(c[g>>2]|0,12,0)|0;Vy(c[g>>2]|0,6,0)|0;Vy(c[g>>2]|0,20,0)|0;Vy(c[g>>2]|0,64,0)|0;g=j&65535;j=wT(h,0,1,g)|0;l=c[f>>2]|0;c[l+48>>2]=j;if((j|0)==0){DDb(a,2084240,(k=i,i=i+16|0,c[k>>2]=h,c[k+8>>2]=g,k)|0);i=k;e=-1163346256;i=b;return e|0}else{c[l+432>>2]=(ba(c[l+416>>2]|0,h)|0)/8|0;MT(d,64,1,c[l+412>>2]|0);e=0;i=b;return e|0}return 0}function Zz(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==119){if((a[d+1|0]|0)!=87){break}if((a[d+2|0]|0)!=16){break}if((a[d+3|0]|0)==0){e=55}else{break}return e|0}}while(0);e=0;return e|0}function _z(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+12>>2]|0;e=a+20|0;c[e>>2]=c[e>>2]|1;e=a+16|0;Vy(c[e>>2]|0,4,0)|0;f=d+16|0;c[f>>2]=pz(c[e>>2]|0)|0;g=d+20|0;c[g>>2]=pz(c[e>>2]|0)|0;c[d+24>>2]=pz(c[e>>2]|0)|0;c[d+28>>2]=pz(c[e>>2]|0)|0;c[d+32>>2]=rz(c[e>>2]|0)|0;c[d+36>>2]=0;c[d+40>>2]=0;c[d+12>>2]=0;c[d+8>>2]=0;d=c[f>>2]|0;f=c[g>>2]|0;if((d|0)==318&(f|0)==198){i=b;return 0}yDb(a,16,2152976,(a=i,i=i+16|0,c[a>>2]=d,c[a+8>>2]=f,a)|0);i=a;i=b;return 0}function $z(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+776|0;f=e|0;g=b+12|0;h=c[g>>2]|0;j=h+40|0;k=b+16|0;do{if((c[j>>2]|0)>0){l=Ty(c[k>>2]|0,0,0,1)|0;m=F;n=h+12|0;o=yU(b,d,c[n>>2]|0,c[j>>2]|0)|0;p=Ty(c[k>>2]|0,0,0,1)|0;q=ZGb(p,F,l,m)|0;m=q;c[j>>2]=(c[j>>2]|0)-m;if((o|0)<0){r=n;break}c[d+32>>2]=c[c[n>>2]>>2];o=d+36|0;c[o>>2]=c[o>>2]|1;if((m|0)>0){s=0}else{r=n;break}i=e;return s|0}else{r=h+12|0}}while(0);n=h+36|0;m=f|0;f=d+32|0;o=d+36|0;q=0;l=c[n>>2]|0;a:while(1){if((l|0)<1){if((pz(c[k>>2]|0)|0)==0){s=-5;t=31;break}p=(pz(c[k>>2]|0)|0)-4|0;c[n>>2]=p;if((p|0)>0){u=q}else{q=q;l=p;continue}}else{u=q}while(1){v=lz(c[k>>2]|0)|0;p=lz(c[k>>2]|0)|0;w=pz(c[k>>2]|0)|0;if((w|0)<4){s=-1094995529;t=31;break a}c[n>>2]=(c[n>>2]|0)-w;do{if((p|0)==2){if((c[r>>2]|0)==0){x=LT(b,0)|0;c[r>>2]=x;if((x|0)==0){s=-12;t=31;break a}c[(c[x+8>>2]|0)+8>>2]=1}c[j>>2]=w-4;x=c[g>>2]|0;y=Ty(c[k>>2]|0,0,0,1)|0;z=F;A=x+12|0;B=x+40|0;x=yU(b,d,c[A>>2]|0,c[B>>2]|0)|0;C=Ty(c[k>>2]|0,0,0,1)|0;D=ZGb(C,F,y,z)|0;z=D;c[B>>2]=(c[B>>2]|0)-z;if((x|0)==-5){E=u;break}if((x|0)<0){s=x;t=31;break a}c[f>>2]=c[c[A>>2]>>2];c[o>>2]=c[o>>2]|1;if((z|0)==0){E=u}else{s=z;t=31;break a}}else if((p|0)==3){z=w-4|0;if(z>>>0>772>>>0){s=-1094995529;t=31;break a}if((mz(c[k>>2]|0,m,z)|0)<(z|0)){s=-5;t=31;break a}else{E=w}}else if((p|0)==1){t=14;break a}else{z=w-4|0;Vy(c[k>>2]|0,z,(z|0)<0|0?-1:0)|0;E=u}}while(0);p=c[n>>2]|0;if((p|0)>0){u=E}else{q=E;l=p;continue a}}}if((t|0)==14){l=h+8|0;do{if((c[l>>2]|0)==0){E=LT(b,0)|0;c[l>>2]=E;if((E|0)==0){s=-12;i=e;return s|0}else{q=c[E+8>>2]|0;c[q+8>>2]=0;c[q+48>>2]=83;c[q+120>>2]=c[h+16>>2];c[q+124>>2]=c[h+20>>2];c[q+792>>2]=c[h+24>>2];q=c[h+32>>2]|0;n=E+64|0;c[n>>2]=q;c[n+4>>2]=(q|0)<0|0?-1:0;c[E+92>>2]=c[h+28>>2];c[E+96>>2]=1;q=E+92|0;n=E+412|0;E=c[q+4>>2]|0;c[n>>2]=c[q>>2];c[n+4>>2]=E;break}}}while(0);h=c[g>>2]|0;g=wZ(d,w+u|0)|0;if((g|0)<0){s=g;i=e;return s|0}g=d+24|0;if((u|0)!=0){a[c[g>>2]|0]=0;a[(c[g>>2]|0)+1|0]=3;a[(c[g>>2]|0)+2|0]=u;a[(c[g>>2]|0)+3|0]=u>>>8;UGb((c[g>>2]|0)+4|0,m|0,u-4|0)|0}a[(c[g>>2]|0)+u|0]=v;a[(c[g>>2]|0)+(u+1)|0]=1;a[(c[g>>2]|0)+(u+2)|0]=w;a[(c[g>>2]|0)+(u+3)|0]=w>>>8;m=(mz(c[k>>2]|0,(c[g>>2]|0)+(u+4)|0,w-4|0)|0)+4|0;if((m|0)<(w|0)){BZ(d);s=-5;i=e;return s|0}c[d+28>>2]=m+u;c[f>>2]=c[c[h+8>>2]>>2];if((v|0)!=0){s=0;i=e;return s|0}c[o>>2]=c[o>>2]|1;s=0;i=e;return s|0}else if((t|0)==31){i=e;return s|0}return 0}function aA(a){a=a|0;return 0}function bA(b){b=b|0;var e=0,f=0;e=c[b+4>>2]|0;b=e;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)!=4475222){f=0;return f|0}f=(a[e+4|0]|0)==2?100:25;return f|0}function cA(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;Vy(d,5,0)|0;c[b>>2]=pz(d)|0;c[b+8>>2]=pz(d)|0;c[b+12>>2]=pz(d)|0;c[b+16>>2]=pz(d)|0;pz(d)|0;c[b+20>>2]=-1;c[b+24>>2]=-1;c[b+4>>2]=11111;b=a+20|0;c[b>>2]=c[b>>2]|1;return 0}function dA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+8|0;f=e|0;g=c[b+12>>2]|0;h=c[b+16>>2]|0;j=g+32|0;if((c[j>>2]|0)!=0){k=-541478725;i=e;return k|0}if((Xy(h)|0)!=0){k=-541478725;i=e;return k|0}l=lz(h)|0;m=l&255;n=l&255;switch(n|0){case 125:{break};case 124:{pz(h)|0;c[g+4>>2]=1e6/(256-(lz(h)|0)|0)|0;break};case 20:{if((c[g>>2]|0)!=0){yDb(b,40,2033336,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}c[j>>2]=1;k=-5;i=e;return k|0};case 2:{j=g+28|0;l=j;if((c[l>>2]|0)!=0){yDb(b,24,2152944,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;$Db(j)}p=WDb(768)|0;c[l>>2]=p;if((p|0)==0){k=-12;i=e;return k|0}if((mz(h,p,768)|0)==768){k=dA(b,d)|0;i=e;return k|0}else{$Db(j);k=-5;i=e;return k|0}break};case 1:case 4:case 3:{j=g+20|0;p=c[j>>2]|0;if((p|0)<0){l=LT(b,0)|0;if((l|0)==0){k=-12;i=e;return k|0}c[j>>2]=c[l>>2];if((c[g+24>>2]|0)<0){DDb(b,1955328,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}MT(l,64,185,c[g+4>>2]|0);q=c[l+8>>2]|0;c[q+8>>2]=0;c[q+48>>2]=104;c[q+120>>2]=c[g+8>>2];c[q+124>>2]=c[g+12>>2];r=c[j>>2]|0}else{r=p}p=c[(c[(c[b+28>>2]|0)+(r<<2)>>2]|0)+8>>2]|0;r=ba(c[p+124>>2]|0,c[p+120>>2]|0)|0;c[f>>2]=1e3;p=WDb(1e3)|0;if((p|0)==0){k=-12;i=e;return k|0}q=Ty(h,0,0,1)|0;a[p]=m;l=(c[g+16>>2]|0)+(pz(h)|0)|0;a:do{if((m<<24>>24|0)==3){s=p;t=1;u=0;while(1){v=jEb(s,f,t+1e3|0)|0;if((v|0)==0){k=-12;break}w=lz(h)|0;x=t+1|0;a[v+t|0]=w;do{if((w|0)>127){a[v+x|0]=lz(h)|0;y=t+2|0}else{if((w|0)==0){y=x;break}if((mz(h,v+x|0,w)|0)!=(w|0)){z=-5;A=v;break a}y=w+x|0}}while(0);x=(w&127)+u|0;if((x|0)==(r|0)){B=v;C=y;D=1;E=40;break a}if((x|0)>(r|0)){z=-1094995529;A=v;break a}if((w|0)==0){G=v;H=y;I=1;E=44;break a}else{s=v;t=y;u=x}}i=e;return k|0}else if((m<<24>>24|0)==4){if((mz(h,p+1|0,2)|0)==2){J=p;K=3;L=0;E=35}else{z=-5;A=p}}else{J=p;K=1;L=0;E=35}}while(0);b:do{if((E|0)==35){while(1){E=0;p=jEb(J,f,K+1e3|0)|0;if((p|0)==0){k=-12;break}m=lz(h)|0;y=K+1|0;a[p+K|0]=m;u=(m|0)==0;if((m|0)>127|u){M=y}else{if((mz(h,p+y|0,m)|0)!=(m|0)){z=-5;A=p;break b}M=m+y|0}y=(m&127)+L|0;if((y|0)==(r|0)){B=p;C=M;D=0;E=40;break b}if((y|0)>(r|0)){z=-1094995529;A=p;break b}if(u){G=p;H=M;I=0;E=44;break b}else{J=p;K=M;L=y;E=35}}i=e;return k|0}}while(0);do{if((E|0)==40){if((lz(h)|0)==0){G=B;H=C;I=D;E=44;break}Ty(h,-1,-1,1)|0;G=B;H=C;I=D;E=44}}while(0);do{if((E|0)==44){D=wZ(d,H)|0;if((D|0)<0){z=D;A=G;break}UGb(c[d+24>>2]|0,G|0,H)|0;ZDb(G);YGb(0,q,0,-1)|0;D=F;C=d+64|0;c[C>>2]=D;c[C+4>>2]=(D|0)<0|0?-1:0;c[d+32>>2]=c[j>>2];c[d+48>>2]=l;if(I){D=d+36|0;c[D>>2]=c[D>>2]|1}D=g+28|0;C=D;if((c[C>>2]|0)!=0){B=GZ(d,0,768)|0;if((B|0)!=0){UGb(B|0,c[C>>2]|0,768)|0}$Db(D)}D=g;c[D>>2]=(c[D>>2]|0)-1;k=0;i=e;return k|0}}while(0);ZDb(A);k=z;i=e;return k|0};default:{yDb(b,16,1988648,(o=i,i=i+24|0,c[o>>2]=n,c[o+8>>2]=n,c[o+16>>2]=n,o)|0);i=o;k=-1094995529;i=e;return k|0}}n=g+24|0;do{if((c[n>>2]|0)<0){z=LT(b,0)|0;if((z|0)==0){k=-12;i=e;return k|0}else{c[n>>2]=c[z>>2];A=c[z+8>>2]|0;c[A+8>>2]=1;c[A+48>>2]=65541;c[A+416>>2]=1;I=A+448|0;c[I>>2]=4;c[I+4>>2]=0;c[A+792>>2]=8;I=g+4|0;l=c[I>>2]|0;c[A+412>>2]=l;c[A+72>>2]=l<<3;l=z+48|0;c[l>>2]=0;c[l+4>>2]=0;MT(z,64,1,c[I>>2]|0);break}}}while(0);g=pz(h)|0;I=TS(h,d,g)|0;if((I|0)==(g|0)){c[d+32>>2]=c[n>>2];c[d+48>>2]=g;g=d+36|0;c[g>>2]=c[g>>2]|1;k=0;i=e;return k|0}if((I|0)<0){k=I;i=e;return k|0}yDb(b,16,2084216,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;k=-5;i=e;return k|0}function eA(a){a=a|0;$Db((c[a+12>>2]|0)+28|0);return 0}function fA(a){a=a|0;var b=0;b=c[a+4>>2]|0;return((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==1227245122?100:0)|0}function gA(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=LT(a,0)|0;if((e|0)==0){f=-12;return f|0}g=LT(a,0)|0;if((g|0)==0){f=-12;return f|0}Vy(d,8,0)|0;a=rz(d)|0;h=b;c[h>>2]=rz(d)|0;rz(d)|0;rz(d)|0;rz(d)|0;b=rz(d)|0;Vy(d,12,0)|0;i=rz(d)|0;j=e+8|0;c[(c[j>>2]|0)+120>>2]=i;i=rz(d)|0;c[(c[j>>2]|0)+124>>2]=i;Vy(d,8,0)|0;i=WDb(768)|0;c[(c[j>>2]|0)+96>>2]=i;i=c[j>>2]|0;k=c[i+96>>2]|0;if((k|0)==0){f=-12;return f|0}c[i+100>>2]=768;mz(d,k,768)|0;k=rz(d)|0;i=g+8|0;c[(c[i>>2]|0)+412>>2]=k;MT(e,32,1,b);b=c[j>>2]|0;c[b+8>>2]=0;c[b+48>>2]=118;c[b+140>>2]=11;b=c[h>>2]|0;h=b;j=(b|0)<0|0?-1:0;b=e+56|0;c[b>>2]=h;c[b+4>>2]=j;b=e+64|0;c[b>>2]=h;c[b+4>>2]=j;j=c[i>>2]|0;c[j+8>>2]=1;c[j+48>>2]=65541;c[j+416>>2]=1;b=j+448|0;c[b>>2]=4;c[b+4>>2]=0;c[j+792>>2]=8;c[j+72>>2]=c[j+412>>2]<<3;j=a-3|0;Ty(d,j,(j|0)<0|0?-1:0,0)|0;MT(g,64,1,c[(c[i>>2]|0)+412>>2]|0);f=0;return f|0}function hA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=e;if((c[g>>2]|0)==0){h=-541478725;i=d;return h|0}if((Xy(f)|0)!=0){h=-541478725;i=d;return h|0}j=e+16|0;do{if((c[j>>2]|0)==0){k=0;do{if((Xy(f)|0)!=0){h=-5;l=14;break}k=(lz(f)|0)+(k<<8)|0;}while((k|0)!=1230389587);if((l|0)==14){i=d;return h|0}k=rz(f)|0;rz(f)|0;m=rz(f)|0;rz(f)|0;n=rz(f)|0;o=n-m|0;m=k-n|0;c[e+12>>2]=m;if((o|m|0)<0){yDb(a,16,2152896,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=d;return h|0}m=TS(f,b,o)|0;if((m|0)<0){h=m;i=d;return h|0}else{o=e+4|0;n=c[o>>2]|0;k=b+8|0;c[k>>2]=n;c[k+4>>2]=(n|0)<0|0?-1:0;c[o>>2]=n+m;p=m;break}}else{m=e+12|0;n=c[m>>2]|0;if((n|0)<=0){p=-11;break}o=TS(f,b,n)|0;if((o|0)<0){h=o;i=d;return h|0}else{n=e+8|0;k=c[n>>2]|0;q=b+8|0;c[q>>2]=k;c[q+4>>2]=(k|0)<0|0?-1:0;c[n>>2]=k+((o|0)/(c[m>>2]|0)|0);c[g>>2]=(c[g>>2]|0)-1;p=o;break}}}while(0);g=(c[j>>2]|0)==0|0;c[j>>2]=g;c[b+32>>2]=g;h=p;i=d;return h|0}function iA(b){b=b|0;var e=0,f=0,g=0,h=0;e=c[b+4>>2]|0;b=a[e]|0;a:do{if((b<<24>>24|0)==75){f=6}else if((b<<24>>24|0)==66){if((a[e+1|0]|0)!=73){break}if((a[e+2|0]|0)==75){switch(a[e+3|0]|0){case 98:case 102:case 103:case 104:case 105:{f=9;break a;break};default:{}}}if(b<<24>>24==75){f=6}}}while(0);do{if((f|0)==6){if((a[e+1|0]|0)!=66){break}if((a[e+2|0]|0)!=50){break}b=a[e+3|0]|0;if((b<<24>>24|0)==97|(b<<24>>24|0)==100|(b<<24>>24|0)==102|(b<<24>>24|0)==103){f=9}}}while(0);do{if((f|0)==9){b=e+8|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==0){break}b=e+20|0;g=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;if(!((g|0)!=0&g>>>0<7681>>>0)){break}g=e+24|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;if(!((b|0)!=0&b>>>0<4801>>>0)){break}b=e+28|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==0){break}b=e+32|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==0){break}else{h=100}return h|0}}while(0);h=0;return h|0}function jA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;d=i;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=LT(b,0)|0;if((g|0)==0){h=-12;i=d;return h|0}j=rz(f)|0;k=g+8|0;c[(c[k>>2]|0)+52>>2]=j;j=e;c[j>>2]=(rz(f)|0)+8;l=rz(f)|0;m=g+56|0;c[m>>2]=l;c[m+4>>2]=0;if(l>>>0>1e6>>>0){yDb(b,16,2033288,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;h=-5;i=d;return h|0}l=rz(f)|0;if(l>>>0>(c[j>>2]|0)>>>0){yDb(b,16,1988576,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;h=-5;i=d;return h|0}Vy(f,4,0)|0;l=rz(f)|0;c[(c[k>>2]|0)+120>>2]=l;l=rz(f)|0;c[(c[k>>2]|0)+124>>2]=l;l=rz(f)|0;o=rz(f)|0;if((l|0)==0|(o|0)==0){yDb(b,16,1955288,(n=i,i=i+16|0,c[n>>2]=l,c[n+8>>2]=o,n)|0);i=n;h=-5;i=d;return h|0}MT(g,64,o,l);l=g+92|0;o=c[g+40>>2]|0;c[l>>2]=c[g+44>>2];c[l+4>>2]=o;o=c[k>>2]|0;c[o+8>>2]=0;c[o+48>>2]=136;if((c[o+52>>2]&16777215|0)==3293771){yDb(b,24,1928328,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=c[k>>2]|0;c[l+48>>2]=0;p=l}else{p=o}if((CT(p,f,4)|0)<0){h=-12;i=d;return h|0}p=rz(f)|0;o=e+4|0;c[o>>2]=p;if(p>>>0>256>>>0){yDb(b,16,1906248,(n=i,i=i+8|0,c[n>>2]=p,n)|0);i=n;h=-5;i=d;return h|0}do{if((p|0)!=0){Vy(f,p<<2,0)|0;if((c[o>>2]|0)==0){break}else{q=0}while(1){l=LT(b,0)|0;if((l|0)==0){h=-12;r=33;break}s=l+8|0;t=c[s>>2]|0;c[t+8>>2]=1;c[t+52>>2]=0;t=pz(f)|0;c[(c[s>>2]|0)+412>>2]=t;MT(l,64,1,t);t=pz(f)|0;l=c[s>>2]|0;c[l+48>>2]=t>>>12&1|86064;u=l+416|0;if((t&8192|0)==0){c[u>>2]=1;t=l+448|0;c[t>>2]=4;c[t+4>>2]=0}else{c[u>>2]=2;u=l+448|0;c[u>>2]=3;c[u+4>>2]=0}if((BT(l,4)|0)!=0){h=-12;r=33;break}l=c[(c[s>>2]|0)+96>>2]|0;x=c[(c[k>>2]|0)+52>>2]|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=q+1|0;v=c[o>>2]|0;if(l>>>0<v>>>0){q=l}else{r=15;break}}if((r|0)==15){if((v|0)==0){break}l=b+28|0;s=0;do{u=rz(f)|0;s=s+1|0;c[(c[(c[l>>2]|0)+(s<<2)>>2]|0)+4>>2]=u;}while(s>>>0<(c[o>>2]|0)>>>0)}else if((r|0)==33){i=d;return h|0}}}while(0);o=0;v=rz(f)|0;while(1){q=o;k=0;p=c[m>>2]|0;s=c[m+4>>2]|0;if(!((k|0)<(s|0)|(k|0)==(s|0)&q>>>0<p>>>0)){r=32;break}l=YGb(p,s,-1,-1)|0;if((q|0)==(l|0)&(k|0)==(F|0)){w=0;y=c[j>>2]|0}else{w=v&1;y=rz(f)|0}l=v&-2;s=y&-2;if(!(s>>>0>l>>>0)){r=30;break}p=jT(g,l,0,q,k,s-l|0,0,w)|0;if((p|0)<0){h=p;r=33;break}else{o=o+1|0;v=s}}if((r|0)==30){yDb(b,16,1885472,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;h=-5;i=d;return h|0}else if((r|0)==32){n=c[g+400>>2]|0;Ty(f,c[n>>2]|0,c[n+4>>2]|0,0)|0;c[e+8>>2]=-1;h=0;i=d;return h|0}else if((r|0)==33){i=d;return h|0}return 0}function kA(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;f=c[a+12>>2]|0;g=c[a+16>>2]|0;h=f+8|0;j=c[h>>2]|0;do{if((j|0)<0){k=c[c[a+28>>2]>>2]|0;l=f+16|0;m=c[l>>2]|0;n=c[l+4>>2]|0;o=k+56|0;p=c[o+4>>2]|0;if(!((n|0)<(p|0)|(n|0)==(p|0)&m>>>0<(c[o>>2]|0)>>>0)){q=-541478725;i=e;return q|0}o=oT(k,m,n,4)|0;if((o|0)>=0){c[f+2072>>2]=c[(c[k+400>>2]|0)+(o*24|0)+16>>2]>>2;c[h>>2]=0;r=0;break}o=c[l+4>>2]|0;yDb(a,16,2152848,(s=i,i=i+16|0,c[s>>2]=c[l>>2],c[s+8>>2]=o,s)|0);i=s;q=-5;i=e;return q|0}else{r=j}}while(0);j=f+4|0;o=f+2072|0;a:do{if(r>>>0<(c[j>>2]|0)>>>0){while(1){t=rz(g)|0;u=c[o>>2]|0;if(t>>>0>(u-4|0)>>>0){v=8;break}c[o>>2]=-4-t+u;c[h>>2]=(c[h>>2]|0)+1;if(t>>>0>3>>>0){break}Vy(g,t,0)|0;if(!((c[h>>2]|0)>>>0<(c[j>>2]|0)>>>0)){break a}}if((v|0)==8){l=f+16|0;k=c[l+4>>2]|0;yDb(a,16,2084144,(s=i,i=i+32|0,c[s>>2]=c[l>>2],c[s+8>>2]=k,c[s+16>>2]=t,c[s+24>>2]=u,s)|0);i=s;q=-5;i=e;return q|0}k=TS(g,b,t)|0;if((k|0)<0){q=k;i=e;return q|0}c[b+32>>2]=c[h>>2];k=c[h>>2]|0;l=f+24+(k-1<<3)|0;n=c[l+4>>2]|0;m=b+8|0;c[m>>2]=c[l>>2];c[m+4>>2]=n;if((c[b+28>>2]|0)<=3){q=0;i=e;return q|0}n=c[b+24>>2]|0;m=YGb(c[l>>2]|0,c[l+4>>2]|0,((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>0)/(c[(c[(c[(c[a+28>>2]|0)+(k<<2)>>2]|0)+8>>2]|0)+416>>2]<<1>>>0)|0,0)|0;c[l>>2]=m;c[l+4>>2]=F;q=0;i=e;return q|0}}while(0);a=TS(g,b,c[o>>2]|0)|0;if((a|0)<0){q=a;i=e;return q|0}c[b+32>>2]=0;a=f+16|0;f=c[a>>2]|0;o=c[a+4>>2]|0;g=YGb(f,o,1,0)|0;c[a>>2]=g;c[a+4>>2]=F;a=b+8|0;c[a>>2]=f;c[a+4>>2]=o;o=b+36|0;c[o>>2]=c[o>>2]|1;c[h>>2]=-1;q=0;i=e;return q|0}function lA(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;f=c[a+12>>2]|0;e=c[a+16>>2]|0;if((c[e+88>>2]|0)==0){g=-1;return g|0}d=c[(c[c[a+28>>2]>>2]|0)+400>>2]|0;a=Ty(e,c[d>>2]|0,c[d+4>>2]|0,0)|0;d=F;e=0;if((d|0)<(e|0)|(d|0)==(e|0)&a>>>0<0>>>0){g=-1;return g|0}TGb(f+16|0,0,2056)|0;c[f+8>>2]=-1;g=0;return g|0}function mA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+48|0;e=d|0;f=d+40|0;g=c[b+12>>2]|0;h=b+16|0;j=c[h>>2]|0;k=LT(b,0)|0;if((k|0)==0){l=-12;i=d;return l|0}m=k+8|0;n=c[m>>2]|0;c[n+52>>2]=0;c[n+8>>2]=0;o=g+8|0;if((c[o>>2]|0)==0){c[n+120>>2]=640;c[n+124>>2]=400}MT(k,60,c[g+20>>2]|0,c[g+16>>2]|0);n=g+4|0;p=~~(+(c[k+40>>2]|0)/+(c[k+44>>2]|0)*+(c[n>>2]|0));c[n>>2]=(p|0)<1?1:p;p=c[m>>2]|0;c[p+48>>2]=1112823892;if((BT(p,2)|0)!=0){l=-12;i=d;return l|0}a[c[(c[m>>2]|0)+96>>2]|0]=16;a[(c[(c[m>>2]|0)+96>>2]|0)+1|0]=0;if((c[j+88>>2]|0)==0){l=0;i=d;return l|0}c[f>>2]=0;p=Wy(j)|0;n=g+24|0;c[n>>2]=p;c[n+4>>2]=F;do{if((OP(b,n,f,0)|0)<0){p=e|0;g=c[h>>2]|0;k=Wy(g)|0;q=YGb(k,F,-256,-1)|0;Ty(g,q,F,0)|0;if((mz(g,p,16)|0)!=16){break}if((PGb(p,637456,16)|0)!=0){break}if((lz(g)|0)!=1){break}q=YGb(c[n>>2]|0,c[n+4>>2]|0,-256,-1)|0;c[n>>2]=q;c[n+4>>2]=F;q=lz(g)|0;if((q-1|0)>>>0>11>>>0){break}k=(mz(g,p,12)|0)!=12;if(!(k|(a[p]|0)==0)){a[e+q|0]=0;CBb(b+1140|0,2251056,p,0)|0}q=lz(g)|0;if((q-1|0)>>>0>19>>>0){break}k=(mz(g,p,20)|0)!=20;if(!(k|(a[p]|0)==0)){a[e+q|0]=0;CBb(b+1140|0,2237392,p,0)|0}q=lz(g)|0;if((q-1|0)>>>0>19>>>0){break}k=(mz(g,p,20)|0)!=20;if(!(k|(a[p]|0)==0)){a[e+q|0]=0;CBb(b+1140|0,2224648,p,0)|0}q=lz(g)|0;if((q-1|0)>>>0>34>>>0){break}k=(mz(g,p,35)|0)!=35;if(k|(a[p]|0)==0){break}a[e+q|0]=0;CBb(b+1140|0,2214728,p,0)|0}}while(0);if((c[o>>2]|0)==0){if((c[f>>2]|0)==0){f=c[n>>2]|0;o=c[n+4>>2]|0;b=c[m>>2]|0;e=0;h=o>>>0>e>>>0|o>>>0==e>>>0&f>>>0>4e3>>>0?1280:640;c[b+120>>2]=h;r=b;s=o;t=f;u=h}else{h=c[m>>2]|0;r=h;s=c[n+4>>2]|0;t=c[n>>2]|0;u=c[h+120>>2]|0}h=u>>3<<1;u=hHb(t,s,h,(h|0)<0|0?-1:0)|0;c[r+124>>2]=u<<4|0>>>28}Ty(j,0,0,0)|0;l=0;i=d;return l|0}function nA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=d+24|0;f=c[e>>2]|0;g=a+16|0;a=c[g>>2]|0;do{if((f|0)==0&(c[e+4>>2]|0)==0){if((Xy(a)|0)!=0){h=-5;return h|0}if((TS(c[g>>2]|0,b,c[d+4>>2]|0)|0)<0){h=-5}else{break}return h|0}else{if((TS(a,b,f)|0)<0){h=-5;return h|0}else{c[e>>2]=-1;c[e+4>>2]=-1;break}}}while(0);e=b+36|0;c[e>>2]=c[e>>2]|1;h=0;return h|0}function oA(b){b=b|0;var e=0,f=0,g=0,h=0;e=c[b+4>>2]|0;b=e;do{if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==1313423960){if((a[e+4|0]|0)!=26){break}f=e+5|0;g=(d[f]|d[f+1|0]<<8)<<16>>16;if(!(g<<16>>16!=0&(g&65535)>>>0<161>>>0)){break}g=a[e+9|0]|0;if(g<<24>>24!=0&(g&255)>>>0<33>>>0){h=100}else{break}return h|0}}while(0);h=0;return h|0}function pA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[b+12>>2]|0;e=c[b+16>>2]|0;f=LT(b,0)|0;if((f|0)==0){g=-12;return g|0}h=f+8|0;i=c[h>>2]|0;c[i+52>>2]=0;c[i+8>>2]=0;if((c[d+8>>2]|0)==0){c[i+120>>2]=640;c[i+124>>2]=400}MT(f,60,c[d+20>>2]|0,c[d+16>>2]|0);i=d+4|0;j=~~(+(c[f+40>>2]|0)/+(c[f+44>>2]|0)*+(c[i>>2]|0));c[i>>2]=(j|0)<1?1:j;Vy(e,5,0)|0;j=(pz(e)|0)<<3;c[(c[h>>2]|0)+120>>2]=j;j=pz(e)|0;c[(c[h>>2]|0)+124>>2]=j;j=(lz(e)|0)&255;i=j<<24>>24;f=(c[h>>2]|0)+124|0;c[f>>2]=ba(c[f>>2]|0,i)|0;f=(lz(e)|0)&255;k=c[h>>2]|0;l=f<<24>>24;m=(l&1|0)==0?2:50;if((l&2|0)==0){n=m;o=m}else{p=m|(ba((l<<4&256)+256|0,i)|0);n=p;o=p}c[k+100>>2]=o;c[k+48>>2]=(l&4|0)!=0?1480739150:1112823892;if((BT(k,n)|0)!=0){g=-12;return g|0}a[c[(c[h>>2]|0)+96>>2]|0]=j;a[(c[(c[h>>2]|0)+96>>2]|0)+1|0]=f;f=c[h>>2]|0;if((mz(e,(c[f+96>>2]|0)+2|0,(c[f+100>>2]|0)-2|0)|0)<0){g=-5;return g|0}if((c[e+88>>2]|0)==0){g=0;return g|0}f=Wy(e)|0;j=YGb(f,F,-9,-1)|0;f=c[(c[h>>2]|0)+100>>2]|0;n=ZGb(j,F,f,(f|0)<0|0?-1:0)|0;f=d+24|0;c[f>>2]=n;c[f+4>>2]=F;OP(b,f,0,0)|0;f=(c[(c[h>>2]|0)+100>>2]|0)+9|0;Ty(e,f,(f|0)<0|0?-1:0,0)|0;g=0;return g|0}function qA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;f=b+12|0;g=c[f>>2]|0;h=c[b+16>>2]|0;if((lz(h)|0)!=1){j=-1094995529;i=d;return j|0}k=c[f>>2]|0;f=LT(b,0)|0;if((f|0)==0){j=-12;i=d;return j|0}l=f+8|0;m=c[l>>2]|0;c[m+52>>2]=0;c[m+8>>2]=0;if((c[k+8>>2]|0)==0){c[m+120>>2]=640;c[m+124>>2]=400}MT(f,60,c[k+20>>2]|0,c[k+16>>2]|0);m=k+4|0;k=~~(+(c[f+40>>2]|0)/+(c[f+44>>2]|0)*+(c[m>>2]|0));c[m>>2]=(k|0)<1?1:k;k=c[l>>2]|0;c[k+48>>2]=1112823892;if((BT(k,4146)|0)!=0){j=-12;i=d;return j|0}a[c[(c[l>>2]|0)+96>>2]|0]=16;a[(c[(c[l>>2]|0)+96>>2]|0)+1|0]=3;if((mz(h,(c[(c[l>>2]|0)+96>>2]|0)+2|0,24)|0)<0){j=-5;i=d;return j|0}Vy(h,144,0)|0;if((mz(h,(c[(c[l>>2]|0)+96>>2]|0)+26|0,24)|0)<0){j=-5;i=d;return j|0}if((mz(h,(c[(c[l>>2]|0)+96>>2]|0)+50|0,4096)|0)<0){j=-5;i=d;return j|0}if((c[h+88>>2]|0)==0){j=0;i=d;return j|0}c[e>>2]=0;k=Wy(h)|0;m=YGb(k,F,-4289,-1)|0;k=g+24|0;c[k>>2]=m;c[k+4>>2]=F;c[(c[l>>2]|0)+120>>2]=640;OP(b,k,e,0)|0;if((c[g+8>>2]|0)==0){g=c[l>>2]|0;l=c[g+120>>2]>>3<<1;e=hHb(c[k>>2]|0,c[k+4>>2]|0,l,(l|0)<0|0?-1:0)|0;c[g+124>>2]=e<<4|0>>>28}Ty(h,4289,0,0)|0;j=0;i=d;return j|0}function rA(a){a=a|0;var b=0,d=0;if((c[a+8>>2]|0)>>>0<12>>>0){b=0;return b|0}d=(PGb(c[a+4>>2]|0,917728,12)|0)==0;b=d?100:0;return b|0}function sA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;f=c[b+12>>2]|0;g=c[b+16>>2]|0;c[e>>2]=0;if((c[g+88>>2]|0)==0){h=-5;i=d;return h|0}j=LT(b,0)|0;if((j|0)==0){h=-12;i=d;return h|0}k=j+8|0;l=c[k>>2]|0;c[l+52>>2]=0;c[l+8>>2]=0;m=f+8|0;if((c[m>>2]|0)==0){c[l+120>>2]=640;c[l+124>>2]=400}MT(j,60,c[f+20>>2]|0,c[f+16>>2]|0);l=f+4|0;n=~~(+(c[j+40>>2]|0)/+(c[j+44>>2]|0)*+(c[l>>2]|0));c[l>>2]=(n|0)<1?1:n;n=c[k>>2]|0;c[n+48>>2]=4801606;if((BT(n,4146)|0)!=0){h=-12;i=d;return h|0}a[c[(c[k>>2]|0)+96>>2]|0]=16;a[(c[(c[k>>2]|0)+96>>2]|0)+1|0]=3;n=Wy(g)|0;l=YGb(n,F,-4144,-1)|0;Ty(g,l,F,0)|0;if((mz(g,(c[(c[k>>2]|0)+96>>2]|0)+50|0,4096)|0)<0){h=-5;i=d;return h|0}if((mz(g,(c[(c[k>>2]|0)+96>>2]|0)+2|0,48)|0)<0){h=-5;i=d;return h|0}l=Wy(g)|0;n=YGb(l,F,-4156,-1)|0;l=f+24|0;c[l>>2]=n;c[l+4>>2]=F;OP(b,l,e,0)|0;if((c[m>>2]|0)==0){m=c[k>>2]|0;k=c[m+120>>2]>>3<<1;e=hHb(c[l>>2]|0,c[l+4>>2]|0,k,(k|0)<0|0?-1:0)|0;c[m+124>>2]=e<<4|0>>>28}Ty(g,12,0,0)|0;h=0;i=d;return h|0}function tA(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=c[a+8>>2]|0;if((b|0)<64){e=0;return e|0}f=c[a+4>>2]|0;a=f;g=f+2|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==27425){h=0}else{e=0;return e|0}while(1){a=(d[g]|d[g+1|0]<<8)<<16>>16;if(!((a<<16>>16|0)==80|(a<<16>>16|0)==64)){e=0;i=5;break}f=(a&65535)+h|0;if((f+3|0)<(b|0)&(f|0)<800){h=f}else{e=50;i=5;break}}if((i|0)==5){return e|0}return 0}function uA(a){a=a|0;var b=0,d=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86070;c[a+412>>2]=8e3;c[a+432>>2]=16;c[a+416>>2]=1;MT(b,64,1,100);d=0;return d|0}function vA(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;f=i;i=i+168|0;g=f|0;h=c[b+16>>2]|0;b=Ty(h,0,0,1)|0;j=F;if((Xy(h)|0)!=0){k=-541478725;i=f;return k|0}pz(h)|0;l=pz(h)|0;m=l>>>3;if(l>>>0>87>>>0){k=-1094995529;i=f;return k|0}l=m<<4;n=mz(h,g,l)|0;if((n|0)<0){k=n;i=f;return k|0}if((n|0)!=(l|0)){k=-5;i=f;return k|0}if((wZ(e,m)|0)<0){k=-12;i=f;return k|0}l=0;do{if((m|0)!=0){n=c[e+24>>2]|0;h=32;o=0;p=g|0;q=0;while(1){r=n;s=h;t=0;u=p;v=q;while(1){w=(d[u]|d[u+1|0]<<8)<<16>>16<<16>>16==129|0;if((s|0)>1){y=s-1|0;z=v<<1|w;A=r}else{B=r;x=fe(w>>>((1-s|0)>>>0)|v<<s|0)|0;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;y=s+31|0;z=w;A=r+4|0}l=z;w=t+1|0;if((w|0)<8){r=A;s=y;t=w;u=u+2|0;v=z}else{break}}v=o+1|0;if((v|0)<(m|0)){n=A;h=y;o=v;p=p+16|0;q=z}else{break}}if((y|0)>=32){break}q=z<<y;l=q;p=q>>>24&255;q=y;o=A;while(1){a[o]=p;h=l;l=h<<8;n=q+8|0;if((n|0)<32){p=h>>>16&255;q=n;o=o+1|0}else{break}}}}while(0);l=0;c[e+48>>2]=1;l=e+64|0;c[l>>2]=b;c[l+4>>2]=j;k=0;i=f;return k|0}function wA(a){a=a|0;var b=0;b=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;c[b+48>>2]=86070;c[b+416>>2]=1;c[b+792>>2]=16;c[b+432>>2]=2;return 0}function xA(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=c[a+16>>2]|0;az(e,27425);az(e,80);a=c[b+24>>2]|0;b=(a|0)==0?8:88;f=0;g=0;while(1){az(e,((d[a+(f>>>3)|0]|0)<<(f&7)>>>6&2)+127|0);h=g+1|0;if((h|0)<80){f=((f|0)<(b|0))+f|0;g=h}else{break}}return 0}function yA(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=LT(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[d+8>>2]|0;c[f+8>>2]=0;c[f+48>>2]=155;c[f+120>>2]=640;c[f+124>>2]=429;c[f+140>>2]=11;MT(d,16,1,12);d=LT(a,0)|0;if((d|0)==0){e=-12;return e|0}a=c[d+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86073;c[a+416>>2]=2;f=a+448|0;c[f>>2]=3;c[f+4>>2]=0;c[a+412>>2]=22050;MT(d,16,1,22050);c[b+8>>2]=1;d=b+16|0;c[d>>2]=0;c[d+4>>2]=0;e=0;return e|0}function zA(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=c[b+12>>2]|0;h=g+8|0;j=b+16|0;while(1){if((c[h>>2]|0)==0){k=13;break}l=c[j>>2]|0;if((c[l+52>>2]|0)!=0){m=-541478725;k=16;break}n=lz(l)|0;if((n|0)==1){m=-541478725;k=16;break}else if((n|0)!=0){k=5;break}}do{if((k|0)==5){l=qz(c[j>>2]|0)|0;o=g+4|0;c[o>>2]=l;if((l|0)==0){m=-1094995529;i=f;return m|0}p=g;q=_Db(g,l+1|0)|0;if((q|0)<0){m=q;i=f;return m|0}a[c[p>>2]|0]=n;q=mz(c[j>>2]|0,(c[p>>2]|0)+1|0,c[o>>2]|0)|0;if((q|0)!=(c[o>>2]|0)){m=-5;i=f;return m|0}if((n&32|0)==0){r=q;break}o=((d[(c[p>>2]|0)+1|0]|0)*65|0)+1|0;if((o|0)>=(q|0)){yDb(b,16,2152360,(l=i,i=i+16|0,c[l>>2]=o,c[l+8>>2]=q,l)|0);i=l;m=-1094995529;i=f;return m|0}if((wZ(e,o)|0)<0){m=-12;i=f;return m|0}o=e+28|0;UGb(c[e+24>>2]|0,(c[p>>2]|0)+1|0,c[o>>2]|0)|0;c[e+32>>2]=1;l=g+16|0;q=c[l+4>>2]|0;s=e+8|0;c[s>>2]=c[l>>2];c[s+4>>2]=q;q=(d[(c[p>>2]|0)+1|0]|0)<<5;c[e+48>>2]=q;p=YGb(q,0,c[l>>2]|0,c[l+4>>2]|0)|0;c[l>>2]=p;c[l+4>>2]=F;c[h>>2]=0;m=c[o>>2]|0;i=f;return m|0}else if((k|0)==13){r=c[g+4>>2]|0}else if((k|0)==16){i=f;return m|0}}while(0);if((wZ(e,r+1|0)|0)<0){m=-12;i=f;return m|0}c[e+32>>2]=0;c[h>>2]=1;h=e+28|0;UGb(c[e+24>>2]|0,c[g>>2]|0,c[h>>2]|0)|0;m=c[h>>2]|0;i=f;return m|0}function AA(a){a=a|0;$Db(c[a+12>>2]|0);return 0}function BA(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<2096){return 0}b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1){return 0}a=b+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>0>1e5>>>0){return 0}a=b+12|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>0>8>>>0){return 0}a=b+16|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=2096){return 0}a=b+21|0;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((e|0)==0){return 0}a=b+25|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==2096){a=b+48|0;return((((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>0)%(e>>>0)|0|0)==0?50:0)|0}else{return 0}return 0}function CA(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=b+8|0;b=c[e>>2]|0;c[b+8>>2]=1;c[b+48>>2]=69638;b=a+16|0;rz(c[b>>2]|0)|0;rz(c[b>>2]|0)|0;f=rz(c[b>>2]|0)|0;c[(c[e>>2]|0)+412>>2]=f;f=rz(c[b>>2]|0)|0;c[(c[e>>2]|0)+416>>2]=f;f=a+1248|0;c[f>>2]=rz(c[b>>2]|0)|0;c[f+4>>2]=0;lz(c[b>>2]|0)|0;a=c[(c[e>>2]|0)+416>>2]|0;g=ba(rz(c[b>>2]|0)|0,a)|0;c[(c[e>>2]|0)+432>>2]=g;Ty(c[b>>2]|0,c[f>>2]|0,c[f+4>>2]|0,0)|0;d=0;return d|0}function DA(a,b){a=a|0;b=b|0;return TS(c[a+16>>2]|0,b,c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+432>>2]|0)|0}function EA(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297371986){e=b+4|0;f=(d[e]|d[e+1|0]<<8)<<16>>16;if((f<<16>>16|0)==(-2|0)|(f<<16>>16|0)==(-257|0)){g=66}else{break}return g|0}}while(0);g=0;return g|0}function FA(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=i;d=a+12|0;e=c[d>>2]|0;f=LT(a,0)|0;if((f|0)==0){g=-12;i=b;return g|0}h=f+8|0;c[(c[h>>2]|0)+8>>2]=1;j=a+16|0;Vy(c[j>>2]|0,4,0)|0;k=tz(c[j>>2]|0)|0;if((k|0)==65279){l=lz(c[j>>2]|0)|0;m=lz(c[j>>2]|0)|0;Vy(c[j>>2]|0,4,0)|0;n=tz(c[j>>2]|0)|0;if(n>>>0<14>>>0){g=-1094995529;i=b;return g|0}Vy(c[j>>2]|0,n-14|0,0)|0;n=Ty(c[j>>2]|0,0,0,1)|0;o=F;if((rz(c[j>>2]|0)|0)!=1145128264){g=-1094995529;i=b;return g|0}p=vz(c[j>>2]|0)|0;if(p>>>0<256>>>0){g=-1094995529;i=b;return g|0}Vy(c[j>>2]|0,4,0)|0;q=vz(c[j>>2]|0)|0;r=p;s=0;if(q>>>0>p>>>0){g=-1094995529;i=b;return g|0}Vy(c[j>>2]|0,12,0)|0;p=YGb(vz(c[j>>2]|0)|0,0,16,0)|0;t=F;if(t>>>0>s>>>0|t>>>0==s>>>0&p>>>0>r>>>0){g=-1094995529;i=b;return g|0}u=c[j>>2]|0;v=Ty(u,0,0,1)|0;w=F;x=YGb(n,o,8,0)|0;y=YGb(x,F,q,0)|0;q=ZGb(y,F,v,w)|0;Vy(u,q,F)|0;q=lz(c[j>>2]|0)|0;if((q|0)==1){z=1347637264}else if((q|0)==0){z=65563}else if((q|0)==2){z=69650}else{DDb(a,2032944,(A=i,i=i+8|0,c[A>>2]=q,A)|0);i=A;g=-1163346256;i=b;return g|0}Vy(c[j>>2]|0,1,0)|0;c[(c[h>>2]|0)+48>>2]=z;q=lz(c[j>>2]|0)|0;c[(c[h>>2]|0)+416>>2]=q;if((q|0)==0){g=-1094995529;i=b;return g|0}Vy(c[j>>2]|0,1,0)|0;q=tz(c[j>>2]|0)|0;c[(c[h>>2]|0)+412>>2]=q;if((q|0)==0){g=-1094995529;i=b;return g|0}Vy(c[j>>2]|0,2,0)|0;Vy(c[j>>2]|0,4,0)|0;q=f+48|0;c[q>>2]=0;c[q+4>>2]=0;q=f+56|0;c[q>>2]=vz(c[j>>2]|0)|0;c[q+4>>2]=0;MT(f,64,1,c[(c[h>>2]|0)+412>>2]|0);f=vz(c[j>>2]|0)|0;c[e+8>>2]=0;q=vz(c[j>>2]|0)|0;u=e+4|0;c[u>>2]=q;if(q>>>0>65535>>>0){yDb(a,24,1988328,(A=i,i=i+8|0,c[A>>2]=q,A)|0);i=A;g=-1094995529;i=b;return g|0}q=vz(c[j>>2]|0)|0;w=e;c[w>>2]=q;v=c[(c[h>>2]|0)+416>>2]|0;if(q>>>0>(65535/(v|0)|0)>>>0){g=-1094995529;i=b;return g|0}c[w>>2]=ba(v,q)|0;c[e+12>>2]=vz(c[j>>2]|0)|0;q=vz(c[j>>2]|0)|0;v=e+16|0;c[v>>2]=q;w=c[(c[h>>2]|0)+416>>2]|0;if(q>>>0>(65535/(w|0)|0)>>>0){g=-1094995529;i=b;return g|0}c[v>>2]=ba(w,q)|0;Vy(c[j>>2]|0,4,0)|0;Vy(c[j>>2]|0,4,0)|0;q=(z|0)==69650;a:do{if(q){z=c[j>>2]|0;w=YGb(p,t,n,o)|0;v=F;y=Ty(z,0,0,1)|0;x=ZGb(w,v,y,F)|0;Vy(z,x,F)|0;x=YGb(vz(c[j>>2]|0)|0,0,16,0)|0;z=F;if(z>>>0>s>>>0|z>>>0==s>>>0&x>>>0>r>>>0){g=-1094995529;i=b;return g|0}y=c[j>>2]|0;v=YGb(x,z,n,o)|0;z=F;x=Ty(y,0,0,1)|0;w=ZGb(v,z,x,F)|0;Vy(y,w,F)|0;w=cEb(c[(c[h>>2]|0)+416>>2]<<5)|0;y=e+20|0;c[y>>2]=w;if((w|0)==0){g=-12;i=b;return g|0}if((c[(c[h>>2]|0)+416>>2]|0)>0){B=0;C=w}else{D=27;break}while(1){if((mz(c[j>>2]|0,C+(B<<5)|0,32)|0)!=32){E=-1094995529;break a}Vy(c[j>>2]|0,24,0)|0;w=B+1|0;if((w|0)>=(c[(c[h>>2]|0)+416>>2]|0)){D=27;break a}B=w;C=c[y>>2]|0}}else{D=27}}while(0);b:do{if((D|0)==27){C=Ty(c[j>>2]|0,0,0,1)|0;B=ZGb(C,F,n,o)|0;C=F;if((s|0)<(C|0)|(s|0)==(C|0)&r>>>0<B>>>0){E=-1094995529;break}B=c[j>>2]|0;C=Ty(B,0,0,1)|0;t=F;p=YGb(r,s,n,o)|0;y=ZGb(p,F,C,t)|0;Vy(B,y,F)|0;if((Xy(c[j>>2]|0)|0)!=0){E=-541478725;break}y=a;B=e+24|0;c:do{if(q){while(1){t=rz(c[j>>2]|0)|0;C=vz(c[j>>2]|0)|0;if(C>>>0<8>>>0){E=-1094995529;break b}p=C-8|0;do{if((t|0)==1096040772){break c}else if((t|0)==1129333825){C=ba(c[u>>2]<<2,c[(c[h>>2]|0)+416>>2]|0)|0;if(p>>>0<C>>>0){E=-1094995529;break b}if((c[B>>2]|0)!=0){yDb(y,24,1955128,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;D=38;break}w=cEb(C)|0;c[B>>2]=w;if((w|0)==0){E=-12;break b}mz(c[j>>2]|0,w,C)|0;Vy(c[j>>2]|0,p-C|0,0)|0;}else{yDb(y,24,1906048,(A=i,i=i+8|0,c[A>>2]=t,A)|0);i=A;D=38}}while(0);if((D|0)==38){D=0;Vy(c[j>>2]|0,p,0)|0;}if((Xy(c[j>>2]|0)|0)!=0){E=-541478725;break b}}}else{while(1){t=rz(c[j>>2]|0)|0;C=vz(c[j>>2]|0)|0;if(C>>>0<8>>>0){E=-1094995529;break b}w=C-8|0;if((t|0)==1096040772){break c}else if((t|0)!=1129333825){yDb(y,24,1906048,(A=i,i=i+8|0,c[A>>2]=t,A)|0);i=A}Vy(c[j>>2]|0,w,0)|0;if((Xy(c[j>>2]|0)|0)!=0){E=-541478725;break b}}}}while(0);w=f;t=0;C=Ty(c[j>>2]|0,0,0,1)|0;x=F;if((t|0)<(x|0)|(t|0)==(x|0)&w>>>0<C>>>0){E=-1094995529;break}if(!((c[B>>2]|0)!=0|q^1)){E=-1094995529;break}C=c[j>>2]|0;x=Ty(C,0,0,1)|0;z=ZGb(w,t,x,F)|0;Vy(C,z,F)|0;if((l|0)==1&(m|0)==0){g=0;i=b;return g|0}DDb(y,1928184,(A=i,i=i+16|0,c[A>>2]=l,c[A+8>>2]=m,A)|0);i=A;g=0;i=b;return g|0}}while(0);m=c[d>>2]|0;$Db(m+20|0);$Db(m+24|0);g=E;i=b;return g|0}else if((k|0)==65534){DDb(a,2083872,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;g=-1163346256;i=b;return g|0}else{yDb(a,16,2151992,(A=i,i=i+8|0,c[A>>2]=k,A)|0);i=A;g=-1094995529;i=b;return g|0}return 0}function GA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;f=c[b+12>>2]|0;g=b+16|0;if((Xy(c[g>>2]|0)|0)!=0){h=-541478725;return h|0}b=f+8|0;i=(c[b>>2]|0)+1|0;c[b>>2]=i;j=c[f+4>>2]|0;do{if((i|0)==(j|0)){k=c[f+16>>2]|0;l=k;m=((k>>>0)/(c[e+416>>2]<<3>>>0)|0)*14|0}else{if(i>>>0<j>>>0){l=c[f>>2]|0;m=c[f+12>>2]|0;break}else{h=-541478725;return h|0}}}while(0);if((c[e+48>>2]|0)==69650){j=e+416|0;if((wZ(d,l+8+((c[j>>2]|0)*36|0)|0)|0)<0){h=-12;return h|0}e=c[d+24>>2]|0;i=e;x=fe(l|0)|0;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;i=e+4|0;x=fe(m|0)|0;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;i=c[j>>2]<<5;UGb(e+8|0,c[f+20>>2]|0,i)|0;k=i|8;i=c[j>>2]<<2;UGb(e+k|0,(c[f+24>>2]|0)+(ba((c[b>>2]|0)-1|0,i)|0)|0,i)|0;b=mz(c[g>>2]|0,e+(i+k)|0,l)|0;if((b|0)!=(l|0)){BZ(d)}c[d+48>>2]=m;n=b}else{n=TS(c[g>>2]|0,d,l)|0}c[d+32>>2]=0;h=(n|0)==(l|0)?n:-5;return h|0}function HA(a){a=a|0;var b=0;b=c[a+12>>2]|0;$Db(b+20|0);$Db(b+24|0);return 0}function IA(b){b=b|0;var e=0,f=0,g=0;if((c[b+8>>2]|0)<16){return 0}e=c[b+4>>2]|0;b=e;if(!((d[b]|d[b+1|0]<<8)<<16>>16<<16>>16==1)){return 0}b=a[e+2|0]|0;if(b<<24>>24==0){return 0}if((a[e+3|0]|0)==0){return 0}f=(b&255)+1|0;b=e+4|0;if(((d[b]|d[b+1|0]<<8)<<16>>16&65535|0)!=(f|0)){return 0}b=a[e+6|0]|0;if(b<<24>>24==0){return 0}if((a[e+7|0]|0)==0){return 0}g=(b&255)+f|0;f=e+8|0;if(((d[f]|d[f+1|0]<<8)<<16>>16&65535|0)!=(g|0)){return 0}f=a[e+10|0]|0;if(f<<24>>24==0){return 0}if((a[e+11|0]|0)==0){return 0}b=e+12|0;if(((d[b]|d[b+1|0]<<8)<<16>>16&65535|0)!=((f&255)+g|0)){return 0}if((a[e+14|0]|0)==0){return 0}else{return((a[e+15|0]|0)==0?0:100)|0}return 0}function JA(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[d+16>>2]|0;g=c[d+12>>2]|0;h=g+8|0;j=0;k=0;do{b[h+(k<<2)>>1]=pz(f)|0;a[h+(k<<2)+2|0]=lz(f)|0;l=lz(f)|0;a[h+(k<<2)+3|0]=l;m=l&255;if(m>>>0>32>>>0){n=3;break}j=m+j|0;k=k+1|0;}while((k|0)<512);if((n|0)==3){yDb(d,16,2083576,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=e;return o|0}n=d+20|0;c[n>>2]=c[n>>2]|1;n=LT(d,0)|0;if((n|0)==0){o=-12;i=e;return o|0}d=c[n+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=103;c[d+120>>2]=320;c[d+124>>2]=192;c[n+80>>2]=5;c[n+84>>2]=6;MT(n,64,2,25);d=j;k=(j|0)<0|0?-1:0;j=n+64|0;c[j>>2]=d;c[j+4>>2]=k;j=n+56|0;c[j>>2]=d;c[j+4>>2]=k;k=n+48|0;c[k>>2]=0;c[k+4>>2]=0;c[g+2056>>2]=0;c[g+2188>>2]=0;c[g+2192>>2]=0;o=0;i=e;return o|0}function KA(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[b+16>>2]|0;j=c[b+12>>2]|0;k=j+2056|0;l=c[k>>2]|0;m=j+8|0;n=j+2192|0;o=j+2188|0;do{if((c[n>>2]|0)!=0){c[o>>2]=(c[o>>2]|0)+1;c[n>>2]=0;p=pz(h)|0;if((p|0)<=42){break}q=j+2196|0;do{if((c[q>>2]|0)==0){r=LT(b,0)|0;c[q>>2]=r;if((r|0)==0){s=-12;i=g;return s|0}else{c[(c[r+8>>2]|0)+8>>2]=1;break}}}while(0);Vy(h,26,0)|0;r=yU(b,f,c[q>>2]|0,p-26|0)|0;if((r|0)<=0){break}c[f+32>>2]=1;t=f+36|0;c[t>>2]=c[t>>2]|1;s=r;i=g;return s|0}}while(0);r=c[o>>2]|0;do{if((r|0)<(d[m+(l<<2)+3|0]|0)){t=m+(l<<2)|0;if((r|0)==0){u=t;v=14;break}w=t;x=r;y=j+2060|0}else{t=c[k>>2]|0;if((t|0)>510){s=-541478725;i=g;return s|0}z=l+1|0;if((a[m+(z<<2)+2|0]|0)==0){s=-541478725;i=g;return s|0}else{c[k>>2]=t+1;c[o>>2]=0;u=m+(z<<2)|0;v=14;break}}}while(0);if((v|0)==14){Ty(h,e[u>>1]<<11,0,0)|0;m=j+2060|0;j=0;do{c[m+(j<<2)>>2]=rz(h)|0;j=j+1|0;}while((j|0)<32);w=u;x=c[o>>2]|0;y=m}Ty(h,(e[w>>1]<<11)+(c[y+(x<<2)>>2]|0)|0,0,0)|0;x=pz(h)|0;y=wZ(f,x+769|0)|0;if((y|0)<0){s=y;i=g;return s|0}y=f+24|0;a[c[y>>2]|0]=0;w=f+28|0;c[w>>2]=x+1;do{if((mz(h,(c[y>>2]|0)+1|0,x)|0)<(x|0)){A=-5}else{m=pz(h)|0;if((m|0)==768){v=21}else if((m|0)!=0){yDb(b,16,2151576,(u=i,i=i+8|0,c[u>>2]=m,u)|0);i=u;A=-1094995529;break}if((v|0)==21){u=c[y>>2]|0;a[u]=a[u]|1;if((mz(h,(c[y>>2]|0)+(c[w>>2]|0)|0,768)|0)<768){A=-5;break}c[w>>2]=(c[w>>2]|0)+768}c[f+32>>2]=0;c[n>>2]=1;if((c[k>>2]|0)!=0){s=0;i=g;return s|0}if((c[o>>2]|0)!=0){s=0;i=g;return s|0}u=f+36|0;c[u>>2]=c[u>>2]|1;u=c[y>>2]|0;a[u]=a[u]|2;s=0;i=g;return s|0}}while(0);BZ(f);s=A;i=g;return s|0}function LA(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1717985635){e=b+4|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==256){f=100}else{break}return f|0}}while(0);f=0;return f|0}function MA(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;d=i;i=i+1088|0;e=d|0;f=d+32|0;g=d+1056|0;j=d+1072|0;l=b+16|0;m=c[l>>2]|0;n=b+12|0;o=c[n>>2]|0;Vy(m,8,0)|0;if((vz(m)|0)!=1684370275){yDb(b,16,2151296,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=d;return q|0}r=Az(m)|0;if(!((r|0)==32&(F|0)==0)){q=-1094995529;i=d;return q|0}r=c[l>>2]|0;s=c[n>>2]|0;t=LT(b,0)|0;if((t|0)==0){q=-12;i=d;return q|0}u=t+8|0;c[(c[u>>2]|0)+8>>2]=1;t=Az(r)|0;v=F;c[(c[u>>2]|0)+412>>2]=~~(c[k>>2]=t,c[k+4>>2]=v,+h[k>>3]);v=rz(r)|0;c[(c[u>>2]|0)+52>>2]=v;v=vz(r)|0;t=vz(r)|0;w=s;c[w>>2]=t;c[(c[u>>2]|0)+432>>2]=t;t=s+4|0;c[t>>2]=vz(r)|0;s=vz(r)|0;c[(c[u>>2]|0)+416>>2]=s;s=vz(r)|0;r=c[u>>2]|0;c[r+792>>2]=s;y=c[t>>2]|0;do{if((y|0)>0){t=c[w>>2]|0;if((t|0)<=0){z=8;break}A=c[r+412>>2]|0;B=t;C=gHb(B<<3|0>>>29,((t|0)<0|0?-1:0)<<3|B>>>29,A,(A|0)<0|0?-1:0)|0;A=hHb(C,F,y,(y|0)<0|0?-1:0)|0;c[r+72>>2]=A}else{z=8}}while(0);if((z|0)==8){c[r+72>>2]=0}y=c[r+52>>2]|0;if((y|0)==1835233388){r=lH(s,(v|4)^2)|0;c[(c[u>>2]|0)+48>>2]=r}else{r=vT(1240632,y)|0;c[(c[u>>2]|0)+48>>2]=r}r=b+28|0;u=c[c[r>>2]>>2]|0;if((Xy(m)|0)!=0){q=-1094995529;i=d;return q|0}y=b;v=o+32|0;s=o+40|0;w=m+88|0;A=j|0;C=j+4|0;j=e|0;e=f|0;f=b+1140|0;B=0;a:while(1){if((B|0)!=0){t=c[s+4>>2]|0;D=0;if((t|0)<(D|0)|(t|0)==(D|0)&(c[s>>2]|0)>>>0<0>>>0){E=B;z=60;break}if((c[w>>2]|0)==0){E=B;z=60;break}}D=vz(m)|0;G=Az(m)|0;H=F;t=Ty(m,0,0,1)|0;I=F;if((Xy(m)|0)!=0){E=B;z=60;break}do{if((D|0)==1718773093){z=53}else if((D|0)==1667785070){J=xI(b,c[l>>2]|0,u,G,H)|0;if((J|0)<0){q=J;z=71;break a}else{K=B}}else if((D|0)==1885432692){J=c[l>>2]|0;L=c[c[r>>2]>>2]|0;M=c[n>>2]|0;N=Ty(J,0,0,1)|0;O=F;P=Az(J)|0;Q=F;R=0;if(Q>>>0>R>>>0|Q>>>0==R>>>0&P>>>0>89478485>>>0){q=-1094995529;z=71;break a}R=Az(J)|0;S=L+64|0;c[S>>2]=R;c[S+4>>2]=F;R=vz(J)|0;T=YGb(c[S>>2]|0,c[S+4>>2]|0,R,0)|0;c[S>>2]=T;c[S+4>>2]=F;T=vz(J)|0;R=YGb(c[S>>2]|0,c[S+4>>2]|0,T,0)|0;c[S>>2]=R;c[S+4>>2]=F;S=L+56|0;c[S>>2]=0;c[S+4>>2]=0;L=0;if((Q|0)>(L|0)|(Q|0)==(L|0)&P>>>0>0>>>0){L=M;R=M+4|0;T=0;U=0;V=0;W=0;X=0;while(1){jT(c[c[r>>2]>>2]|0,U,T,X,W,0,0,1)|0;Y=c[L>>2]|0;if((Y|0)==0){Z=sF(J)|0}else{Z=Y}Y=YGb(Z,(Z|0)<0|0?-1:0,U,T)|0;_=F;$=c[R>>2]|0;if(($|0)==0){aa=sF(J)|0}else{aa=$}$=YGb(c[S>>2]|0,c[S+4>>2]|0,aa,(aa|0)<0|0?-1:0)|0;ba=F;c[S>>2]=$;c[S+4>>2]=ba;ca=V+1|0;da=(ca|0)<0|0?-1:0;if((da|0)<(Q|0)|(da|0)==(Q|0)&ca>>>0<P>>>0){T=_;U=Y;V=ca;W=ba;X=$}else{ea=_;fa=Y;break}}}else{ea=0;fa=0}X=Ty(J,0,0,1)|0;W=ZGb(X,F,N,O)|0;X=F;if((X|0)>(H|0)|(X|0)==(H|0)&W>>>0>G>>>0){z=48;break a}W=YGb(N,O,G,H)|0;X=F;V=Ty(J,0,0,1)|0;U=ZGb(W,X,V,F)|0;Vy(J,U,F)|0;U=M+8|0;c[U>>2]=fa;c[U+4>>2]=ea;K=B}else if((D|0)==1684108385){Vy(m,4,0)|0;U=Ty(m,0,0,1)|0;c[v>>2]=U;c[v+4>>2]=F;U=0;V=(H|0)<(U|0)|(H|0)==(U|0)&G>>>0<0>>>0;U=YGb(G,H,-4,-1)|0;X=V?-1:U;U=V?-1:F;c[s>>2]=X;c[s+4>>2]=U;V=0;if(!((U|0)>(V|0)|(U|0)==(V|0)&X>>>0>0>>>0)){K=1;break}if((c[w>>2]|0)==0){K=1;break}Vy(m,X,U)|0;K=1}else if((D|0)==1802857321){ga=c[l>>2]|0;U=0;if(H>>>0>U>>>0|H>>>0==U>>>0&G>>>0>2147483631>>>0){q=-1094995529;z=71;break a}ha=(c[c[r>>2]>>2]|0)+8|0;U=c[ha>>2]|0;X=c[U+48>>2]|0;if((X|0)==86032){V=0;if((H|0)<(V|0)|(H|0)==(V|0)&G>>>0<24>>>0){z=31;break a}mz(ga,A,12)|0;if((BT(c[ha>>2]|0,36)|0)!=0){q=-1094995529;z=71;break a}if((PGb(C,1905912,8)|0)!=0){V=c[(c[ha>>2]|0)+96>>2]|0;x=603979776;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=(c[(c[ha>>2]|0)+96>>2]|0)+4|0;x=1667329121;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=(c[(c[ha>>2]|0)+96>>2]|0)+8|0;x=0;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;UGb((c[(c[ha>>2]|0)+96>>2]|0)+12|0,A|0,12)|0;mz(ga,(c[(c[ha>>2]|0)+96>>2]|0)+24|0,12)|0;V=YGb(G,H,-24,-1)|0;Vy(ga,V,F)|0;K=B;break}V=0;if((H|0)<(V|0)|(H|0)==(V|0)&G>>>0<48>>>0){z=35;break a}mz(ga,c[(c[ha>>2]|0)+96>>2]|0,36)|0;V=YGb(G,H,-48,-1)|0;Vy(ga,V,F)|0;K=B;break}else if((X|0)==86018){X=Ty(ga,0,0,1)|0;V=F;kH(b,ga,g)|0;W=Ty(ga,0,0,1)|0;T=F;P=YGb(X,V,G,H)|0;V=ZGb(P,F,W,T)|0;T=V;if((T|0)<0){z=28;break a}V=c[ha>>2]|0;if((c[V+96>>2]|0)==0){z=28;break a}if((c[V+48>>2]|0)!=86018){z=28;break a}Vy(ga,T,(T|0)<0|0?-1:0)|0;K=B;break}else{if((CT(U,ga,G)|0)<0){q=-1094995529;z=71;break a}else{K=B;break}}}else if((D|0)==1768842863){U=c[l>>2]|0;T=vz(U)|0;if((T|0)==0){K=B;break}else{ia=0}while(1){xz(U,2147483647,j,32)|0;xz(U,2147483647,e,1024)|0;CBb(f,j,e,0)|0;V=ia+1|0;if(V>>>0<T>>>0){ia=V}else{K=B;break}}}else{T=D>>>16&255;U=D>>>8&255;M=D&255;yDb(y,24,2083352,(p=i,i=i+56|0,c[p>>2]=D,c[p+8>>2]=D>>>0>536870911>>>0?D>>>24:32,c[p+16>>2]=T>>>0<32>>>0?32:T,c[p+24>>2]=U>>>0<32>>>0?32:U,c[p+32>>2]=M>>>0<32>>>0?32:M,c[p+40>>2]=G,c[p+48>>2]=H,p)|0);i=p;z=53}}while(0);if((z|0)==53){z=0;D=0;if((H|0)<(D|0)|(H|0)==(D|0)&G>>>0<0>>>0){q=-1094995529;z=71;break}else{K=B}}D=0;if((H|0)>(D|0)|(H|0)==(D|0)&G>>>0>0>>>0){D=ZGb(-1,2147483647,G,H)|0;M=F;if((I|0)>(M|0)|(I|0)==(M|0)&t>>>0>D>>>0){q=-1094995529;z=71;break}D=YGb(t,I,G,H)|0;M=F;U=Ty(m,0,0,1)|0;T=ZGb(D,M,U,F)|0;U=F;J=0;if((U|0)<(J|0)|(U|0)==(J|0)&T>>>0<0>>>0){ja=0;ka=0}else{T=Ty(m,0,0,1)|0;J=ZGb(D,M,T,F)|0;ja=F;ka=J}Vy(m,ka,ja)|0;}if((Xy(m)|0)==0){B=K}else{E=K;z=60;break}}if((z|0)==28){yDb(y,16,1954960,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=d;return q|0}else if((z|0)==31){yDb(y,16,1928072,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Vy(ga,G,H)|0;q=-1094995529;i=d;return q|0}else if((z|0)==35){yDb(y,16,1928072,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;$Db((c[ha>>2]|0)+96|0);q=-1094995529;i=d;return q|0}else if((z|0)==48){yDb(y,16,1988104,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=d;return q|0}else if((z|0)==60){if((E|0)==0){q=-1094995529;i=d;return q|0}E=c[o>>2]|0;do{if((E|0)>0){y=c[o+4>>2]|0;if((y|0)<=0){z=65;break}ha=o+40|0;H=c[ha>>2]|0;G=c[ha+4>>2]|0;ha=0;if(!((G|0)>(ha|0)|(G|0)==(ha|0)&H>>>0>0>>>0)){break}ha=eHb(H,G,E,(E|0)<0|0?-1:0)|0;G=gHb(ha,F,y,(y|0)<0|0?-1:0)|0;y=u+64|0;c[y>>2]=G;c[y+4>>2]=F}else{z=65}}while(0);b:do{if((z|0)==65){do{if((c[u+404>>2]|0)!=0){E=u+56|0;y=c[E>>2]|0;G=c[E+4>>2]|0;E=0;if(!((G|0)>(E|0)|(G|0)==(E|0)&y>>>0>0>>>0)){break}E=c[u+8>>2]|0;ha=c[E+412>>2]|0;H=o+40|0;ga=c[H>>2]|0;K=gHb(ga<<3|0>>>29,c[H+4>>2]<<3|ga>>>29,ha,(ha|0)<0|0?-1:0)|0;ha=eHb(K,F,y,G)|0;c[E+72>>2]=ha;break b}}while(0);yDb(b,16,2032424,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=d;return q|0}}while(0);MT(u,64,1,c[(c[u+8>>2]|0)+412>>2]|0);p=u+48|0;c[p>>2]=0;c[p+4>>2]=0;p=o+40|0;u=c[p+4>>2]|0;b=-1;if(!((u|0)>(b|0)|(u|0)==(b|0)&(c[p>>2]|0)>>>0>-1>>>0)){q=0;i=d;return q|0}p=o+32|0;Ty(m,c[p>>2]|0,c[p+4>>2]|0,0)|0;q=0;i=d;return q|0}else if((z|0)==71){i=d;return q|0}return 0}function NA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[a+16>>2]|0;e=c[c[a+28>>2]>>2]|0;f=c[a+12>>2]|0;if((Xy(d)|0)!=0){g=-541478725;return g|0}a=f+40|0;h=c[a>>2]|0;i=c[a+4>>2]|0;a=0;do{if((i|0)>(a|0)|(i|0)==(a|0)&h>>>0>0>>>0){j=f+32|0;k=YGb(c[j>>2]|0,c[j+4>>2]|0,h,i)|0;j=F;l=Ty(d,0,0,1)|0;m=F;n=ZGb(k,j,l,m)|0;o=F;if((k|0)==(l|0)&(j|0)==(m|0)){g=-541478725;return g|0}m=0;if((o|0)<(m|0)|(o|0)==(m|0)&n>>>0<0>>>0){g=-5}else{p=o;q=n;break}return g|0}else{p=0;q=4096}}while(0);i=c[f+4>>2]|0;h=c[f>>2]|0;do{if((h|0)>0&(i|0)==1){a=4096-(4096%(h|0)|0)|0;n=(a|0)<0|0?-1:0;o=(n|0)>(p|0)|(n|0)==(p|0)&a>>>0>q>>>0?q:a;r=(o|0)/(h|0)|0;s=o}else{o=c[e+404>>2]|0;if((o|0)==0){r=i;s=h;break}a=f+16|0;n=c[a>>2]|0;m=c[a+4>>2]|0;a=o-1|0;o=a;j=(a|0)<0|0?-1:0;if((m|0)<(j|0)|(m|0)==(j|0)&n>>>0<o>>>0){a=YGb(n,m,1,0)|0;l=a;a=c[e+400>>2]|0;k=a+(l*24|0)|0;t=n;u=a+(t*24|0)|0;v=ZGb(c[k>>2]|0,c[k+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;u=a+(l*24|0)+8|0;l=a+(t*24|0)+8|0;t=ZGb(c[u>>2]|0,c[u+4>>2]|0,c[l>>2]|0,c[l+4>>2]|0)|0;r=t;s=v;break}if((n|0)==(o|0)&(m|0)==(j|0)){j=f+8|0;m=n;n=c[e+400>>2]|0;o=n+(m*24|0)|0;v=ZGb(c[j>>2]|0,c[j+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;o=e+56|0;j=n+(m*24|0)+8|0;m=ZGb(c[o>>2]|0,c[o+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;r=m;s=v;break}else{g=-5;return g|0}}}while(0);e=(s|0)<0|0?-1:0;if((s|0)==0|(r|0)==0|((e|0)>(p|0)|(e|0)==(p|0)&s>>>0>q>>>0)){g=-5;return g|0}q=TS(d,b,s)|0;if((q|0)<0){g=q;return g|0}c[b+28>>2]=q;c[b+32>>2]=0;q=f+24|0;s=c[q>>2]|0;d=c[q+4>>2]|0;p=b+8|0;c[p>>2]=s;c[p+4>>2]=d;p=b+16|0;c[p>>2]=s;c[p+4>>2]=d;d=f+16|0;f=YGb(c[d>>2]|0,c[d+4>>2]|0,1,0)|0;c[d>>2]=f;c[d+4>>2]=F;d=YGb(c[q>>2]|0,c[q+4>>2]|0,r,(r|0)<0|0?-1:0)|0;c[q>>2]=d;c[q+4>>2]=F;g=0;return g|0}function OA(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[c[a+28>>2]>>2]|0;g=c[a+12>>2]|0;h=0;i=(e|0)>(h|0)|(e|0)==(h|0)&d>>>0>0>>>0;h=i?d:0;d=i?e:0;e=c[g+4>>2]|0;do{if((e|0)>0){i=c[g>>2]|0;if((i|0)<=0){j=6;break}k=i;l=(i|0)<0|0?-1:0;i=e;m=(e|0)<0|0?-1:0;n=eHb(h,d,i,m)|0;o=gHb(n,F,k,l)|0;n=F;p=g+40|0;q=c[p>>2]|0;r=c[p+4>>2]|0;p=0;if((r|0)>(p|0)|(r|0)==(p|0)&q>>>0>0>>>0){p=(n|0)>(r|0)|(n|0)==(r|0)&o>>>0>q>>>0;s=p?r:n;t=p?q:o}else{s=n;t=o}o=eHb(t,s,k,l)|0;l=F;k=gHb(i,m,o,l)|0;u=F;v=k;w=l;x=o;y=s;z=t}else{j=6}}while(0);do{if((j|0)==6){if((c[b+404>>2]|0)==0){A=-1;return A|0}else{t=oT(b,h,d,f)|0;s=c[b+400>>2]|0;e=s+(t*24|0)+8|0;o=s+(t*24|0)|0;u=c[e+4>>2]|0;v=c[e>>2]|0;w=(t|0)<0|0?-1:0;x=t;y=c[o+4>>2]|0;z=c[o>>2]|0;break}}}while(0);b=c[a+16>>2]|0;a=g+32|0;f=YGb(c[a>>2]|0,c[a+4>>2]|0,z,y)|0;y=Ty(b,f,F,0)|0;f=F;b=0;if((f|0)<(b|0)|(f|0)==(b|0)&y>>>0<0>>>0){A=-1;return A|0}y=g+16|0;c[y>>2]=x;c[y+4>>2]=w;w=g+24|0;c[w>>2]=v;c[w+4>>2]=u;A=0;return A|0}function PA(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;f=c[a+12>>2]|0;g=e+48|0;j=uT(1240632,c[g>>2]|0)|0;if((c[a+24>>2]|0)!=1){yDb(a,16,2032224,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=b;return m|0}n=c[g>>2]|0;if((n-86018|0)>>>0<2>>>0){yDb(a,16,1988016,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1163346256;i=b;return m|0}a:do{switch(n|0){case 65540:case 65536:case 65537:case 65548:case 65549:case 65544:case 65545:case 65557:case 65556:case 65559:case 65558:case 65543:case 65542:{o=1835233388;break};default:{if((j|0)!=0){o=j;break a}yDb(a,16,1954928,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=b;return m|0}}}while(0);j=e+432|0;do{if((c[j>>2]|0)==0){if((c[d+88>>2]|0)!=0){break}yDb(a,16,1927960,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=b;return m|0}}while(0);Yy(d,1717985635);fz(d,1);fz(d,0);Yy(d,1668506980);ez(d,32,0);h[k>>3]=+(c[e+412>>2]|0);ez(d,c[k>>2]|0,c[k+4>>2]|0);Yy(d,o);switch(c[g>>2]|0){case 65557:case 65559:{p=3;break};case 65536:case 65548:case 65544:{p=2;break};case 65556:case 65558:{p=1;break};default:{p=0}}Zy(d,p);Zy(d,c[j>>2]|0);j=c[g>>2]|0;p=e+416|0;o=c[p>>2]|0;if((j|0)==86016|(j|0)==86017){q=1152}else if((j|0)==86059){q=384}else if((j|0)==86046){q=320}else if((j|0)==65540|(j|0)==65536|(j|0)==65537|(j|0)==65548|(j|0)==65549|(j|0)==65544|(j|0)==65545|(j|0)==65557|(j|0)==65556|(j|0)==65559|(j|0)==65558|(j|0)==65543|(j|0)==65542){q=1}else if((j|0)==69633){l=o<<2;q=((1024-l<<3|0)/(l|0)|0)+1|0}else if((j|0)==86032){q=4096}else if((j|0)==69638){q=(((o*-14|0)+2048|0)/(o|0)|0)+2|0}else if((j|0)==73728|(j|0)==86034|(j|0)==86076|(j|0)==86040){q=160}else if((j|0)==86035){q=o<<11}else if((j|0)==86019){q=1536}else if((j|0)==69632){q=64}else if((j|0)==86025|(j|0)==86026){q=6}else{q=0}Zy(d,q);Zy(d,c[p>>2]|0);Zy(d,u0a(c[g>>2]|0)|0);p=e+448|0;if(!((c[p>>2]|0)==0&(c[p+4>>2]|0)==0)){Yy(d,1851877475);ez(d,12,0);wF(d,c[p>>2]|0,c[p+4>>2]|0)}p=c[g>>2]|0;if((p|0)==86035){Yy(d,1768650091);g=e+100|0;q=c[g>>2]|0;ez(d,q,(q|0)<0|0?-1:0);Ry(d,c[e+96>>2]|0,c[g>>2]|0)}else if((p|0)==73728){Yy(d,1768650091);ez(d,29,0);Ry(d,2281248,12);Zy(d,17);Ry(d,2266048,8);Py(d,0);fz(d,33279);Py(d,0);Py(d,1)}else if((p|0)==86032){Yy(d,1768650091);p=e+100|0;g=(c[p>>2]|0)+12|0;ez(d,g,(g|0)<0|0?-1:0);Ry(d,2298528,12);Ry(d,c[e+96>>2]|0,c[p>>2]|0)}p=a+1140|0;do{if((ABb(c[p>>2]|0)|0)!=0){Yy(d,1868983913);a=BBb(c[p>>2]|0,9203512,0,2)|0;if((a|0)==0){r=0;s=4}else{e=0;g=0;q=a;do{a=SGb(c[q>>2]|0)|0;g=YGb(a+2+(SGb(c[q+4>>2]|0)|0)|0,0,g,e)|0;e=F;q=BBb(c[p>>2]|0,9203512,q,2)|0;}while((q|0)!=0);q=YGb(g,e,4,0)|0;r=F;s=q}ez(d,s,r);Zy(d,ABb(c[p>>2]|0)|0);q=BBb(c[p>>2]|0,9203512,0,2)|0;if((q|0)==0){break}else{t=q}do{_y(d,c[t>>2]|0)|0;_y(d,c[t+4>>2]|0)|0;t=BBb(c[p>>2]|0,9203512,t,2)|0;}while((t|0)!=0)}}while(0);Yy(d,1635017060);t=Ty(d,0,0,1)|0;p=f;c[p>>2]=t;c[p+4>>2]=F;ez(d,-1,-1);Zy(d,0);Sy(d);m=0;i=b;return m|0}function QA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[b+12>>2]|0;f=d+28|0;Ry(c[b+16>>2]|0,c[d+24>>2]|0,c[f>>2]|0);if((c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+432>>2]|0)!=0){g=0;return g|0}b=e+8|0;d=c[b>>2]|0;h=e+16|0;i=(c[h>>2]|0)+5|0;do{if((i|0)<0){c[b>>2]=0}else{j=jEb(d,e+12|0,i)|0;c[b>>2]=j;if((j|0)==0){break}k=c[f>>2]|0;l=k>>28;if((l|0)==0){m=k}else{k=c[h>>2]|0;c[h>>2]=k+1;a[j+k|0]=l|128;m=c[f>>2]|0}l=m>>21;if((l|0)==0){n=m}else{k=c[h>>2]|0;c[h>>2]=k+1;a[(c[b>>2]|0)+k|0]=l|128;n=c[f>>2]|0}l=n>>14;if((l|0)==0){o=n}else{k=c[h>>2]|0;c[h>>2]=k+1;a[(c[b>>2]|0)+k|0]=l|128;o=c[f>>2]|0}l=o>>7;if((l|0)==0){p=o&255}else{k=c[h>>2]|0;c[h>>2]=k+1;a[(c[b>>2]|0)+k|0]=l|128;p=c[f>>2]&255}l=c[h>>2]|0;c[h>>2]=l+1;a[(c[b>>2]|0)+l|0]=p&127;l=e+20|0;c[l>>2]=(c[l>>2]|0)+1;g=0;return g|0}}while(0);ZDb(d);g=-12;return g|0}function RA(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[d+88>>2]|0)==0){f=b+8|0;$Db(f);return 0}a=Ty(d,0,0,1)|0;g=F;h=b;Ty(d,c[h>>2]|0,c[h+4>>2]|0,0)|0;i=c[h>>2]|0;j=c[h+4>>2]|0;h=YGb(a,g,-8,-1)|0;k=ZGb(h,F,i,j)|0;ez(d,k,F);Ty(d,a,g,0)|0;if((c[e+432>>2]|0)==0){Yy(d,1953194352);g=b+16|0;a=(c[g>>2]|0)+24|0;ez(d,a,(a|0)<0|0?-1:0);a=b+20|0;k=c[a>>2]|0;ez(d,k,(k|0)<0|0?-1:0);k=c[a>>2]|0;a=c[e+48>>2]|0;j=c[e+416>>2]|0;if((a|0)==73728|(a|0)==86034|(a|0)==86076|(a|0)==86040){l=160}else if((a|0)==69638){l=(((j*-14|0)+2048|0)/(j|0)|0)+2|0}else if((a|0)==86059){l=384}else if((a|0)==69632){l=64}else if((a|0)==65540|(a|0)==65536|(a|0)==65537|(a|0)==65548|(a|0)==65549|(a|0)==65544|(a|0)==65545|(a|0)==65557|(a|0)==65556|(a|0)==65559|(a|0)==65558|(a|0)==65543|(a|0)==65542){l=1}else if((a|0)==86025|(a|0)==86026){l=6}else if((a|0)==86016|(a|0)==86017){l=1152}else if((a|0)==69633){e=j<<2;l=((1024-e<<3|0)/(e|0)|0)+1|0}else if((a|0)==86035){l=j<<11}else if((a|0)==86046){l=320}else if((a|0)==86032){l=4096}else if((a|0)==86019){l=1536}else{l=0}ez(d,ba(l,k)|0,0);Zy(d,0);Zy(d,0);Ry(d,c[b+8>>2]|0,c[g>>2]|0);c[b+12>>2]=0}Sy(d);f=b+8|0;$Db(f);return 0}function SA(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[b+8>>2]|0;do{if((e|0)>0){f=c[b+4>>2]|0;g=-256;h=0;i=0;j=0;k=0;a:while(1){l=d[f+k|0]|g;do{if((g|0)==256){if(l>>>0<432>>>0){if(l>>>0<j>>>0){m=0;n=14;break a}else{o=l}}else{o=0}if((l|0)==438|(l|0)==435){p=o;q=i;r=h+1|0;break}else if((l|0)==432){if((a[f+(k+1)|0]|0)==32){p=o;q=i+1|0;r=h;break}else{m=0;n=14;break a}}else{if((l|0)==436|l>>>0>439>>>0){m=0;n=14;break a}else{p=o;q=i;r=h;break}}}else{p=j;q=i;r=h}}while(0);s=k+1|0;if((s|0)<(e|0)){g=l<<8;h=r;i=q;j=p;k=s}else{n=11;break}}if((n|0)==11){if((q|0)==0){break}if((q*9|0|0)>(r*10|0|0)){break}else{m=50}return m|0}else if((n|0)==14){return m|0}}}while(0);m=0;return m|0}function TA(a){a=a|0;var b=0,d=0,e=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=0;c[e+48>>2]=133;MT(b,32,1,300);e=Wy(c[a+16>>2]|0)|0;a=e;if((a|0)<=0){d=0;return d|0}e=(ba(c[b+44>>2]|0,a)|0)/7200|0;a=b+56|0;c[a>>2]=e;c[a+4>>2]=(e|0)<0|0?-1:0;d=0;return d|0}function UA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=d+24|0;f=b+16|0;b=TS(c[f>>2]|0,d,24)|0;a:do{if((b|0)<1){g=b}else{h=b;while(1){if((a[c[e>>2]|0]&63)==9){g=h;break a}BZ(d);i=TS(c[f>>2]|0,d,24)|0;if((i|0)<1){g=i;break}else{h=i}}}}while(0);c[d+32>>2]=0;f=d+64|0;b=eHb(c[f>>2]|0,c[f+4>>2]|0,24,0)|0;f=F;h=d+8|0;c[h>>2]=b;c[h+4>>2]=f;h=d+16|0;c[h>>2]=b;c[h+4>>2]=f;if((g|0)<=5){return g|0}f=c[e>>2]|0;if(!((a[f]&63)==9)){return g|0}if(!((a[f+1|0]&63)==1)){return g|0}if(!((a[f+5|0]&15)==0)){return g|0}c[d+36>>2]=1;return g|0}function VA(b){b=b|0;var e=0,f=0,g=0,h=0;if((c[b+8>>2]|0)<32){e=0;return e|0}f=c[b+4>>2]|0;b=f+24|0;g=b|0;h=b+4|0;if(!((d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)==0&(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)==0)){e=0;return e|0}h=f+10|0;if(!((d[h]|d[h+1|0]<<8)<<16>>16<<16>>16==0)){e=0;return e|0}if((a[f]|0)!=1){e=0;return e|0}h=f+20|0;g=de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0;if((g&65535)>>>0>512>>>0){e=0;return e|0}if((a[f+18|0]|0)!=0){e=0;return e|0}if((a[f+19|0]|0)==0){e=0;return e|0}h=f+14|0;if((d[h]|d[h+1|0]<<8)<<16>>16<<16>>16==0){e=0;return e|0}h=f+16|0;if((d[h]|d[h+1|0]<<8)<<16>>16<<16>>16==0){e=0;return e|0}h=f+2|0;b=fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;h=f+22|0;if(b>>>0<((g&65535)+32+((de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>0){e=0;return e|0}h=f+6|0;g=f+12|0;e=((d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)==0?60:30)>>>(((d[g]|d[g+1|0]<<8)<<16>>16<<16>>16!=256|0)>>>0);return e|0}function WA(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+12>>2]|0;e=d+8|0;f=c[e>>2]|0;do{if((f|0)!=0){g=PEb(d+12|0,f)|0;if((g|0)>=0){break}yDb(a,16,2032128,(h=i,i=i+8|0,c[h>>2]=c[e>>2],h)|0);i=h;j=g;i=b;return j|0}}while(0);c[d+20>>2]=0;c[d+56>>2]=-1;c[d+60>>2]=-1;d=a+20|0;c[d>>2]=c[d>>2]|1;j=0;i=b;return j|0}function XA(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;g=c[b+12>>2]|0;h=c[b+16>>2]|0;if((Xy(h)|0)!=0){j=-541478725;i=f;return j|0}k=Ty(h,0,0,1)|0;l=F;m=g+20|0;n=g+24|0;do{if((c[m>>2]|0)==0){if((mz(h,n,32)|0)==32){break}else{j=-541478725}i=f;return j|0}}while(0);if((a[n]|0)!=1){yDb(b,16,2082984,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;j=-1094995529;i=f;return j|0}o=g+26|0;p=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=g+38|0;q=de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0;o=g+40|0;r=de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0;o=g+44|0;s=de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0;o=g+46|0;t=(d[o]|d[o+1|0]<<8)<<16>>16;o=de(t|0)|0;u=q&65535;q=r&65535;r=ba(u+15&131056,q)|0;v=((ba(r,d[g+43|0]|0)|0)>>>3)+(s&65535)|0;if((s&65535)>>>0>512>>>0){j=-1094995529;i=f;return j|0}s=0;r=YGb(o&65535,0,32,0)|0;w=YGb(r,F,v,0)|0;r=F;if(s>>>0<r>>>0|s>>>0==r>>>0&p>>>0<w>>>0){j=-1094995529;i=f;return j|0}do{if((c[m>>2]|0)==0){x=18}else{w=o&65535;if(t<<16>>16==0){x=18;break}r=g+60|0;if((c[r>>2]|0)==-1){s=LT(b,0)|0;if((s|0)==0){j=-12;i=f;return j|0}y=c[s+8>>2]|0;c[y+8>>2]=1;c[y+52>>2]=0;c[y+48>>2]=65540;z=y+416|0;if((a[g+25|0]&16)==0){c[z>>2]=1;A=y+448|0;c[A>>2]=4;c[A+4>>2]=0}else{c[z>>2]=2;z=y+448|0;c[z>>2]=3;c[z+4>>2]=0}z=g+4|0;c[y+412>>2]=c[z>>2];y=s+48|0;c[y>>2]=0;c[y+4>>2]=0;c[r>>2]=c[s>>2];MT(s,64,1,c[z>>2]|0)}z=TS(h,e,w)|0;if((z|0)<0){j=z;i=f;return j|0}else{c[e+32>>2]=c[r>>2];r=e+64|0;c[r>>2]=k;c[r+4>>2]=l;c[e+48>>2]=w;c[m>>2]=0;B=z;break}}}while(0);do{if((x|0)==18){z=g+56|0;do{if((c[z>>2]|0)==-1){w=LT(b,0)|0;if((w|0)==0){j=-12;i=f;return j|0}r=c[w+8>>2]|0;c[r+8>>2]=0;c[r+52>>2]=0;c[r+48>>2]=160;c[r+120>>2]=u;c[r+124>>2]=q;r=w+48|0;c[r>>2]=0;c[r+4>>2]=0;c[z>>2]=c[w>>2];if((c[g+8>>2]|0)==0){MT(w,64,1,c[g+4>>2]|0);break}else{MT(w,64,c[g+16>>2]|0,c[g+12>>2]|0);break}}}while(0);if((wZ(e,v+32|0)|0)<0){j=-12;i=f;return j|0}w=e+24|0;UGb(c[w>>2]|0,n|0,32)|0;r=mz(h,(c[w>>2]|0)+32|0,v)|0;if((r|0)<0){BZ(e);j=r;i=f;return j|0}yZ(e,r+32|0);c[e+32>>2]=c[z>>2];w=e+36|0;c[w>>2]=c[w>>2]|1;w=e+64|0;c[w>>2]=k;c[w+4>>2]=l;if((c[g+8>>2]|0)==0){w=o&65535;C=t<<16>>16==0?220:w;D=w}else{C=1;D=o&65535}c[e+48>>2]=C;c[m>>2]=D;if(t<<16>>16==0){B=r;break}else{j=r}i=f;return j|0}}while(0);Vy(h,p-32-(o&65535)-v|0,0)|0;j=B;i=f;return j|0}function YA(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,2250912,20)|0)!=0;return(b?0:100)|0}function ZA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;d=i;i=i+4120|0;e=d|0;f=d+8|0;g=d+4104|0;h=d+4112|0;j=b+12|0;k=c[j>>2]|0;l=b+16|0;m=f|0;n=wz(c[l>>2]|0,m,4096)|0;a:do{if((n|0)<1){o=n;p=63}else{q=k+20|0;r=e;s=b+32|0;t=0;u=0;v=0;b:while(1){w=u+16|0;c:do{if((u|0)==0){x=v;while(1){y=x+1|0;c[g>>2]=m;z=qd(m|0,2031944)|0;A=f+z|0;c[g>>2]=A;B=hc(A|0,2031944)|0;C=f+(B+z)|0;c[g>>2]=C;if((a[C]|0)==0){D=C}else{E=z+1+B|0;B=f+E|0;c[g>>2]=B;a[C]=0;C=f+(E+(qd(B|0,2031944)|0))|0;c[g>>2]=C;D=C}C=a[A]|0;do{if(!((C<<24>>24|0)==0|(C<<24>>24|0)==35)){if((QGb(A,2082768)|0)==0){G=y;break c}if((QGb(A,1954800)|0)==0){p=18;break b}if((QGb(A,1885056)|0)!=0){H=y;I=A;p=62;break b}B=qd(D|0,2031944)|0;E=D+B|0;c[g>>2]=E;z=hc(E|0,2031944)|0;J=D+(z+B)|0;c[g>>2]=J;if((a[J]|0)==0){K=J}else{c[g>>2]=D+(B+1+z);a[J]=0;J=c[g>>2]|0;z=J+(qd(J|0,2031944)|0)|0;c[g>>2]=z;K=z}z=qd(K|0,2031944)|0;J=K+z|0;c[g>>2]=J;B=hc(J|0,2031944)|0;L=K+(B+z)|0;c[g>>2]=L;if((a[L]|0)!=0){c[g>>2]=K+(z+1+B);a[L]=0;L=c[g>>2]|0;c[g>>2]=L+(qd(L|0,2031944)|0)}if((QGb(E,2343136)|0)!=0){M=y;p=59;break b}if((QGb(J,2320768)|0)!=0){M=y;p=59;break b}if((c[q>>2]|0)>=0){break}c[q>>2]=1}}while(0);A=wz(c[l>>2]|0,m,4096)|0;if((A|0)<1){o=A;p=63;break a}else{x=y}}}else{x=v;while(1){N=x+1|0;c[g>>2]=m;A=qd(m|0,2031944)|0;C=f+A|0;c[g>>2]=C;J=hc(C|0,2031944)|0;E=f+(J+A)|0;c[g>>2]=E;if((a[E]|0)==0){O=E}else{L=A+1+J|0;J=f+L|0;c[g>>2]=J;a[E]=0;E=f+(L+(qd(J|0,2031944)|0))|0;c[g>>2]=E;O=E}E=a[C]|0;do{if(!((E<<24>>24|0)==0|(E<<24>>24|0)==35)){if((QGb(C,2082768)|0)==0){G=N;break c}if((QGb(C,1954800)|0)==0){J=qd(O|0,2031944)|0;P=O+J|0;c[g>>2]=P;L=hc(P|0,2031944)|0;A=O+(L+J)|0;c[g>>2]=A;if((a[A]|0)!=0){c[g>>2]=O+(J+1+L);a[A]=0;A=c[g>>2]|0;c[g>>2]=A+(qd(A|0,2031944)|0)}Q=VEb(h,P,1)|0;if((Q|0)<0){p=49;break b}A=c[h+4>>2]|0;c[w>>2]=c[h>>2];c[w+4>>2]=A;break}if((QGb(C,1885056)|0)!=0){H=N;I=C;p=62;break b}A=qd(O|0,2031944)|0;L=O+A|0;c[g>>2]=L;J=hc(L|0,2031944)|0;B=O+(J+A)|0;c[g>>2]=B;if((a[B]|0)==0){R=B}else{c[g>>2]=O+(A+1+J);a[B]=0;B=c[g>>2]|0;J=B+(qd(B|0,2031944)|0)|0;c[g>>2]=J;R=J}J=qd(R|0,2031944)|0;B=R+J|0;c[g>>2]=B;A=hc(B|0,2031944)|0;z=R+(A+J)|0;c[g>>2]=z;if((a[z]|0)!=0){c[g>>2]=R+(J+1+A);a[z]=0;z=c[g>>2]|0;c[g>>2]=z+(qd(z|0,2031944)|0)}if((QGb(L,2343136)|0)!=0){M=N;p=59;break b}if((QGb(B,2320768)|0)!=0){M=N;p=59;break b}if((c[q>>2]|0)>=0){break}c[q>>2]=1}}while(0);C=wz(c[l>>2]|0,m,4096)|0;if((C|0)<1){o=C;p=63;break a}else{x=N}}}}while(0);S=wAb(g,2031944)|0;if((S|0)==0){p=26;break}c[e>>2]=S;w=c[j>>2]|0;do{if((c[w+20>>2]|0)>0){x=a[S]|0;if(x<<24>>24==0){break}else{T=S;U=S;V=x}while(1){x=V<<24>>24;do{if(((x|32)-97|0)>>>0<26>>>0|(x-48|0)>>>0<10>>>0){W=U}else{if((V<<24>>24|0)==95|(V<<24>>24|0)==45){W=U;break}if((T|0)==(U|0)){p=35;break b}if((V<<24>>24|0)==46){W=U;break}else if((V<<24>>24|0)!=47){p=35;break b}W=T+1|0}}while(0);x=T+1|0;C=a[x]|0;if(C<<24>>24==0){break}else{T=x;U=W;V=C}}}}while(0);C=SGb(s|0)|0;x=C+16+(SGb(S|0)|0)|0;C=WDb(x)|0;if((C|0)==0){X=0;Y=-12;break}MS(C,x,s,S);$Db(r);x=w+12|0;E=c[x>>2]|0;if(E>>>0<t>>>0){Z=E;_=c[w+4>>2]|0;$=t}else{B=t<<1;L=B>>>0>16>>>0?B:16;if(L>>>0<=E>>>0|L>>>0>178956970>>>0){X=C;Y=-12;break}E=w+4|0;B=XDb(c[E>>2]|0,L*24|0)|0;if((B|0)==0){X=C;Y=-12;break}z=B;c[E>>2]=z;Z=c[x>>2]|0;_=z;$=L}c[x>>2]=Z+1;x=_+(Z*24|0)|0;TGb(x|0,0,24)|0;c[x>>2]=C;C=_+(Z*24|0)+8|0;c[C>>2]=0;c[C+4>>2]=-2147483648;C=_+(Z*24|0)+16|0;c[C>>2]=0;c[C+4>>2]=-2147483648;C=wz(c[l>>2]|0,m,4096)|0;if((C|0)<1){o=C;p=63;break a}else{t=$;u=x;v=G}}if((p|0)==18){v=qd(D|0,2031944)|0;u=D+v|0;c[g>>2]=u;t=hc(u|0,2031944)|0;u=D+(t+v)|0;c[g>>2]=u;if((a[u]|0)!=0){c[g>>2]=D+(v+1+t);a[u]=0;u=c[g>>2]|0;c[g>>2]=u+(qd(u|0,2031944)|0)}yDb(b,16,1927832,(aa=i,i=i+8|0,c[aa>>2]=y,aa)|0);i=aa;ba=-1094995529;break}else if((p|0)==26){yDb(b,16,1987688,(aa=i,i=i+8|0,c[aa>>2]=G,aa)|0);i=aa;ba=-1094995529;break}else if((p|0)==35){yDb(b,16,2265976,(aa=i,i=i+8|0,c[aa>>2]=S,aa)|0);i=aa;X=0;Y=-1}else if((p|0)==49){yDb(b,16,1905800,(aa=i,i=i+16|0,c[aa>>2]=N,c[aa+8>>2]=P,aa)|0);i=aa;ba=Q;break}else if((p|0)==59){yDb(b,16,2298448,(aa=i,i=i+8|0,c[aa>>2]=M,aa)|0);i=aa;ba=-1094995529;break}else if((p|0)==62){yDb(b,16,2281176,(aa=i,i=i+16|0,c[aa>>2]=H,c[aa+8>>2]=I,aa)|0);i=aa;ba=-1094995529;break}ZDb(X);ZDb(c[e>>2]|0);ba=Y}}while(0);d:do{if((p|0)==63){if((o|0)<0){ba=o;break}Y=c[k+12>>2]|0;if((Y|0)==0){ba=-1094995529;break}e=c[k+4>>2]|0;X=0;aa=0;I=0;while(1){H=e+(I*24|0)+8|0;M=c[H>>2]|0;Q=c[H+4>>2]|0;if((M|0)==0&(Q|0)==(-2147483648|0)){c[H>>2]=aa;c[H+4>>2]=X;ca=X;da=aa}else{ca=Q;da=M}M=e+(I*24|0)+16|0;Q=c[M>>2]|0;H=c[M+4>>2]|0;if((Q|0)==0&(H|0)==(-2147483648|0)){ea=ca;fa=da;ga=I;break}M=YGb(Q,H,da,ca)|0;H=F;Q=I+1|0;if(Q>>>0<Y>>>0){X=H;aa=M;I=Q}else{ea=H;fa=M;ga=Q;break}}if((ga|0)==(Y|0)){I=b+1064|0;c[I>>2]=fa;c[I+4>>2]=ea;c[k+24>>2]=1}I=bB(b,0)|0;if((I|0)<0){ba=I;break}I=k+16|0;if((c[(c[I>>2]|0)+24>>2]|0)==0){ha=0;i=d;return ha|0}else{ia=0}while(1){aa=LT(b,0)|0;if((aa|0)==0){ba=-12;break d}X=c[(c[(c[I>>2]|0)+28>>2]|0)+(ia<<2)>>2]|0;e=BRa(c[aa+8>>2]|0,c[X+8>>2]|0)|0;if((e|0)<0){ba=e;break d}e=X+412|0;Q=aa+412|0;M=c[e+4>>2]|0;c[Q>>2]=c[e>>2];c[Q+4>>2]=M;M=X+92|0;Q=aa+92|0;e=c[M+4>>2]|0;c[Q>>2]=c[M>>2];c[Q+4>>2]=e;e=X+40|0;Q=aa+40|0;M=c[e+4>>2]|0;c[Q>>2]=c[e>>2];c[Q+4>>2]=M;M=X+80|0;X=aa+80|0;aa=c[M+4>>2]|0;c[X>>2]=c[M>>2];c[X+4>>2]=aa;aa=ia+1|0;if(aa>>>0<(c[(c[I>>2]|0)+24>>2]|0)>>>0){ia=aa}else{ha=0;break}}i=d;return ha|0}}while(0);ia=c[j>>2]|0;j=ia+16|0;if((c[j>>2]|0)!=0){KT(j)}j=ia+12|0;b=ia+4|0;if((c[j>>2]|0)!=0){ia=b;k=0;do{$Db((c[ia>>2]|0)+(k*24|0)|0);k=k+1|0;}while(k>>>0<(c[j>>2]|0)>>>0)}$Db(b);ha=ba;i=d;return ha|0}function _A(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;e=d|0;f=a+12|0;g=c[f>>2]|0;h=g+16|0;while(1){j=gT(c[h>>2]|0,b)|0;if(!((j|0)==-541478725)){k=7;break}l=c[f>>2]|0;m=c[l+8>>2]|0;n=(m-(c[l+4>>2]|0)|0)/24|0;o=m+16|0;if((c[o>>2]|0)==0&(c[o+4>>2]|0)==(-2147483648|0)){m=(c[l+16>>2]|0)+1064|0;p=c[m+4>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=p}p=n+1|0;if(!(p>>>0<(c[l+12>>2]|0)>>>0)){q=-541478725;k=12;break}l=bB(a,p)|0;if((l|0)<0){q=l;k=12;break}}if((k|0)==7){if((j|0)<0){q=j;i=d;return q|0}a=(c[g+8>>2]|0)+8|0;g=c[h>>2]|0;h=g+1056|0;f=ZGb(c[a>>2]|0,c[a+4>>2]|0,c[h>>2]|0,c[h+4>>2]|0)|0;c[e>>2]=1;c[e+4>>2]=1e6;h=KDb(f,F,e,(c[(c[g+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0)+40|0)|0;g=F;e=b+8|0;f=c[e>>2]|0;a=c[e+4>>2]|0;if(!((f|0)==0&(a|0)==(-2147483648|0))){l=YGb(f,a,h,g)|0;c[e>>2]=l;c[e+4>>2]=F}e=b+16|0;b=c[e>>2]|0;l=c[e+4>>2]|0;if((b|0)==0&(l|0)==(-2147483648|0)){q=j;i=d;return q|0}a=YGb(b,l,h,g)|0;c[e>>2]=a;c[e+4>>2]=F;q=j;i=d;return q|0}else if((k|0)==12){i=d;return q|0}return 0}function $A(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;a=b+16|0;if((c[a>>2]|0)!=0){KT(a)}a=b+12|0;d=b+4|0;if((c[a>>2]|0)==0){$Db(d);return 0}b=d;e=0;do{$Db((c[b>>2]|0)+(e*24|0)|0);e=e+1|0;}while(e>>>0<(c[a>>2]|0)>>>0);$Db(d);return 0}function aB(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+24|0;m=l|0;n=l+8|0;o=l+16|0;p=a+12|0;q=c[p>>2]|0;r=q+8|0;s=c[r>>2]|0;t=q+16|0;c[o>>2]=c[t>>2];if((c[q+24>>2]|0)==0){u=-29;i=l;return u|0}if((k&10|0)!=0){u=-38;i=l;return u|0}c[t>>2]=0;q=c[p>>2]|0;do{if((b|0)>-1){if(!((c[a+24>>2]|0)>>>0>b>>>0)){v=-22;break}w=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;x=c[w+40>>2]|0;y=c[w+44>>2]|0;c[m>>2]=1;c[m+4>>2]=1e6;c[n>>2]=x;c[n+4>>2]=y;y=KDb(f,g,n,m)|0;x=F;w=JDb(d,e,n,m,8195)|0;z=F;A=JDb(h,j,n,m,8194)|0;B=F;C=A;D=x;E=y;G=z;H=w;I=6}else{B=j;C=h;D=g;E=f;G=e;H=d;I=6}}while(0);do{if((I|0)==6){d=q+12|0;e=c[d>>2]|0;if((e|0)>1){f=c[q+4>>2]|0;g=0;h=e;while(1){e=(g+h|0)/2|0;j=f+(e*24|0)+8|0;m=c[j+4>>2]|0;n=(D|0)<(m|0)|(D|0)==(m|0)&E>>>0<(c[j>>2]|0)>>>0;j=n?g:e;m=n?e:h;if((m-j|0)>1){g=j;h=m}else{J=j;break}}}else{J=0}h=bB(a,J)|0;if((h|0)<0){v=h;break}h=cB(c[p>>2]|0,b,H,G,E,D,C,B,k)|0;if((h|0)<0){if(!(J>>>0<((c[d>>2]|0)-1|0)>>>0)){v=h;break}g=J+1|0;f=(c[q+4>>2]|0)+(g*24|0)+8|0;j=c[f+4>>2]|0;if((j|0)<(B|0)|(j|0)==(B|0)&(c[f>>2]|0)>>>0<C>>>0){f=bB(a,g)|0;if((f|0)<0){v=f;break}K=cB(c[p>>2]|0,b,H,G,E,D,C,B,k)|0}else{K=h}if((K|0)<0){v=K;break}else{L=K}}else{L=h}KT(o);u=L;i=l;return u|0}}while(0);if((c[t>>2]|0)!=0){KT(t)}c[t>>2]=c[o>>2];c[r>>2]=s;u=v;i=l;return u|0}function bB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;e=c[a+12>>2]|0;f=e+4|0;g=c[f>>2]|0;h=g+(b*24|0)|0;j=e+16|0;if((c[j>>2]|0)!=0){KT(j)}k=tN()|0;c[j>>2]=k;if((k|0)==0){l=-12;i=d;return l|0}m=a+1160|0;n=k+1160|0;k=c[m+4>>2]|0;c[n>>2]=c[m>>2];c[n+4>>2]=k;k=h|0;n=aT(j,c[k>>2]|0,0,0)|0;do{if((n|0)<0){o=n}else{m=AT(c[j>>2]|0,0)|0;if((m|0)<0){o=m;break}c[e+8>>2]=h;m=g+(b*24|0)+8|0;if(!((c[m>>2]|0)==0&(c[m+4>>2]|0)==(-2147483648|0))){l=0;i=d;return l|0}if((b|0)==0){p=0;q=0}else{r=b-1|0;s=c[f>>2]|0;t=s+(r*24|0)+8|0;u=s+(r*24|0)+16|0;r=YGb(c[u>>2]|0,c[u+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0)|0;p=F;q=r}c[m>>2]=q;c[m+4>>2]=p;l=0;i=d;return l|0}}while(0);yDb(a,16,2150312,(a=i,i=i+8|0,c[a>>2]=c[k>>2],a)|0);i=a;KT(j);l=o;i=d;return l|0}function cB(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=i;i=i+16|0;m=l|0;n=l+8|0;o=(c[a+8>>2]|0)+8|0;p=a+16|0;a=c[p>>2]|0;q=a+1056|0;r=ZGb(c[o>>2]|0,c[o+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;q=F;o=ZGb(f,g,r,q)|0;g=F;f=(d|0)==0&(e|0)==(-2147483648|0);s=ZGb(d,e,r,q)|0;e=f?0:s;s=f?-2147483648:F;f=(h|0)==(-1|0)&(j|0)==2147483647;d=ZGb(h,j,r,q)|0;q=f?-1:d;d=f?2147483647:F;do{if((b|0)>-1){if((c[a+24>>2]|0)>>>0>b>>>0){f=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;r=c[f+44>>2]|0;c[m>>2]=c[f+40>>2];c[m+4>>2]=r;c[n>>2]=1;c[n+4>>2]=1e6;r=KDb(o,g,n,m)|0;f=F;j=JDb(e,s,n,m,8195)|0;h=F;t=JDb(q,d,n,m,8194)|0;u=F;v=t;w=f;x=r;y=h;z=j;A=c[p>>2]|0;break}else{B=-5;i=l;return B|0}}else{u=d;v=q;w=g;x=o;y=s;z=e;A=a}}while(0);B=tT(A,b,z,y,x,w,v,u,k)|0;i=l;return B|0}function dB(a){a=a|0;c[c[a+12>>2]>>2]=1;return 0}function eB(a,b){a=a|0;b=b|0;var d=0;d=c[a+12>>2]|0;c[d>>2]=eAb(c[d>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0)|0;return 0}function fB(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+64|0;d=b|0;Lb(d|0,64,2149792,(e=i,i=i+8|0,c[e>>2]=c[c[a+12>>2]>>2],e)|0)|0;i=e;e=c[a+16>>2]|0;Ry(e,d,SGb(d|0)|0);i=b;return 0}function gB(a){a=a|0;var b=0,d=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=65552;c[a+52>>2]=1685414244;c[a+416>>2]=6;b=a+448|0;c[b>>2]=1551;c[b+4>>2]=0;c[a+412>>2]=96e3;c[a+72>>2]=13824e3;c[a+432>>2]=18;c[a+792>>2]=24;d=0;return d|0}function hB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+16>>2]|0;if((Xy(d)|0)!=0){e=-5;return e|0}a=tz(d)|0;tz(d)|0;f=TS(d,b,a)|0;c[b+32>>2]=0;e=f;return e|0}function iB(a){a=a|0;var b=0;b=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[b+416>>2]|0)==6){return((c[b+412>>2]|0)!=96e3)<<31>>31|0}else{return-1|0}return 0}function jB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=b+28|0;f=c[e>>2]|0;if((f|0)>65535){yDb(a,16,2031680,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-1;i=d;return h|0}else{g=a+16|0;fz(c[g>>2]|0,f);fz(c[g>>2]|0,32784);Ry(c[g>>2]|0,c[b+24>>2]|0,c[e>>2]|0);h=0;i=d;return h|0}return 0}function kB(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<4){b=0;return b|0}e=c[a+4>>2]|0;a=e;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1095321156){b=0;return b|0}a=e+16|0;b=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==128?100:25;return b|0}function lB(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[b+16>>2]|0;if((rz(e)|0)!=1095321156){yDb(b,16,2031616,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1094995529;i=d;return g|0}h=pz(e)|0;j=pz(e)|0;k=LT(b,0)|0;if((k|0)==0){g=-12;i=d;return g|0}l=k+8|0;m=c[l>>2]|0;c[m+8>>2]=0;c[m+48>>2]=151;m=pz(e)|0;c[(c[l>>2]|0)+120>>2]=m;m=pz(e)|0;c[(c[l>>2]|0)+124>>2]=m;m=rz(e)|0;if((m|0)==0){yDb(b,24,1987376,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;n=100}else{n=m}MT(k,24,n,1e3);Vy(e,112,0)|0;e=k+56|0;c[e>>2]=j;c[e+4>>2]=(j|0)<0|0?-1:0;if((BT(c[l>>2]|0,2)|0)!=0){g=-12;i=d;return g|0}j=c[(c[l>>2]|0)+96>>2]|0;x=h&65535;a[j]=x;x=x>>8;a[j+1|0]=x;if((h|0)!=256){g=0;i=d;return g|0}c[k+80>>2]=2;c[k+84>>2]=1;g=0;i=d;return g|0}function mB(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[a+16>>2]|0;g=f+52|0;if((c[g>>2]|0)!=0){h=-541478725;i=e;return h|0}if((TS(f,b,12)|0)!=12){h=-5;i=e;return h|0}j=b+24|0;k=b+28|0;l=1;while(1){if((c[g>>2]|0)!=0){h=0;m=15;break}if((l|0)==0){n=VS(f,b,12)|0;if((n|0)<0){m=7;break}}o=c[j>>2]|0;p=c[k>>2]|0;q=o+(p-8)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;if(r>>>0>2147483643>>>0){m=9;break}q=o+(p-12)|0;if((d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)==1380339525){m=11;break}s=VS(f,b,r)|0;if((s|0)<0){m=14;break}else{l=0}}if((m|0)==7){BZ(b);h=n;i=e;return h|0}else if((m|0)==9){yDb(a,16,2149624,(t=i,i=i+8|0,c[t>>2]=r,t)|0);i=t;h=-5;i=e;return h|0}else if((m|0)==11){if((r|0)==0){h=0;i=e;return h|0}yDb(a,24,2082272,(t=i,i=i+8|0,c[t>>2]=r,t)|0);i=t;Vy(f,r,0)|0;h=0;i=e;return h|0}else if((m|0)==14){BZ(b);h=s;i=e;return h|0}else if((m|0)==15){i=e;return h|0}return 0}function nB(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=c[a+4>>2]|0;e=b;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)!=1145258562){f=0;return f|0}e=b+5|0;g=fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;if(g>>>0<13>>>0){f=0;return f|0}e=YGb(g,0,13,0)|0;h=F;i=c[a+8>>2]|0;a=(i|0)<0|0?-1:0;if((h|0)>(a|0)|(h|0)==(a|0)&e>>>0>i>>>0){f=25;return f|0}i=b+g|0;f=(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)==1145258562?100:0;return f|0}function oB(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<44){b=0;return b|0}e=c[a+4>>2]|0;if((PGb(e,1349904,5)|0)!=0){b=0;return b|0}a=e+26|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){b=0;return b|0}a=e+24|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){b=0;return b|0}a=e+40|0;e=((fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)-1235|0)>>>0>18>>>0;b=e?0:100;return b|0}function pB(b){b=b|0;var e=0;e=c[b+4>>2]|0;b=e;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)!=1437204480){return 0}b=e+12|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)!=22050){return 0}if((a[e+16|0]|0)==16){return((a[e+17|0]|0)==0?100:0)|0}else{return 0}return 0}function qB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;if((rz(d)|0)!=1437204480){e=-1094995529;return e|0}c[b+8>>2]=rz(d)|0;f=b+12|0;c[f>>2]=pz(d)|0;g=b+16|0;c[g>>2]=pz(d)|0;h=b+20|0;c[h>>2]=rz(d)|0;i=b+24|0;c[i>>2]=lz(d)|0;j=b+28|0;c[j>>2]=lz(d)|0;c[b+32>>2]=pz(d)|0;if((c[h>>2]|0)!=22050){e=-1094995529;return e|0}if((c[i>>2]|0)!=16){e=-1094995529;return e|0}i=(c[j>>2]|0)==0;if(!i){e=i?0:-1094995529;return e|0}c[b+76>>2]=0;TGb(b+40|0,0,16)|0;i=LT(a,0)|0;if((i|0)==0){e=-12;return e|0}MT(i,32,1,12);c[b+4>>2]=c[i>>2];j=c[i+8>>2]|0;c[j+8>>2]=0;c[j+48>>2]=95;c[j+52>>2]=0;c[j+120>>2]=c[f>>2];c[j+124>>2]=c[g>>2];g=LT(a,0)|0;if((g|0)==0){e=-12;return e|0}MT(g,32,1,22050);c[b>>2]=c[g>>2];b=c[g+8>>2]|0;c[b+8>>2]=1;c[b+48>>2]=86042;c[b+52>>2]=0;c[b+416>>2]=1;g=b+448|0;c[g>>2]=4;c[g+4>>2]=0;c[b+412>>2]=22050;c[b+792>>2]=8;c[b+72>>2]=176400;e=0;return e|0}function rB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;b=e+76|0;g=c[b>>2]|0;if((g|0)!=0){h=TS(f,d,g)|0;if((h|0)<0){i=h;return i|0}c[d+32>>2]=c[e>>2];h=e+40|0;g=c[h>>2]|0;j=c[h+4>>2]|0;k=d+8|0;c[k>>2]=g;c[k+4>>2]=j;k=(c[b>>2]|0)-((g|0)==0&(j|0)==0&1)|0;c[d+48>>2]=k;j=YGb(k,(k|0)<0|0?-1:0,c[h>>2]|0,c[h+4>>2]|0)|0;c[h>>2]=j;c[h+4>>2]=F;c[b>>2]=0;i=0;return i|0}h=e+60|0;c[h>>2]=lz(f)|0;c[e+56>>2]=lz(f)|0;j=e+64|0;c[j>>2]=pz(f)|0;k=e+72|0;c[k>>2]=rz(f)|0;g=e+68|0;c[g>>2]=rz(f)|0;if((Xy(f)|0)!=0){i=-5;return i|0}if((c[f+76>>2]|0)!=0){i=-5;return i|0}if(!((rz(f)|0)==-1437226411)){i=-1094995529;return i|0}l=c[k>>2]|0;if((l|0)<0){i=-1094995529;return i|0}k=c[g>>2]>>31&-1094995529;if((k|0)!=0){i=k;return i|0}k=c[j>>2]|0;m=k<<16;if((m|0)<0){n=-(m>>16)|0;c[j>>2]=n;o=1;p=n}else{o=0;p=k}k=SS(f,(ba(o+3|0,p)|0)+l|0)|0;l=wZ(d,k+4|0)|0;if((l|0)<0){i=l;return i|0}c[d+32>>2]=c[e+4>>2];l=e+48|0;e=c[l>>2]|0;p=c[l+4>>2]|0;n=YGb(e,p,1,0)|0;c[l>>2]=n;c[l+4>>2]=F;l=d+8|0;c[l>>2]=e;c[l+4>>2]=p;p=d+24|0;a[c[p>>2]|0]=o;a[(c[p>>2]|0)+1|0]=c[j>>2];a[(c[p>>2]|0)+2|0]=(c[j>>2]|0)>>>8;a[(c[p>>2]|0)+3|0]=c[h>>2];h=mz(f,(c[p>>2]|0)+4|0,k)|0;if((h|0)<0){BZ(d);i=h;return i|0}if((h|0)<(k|0)){yZ(d,h+4|0)}c[b>>2]=c[g>>2];i=0;return i|0}function sB(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;b=i;i=i+16|0;e=b|0;TGb(e|0,0,12)|0;f=c[a+8>>2]|0;g=f-2|0;a:do{if((g|0)>0){h=c[a+4>>2]|0;j=e|0;k=e+4|0;l=e+8|0;m=h;n=-65536;o=0;p=0;q=0;r=0;s=0;while(1){t=m+2|0;u=m;v=(de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535;w=v|n;do{if((w|0)==(-14745368|0)){x=t;if(!(((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&-3841)<<16>>16==-4089)){y=q;z=r;A=s;break}x=s+1|0;c[l>>2]=x;y=q;z=r;A=x}else if((w|0)==(-25230976|0)|(w|0)==2147385345){x=q+1|0;c[j>>2]=x;y=x;z=r;A=s}else if((w|0)==536864768){x=t;if(!(((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&-16)<<16>>16==2032)){y=q;z=r;A=s;break}x=r+1|0;c[k>>2]=x;y=q;z=x;A=s}else{y=q;z=r;A=s}}while(0);if((m-h|0)>3){w=m-4|0;x=((d[u]|d[u+1|0]<<8)<<16>>16&65535)-((d[w]|d[w+1|0]<<8)<<16>>16&65535)|0;w=(x|0)>-1?x:-x|0;x=YGb(w,(w|0)<0|0?-1:0,p,o)|0;B=F;C=x}else{B=o;C=p}if(!(t>>>0<(h+g|0)>>>0)){D=B;E=C;G=y;H=z;I=A;break a}m=t;n=v<<16;o=B;p=C;q=y;r=z;s=A}}else{D=0;E=0;G=0;H=0;I=0}}while(0);A=H+G+I|0;z=(H|0)>(G|0)|0;G=c[e+(((I|0)>(c[e+(z<<2)>>2]|0)?2:z)<<2)>>2]|0;do{if((G|0)>3){if(((f|0)/(G|0)|0|0)>=32768){break}if((G<<2|0)<=(A*3|0|0)){break}z=eHb(E,D,f,(f|0)<0|0?-1:0)|0;e=F;I=0;if((e|0)>(I|0)|(e|0)==(I|0)&z>>>0>200>>>0){J=51}else{break}i=b;return J|0}}while(0);J=0;i=b;return J|0}function tB(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b|0;e=b+4|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0;a=(fe(b|0)|0)==1145586770&(e|0)==1146377032;return(a?100:0)|0}function uB(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=LT(b,0)|0;if((g|0)==0){h=-12;i=d;return h|0}j=c[g+8>>2]|0;c[j+8>>2]=1;c[j+48>>2]=86020;c[g+236>>2]=1463898624;if((Xy(f)|0)!=0){h=-541478725;i=d;return h|0}g=b+1140|0;a:while(1){j=Az(f)|0;k=F;l=Az(f)|0;m=F;n=0;if(m>>>0<n>>>0|m>>>0==n>>>0&l>>>0<4>>>0){o=5;break}n=536870912;if(m>>>0>n>>>0|m>>>0==n>>>0&l>>>0>0>>>0){o=7;break}n=1229866575;p=1179208773;do{if((j|0)==1145132097&(k|0)==1398035021){o=9;break a}else if((j|0)==(n|0)&(k|0)==(p|0)){q=0;if(m>>>0>q>>>0|m>>>0==q>>>0&l>>>0>2147483647>>>0){o=13;break}q=l;r=WDb(q)|0;if((r|0)==0){o=13;break}mz(f,r,q)|0;q=YGb(l,m,-1,0)|0;a[r+q|0]=0;CBb(g,2031600,r,8)|0}else{o=13}}while(0);if((o|0)==13){o=0;p=Vy(f,l,m)|0;k=p;if((k|0)<0){h=k;o=15;break}}if((Xy(f)|0)!=0){h=-541478725;o=15;break}}if((o|0)==5){yDb(b,16,2149528,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;h=-1094995529;i=d;return h|0}else if((o|0)==7){yDb(b,16,2082240,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;h=-1094995529;i=d;return h|0}else if((o|0)==9){s=Ty(f,0,0,1)|0;f=YGb(s,F,l,m)|0;s=F;b=e;c[b>>2]=f;c[b+4>>2]=s;h=s>>>0>m>>>0|s>>>0==m>>>0&f>>>0>l>>>0?0:-1094995529;i=d;return h|0}else if((o|0)==15){i=d;return h|0}return 0}function vB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=a+16|0;a=Ty(c[d>>2]|0,0,0,1)|0;g=ZGb(e,f,a,F)|0;a=F;f=0;e=(a|0)>(f|0)|(a|0)==(f|0)&g>>>0>1024>>>0;f=e?1024:g;g=e?0:a;a=0;if((g|0)<(a|0)|(g|0)==(a|0)&f>>>0<1>>>0){h=-541478725;return h|0}a=TS(c[d>>2]|0,b,f)|0;if((a|0)<0){h=a;return h|0}c[b+32>>2]=0;h=a;return h|0}function wB(a){a=a|0;var b=0,d=0,e=0;b=cEb(33136)|0;if((b|0)==0){d=0;return d|0}e=LT(a,0)|0;c[b+8>>2]=e;if((e|0)==0){ZDb(b);d=0;return d|0}else{c[b+4>>2]=a;a=c[e+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=25;c[a+72>>2]=25e6;a=e+48|0;c[a>>2]=0;c[a+4>>2]=0;d=b;return d|0}return 0}function xB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+33120>>2]|0;if((d|0)>0){e=0}else{f=-1;return f|0}while(1){if((c[a+12+(e<<2)>>2]|0)!=0){g=a+32+(e*80|0)+28|0;if((c[g>>2]|0)!=0){break}}h=e+1|0;if((h|0)<(d|0)){e=h}else{f=-1;i=6;break}}if((i|0)==6){return f|0}UGb(b|0,a+32+(e*80|0)|0,80)|0;c[g>>2]=0;f=c[b+28>>2]|0;return f|0}function yB(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;k=i;i=i+48|0;l=k|0;m=k+8|0;n=k+24|0;TGb(n|0,0,20)|0;if((g|0)<480){o=-1;i=k;return o|0}p=b|0;q=D7(c[p>>2]|0,f,g)|0;c[p>>2]=q;if((q|0)==0){o=-1;i=k;return o|0}if((c[q+8>>2]|0)>(g|0)){o=-1;i=k;return o|0}g=f+4323|0;r=(a[g]|0)==80?g:0;a:do{if((r|0)==0){c[b+33120>>2]=0;s=0;t=63}else{u=a[r+1|0]&63;v=d[r+4|0]|0;w=v>>>3&7;x=a[r+3|0]&31;y=v&7;if(w>>>0>2>>>0){yDb(c[b+4>>2]|0,16,2298352,(z=i,i=i+8|0,c[z>>2]=w,z)|0);i=z;A=0;B=c[b+33120>>2]|0}else{if(x>>>0>3>>>0){yDb(c[b+4>>2]|0,16,2281112,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z;c[b+33120>>2]=0;s=0;t=63;break}c[m>>2]=1;c[m+4>>2]=0;c[m+8>>2]=2;c[m+12>>2]=4;v=c[m+(x<<2)>>2]|0;x=(y|0)!=0&(v|0)==1&(w|0)==2?2:v;v=b+4|0;if((x|0)>0){y=1347600+(w<<2)|0;C=0;while(1){D=b+12+(C<<2)|0;E=c[D>>2]|0;if((E|0)==0){G=LT(c[v>>2]|0,0)|0;c[D>>2]=G;if((G|0)==0){H=C;break}MT(G,64,1,3e4);G=c[(c[D>>2]|0)+8>>2]|0;c[G+8>>2]=1;c[G+48>>2]=65536;vZ(b+32+(C*80|0)|0);c[b+32+(C*80|0)+28>>2]=0;c[b+32+(C*80|0)+24>>2]=b+352+(C<<13);c[b+32+(C*80|0)+32>>2]=c[c[D>>2]>>2];G=b+32+(C*80|0)+36|0;c[G>>2]=c[G>>2]|1;I=c[D>>2]|0}else{I=E}E=c[y>>2]|0;D=c[I+8>>2]|0;c[D+412>>2]=E;c[D+416>>2]=2;G=D+448|0;c[G>>2]=3;c[G+4>>2]=0;c[D+72>>2]=E<<5;E=I+48|0;c[E>>2]=0;c[E+4>>2]=0;E=C+1|0;if((E|0)<(x|0)){C=E}else{H=E;break}}J=H;K=c[p>>2]|0}else{J=0;K=q}c[b+33120>>2]=J;A=(c[K+80+(w<<2)>>2]|0)+u<<2;B=J}C=b+33120|0;if((B|0)>0){x=b+33128|0;y=0;while(1){v=b+32+(y*80|0)+64|0;c[v>>2]=h;c[v+4>>2]=j;c[b+32+(y*80|0)+28>>2]=A;v=gHb(c[x>>2]|0,c[x+4>>2]|0,24e4,0)|0;E=c[(c[(c[b+12+(y<<2)>>2]|0)+8>>2]|0)+72>>2]|0;D=hHb(v,F,E,(E|0)<0|0?-1:0)|0;E=b+32+(y*80|0)+8|0;c[E>>2]=D;c[E+4>>2]=F;c[n+(y<<2)>>2]=b+352+(y<<13);E=y+1|0;D=c[C>>2]|0;if((E|0)<(D|0)){y=E}else{L=D;break}}}else{L=B}if((L|0)==0){s=A;t=63;break}y=c[p>>2]|0;C=(a[g]|0)==80?g:0;if((C|0)==0){M=A;N=y;break}x=d[C+4|0]|0;u=x>>>3&7;w=x&7;if(w>>>0>1>>>0|u>>>0>2>>>0){s=A;t=63;break}x=(a[C+1|0]&63)+(c[y+80+(u<<2)>>2]|0)<<2;u=y+12|0;C=c[u>>2]|0;D=(C|0)/2|0;if((c[y+32>>2]|0)==720){O=(a[f+1|0]&12)!=0?0:2}else{O=0}E=y+16|0;v=c[E>>2]|0;G=(w|0)==1;if(((O&255)+v|0)>((G?2:4)|0)){yDb(0,16,1905696,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;s=A;t=63;break}if((v|0)<=0){s=A;t=63;break}P=(w|0)==0;w=y+112|0;Q=y+76|0;y=0;R=f;S=O;T=C;C=v;b:while(1){if(!((S&255)>>>0<4>>>0)){t=31;break}v=c[n+((S&255)<<2)>>2]|0;if((v|0)==0){s=A;t=63;break a}U=S+1&255;if((T|0)>0){V=0;W=R;X=v;v=U;Y=T;while(1){Z=W+480|0;if(G&(V|0)==(D|0)){if(!((v&255)>>>0<4>>>0)){t=36;break b}_=v+1&255;$=c[n+((v&255)<<2)>>2]|0;if(($|0)==0){aa=_;ca=Z;da=Y;break}else{ea=_;fa=$}}else{ea=v;fa=X}$=0;_=Z;while(1){if(P){Z=8;do{ga=(ba(c[Q>>2]|0,(Z-8|0)/2|0)|0)+(d[(c[w>>2]|0)+(V*9|0)+$|0]|0)<<1;do{if((ga|0)<(x|0)){ha=a[_+(Z|1)|0]|0;a[fa+ga|0]=ha;ia=a[_+Z|0]|0;ja=fa+(ga|1)|0;a[ja]=ia;if(!(ia<<24>>24==-128&ha<<24>>24==0)){break}a[ja]=0}}while(0);Z=Z+2|0;}while((Z|0)<80)}else{Z=(V|0)%(D|0)|0;ga=Z+D|0;ja=8;do{ha=d[_+(ja+2)|0]|0;ia=ha>>>4|d[_+ja|0]<<4;ka=ja+1|0;la=d[_+ka|0]<<4|ha&15;ha=la&65535;do{if((ia|0)==2048){ma=0;na=0}else{oa=ia&65535;pa=(oa&65535)>>>0<2048>>>0?oa:oa|-4096;oa=pa&65535;qa=(pa&65535)>>>8;ra=qa&15;if((ra-2&65535)>>>0>11>>>0){ma=qa&255;na=pa&255;break}if((ra&65535)>>>0<8>>>0){pa=ra-1&65535;qa=oa-(pa<<8)<<pa;ma=(qa&65535)>>>8&255;na=qa&255;break}else{qa=14-ra&65535;ra=((qa<<8|1)+oa<<qa)+65535|0;ma=(ra&65535)>>>8&255;na=ra&255;break}}}while(0);do{if((la|0)==2048){sa=0;ta=0}else{ia=(ha&65535)>>>0<2048>>>0?ha:ha|-4096;ra=ia&65535;qa=(ia&65535)>>>8;oa=qa&15;if((oa-2&65535)>>>0>11>>>0){sa=qa&255;ta=ia&255;break}if((oa&65535)>>>0<8>>>0){ia=oa-1&65535;qa=ra-(ia<<8)<<ia;sa=(qa&65535)>>>8&255;ta=qa&255;break}else{qa=14-oa&65535;oa=((qa<<8|1)+ra<<qa)+65535|0;sa=(oa&65535)>>>8&255;ta=oa&255;break}}}while(0);ha=(ja-8|0)/3|0;la=(ba(c[Q>>2]|0,ha)|0)+(d[(c[w>>2]|0)+(Z*9|0)+$|0]|0)<<1;if((la|0)<(x|0)){a[fa+la|0]=na;a[fa+(la|1)|0]=ma;la=(ba(c[Q>>2]|0,ha)|0)+(d[(c[w>>2]|0)+(ga*9|0)+$|0]|0)<<1;a[fa+la|0]=ta;a[fa+(la|1)|0]=sa;ua=ka}else{ua=ja}ja=ua+2|0;}while((ja|0)<80)}ja=$+1|0;if((ja|0)<9){$=ja;_=_+1280|0}else{break}}_=W+12e3|0;$=V+1|0;ja=c[u>>2]|0;if(($|0)<(ja|0)){V=$;W=_;X=fa;v=ea;Y=ja}else{aa=ea;ca=_;da=ja;break}}va=aa;wa=ca;xa=da;ya=c[E>>2]|0}else{va=U;wa=R;xa=T;ya=C}Y=y+1|0;if((Y|0)<(ya|0)){y=Y;R=wa;S=va;T=xa;C=ya}else{s=A;t=63;break a}}if((t|0)==31){yDb(0,0,1884952,(z=i,i=i+24|0,c[z>>2]=2343048,c[z+8>>2]=2320632,c[z+16>>2]=152,z)|0);i=z;Cd();return 0}else if((t|0)==36){yDb(0,0,1884952,(z=i,i=i+24|0,c[z>>2]=2343048,c[z+8>>2]=2320632,c[z+16>>2]=162,z)|0);i=z;Cd();return 0}}}while(0);if((t|0)==63){M=s;N=c[p>>2]|0}do{if((c[N+32>>2]|0)==720){if((a[f+1|0]&12)==0){c[b+140>>2]=0;c[b+60>>2]=0;s=b+33128|0;t=YGb(c[s>>2]|0,c[s+4>>2]|0,M,(M|0)<0|0?-1:0)|0;c[s>>2]=t;c[s+4>>2]=F;break}else{c[b+300>>2]=0;c[b+220>>2]=0;break}}else{s=b+33128|0;t=YGb(c[s>>2]|0,c[s+4>>2]|0,M,(M|0)<0|0?-1:0)|0;c[s>>2]=t;c[s+4>>2]=F}}while(0);M=b+8|0;if((N|0)==0){za=0}else{s=c[M>>2]|0;t=c[s+8>>2]|0;MT(s,64,c[N+20>>2]|0,c[N+24>>2]|0);N=(c[p>>2]|0)+20|0;s=t+104|0;z=c[N+4>>2]|0;c[s>>2]=c[N>>2];c[s+4>>2]=z;z=f+453|0;s=(a[z]|0)==97?z:0;z=a[f+4|0]|0;do{if((s|0)==0){Aa=0}else{N=a[s+2|0]&7;if((N|0)==2){Aa=1;break}if(!((z&7)==0)){Aa=0;break}Aa=(N|0)==7|0}}while(0);z=(c[p>>2]|0)+40+(Aa<<3)|0;Aa=(c[M>>2]|0)+80|0;s=c[z+4>>2]|0;c[Aa>>2]=c[z>>2];c[Aa+4>>2]=s;s=c[p>>2]|0;Aa=c[s+8>>2]|0;c[l>>2]=8;c[l+4>>2]=1;z=KDb(Aa,(Aa|0)<0|0?-1:0,l,s+20|0)|0;c[t+72>>2]=z;za=c[(c[p>>2]|0)+8>>2]|0}vZ(e);c[e+24>>2]=f;f=e+64|0;c[f>>2]=h;c[f+4>>2]=j;c[e+28>>2]=za;j=e+36|0;c[j>>2]=c[j>>2]|1;c[e+32>>2]=c[c[M>>2]>>2];M=b+33124|0;b=c[M>>2]|0;j=e+8|0;c[j>>2]=b;c[j+4>>2]=(b|0)<0|0?-1:0;c[M>>2]=b+1;o=za;i=k;return o|0}function zB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=b;c[a+33124>>2]=f;do{if((c[a+33120>>2]|0)!=0){b=c[a>>2]|0;if((b|0)==0){yDb(c[a+4>>2]|0,16,1995960,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;break}else{c[e>>2]=8;c[e+4>>2]=c[(c[(c[a+12>>2]|0)+8>>2]|0)+72>>2];g=KDb(f,(f|0)<0|0?-1:0,b+20|0,e)|0;b=a+33128|0;c[b>>2]=g;c[b+4>>2]=F;break}}}while(0);c[a+140>>2]=0;c[a+60>>2]=0;c[a+300>>2]=0;c[a+220>>2]=0;i=d;return}function AB(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[a+8>>2]|0;if((b|0)<5){e=0;return e|0}f=b-4|0;if((f|0)<=0){e=0;return e|0}g=c[a+4>>2]|0;a=0;h=0;i=0;j=0;k=0;while(1){l=g+h|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=fe(m|0)|0;do{if((l&522304|0)==458752){do{if((l&-16253057|0)==520552511){n=k+1|0;if((l&-129|0)!=520552511){o=n;p=j;q=i;break}o=n;p=(h|0)==0?1:j;q=i+1|0}else{o=k;p=j;q=i}}while(0);if((l|0)==(-12646656|0)|(l|0)==4130560){r=h}else{r=a}if((m|0)!=17252351){s=o;t=p;u=q;v=r;break}s=o;t=p;u=((h-r|0)==80)+q|0;v=r}else{s=k;t=j;u=i;v=a}}while(0);m=h+1|0;if((m|0)<(f|0)){a=v;h=m;i=u;j=t;k=s}else{break}}if((u|0)==0){e=0;return e|0}if(((b|0)/(u|0)|0|0)>=1048576){e=0;return e|0}if(!((u|0)<5&(t|0)==0)){e=75;return e|0}do{if((s|0)>9){if(((b|0)/(s|0)|0|0)<24e3){e=75}else{break}return e|0}}while(0);e=25;return e|0}function BB(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;e=i;i=i+24|0;f=e|0;g=e+16|0;h=b+12|0;j=c[h>>2]|0;k=cEb(33136)|0;l=k;do{if((k|0)!=0){m=LT(b,0)|0;c[k+8>>2]=m;if((m|0)==0){ZDb(k);break}c[k+4>>2]=b;n=c[m+8>>2]|0;c[n+8>>2]=0;c[n+48>>2]=25;c[n+72>>2]=25e6;n=m+48|0;c[n>>2]=0;c[n+4>>2]=0;n=j;c[n>>2]=l;m=b+16|0;o=vz(c[m>>2]|0)|0;a:do{if((o&-129|0)==520552511){p=o}else{q=o;r=0;while(1){if((Xy(c[m>>2]|0)|0)!=0){break}if((q|0)==(-12646656|0)|(q|0)==4130560){s=Ty(c[m>>2]|0,0,0,1)|0;t=s}else{t=r}if((q|0)==-12646655){s=Ty(c[m>>2]|0,0,0,1)|0;u=ZGb(s,F,t,0)|0;if((u|0)==80&(F|0)==0){v=12;break}}u=lz(c[m>>2]|0)|0|q<<8;if((u&-129|0)==520552511){p=u;break a}else{q=u;r=t}}if((v|0)==12){Ty(c[m>>2]|0,-163,-1,1)|0;p=vz(c[m>>2]|0)|0;break}yDb(b,16,2031576,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=-1;i=e;return y|0}}while(0);o=j+4|0;r=o;x=fe(p|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;if((mz(c[m>>2]|0,j+8|0,476)|0)!=476){y=-5;i=e;return y|0}r=Ty(c[m>>2]|0,-480,-1,1)|0;q=F;u=0;if((q|0)<(u|0)|(q|0)==(u|0)&r>>>0<0>>>0){y=-5;i=e;return y|0}r=D7(c[c[n>>2]>>2]|0,o,480)|0;c[c[n>>2]>>2]=r;r=c[c[n>>2]>>2]|0;if((r|0)==0){yDb(b,16,1987328,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=-1;i=e;return y|0}o=c[r+8>>2]|0;c[g>>2]=8;c[g+4>>2]=1;u=KDb(o,(o|0)<0|0?-1:0,g,r+20|0)|0;c[b+1072>>2]=u;u=c[m>>2]|0;if((c[u+88>>2]|0)==0){y=0;i=e;return y|0}r=f|0;o=Ty(u,0,0,1)|0;u=F;q=cEb(240)|0;s=c[h>>2]|0;do{if((mz(c[m>>2]|0,q,240)|0)>=240){z=c[(c[c[s>>2]>>2]|0)+28>>2]|0;if((z|0)==25){A=1}else{A=(z|0)==50|0}z=q+86|0;B=(a[z]|0)==19?z:0;if((B|0)==0){yDb(b,16,1927688,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}else{z=B+1|0;$Fb(r,fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0,A)|0;CBb(b+1140|0,1954576,r,0)|0;break}}}while(0);ZDb(q);Ty(c[m>>2]|0,o,u,0)|0;y=0;i=e;return y|0}}while(0);c[j>>2]=0;y=-1;i=e;return y|0}function CB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+12>>2]|0;e=d;f=c[e>>2]|0;g=c[f+33120>>2]|0;a:do{if((g|0)>0){h=0;while(1){if((c[f+12+(h<<2)>>2]|0)!=0){i=f+32+(h*80|0)+28|0;if((c[i>>2]|0)!=0){break}}j=h+1|0;if((j|0)<(g|0)){h=j}else{break a}}UGb(b|0,f+32+(h*80|0)|0,80)|0;c[i>>2]=0;j=c[b+28>>2]|0;if((j|0)<0){break}else{k=j}return k|0}}while(0);i=a+16|0;a=Ty(c[i>>2]|0,0,0,1)|0;f=F;g=c[c[e>>2]>>2]|0;if((g|0)==0){k=-5;return k|0}j=c[g+8>>2]|0;g=d+4|0;if((mz(c[i>>2]|0,g,j)|0)<1){k=-5;return k|0}k=yB(c[e>>2]|0,b,g,j,a,f)|0;return k|0}function DB(a){a=a|0;ZDb(c[c[a+12>>2]>>2]|0);return 0}function EB(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+8|0;b=f|0;g=c[c[a+12>>2]>>2]|0;h=E7(c[(c[g+8>>2]|0)+8>>2]|0)|0;j=a+16|0;k=Wy(c[j>>2]|0)|0;l=a+1248|0;a=c[l>>2]|0;m=c[l+4>>2]|0;l=ZGb(k,F,a,m)|0;k=F;n=YGb(l,k,-1,-1)|0;o=F;p=c[h+8>>2]|0;h=p;q=(p|0)<0|0?-1:0;p=fHb(n,o,h,q)|0;r=ZGb(n,o,p,F)|0;p=F;o=gHb(h,q,d,e)|0;e=F;d=-1;if(((k|0)>(d|0)|(k|0)==(d|0)&l>>>0>-1>>>0)&((e|0)>(p|0)|(e|0)==(p|0)&o>>>0>r>>>0)){s=p;t=r}else{r=0;p=(e|0)<(r|0)|(e|0)==(r|0)&o>>>0<0>>>0;s=p?0:e;t=p?0:o}o=YGb(t,s,a,m)|0;m=F;a=Ty(c[j>>2]|0,o,m,0)|0;j=F;s=0;if((j|0)<(s|0)|(j|0)==(s|0)&a>>>0<0>>>0){u=-1;i=f;return u|0}a=c[g>>2]|0;s=c[a+8>>2]|0;j=eHb(o,m,s,(s|0)<0|0?-1:0)|0;s=j;c[g+33124>>2]=s;do{if((c[g+33120>>2]|0)!=0){if((a|0)==0){yDb(c[g+4>>2]|0,16,1995960,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;break}else{c[b>>2]=8;c[b+4>>2]=c[(c[(c[g+12>>2]|0)+8>>2]|0)+72>>2];j=KDb(s,(s|0)<0|0?-1:0,a+20|0,b)|0;m=g+33128|0;c[m>>2]=j;c[m+4>>2]=F;break}}}while(0);c[g+140>>2]=0;c[g+60>>2]=0;c[g+300>>2]=0;c[g+220>>2]=0;u=0;i=f;return u|0}function FB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+8|0;d=b|0;e=a+12|0;f=c[e>>2]|0;g=a+1140|0;h=BBb(c[g>>2]|0,2031464,0,0)|0;j=c[e>>2]|0;e=a+24|0;a:do{if(!((c[e>>2]|0)>>>0>3>>>0)){k=j+8|0;c[k>>2]=0;l=j+12|0;m=l;c[j+16>>2]=0;c[l>>2]=0;l=c[e>>2]|0;if((l|0)==0){break}n=a+28|0;o=0;p=0;q=l;while(1){l=c[(c[n>>2]|0)+(p<<2)>>2]|0;r=c[(c[l+8>>2]|0)+8>>2]|0;if((r|0)==1){s=c[k>>2]|0;if((s|0)>1){break a}c[k>>2]=s+1;c[m+(s<<2)>>2]=l;t=o;u=c[e>>2]|0}else if((r|0)==0){if((o|0)==0){t=l;u=q}else{break a}}else{break a}l=p+1|0;if(l>>>0<u>>>0){o=t;p=l;q=u}else{break}}if((t|0)==0){break}q=c[t+8>>2]|0;if((c[q+48>>2]|0)!=25){break}p=c[k>>2]|0;if((p|0)>0){o=0;do{l=c[m+(o<<2)>>2]|0;if((l|0)!=0){r=c[l+8>>2]|0;if((c[r+48>>2]|0)!=65536){break a}if((c[r+412>>2]|0)!=48e3){break a}if((c[r+416>>2]|0)!=2){break a}}o=o+1|0;}while((o|0)<(p|0))}p=E7(q)|0;c[j+4>>2]=p;if((p|0)==0){break}if((c[k>>2]|0)>1){if((c[p+16>>2]|0)<2){break}}c[j+28>>2]=0;c[j+40>>2]=0;c[j+44>>2]=0;p=BBb(c[g>>2]|0,1954544,0,0)|0;if((p|0)!=0){o=bU(c[p+4>>2]|0)|0;p=j+32|0;c[p>>2]=o;c[p+4>>2]=F}p=c[k>>2]|0;b:do{if((p|0)>0){o=j+20|0;r=0;l=p;while(1){if((c[m+(r<<2)>>2]|0)==0){v=l}else{s=UBb(192e5)|0;c[o+(r<<2)>>2]=s;if((s|0)==0){break}v=c[k>>2]|0}s=r+1|0;if((s|0)<(v|0)){r=s;l=v}else{break b}}if((r|0)>0){w=r}else{break a}while(1){w=w-1|0;VBb(c[o+(w<<2)>>2]|0);if((w|0)<=0){break a}}}}while(0);if((j|0)==0){break}c[d>>2]=c[(c[f+4>>2]|0)+28>>2];c[d+4>>2]=1;c:do{if((h|0)==0){k=0;while(1){if(!(k>>>0<(c[e>>2]|0)>>>0)){break}m=BBb(c[(c[(c[n>>2]|0)+(k<<2)>>2]|0)+88>>2]|0,2031464,0,0)|0;if((m|0)==0){k=k+1|0}else{x=m;y=35;break c}}z=f+576048|0;A=a}else{x=h;y=35}}while(0);do{if((y|0)==35){n=f+576048|0;k=a;if((dGb(n,d,c[x+4>>2]|0,k)|0)>-1){B=0}else{z=n;A=k;break}i=b;return B|0}}while(0);B=cGb(z,d,0,0,A)|0;i=b;return B|0}}while(0);yDb(a,16,1987136,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;B=-1;i=b;return B|0}



function GB(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=i;g=c[b+12>>2]|0;h=g;j=c[(c[b+28>>2]|0)+(c[e+32>>2]<<2)>>2]|0;k=c[e+24>>2]|0;l=c[e+28>>2]|0;e=g+48|0;m=g+4|0;n=c[m>>2]|0;o=g+28|0;p=c[o>>2]|0;q=c[n+92+(((p>>>0)%5|0)<<2)>>2]<<2;r=j+8|0;s=c[r>>2]|0;t=c[s+8>>2]|0;if((t|0)==1){u=c[g+8>>2]|0;v=0;while(1){if((v|0)>=(u|0)){break}if((c[h+12+(v<<2)>>2]|0)==(j|0)){break}else{v=v+1|0}}j=h+20+(v<<2)|0;if(((WBb(c[j>>2]|0)|0)+l|0)>19199999){yDb(c[r>>2]|0,16,2081984,(w=i,i=i+8|0,c[w>>2]=c[o>>2],w)|0);i=w}_Bb(c[j>>2]|0,k,l,0)|0;l=((q|0)<=(WBb(c[j>>2]|0)|0))<<v;v=g+40|0;c[v>>2]=l|c[v>>2]}else if((t|0)==0){t=g+44|0;if((c[t>>2]|0)==0){x=n}else{yDb(s,16,2149320,(w=i,i=i+8|0,c[w>>2]=p,w)|0);i=w;x=c[m>>2]|0}UGb(e|0,k|0,c[x+8>>2]|0)|0;c[t>>2]=1}t=g+44|0;if((c[t>>2]|0)!=1){i=f;return 0}x=g+40|0;k=g+8|0;p=c[k>>2]|0;if(((c[x>>2]|0)+1|0)!=(1<<p|0)){i=f;return 0}s=c[m>>2]|0;if((c[s+8>>2]|0)>0){n=e;v=e;do{l=v-n|0;IB(19,h,v+86|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;j=v+94|0;IB(19,h,j,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;r=v+102|0;IB(19,h,r,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(19,h,v+110|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=v+118|0;IB(19,h,u,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=v+126|0;IB(19,h,y,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;z=c[m>>2]|0;A=c[z+12>>2]|0;if((((l|0)/((c[z+8>>2]|0)/(ba(c[z+16>>2]|0,A)|0)|0|0)|0|0)%(A|0)|0|0)>5){IB(98,h,j,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,r,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(98,h,u,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,y,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}IB(19,h,v+166|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=v+174|0;IB(19,h,y,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=v+182|0;IB(19,h,u,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(19,h,v+190|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;r=v+198|0;IB(19,h,r,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;j=v+206|0;IB(19,h,j,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;A=c[m>>2]|0;z=c[A+12>>2]|0;if((((l|0)/((c[A+8>>2]|0)/(ba(c[A+16>>2]|0,z)|0)|0|0)|0|0)%(z|0)|0|0)>5){IB(98,h,y,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,u,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(98,h,r,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,j,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}IB(98,h,v+253|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,v+258|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(98,h,v+298|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,v+303|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(98,h,v+333|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,v+338|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(98,h,v+378|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,v+383|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(98,h,v+413|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,v+418|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(98,h,v+458|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;IB(99,h,v+463|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;v=v+12e3|0;B=c[m>>2]|0;}while(v>>>0<(g+((c[B+8>>2]|0)+48)|0)>>>0);C=c[k>>2]|0;D=B}else{C=p;D=s}c[x>>2]=0;if((C|0)>0){C=0;s=D;while(1){p=c[s+92+((((c[o>>2]|0)>>>0)%5|0)<<2)>>2]<<2;B=c[s+12>>2]|0;if((B|0)>0){v=h+20+(C<<2)|0;n=0;j=g+((ba(C*12e3|0,B)|0)+48)|0;B=s;while(1){r=0;u=j+480|0;y=B;while(1){IB(c[1347616+(n*36|0)+(r<<2)>>2]|0,h,u+3|0,(w=i,i=i+8|0,c[w>>2]=(n|0)>=((c[y+12>>2]|0)/2|0|0),w)|0);i=w;z=8;do{A=c[m>>2]|0;l=(ba(c[A+76>>2]|0,(z-8|0)/2|0)|0)+(d[(c[A+112>>2]|0)+(n*9|0)+r|0]|0)<<1;if((l|0)<(p|0)){A=c[v>>2]|0;E=c[A>>2]|0;F=c[A+12>>2]|0;G=(c[A+4>>2]|0)+(l|1)|0;do{if(G>>>0<F>>>0){if(!(G>>>0<E>>>0)){H=G;break}H=F+(G-E)|0}else{H=E+(G-F)|0}}while(0);a[u+z|0]=a[H]|0;F=c[v>>2]|0;G=c[F>>2]|0;E=c[F+12>>2]|0;A=(c[F+4>>2]|0)+l|0;do{if(A>>>0<E>>>0){if(!(A>>>0<G>>>0)){I=A;break}I=E+(A-G)|0}else{I=G+(A-E)|0}}while(0);a[u+(z|1)|0]=a[I]|0}z=z+2|0;}while((z|0)<80);z=r+1|0;if((z|0)>=9){break}r=z;u=u+1280|0;y=c[m>>2]|0}y=n+1|0;u=c[m>>2]|0;if((y|0)<(c[u+12>>2]|0)){n=y;j=j+12e3|0;B=u}else{J=v;break}}}else{J=h+20+(C<<2)|0}$Bb(c[J>>2]|0,q);v=((q|0)<=(WBb(c[J>>2]|0)|0))<<C;c[x>>2]=v|c[x>>2];v=C+1|0;B=c[m>>2]|0;if((v|0)<(c[k>>2]|0)){C=v;s=B}else{K=B;break}}}else{K=D}c[t>>2]=0;c[o>>2]=(c[o>>2]|0)+1;o=c[K+8>>2]|0;if((o|0)<=0){i=f;return 0}Ry(c[b+16>>2]|0,e,o);i=f;return 0}function HB(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;a=b;d=b+8|0;if((c[d>>2]|0)>0){e=0}else{return 0}do{VBb(c[a+20+(e<<2)>>2]|0);e=e+1|0;}while((e|0)<(c[d>>2]|0));return 0}function IB(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+64|0;h=g|0;j=g+48|0;a[e]=b;switch(b|0){case 19:{b=e+1|0;x=fe(ZFb(d+576048|0,c[d+28>>2]|0)|0|8421568|0)|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;i=g;return};case 83:case 99:{b=d+32|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=c[d+28>>2]|0;m=c[d+4>>2]|0;n=c[m+20>>2]|0;o=c[m+24>>2]|0;eX(YGb(HDb(b,(b|0)<0|0?-1:0,n,(n|0)<0|0?-1:0,o,(o|0)<0|0?-1:0,2)|0,F,k,l)|0,h)|0;a[e+1|0]=-1;l=c[h>>2]|0;a[e+2|0]=(l|0)%10|0|((l|0)/10|0)<<4|128;l=c[h+4>>2]|0;a[e+3|0]=(l|0)%10|0|((l|0)/10|0)<<4|128;l=c[h+8>>2]|0;a[e+4|0]=(l|0)%10|0|((l|0)/10|0)<<4|192;i=g;return};case 81:{a[e+1|0]=28;a[e+2|0]=-49;l=c[d+4>>2]|0;if((c[l+64>>2]|0)==0){p=-96}else{p=(c[l+28>>2]<<2|128)&255}a[e+3|0]=p;a[e+4|0]=-1;i=g;return};case 80:{p=j|0;l=j;c[l>>2]=f;c[l+4>>2]=0;l=d+4|0;f=c[l>>2]|0;a[e+1|0]=(c[f+92+((((c[d+28>>2]|0)>>>0)%5|0)<<2)>>2]|0)-(c[f+80>>2]|0)|192;a[e+2|0]=((w=c[p+4>>2]|0,c[p+4>>2]=w+8,c[(c[p>>2]|0)+w>>2]|0)|0)!=0|0;p=c[l>>2]|0;a[e+3|0]=c[p>>2]<<5|c[p+16>>2]&2|192;a[e+4|0]=-128;i=g;return};case 82:case 98:{p=d+32|0;l=c[p>>2]|0;f=c[p+4>>2]|0;p=c[d+28>>2]|0;j=c[d+4>>2]|0;d=c[j+20>>2]|0;k=c[j+24>>2]|0;eX(YGb(HDb(p,(p|0)<0|0?-1:0,d,(d|0)<0|0?-1:0,k,(k|0)<0|0?-1:0,2)|0,F,l,f)|0,h)|0;a[e+1|0]=-1;f=c[h+12>>2]|0;a[e+2|0]=(f|0)%10|0|((f|0)/10|0)<<4|192;f=c[h+16>>2]|0;a[e+3|0]=((f|0)/10|0)<<4|((f|0)%10|0);f=c[h+20>>2]|0;a[e+4|0]=(((f|0)%100|0|0)/10|0)<<4|((f|0)%10|0);i=g;return};default:{f=e+1|0;x=-1;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;i=g;return}}}function JB(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[b+8>>2]|0)<15){e=0;return e|0}f=c[b+4>>2]|0;b=f+11|0;g=(d[b]|d[b+1|0]<<8)<<16>>16;b=de(g|0)|0;h=f+13|0;i=(d[h]|d[h+1|0]<<8)<<16>>16;h=de(i|0)|0;do{if((a[f]|0)==68){if((a[f+1|0]|0)!=69){break}if((a[f+2|0]|0)!=88){break}if((a[f+3|0]|0)!=65){break}if(!(g<<16>>16!=0&(b&65535)>>>0<2049>>>0)){break}if(i<<16>>16!=0&(h&65535)>>>0<2049>>>0){e=100}else{break}return e|0}}while(0);e=0;return e|0}function KB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+16>>2]|0;g=c[a+12>>2]|0;if((rz(f)|0)!=1096303940){h=-1094995529;i=b;return h|0}j=lz(f)|0;k=tz(f)|0;l=g;c[l>>2]=k;if((k|0)==0){yDb(a,16,1954512,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}k=vz(f)|0;do{if((k|0)>0){c[e>>2]=1e3;c[d>>2]=k}else{if((k|0)<0){c[e>>2]=1e5;c[d>>2]=-k;break}else{c[e>>2]=10;c[d>>2]=1;break}}}while(0);k=tz(f)|0;n=tz(f)|0;o=g+4|0;c[o>>2]=0;p=LT(a,0)|0;if((p|0)==0){h=-12;i=b;return h|0}if((rz(f)|0)==1163280727){c[o>>2]=1;q=vz(f)|0;r=Ty(f,0,0,1)|0;s=YGb(r,F,q,0)|0;q=g+24|0;c[q>>2]=s;c[q+4>>2]=F;Vy(f,16,0)|0;s=rz(f)|0;r=LT(a,0)|0;if((r|0)==0){h=-12;i=b;return h|0}t=r+8|0;u=AO(f,c[t>>2]|0,s)|0;if((u|0)<0){h=u;i=b;return h|0}u=c[(c[t>>2]|0)+412>>2]|0;if((u|0)>0){MT(r,64,1,u)}u=Ty(f,0,0,1)|0;r=F;v=c[q+4>>2]|0;a:do{if((r|0)<(v|0)|(r|0)==(v|0)&u>>>0<(c[q>>2]|0)>>>0){w=s;while(1){if((Xy(f)|0)!=0){x=w;break a}y=rz(f)|0;z=rz(f)|0;if((y|0)==1635017060){x=z;break a}Vy(f,z,0)|0;y=Ty(f,0,0,1)|0;A=F;B=c[q+4>>2]|0;if((A|0)<(B|0)|(A|0)==(B|0)&y>>>0<(c[q>>2]|0)>>>0){w=z}else{x=z;break}}}else{x=s}}while(0);s=c[l>>2]|0;u=((x-1+s|0)>>>0)/(s>>>0)|0;s=g+8|0;c[s>>2]=u;v=c[(c[t>>2]|0)+432>>2]|0;if((v|0)!=0){t=u-1+v|0;c[s>>2]=t-((t|0)%(v|0)|0)}c[g+12>>2]=x;x=Ty(f,0,0,1)|0;v=g+16|0;c[v>>2]=x;c[v+4>>2]=F;Ty(f,c[q>>2]|0,c[q+4>>2]|0,0)|0;}q=p+8|0;v=c[q>>2]|0;c[v+8>>2]=0;c[v+48>>2]=99;c[v+120>>2]=k;c[v+124>>2]=n;n=c[e>>2]|0;v=c[d>>2]|0;iFb(e,d,n,(n|0)<0|0?-1:0,v,(v|0)<0|0?-1:0,2147483647,0)|0;MT(p,33,c[d>>2]|0,c[e>>2]|0);if((j&192|0)!=0){j=(c[q>>2]|0)+124|0;c[j>>2]=c[j>>2]>>1}c[g+32>>2]=(c[o>>2]|0)==0;o=Ty(f,0,0,1)|0;f=g+24|0;c[f>>2]=o;c[f+4>>2]=F;f=a+1056|0;c[f>>2]=0;c[f+4>>2]=0;f=c[l>>2]|0;l=gHb(f,(f|0)<0|0?-1:0,1e6,0)|0;o=c[d>>2]|0;d=gHb(l,F,o,(o|0)<0|0?-1:0)|0;o=c[e>>2]|0;e=eHb(d,F,o,(o|0)<0|0?-1:0)|0;o=a+1064|0;c[o>>2]=e;c[o+4>>2]=F;yDb(a,48,1927640,(m=i,i=i+8|0,c[m>>2]=f,m)|0);i=m;h=0;i=b;return h|0}function LB(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+792|0;g=f|0;h=f+16|0;j=h|0;k=c[b+12>>2]|0;l=k+32|0;do{if((c[l>>2]|0)==0){if((c[k+4>>2]|0)==0){break}m=k+12|0;if((c[m>>2]|0)==0){break}c[l>>2]=1;n=b+16|0;o=k+16|0;Ty(c[n>>2]|0,c[o>>2]|0,c[o+4>>2]|0,0)|0;p=c[m>>2]|0;q=c[k+8>>2]|0;r=p>>>0>q>>>0?q:p;p=TS(c[n>>2]|0,e,r)|0;c[e+32>>2]=1;if((p|0)!=(r|0)){s=-5;i=f;return s|0}c[m>>2]=(c[m>>2]|0)-r;r=Ty(c[n>>2]|0,0,0,1)|0;c[o>>2]=r;c[o+4>>2]=F;s=0;i=f;return s|0}}while(0);o=b+16|0;r=k+24|0;Ty(c[o>>2]|0,c[r>>2]|0,c[r+4>>2]|0,0)|0;if((Xy(c[o>>2]|0)|0)!=0){s=-541478725;i=f;return s|0}n=k;k=g|0;m=g;p=h+4|0;q=0;while(1){if((c[n>>2]|0)==0){s=-541478725;t=28;break}u=mz(c[o>>2]|0,k,4)|0;if((u|0)!=4){t=10;break}v=c[m>>2]|0;if((v|0)==1280070990){t=12;break}else if((v|0)==1296126534){t=17;break}else if((v|0)!=1346456899){t=27;break}c[j>>2]=1346456899;mz(c[o>>2]|0,p,768)|0;if((Xy(c[o>>2]|0)|0)==0){q=772}else{s=-541478725;t=28;break}}if((t|0)==10){yDb(b,16,2149264,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=(u|0)<0?u:-1094995529;i=f;return s|0}else if((t|0)==12){if((wZ(e,q+4|0)|0)<0){s=-12;i=f;return s|0}c[e+32>>2]=0;u=e+24|0;if((q|0)!=0){UGb(c[u>>2]|0,h|0,q)|0}p=(c[u>>2]|0)+q|0;x=c[m>>2]|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[n>>2]=(c[n>>2]|0)-1;p=Ty(c[o>>2]|0,0,0,1)|0;c[r>>2]=p;c[r+4>>2]=F;c[l>>2]=0;s=0;i=f;return s|0}else if((t|0)==17){p=mz(c[o>>2]|0,g+4|0,5)|0;if((p|0)!=5){yDb(b,16,2081944,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=(p|0)<0?p:-1094995529;i=f;return s|0}p=g+5|0;m=fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if(m>>>0>16777215>>>0){yDb(b,16,2031408,(w=i,i=i+8|0,c[w>>2]=m,w)|0);i=w;s=-1094995529;i=f;return s|0}p=q|9;if((wZ(e,p+m|0)|0)<0){s=-12;i=f;return s|0}u=e+24|0;UGb((c[u>>2]|0)+q|0,k|0,9)|0;if((mz(c[o>>2]|0,(c[u>>2]|0)+p|0,m)|0)!=(m|0)){BZ(e);s=-5;i=f;return s|0}if((q|0)!=0){UGb(c[u>>2]|0,h|0,q)|0}c[e+32>>2]=0;c[n>>2]=(c[n>>2]|0)-1;n=Ty(c[o>>2]|0,0,0,1)|0;c[r>>2]=n;c[r+4>>2]=F;c[l>>2]=0;s=0;i=f;return s|0}else if((t|0)==27){l=d[g+1|0]|0;r=d[g+2|0]|0;n=d[g+3|0]|0;yDb(b,16,1987104,(w=i,i=i+32|0,c[w>>2]=v&255,c[w+8>>2]=l,c[w+16>>2]=r,c[w+24>>2]=n,w)|0);i=w;s=-1094995529;i=f;return s|0}else if((t|0)==28){i=f;return s|0}return 0}function MB(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==4){b=a[d+1|0]|0;if((b<<24>>24|0)==0|(b<<24>>24|0)==4|(b<<24>>24|0)==12|(b<<24>>24|0)==20){e=12}else{break}return e|0}}while(0);e=0;return e|0}function NB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=tz(e)|0;if((f|0)==1024){c[d>>2]=1;g=0;h=0}else if((f|0)==1036){c[d>>2]=4;g=0;h=51}else if((f|0)==1044){c[d>>2]=6;g=0;h=63}else if((f|0)==1028){c[d>>2]=2;g=0;h=0}else{yDb(a,32,2081864,(j=i,i=i+8|0,c[j>>2]=f,j)|0);i=j;k=-1;i=b;return k|0}j=tz(e)|0;Vy(e,(lz(e)|0)>>>3&4|11,0)|0;e=LT(a,0)|0;if((e|0)==0){k=-12;i=b;return k|0}a=c[e+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=0;c[a+48>>2]=69657;c[a+416>>2]=c[d>>2];f=a+448|0;c[f>>2]=h;c[f+4>>2]=g;c[a+412>>2]=j;MT(e,64,1,j);c[d+4>>2]=0;k=0;i=b;return k|0}function OB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+12>>2]|0;e=TS(c[a+16>>2]|0,b,(c[d>>2]|0)*76|0)|0;if((e|0)<0){f=e;return f|0}e=d+4|0;d=c[e>>2]|0;c[e>>2]=d+1;e=b+8|0;c[e>>2]=d;c[e+4>>2]=0;f=0;return f|0}function PB(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((e|0)==1749963569|(e|0)==1816675155|(e|0)==1145128275|(e|0)==1313163347|(e|0)==1413961323|(e|0)==1799635277|(e|0)==1749241933|(e|0)==1684559437|(e|0)==1749636685)){f=0;return f|0}e=b+4|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if(b>>>0>1048575>>>0){g=fe(b|0)|0}else{g=b}f=(g-8|0)>>>0>1048567>>>0?0:100;return f|0}function QB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;b=i;d=a+12|0;e=c[d>>2]|0;f=a+16|0;g=c[f>>2]|0;h=e+32|0;j=e;k=a;l=e+4|0;m=0;a:while(1){if((c[h>>2]|0)!=0){if((c[l>>2]|0)!=0){n=98;break}}o=Ty(g,0,0,1)|0;p=F;q=rz(g)|0;r=rz(g)|0;if((m|0)==0){s=r>>>0>(fe(r|0)|0)>>>0|0;c[j>>2]=s;t=s}else{t=c[j>>2]|0}if((t|0)==0){u=r}else{u=fe(r|0)|0}if(u>>>0<8>>>0){n=10;break}b:do{if((q|0)==1145128275){r=c[d>>2]|0;s=c[f>>2]|0;c[r+44>>2]=rz(s)|0;c[r+40>>2]=rz(s)|0;c[r+48>>2]=rz(s)|0;c[r+32>>2]=69655}else if((q|0)==1749636685){r=c[d>>2]|0;Vy(c[f>>2]|0,10,0)|0;s=pz(c[f>>2]|0)|0;if((s|0)!=0){c[r+8>>2]=1;c[r+12>>2]=s}c[r+4>>2]=119}else if((q|0)==1413961323){c[l>>2]=121}else if((q|0)==1145263213){r=c[d>>2]|0;s=c[f>>2]|0;Vy(s,4,0)|0;c[r+16>>2]=pz(s)|0;c[r+20>>2]=pz(s)|0;c[r+8>>2]=1;c[r+12>>2]=15;c[r+4>>2]=38}else if((q|0)==1749241933){c[l>>2]=2}else if((q|0)==1413960048|(q|0)==1934706516){c[l>>2]=122}else if((q|0)==1414613360){c[l>>2]=123}else if((q|0)==1799635277){c[l>>2]=130}else if((q|0)==1684559437){r=c[d>>2]|0;s=c[f>>2]|0;Vy(s,8,0)|0;c[r+24>>2]=rz(s)|0;Vy(s,4,0)|0;v=r+12|0;c[v>>2]=rz(s)|0;w=rz(s)|0;c[r+8>>2]=w;if((c[v>>2]|0)<1|(w|0)<1){n=96;break a}c[r+4>>2]=92}else if((q|0)==1816675155|(q|0)==1313163347){r=rz(g)|0;if((r|0)==1381258055){Vy(g,4,0)|0;}else{if((r&65535|0)!=21584){n=27;break a}}r=c[d>>2]|0;w=c[f>>2]|0;c[r+40>>2]=2;v=r+44|0;c[v>>2]=-1;s=r+48|0;c[s>>2]=1;do{if((Xy(w)|0)==0){x=r+52|0;y=-1;z=-1;A=-1;B=1;c:while(1){while(1){C=(lz(w)|0)&255;if((C|0)==255){n=61;break c}else if((C|0)==253){break}D=(lz(w)|0)&255;if((D|0)==0){E=0}else{G=0;H=0;while(1){I=(lz(w)|0)&255|H<<8;J=G+1|0;if((J|0)<(D|0)){G=J;H=I}else{E=I;break}}}yDb(k,48,2161816,(K=i,i=i+16|0,c[K>>2]=C,c[K+8>>2]=E,K)|0);i=K;if((Xy(w)|0)!=0){L=y;M=z;N=A;break c}}yDb(k,48,2298272,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;d:do{if((Xy(w)|0)==0){H=y;G=z;D=A;I=1;J=B;while(1){O=(lz(w)|0)&255;switch(O|0){case 132:{P=(lz(w)|0)&255;if((P|0)==0){Q=0}else{R=0;S=0;while(1){T=(lz(w)|0)&255|S<<8;U=R+1|0;if((U|0)<(P|0)){R=U;S=T}else{Q=T;break}}}c[v>>2]=Q;yDb(k,48,2237088,(K=i,i=i+8|0,c[K>>2]=Q,K)|0);i=K;V=J;W=I;X=D;Y=G;Z=H;break};case 133:{S=(lz(w)|0)&255;if((S|0)==0){_=0}else{R=0;P=0;while(1){T=(lz(w)|0)&255|P<<8;U=R+1|0;if((U|0)<(S|0)){R=U;P=T}else{_=T;break}}}c[x>>2]=_;yDb(k,48,2224424,(K=i,i=i+8|0,c[K>>2]=_,K)|0);i=K;V=J;W=I;X=D;Y=G;Z=H;break};case 131:{P=(lz(w)|0)&255;if((P|0)==0){$=0}else{R=0;S=0;while(1){T=(lz(w)|0)&255|S<<8;U=R+1|0;if((U|0)<(P|0)){R=U;S=T}else{$=T;break}}}yDb(k,48,2250800,(K=i,i=i+8|0,c[K>>2]=$,K)|0);i=K;V=J;W=I;X=D;Y=G;Z=$;break};case 138:{S=(lz(w)|0)&255;if((S|0)==0){aa=0}else{R=0;P=0;while(1){T=(lz(w)|0)&255|P<<8;U=R+1|0;if((U|0)<(S|0)){R=U;P=T}else{aa=T;break}}}yDb(k,48,2214600,(K=i,i=i+16|0,c[K>>2]=138,c[K+8>>2]=aa,K)|0);i=K;yDb(k,48,2204888,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;V=J;W=0;X=D;Y=G;Z=H;break};case 160:{P=(lz(w)|0)&255;if((P|0)==0){ca=0}else{R=0;S=0;while(1){T=(lz(w)|0)&255|S<<8;U=R+1|0;if((U|0)<(P|0)){R=U;S=T}else{ca=T;break}}}yDb(k,48,2197376,(K=i,i=i+8|0,c[K>>2]=ca,K)|0);i=K;V=J;W=I;X=ca;Y=G;Z=H;break};case 130:{S=(lz(w)|0)&255;if((S|0)==0){da=0}else{R=0;P=0;while(1){T=(lz(w)|0)&255|P<<8;U=R+1|0;if((U|0)<(S|0)){R=U;P=T}else{da=T;break}}}c[s>>2]=da;yDb(k,48,2265864,(K=i,i=i+8|0,c[K>>2]=da,K)|0);i=K;V=J;W=I;X=D;Y=G;Z=H;break};case 255:{yDb(k,48,2185144,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;V=0;W=0;X=D;Y=G;Z=H;break};case 128:{P=(lz(w)|0)&255;if((P|0)==0){ea=0}else{R=0;S=0;while(1){T=(lz(w)|0)&255|S<<8;U=R+1|0;if((U|0)<(P|0)){R=U;S=T}else{ea=T;break}}}yDb(k,48,2281048,(K=i,i=i+8|0,c[K>>2]=ea,K)|0);i=K;V=J;W=I;X=D;Y=ea;Z=H;break};default:{S=(lz(w)|0)&255;if((S|0)==0){fa=0}else{R=0;P=0;while(1){T=(lz(w)|0)&255|P<<8;U=R+1|0;if((U|0)<(S|0)){R=U;P=T}else{fa=T;break}}}yDb(k,48,2214600,(K=i,i=i+16|0,c[K>>2]=O,c[K+8>>2]=fa,K)|0);i=K;V=J;W=I;X=D;Y=G;Z=H}}if((Xy(w)|0)!=0|(W|0)==0){ga=Z;ha=Y;ia=X;ja=V;break d}else{H=Z;G=Y;D=X;I=W;J=V}}}else{ga=y;ha=z;ia=A;ja=B}}while(0);if((Xy(w)|0)!=0|(ja|0)==0){L=ga;M=ha;N=ia;break}else{y=ga;z=ha;A=ia;B=ja}}if((n|0)==61){n=0;yDb(k,48,2169968,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;Xy(w)|0;L=y;M=z;N=A}if((L|0)==0){c[r+32>>2]=65536;ka=M;break}else if((L|0)==7){c[r+32>>2]=69642;ka=M;break}else if((L|0)==(-1|0)){if((M|0)==(-1|0)){la=-1}else if((M|0)==1){c[r+32>>2]=69652;la=1}else if((M|0)==2){c[r+32>>2]=69654;la=2}else if((M|0)==3){c[r+32>>2]=69653;la=3}else{DDb(k,2155176,(K=i,i=i+8|0,c[K>>2]=M,K)|0);i=K;break b}if((N|0)==(-1|0)){ka=la;break}else if((N|0)==8){c[r+32>>2]=65554;ka=la;break}else if((N|0)==10){if((la|0)==(-1|0)|(la|0)==2){c[r+32>>2]=69652;ka=la;break}else if((la|0)==3){c[r+32>>2]=69654;ka=3;break}else{DDb(k,2148224,(K=i,i=i+16|0,c[K>>2]=la,c[K+8>>2]=10,K)|0);i=K;break b}}else if((N|0)==16){c[r+32>>2]=86017;ka=la;break}else{c[r+32>>2]=0;DDb(k,2141712,(K=i,i=i+8|0,c[K>>2]=N,K)|0);i=K;break b}}else{DDb(k,2135776,(K=i,i=i+8|0,c[K>>2]=L,K)|0);i=K;break b}}else{ka=-1}}while(0);if(!((c[v>>2]|0)==-1)){break}c[v>>2]=(ka|0)==3?48e3:22050}else if((q|0)==1749963569){if((rz(g)|0)!=1396916549){n=13;break a}r=c[d>>2]|0;w=c[f>>2]|0;if((c[r>>2]|0)==0){ma=rz(w)|0}else{ma=vz(w)|0}c[r+44>>2]=ma;s=r+40|0;c[s>>2]=lz(w)|0;c[r+48>>2]=lz(w)|0;B=lz(w)|0;Vy(w,13,0)|0;if((B|0)==2){c[r+32>>2]=69656;break}else if((B|0)==0){w=c[s>>2]|0;if((w|0)==1){c[r+32>>2]=65540;break}else if((w|0)==2){c[r+32>>2]=65536;break}else{break}}else if((B|0)==1){c[r+32>>2]=65542;c[s>>2]=1;break}else{DDb(k,2129640,(K=i,i=i+8|0,c[K>>2]=B,K)|0);i=K;break}}}while(0);q=YGb(u,0,o,p)|0;Ty(g,q,F,0)|0;q=m+1|0;if((q|0)<5){m=q}else{n=98;break}}if((n|0)==10){yDb(k,16,1927608,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;na=-5;i=b;return na|0}else if((n|0)==13){DDb(k,1905624,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;na=-5;i=b;return na|0}else if((n|0)==27){DDb(k,1884896,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;na=-5;i=b;return na|0}else if((n|0)==96){yDb(k,16,2320584,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;yDb(k,16,2342992,(K=i,i=i+8|0,c[K>>2]=-1094995529,K)|0);i=K;na=-5;i=b;return na|0}else if((n|0)==98){Ty(g,0,0,0)|0;if((c[l>>2]|0)!=0){g=LT(a,0)|0;if((g|0)==0){na=-12;i=b;return na|0}c[e+28>>2]=c[g>>2];n=c[g+8>>2]|0;c[n+8>>2]=0;m=c[l>>2]|0;c[n+48>>2]=m;if((m|0)==2){c[g+236>>2]=2}c[n+52>>2]=0;c[n+120>>2]=c[e+16>>2];c[n+124>>2]=c[e+20>>2];n=c[e+24>>2]|0;m=n;l=(n|0)<0|0?-1:0;n=g+64|0;c[n>>2]=m;c[n+4>>2]=l;n=g+56|0;c[n>>2]=m;c[n+4>>2]=l;l=e+8|0;n=c[l>>2]|0;m=e+12|0;if((n|0)==0){oa=0;pa=0}else{MT(g,64,n,c[m>>2]|0);oa=c[l>>2]|0;pa=0}l=g+92|0;n=pa|c[m>>2];m=oa|0;c[l>>2]=n;c[l+4>>2]=m;l=g+412|0;c[l>>2]=n;c[l+4>>2]=m}if((c[h>>2]|0)==0){na=1;i=b;return na|0}m=e+48|0;l=c[m>>2]|0;if((l-1|0)>>>0>1>>>0){yDb(k,24,2031296,(K=i,i=i+8|0,c[K>>2]=l,K)|0);i=K;c[h>>2]=0;na=1;i=b;return na|0}l=e+44|0;n=c[l>>2]|0;if((n|0)<1){yDb(k,16,1987024,(K=i,i=i+8|0,c[K>>2]=n,K)|0);i=K;c[h>>2]=0;na=1;i=b;return na|0}n=e+40|0;g=c[n>>2]|0;if((g|0)<1){yDb(k,16,1954376,(K=i,i=i+8|0,c[K>>2]=g,K)|0);i=K;c[h>>2]=0;na=1;i=b;return na|0}K=LT(a,0)|0;if((K|0)==0){na=-12;i=b;return na|0}MT(K,33,1,c[l>>2]|0);a=c[K+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=c[h>>2];c[a+52>>2]=0;h=c[m>>2]|0;c[a+416>>2]=h;m=c[l>>2]|0;c[a+412>>2]=m;l=c[n>>2]<<3;c[a+792>>2]=l;c[a+72>>2]=(ba(ba(m,h)|0,l)|0)/4|0;c[a+432>>2]=ba(l,h)|0;c[e+36>>2]=c[K>>2];e=K+48|0;c[e>>2]=0;c[e+4>>2]=0;na=1;i=b;return na|0}return 0}function RB(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;f=c[a+12>>2]|0;g=c[a+16>>2]|0;h=f;j=f+32|0;k=f+36|0;l=b+32|0;m=f+40|0;n=f+48|0;o=b+48|0;p=b+28|0;q=b+24|0;r=a;a=f+28|0;f=b+36|0;s=0;t=0;u=0;v=0;w=0;a:while(1){x=rz(g)|0;if((c[h>>2]|0)==0){y=rz(g)|0}else{y=vz(g)|0}if(y>>>0<9>>>0){z=-1094995529;A=35;break}B=y-8|0;if((x|0)==1749963569){if(B>>>0<32>>>0){z=-1094995529;A=35;break}Vy(g,32,0)|0;C=y-40|0;A=9}else if((x|0)==1682854705|(x|0)==1816413011|(x|0)==1128549971|(x|0)==1313162323){C=B;A=9}else if((x|0)==1749636685|(x|0)==1413961323|(x|0)==1413960048|(x|0)==1934706516|(x|0)==1799635277){D=1;A=25}else if((x|0)==1716082253|(x|0)==1413961318|(x|0)==1833189709|(x|0)==1698971981){D=v;A=25}else if((x|0)==1145263213){Vy(g,8,0)|0;E=v;F=y-16|0;A=28}else if((x|0)==1261459021|(x|0)==1749241933|(x|0)==1414613360){E=1;F=B;A=28}else if((x|0)==1177572941){E=v;F=B;A=28}else if((x|0)==0|(x|0)==1699631921|(x|0)==1816478547|(x|0)==1145980243|(x|0)==1313162579){G=w;H=v;I=1;J=-5;K=s}else{Vy(g,B,0)|0;G=w;H=v;I=u;J=t;K=s}do{if((A|0)==9){A=0;B=c[j>>2]|0;if((B|0)==0){Vy(g,C,0)|0;G=w;H=v;I=u;J=t;K=s;break}else if((B|0)==65554|(B|0)==86017){B=rz(g)|0;Vy(g,8,0)|0;L=B;M=C-12|0}else{L=w;M=C}if((s|0)!=0){DDb(r,2149152,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;BZ(b)}B=TS(g,b,M)|0;if((B|0)<0){z=B;A=35;break a}c[l>>2]=c[k>>2];O=c[j>>2]|0;if((O|0)==69642|(O|0)==69652|(O|0)==69654|(O|0)==69656|(O|0)==69653){if((c[p>>2]|0)<4){A=17;break a}P=c[q>>2]|0;Q=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;if((O|0)==69653){c[o>>2]=fe(Q|0)|0;G=L;H=v;I=1;J=B;K=0;break}else{c[o>>2]=Q;G=L;H=v;I=1;J=B;K=0;break}}else if((O|0)==69655){c[o>>2]=(B<<1|0)/(c[n>>2]|0)|0;G=L;H=v;I=1;J=B;K=0;break}else if((O|0)==65554|(O|0)==86017){c[o>>2]=L;G=L;H=v;I=1;J=B;K=0;break}else{c[o>>2]=(M>>>0)/((ba(c[n>>2]|0,c[m>>2]|0)|0)>>>0)|0;G=L;H=v;I=1;J=B;K=0;break}}else if((A|0)==25){A=0;Ty(g,-8,-1,1)|0;E=D;F=y;A=28}}while(0);do{if((A|0)==28){A=0;if((s|0)==0){R=TS(g,b,F)|0}else{R=VS(g,b,F)|0}if((R|0)<0){G=w;H=E;I=1;J=R;K=s;break}c[l>>2]=c[a>>2];c[f>>2]=c[f>>2]|E;G=w;H=E;I=1;J=R;K=(x|0)==1749636685|0}}while(0);if((I|0)==0|(K|0)!=0){s=K;t=J;u=I;v=H;w=G}else{z=J;A=35;break}}if((A|0)==17){yDb(r,16,2081840,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;BZ(b);z=-1094995529;i=e;return z|0}else if((A|0)==35){i=e;return z|0}return 0}function SB(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((e|0)==1717661728){a=b+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==0){f=4}}else if((e|0)==544235878){e=b+8|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==1){f=4}}do{if((f|0)==4){e=b+4|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)!=0){break}e=b+12|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==0){break}e=b+20|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==0){break}else{g=75}return g|0}}while(0);g=0;return g|0}function TB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a+16|0;Vy(c[d>>2]|0,4,0)|0;if((rz(c[d>>2]|0)|0)!=0){e=-1094995529;i=b;return e|0}f=rz(c[d>>2]|0)|0;g=(f|0)!=0;if(f>>>0>1>>>0){e=-1094995529;i=b;return e|0}f=c[d>>2]|0;if(g){h=rz(f)|0;j=rz(c[d>>2]|0)|0;k=rz(c[d>>2]|0)|0;l=j;m=h}else{h=vz(f)|0;f=vz(c[d>>2]|0)|0;k=vz(c[d>>2]|0)|0;l=f;m=h}if((k|0)==0|(m|0)==0){e=-1094995529;i=b;return e|0}h=LT(a,0)|0;if((h|0)==0){e=-12;i=b;return e|0}f=h+8|0;j=c[f>>2]|0;c[j+8>>2]=1;c[j+416>>2]=k;c[j+412>>2]=m;if((l|0)==1){DDb(a,2081792,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1094995529;i=b;return e|0}else if((l|0)==0){a=g?65536:65537;c[j+48>>2]=a;n=a}else if((l|0)==2){c[j+48>>2]=65540;n=65540}else{e=-1094995529;i=b;return e|0}j=u0a(n)|0;n=c[f>>2]|0;c[n+792>>2]=j;c[n+432>>2]=(ba(c[n+416>>2]|0,j)|0)/8|0;MT(h,64,1,c[n+412>>2]|0);n=Vy(c[d>>2]|0,2024,0)|0;d=F;h=0;e=(d|0)<(h|0)|(d|0)==(h|0)&n>>>0<0>>>0?-1094995529:0;i=b;return e|0}function UB(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==70){if((a[d+1|0]|0)!=70){break}if((a[d+2|0]|0)!=77){break}if(((a[d+3|0]|0)-49&255)>>>0<2>>>0){e=101}else{break}return e|0}}while(0);e=0;return e|0}function VB(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;b=i;i=i+256|0;d=b+128|0;e=a+12|0;f=c[e>>2]|0;j=a+16|0;l=c[j>>2]|0;m=rz(l)|0;a:do{if((m|0)==843925062){n=b|0;o=c[e>>2]|0;p=c[j>>2]|0;q=vz(p)|0;r=o+44|0;c[r>>2]=q;b:do{if((q|0)==4096){s=Az(p)|0;t=o;c[t>>2]=s;c[t+4>>2]=F;if((c[p+88>>2]|0)==0){t=o+8|0;c[t>>2]=-1;c[t+4>>2]=2147483647}else{t=Wy(p)|0;s=o+8|0;c[s>>2]=t;c[s+4>>2]=F}c:do{if((Xy(p)|0)==0){d:while(1){s=vz(p)|0;t=vz(p)|0;u=Ty(p,0,0,1)|0;v=YGb(u,F,t,0)|0;t=F;do{if((s|0)==1296124238){vz(p)|0;vz(p)|0;w=t;x=v}else if((s|0)==0){break c}else if((s|0)==1129270605){u=LT(a,0)|0;if((u|0)==0){break b}MT(u,64,1,1e6);y=c[u+8>>2]|0;c[y+48>>2]=vz(p)|0;c[y+8>>2]=lz(p)|0;c[y+72>>2]=vz(p)|0;u=y+88|0;c[u>>2]=vz(p)|0;c[y+92>>2]=vz(p)|0;c[y+688>>2]=vz(p)|0;if((c[u>>2]&4194304|0)!=0){if((CT(y,p,vz(p)|0)|0)<0){z=-12;break d}}Ty(p,v,t,0)|0;u=vz(p)|0;A=vz(p)|0;B=Ty(p,0,0,1)|0;C=YGb(B,F,A,0)|0;A=F;if((u|0)==1398030677){c[y+412>>2]=vz(p)|0;c[y+416>>2]=pz(p)|0;c[y+424>>2]=pz(p)|0;w=A;x=C;break}else if((u|0)==1398036041){c[y+104>>2]=vz(p)|0;c[y+108>>2]=vz(p)|0;c[y+120>>2]=tz(p)|0;c[y+124>>2]=tz(p)|0;c[y+136>>2]=tz(p)|0;c[y+140>>2]=vz(p)|0;c[y+500>>2]=lz(p)|0;c[y+504>>2]=lz(p)|0;u=y+508|0;c[u>>2]=lz(p)|0;B=y+492|0;g[B>>2]=+((tz(p)|0)>>>0>>>0)/1.0e4;D=y+496|0;g[D>>2]=+((tz(p)|0)>>>0>>>0)/1.0e4;c[y+76>>2]=vz(p)|0;xz(p,2147483647,n,128)|0;c[y+536>>2]=eEb(n)|0;c[y+540>>2]=vz(p)|0;c[y+544>>2]=vz(p)|0;c[y+524>>2]=vz(p)|0;E=Az(p)|0;G=F;g[y+184>>2]=(c[k>>2]=E,c[k+4>>2]=G,+h[k>>3]);G=Az(p)|0;E=F;g[y+160>>2]=(c[k>>2]=G,c[k+4>>2]=E,+h[k>>3]);E=Az(p)|0;G=F;g[y+188>>2]=(c[k>>2]=E,c[k+4>>2]=G,+h[k>>3]);G=Az(p)|0;E=F;g[y+172>>2]=(c[k>>2]=G,c[k+4>>2]=E,+h[k>>3]);c[y+784>>2]=vz(p)|0;c[y+680>>2]=vz(p)|0;c[y+156>>2]=vz(p)|0;c[y+180>>2]=vz(p)|0;c[y+324>>2]=vz(p)|0;c[y+144>>2]=vz(p)|0;c[y+296>>2]=vz(p)|0;c[y+836>>2]=vz(p)|0;c[y+596>>2]=vz(p)|0;E=Az(p)|0;G=F;g[y+548>>2]=(c[k>>2]=E,c[k+4>>2]=G,+h[k>>3]);c[y+52>>2]=vz(p)|0;c[y+808>>2]=lz(p)|0;c[y+568>>2]=vz(p)|0;c[y+232>>2]=vz(p)|0;c[y+268>>2]=vz(p)|0;c[y+276>>2]=vz(p)|0;c[y+360>>2]=vz(p)|0;c[y+308>>2]=vz(p)|0;c[y+168>>2]=vz(p)|0;G=Az(p)|0;E=F;g[B>>2]=(c[k>>2]=G,c[k+4>>2]=E,+h[k>>3]);E=Az(p)|0;G=F;g[D>>2]=(c[k>>2]=E,c[k+4>>2]=G,+h[k>>3]);c[u>>2]=vz(p)|0;c[y+364>>2]=vz(p)|0;w=A;x=C;break}else{w=A;x=C;break}}else{w=t;x=v}}while(0);Ty(p,x,w,0)|0;if((Xy(p)|0)!=0){break c}}i=b;return z|0}}while(0);v=Ty(p,0,0,1)|0;t=c[r>>2]|0;s=fHb(v,F,t,(t|0)<0|0?-1:0)|0;if(!((s|0)==0&(F|0)==0)){do{lz(p)|0;s=Ty(p,0,0,1)|0;t=c[r>>2]|0;v=fHb(s,F,t,(t|0)<0|0?-1:0)|0;}while(!((v|0)==0&(F|0)==0))}v=o+72|0;c[o+64>>2]=v;c[o+68>>2]=v;c[o+48>>2]=0;v=o+56|0;c[v>>2]=0;c[v+4>>2]=0;c[o+16>>2]=0;c[o+40>>2]=1;z=0;i=b;return z|0}}while(0);o=a+24|0;if((c[o>>2]|0)==0){z=-1;i=b;return z|0}r=a+28|0;p=0;while(1){$Db((c[(c[(c[r>>2]|0)+(p<<2)>>2]|0)+8>>2]|0)+536|0);n=p+1|0;if(n>>>0<(c[o>>2]|0)>>>0){p=n}else{z=-1;break}}i=b;return z|0}else if((m|0)==827147846){p=vz(l)|0;o=f+44|0;c[o>>2]=p;if((p|0)!=4096){break}p=Az(l)|0;r=f;c[r>>2]=p;c[r+4>>2]=F;if((c[l+88>>2]|0)==0){r=f+8|0;c[r>>2]=-1;c[r+4>>2]=2147483647}else{r=Wy(l)|0;p=f+8|0;c[p>>2]=r;c[p+4>>2]=F}p=vz(l)|0;vz(l)|0;e:do{if((p|0)>0){r=d|0;n=0;while(1){q=LT(a,0)|0;if((q|0)==0){break a}MT(q,64,1,1e6);v=c[q+8>>2]|0;c[v+48>>2]=vz(l)|0;q=v+8|0;c[q>>2]=lz(l)|0;c[v+72>>2]=vz(l)|0;t=v+88|0;c[t>>2]=vz(l)|0;c[v+92>>2]=vz(l)|0;c[v+688>>2]=vz(l)|0;s=c[q>>2]|0;if((s|0)==1){c[v+412>>2]=vz(l)|0;c[v+416>>2]=pz(l)|0;c[v+424>>2]=pz(l)|0}else if((s|0)==0){c[v+104>>2]=vz(l)|0;c[v+108>>2]=vz(l)|0;c[v+120>>2]=tz(l)|0;c[v+124>>2]=tz(l)|0;c[v+136>>2]=tz(l)|0;c[v+140>>2]=vz(l)|0;c[v+500>>2]=lz(l)|0;c[v+504>>2]=lz(l)|0;s=v+508|0;c[s>>2]=lz(l)|0;q=v+492|0;g[q>>2]=+((tz(l)|0)>>>0>>>0)/1.0e4;C=v+496|0;g[C>>2]=+((tz(l)|0)>>>0>>>0)/1.0e4;c[v+76>>2]=vz(l)|0;xz(l,2147483647,r,128)|0;c[v+536>>2]=eEb(r)|0;c[v+540>>2]=vz(l)|0;c[v+544>>2]=vz(l)|0;c[v+524>>2]=vz(l)|0;A=Az(l)|0;y=F;g[v+184>>2]=(c[k>>2]=A,c[k+4>>2]=y,+h[k>>3]);y=Az(l)|0;A=F;g[v+160>>2]=(c[k>>2]=y,c[k+4>>2]=A,+h[k>>3]);A=Az(l)|0;y=F;g[v+188>>2]=(c[k>>2]=A,c[k+4>>2]=y,+h[k>>3]);y=Az(l)|0;A=F;g[v+172>>2]=(c[k>>2]=y,c[k+4>>2]=A,+h[k>>3]);c[v+784>>2]=vz(l)|0;c[v+680>>2]=vz(l)|0;c[v+156>>2]=vz(l)|0;c[v+180>>2]=vz(l)|0;c[v+324>>2]=vz(l)|0;c[v+144>>2]=vz(l)|0;c[v+296>>2]=vz(l)|0;c[v+836>>2]=vz(l)|0;c[v+596>>2]=vz(l)|0;A=Az(l)|0;y=F;g[v+548>>2]=(c[k>>2]=A,c[k+4>>2]=y,+h[k>>3]);c[v+52>>2]=vz(l)|0;c[v+808>>2]=lz(l)|0;c[v+568>>2]=vz(l)|0;c[v+232>>2]=vz(l)|0;c[v+268>>2]=vz(l)|0;c[v+276>>2]=vz(l)|0;c[v+360>>2]=vz(l)|0;c[v+308>>2]=vz(l)|0;c[v+168>>2]=vz(l)|0;y=Az(l)|0;A=F;g[q>>2]=(c[k>>2]=y,c[k+4>>2]=A,+h[k>>3]);A=Az(l)|0;y=F;g[C>>2]=(c[k>>2]=A,c[k+4>>2]=y,+h[k>>3]);c[s>>2]=vz(l)|0;c[v+364>>2]=vz(l)|0}else{break a}if((c[t>>2]&4194304|0)!=0){if((CT(v,l,vz(l)|0)|0)<0){z=-12;break}}n=n+1|0;if((n|0)>=(p|0)){break e}}i=b;return z|0}}while(0);p=Ty(l,0,0,1)|0;n=c[o>>2]|0;r=fHb(p,F,n,(n|0)<0|0?-1:0)|0;if(!((r|0)==0&(F|0)==0)){do{lz(l)|0;r=Ty(l,0,0,1)|0;n=c[o>>2]|0;p=fHb(r,F,n,(n|0)<0|0?-1:0)|0;}while(!((p|0)==0&(F|0)==0))}o=f+72|0;c[f+64>>2]=o;c[f+68>>2]=o;c[f+48>>2]=0;o=f+56|0;c[o>>2]=0;c[o+4>>2]=0;c[f+16>>2]=0;c[f+40>>2]=1;z=0;i=b;return z|0}}while(0);f=a+24|0;if((c[f>>2]|0)==0){z=-1;i=b;return z|0}l=a+28|0;a=0;while(1){$Db((c[(c[(c[l>>2]|0)+(a<<2)>>2]|0)+8>>2]|0)+536|0);d=a+1|0;if(d>>>0<(c[f>>2]|0)>>>0){a=d}else{z=-1;break}}i=b;return z|0}function WB(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;g=b+12|0;h=c[g>>2]|0;j=h+16|0;k=c[j>>2]|0;if((k|0)==0){l=(c[h+68>>2]|0)-(c[h+64>>2]|0)|0;do{if((l|0)<20){m=Ty(c[b+16>>2]|0,0,0,1)|0;n=F;o=h;p=c[o>>2]|0;q=c[o+4>>2]|0;do{if((p|0)==0&(q|0)==0){o=h+8|0;r=c[o>>2]|0;s=c[o+4>>2]|0;if((m|0)==(r|0)&(n|0)==(s|0)){t=-541478725;i=f;return t|0}else{o=ZGb(r,s,m,n)|0;u=F;v=o;break}}else{if((m|0)==(p|0)&(n|0)==(q|0)){t=-11;i=f;return t|0}if((n|0)<(q|0)|(n|0)==(q|0)&m>>>0<p>>>0){o=ZGb(p,q,m,n)|0;u=F;v=o;break}else{o=h+8|0;s=c[o>>2]|0;r=c[o+4>>2]|0;o=ZGb(-4096,-1,m,n)|0;w=YGb(o,F,p,q)|0;o=YGb(w,F,s,r)|0;u=F;v=o;break}}}while(0);q=c[h+44>>2]|0;p=eHb(v,u,q,(q|0)<0|0?-1:0)|0;n=q-14|0;q=gHb(n,(n|0)<0|0?-1:0,p,F)|0;p=YGb(q,F,l,(l|0)<0|0?-1:0)|0;q=F;n=0;m=(q|0)<(n|0)|(q|0)==(n|0)&p>>>0<20>>>0;if(m){t=m?-11:1}else{break}i=f;return t|0}}while(0);l=h+20|0;if((ZB(b,l,16,1)|0)!=16){t=-1;i=f;return t|0}do{if(!((a[h+21|0]&2)==0)){if((ZB(b,h+36|0,4,1)|0)==4){break}else{t=-1}i=f;return t|0}}while(0);c[j>>2]=1;x=c[g>>2]|0;y=l}else if((k|0)==1){x=h;y=h+20|0}else{t=0;i=f;return t|0}k=(d[h+23|0]|0)<<8|(d[h+22|0]|0)<<16|(d[h+24|0]|0);l=(c[x+68>>2]|0)-(c[x+64>>2]|0)|0;do{if((l|0)<(k|0)){g=Ty(c[b+16>>2]|0,0,0,1)|0;u=F;v=x;m=c[v>>2]|0;p=c[v+4>>2]|0;do{if((m|0)==0&(p|0)==0){v=x+8|0;n=c[v>>2]|0;q=c[v+4>>2]|0;if((g|0)==(n|0)&(u|0)==(q|0)){t=-541478725;i=f;return t|0}else{v=ZGb(n,q,g,u)|0;z=F;A=v;break}}else{if((g|0)==(m|0)&(u|0)==(p|0)){t=-11;i=f;return t|0}if((u|0)<(p|0)|(u|0)==(p|0)&g>>>0<m>>>0){v=ZGb(m,p,g,u)|0;z=F;A=v;break}else{v=x+8|0;q=c[v>>2]|0;n=c[v+4>>2]|0;v=ZGb(-4096,-1,g,u)|0;o=YGb(v,F,m,p)|0;v=YGb(o,F,q,n)|0;z=F;A=v;break}}}while(0);p=c[x+44>>2]|0;m=eHb(A,z,p,(p|0)<0|0?-1:0)|0;u=p-14|0;p=gHb(u,(u|0)<0|0?-1:0,m,F)|0;m=YGb(p,F,l,(l|0)<0|0?-1:0)|0;p=F;u=0;g=(u|0)>(p|0)|(u|0)==(p|0)&k>>>0>m>>>0;if(g){t=g?-11:1}else{break}i=f;return t|0}}while(0);l=(d[h+26|0]|0)<<8|(d[h+25|0]|0)<<16|(d[h+27|0]|0);if((wZ(e,k)|0)<0){t=-12;i=f;return t|0}z=d[y]|0;c[e+32>>2]=z;if(!(z>>>0<(c[b+24>>2]|0)>>>0)){yDb(b,16,2148968,(y=i,i=i+8|0,c[y>>2]=z,y)|0);i=y;BZ(e);c[j>>2]=0;t=-1;i=f;return t|0}y=Ty(c[b+16>>2]|0,0,0,1)|0;z=e+64|0;c[z>>2]=y;c[z+4>>2]=F;z=h+21|0;if(!((a[z]&1)==0)){y=e+36|0;c[y>>2]=c[y>>2]|1}c[j>>2]=0;if((ZB(b,c[e+24>>2]|0,k,0)|0)!=(k|0)){BZ(e);t=-1;i=f;return t|0}k=h+28|0;b=k|0;j=k+4|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;b=fe(k|0)|0;k=j|0;j=e+8|0;c[j>>2]=b;c[j+4>>2]=k;if((a[z]&2)==0){z=e+16|0;c[z>>2]=b;c[z+4>>2]=k}else{z=h+36|0;h=ZGb(b,k,fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0,0)|0;z=e+16|0;c[z>>2]=h;c[z+4>>2]=F}c[e+48>>2]=l;t=0;i=f;return t|0}function XB(a){a=a|0;var b=0,d=0;b=a+24|0;if((c[b>>2]|0)==0){return 0}d=a+28|0;a=0;do{$Db((c[(c[(c[d>>2]|0)+(a<<2)>>2]|0)+8>>2]|0)+536|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return 0}function YB(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0,G=0,H=0,I=0,J=0;b=a+12|0;g=c[b>>2]|0;h=g;i=c[h>>2]|0;j=c[h+4>>2]|0;k=g+8|0;l=c[k>>2]|0;m=c[k+4>>2]|0;n=a+16|0;do{if(((i|0)!=0|(j|0)!=0)&((j|0)<(m|0)|(j|0)==(m|0)&i>>>0<l>>>0)){a=c[n>>2]|0;Ty(a,4096,0,0)|0;Vy(a,4,0)|0;o=Az(a)|0;a=F;p=c[h>>2]|0;q=c[h+4>>2]|0;if((a|0)<(e|0)|(a|0)==(e|0)&o>>>0<d>>>0){r=0;s=4096;t=q;u=p;break}r=q;s=p;t=c[k+4>>2]|0;u=c[k>>2]|0}else{r=0;s=4096;t=m;u=l}}while(0);l=r;r=s;s=t;t=u;a:while(1){v=YGb(t,s,-4096,-1)|0;w=F;x=l;y=r;while(1){if((x|0)>(w|0)|(x|0)==(w|0)&y>>>0>v>>>0){z=13;break a}u=c[n>>2]|0;m=(c[b>>2]|0)+8|0;k=YGb(c[m>>2]|0,c[m+4>>2]|0,-4096,-1)|0;m=F;h=(m|0)<(x|0)|(m|0)==(x|0)&k>>>0<y>>>0;i=h?k:y;k=h?m:x;m=0;h=(k|0)>(m|0)|(k|0)==(m|0)&i>>>0>4096>>>0;Ty(u,h?i:4096,h?k:0,0)|0;Vy(u,4,0)|0;k=Az(u)|0;u=F;h=c[n>>2]|0;i=(c[b>>2]|0)+8|0;m=YGb(c[i>>2]|0,c[i+4>>2]|0,-4096,-1)|0;i=F;j=(i|0)<(w|0)|(i|0)==(w|0)&m>>>0<v>>>0;p=j?m:v;m=j?i:w;i=0;j=(m|0)>(i|0)|(m|0)==(i|0)&p>>>0>4096>>>0;Ty(h,j?p:4096,j?m:0,0)|0;Vy(h,4,0)|0;m=Az(h)|0;h=F;A=(u|0)>(e|0)|(u|0)==(e|0)&k>>>0>d>>>0;if(!(((h|0)>(e|0)|(h|0)==(e|0)&m>>>0>d>>>0)&(A^1))){z=8;break a}j=ZGb(v,w,y,x)|0;B=+(j>>>0)+ +(F|0)*4294967296.0;j=ZGb(d,e,k,u)|0;C=B*(+(j>>>0)+ +(F|0)*4294967296.0);j=ZGb(m,h,k,u)|0;B=C/(+(j>>>0)+ +(F|0)*4294967296.0);j=eHb(~~+B>>>0,(E=+B,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0),4096,0)|0;u=j<<12|0>>>20;k=F<<12|j>>>20;if((k|0)>(x|0)|(k|0)==(x|0)&u>>>0>y>>>0){j=(k|0)<(w|0)|(k|0)==(w|0)&u>>>0<v>>>0;D=j?k:w;G=j?u:v}else{D=x;G=y}u=c[n>>2]|0;j=(c[b>>2]|0)+8|0;k=YGb(c[j>>2]|0,c[j+4>>2]|0,-4096,-1)|0;j=F;h=(j|0)<(D|0)|(j|0)==(D|0)&k>>>0<G>>>0;m=h?k:G;k=h?j:D;j=0;h=(k|0)>(j|0)|(k|0)==(j|0)&m>>>0>4096>>>0;Ty(u,h?m:4096,h?k:0,0)|0;Vy(u,4,0)|0;k=Az(u)|0;u=F;if((k|0)==(d|0)&(u|0)==(e|0)){H=D;I=G;break a}h=YGb(G,D,4096,0)|0;if((u|0)>(e|0)|(u|0)==(e|0)&k>>>0>d>>>0){l=x;r=y;s=D;t=G;continue a}else{x=F;y=h}}}if((z|0)==8){H=A?x:w;I=A?y:v}else if((z|0)==13){z=(f&1|0)!=0;H=z?x:w;I=z?y:v}v=c[n>>2]|0;n=(c[b>>2]|0)+8|0;b=YGb(c[n>>2]|0,c[n+4>>2]|0,-4096,-1)|0;n=F;y=(n|0)<(H|0)|(n|0)==(H|0)&b>>>0<I>>>0;z=y?b:I;I=y?n:H;H=0;n=(I|0)>(H|0)|(I|0)==(H|0)&z>>>0>4096>>>0;H=Ty(v,n?z:4096,n?I:0,0)|0;I=F;n=0;if((I|0)<(n|0)|(I|0)==(n|0)&H>>>0<0>>>0){J=-1;return J|0}c[g+16>>2]=0;H=g+72|0;c[g+64>>2]=H;c[g+68>>2]=H;c[g+40>>2]=1;J=0;return J|0}function ZB(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;g=c[a+12>>2]|0;h=a+16|0;j=c[h>>2]|0;a:do{if((d|0)>0){k=g+68|0;l=g+64|0;m=g+8|0;n=g+44|0;o=j+8|0;p=g+56|0;q=g+72|0;r=g+40|0;s=a;t=e;u=d;v=b;w=c[l>>2]|0;b:while(1){x=(c[k>>2]|0)-w|0;if((x|0)<0){y=-1;z=27;break}A=(t|0)==0;B=w;C=x;while(1){D=(C|0)>(u|0)?u:C;if((D|0)!=0){break}x=Ty(j,0,0,1)|0;if((x|0)==(c[m>>2]|0)&(F|0)==(c[m+4>>2]|0)){x=c[n>>2]|0;Ty(j,x,(x|0)<0|0?-1:0,0)|0;}while(1){if((c[o>>2]|0)!=(c[n>>2]|0)){x=Ty(j,0,0,1)|0;E=F;Ez(j,c[n>>2]|0)|0;Ty(j,x,E,0)|0;}E=tz(j)|0;if((E|0)!=26221){yDb(s,16,2081736,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;x=E;do{if((Xy(c[h>>2]|0)|0)!=0){z=13;break b}x=lz(c[h>>2]|0)|0|x<<8;}while((x|0)!=26221)}x=tz(j)|0;E=Az(j)|0;c[p>>2]=E;c[p+4>>2]=F;H=tz(j)|0;mz(j,q,(c[n>>2]|0)-14|0)|0;E=58-x+(c[n>>2]|0)|0;I=g+E|0;c[k>>2]=I;if((E|0)<72|(H|0)<0){y=-1;z=27;break b}if((c[r>>2]|0)==0){if((H&32768|0)==0){z=23;break}}if((H|0)!=0){z=21;break}E=Ty(j,0,0,1)|0;x=F;J=c[n>>2]|0;K=gHb(J,(J|0)<0|0?-1:0,3,0)|0;L=F;if((x|0)<(L|0)|(x|0)==(L|0)&E>>>0<K>>>0){y=0;z=27;break b}K=-J|0;J=K;Ty(j,J<<1|0>>>31,((K|0)<0|0?-1:0)<<1|J>>>31,1)|0;}if((z|0)==21){z=0;c[r>>2]=0;J=H&32767;if(J>>>0<14>>>0){y=-1;z=27;break b}K=g+(J+58)|0;c[l>>2]=K;if(A){M=u;break a}else{N=K}}else if((z|0)==23){z=0;c[l>>2]=q;N=q}K=I-N|0;if((K|0)<0){y=-1;z=27;break b}else{B=N;C=K}}UGb(v|0,B|0,D)|0;C=(c[l>>2]|0)+D|0;c[l>>2]=C;A=u-D|0;if((A|0)>0){t=0;u=A;v=v+D|0;w=C}else{M=A;break a}}if((z|0)==13){yDb(s,16,2031264,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;y=-1;i=f;return y|0}else if((z|0)==27){i=f;return y|0}}else{M=d}}while(0);y=d-M|0;i=f;return y|0}function _B(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+40|0;d=b|0;e=b+8|0;f=b+16|0;j=b+24|0;l=b+32|0;m=c[a+12>>2]|0;n=a+16|0;c[l>>2]=c[n>>2];o=BBb(c[a+1140>>2]|0,2148912,0,0)|0;do{if((o|0)!=0){p=VEb(m+4168|0,c[o+4>>2]|0,0)|0;if((p|0)<0){q=p}else{break}i=b;return q|0}}while(0);o=m+44|0;c[o>>2]=4096;Yy(c[l>>2]|0,843925062);Zy(c[l>>2]|0,c[o>>2]|0);ez(c[l>>2]|0,0,0);if((Mz(l)|0)<0){q=-12;i=b;return q|0}p=a+24|0;Zy(c[l>>2]|0,c[p>>2]|0);r=c[p>>2]|0;if((r|0)==0){s=0}else{t=c[a+28>>2]|0;u=0;v=0;while(1){w=(c[(c[(c[t+(v<<2)>>2]|0)+8>>2]|0)+72>>2]|0)+u|0;x=v+1|0;if(x>>>0<r>>>0){u=w;v=x}else{s=w;break}}}Zy(c[l>>2]|0,s);s=c[n>>2]|0;v=Oz(c[l>>2]|0,j)|0;Zy(s,1296124238);Zy(s,v);Ry(s,c[j>>2]|0,v);ZDb(c[j>>2]|0);a:do{if((c[p>>2]|0)!=0){j=a+28|0;v=0;while(1){s=c[(c[j>>2]|0)+(v<<2)>>2]|0;MT(s,64,1,1e6);if((Mz(l)|0)<0){q=-12;y=22;break}u=c[s+8>>2]|0;Zy(c[l>>2]|0,c[u+48>>2]|0);s=u+8|0;Py(c[l>>2]|0,c[s>>2]|0);Zy(c[l>>2]|0,c[u+72>>2]|0);r=u+88|0;Zy(c[l>>2]|0,c[r>>2]|0);Zy(c[l>>2]|0,c[u+92>>2]|0);Zy(c[l>>2]|0,c[u+688>>2]|0);if((c[r>>2]&4194304|0)!=0){r=u+100|0;Zy(c[l>>2]|0,c[r>>2]|0);Ry(c[l>>2]|0,c[u+96>>2]|0,c[r>>2]|0)}r=c[n>>2]|0;t=Oz(c[l>>2]|0,f)|0;Zy(r,1129270605);Zy(r,t);Ry(r,c[f>>2]|0,t);ZDb(c[f>>2]|0);if((Mz(l)|0)<0){q=-12;y=22;break}t=c[s>>2]|0;if((t|0)==1){Zy(c[l>>2]|0,c[u+412>>2]|0);az(c[l>>2]|0,c[u+416>>2]|0);az(c[l>>2]|0,c[u+424>>2]|0);s=c[n>>2]|0;r=Oz(c[l>>2]|0,d)|0;Zy(s,1398030677);Zy(s,r);Ry(s,c[d>>2]|0,r);ZDb(c[d>>2]|0)}else if((t|0)==0){Zy(c[l>>2]|0,c[u+104>>2]|0);Zy(c[l>>2]|0,c[u+108>>2]|0);fz(c[l>>2]|0,c[u+120>>2]|0);fz(c[l>>2]|0,c[u+124>>2]|0);fz(c[l>>2]|0,c[u+136>>2]|0);Zy(c[l>>2]|0,c[u+140>>2]|0);Py(c[l>>2]|0,c[u+500>>2]|0);Py(c[l>>2]|0,c[u+504>>2]|0);t=u+508|0;Py(c[l>>2]|0,c[t>>2]|0);r=u+492|0;fz(c[l>>2]|0,~~(+g[r>>2]*1.0e4));s=u+496|0;fz(c[l>>2]|0,~~(+g[s>>2]*1.0e4));Zy(c[l>>2]|0,c[u+76>>2]|0);w=c[u+536>>2]|0;_y(c[l>>2]|0,(w|0)==0?2081680:w)|0;Zy(c[l>>2]|0,c[u+540>>2]|0);Zy(c[l>>2]|0,c[u+544>>2]|0);Zy(c[l>>2]|0,c[u+524>>2]|0);h[k>>3]=+g[u+184>>2];ez(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);h[k>>3]=+g[u+160>>2];ez(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);h[k>>3]=+g[u+188>>2];ez(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);h[k>>3]=+g[u+172>>2];ez(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);Zy(c[l>>2]|0,c[u+784>>2]|0);Zy(c[l>>2]|0,c[u+680>>2]|0);Zy(c[l>>2]|0,c[u+156>>2]|0);Zy(c[l>>2]|0,c[u+180>>2]|0);Zy(c[l>>2]|0,c[u+324>>2]|0);Zy(c[l>>2]|0,c[u+144>>2]|0);Zy(c[l>>2]|0,c[u+296>>2]|0);Zy(c[l>>2]|0,c[u+836>>2]|0);Zy(c[l>>2]|0,c[u+596>>2]|0);h[k>>3]=+g[u+548>>2];ez(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);Zy(c[l>>2]|0,c[u+52>>2]|0);Py(c[l>>2]|0,c[u+808>>2]|0);Zy(c[l>>2]|0,c[u+568>>2]|0);Zy(c[l>>2]|0,c[u+232>>2]|0);Zy(c[l>>2]|0,c[u+268>>2]|0);Zy(c[l>>2]|0,c[u+276>>2]|0);Zy(c[l>>2]|0,c[u+360>>2]|0);Zy(c[l>>2]|0,c[u+308>>2]|0);Zy(c[l>>2]|0,c[u+168>>2]|0);h[k>>3]=+g[r>>2];ez(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);h[k>>3]=+g[s>>2];ez(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);Zy(c[l>>2]|0,c[t>>2]|0);Zy(c[l>>2]|0,c[u+364>>2]|0);u=c[n>>2]|0;t=Oz(c[l>>2]|0,e)|0;Zy(u,1398036041);Zy(u,t);Ry(u,c[e>>2]|0,t);ZDb(c[e>>2]|0)}else{q=-1;y=22;break}v=v+1|0;if(!(v>>>0<(c[p>>2]|0)>>>0)){break a}}if((y|0)==22){i=b;return q|0}}}while(0);y=c[n>>2]|0;c[l>>2]=y;ez(y,0,0);y=Ty(c[l>>2]|0,0,0,1)|0;n=c[o>>2]|0;p=fHb(y,F,n,(n|0)<0|0?-1:0)|0;n=c[l>>2]|0;if((p|0)==0&(F|0)==0){z=n}else{p=n;while(1){Py(p,0);n=Ty(c[l>>2]|0,0,0,1)|0;y=c[o>>2]|0;e=fHb(n,F,y,(y|0)<0|0?-1:0)|0;y=c[l>>2]|0;if((e|0)==0&(F|0)==0){z=y;break}else{p=y}}}Sy(z);c[m+64>>2]=m+72;z=(c[o>>2]|0)+58|0;c[m+68>>2]=m+z;if((z|0)<=71){yDb(0,0,2031216,(z=i,i=i+24|0,c[z>>2]=1986992,c[z+8>>2]=1954336,c[z+16>>2]=224,z)|0);i=z;Cd();return 0}c[m+48>>2]=0;z=m+56|0;c[z>>2]=0;c[z+4>>2]=0;c[m+40>>2]=1;q=0;i=b;return q|0}function $B(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;e=i;i=i+24|0;f=e|0;g=b+12|0;h=c[g>>2]|0;j=h+4168|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=d+16|0;m=c[j>>2]|0;n=c[j+4>>2]|0;j=YGb(m,n,k,l)|0;o=F;p=f|0;a[p]=c[d+32>>2];q=f+1|0;a[q]=0;if((c[d+36>>2]&1|0)==0){r=2}else{a[q]=1;r=3}s=d+28|0;t=c[s>>2]|0;a[f+4|0]=t;a[f+3|0]=t>>>8;a[f+2|0]=t>>>16;t=c[d+48>>2]|0;a[f+7|0]=t;a[f+6|0]=t>>>8;a[f+5|0]=t>>>16;t=d+8|0;u=c[t>>2]|0;v=c[t+4>>2]|0;t=YGb(u,v,k,l)|0;l=F;k=fe(t|0)|0;t=f+8|0;w=t|0;x=fe(l|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;w=t+4|0;x=k|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;if((u|0)==(m|0)&(v|0)==(n|0)){y=16}else{a[q]=r;r=ZGb(u,v,m,n)|0;n=f+16|0;x=fe(r|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;y=20}n=h+48|0;r=h+64|0;if((c[n>>2]|0)==0){c[n>>2]=14-(h+72)+(c[r>>2]|0);n=h+56|0;c[n>>2]=j;c[n+4>>2]=o}o=h+68|0;h=b+16|0;b=y;y=p;while(1){p=c[r>>2]|0;n=(c[o>>2]|0)-p|0;j=(n|0)>(b|0)?b:n;UGb(p|0,y|0,j)|0;p=(c[r>>2]|0)+j|0;c[r>>2]=p;n=b-j|0;if(!(p>>>0<(c[o>>2]|0)>>>0)){p=c[g>>2]|0;f=c[h>>2]|0;m=p+68|0;v=p+64|0;u=c[v>>2]|0;q=(c[m>>2]|0)-u|0;TGb(u|0,0,q|0)|0;fz(f,26221);fz(f,q);q=p+56|0;ez(f,c[q>>2]|0,c[q+4>>2]|0);q=p+48|0;u=c[q>>2]|0;w=p+40|0;fz(f,(c[w>>2]|0)==0?u:u|32768);u=p+72|0;Ry(f,u,(c[m>>2]|0)-u|0);Sy(f);c[q>>2]=0;c[v>>2]=u;c[w>>2]=0}if((n|0)>0){b=n;y=y+j|0}else{break}}y=c[s>>2]|0;s=c[g>>2]|0;if((y|0)<=0){i=e;return 0}b=s+68|0;o=s+64|0;s=y;y=c[d+24>>2]|0;while(1){d=c[o>>2]|0;r=(c[b>>2]|0)-d|0;j=(r|0)>(s|0)?s:r;UGb(d|0,y|0,j)|0;d=(c[o>>2]|0)+j|0;c[o>>2]=d;r=s-j|0;if(!(d>>>0<(c[b>>2]|0)>>>0)){d=c[g>>2]|0;n=c[h>>2]|0;w=d+68|0;u=d+64|0;v=c[u>>2]|0;q=(c[w>>2]|0)-v|0;TGb(v|0,0,q|0)|0;fz(n,26221);fz(n,q);q=d+56|0;ez(n,c[q>>2]|0,c[q+4>>2]|0);q=d+48|0;v=c[q>>2]|0;f=d+40|0;fz(n,(c[f>>2]|0)==0?v:v|32768);v=d+72|0;Ry(n,v,(c[w>>2]|0)-v|0);Sy(n);c[q>>2]=0;c[u>>2]=v;c[f>>2]=0}if((r|0)>0){s=r;y=y+j|0}else{break}}i=e;return 0}function aC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=b+64|0;e=c[d>>2]|0;f=b+72|0;if(!(e>>>0>f>>>0)){return 0}g=c[a+16>>2]|0;a=b+68|0;h=(c[a>>2]|0)-e|0;TGb(e|0,0,h|0)|0;fz(g,26221);fz(g,h);h=b+56|0;ez(g,c[h>>2]|0,c[h+4>>2]|0);h=b+48|0;e=c[h>>2]|0;i=b+40|0;fz(g,(c[i>>2]|0)==0?e:e|32768);Ry(g,f,(c[a>>2]|0)-f|0);Sy(g);c[h>>2]=0;c[d>>2]=f;c[i>>2]=0;return 0}function bC(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,1884880,11)|0)==0;return(b?100:0)|0}function cC(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=i;i=i+1312|0;e=d|0;f=d+256|0;g=d+264|0;h=d+272|0;j=d+280|0;k=d+1304|0;l=b+16|0;a:do{if((Xy(c[l>>2]|0)|0)==0){m=j|0;n=j;o=e|0;p=h;q=p+4|0;r=b;s=b+1132|0;t=b+1136|0;u=b+1140|0;while(1){while(1){v=c[l>>2]|0;w=0;b:while(1){x=lz(v)|0;y=x&255;do{if(!(y<<24>>24==0)){z=x&255;if((z|0)==92){if((w|0)<1023){a[j+w|0]=y;A=w+1|0}else{A=w}B=A;C=(lz(v)|0)&255}else if((z|0)==10){break}else{B=w;C=y}if((B|0)>=1023){w=B;continue b}a[j+B|0]=C;w=B+1|0;continue b}}while(0);a[j+w|0]=0;if((Xy(v)|0)!=0){break}y=a[m]|0;if((y<<24>>24|0)==59|(y<<24>>24|0)==35|(y<<24>>24|0)==0){w=0}else{break}}if((PGb(m,2148864,8)|0)==0){D=16;break}if((PGb(m,2081656,9)|0)==0){D=19;break}else{E=m}while(1){w=a[E]|0;if((w<<24>>24|0)==61){D=64;break}else if((w<<24>>24|0)==92){v=E+1|0;G=v;H=a[v]|0}else{G=E;H=w}if(H<<24>>24==0){break}E=G+1|0}do{if((D|0)==64){D=0;w=E-n|0;v=WDb(w+1|0)|0;if((v|0)==0){break}y=j+w|0;if((w|0)>0){w=v;x=m;while(1){z=(a[x]|0)==92?x+1|0:x;I=z+1|0;J=w+1|0;a[w]=a[z]|0;if(I>>>0<y>>>0){w=J;x=I}else{break}}a[J]=0}else{a[v]=0}x=E+1|0;w=SGb(x|0)|0;y=w+1|0;I=WDb(y)|0;if((I|0)==0){ZDb(v);break}z=E+y|0;if((w|0)>0){w=I;y=x;while(1){x=(a[y]|0)==92?y+1|0:y;K=x+1|0;L=w+1|0;a[w]=a[x]|0;if(K>>>0<z>>>0){w=L;y=K}else{break}}a[L]=0}else{a[I]=0}CBb(u,v,I,12)|0}}while(0);if((Xy(c[l>>2]|0)|0)!=0){M=s;break a}}if((D|0)==16){D=0;y=LT(b,0)|0;if((y|0)==0){N=-12;D=79;break}w=c[y+8>>2]|0;c[w+8>>2]=2;c[w+48>>2]=135168;O=y+88|0}else if((D|0)==19){D=0;c[h>>2]=1;c[h+4>>2]=1e9;y=c[l>>2]|0;w=0;c:while(1){z=lz(y)|0;K=z&255;do{if(!(K<<24>>24==0)){x=z&255;if((x|0)==92){if((w|0)<255){a[e+w|0]=K;P=w+1|0}else{P=w}Q=P;R=(lz(y)|0)&255}else if((x|0)==10){break}else{Q=w;R=K}if((Q|0)>=255){w=Q;continue c}a[e+Q|0]=R;w=Q+1|0;continue c}}while(0);a[e+w|0]=0;if((Xy(y)|0)!=0){break}K=a[o]|0;if((K<<24>>24|0)==59|(K<<24>>24|0)==35|(K<<24>>24|0)==0){w=0}else{break}}w=xd(o|0,2031200,(y=i,i=i+16|0,c[y>>2]=h,c[y+8>>2]=q,y)|0)|0;i=y;d:do{if((w|0)!=0){K=c[l>>2]|0;z=0;e:while(1){x=lz(K)|0;S=x&255;do{if(!(S<<24>>24==0)){T=x&255;if((T|0)==10){break}else if((T|0)==92){if((z|0)<255){a[e+z|0]=S;U=z+1|0}else{U=z}V=U;W=(lz(K)|0)&255}else{V=z;W=S}if((V|0)>=255){z=V;continue e}a[e+V|0]=W;z=V+1|0;continue e}}while(0);a[e+z|0]=0;if((Xy(K)|0)!=0){break d}S=a[o]|0;if((S<<24>>24|0)==59|(S<<24>>24|0)==35|(S<<24>>24|0)==0){z=0}else{break}}}}while(0);w=xd(o|0,1986976,(y=i,i=i+8|0,c[y>>2]=f,y)|0)|0;i=y;f:do{if((w|0)==0){yDb(r,16,1954288,(y=i,i=i+8|0,c[y>>2]=o,y)|0);i=y;z=c[s>>2]|0;if((z|0)==0){X=0;Y=0}else{K=(c[(c[t>>2]|0)+(z-1<<2)>>2]|0)+24|0;z=c[K>>2]|0;S=c[K+4>>2]|0;K=(z|0)==0&(S|0)==(-2147483648|0);X=K?0:S;Y=K?0:z}c[f>>2]=Y;c[f+4>>2]=X}else{z=c[l>>2]|0;K=0;g:while(1){S=lz(z)|0;x=S&255;do{if(!(x<<24>>24==0)){I=S&255;if((I|0)==10){break}else if((I|0)==92){if((K|0)<255){a[e+K|0]=x;Z=K+1|0}else{Z=K}_=Z;$=(lz(z)|0)&255}else{_=K;$=x}if((_|0)>=255){K=_;continue g}a[e+_|0]=$;K=_+1|0;continue g}}while(0);a[e+K|0]=0;if((Xy(z)|0)!=0){break f}x=a[o]|0;if((x<<24>>24|0)==59|(x<<24>>24|0)==35|(x<<24>>24|0)==0){K=0}else{break}}}}while(0);w=xd(o|0,1927584,(y=i,i=i+8|0,c[y>>2]=g,y)|0)|0;i=y;if((w|0)==0){yDb(r,16,1905576,(y=i,i=i+8|0,c[y>>2]=o,y)|0);i=y;c[g>>2]=0;c[g+4>>2]=-2147483648;aa=-2147483648;ba=0}else{aa=c[g+4>>2]|0;ba=c[g>>2]|0}w=OT(b,c[s>>2]|0,p,c[f>>2]|0,c[f+4>>2]|0,ba,aa,0)|0;if((w|0)==0){N=-12;D=79;break}O=w+32|0}if((Xy(c[l>>2]|0)|0)==0){u=O}else{M=s;break a}}if((D|0)==79){i=d;return N|0}}else{M=b+1132|0}}while(0);D=b+1056|0;c[D>>2]=0;c[D+4>>2]=0;D=c[M>>2]|0;if((D|0)==0){N=0;i=d;return N|0}M=c[(c[b+1136>>2]|0)+(D-1<<2)>>2]|0;D=M+24|0;O=c[D>>2]|0;l=c[D+4>>2]|0;c[k>>2]=1;c[k+4>>2]=1e6;D=KDb(O,l,M+4|0,k)|0;k=b+1064|0;c[k>>2]=D;c[k+4>>2]=F;N=0;i=d;return N|0}function dC(a,b){a=a|0;b=b|0;return-541478725|0}function eC(a){a=a|0;var b=0;b=a+16|0;Ry(c[b>>2]|0,1884840,11);Py(c[b>>2]|0,49);Py(c[b>>2]|0,10);Sy(c[b>>2]|0);return 0}function fC(a,b){a=a|0;b=b|0;return 0}function gC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+16|0;hC(c[d>>2]|0,c[a+1140>>2]|0);e=a+24|0;if((c[e>>2]|0)!=0){f=a+28|0;g=0;do{Ry(c[d>>2]|0,2081616,8);Py(c[d>>2]|0,10);hC(c[d>>2]|0,c[(c[(c[f>>2]|0)+(g<<2)>>2]|0)+88>>2]|0);g=g+1|0;}while(g>>>0<(c[e>>2]|0)>>>0)}e=a+1132|0;if((c[e>>2]|0)==0){i=b;return 0}g=a+1136|0;a=0;do{f=c[(c[g>>2]|0)+(a<<2)>>2]|0;Ry(c[d>>2]|0,2031184,9);Py(c[d>>2]|0,10);h=c[f+8>>2]|0;Kz(c[d>>2]|0,1986912,(j=i,i=i+16|0,c[j>>2]=c[f+4>>2],c[j+8>>2]=h,j)|0)|0;i=j;h=f+16|0;k=c[h+4>>2]|0;Kz(c[d>>2]|0,1954248,(j=i,i=i+16|0,c[j>>2]=c[h>>2],c[j+8>>2]=k,j)|0)|0;i=j;k=f+24|0;h=c[k+4>>2]|0;Kz(c[d>>2]|0,1927536,(j=i,i=i+16|0,c[j>>2]=c[k>>2],c[j+8>>2]=h,j)|0)|0;i=j;hC(c[d>>2]|0,c[f+32>>2]|0);a=a+1|0;}while(a>>>0<(c[e>>2]|0)>>>0);i=b;return 0}function hC(a,b){a=a|0;b=b|0;var d=0,e=0;d=BBb(b,9203032,0,2)|0;if((d|0)==0){return}else{e=d}do{iC(a,c[e>>2]|0);Py(a,61);iC(a,c[e+4>>2]|0);Py(a,10);e=BBb(b,9203032,e,2)|0;}while((e|0)!=0);return}function iC(b,c){b=b|0;c=c|0;var d=0,e=0;d=c;a:while(1){c=a[d]|0;switch(c<<24>>24){case 0:{break a;break};case 35:case 59:case 61:case 92:case 10:{Py(b,92);e=a[d]|0;break};default:{e=c}}Py(b,e&255);d=d+1|0}return}function jC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+88|0;f=e|0;g=e+8|0;c[f>>2]=b;h=c[a+8>>2]|0;qAb(b,2252056,f)|0;b=(d&2|0)!=0;do{if((d&1|0)==0|b^1){if(!b){j=0;break}j=(c[h+8>>2]|0)==0?65:577}else{j=(c[h+8>>2]|0)==0?66:578}}while(0);b=cCb(c[f>>2]|0,j,(j=i,i=i+8|0,c[j>>2]=438,j)|0)|0;i=j;if((b|0)==-1){k=-(c[(ld()|0)>>2]|0)|0;i=e;return k|0}c[h+4>>2]=b;if((od(b|0,g|0)|0)==0){l=(c[g+12>>2]&61440|0)==4096|0}else{l=0}c[a+24>>2]=l;k=0;i=e;return k|0}function kC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=c[a+8>>2]|0;a=c[e+12>>2]|0;f=wb(c[e+4>>2]|0,b|0,((a|0)<(d|0)?a:d)|0)|0;if(!((f|0)==-1)){g=f;return g|0}g=-(c[(ld()|0)>>2]|0)|0;return g|0}function lC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=c[a+8>>2]|0;a=c[e+12>>2]|0;f=Pd(c[e+4>>2]|0,b|0,((a|0)<(d|0)?a:d)|0)|0;if(!((f|0)==-1)){g=f;return g|0}g=-(c[(ld()|0)>>2]|0)|0;return g|0}function mC(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;d=i;i=i+80|0;f=d|0;g=c[(c[a+8>>2]|0)+4>>2]|0;do{if((e|0)==65536){if((od(g|0,f|0)|0)<0){h=-(c[(ld()|0)>>2]|0)|0;break}if((c[f+12>>2]&61440|0)==4096){h=0;break}h=c[f+36>>2]|0}else{a=cb(g|0,b|0,e|0)|0;if((a|0)>=0){h=a;break}h=-(c[(ld()|0)>>2]|0)|0}}while(0);i=d;return(F=(h|0)<0|0?-1:0,h)|0}function nC(a){a=a|0;return Ub(c[(c[a+8>>2]|0)+4>>2]|0)|0}function oC(a){a=a|0;return c[(c[a+8>>2]|0)+4>>2]|0}function pC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;c[e>>2]=f;qAb(f,2252056,e)|0;if((_b(c[e>>2]|0,0)|0)<0){g=-(c[(ld()|0)>>2]|0)|0;i=d;return g|0}if((b&1|0)==0){h=0}else{h=(_b(c[e>>2]|0,4)|0)>>>31^1}if((b&2|0)==0){g=h;i=d;return g|0}else{g=(_b(c[e>>2]|0,2)|0)>-1;i=d;return(g?h|2:h)|0}return 0}function qC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((c[e+88>>2]|0)==0){f=-5;i=b;return f|0}g=Wy(e)|0;h=YGb(g,F,-36,-1)|0;Ty(e,h,F,0)|0;if((vz(e)|0)!=1382116964){yDb(a,16,2081408,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;f=-1094995529;i=b;return f|0}h=LT(a,0)|0;if((h|0)==0){f=-12;i=b;return f|0}g=h+64|0;c[g>>2]=vz(e)|0;c[g+4>>2]=0;if((tz(e)|0)==0){Vy(e,2,0)|0;g=h+8|0;k=c[g>>2]|0;c[k+8>>2]=0;c[k+48>>2]=14;c[k+140>>2]=28;c[k+52>>2]=0;k=tz(e)|0;c[(c[g>>2]|0)+120>>2]=k;k=tz(e)|0;c[(c[g>>2]|0)+124>>2]=k;c[d>>2]=tz(e)|0;MT(h,64,1,tz(e)|0);Ty(e,0,0,0)|0;f=0;i=b;return f|0}else{DDb(a,2031064,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;f=-1163346256;i=b;return f|0}return 0}function rC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+12>>2]|0;e=c[c[a+28>>2]>>2]|0;f=a+16|0;if((Xy(c[f>>2]|0)|0)!=0){g=-5;return g|0}a=Ty(c[f>>2]|0,0,0,1)|0;h=e+8|0;e=c[h>>2]|0;i=c[e+124>>2]|0;j=d;d=c[e+120>>2]<<2;e=ba(d,(c[j>>2]|0)+i|0)|0;k=eHb(a,F,e,(e|0)<0|0?-1:0)|0;e=b+16|0;c[e>>2]=k;c[e+4>>2]=F;e=b+28|0;c[e>>2]=TS(c[f>>2]|0,b,ba(d,i)|0)|0;i=ba(c[(c[h>>2]|0)+120>>2]<<2,c[j>>2]|0)|0;Vy(c[f>>2]|0,i,(i|0)<0|0?-1:0)|0;i=c[e>>2]|0;if((i|0)<0){g=i;return g|0}i=b+36|0;c[i>>2]=c[i>>2]|1;g=0;return g|0}function sC(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;f=c[a+16>>2]|0;g=0;h=(e|0)>(g|0)|(e|0)==(g|0)&d>>>0>0>>>0;g=c[(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+8>>2]|0;b=c[g+120>>2]|0;a=c[g+124>>2]|0;g=gHb(h?d<<2|0>>>30:0,h?e<<2|d>>>30:0,b,(b|0)<0|0?-1:0)|0;b=gHb(g,F,a,(a|0)<0|0?-1:0)|0;Ty(f,b,F,0)|0;b=F;((b|0)<0|0?-1:0)>>31|((b|0)<0|0?-1:0)<<1;return b>>31|((b|0)<0|0?-1:0)<<1|0}function tC(a){a=a|0;var b=0,d=0;b=i;if((c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+140>>2]|0)==28){d=0;i=b;return d|0}yDb(a,16,2081360,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;d=-1094995529;i=b;return d|0}function uC(a,b){a=a|0;b=b|0;var d=0;d=c[a+12>>2]|0;Ry(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);b=d;c[b>>2]=(c[b>>2]|0)+1;return 0}function vC(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=c[c[a+28>>2]>>2]|0;Zy(d,1382116964);Zy(d,c[b>>2]|0);fz(d,0);fz(d,0);b=e+8|0;fz(d,c[(c[b>>2]|0)+120>>2]|0);fz(d,c[(c[b>>2]|0)+124>>2]|0);fz(d,0);e=c[b>>2]|0;fz(d,(c[e+108>>2]|0)/(c[e+104>>2]|0)|0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);Py(d,0);return 0}function wC(a){a=a|0;var b=0;if((c[a+8>>2]|0)<4){return 0}else{b=(PGb(c[a+4>>2]|0,2031048,4)|0)==0;return(b?50:0)|0}return 0}function xC(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=i;i=i+88|0;f=e|0;g=e+8|0;h=e+16|0;j=e+32|0;k=e+40|0;l=e+72|0;c[f>>2]=0;c[j>>2]=0;m=LT(b,0)|0;if((m|0)==0){n=-12;i=e;return n|0}o=m+8|0;p=c[o>>2]|0;c[p+8>>2]=1;c[p+48>>2]=86028;c[m+236>>2]=1463898624;p=b+16|0;q=(rz(c[p>>2]|0)|0)==1130450022;r=c[p>>2]|0;if(!q){Ty(r,-4,-1,1)|0;n=0;i=e;return n|0}if((Xy(r)|0)!=0){n=0;i=e;return n|0}r=e+24|0;q=b+1140|0;s=b;t=j;u=l|0;v=l+12|0;l=m+40|0;w=k|0;x=k+24|0;y=m+56|0;z=1;a:while(1){while(1){if((c[f>>2]|0)!=0){n=0;A=36;break a}mz(c[p>>2]|0,r,4)|0;Y9(r,f,g,h);B=c[g>>2]|0;if((B|0)==0|(B|0)==5|(B|0)==6|(B|0)==4){B=cEb((c[h>>2]|0)+16|0)|0;c[j>>2]=B;if((B|0)==0){n=-12;A=36;break a}C=mz(c[p>>2]|0,B,c[h>>2]|0)|0;if((C|0)!=(c[h>>2]|0)){D=-5;A=34;break a}}else{C=c[h>>2]|0;B=Vy(c[p>>2]|0,C,(C|0)<0|0?-1:0)|0;C=B;if((C|0)<0){n=C;A=36;break a}}C=c[g>>2]|0;if((C|0)==5){B=c[h>>2]|0;if((B|0)<431){D=-1094995529;A=34;break a}E=c[j>>2]|0;F=(d[E+395|0]|0)-1|0;if((F|0)<1){D=-1094995529;A=34;break a}else{G=E+396|0;H=1;I=E;J=B}while(1){if((G+36-I|0)>(J|0)){K=-1094995529;L=I;break a}B=G;E=B|0;M=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=B+4|0;B=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=a[G+8|0]|0;UGb(u|0,G+9|0,12)|0;a[v]=0;N=a[G+35|0]|0;if(N<<24>>24==0){K=-1094995529;L=I;break a}O=fe(M|0)|0;OT(b,E&255,l,fe(B|0)|0,O|0,0,-2147483648,u)|0;if((H|0)>=(F|0)){break}G=G+(((N&255)*12|0)+36)|0;H=H+1|0;I=c[j>>2]|0;J=c[h>>2]|0}$Db(t)}else if((C|0)==6){P=fX(b,c[j>>2]|0,c[h>>2]|0)|0;$Db(t);if((P|0)<0){A=28;break a}}else if((C|0)==0){break}else{if(z){D=-1094995529;A=34;break a}do{if((C|0)==4){if((eN(b,q,c[j>>2]|0,c[h>>2]|0)|0)==0){break}yDb(s,24,2081320,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q}}while(0);$Db(t)}if((Xy(c[p>>2]|0)|0)!=0){n=0;A=36;break a}}if(!z){D=-1094995529;A=34;break}if((c[h>>2]|0)!=34){D=-1094995529;A=34;break}c[(c[o>>2]|0)+96>>2]=c[j>>2];c[(c[o>>2]|0)+100>>2]=34;c[j>>2]=0;C=c[o>>2]|0;X9(C,k,c[C+96>>2]|0);C=c[w>>2]|0;do{if((C|0)>0){MT(m,64,1,C);F=c[x>>2]|0;N=c[x+4>>2]|0;O=0;if(!((N|0)>(O|0)|(N|0)==(O|0)&F>>>0>0>>>0)){break}c[y>>2]=F;c[y+4>>2]=N}}while(0);if((Xy(c[p>>2]|0)|0)==0){z=0}else{n=0;A=36;break}}if((A|0)==28){yDb(s,16,2148640,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;n=P;i=e;return n|0}else if((A|0)==34){K=D;L=c[j>>2]|0}else if((A|0)==36){i=e;return n|0}ZDb(L);n=K;i=e;return n|0}function yC(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[b+1316>>2]|0;j=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;if((c[(c[b+12>>2]|0)+4>>2]|0)==0){k=0;i=d;return k|0}if((c[b+24>>2]|0)>>>0>1>>>0){yDb(b,16,2031016,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;k=-22;i=d;return k|0}if((c[j+48>>2]|0)!=86028){yDb(b,16,1986744,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;k=-22;i=d;return k|0}l=(h|0)<0?8192:h;h=(l|0)>16777215?16777215:l;l=b+16|0;m=BC(c[l>>2]|0,j,0)|0;if((m|0)!=0){k=m;i=d;return k|0}m=c[l>>2]|0;n=b+1140|0;b=(h|0)!=0;o=(c[j+88>>2]&8388608|0)!=0?1954208:1927512;QG(n,1087448,0);j=FU(c[n>>2]|0,o,e)|0;p=j+4|0;q=WDb(p)|0;c[g>>2]=q;if((q|0)==0){r=-12}else{a[q]=b?4:-124;a[q+3|0]=j;a[q+2|0]=j>>>8;a[q+1|0]=j>>>16;c[f>>2]=q+4;GU(f,n,o,c[e>>2]|0)|0;Ry(m,q,p);$Db(g);c[f>>2]=0;r=0}if((r|0)!=0|b^1){k=r;i=d;return k|0}r=c[l>>2]|0;Py(r,129);hz(r,h);Qy(r,0,h);k=0;i=d;return k|0}function zC(a,b){a=a|0;b=b|0;Ry(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function AC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+16|0;d=b|0;e=c[a+16>>2]|0;if((c[(c[a+12>>2]|0)+4>>2]|0)==0){f=0;i=b;return f|0}if((V9(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0,b+8|0,d)|0)==0){f=-1;i=b;return f|0}if((c[e+88>>2]|0)==0){yDb(a,24,2081288,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=0;i=b;return f|0}else{a=Ty(e,0,0,1)|0;g=F;Ty(e,8,0,0)|0;Ry(e,c[d>>2]|0,34);Ty(e,a,g,0)|0;Sy(e);f=0;i=b;return f|0}return 0}function BC(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+8|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;c[g>>2]=1130450022;c[g+4>>2]=570425344;a[g+4|0]=(e|0)!=0?-128:0;if((V9(d,j,h)|0)==0){k=-1;i=f;return k|0}Ry(b,g,8);Ry(b,c[h>>2]|0,34);k=0;i=f;return k|0}function CC(a){a=a|0;var b=0,e=0,f=0;if((c[a+8>>2]|0)<128){return 0}b=c[a+4>>2]|0;a=b+4|0;e=(d[a]|d[a+1|0]<<8)<<16>>16;if((e+20719&65535)>>>0>1>>>0&e<<16>>16!=-20668){return 0}e=b+16|0;a=e;do{if(!((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==-3590)){f=e;if(!((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)>>>0>2e3>>>0)){break}return 0}}while(0);e=b+8|0;if(((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>0>4096>>>0){return 0}else{e=b+10|0;return(((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>0>4096>>>0?0:99)|0}return 0}function DC(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+136|0;f=e|0;g=e+128|0;h=c[a+12>>2]|0;j=c[a+16>>2]|0;c[h+8>>2]=0;k=f|0;if((mz(j,k,128)|0)!=128){l=-5;i=e;return l|0}m=f+4|0;n=(d[m]|d[m+1|0]<<8)<<16>>16;m=f+16|0;o=m;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(p|0)==0?5:p;p=LT(a,0)|0;if((p|0)==0){l=-12;i=e;return l|0}c[h>>2]=c[p>>2];q=p+8|0;r=c[q>>2]|0;c[r+8>>2]=0;c[r+48>>2]=51;c[r+52>>2]=0;s=f+8|0;t=(d[s]|d[s+1|0]<<8)<<16>>16;c[r+120>>2]=t&65535;s=f+10|0;f=(d[s]|d[s+1|0]<<8)<<16>>16;c[r+124>>2]=f&65535;if(t<<16>>16==0|f<<16>>16==0){yDb(a,24,2148448,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;f=c[q>>2]|0;c[f+120>>2]=640;c[f+124>>2]=480;v=f}else{v=r}if((BT(v,128)|0)!=0){l=-12;i=e;return l|0}UGb(c[(c[q>>2]|0)+96>>2]|0,k|0,128)|0;if((mz(j,g|0,6)|0)!=6){yDb(a,16,2081208,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;l=-5;i=e;return l|0}Ty(j,-6,-1,1)|0;if((b[g+4>>1]|0)==-21846){v=LT(a,0)|0;if((v|0)==0){l=-12;i=e;return l|0}c[h+4>>2]=c[v>>2];h=c[g>>2]|0;g=c[v+8>>2]|0;c[g+432>>2]=h;c[g+8>>2]=1;c[g+48>>2]=65541;c[g+52>>2]=0;c[g+412>>2]=22050;c[g+416>>2]=1;c[g+72>>2]=c[(c[q>>2]|0)+412>>2]<<3;c[g+792>>2]=8;r=g+448|0;c[r>>2]=4;c[r+4>>2]=0;c[g+100>>2]=0;MT(p,64,h,22050);MT(v,64,1,22050);l=0;i=e;return l|0}v=m;if((d[v]|d[v+1|0]<<8)<<16>>16<<16>>16==-3590){MT(p,64,5,70);Ty(j,12,0,0)|0;ZDb(c[(c[q>>2]|0)+96>>2]|0);if((BT(c[q>>2]|0,12)|0)!=0){l=-12;i=e;return l|0}UGb(c[(c[q>>2]|0)+96>>2]|0,k|0,12)|0;l=0;i=e;return l|0}if((n<<16>>16|0)==(-20719|0)){MT(p,64,o,70);l=0;i=e;return l|0}else if((n<<16>>16|0)==(-20668|0)|(n<<16>>16|0)==(-20718|0)){MT(p,64,o,1e3);l=0;i=e;return l|0}else{yDb(a,16,2030960,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;l=-1094995529;i=e;return l|0}return 0}function EC(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+8|0;g=f|0;h=c[d+12>>2]|0;j=c[d+16>>2]|0;d=g|0;k=g;l=g+4|0;g=h;m=e+32|0;n=h+8|0;o=e+8|0;p=e+64|0;q=e+24|0;r=h+4|0;while(1){if((mz(j,d,6)|0)!=6){s=-5;t=12;break}u=c[k>>2]|0;h=b[l>>1]|0;if((h<<16>>16|0)==(-2566|0)|(h<<16>>16|0)==(-3590|0)){if(u>>>0>6>>>0){t=6;break}}else if((h<<16>>16|0)==(-21846|0)){t=9;break}Vy(j,u-6|0,0)|0;}if((t|0)==6){if((wZ(e,u)|0)!=0){s=-5;i=f;return s|0}c[m>>2]=c[g>>2];g=c[n>>2]|0;c[n>>2]=g+1;c[o>>2]=g;c[o+4>>2]=(g|0)<0|0?-1:0;g=Ty(j,0,0,1)|0;c[p>>2]=g;c[p+4>>2]=F;g=c[q>>2]|0;a[g]=a[d]|0;a[g+1|0]=a[d+1|0]|0;a[g+2|0]=a[d+2|0]|0;a[g+3|0]=a[d+3|0]|0;a[g+4|0]=a[d+4|0]|0;a[g+5|0]=a[d+5|0]|0;d=u-6|0;if((mz(j,(c[q>>2]|0)+6|0,d)|0)==(d|0)){s=d;i=f;return s|0}BZ(e);s=-5;i=f;return s|0}else if((t|0)==9){if((wZ(e,u)|0)!=0){s=-5;i=f;return s|0}Vy(j,10,0)|0;c[m>>2]=c[r>>2];r=Ty(j,0,0,1)|0;c[p>>2]=r;c[p+4>>2]=F;if((mz(j,c[q>>2]|0,u)|0)==(u|0)){s=u;i=f;return s|0}BZ(e);s=-5;i=f;return s|0}else if((t|0)==12){i=f;return s|0}return 0}function FC(b){b=b|0;var e=0,f=0,g=0;e=c[b+4>>2]|0;do{if((a[e]|0)==70){if((a[e+1|0]|0)!=76){break}if((a[e+2|0]|0)!=86){break}if(!((d[e+3|0]|0)>>>0<5>>>0)){break}b=e+5|0;if((a[b]|0)!=0){break}f=b;if((fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)>>>0>8>>>0){g=100}else{break}return g|0}}while(0);g=0;return g|0}function GC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a+16|0;Vy(c[d>>2]|0,4,0)|0;e=lz(c[d>>2]|0)|0;if((e|0)==0){yDb(a,24,2085928,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;f=a+20|0;c[f>>2]=c[f>>2]|1;g=5;h=f;j=4}else{f=a+20|0;c[f>>2]=c[f>>2]|1;if((e&1|0)==0){k=e;l=f}else{g=e;h=f;j=4}}if((j|0)==4){f=LT(a,0)|0;if((f|0)==0){m=-12;i=b;return m|0}c[(c[f+8>>2]|0)+8>>2]=0;e=c[a+24>>2]|0;do{if(e>>>0>2>>>0){j=9}else{if((e|0)!=2){break}n=c[a+28>>2]|0;if((c[(c[(c[n>>2]|0)+8>>2]|0)+8>>2]|0)==2){break}if((c[(c[(c[n+4>>2]|0)+8>>2]|0)+8>>2]|0)!=2){j=9}}}while(0);if((j|0)==9){c[h>>2]=c[h>>2]&-2}MT(f,32,1,1e3);k=g;l=h}if((k&4|0)!=0){k=LT(a,0)|0;if((k|0)==0){m=-12;i=b;return m|0}c[(c[k+8>>2]|0)+8>>2]=1;h=c[a+24>>2]|0;do{if(h>>>0>2>>>0){j=17}else{if((h|0)!=2){break}g=c[a+28>>2]|0;if((c[(c[(c[g>>2]|0)+8>>2]|0)+8>>2]|0)==2){break}if((c[(c[(c[g+4>>2]|0)+8>>2]|0)+8>>2]|0)!=2){j=17}}}while(0);if((j|0)==17){c[l>>2]=c[l>>2]&-2}MT(k,32,1,1e3)}k=vz(c[d>>2]|0)|0;Ty(c[d>>2]|0,k,(k|0)<0|0?-1:0,0)|0;Vy(c[d>>2]|0,4,0)|0;d=a+1056|0;c[d>>2]=0;c[d+4>>2]=0;m=0;i=b;return m|0}function HC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;e=i;i=i+16|0;f=e|0;g=c[b+12>>2]|0;h=g;j=b+16|0;k=g+80|0;l=g+84|0;m=g+48|0;n=b;o=b+24|0;p=b+28|0;q=b+1112|0;r=b+1116|0;s=b+20|0;t=f|0;u=0;a:while(1){v=Ty(c[j>>2]|0,0,0,1)|0;w=F;x=lz(c[j>>2]|0)|0;y=uz(c[j>>2]|0)|0;z=uz(c[j>>2]|0)|0;A=(lz(c[j>>2]|0)|0)<<24;B=A|z;C=((A|0)<0|0?-1:0)|0;if((Xy(c[j>>2]|0)|0)!=0){D=-541478725;E=178;break}Vy(c[j>>2]|0,3,0)|0;A=c[k>>2]|0;do{if((A|0)<(c[l>>2]|0)){z=m+(A<<4)+8|0;G=c[z>>2]|0;H=c[z+4>>2]|0;if(!((v|0)==(G|0)&(w|0)==(H|0))){if(!((w|0)>(H|0)|(w|0)==(H|0)&v>>>0>G>>>0)){break}yDb(n,24,2090976,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;if((c[o>>2]|0)!=0){z=0;do{J=c[(c[p>>2]|0)+(z<<2)>>2]|0;K=J+404|0;L=c[K>>2]|0;if((L|0)>0){M=J+400|0;J=0;N=0;O=L;while(1){L=c[M>>2]|0;P=L+(J*24|0)|0;Q=P|0;R=c[Q+4>>2]|0;if((R|0)<(H|0)|(R|0)==(H|0)&(c[Q>>2]|0)>>>0<G>>>0){Q=L+(N*24|0)|0;L=P;c[Q>>2]=c[L>>2];c[Q+4>>2]=c[L+4>>2];c[Q+8>>2]=c[L+8>>2];c[Q+12>>2]=c[L+12>>2];c[Q+16>>2]=c[L+16>>2];c[Q+20>>2]=c[L+20>>2];S=N+1|0;T=c[K>>2]|0}else{S=N;T=O}L=J+1|0;if((L|0)<(T|0)){J=L;N=S;O=T}else{U=S;break}}}else{U=0}c[K>>2]=U;z=z+1|0;}while(z>>>0<(c[o>>2]|0)>>>0)}c[l>>2]=0;break}z=m+(A<<4)|0;G=ZGb(B,C,c[z>>2]|0,c[z+4>>2]|0)|0;z=F;H=-1;O=(z|0)>(H|0)|(z|0)==(H|0)&G>>>0>-1>>>0;H=ZGb(0,0,G,z)|0;N=O?z:F;z=0;if((N|0)<(z|0)|(N|0)==(z|0)&(O?G:H)>>>0<2501>>>0){c[k>>2]=A+1;break}yDb(n,24,2090976,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;if((c[o>>2]|0)!=0){H=0;do{G=c[(c[p>>2]|0)+(H<<2)>>2]|0;O=G+404|0;z=c[O>>2]|0;if((z|0)>0){N=G+400|0;G=0;J=0;M=z;while(1){z=c[N>>2]|0;L=z+(G*24|0)|0;Q=L|0;P=c[Q+4>>2]|0;if((P|0)<(w|0)|(P|0)==(w|0)&(c[Q>>2]|0)>>>0<v>>>0){Q=z+(J*24|0)|0;z=L;c[Q>>2]=c[z>>2];c[Q+4>>2]=c[z+4>>2];c[Q+8>>2]=c[z+8>>2];c[Q+12>>2]=c[z+12>>2];c[Q+16>>2]=c[z+16>>2];c[Q+20>>2]=c[z+20>>2];V=J+1|0;W=c[O>>2]|0}else{V=J;W=M}z=G+1|0;if((z|0)<(W|0)){G=z;J=V;M=W}else{X=V;break}}}else{X=0}c[O>>2]=X;H=H+1|0;}while(H>>>0<(c[o>>2]|0)>>>0)}c[l>>2]=0}}while(0);do{if((y|0)==0){Y=u}else{A=Ty(c[j>>2]|0,0,0,1)|0;H=YGb(A,F,y,(y|0)<0|0?-1:0)|0;A=F;b:do{if((x|0)==8){Z=y-1|0;_=lz(c[j>>2]|0)|0;$=1}else if((x|0)==18){if(!((y|0)>18&((B|0)==0&(C|0)==0))){Z=y;_=0;$=2;break}M=Ty(c[j>>2]|0,0,0,1)|0;J=F;G=c[j>>2]|0;do{if((lz(G)|0)==2){N=tz(G)|0;if((N|0)>=11){Vy(G,N,(N|0)<0|0?-1:0)|0;break}mz(G,t,N)|0;a[f+N|0]=0;if((N|0)<0){break}if((QGb(t,1884808)|0)==0){break}if((QGb(t,2342920)|0)!=0){break}N=c[o>>2]|0;if((N|0)==0){aa=0;ba=0}else{K=c[p>>2]|0;z=0;Q=0;L=0;while(1){P=c[K+(L<<2)>>2]|0;R=c[(c[P+8>>2]|0)+8>>2]|0;if((R|0)==1){ca=Q;da=P}else if((R|0)==0){ca=P;da=z}else{ca=Q;da=z}P=L+1|0;if(P>>>0<N>>>0){z=da;Q=ca;L=P}else{aa=da;ba=ca;break}}}if((KC(b,aa,ba,t,H,A,0)|0)>-1){E=44;break b}}}while(0);Ty(c[j>>2]|0,M,J,0)|0;Z=y;_=0;$=2}else if((x|0)==9){G=lz(c[j>>2]|0)|0;if((G&240|0)==80){E=44}else{Z=y-1|0;_=G;$=0}}else{yDb(n,48,2148392,(I=i,i=i+24|0,c[I>>2]=x,c[I+8>>2]=y,c[I+16>>2]=0,I)|0);i=I;E=44}}while(0);if((E|0)==44){E=0;Ty(c[j>>2]|0,H,A,0)|0;Y=u;break}if((Z|0)==0){Y=u;break}G=c[o>>2]|0;c:do{if((G|0)==0){ea=u;fa=0}else{O=c[p>>2]|0;L=_<<2&8;Q=L+8|0;z=_&240;N=z>>>4;K=(L|0)==0?65541:65536;L=_&15;if(($|0)==1){ga=0}else{P=0;while(1){R=c[O+(P<<2)>>2]|0;d:do{if(($|0)==0){ha=c[R+8>>2]|0;if((c[ha+8>>2]|0)!=0){break}if((c[q>>2]|0)!=0){ea=R;fa=P;break c}ia=c[ha+48>>2]|0;if((ia|0)==0){if((c[ha+52>>2]|0)==0){ea=R;fa=P;break c}}switch(L|0){case 3:{if((ia|0)==87){ea=R;fa=P;break c}else{break d}break};case 6:{if((ia|0)==132){ea=R;fa=P;break c}else{break d}break};case 4:{if((ia|0)==93){ea=R;fa=P;break c}else{break d}break};case 5:{if((ia|0)==107){ea=R;fa=P;break c}else{break d}break};case 7:{if((ia|0)==28){ea=R;fa=P;break c}else{break d}break};case 2:{if((ia|0)==22){ea=R;fa=P;break c}else{break d}break};default:{if((c[ha+52>>2]|0)==(L|0)){ea=R;fa=P;break c}else{break d}}}}else if(($|0)==2){if((c[(c[R+8>>2]|0)+8>>2]|0)==2){ea=R;fa=P;break c}}}while(0);ha=P+1|0;if(ha>>>0<G>>>0){P=ha}else{ea=R;fa=ha;break c}}}while(1){P=c[O+(ga<<2)>>2]|0;L=c[P+8>>2]|0;e:do{if((c[L+8>>2]|0)==1){if((c[r>>2]|0)!=0){ea=P;fa=ga;break c}J=c[L+48>>2]|0;if((J|0)==0){if((c[L+52>>2]|0)==0){ea=P;fa=ga;break c}}if((c[L+792>>2]|0)!=(Q|0)){break}switch(z|0){case 32:{if((J|0)==86017){ea=P;fa=ga;break c}else{break e}break};case 176:{if((J|0)==86052){ea=P;fa=ga;break c}else{break e}break};case 16:{if((J|0)==69645){ea=P;fa=ga;break c}else{break e}break};case 160:{if((J|0)==86018){ea=P;fa=ga;break c}else{break e}break};case 48:{if((K|0)==(J|0)){ea=P;fa=ga;break c}else{break e}break};case 0:{if((K|0)==(J|0)){ea=P;fa=ga;break c}else{break e}break};case 112:{if((c[L+412>>2]|0)==8e3&(J|0)==65543){ea=P;fa=ga;break c}else{break e}break};case 128:{if((c[L+412>>2]|0)==8e3&(J|0)==65542){ea=P;fa=ga;break c}else{break e}break};case 80:case 64:case 96:{if((J|0)==86050){ea=P;fa=ga;break c}else{break e}break};default:{if((c[L+52>>2]|0)==(N|0)){ea=P;fa=ga;break c}else{break e}}}}}while(0);L=ga+1|0;if(L>>>0<G>>>0){ga=L}else{ea=P;fa=L;break}}}}while(0);if((fa|0)==(G|0)){yDb(n,24,2081160,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;N=c[1048984+($<<2)>>2]|0;K=LT(b,0)|0;if((K|0)==0){D=-12;E=178;break a}c[(c[K+8>>2]|0)+8>>2]=N;N=c[o>>2]|0;do{if(N>>>0>2>>>0){E=86}else{if((N|0)!=2){break}z=c[p>>2]|0;if((c[(c[(c[z>>2]|0)+8>>2]|0)+8>>2]|0)==2){break}if((c[(c[(c[z+4>>2]|0)+8>>2]|0)+8>>2]|0)!=2){E=86}}}while(0);if((E|0)==86){E=0;c[s>>2]=c[s>>2]&-2}MT(K,32,1,1e3);ja=K}else{ja=ea}N=c[ja+76>>2]|0;if((N|0)>31){if((_&240|0)==16|($|0)==1){E=91}}else{if((N|0)>15){E=91}else{E=93;break a}}if((E|0)==91){E=0;if(!((_&240|0)==48&($|0)==0|(N|0)>47)){E=93;break a}}Ty(c[j>>2]|0,H,A,0)|0;Y=ja}}while(0);Vy(c[j>>2]|0,4,0)|0;u=Y}if((E|0)==93){Y=_&240;u=(Y|0)==16;ea=($|0)==1;if(u|ea){jT(ja,v,w,B,C,Z,0,1)|0}w=c[j>>2]|0;do{if((c[w+88>>2]|0)!=0){v=b+1064|0;s=c[v>>2]|0;p=c[v+4>>2]|0;if(!((s|0)==0&(p|0)==0|(s|0)==0&(p|0)==(-2147483648|0))){break}p=g+88|0;if((c[p>>2]|0)!=0){break}s=Ty(w,0,0,1)|0;o=F;fa=Wy(c[j>>2]|0)|0;ga=F;r=fa;while(1){fa=c[j>>2]|0;q=YGb(r,ga,-4,-1)|0;Ty(fa,q,F,0)|0;q=vz(c[j>>2]|0)|0;fa=c[j>>2]|0;t=YGb(r,ga,-3,-1)|0;ba=q;aa=(q|0)<0|0?-1:0;ca=ZGb(t,F,ba,aa)|0;Ty(fa,ca,F,0)|0;if((q|0)!=((uz(c[j>>2]|0)|0)+11|0)){break}ca=uz(c[j>>2]|0)|0;ka=(lz(c[j>>2]|0)|0)<<24|ca;if((ka|0)!=0){E=102;break}ca=0;fa=YGb(r,ga,-8,-1)|0;t=F;if((ga|0)<(ca|0)|(ga|0)==(ca|0)&r>>>0<8>>>0|((t|0)<(aa|0)|(t|0)==(aa|0)&fa>>>0<ba>>>0)){break}ba=q+4|0;q=ZGb(r,ga,ba,(ba|0)<0|0?-1:0)|0;ga=F;r=q}if((E|0)==102){r=gHb(ka,0,1e6,0)|0;ga=hHb(r,F,1e3,0)|0;c[v>>2]=ga;c[v+4>>2]=F}Ty(c[j>>2]|0,s,o,0)|0;c[p>>2]=1}}while(0);f:do{if(ea){ka=_&1;w=ka+1|0;ga=44100<<(_>>>2&3)>>3;r=(_<<2&8)+8|0;q=ja+8|0;ba=c[q>>2]|0;fa=ba+416|0;aa=ba+412|0;do{if((c[fa>>2]|0)==0){E=110}else{t=c[aa>>2]|0;if((t|0)==0){E=110;break}ca=c[ba+792>>2]|0;if((ca|0)==0){E=110}else{la=t;ma=ca}}}while(0);if((E|0)==110){c[fa>>2]=w;p=ba+448|0;c[p>>2]=4-ka;c[p+4>>2]=0;c[aa>>2]=ga;c[ba+792>>2]=r;la=ga;ma=r}p=ba+48|0;if((c[p>>2]|0)!=0){switch(Y|0){case 0:case 48:case 160:case 16:case 96:{na=Z;oa=ga;pa=w;qa=q;break f;break};case 176:{na=Z;oa=16e3;pa=w;qa=q;break f;break};case 32:{c[ja+236>>2]=1;na=Z;oa=ga;pa=w;qa=q;break f;break};case 80:{na=Z;oa=8e3;pa=w;qa=q;break f;break};case 64:{na=Z;oa=16e3;pa=w;qa=q;break f;break};case 128:{na=Z;oa=8e3;pa=w;qa=q;break f;break};case 112:{na=Z;oa=8e3;pa=w;qa=q;break f;break};default:{DDb(n,1905496,(I=i,i=i+8|0,c[I>>2]=Y>>>4,I)|0);i=I;na=Z;oa=ga;pa=w;qa=q;break f}}}switch(Y|0){case 0:{c[p>>2]=(ma|0)==8?65541:65536;ra=ba;sa=la;break};case 48:{c[p>>2]=(ma|0)==8?65541:65536;ra=ba;sa=la;break};case 160:{c[p>>2]=86018;ra=ba;sa=la;break};case 16:{c[p>>2]=69645;ra=ba;sa=la;break};case 176:{c[p>>2]=86052;c[ba+412>>2]=16e3;ra=ba;sa=16e3;break};case 32:{c[p>>2]=86017;c[ja+236>>2]=1;ra=ba;sa=la;break};case 80:{c[ba+412>>2]=8e3;c[p>>2]=86050;ra=ba;sa=8e3;break};case 64:{c[ba+412>>2]=16e3;c[p>>2]=86050;ra=ba;sa=16e3;break};case 96:{c[p>>2]=86050;ra=ba;sa=la;break};case 128:{c[ba+412>>2]=8e3;c[p>>2]=65542;ra=ba;sa=8e3;break};case 112:{c[ba+412>>2]=8e3;c[p>>2]=65543;ra=ba;sa=8e3;break};default:{p=Y>>>4;DDb(n,1905496,(I=i,i=i+8|0,c[I>>2]=p,I)|0);i=I;c[ba+52>>2]=p;p=c[q>>2]|0;ra=p;sa=c[p+412>>2]|0}}c[g+36>>2]=sa;p=c[ra+416>>2]|0;c[g+40>>2]=p;na=Z;oa=sa;pa=p;qa=q}else{if(($|0)!=0){na=Z;oa=0;pa=0;qa=ja+8|0;break}p=_&15;o=ja+8|0;s=c[o>>2]|0;switch(p|0){case 7:{c[s+48>>2]=28;c[ja+236>>2]=2;ta=3;break};case 9:{c[s+48>>2]=13;ta=3;break};case 2:{c[s+48>>2]=22;ta=0;break};case 8:{c[s+48>>2]=5;ta=0;break};case 3:{c[s+48>>2]=87;ta=0;break};case 6:{c[s+48>>2]=132;ta=0;break};case 4:{c[s+48>>2]=93;E=143;break};case 5:{c[s+48>>2]=107;E=143;break};default:{DDb(n,1927488,(I=i,i=i+8|0,c[I>>2]=p,I)|0);i=I;c[s+52>>2]=p;ta=0}}do{if((E|0)==143){if((c[s+100>>2]|0)!=1){BT(s,1)|0}p=s+96|0;v=c[j>>2]|0;if((c[p>>2]|0)==0){Vy(v,1,0)|0;ta=1;break}else{ca=(lz(v)|0)&255;a[c[p>>2]|0]=ca;ta=1;break}}}while(0);na=Z-ta|0;oa=0;pa=0;qa=o}}while(0);ta=c[(c[qa>>2]|0)+48>>2]|0;do{if((ta|0)==86018|(ta|0)==28|(ta|0)==13){Z=lz(c[j>>2]|0)|0;_=na-1|0;sa=c[(c[qa>>2]|0)+48>>2]|0;if((sa|0)==28|(sa|0)==13){sa=(uz(c[j>>2]|0)|0)-8388608|0;ra=sa^-8388608;Y=YGb(ra,(ra|0)<0|0?-1:0,B,C)|0;ra=F;la=g+8|0;if((sa|0)>-1){c[la>>2]=1;yDb(n,24,2030904,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}sa=(c[la>>2]|0)==0;ua=sa?C:-2147483648;va=sa?B:0;wa=ra;xa=Y}else{ua=C;va=B;wa=-2147483648;xa=0}if((Z|0)!=0){ya=_;za=ua;Aa=va;Ba=wa;Ca=xa;E=166;break}Z=c[qa>>2]|0;if((c[Z+96>>2]|0)!=0){if((c[Z+48>>2]|0)!=86018){ya=_;za=ua;Aa=va;Ba=wa;Ca=xa;E=166;break}Z=c[j>>2]|0;Y=h+12+($<<2)|0;ZDb(c[Y>>2]|0);ra=cEb(na+15|0)|0;c[Y>>2]=ra;if((ra|0)==0){D=-12;i=e;return D|0}else{c[h+24+($<<2)>>2]=_;mz(Z,ra,_)|0;Da=-11;break}}ZDb(0);ra=(CT(c[qa>>2]|0,c[j>>2]|0,_)|0)>>31&-12;if((ra|0)<0){D=ra;i=e;return D|0}ra=BBb(c[b+1140>>2]|0,1986728,0,0)|0;_=c[qa>>2]|0;if((c[_+48>>2]|0)!=86018|(ra|0)==0){Da=-11;break}if((QGb(c[ra+4>>2]|0,1954192)|0)!=0){Da=-11;break}c[_+100>>2]=2;Da=-11}else{ya=na;za=C;Aa=B;Ba=-2147483648;Ca=0;E=166}}while(0);g:do{if((E|0)==166){if((ya|0)==0){Da=-11;break}B=TS(c[j>>2]|0,d,ya)|0;if((B|0)<0){D=B;i=e;return D|0}C=d+16|0;c[C>>2]=Aa;c[C+4>>2]=za;C=(Ca|0)==0&(Ba|0)==(-2147483648|0);na=d+8|0;c[na>>2]=C?Aa:Ca;c[na+4>>2]=C?za:Ba;c[d+32>>2]=c[ja>>2];C=g+12+($<<2)|0;do{if((c[C>>2]|0)!=0){na=g+24+($<<2)|0;qa=GZ(d,1,c[na>>2]|0)|0;if((qa|0)==0){break}UGb(qa|0,c[C>>2]|0,c[na>>2]|0)|0;$Db(C);c[na>>2]=0}}while(0);do{if(ea){C=g+36|0;o=g+40|0;if((oa|0)==(c[C>>2]|0)){if((pa|0)==(c[o>>2]|0)){break}}c[C>>2]=oa;c[o>>2]=pa;fU(d,pa,0,0,oa,0,0)|0}else{if(!(u|($|0)==2)){Da=B;break g}}}while(0);o=d+36|0;c[o>>2]=c[o>>2]|1;Da=B}}while(0);Vy(c[j>>2]|0,4,0)|0;D=Da;i=e;return D|0}else if((E|0)==178){i=e;return D|0}return 0}function IC(a){a=a|0;var b=0;b=c[a+12>>2]|0;$Db(b+12|0);$Db(b+16|0);$Db(b+20|0);return 0}function JC(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;c[(c[a+12>>2]|0)+84>>2]=0;g=Lz(c[a+16>>2]|0,b,d,e,f)|0;return g|0}function KC(b,d,e,f,g,j,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0.0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0,na=0,oa=0;m=i;i=i+528|0;n=m|0;o=m+256|0;p=m+264|0;q=m+272|0;r=b+12|0;s=c[r>>2]|0;t=c[b+16>>2]|0;u=lz(t)|0;a:do{switch(u|0){case 3:{v=(e|0)!=0;do{if(!((d|0)==0&(v^1)|(f|0)==0)){if((c[t+88>>2]|0)==0){break}if(!((QGb(2320472,f)|0)==0&(l|0)==1)){break}w=v?e:d;x=n|0;y=o;z=p;A=c[r>>2]|0;c[o>>2]=0;c[p>>2]=0;B=Ty(t,0,0,1)|0;C=F;do{if((c[w+404>>2]|0)>0){yDb(b,24,2123176,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;G=0}else{if((c[b+1084>>2]&2|0)!=0){G=0;break}H=Ty(t,0,0,1)|0;I=F;J=YGb(g,j,-2,-1)|0;K=F;b:do{if((I|0)<(K|0)|(I|0)==(K|0)&H>>>0<J>>>0){L=YGb(g,j,-1,-1)|0;M=F;N=0;O=0;while(1){R=tz(t)|0;if((R|0)>=256){S=16;break}mz(t,x,R)|0;a[n+R|0]=0;if((R|0)<=0){T=O;U=-38;V=N;break}if((lz(t)|0)!=10){T=O;U=-38;V=N;break}W=vz(t)|0;if(W>>>0>268435455>>>0){T=O;U=-38;V=N;break}if((QGb(2117944,x)|0)==0){if((c[o>>2]|0)==0){X=o;Y=W;Z=N}else{S=22}}else{S=22}if((S|0)==22){S=0;if((QGb(2107968,x)|0)!=0){T=O;U=-38;V=N;break}if((c[p>>2]|0)==0){X=p;Y=O;Z=W}else{T=O;U=-38;V=N;break}}_=cEb(W<<3)|0;c[X>>2]=_;if((_|0)==0){$=-12;break b}c:do{if((W|0)!=0){_=0;do{ba=Ty(t,0,0,1)|0;ca=F;if(!((ca|0)<(M|0)|(ca|0)==(M|0)&ba>>>0<L>>>0)){break c}if((lz(t)|0)!=0){da=-38;S=41;break b}ba=Az(t)|0;ca=F;ea=(c[k>>2]=ba,c[k+4>>2]=ca,+h[k>>3]);ca=(E=+ea,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);ba=(c[X>>2]|0)+(_<<3)|0;c[ba>>2]=~~+ea>>>0;c[ba+4>>2]=ca;_=_+1|0;}while(_>>>0<W>>>0)}}while(0);if((c[o>>2]|0)!=0){if((c[p>>2]|0)!=0){T=Y;U=0;V=Z;break}}W=Ty(t,0,0,1)|0;_=F;if((_|0)<(K|0)|(_|0)==(K|0)&W>>>0<J>>>0){N=Z;O=Y}else{T=Y;U=-38;V=Z;break}}if((S|0)==16){Vy(t,R,(R|0)<0|0?-1:0)|0;T=O;U=-38;V=N}if(!((T|0)==(V|0)&V>>>0>1>>>0)){da=U;S=41;break}L=c[p>>2]|0;M=c[L>>2]|0;W=c[L+4>>2]|0;if((W|0)<(j|0)|(W|0)==(j|0)&M>>>0<g>>>0){da=U;S=41;break}if((V|0)==0){$=U;break}L=A+48|0;_=A+84|0;ca=0;ba=W;W=M;while(1){M=(c[o>>2]|0)+(ca<<3)|0;fa=gHb(c[M>>2]|0,c[M+4>>2]|0,1e3,0)|0;jT(w,W,ba,fa,F,0,0,1)|0;if(ca>>>0<2>>>0){fa=(c[p>>2]|0)+(ca<<3)|0;M=c[fa+4>>2]|0;ha=L+(ca<<4)+8|0;c[ha>>2]=c[fa>>2];c[ha+4>>2]=M;M=(c[o>>2]|0)+(ca<<3)|0;ha=gHb(c[M>>2]|0,c[M+4>>2]|0,1e3,0)|0;M=L+(ca<<4)|0;c[M>>2]=ha;c[M+4>>2]=F;M=ca+1|0;c[_>>2]=M;ia=M}else{ia=ca+1|0}if(!(ia>>>0<V>>>0)){$=U;break b}M=(c[p>>2]|0)+(ia<<3)|0;ca=ia;ba=c[M+4>>2]|0;W=c[M>>2]|0}}else{da=-38;S=41}}while(0);if((S|0)==41){yDb(b,24,2096424,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;$=da}$Db(y);$Db(z);Ty(t,B,C,0)|0;G=$}}while(0);if((G|0)>=0){break}yDb(b,16,2298152,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D}}while(0);v=YGb(g,j,-2,-1)|0;C=F;B=q|0;z=l+1|0;while(1){y=Ty(t,0,0,1)|0;w=F;if(!((w|0)<(C|0)|(w|0)==(C|0)&y>>>0<v>>>0)){break}ja=tz(t)|0;if((ja|0)>=256){S=48;break}mz(t,B,ja)|0;a[q+ja|0]=0;if((ja|0)<=0){break}if((KC(b,d,e,B,g,j,z)|0)<0){ka=-1;S=146;break}}if((S|0)==48){Vy(t,ja,(ja|0)<0|0?-1:0)|0;}else if((S|0)==146){i=m;return ka|0}if((lz(t)|0)==9){la=0.0;break a}else{ka=-1}i=m;return ka|0};case 2:{z=tz(t)|0;if((z|0)<256){mz(t,q|0,z)|0;a[q+z|0]=0;if((z|0)<0){ka=-1}else{la=0.0;break a}i=m;return ka|0}else{Vy(t,z,(z|0)<0|0?-1:0)|0;ka=-1;i=m;return ka|0}break};case 0:{z=Az(t)|0;B=F;la=(c[k>>2]=z,c[k+4>>2]=B,+h[k>>3]);break};case 1:{la=+(lz(t)|0);break};case 8:{Vy(t,4,0)|0;B=YGb(g,j,-2,-1)|0;z=F;v=q|0;C=l+1|0;while(1){y=Ty(t,0,0,1)|0;w=F;if(!((w|0)<(z|0)|(w|0)==(z|0)&y>>>0<B>>>0)){break}ma=tz(t)|0;if((ma|0)>=256){S=55;break}mz(t,v,ma)|0;a[q+ma|0]=0;if((ma|0)<=0){break}if((KC(b,d,e,v,g,j,C)|0)<0){ka=-1;S=146;break}}if((S|0)==55){Vy(t,ma,(ma|0)<0|0?-1:0)|0;}else if((S|0)==146){i=m;return ka|0}if((lz(t)|0)==9){la=0.0;break a}else{ka=-1}i=m;return ka|0};case 10:{C=vz(t)|0;v=YGb(g,j,-1,-1)|0;B=F;z=l+1|0;y=0;while(1){if(!(y>>>0<C>>>0)){la=0.0;break a}w=Ty(t,0,0,1)|0;A=F;if(!((A|0)<(B|0)|(A|0)==(B|0)&w>>>0<v>>>0)){la=0.0;break a}if((KC(b,0,0,0,g,j,z)|0)<0){ka=-1;break}else{y=y+1|0}}i=m;return ka|0};case 11:{Vy(t,10,0)|0;la=0.0;break};case 5:case 6:case 13:{la=0.0;break};default:{ka=-1;i=m;return ka|0}}}while(0);if((l|0)!=1|(f|0)==0){ka=0;i=m;return ka|0}if((d|0)==0){na=0}else{na=c[d+8>>2]|0}if((e|0)==0){oa=0}else{oa=c[e+8>>2]|0}d:do{if(u>>>0<2>>>0){if((QGb(f,2281008)|0)==0){ea=la*1.0e6;l=(E=+ea,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);t=b+1064|0;c[t>>2]=~~+ea>>>0;c[t+4>>2]=l;break}l=(oa|0)==0;do{if(!((QGb(f,2265824)|0)!=0|l)){t=~~(la*1024.0);if(!((t|0)>-1)){break}c[oa+72>>2]=t;break d}}while(0);t=(na|0)==0;do{if(!((QGb(f,2250736)|0)!=0|t)){j=~~(la*1024.0);if(!((j|0)>-1)){break}c[na+72>>2]=j;break d}}while(0);if((QGb(f,2236960)|0)==0){j=LT(b,0)|0;if((j|0)==0){ka=-12;i=m;return ka|0}g=j+8|0;c[(c[g>>2]|0)+8>>2]=2;ma=c[b+24>>2]|0;do{if(ma>>>0>2>>>0){S=84}else{if((ma|0)!=2){break}ja=c[b+28>>2]|0;if((c[(c[(c[ja>>2]|0)+8>>2]|0)+8>>2]|0)==2){break}if((c[(c[(c[ja+4>>2]|0)+8>>2]|0)+8>>2]|0)!=2){S=84}}}while(0);if((S|0)==84){ma=b+20|0;c[ma>>2]=c[ma>>2]&-2}MT(j,32,1,1e3);c[(c[g>>2]|0)+48>>2]=94210;break}if((c[s+4>>2]|0)==0){break}if(!((QGb(f,2224312)|0)!=0|l)){ma=~~la;ja=c[e+8>>2]|0;switch(ma|0){case 2:{c[ja+48>>2]=22;break d;break};case 8:{c[ja+48>>2]=5;break d;break};case 3:{c[ja+48>>2]=87;break d;break};case 6:{c[ja+48>>2]=132;break d;break};case 4:{c[ja+48>>2]=93;break d;break};case 5:{c[ja+48>>2]=107;break d;break};case 7:{c[ja+48>>2]=28;c[e+236>>2]=2;break d;break};case 9:{c[ja+48>>2]=13;break d;break};default:{DDb(b,1927488,(D=i,i=i+8|0,c[D>>2]=ma,D)|0);i=D;c[ja+52>>2]=ma;break d}}}if((QGb(f,2214568)|0)!=0|t){if(!((QGb(f,2204872)|0)!=0|t)){c[na+412>>2]=~~la;break}if(!((QGb(f,2197360)|0)!=0|t)){c[na+792>>2]=~~la;break}if(!((QGb(f,2185104)|0)!=0|t)){ma=~~(la+1.0);c[na+416>>2]=ma;ja=(ma|0)==2;ma=na+448|0;c[ma>>2]=ja?3:4;c[ma+4>>2]=ja?0:0;break}if(!((QGb(f,2169920)|0)!=0|l)){c[oa+120>>2]=~~la;break}if((QGb(f,2161776)|0)!=0|l){break}c[oa+124>>2]=~~la;break}ja=~~la<<4;switch(ja|0){case 0:{c[na+48>>2]=(c[na+792>>2]|0)==8?65541:65536;break d;break};case 48:{c[na+48>>2]=(c[na+792>>2]|0)==8?65541:65536;break d;break};case 160:{c[na+48>>2]=86018;break d;break};case 16:{c[na+48>>2]=69645;break d;break};case 176:{c[na+48>>2]=86052;c[na+412>>2]=16e3;break d;break};case 32:{c[na+48>>2]=86017;c[d+236>>2]=1;break d;break};case 80:{c[na+412>>2]=8e3;c[na+48>>2]=86050;break d;break};case 64:{c[na+412>>2]=16e3;c[na+48>>2]=86050;break d;break};case 96:{c[na+48>>2]=86050;break d;break};case 128:{c[na+412>>2]=8e3;c[na+48>>2]=65542;break d;break};case 112:{c[na+412>>2]=8e3;c[na+48>>2]=65543;break d;break};default:{ma=ja>>4;DDb(b,1905496,(D=i,i=i+8|0,c[D>>2]=ma,D)|0);i=D;c[na+52>>2]=ma;break d}}}}while(0);do{if((u|0)==3){if((c[b+24>>2]|0)!=1){break}if((na|0)==0){if((QGb(f,2214568)|0)!=0){S=126}}else{S=126}if((S|0)==126){if((oa|0)!=0){break}if((QGb(f,2224312)|0)!=0){break}}d=b+20|0;c[d>>2]=c[d>>2]&-2}}while(0);if((QGb(f,2281008)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2155160)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2169920)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2161776)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2265824)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2148208)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2224312)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2250736)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2204872)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2197360)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2185104)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2214568)|0)==0){ka=0;i=m;return ka|0}if((QGb(f,2236960)|0)==0){ka=0;i=m;return ka|0}if((u|0)==1){oa=q|0;sAb(oa,la>0.0?2141632:2135728,256)|0;CBb(b+1140|0,f,oa,0)|0;ka=0;i=m;return ka|0}else if((u|0)==0){oa=q|0;Lb(oa|0,256,2129624,(D=i,i=i+8|0,h[D>>3]=la,D)|0)|0;i=D;CBb(b+1140|0,f,oa,0)|0;ka=0;i=m;return ka|0}else if((u|0)==2){CBb(b+1140|0,f,q|0,0)|0;ka=0;i=m;return ka|0}else{ka=0;i=m;return ka|0}return 0}function LC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0.0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;b=i;d=c[a+16>>2]|0;e=c[a+12>>2]|0;f=a+24|0;a:do{if((c[f>>2]|0)==0){g=0.0;j=0;l=0;m=0}else{n=a+28|0;o=a;p=0.0;q=0;r=0;s=0;t=0;b:while(1){u=c[(c[n>>2]|0)+(q<<2)>>2]|0;v=c[u+8>>2]|0;w=c[v+8>>2]|0;do{if((w|0)==0){x=c[u+96>>2]|0;do{if((x|0)==0){y=7}else{z=c[u+92>>2]|0;if((z|0)==0){y=7;break}A=+(z|0)/+(x|0)}}while(0);if((y|0)==7){y=0;A=1.0/(+(c[v+104>>2]|0)/+(c[v+108>>2]|0))}if((s|0)!=0){y=9;break b}if((c[v+52>>2]|0)==0){y=11;break b}else{B=t;C=v;D=r;E=A}}else if((w|0)==1){if((t|0)!=0){y=13;break b}if((OC(a,v)|0)<0){G=-1094995529;y=58;break b}if((c[v+48>>2]|0)!=65537){B=v;C=s;D=r;E=p;break}yDb(o,24,2148104,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;B=v;C=s;D=r;E=p}else if((w|0)==2){I=c[v+48>>2]|0;if((I|0)==94210){B=t;C=s;D=v;E=p}else{y=18;break b}}else{y=19;break b}}while(0);MT(c[(c[n>>2]|0)+(q<<2)>>2]|0,32,1,1e3);u=cEb(8)|0;if((u|0)==0){G=-12;y=58;break}c[(c[(c[n>>2]|0)+(q<<2)>>2]|0)+12>>2]=u;x=u;c[x>>2]=-1;c[x+4>>2]=-1;x=q+1|0;if(x>>>0<(c[f>>2]|0)>>>0){p=E;q=x;r=D;s=C;t=B}else{g=E;j=D;l=C;m=B;break a}}if((y|0)==9){yDb(o,16,2169872,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;G=-22;i=b;return G|0}else if((y|0)==11){t=H0a(c[v+48>>2]|0)|0;yDb(o,16,2161712,(H=i,i=i+16|0,c[H>>2]=t,c[H+8>>2]=q,H)|0);i=H;G=-22;i=b;return G|0}else if((y|0)==13){yDb(o,16,2155112,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;G=-22;i=b;return G|0}else if((y|0)==18){t=H0a(I)|0;yDb(o,16,2141568,(H=i,i=i+16|0,c[H>>2]=t,c[H+8>>2]=q,H)|0);i=H;G=-1094995529;i=b;return G|0}else if((y|0)==19){t=lGb(w)|0;yDb(o,16,2135664,(H=i,i=i+16|0,c[H>>2]=t,c[H+8>>2]=q,H)|0);i=H;G=-22;i=b;return G|0}else if((y|0)==58){i=b;return G|0}}}while(0);y=e+32|0;c[y>>2]=0;c[y+4>>2]=-2147483648;Ry(d,2129616,3);Py(d,1);y=(m|0)!=0;w=y&1;I=(l|0)!=0;v=I&1;Py(d,w<<2|v);Zy(d,9);Zy(d,0);B=c[f>>2]|0;if((B|0)!=0){C=a+28|0;D=e;t=0;s=B;while(1){if((c[(c[(c[(c[C>>2]|0)+(t<<2)>>2]|0)+8>>2]|0)+52>>2]|0)==5){Py(d,8);hz(d,0);hz(d,0);Zy(d,0);Zy(d,11);c[D>>2]=5;J=c[f>>2]|0}else{J=s}B=t+1|0;if(B>>>0<J>>>0){t=B;s=J}else{break}}}Py(d,18);J=Ty(d,0,0,1)|0;s=F;hz(d,0);hz(d,0);Zy(d,0);Py(d,2);fz(d,10);Ry(d,2123160,10);Py(d,8);t=Ty(d,0,0,1)|0;D=F;C=(j|0)!=0;j=(C&1|2)+(-v&5)+(-w&5)|0;Zy(d,j);fz(d,8);Ry(d,2117928,8);w=Ty(d,0,0,1)|0;v=e+8|0;c[v>>2]=w;c[v+4>>2]=F;v=a+1064|0;w=eHb(c[v>>2]|0,c[v+4>>2]|0,1e6,0)|0;E=+(w>>>0)+ +(F|0)*4294967296.0;Py(d,0);h[k>>3]=E;ez(d,c[k>>2]|0,c[k+4>>2]|0);if(I){fz(d,5);Ry(d,2107960,5);E=+(c[l+120>>2]|0);Py(d,0);h[k>>3]=E;ez(d,c[k>>2]|0,c[k+4>>2]|0);fz(d,6);Ry(d,2096416,6);E=+(c[l+124>>2]|0);Py(d,0);h[k>>3]=E;ez(d,c[k>>2]|0,c[k+4>>2]|0);fz(d,13);Ry(d,2090960,13);E=+(c[l+72>>2]|0)*.0009765625;Py(d,0);h[k>>3]=E;ez(d,c[k>>2]|0,c[k+4>>2]|0);fz(d,9);Ry(d,2085912,9);Py(d,0);h[k>>3]=g;ez(d,c[k>>2]|0,c[k+4>>2]|0);fz(d,12);Ry(d,2080944,12);g=+((c[l+52>>2]|0)>>>0>>>0);Py(d,0);h[k>>3]=g;ez(d,c[k>>2]|0,c[k+4>>2]|0)}if(y){fz(d,13);Ry(d,2075464,13);g=+(c[m+72>>2]|0)*.0009765625;Py(d,0);h[k>>3]=g;ez(d,c[k>>2]|0,c[k+4>>2]|0);fz(d,15);Ry(d,2070864,15);g=+(c[m+412>>2]|0);Py(d,0);h[k>>3]=g;ez(d,c[k>>2]|0,c[k+4>>2]|0);fz(d,15);Ry(d,2066432,15);y=(c[m+48>>2]|0)==65541;Py(d,0);ez(d,y?0:0,y?1075838976:1076887552);fz(d,6);Ry(d,2062192,6);y=(c[m+416>>2]|0)==2;Py(d,1);Py(d,y&1);fz(d,12);Ry(d,2058656,12);g=+((c[m+52>>2]|0)>>>0>>>0);Py(d,0);h[k>>3]=g;ez(d,c[k>>2]|0,c[k+4>>2]|0)}if(C){fz(d,10);Ry(d,2050408,10);Py(d,0);ez(d,0,0)}C=a+1140|0;m=BBb(c[C>>2]|0,9203488,0,2)|0;c:do{if((m|0)==0){K=j}else{y=a;l=j;I=m;while(1){w=I;d:while(1){L=c[w>>2]|0;do{if((QGb(L,2107960)|0)!=0){if((QGb(L,2096416)|0)==0){break}if((QGb(L,2090960)|0)==0){break}if((QGb(L,2085912)|0)==0){break}if((QGb(L,2080944)|0)==0){break}if((QGb(L,2075464)|0)==0){break}if((QGb(L,2070864)|0)==0){break}if((QGb(L,2066432)|0)==0){break}if((QGb(L,2062192)|0)==0){break}if((QGb(L,2058656)|0)==0){break}if((QGb(L,2117928)|0)==0){break}if((QGb(L,2123160)|0)!=0){break d}}}while(0);yDb(y,48,2041440,(H=i,i=i+8|0,c[H>>2]=L,H)|0);i=H;v=BBb(c[C>>2]|0,9203488,w,2)|0;if((v|0)==0){K=l;break c}else{w=v}}v=SGb(L|0)|0;fz(d,v);Ry(d,L,v);Py(d,2);v=c[w+4>>2]|0;B=SGb(v|0)|0;fz(d,B);Ry(d,v,B);B=l+1|0;v=BBb(c[C>>2]|0,9203488,w,2)|0;if((v|0)==0){K=B;break}else{l=B;I=v}}}}while(0);fz(d,8);Ry(d,2038e3,8);C=Ty(d,0,0,1)|0;L=e+16|0;c[L>>2]=C;c[L+4>>2]=F;Py(d,0);ez(d,0,0);fz(d,0);Ry(d,9203488,0);Py(d,9);L=Ty(d,0,0,1)|0;C=ZGb(L,F,J,s)|0;L=F;e=YGb(C,L,-10,0)|0;Ty(d,t,D,0)|0;Zy(d,K);Ty(d,J,s,0)|0;hz(d,e);e=YGb(C,L,-3,-1)|0;Vy(d,e,F)|0;e=YGb(C,L,1,0)|0;Zy(d,e);e=c[f>>2]|0;if((e|0)==0){G=0;i=b;return G|0}L=a+28|0;C=0;s=e;while(1){e=c[(c[(c[L>>2]|0)+(C<<2)>>2]|0)+8>>2]|0;J=e+48|0;K=c[J>>2]|0;if((K|0)==86018|(K|0)==28|(K|0)==13){Py(d,(c[e+8>>2]|0)==0?9:8);hz(d,0);hz(d,0);Py(d,0);hz(d,0);K=Ty(d,0,0,1)|0;D=F;if((c[J>>2]|0)==86018){Py(d,OC(a,e)|0);Py(d,0);Ry(d,c[e+96>>2]|0,c[e+100>>2]|0)}else{Py(d,c[e+52>>2]|16);Py(d,0);hz(d,0);cX(d,c[e+96>>2]|0,c[e+100>>2]|0)|0}e=Ty(d,0,0,1)|0;J=ZGb(e,F,K,D)|0;D=F;K=ZGb(-10,-1,J,D)|0;Ty(d,K,F,1)|0;hz(d,J);K=YGb(J,D,7,0)|0;Vy(d,K,F)|0;K=YGb(J,D,11,0)|0;Zy(d,K);M=c[f>>2]|0}else{M=s}K=C+1|0;if(K>>>0<M>>>0){C=K;s=M}else{G=0;break}}i=b;return G|0}function MC(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=c[b+16>>2]|0;k=e+32|0;l=b+28|0;m=c[(c[l>>2]|0)+(c[k>>2]<<2)>>2]|0;n=c[m+8>>2]|0;o=c[b+12>>2]|0;p=c[m+12>>2]|0;m=e+28|0;c[g>>2]=c[m>>2];c[h>>2]=0;q=n+48|0;r=c[q>>2]|0;if((r|0)==28|(r|0)==13){s=5}else if((r|0)==93|(r|0)==107|(r|0)==92|(r|0)==86018){s=2}else{s=1}r=n+8|0;t=c[r>>2]|0;do{if((t|0)==0){Py(j,9);u=c[n+52>>2]|0;if((u|0)!=0){v=(c[e+36>>2]<<4&16^16)+16|u;break}u=H0a(c[q>>2]|0)|0;yDb(b,16,1986600,(w=i,i=i+8|0,c[w>>2]=u,w)|0);i=w;x=-22;i=f;return x|0}else if((t|0)==2){Py(j,18);v=-1}else if((t|0)==1){u=OC(b,n)|0;if((c[g>>2]|0)==0){yDb(0,0,1954144,(w=i,i=i+24|0,c[w>>2]=1927456,c[w+8>>2]=1905440,c[w+16>>2]=491,w)|0);i=w;Cd();return 0}else{Py(j,8);v=u;break}}else{x=-22;i=f;return x|0}}while(0);t=c[q>>2]|0;do{if((t|0)==28|(t|0)==13){if((c[n+100>>2]|0)<=0){break}if((a[c[n+96>>2]|0]|0)==1){break}u=bX(c[e+24>>2]|0,h,g)|0;if((u|0)<0){x=u}else{break}i=f;return x|0}else if((t|0)==86018){if((c[m>>2]|0)<=2){break}u=c[e+24>>2]|0;if(!(((de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&-16)<<16>>16==-16)){break}u=(c[(c[l>>2]|0)+(c[k>>2]<<2)>>2]|0)+64|0;y=b;if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==0)){yDb(y,24,2342856,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}yDb(y,16,1884640,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1094995529;i=f;return x|0}}while(0);k=o+32|0;l=c[k>>2]|0;m=c[k+4>>2]|0;t=e+16|0;if((l|0)==0&(m|0)==(-2147483648|0)){y=ZGb(0,0,c[t>>2]|0,c[t+4>>2]|0)|0;u=F;c[k>>2]=y;c[k+4>>2]=u;z=u;A=y}else{z=m;A=l}l=c[t>>2]|0;m=c[t+4>>2]|0;y=ZGb(0,0,A,z)|0;u=F;if((m|0)<(u|0)|(m|0)==(u|0)&l>>>0<y>>>0){yDb(b,24,2320352,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-22;i=f;return x|0}y=YGb(A,z,l,m)|0;m=F;l=y;do{if((c[q>>2]|0)==86052){z=y|0;A=m&0;u=p;B=ZGb(z,A,c[u>>2]|0,c[u+4>>2]|0)|0;C=F;D=0;if(!((C|0)>(D|0)|(C|0)==(D|0)&B>>>0>160>>>0)){E=u;G=A;H=z;break}yDb(b,24,2298008,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;E=u;G=A;H=z}else{E=p;G=m&0;H=y|0}}while(0);y=c[E+4>>2]|0;if((y|0)<(G|0)|(y|0)==(G|0)&(c[E>>2]|0)>>>0<H>>>0){c[E>>2]=H;c[E+4>>2]=G}hz(j,(c[g>>2]|0)+s|0);hz(j,l);Py(j,l>>>24&127);hz(j,c[o>>2]|0);if((c[r>>2]|0)==2){r=Ty(j,0,0,1)|0;l=F;Py(j,2);fz(j,10);Ry(j,2280968,10);Py(j,8);Zy(j,2);fz(j,4);Ry(j,2265768,4);Py(j,2);fz(j,4);Ry(j,2250704,4);fz(j,4);Ry(j,2236928,4);Py(j,2);G=c[e+24>>2]|0;E=SGb(G|0)|0;fz(j,E);Ry(j,G,E);fz(j,0);Ry(j,9203488,0);Py(j,9);E=Ty(j,0,0,1)|0;G=ZGb(E,F,r,l)|0;E=G;G=YGb(r,l,-10,-1)|0;Ty(j,G,F,0)|0;hz(j,E);G=E+7|0;Ty(j,G,(G|0)<0|0?-1:0,1)|0;Zy(j,E+11|0)}else{Py(j,v);v=c[q>>2]|0;if((v|0)==92){Py(j,0);I=c[q>>2]|0}else{I=v}do{if((I|0)==28|(I|0)==13){Py(j,1);v=e+8|0;q=ZGb(c[v>>2]|0,c[v+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0)|0;hz(j,q)}else if((I|0)==86018){Py(j,1)}else if((I|0)==93|(I|0)==107){if((c[n+100>>2]|0)==0){q=c[n+120>>2]|0;v=c[n+124>>2]|0;Py(j,(q+15&268435440)-q<<4|(v+15&-16)-v);break}else{Py(j,d[c[n+96>>2]|0]|0);break}}}while(0);n=c[h>>2]|0;if((n|0)==0){J=c[e+24>>2]|0}else{J=n}Ry(j,J,c[g>>2]|0);Zy(j,s+11+(c[g>>2]|0)|0);g=o+24|0;o=c[g>>2]|0;s=c[g+4>>2]|0;J=e+8|0;n=YGb(c[k>>2]|0,c[k+4>>2]|0,c[J>>2]|0,c[J+4>>2]|0)|0;J=c[e+48>>2]|0;e=YGb(n,F,J,(J|0)<0|0?-1:0)|0;J=F;n=(s|0)>(J|0)|(s|0)==(J|0)&o>>>0>e>>>0;c[g>>2]=n?o:e;c[g+4>>2]=n?s:J}ZDb(c[h>>2]|0);x=c[j+76>>2]|0;i=f;return x|0}function NC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0;b=i;d=c[a+16>>2]|0;e=c[a+12>>2]|0;f=a+24|0;g=c[f>>2]|0;if((g|0)!=0){j=a+28|0;l=0;m=g;while(1){g=c[(c[j>>2]|0)+(l<<2)>>2]|0;n=c[g+8>>2]|0;o=c[g+12>>2]|0;do{if((c[n+8>>2]|0)==0){g=c[n+48>>2]|0;if(!((g|0)==28|(g|0)==13)){p=m;break}g=c[o>>2]|0;Py(d,9);hz(d,5);hz(d,g);Py(d,g>>>24&127);hz(d,0);Py(d,23);Py(d,2);hz(d,0);Zy(d,16);p=c[f>>2]|0}else{p=m}}while(0);o=l+1|0;if(o>>>0<p>>>0){l=o;m=p}else{break}}}p=Ty(d,0,0,1)|0;m=F;l=e+8|0;f=Ty(d,c[l>>2]|0,c[l+4>>2]|0,0)|0;l=F;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&f>>>0<0>>>0){yDb(a,24,2081e3,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}else{f=e+24|0;r=(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0)/1.0e3;Py(d,0);h[k>>3]=r;ez(d,c[k>>2]|0,c[k+4>>2]|0)}f=e+16|0;e=Ty(d,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=F;j=0;if((f|0)<(j|0)|(f|0)==(j|0)&e>>>0<0>>>0){yDb(a,24,2030768,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=Ty(d,p,m,0)|0;t=F;i=b;return 0}else{Py(d,0);h[k>>3]=+(p>>>0)+ +(m|0)*4294967296.0;ez(d,c[k>>2]|0,c[k+4>>2]|0);s=Ty(d,p,m,0)|0;t=F;i=b;return 0}return 0}function OC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=(c[b+792>>2]|0)==16?2:0;f=c[b+48>>2]|0;do{if((f|0)==86018){g=175}else{h=c[b+412>>2]|0;if((f|0)==86052){if((h|0)!=16e3){yDb(a,16,2214520,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;g=-22;break}if((c[b+416>>2]|0)==1){g=182;break}yDb(a,16,2204832,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;g=-22;break}if((h|0)==16e3|(h|0)==8e3|(h|0)==5512){if((f|0)==86017){k=12}else{l=e}}else if((h|0)==44100){l=e|12}else if((h|0)==11025){l=e|4}else if((h|0)==22050){l=e|8}else{k=12}if((k|0)==12){yDb(a,16,2197248,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;g=-22;break}m=(c[b+416>>2]|0)>1|l;if((f|0)==65541){g=m;break}else if((f|0)==69645){g=m|18;break}else if((f|0)==65536){g=m|50;break}else if((f|0)==86050){if((h|0)==8e3){g=m|82;break}else if((h|0)==16e3){g=m|66;break}else{g=m|98;break}}else if((f|0)==65537){g=m|2;break}else if((f|0)==86017){g=m|34;break}else if((f|0)==65543){g=114;break}else if((f|0)==65542){g=130;break}else if((f|0)==0){g=c[b+52>>2]<<4|m;break}else{m=H0a(f)|0;yDb(a,16,2185048,(j=i,i=i+8|0,c[j>>2]=m,j)|0);i=j;g=-22;break}}}while(0);i=d;return g|0}function PC(a){a=a|0;return c[((a|0)==0?5221480:a+24|0)>>2]|0}function QC(a){a=a|0;return c[((a|0)==0?5221472:a+40|0)>>2]|0}function RC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[214508]|0;d=a+24|0;c[d>>2]=0;e=a;a=b;while(1){b=c[a>>2]|0;if((b|0)==0){f=a;if(((D=c[f>>2]|0,(c[f>>2]|0)==0?(c[f>>2]=e)|0:0,D)|0)==0){break}g=c[a>>2]|0}else{g=b}a=g+24|0}c[214508]=d;return}function SC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[214506]|0;d=a+40|0;c[d>>2]=0;e=a;a=b;while(1){b=c[a>>2]|0;if((b|0)==0){f=a;if(((D=c[f>>2]|0,(c[f>>2]|0)==0?(c[f>>2]=e)|0:0,D)|0)==0){break}g=c[a>>2]|0}else{g=b}a=g+40|0}c[214506]=d;return}function TC(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+32|0;e=d|0;a:do{if((b|0)==0){f=0}else{g=cc(b|0,46)|0;if((g|0)==0){f=0;break}h=g+1|0;g=e|0;j=e;k=g;l=c;b:while(1){m=a[l]|0;do{if(!((m<<24>>24|0)==0|(m<<24>>24|0)==44)){if(!((k-j|0)>>>0<31>>>0)){break}a[k]=m;k=k+1|0;l=l+1|0;continue b}}while(0);a[k]=0;if((yAb(g,h)|0)==0){f=1;break a}if((a[l]|0)==0){f=0;break}else{k=g;l=l+1|0}}}}while(0);i=d;return f|0}function UC(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+32|0;g=f|0;h=(b|0)!=0;j=(d|0)==0;do{if(!(h|j)){if((WS(d)|0)==0){break}if(($E(d)|0)==0){break}k=UC(1986552,0,0)|0;i=f;return k|0}}while(0);l=c[1305368]|0;if((l|0)==0){k=0;i=f;return k|0}m=(e|0)==0;n=g|0;o=g;if(h){p=0;q=0;r=l}else{h=0;g=0;s=l;while(1){l=c[s+8>>2]|0;if((l|0)==0|m){t=0}else{u=(QGb(l,e)|0)==0;t=u?10:0}do{if(j){v=t}else{u=c[s+12>>2]|0;if((u|0)==0){v=t;break}l=cc(d|0,46)|0;a:do{if((l|0)==0){w=1}else{x=l+1|0;y=n;z=u;while(1){A=a[z]|0;do{if((A<<24>>24|0)==0|(A<<24>>24|0)==44){B=12}else{if(!((y-o|0)>>>0<31>>>0)){B=12;break}a[y]=A;C=y+1|0}}while(0);if((B|0)==12){B=0;a[y]=0;if((yAb(n,x)|0)==0){w=0;break a}if((a[z]|0)==0){w=1;break a}else{C=n}}y=C;z=z+1|0}}}while(0);v=w?t:t|5}}while(0);u=(v|0)>(g|0);l=u?s:h;z=c[((s|0)==0?5221472:s+40|0)>>2]|0;if((z|0)==0){k=l;break}else{h=l;g=u?v:g;s=z}}i=f;return k|0}while(1){s=c[r>>2]|0;b:do{if((s|0)==0){D=0}else{g=SGb(b|0)|0;v=s;while(1){h=Vb(v|0,44)|0;if((h|0)==0){break}t=h-v|0;if((zAb(b,v,(t|0)>(g|0)?t:g)|0)==0){D=100;break b}else{v=h+1|0}}g=(yAb(b,v)|0)==0;D=g?100:0}}while(0);s=c[r+8>>2]|0;if((s|0)==0|m){E=D}else{g=(QGb(s,e)|0)==0;E=g?D|10:D}do{if(j){F=E}else{g=c[r+12>>2]|0;if((g|0)==0){F=E;break}s=cc(d|0,46)|0;c:do{if((s|0)==0){G=1}else{h=s+1|0;t=n;w=g;while(1){C=a[w]|0;do{if((C<<24>>24|0)==0|(C<<24>>24|0)==44){B=36}else{if(!((t-o|0)>>>0<31>>>0)){B=36;break}a[t]=C;H=t+1|0}}while(0);if((B|0)==36){B=0;a[t]=0;if((yAb(n,h)|0)==0){G=0;break c}if((a[w]|0)==0){G=1;break c}else{H=n}}t=H;w=w+1|0}}}while(0);F=G?E:E+5|0}}while(0);g=(F|0)>(q|0);s=g?r:p;v=c[((r|0)==0?5221472:r+40|0)>>2]|0;if((v|0)==0){k=s;break}else{p=s;q=g?F:q;r=v}}i=f;return k|0}function VC(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;e=c[a>>2]|0;if((QGb(e,2250696)|0)==0){g=3}else{if((QGb(e,2148088)|0)==0){g=3}else{h=a}}if((g|0)==3){h=UC(0,d,0)|0}if((f|0)==3){i=c[h+24>>2]|0;return i|0}else if((f|0)==0){a=c[h>>2]|0;if((QGb(a,1986552)|0)==0){g=7}else{if((QGb(a,2080928)|0)==0){g=7}}do{if((g|0)==7){a=$E(d)|0;if((a|0)==0){break}else{i=a}return i|0}}while(0);i=c[h+20>>2]|0;return i|0}else if((f|0)==1){i=c[h+16>>2]|0;return i|0}else{i=0;return i|0}return 0}function WC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[1305370]|0;if((b|0)==0){d=0;return d|0}e=(a|0)==0;f=b;a:while(1){b=c[f>>2]|0;if(!(e|(b|0)==0)){g=SGb(a|0)|0;h=b;while(1){b=Vb(h|0,44)|0;if((b|0)==0){break}i=b-h|0;if((zAb(a,h,(i|0)>(g|0)?i:g)|0)==0){d=f;j=9;break a}else{h=b+1|0}}if((yAb(a,h)|0)==0){d=f;j=9;break}}g=c[((f|0)==0?5221480:f+24|0)>>2]|0;if((g|0)==0){d=0;j=9;break}else{f=g}}if((j|0)==9){return d|0}return 0}function XC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+256|0;e=c[b+28>>2]|0;f=eAb(0,c[b+24>>2]|0,e)|0;g=d|0;h=b+16|0;j=c[h>>2]|0;k=c[h+4>>2]|0;h=b+8|0;l=c[h>>2]|0;m=c[h+4>>2]|0;h=c[b+48>>2]|0;Lb(g|0,256,2148008,(n=i,i=i+64|0,c[n>>2]=c[b+32>>2],c[n+8>>2]=j,c[n+16>>2]=k,c[n+24>>2]=l,c[n+32>>2]=m,c[n+40>>2]=h,c[n+48>>2]=e,c[n+56>>2]=f,n)|0)|0;i=n;f=c[b+36>>2]|0;if((f|0)!=1){uAb(g,256,2080864,(n=i,i=i+8|0,c[n>>2]=f,n)|0)|0;i=n}f=b+44|0;e=c[f>>2]|0;do{if((e|0)!=0){uAb(g,256,2030640,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;if((c[f>>2]|0)<=0){break}h=b+40|0;m=0;do{l=c[h>>2]|0;k=c[l+(m*12|0)+4>>2]|0;j=eAb(0,c[l+(m*12|0)>>2]|0,k)|0;uAb(g,256,1986536,(n=i,i=i+16|0,c[n>>2]=k,c[n+8>>2]=j,n)|0)|0;i=n;m=m+1|0;}while((m|0)<(c[f>>2]|0))}}while(0);uAb(g,256,1954096,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0)|0;i=n;n=c[a+16>>2]|0;Ry(n,g,SGb(g|0)|0);i=d;return 0}function YC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+24|0;if((c[d>>2]|0)==0){i=b;return 0}do{if((c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)==0){Kz(c[a+16>>2]|0,1985608,(e=i,i=i+8|0,c[e>>2]=2250280,e)|0)|0;i=e;if((c[d>>2]|0)!=0){break}i=b;return 0}}while(0);f=a+28|0;g=a+16|0;a=0;do{h=c[(c[f>>2]|0)+(a<<2)>>2]|0;j=c[h+8>>2]|0;MT(h,64,c[j+104>>2]|0,c[j+108>>2]|0);j=c[h+40>>2]|0;k=c[h+44>>2]|0;Kz(c[g>>2]|0,2147984,(e=i,i=i+24|0,c[e>>2]=a,c[e+8>>2]=j,c[e+16>>2]=k,e)|0)|0;i=e;Sy(c[g>>2]|0);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0);i=b;return 0}function ZC(b){b=b|0;var e=0,f=0,g=0;do{if((c[b+8>>2]|0)>8){e=c[b+4>>2]|0;if((a[e]|0)!=70){break}if((a[e+1|0]|0)!=82){break}if((a[e+2|0]|0)!=77){break}f=e+4|0;if((d[f]|d[f+1|0]<<8)<<16>>16<<16>>16==0){break}f=e+6|0;if((d[f]|d[f+1|0]<<8)<<16>>16<<16>>16==0){break}else{g=25}return g|0}}while(0);g=0;return g|0}function _C(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+16>>2]|0;d=LT(a,0)|0;if((d|0)==0){e=-12;return e|0}a=d+8|0;d=c[a>>2]|0;c[d+8>>2]=0;c[d+48>>2]=14;Vy(b,3,0)|0;d=c0a(1041096,lz(b)|0)|0;f=c[a>>2]|0;c[f+140>>2]=d;if((d|0)==0){e=-1094995529;return e|0}c[f+52>>2]=0;f=pz(b)|0;c[(c[a>>2]|0)+120>>2]=f;f=pz(b)|0;c[(c[a>>2]|0)+124>>2]=f;e=0;return e|0}function $C(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;f=c[b+12>>2]|0;if((c[f>>2]|0)!=0){g=-541478725;return g|0}h=e+140|0;i=QZ(c[h>>2]|0,c[e+120>>2]|0,c[e+124>>2]|0)|0;if((i|0)<0){g=-1094995529;return g|0}e=TS(c[b+16>>2]|0,d,i)|0;if((e|0)<0){g=e;return g|0}do{if((c[h>>2]|0)==30){e=d+28|0;if((c[e>>2]|0)<4){break}i=d+24|0;b=3;while(1){j=(c[i>>2]|0)+b|0;a[j]=~a[j];if((b+5|0)>(c[e>>2]|0)){break}else{b=b+4|0}}}}while(0);c[d+32>>2]=0;c[f>>2]=(c[f>>2]|0)+1;g=0;return g|0}function aD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=LT(a,0)|0;if((d|0)==0){e=-12;i=b;return e|0}a=d+8|0;f=c[a>>2]|0;c[f+8>>2]=1;c[f+48>>2]=69660;c[f+412>>2]=16e3;c[f+416>>2]=1;f=u0a(69660)|0;g=c[a>>2]|0;c[g+792>>2]=f;if((f|0)<=0){yDb(0,0,2080816,(f=i,i=i+24|0,c[f>>2]=2030568,c[f+8>>2]=1986480,c[f+16>>2]=43,f)|0);i=f;Cd();return 0}MT(d,64,1,c[g+412>>2]|0);e=0;i=b;return e|0}function bD(a){a=a|0;var b=0,d=0,e=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86069;e=a+448|0;c[e>>2]=4;c[e+4>>2]=0;c[a+416>>2]=1;c[a+412>>2]=8e3;MT(b,64,1,8e3);a=b+48|0;c[a>>2]=0;c[a+4>>2]=0;d=0;return d|0}function cD(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+16|0;b=Ty(c[f>>2]|0,0,0,1)|0;g=e+64|0;c[g>>2]=b;c[g+4>>2]=F;g=lz(c[f>>2]|0)|0;b=d[1046640+(g&3)|0]|0;h=wZ(e,b)|0;if((h|0)<0){i=h;return i|0}h=e+24|0;a[c[h>>2]|0]=g;c[e+48>>2]=240;c[e+32>>2]=0;g=b-1|0;b=mz(c[f>>2]|0,(c[h>>2]|0)+1|0,g)|0;if((b|0)<(g|0)){BZ(e);i=(b|0)<0?b:-541478725;return i|0}else{i=c[e+28>>2]|0;return i|0}return 0}function dD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+12>>2]|0;e=LT(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=e+8|0;h=c[g>>2]|0;c[h+8>>2]=1;c[h+48>>2]=86070;c[h+412>>2]=8e3;c[h+416>>2]=1;do{if((d|0)!=0){j=c[d+4>>2]|0;if((j|0)==0){break}c[a+1072>>2]=j}}while(0);d=a+1072|0;j=c[d>>2]|0;if((j|0)==8e3){k=h;l=8}else if((j|0)==0){yDb(a,48,2147864,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;c[d>>2]=8e3;k=c[g>>2]|0;l=8}else if((j|0)==6400){c[h+432>>2]=8;n=h;o=64}else{yDb(a,16,2080696,(m=i,i=i+8|0,c[m>>2]=j,m)|0);i=m;f=-1094995529;i=b;return f|0}if((l|0)==8){c[k+432>>2]=10;n=k;o=80}MT(e,o,1,c[n+412>>2]|0);f=0;i=b;return f|0}function eD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+28|0;e=TS(c[a+16>>2]|0,b,c[(c[(c[c[d>>2]>>2]|0)+8>>2]|0)+432>>2]|0)|0;c[b+32>>2]=0;if((e|0)<0){return e|0}a=b+64|0;f=c[(c[(c[c[d>>2]>>2]|0)+8>>2]|0)+432>>2]|0;d=eHb(c[a>>2]|0,c[a+4>>2]|0,f,(f|0)<0|0?-1:0)|0;f=F;a=b+8|0;c[a>>2]=d;c[a+4>>2]=f;a=b+16|0;c[a>>2]=d;c[a+4>>2]=f;return e|0}function fD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+1024|0;d=b|0;e=c[a+12>>2]|0;f=a+16|0;g=c[f>>2]|0;do{if((c[a+24>>2]|0)==1){h=c[c[a+28>>2]>>2]|0;j=c[h+8>>2]|0;if((c[j+8>>2]|0)!=0){break}if((c[j+48>>2]|0)!=98){break}k=c[j+120>>2]|0;l=c[j+124>>2]|0;MT(h,64,1,100);h=d|0;m=j+140|0;do{if((fDb(h,c[m>>2]|0)|0)<0){if((c[m>>2]|0)==11){jD(g,k,l,c[e+4>>2]|0,0);break}else{yDb(0,0,1986248,(n=i,i=i+24|0,c[n>>2]=1954024,c[n+8>>2]=1927400,c[n+16>>2]=101,n)|0);i=n;Cd();return 0}}else{jD(g,k,l,c[e+4>>2]|0,h)}}while(0);Sy(c[f>>2]|0);o=0;i=b;return o|0}}while(0);yDb(a,16,2030456,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=b;return o|0}function gD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=(c[a+12>>2]|0)+12|0;if((c[d>>2]|0)!=0){e=iD(a,b)|0;return e|0}a=WDb(80)|0;f=a;c[d>>2]=f;if((a|0)==0){e=-12;return e|0}e=EZ(f,b)|0;return e|0}function hD(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;iD(a,0)|0;$Db(b+12|0);Py(d,59);return 0}function iD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=c[a+16>>2]|0;h=f+12|0;j=c[h>>2]|0;if((j|0)==0){k=0;i=d;return k|0}l=HZ(j,0,e)|0;m=l;n=(l|0)!=0;if(!((c[e>>2]|0)==1024|n^1)){yDb(a,16,2080584,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-1094995529;i=d;return k|0}if(n){n=31;a=0;e=255;do{l=(c[m+(a<<2)>>2]|0)>>>24;o=l>>>0<e>>>0;n=o?a&255:n;e=o?l:e;a=a+1|0;}while(a>>>0<256>>>0);p=e>>>0<128>>>0?5:4;q=n&255}else{p=4;q=31}n=(b|0)!=0;do{if(n){e=b+8|0;a=c[e>>2]|0;m=c[e+4>>2]|0;if((a|0)==0&(m|0)==(-2147483648|0)){break}e=(c[h>>2]|0)+8|0;l=ZGb(a,m,c[e>>2]|0,c[e+4>>2]|0)|0;e=l;if(e>>>0>65535>>>0){r=-e>>31&65535}else{r=l&65535}c[f+16>>2]=r&65535}else{l=c[f+8>>2]|0;if(!((l|0)>-1)){break}c[f+16>>2]=l}}while(0);Py(g,33);Py(g,249);Py(g,4);Py(g,p);az(g,c[f+16>>2]|0);Py(g,q);Py(g,0);Ry(g,c[j+24>>2]|0,c[j+28>>2]|0);BZ(c[h>>2]|0);if(!n){k=0;i=d;return k|0}EZ(c[h>>2]|0,b)|0;k=0;i=d;return k|0}function jD(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;Ry(a,1905384,3);Ry(a,1884600,3);az(a,b);az(a,d);if((f|0)==0){Py(a,0);Py(a,0);Py(a,0)}else{Py(a,247);Py(a,31);Py(a,0);d=0;do{hz(a,c[f+(d<<2)>>2]&16777215);d=d+1|0;}while((d|0)<256)}if(!((e|0)>-1)){return}Py(a,33);Py(a,255);Py(a,11);Ry(a,2342800,11);Py(a,3);Py(a,1);az(a,e&65535);Py(a,0);return}function kD(a){a=a|0;var b=0;b=c[a+4>>2]|0;do{if((PGb(b,986976,6)|0)!=0){if((PGb(b,986960,6)|0)==0){break}return 0}}while(0);a=b+6|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){return 0}else{a=b+8|0;return((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0?0:100)|0}return 0}function lD(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;e=c[a+16>>2]|0;f=0;while(1){if((f|0)>=6){break}g=lz(e)|0;do{if((g|0)==(d[986976+f|0]|0|0)){h=f}else{if((g|0)==(d[986960+f|0]|0|0)){h=f;break}h=-((g|0)!=71|0)|0}}while(0);if((Xy(e)|0)==0){f=h+1|0}else{i=-541478725;j=10;break}}if((j|0)==10){return i|0}c[b+4>>2]=c[b+12>>2];b=pz(e)|0;j=pz(e)|0;if((b|0)==0|(j|0)==0){i=-1094995529;return i|0}h=LT(a,0)|0;if((h|0)==0){i=-12;return i|0}MT(h,64,1,100);a=c[h+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=98;c[a+120>>2]=b;c[a+124>>2]=j;j=Ty(e,0,0,0)|0;i=(j|0)==0&(F|0)==0?0:-5;return i|0}function mD(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+264|0;g=f|0;h=b+12|0;j=c[h>>2]|0;k=b+16|0;l=c[k>>2]|0;m=Ty(l,0,0,1)|0;n=F;o=f+256|0;p=mz(l,o,6)|0;do{if((p|0)==6){if((PGb(o,986976,6)|0)==0){q=n;r=m;s=1;t=5;break}u=(PGb(o,986960,6)|0)==0;if(u){q=n;r=m;s=u&1;t=5}else{t=9}}else{if((p|0)<0){v=p}else{t=9;break}i=f;return v|0}}while(0);if((t|0)==9){o=-p|0;Ty(l,o,(o|0)<0|0?-1:0,1)|0;w=n;x=m;y=-541478725;z=0}a:while(1){if((t|0)==5){t=0;m=Vy(l,4,0)|0;n=m;if((n|0)<0){v=n;t=60;break}n=lz(l)|0;m=Vy(l,2,0)|0;o=m;if((o|0)<0){v=o;t=60;break}if((n&128|0)==0){w=q;x=r;y=o;z=s;continue}o=3<<(n&7)+1;n=Vy(l,o,(o|0)<0|0?-1:0)|0;o=n;if((o|0)<0){v=o;t=60;break}else{w=q;x=r;y=o;z=s}}o=g|0;n=g+1|0;m=y;b:while(1){p=lz(l)|0;if((p|0)==59){A=m;B=1;C=1;break a}if((Xy(l)|0)!=0){A=m;B=1;C=0;break a}if((p|0)==44){t=32;break}else if((p|0)!=33){t=44;break}p=c[h>>2]|0;u=c[k>>2]|0;D=lz(u)|0;do{if((D|0)==255){E=lz(u)|0;G=mz(u,o,E)|0;if((G|0)<0|(E|0)==0){H=G;break}if((E|0)!=11){I=0;t=28;break}E=lz(u)|0;G=mz(u,o,E)|0;if((G|0)<0|(E|0)==0){H=G;break}if((E|0)!=3){I=0;t=28;break}if((a[o]|0)!=1){I=0;t=28;break}E=(d[n]|d[n+1|0]<<8)<<16>>16;G=p+16|0;c[G>>2]=E&65535;if(!(E<<16>>16==0)){I=0;t=28;break}c[G>>2]=-1;I=0;t=28}else if((D|0)==249){G=lz(u)|0;if((G|0)<4){t=16;break b}E=Vy(u,1,0)|0;if((E|0)<0){break b}E=pz(u)|0;J=p+4|0;c[J>>2]=E;if((E|0)<(c[p+8>>2]|0)){c[J>>2]=c[p+12>>2]}J=G-3|0;G=Vy(u,J,(J|0)<0|0?-1:0)|0;if((G|0)<0){break b}else{I=0;t=28}}else{I=0;t=28}}while(0);if((t|0)==28){while(1){t=0;p=lz(u)|0;if((p|0)==0){K=I;break}D=Vy(u,p,(p|0)<0|0?-1:0)|0;p=D;if((p|0)<0){K=p;break}else{I=p;t=28}}H=(K|0)<0?K:0}if((H|0)<0){break}else{m=H}}do{if((t|0)==16){t=0;yDb(b,8,2030336,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L}else if((t|0)==32){t=0;m=Vy(l,8,0)|0;n=m;if((n|0)<0){v=n;t=60;break a}n=lz(l)|0;if((n&128|0)!=0){m=3<<(n&7)+1;n=Vy(l,m,(m|0)<0|0?-1:0)|0;m=n;if((m|0)<0){v=m;t=60;break a}}if((lz(l)|0)<1){yDb(b,16,2147648,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;break}do{m=lz(l)|0;if((m|0)==0){t=39;break a}n=Vy(l,m,(m|0)<0|0?-1:0)|0;}while((n|0)>=0)}else if((t|0)==44){t=0;yDb(b,16,2080496,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L}}while(0);if((z|0)==0){Ty(l,x,w,0)|0;M=0}else{M=0}while(1){if((M|0)>=6){break}n=lz(l)|0;do{if((n|0)==(d[986976+M|0]|0)){N=M}else{if((n|0)==(d[986960+M|0]|0)){N=M;break}N=-((n|0)!=71|0)|0}}while(0);if((Xy(l)|0)==0){M=N+1|0}else{v=-541478725;t=60;break a}}n=Ty(l,0,0,1)|0;m=YGb(n,F,-6,-1)|0;q=F;r=m;s=1;t=5}if((t|0)==39){s=Ty(l,0,0,1)|0;r=F;q=Ty(l,x,w,0)|0;if(!((q|0)==(x|0)&(F|0)==(w|0))){v=-5;i=f;return v|0}q=ZGb(s,r,x,w)|0;w=TS(l,e,q)|0;if((w|0)<0){v=w;i=f;return v|0}if((z|0)!=0){z=e+36|0;c[z>>2]=c[z>>2]|1}c[e+32>>2]=0;z=j+4|0;c[e+48>>2]=c[z>>2];c[z>>2]=c[j+12>>2];A=w;B=0;C=0}else if((t|0)==60){i=f;return v|0}if(!((A|0)>-1&B|(A|0)==-541478725)){v=A;i=f;return v|0}if((c[j+24>>2]|0)!=0){v=-541478725;i=f;return v|0}do{if(!C){if((Xy(l)|0)==0){v=-541478725}else{break}i=f;return v|0}}while(0);C=c[j+16>>2]|0;do{if((C|0)>=0){A=j+20|0;B=(c[A>>2]|0)+1|0;c[A>>2]=B;if((B|0)<(C|0)){break}else{v=-541478725}i=f;return v|0}}while(0);C=Ty(l,0,0,0)|0;v=C;i=f;return v|0}function nD(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=LT(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[d+8>>2]|0;c[f+8>>2]=1;c[f+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[f+416>>2]=1;a=f+448|0;c[a>>2]=4;c[a+4>>2]=0;a=b+4|0;c[f+412>>2]=c[a>>2];c[f+72>>2]=((c[a>>2]|0)*264|0|0)/160|0;MT(d,64,160,8e3);e=0;return e|0}function oD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+16|0;a=Ty(c[d>>2]|0,0,0,1)|0;e=b+64|0;c[e>>2]=a;c[e+4>>2]=F;c[b+32>>2]=0;a=TS(c[d>>2]|0,b,33)|0;if((a|0)<33){BZ(b);f=(a|0)<0?a:-5;return f|0}else{c[b+48>>2]=1;a=eHb(c[e>>2]|0,c[e+4>>2]|0,33,0)|0;e=b+8|0;c[e>>2]=a;c[e+4>>2]=F;f=0;return f|0}return 0}function pD(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;do{if((PGb(b,985808,6)|0)==0){if((PGb(b+10|0,985816,6)|0)==0){d=100}else{break}return d|0}}while(0);d=0;return d|0}function qD(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;b=i;i=i+152|0;e=b|0;f=b+128|0;g=b+136|0;h=b+144|0;j=c[a+16>>2]|0;k=c[a+12>>2]|0;l=(vD(j,f,g)|0)==0;if(l|(c[f>>2]|0)!=188){yDb(a,16,1927248,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=b;return n|0}l=c[g>>2]|0;c[g>>2]=l-2;do{if((lz(j)|0)==224){if((lz(j)|0)!=255){break}o=l-4|0;c[g>>2]=o;p=tz(j)|0;c[h>>2]=p;if((p|0)>(o|0)){yDb(a,16,1884504,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=b;return n|0}q=o-p|0;c[g>>2]=q;o=k;c[o>>2]=0;c[o+4>>2]=-2147483648;r=k+8|0;c[r>>2]=0;c[r+4>>2]=-2147483648;a:do{if((p|0)>1){s=p;while(1){t=lz(j)|0;u=lz(j)|0;v=s-2|0;c[h>>2]=v;if((u|0)>(v|0)){w=v;break a}x=v-u|0;c[h>>2]=x;do{if((u|0)==4){v=vz(j)|0;if((t|0)==66){c[r>>2]=v;c[r+4>>2]=0;break}else if((t|0)==65){c[o>>2]=v;c[o+4>>2]=0;break}else{break}}else{Vy(j,u,(u|0)<0|0?-1:0)|0;}}while(0);if((x|0)>1){s=x}else{w=x;break}}}else{w=p}}while(0);Vy(j,w,(w|0)<0|0?-1:0)|0;p=q-2|0;c[g>>2]=p;s=tz(j)|0;c[h>>2]=s;if((s|0)>(p|0)){yDb(a,16,2342744,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=b;return n|0}u=p-s|0;c[g>>2]=u;b:do{if((s|0)>0){t=a;v=k+16|0;y=v;z=k+20|0;A=k+24|0;B=k+32|0;C=v;v=a+1140|0;D=e|0;E=a+28|0;G=0;H=0;I=s;while(1){J=I;c:while(1){K=lz(j)|0;L=lz(j)|0;M=tz(j)|0;N=J-4-M|0;c[h>>2]=N;do{if((K&128|0)==0){yDb(t,16,2320168,(m=i,i=i+8|0,c[m>>2]=K,m)|0);i=m}else{O=K&127;if((L&192|0)!=192){yDb(t,16,2297944,(m=i,i=i+8|0,c[m>>2]=L,m)|0);i=m;break}P=L&63;c[y>>2]=0;c[z>>2]=0;c[A>>2]=0;c[B>>2]=-2147483648;c[B+4>>2]=0;d:do{if((M|0)>1){Q=M;while(1){R=lz(j)|0;S=lz(j)|0;T=Q-2|0;if((S|0)>(T|0)){U=T;break d}V=T-S|0;do{if((S|0)==4){T=vz(j)|0;if((R|0)==80){W=T-1|0;X=1046648+((W>>>0>8>>>0?8:W)<<3)|0;W=c[X+4>>2]|0;c[C>>2]=c[X>>2];c[C+4>>2]=W;break}else if((R|0)!=82){break}if(!((T-1|0)>>>0<2>>>0)){break}c[A>>2]=T}else if((S|0)==8){if((R|0)!=77){Y=36;break}T=sz(j)|0;c[B>>2]=T;c[B+4>>2]=F}else{Y=36}}while(0);if((Y|0)==36){Y=0;Vy(j,S,(S|0)<0|0?-1:0)|0;}if((V|0)>1){Q=V}else{U=V;break}}}else{U=M}}while(0);do{if((O-7|0)>>>0<2>>>0|(O|0)==24){Q=c[B>>2]|0;R=c[A>>2]|0;T=Q&255;if((R|0)==0){Z=T}else{Z=(T|0)/(R|0)|0}if((Q|0)<0){break}Lb(D|0,128,2185008,(m=i,i=i+40|0,c[m>>2]=Q>>>24&31,c[m+8>>2]=Q>>>16&255,c[m+16>>2]=Q>>>8&255,c[m+24>>2]=Q>>>29&1|58,c[m+32>>2]=Z,m)|0)|0;i=m;CBb(v,2280808,D,0)|0}}while(0);Vy(j,U,(U|0)<0|0?-1:0)|0;_=xD(a,P,O)|0;if((_|0)>=0){break c}}}while(0);if((N|0)>0){J=N}else{$=N;aa=G;ba=H;break b}}J=c[(c[E>>2]|0)+(_<<2)>>2]|0;if((G|0)==0|(H|0)==0){ca=c[y>>2]<<1;da=c[z>>2]|0}else{ca=H;da=G}x=c[o+4>>2]|0;M=J+48|0;c[M>>2]=c[o>>2];c[M+4>>2]=x;x=c[o>>2]|0;M=c[o+4>>2]|0;do{if(!((x|0)==0&(M|0)==(-2147483648|0))){L=c[r>>2]|0;K=c[r+4>>2]|0;if((L|0)==0&(K|0)==(-2147483648|0)){break}Q=ZGb(L,K,x,M)|0;K=J+56|0;c[K>>2]=Q;c[K+4>>2]=F}}while(0);if((N|0)>0){G=da;H=ca;I=N}else{$=N;aa=da;ba=ca;break}}}else{$=s;aa=0;ba=0}}while(0);if(($|0)<0){yDb(a,16,2265648,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}if((p|0)!=(s|0)){Vy(j,u,(u|0)<0|0?-1:0)|0;}if((vD(j,f,h)|0)==0){yDb(a,16,2250584,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=b;return n|0}r=c[f>>2]|0;do{if((r|0)==252){wD(a,c[h>>2]|0);if((vD(j,f,h)|0)!=0){ea=c[f>>2]|0;break}yDb(a,16,2250584,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=b;return n|0}else{ea=r}}while(0);do{if((ea|0)==253){r=c[h>>2]|0;if((r|0)<=56){yDb(a,32,2204808,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;fa=ba;ga=aa;ha=r;break}u=r-57|0;c[h>>2]=u;Vy(j,5,0)|0;Vy(j,48,0)|0;s=1047480+((d[1191992+((rz(j)|0)>>>6&31)|0]|0)<<3)|0;if((aa|0)==0|(ba|0)==0){p=c[s+4>>2]|0;o=c[s>>2]|0;yDb(a,24,2236816,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;ia=o<<1;ja=p}else{ia=ba;ja=aa}if((u|0)<=23){fa=ia;ga=ja;ha=u;break}u=r-81|0;c[h>>2]=u;Vy(j,16,0)|0;r=a+1140|0;p=rz(j)|0;o=k+24|0;s=c[o>>2]|0;q=e|0;I=p&255;if((s|0)==0){ka=I}else{ka=(I|0)/(s|0)|0}if((p|0)>=0){Lb(q|0,128,2185008,(m=i,i=i+40|0,c[m>>2]=p>>>24&31,c[m+8>>2]=p>>>16&255,c[m+16>>2]=p>>>8&255,c[m+24>>2]=p>>>29&1|58,c[m+32>>2]=ka,m)|0)|0;i=m;CBb(r,2224176,q,0)|0}p=rz(j)|0;s=c[o>>2]|0;o=p&255;if((s|0)==0){la=o}else{la=(o|0)/(s|0)|0}if((p|0)<0){fa=ia;ga=ja;ha=u;break}Lb(q|0,128,2185008,(m=i,i=i+40|0,c[m>>2]=p>>>24&31,c[m+8>>2]=p>>>16&255,c[m+16>>2]=p>>>8&255,c[m+24>>2]=p>>>29&1|58,c[m+32>>2]=la,m)|0)|0;i=m;CBb(r,2214456,q,0)|0;fa=ia;ga=ja;ha=u}else{yDb(a,32,2197216,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;fa=ba;ga=aa;ha=c[h>>2]|0}}while(0);Vy(j,ha,(ha|0)<0|0?-1:0)|0;u=(ga|0)==0|(fa|0)==0;q=u?1001:ga;r=u?6e4:fa;u=a+24|0;if((c[u>>2]|0)==0){n=0;i=b;return n|0}p=a+28|0;s=0;while(1){MT(c[(c[p>>2]|0)+(s<<2)>>2]|0,32,q,r);o=s+1|0;if(o>>>0<(c[u>>2]|0)>>>0){s=o}else{n=0;break}}i=b;return n|0}}while(0);yDb(a,16,1905312,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=b;return n|0}function rD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[a+16>>2]|0;h=c[a+12>>2]|0;j=g+52|0;if((c[j>>2]|0)!=0){k=-541478725;i=d;return k|0}l=a;while(1){if((vD(g,e,f)|0)==0){m=4;break}n=c[e>>2]|0;if((n|0)==191){o=c[f>>2]|0;if((o|0)>=16){m=12;break}yDb(l,16,2080376,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}else if((n|0)==252){wD(a,c[f>>2]|0)}else{n=c[f>>2]|0;Vy(g,n,(n|0)<0|0?-1:0)|0;}if((c[j>>2]|0)!=0){k=-541478725;m=22;break}}if((m|0)==4){if((Xy(g)|0)!=0){k=-1;i=d;return k|0}yDb(l,16,2147592,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=-1;i=d;return k|0}else if((m|0)==12){j=o-16|0;c[f>>2]=j;o=lz(g)|0;e=xD(a,lz(g)|0,o)|0;if((e|0)<0){k=e;i=d;return k|0}o=c[(c[a+28>>2]|0)+(e<<2)>>2]|0;a=vz(g)|0;n=vz(g)|0;vz(g)|0;lz(g)|0;lz(g)|0;q=o+8|0;o=c[(c[q>>2]|0)+48>>2]|0;a:do{if((o|0)==65548|(o|0)==65536){r=n>>16;s=n&65535;t=(u0a(o)|0)>>3;do{if((r|0)<=(s|0)){u=ba(t,s)|0;if((u|0)>(j|0)){break}v=ba(t,r)|0;Vy(g,v,(v|0)<0|0?-1:0)|0;v=ba(t,s-r|0)|0;c[f>>2]=v;w=TS(g,b,v)|0;if((j|0)==(u|0)){x=w;break a}v=j-u|0;Vy(g,v,(v|0)<0|0?-1:0)|0;x=w;break a}}while(0);yDb(l,16,2030248,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;m=17}else{m=17}}while(0);if((m|0)==17){x=TS(g,b,j)|0}c[b+32>>2]=e;e=b+16|0;c[e>>2]=a;c[e+4>>2]=(a|0)<0|0?-1:0;if((c[(c[q>>2]|0)+48>>2]|0)!=25){k=x;i=d;return k|0}c[b+48>>2]=c[h+24>>2];k=x;i=d;return k|0}else if((m|0)==22){i=d;return k|0}return 0}function sD(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=c[a+28>>2]|0;g=c[f>>2]|0;h=(c[f+(b<<2)>>2]|0)+48|0;b=c[h>>2]|0;f=c[h+4>>2]|0;h=(f|0)>(e|0)|(f|0)==(e|0)&b>>>0>d>>>0;i=h?b:d;d=h?f:e;e=ZGb(i,d,b,f)|0;f=oT(g,e,F,5)|0;if((f|0)<0){j=-1;return j|0}e=c[g+400>>2]|0;b=e+(f*24|0)|0;h=c[b>>2]|0;k=c[b+4>>2]|0;if((f|0)<((c[g+404>>2]|0)-2|0)){g=e+((f+2|0)*24|0)|0;f=ZGb(c[g>>2]|0,c[g+4>>2]|0,h,k)|0;l=F;m=f}else{l=0;m=104857600}f=a+16|0;a=Ty(c[f>>2]|0,h,k,0)|0;k=a;if((k|0)<0){j=k;return j|0}k=0;a=l>>>0>k>>>0|l>>>0==k>>>0&m>>>0>204800>>>0;k=uD(c[f>>2]|0,a?m:204800,a?l:0,i)|0;l=ZGb(k,F,i,d)|0;d=F;i=-1;k=(d|0)>(i|0)|(d|0)==(i|0)&l>>>0>-1>>>0;i=ZGb(0,0,l,d)|0;a=k?d:F;d=0;j=((a|0)>(d|0)|(a|0)==(d|0)&(k?l:i)>>>0>4>>>0)<<31>>31;return j|0}function tD(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;b=a+16|0;a=c[b>>2]|0;g=Ty(a,c[d>>2]|0,c[d+4>>2]|0,0)|0;h=F;i=0;if((h|0)<(i|0)|(h|0)==(i|0)&g>>>0<0>>>0){j=-2147483648;k=0;return(F=j,k)|0}g=ZGb(e,f,c[d>>2]|0,c[d+4>>2]|0)|0;f=uD(c[b>>2]|0,g,F,-1)|0;g=F;b=Ty(a,0,0,1)|0;c[d>>2]=b;c[d+4>>2]=F;j=g;k=f;return(F=j,k)|0}function uD(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=vz(a)|0;k=e;l=(e|0)<0|0?-1:0;a:do{if((e|0)>-1){m=d;n=b;o=-2147483648;p=0;q=j;r=0;s=0;while(1){t=m;u=n;v=q;while(1){w=YGb(u,t,-1,-1)|0;x=F;y=(u|0)!=0|(t|0)!=0;if((v|0)!=0){if(!y){z=o;A=p;B=r;C=s;break a}if((Xy(a)|0)!=0){z=o;A=p;B=r;C=s;break a}t=x;u=w;v=lz(a)|0|v<<8;continue}if(!y){z=o;A=p;B=r;C=s;break a}if((Xy(a)|0)!=0){z=o;A=p;B=r;C=s;break a}y=lz(a)|0;if((y|0)!=1){t=x;u=w;v=y;continue}D=Ty(a,0,0,1)|0;E=F;y=Ty(a,-5,-1,1)|0;G=F;H=0;if((G|0)<(H|0)|(G|0)==(H|0)&y>>>0<0>>>0){z=o;A=p;B=r;C=s;break a}y=(vD(a,h,g)|0)==0;if(!(y|(c[h>>2]|0)!=191)){break}y=Ty(a,D,E,0)|0;H=F;G=0;if((H|0)<(G|0)|(H|0)==(G|0)&y>>>0<0>>>0){z=o;A=p;B=r;C=s;break a}else{t=x;u=w;v=1}}lz(a)|0;lz(a)|0;v=vz(a)|0;u=0;t=Ty(a,0,0,1)|0;y=YGb(t,F,-22,-1)|0;t=F;if(!((l|0)>(u|0)|(l|0)==(u|0)&k>>>0>v>>>0)){z=u;A=v;B=t;C=y;break a}G=Ty(a,D,E,0)|0;H=F;I=-1;if((H|0)>(I|0)|(H|0)==(I|0)&G>>>0>-1>>>0){m=x;n=w;o=u;p=v;q=1;r=t;s=y}else{z=u;A=v;B=t;C=y;break}}}else{s=d;r=b;q=j;while(1){p=YGb(r,s,-1,-1)|0;o=F;n=(r|0)!=0|(s|0)!=0;if((q|0)!=0){if(!n){J=-2147483648;K=0;L=28;break}if((Xy(a)|0)!=0){J=-2147483648;K=0;L=28;break}s=o;r=p;q=lz(a)|0|q<<8;continue}if(!n){J=-2147483648;K=0;L=28;break}if((Xy(a)|0)!=0){J=-2147483648;K=0;L=28;break}n=lz(a)|0;if((n|0)!=1){s=o;r=p;q=n;continue}n=Ty(a,0,0,1)|0;m=F;y=Ty(a,-5,-1,1)|0;t=F;v=0;if((t|0)<(v|0)|(t|0)==(v|0)&y>>>0<0>>>0){J=-2147483648;K=0;L=28;break}y=(vD(a,h,g)|0)==0;if(!(y|(c[h>>2]|0)!=191)){L=25;break}y=Ty(a,n,m,0)|0;m=F;n=0;if((m|0)<(n|0)|(m|0)==(n|0)&y>>>0<0>>>0){J=-2147483648;K=0;L=28;break}else{s=o;r=p;q=1}}if((L|0)==25){lz(a)|0;lz(a)|0;q=vz(a)|0;r=Ty(a,0,0,1)|0;s=YGb(r,F,-22,-1)|0;z=0;A=q;B=F;C=s;break}else if((L|0)==28){i=f;return(F=J,K)|0}}}while(0);if((C|0)==0&(B|0)==0){J=z;K=A;i=f;return(F=J,K)|0}Ty(a,C,B,0)|0;J=z;K=A;i=f;return(F=J,K)|0}function vD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;do{if((vz(a)|0)==0){if((lz(a)|0)!=1){e=0;break}c[b>>2]=lz(a)|0;f=vz(a)|0;c[d>>2]=f;if(f>>>0>16777215>>>0|(f|0)<16){e=0;break}c[d>>2]=f-16;if((vz(a)|0)!=0){e=0;break}if((lz(a)|0)!=225){e=0;break}e=(lz(a)|0)==226|0}else{e=0}}while(0);return e|0}function wD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=c[a+16>>2]|0;f=rz(e)|0;g=rz(e)|0;h=b-8|0;do{if((c[a+1084>>2]&2|0)==0){b=c[a+28>>2]|0;if((b|0)==0){break}j=c[b>>2]|0;if(g>>>0>1e3>>>0){yDb(a,16,1986040,(k=i,i=i+16|0,c[k>>2]=g,c[k+8>>2]=g,k)|0);i=k;l=1e3}else{l=g}b=l<<2;if(h>>>0<b>>>0){yDb(a,16,1953928,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;Vy(e,h,(h|0)<0|0?-1:0)|0;i=d;return}m=h-b|0;jT(j,0,0,0,0,0,0,0)|0;if((l|0)!=0){b=f;n=0;o=0;do{p=rz(e)|0;q=gHb(o,(o|0)<0|0?-1:0,b,n)|0;r=YGb(q,F,1,0)|0;jT(j,p<<10|0>>>22,0<<10|p>>>22,r,F,0,0,0)|0;o=o+1|0;}while(o>>>0<l>>>0)}Vy(e,m,(m|0)<0|0?-1:0)|0;i=d;return}}while(0);Vy(e,h,(h|0)<0|0?-1:0)|0;i=d;return}function xD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=aU(a,b)|0;if((e|0)>-1){f=e;return f|0}e=LT(a,0)|0;if((e|0)==0){f=-12;return f|0}c[e+4>>2]=b;switch(d|0){case 3:case 4:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=8;break};case 7:case 8:case 24:{d=c[e+8>>2]|0;c[d+8>>2]=2;c[d+48>>2]=0;break};case 26:case 29:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=28;c[e+236>>2]=2;break};case 17:{d=c[e+8>>2]|0;c[d+8>>2]=1;c[d+48>>2]=86019;c[d+416>>2]=2;b=d+448|0;c[b>>2]=3;c[b+4>>2]=0;c[d+412>>2]=48e3;break};case 22:case 23:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=1;c[e+236>>2]=2;break};case 30:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=100;break};case 13:case 14:case 15:case 16:case 25:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=25;break};case 11:case 12:case 20:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=2;c[e+236>>2]=2;break};case 10:{d=c[e+8>>2]|0;c[d+8>>2]=1;c[d+48>>2]=65536;c[d+416>>2]=1;b=d+448|0;c[b>>2]=4;c[b+4>>2]=0;c[d+412>>2]=48e3;c[d+72>>2]=768e3;c[d+432>>2]=2;c[d+792>>2]=16;break};case 9:{d=c[e+8>>2]|0;c[d+8>>2]=1;c[d+48>>2]=65548;c[d+416>>2]=1;b=d+448|0;c[b>>2]=4;c[b+4>>2]=0;c[d+412>>2]=48e3;c[d+72>>2]=1152e3;c[d+432>>2]=3;c[d+792>>2]=24;break};default:{d=c[e+8>>2]|0;c[d+8>>2]=-1;c[d+48>>2]=0}}f=(c[a+24>>2]|0)-1|0;return f|0}function yD(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+272|0;f=e|0;g=e+8|0;h=e+264|0;j=d+16|0;k=c[j>>2]|0;l=d+12|0;m=c[l>>2]|0;TGb(g|0,0,255)|0;n=BBb(c[d+1140>>2]|0,2320144,0,0)|0;if((c[k+88>>2]|0)==0){yDb(d,16,2297872,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}q=m+52|0;c[q>>2]=c[q>>2]|524288;r=d+24|0;a:do{if((c[r>>2]|0)==0){s=n;t=0}else{u=d+28|0;v=m+8|0;w=m+44|0;x=m+48|0;y=m+10|0;z=n;A=0;B=0;C=0;b:while(1){D=c[(c[u>>2]|0)+(B<<2)>>2]|0;E=cEb(96)|0;F=E;if((E|0)==0){p=-12;G=46;break}H=D+12|0;c[H>>2]=E;I=D+8|0;J=(uT(985824,c[(c[I>>2]|0)+48>>2]|0)|0)&65535;K=E+52|0;b[K>>1]=J;L=c[I>>2]|0;M=c[L+8>>2]|0;do{if((M|0)==1){if((c[L+48>>2]|0)!=65536){G=8;break b}N=L+412|0;if((c[N>>2]|0)!=48e3){G=10;break b}if((c[L+416>>2]|0)!=1){G=12;break b}c[E+40>>2]=2;O=c[N>>2]|0;c[E+48>>2]=O;MT(D,64,1,O);c[E+44>>2]=16;c[E+56>>2]=-2;c[E+60>>2]=-2;c[E+64>>2]=-2;b[v>>1]=(b[v>>1]|0)+1;c[q>>2]=c[q>>2]|67108864;P=C;Q=65;R=z}else if((M|0)==0){if((B|0)!=0){G=15;break b}O=c[L+124>>2]|0;if((O|0)==480|(O|0)==512){c[E+56>>2]=5;c[E+48>>2]=60;S=6e4;T=1001;U=c[q>>2]|128}else if((O|0)==576|(O|0)==608){c[E+56>>2]=6;b[K>>1]=J+1;c[E+48>>2]=50;S=50;T=1;U=c[q>>2]|64}else{G=19;break b}c[q>>2]=U;c[w>>2]=T;c[x>>2]=S;if((z|0)==0){O=BBb(c[D+88>>2]|0,2320144,0,0)|0;V=O;W=c[w>>2]|0;X=c[x>>2]|0}else{V=z;W=T;X=S}MT(D,64,W,X);O=c[H>>2]|0;N=0;while(1){if((N|0)>=6){G=26;break}Y=c[I>>2]|0;if((c[Y+124>>2]|0)==(c[985944+(N<<3)>>2]|0)){G=25;break}else{N=N+1|0}}if((G|0)==25){G=0;c[O+60>>2]=c[985948+(N<<3)>>2];Z=Y}else if((G|0)==26){G=0;c[E+60>>2]=-1;Z=c[I>>2]|0}c[E+44>>2]=c[Z+72>>2];c[E+64>>2]=2;_=c[Z+48>>2]|0;if((_|0)==1){c[E+40>>2]=9;b[y>>1]=(b[y>>1]|0)+1;P=F;Q=76;R=V;break}else if((_|0)==2){c[E+88>>2]=-1;c[E+40>>2]=4;b[y>>1]=(b[y>>1]|0)+1;c[q>>2]=c[q>>2]|32768;P=F;Q=77;R=V;break}else if((_|0)==25){if((c[Z+140>>2]|0)==4){b[K>>1]=(b[K>>1]|0)+2;c[E+40>>2]=6;c[q>>2]=c[q>>2]|8192;P=F;Q=69;R=V;break}else{c[E+40>>2]=5;c[q>>2]=c[q>>2]|4096;P=F;Q=68;R=V;break}}else if((_|0)==8){c[E+40>>2]=1;c[q>>2]=c[q>>2]|16384;P=F;Q=74;R=V;break}else{G=34;break b}}else{P=C;Q=A;R=z}}while(0);F=g+Q|0;K=a[F]|0;a[F]=K+1;b[E+54>>1]=(K&255)+48|Q<<8;K=c[r>>2]|0;c[E+92>>2]=K-(c[D>>2]|0);F=B+1|0;if(F>>>0<K>>>0){z=R;A=Q;B=F;C=P}else{s=R;t=P;break a}}if((G|0)==8){yDb(d,16,2280760,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==10){yDb(d,16,2265600,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==12){yDb(d,16,2250536,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==15){yDb(d,16,2236760,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==19){yDb(d,16,2224080,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==34){yDb(d,16,2214424,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==46){i=e;return p|0}}}while(0);c[h>>2]=1;c[h+4>>2]=48e3;if((ZW(d,2365392,h)|0)<0){p=-1;i=e;return p|0}h=(t|0)==0;do{if(!((s|0)==0|h)){G=c[t+64>>2]|0;P=m+184|0;R=P;Q=xd(c[s+4>>2]|0,2204768,(o=i,i=i+40|0,c[o>>2]=m+172,c[o+8>>2]=m+176,c[o+16>>2]=m+180,c[o+24>>2]=f,c[o+32>>2]=P,o)|0)|0;i=o;if((Q|0)!=5){yDb(d,16,2197160,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}c[m+188>>2]=0;c[m+192>>2]=(a[f]|0)!=58;if((G|0)!=2){break}c[R>>2]=c[R>>2]<<1}}while(0);if(!h){h=c[t+48>>2]|0;b[m+108>>1]=(h|0)==60?7:8;c[m+104>>2]=h;b[m+110>>1]=21552;c[m+96>>2]=3;c[m+112>>2]=c[t+56>>2];c[m+116>>2]=c[t+60>>2];c[m+100>>2]=16;c[m+120>>2]=c[t+64>>2]}c[q>>2]=c[q>>2]|2097152;q=DD(d,0)|0;if((q|0)<0){p=q;i=e;return p|0}ED(c[l>>2]|0,c[j>>2]|0);FD(d);c[m+168>>2]=3;Sy(k);p=0;i=e;return p|0}function zD(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;g=a+12|0;h=c[g>>2]|0;j=a+16|0;k=c[j>>2]|0;l=b+32|0;m=a+28|0;n=c[(c[m>>2]|0)+(c[l>>2]<<2)>>2]|0;o=Ty(k,0,0,1)|0;p=F;q=Ty(k,0,0,1)|0;r=eHb(q,F,1024,0)|0;q=r;Zy(k,0);Py(k,1);Py(k,191);Zy(k,0);Zy(k,0);Py(k,225);Py(k,226);r=n+8|0;n=c[r>>2]|0;do{if((c[n+48>>2]|0)==2){s=c[b+28>>2]|0;t=(s|0)%4|0;if((t|0)==0){u=4;break}v=4-t|0;w=s}else{u=4}}while(0);do{if((u|0)==4){s=c[b+28>>2]|0;if((c[n+8>>2]|0)!=1){v=0;w=s;break}v=65536-s|0;w=s}}while(0);n=b+28|0;u=w+v|0;w=c[g>>2]|0;g=c[j>>2]|0;j=c[(c[m>>2]|0)+(c[l>>2]<<2)>>2]|0;l=c[j+12>>2]|0;m=j+8|0;if((c[(c[m>>2]|0)+8>>2]|0)==0){x=c[w+4>>2]|0}else{s=b+16|0;t=c[s>>2]|0;y=c[s+4>>2]|0;s=c[w+48>>2]|0;z=c[w+44>>2]|0;w=gHb(z,(z|0)<0|0?-1:0,48e3,0)|0;z=HDb(t,y,s,(s|0)<0|0?-1:0,w,F,3)|0;x=z}Py(g,e[l+52>>1]|0);Py(g,c[j>>2]|0);Zy(g,x);j=c[m>>2]|0;do{if((c[j+8>>2]|0)==1){fz(g,0);fz(g,(u|0)/2|0)}else{m=c[j+48>>2]|0;if((m|0)==25){Py(g,(u|0)/4096|0);hz(g,0);break}else if((m|0)==2){m=c[b+24>>2]|0;z=(c[n>>2]|0)-4|0;if((z|0)<1){A=1}else{w=l+88|0;s=-1;y=0;while(1){t=d[m+y|0]|0|s<<8;do{if((t|0)==440){if(!((c[w>>2]|0)==-1)){break}c[w>>2]=(d[m+(y+4)|0]|0)>>>6&1}}while(0);B=y+1|0;if((B|0)>=(z|0)|(t|0)==256){break}else{s=t;y=B}}A=y+2|0}s=(d[m+A|0]|0)>>>3&7;if((s|0)==3){Py(g,15);z=l+76|0;c[z>>2]=(c[z>>2]|0)+1}else if((s|0)==1){Py(g,13);s=l+68|0;c[s>>2]=(c[s>>2]|0)+1}else{Py(g,14);s=l+72|0;c[s>>2]=(c[s>>2]|0)+1}hz(g,u);break}else{Zy(g,u);break}}}while(0);Zy(g,x);Py(g,1);Py(g,0);Ry(k,c[b+24>>2]|0,c[n>>2]|0);if((v|0)>0){n=(v|0)<0|0?-1:0;b=v;do{Py(k,0);b=YGb(b,n,-1,-1)|0;n=F;v=0;}while((n|0)>(v|0)|(n|0)==(v|0)&b>>>0>0>>>0)}if((c[(c[r>>2]|0)+8>>2]|0)==0){r=h+156|0;b=c[r>>2]|0;n=h+152|0;do{if(((b>>>0)%500|0|0)==0){v=bEb(n,b+500|0,4)|0;if((v|0)>=0){C=c[r>>2]|0;break}c[r>>2]=0;c[h+4>>2]=0;yDb(a,16,2342680,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;D=v;i=f;return D|0}else{C=b}}while(0);c[r>>2]=C+1;c[(c[n>>2]|0)+(C<<2)>>2]=q;q=h+4|0;c[q>>2]=(c[q>>2]|0)+2}GD(k,o,p)|0;p=h+168|0;h=(c[p>>2]|0)+1|0;c[p>>2]=h;if((h|0)!=100){D=0;i=f;return D|0}h=DD(a,0)|0;if((h|0)<0){D=h;i=f;return D|0}c[p>>2]=0;D=0;i=f;return D|0}function AD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;YW(a);g=Ty(f,0,0,1)|0;h=F;Zy(f,0);Py(f,1);Py(f,251);Zy(f,0);Zy(f,0);Py(f,225);Py(f,226);GD(f,g,h)|0;h=Ty(f,0,0,1)|0;g=F;Ty(f,0,0,0)|0;i=DD(a,1)|0;if((i|0)<0){j=i;return j|0}ED(c[b>>2]|0,c[e>>2]|0);FD(a);Sy(f);e=d+164|0;b=d+160|0;a:do{if((c[e>>2]|0)>>>0>1>>>0){i=b;k=1;while(1){l=(c[i>>2]|0)+(k<<3)|0;Ty(f,c[l>>2]|0,c[l+4>>2]|0,0)|0;l=DD(a,1)|0;if((l|0)<0){j=l;break}Sy(f);k=k+1|0;if(!(k>>>0<(c[e>>2]|0)>>>0)){break a}}return j|0}}while(0);Ty(f,h,g,0)|0;$Db(d+152|0);$Db(b);j=0;return j|0}function BD(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;do{if((d|0)!=0){if((c[(c[(c[(c[a+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+8>>2]|0)+8>>2]|0)!=0){break}c[d+48>>2]=2}}while(0);return _W(a,b,d,e,740,246)|0}function CD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[a+12>>2]|0;f=c[a+28>>2]|0;a=e+48|0;g=e+44|0;e=c[f+(c[d+32>>2]<<2)>>2]|0;h=c[e+12>>2]|0;i=d+16|0;d=c[i>>2]|0;j=c[i+4>>2]|0;if((c[(c[e+8>>2]|0)+8>>2]|0)==1){e=c[a>>2]|0;i=c[g>>2]|0;k=gHb(i,(i|0)<0|0?-1:0,48e3,0)|0;i=HDb(d,j,e,(e|0)<0|0?-1:0,k,F,3)|0;l=i&-2}else{l=d}d=c[f+(c[b+32>>2]<<2)>>2]|0;f=c[d+12>>2]|0;i=b+16|0;b=c[i>>2]|0;k=c[i+4>>2]|0;if((c[(c[d+8>>2]|0)+8>>2]|0)==1){d=c[a>>2]|0;a=c[g>>2]|0;g=gHb(a,(a|0)<0|0?-1:0,48e3,0)|0;a=HDb(b,k,d,(d|0)<0|0?-1:0,g,F,3)|0;m=a&-2}else{m=b}if((m|0)>(l|0)){n=1;return n|0}if((m|0)!=(l|0)){n=0;return n|0}n=(c[f+92>>2]|0)>>>0>(c[h+92>>2]|0)>>>0|0;return n|0}function DD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=a+12|0;f=c[e>>2]|0;g=a+16|0;h=c[g>>2]|0;j=Ty(h,0,0,1)|0;k=F;if((b|0)==0){b=f+164|0;l=c[b>>2]|0;m=f+160|0;do{if(((l>>>0)%30|0|0)==0){f=bEb(m,l+30|0,8)|0;if((f|0)>=0){n=c[b>>2]|0;break}c[b>>2]=0;yDb(a,16,2030152,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=f;i=d;return p|0}else{n=l}}while(0);c[b>>2]=n+1;b=(c[m>>2]|0)+(n<<3)|0;c[b>>2]=j;c[b+4>>2]=k}Zy(h,0);Py(h,1);Py(h,188);Zy(h,0);Zy(h,0);Py(h,225);Py(h,226);Py(h,224);Py(h,255);b=c[e>>2]|0;n=c[g>>2]|0;m=a+32|0;l=cc(m|0,47)|0;f=Ty(n,0,0,1)|0;o=F;fz(n,0);q=(l|0)==0?m:l+1|0;l=SGb(q|0)|0;Py(n,64);Py(n,l+18|0);Ry(n,1884440,17);Ry(n,q,l);Py(n,0);Py(n,65);Py(n,4);Zy(n,0);Py(n,66);Py(n,4);l=b+4|0;Zy(n,c[l>>2]|0);Py(n,67);Py(n,4);Zy(n,0);Py(n,68);Py(n,4);Zy(n,c[l>>2]|0);Py(n,69);Py(n,4);l=Wy(n)|0;b=eHb(l,F,1024,0)|0;Zy(n,b);b=Ty(n,0,0,1)|0;l=F;Ty(n,f,o,0)|0;q=ZGb(-2,0,f,o)|0;o=YGb(q,F,b,l)|0;fz(n,o);Ty(n,b,l,0)|0;l=c[e>>2]|0;e=c[g>>2]|0;g=Ty(e,0,0,1)|0;b=F;fz(e,0);n=a+24|0;if((c[n>>2]|0)==0){r=0}else{o=a+28|0;q=0;while(1){HD(a,c[(c[(c[o>>2]|0)+(q<<2)>>2]|0)+12>>2]|0,q);f=q+1|0;m=c[n>>2]|0;if(f>>>0<m>>>0){q=f}else{r=m;break}}}HD(a,l+56|0,r);r=Ty(e,0,0,1)|0;l=F;Ty(e,g,b,0)|0;a=ZGb(-2,0,g,b)|0;b=YGb(a,F,r,l)|0;fz(e,b);Ty(e,r,l,0)|0;l=GD(h,j,k)|0;p=l;i=d;return p|0}function ED(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=Ty(b,0,0,1)|0;e=F;f=c[a+4>>2]|0;g=(((f+1|0)>>>0)/1e3|0)+1|0;h=(f>>>0)/(g>>>0)|0;Zy(b,0);Py(b,1);Py(b,252);Zy(b,0);Zy(b,0);Py(b,225);Py(b,226);Yy(b,g);Yy(b,h);f=a+152|0;a=c[f>>2]|0;do{if((a|0)!=0&(h|0)>0){i=0;j=a;while(1){Yy(b,c[j+((ba(i,g)|0)>>1<<2)>>2]|0);k=i+1|0;if((k|0)>=(h|0)){break}i=k;j=c[f>>2]|0}if((h|0)<1e3){l=h;break}m=GD(b,d,e)|0;n=F;return}else{l=0}}while(0);do{Yy(b,0);l=l+1|0;}while((l|0)<1e3);m=GD(b,d,e)|0;n=F;return}function FD(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=a+12|0;f=c[d>>2]|0;g=a+16|0;h=c[g>>2]|0;i=Ty(h,0,0,1)|0;j=F;Zy(h,0);Py(h,1);Py(h,253);Zy(h,0);Zy(h,0);Py(h,225);Py(h,226);Py(h,3);k=f+36|0;Zy(h,c[k>>2]|0);l=Ty(h,0,0,1)|0;m=f+24|0;c[m>>2]=l;l=c[d>>2]|0;n=c[g>>2]|0;o=l+36|0;Yy(n,c[o>>2]|0);Yy(n,3);p=a+24|0;Yy(n,(c[p>>2]|0)+1|0);Yy(n,c[l+28>>2]|0);Yy(n,e[l+40>>1]|0);Yy(n,(c[p>>2]|0)+1|0);Yy(n,c[l+32>>2]|0);Yy(n,e[l+42>>1]|0);Yy(n,c[o>>2]|0);Yy(n,0);Yy(n,0);Yy(n,0);n=c[d>>2]|0;o=c[g>>2]|0;l=(c[n+48>>2]|0)==6e4?60:50;q=BBb(c[a+1140>>2]|0,2080328,0,0)|0;if((q|0)==0){r=0;s=0}else{t=bU(c[q+4>>2]|0)|0;r=F;s=t}t=c[n+192>>2]<<29|c[n+188>>2]<<30;q=c[n+172>>2]|0;u=c[n+176>>2]|0;v=c[n+180>>2]|0;w=c[n+184>>2]|0;x=n+4|0;y=l*3600|0;z=l*60|0;A=(ba(u,z)|0)+(ba(q,y)|0)+(ba(v,l)|0)+w+(c[x>>2]|0)|0;Yy(o,c[n+52>>2]|0);Yy(o,c[x>>2]|0);Yy(o,c[x>>2]|0);Yy(o,0);Yy(o,c[x>>2]|0);Yy(o,t|q<<24|u<<16|v<<8|w);Yy(o,((((A>>>0)/(y>>>0)|0)>>>0)%24|0)<<24|t|((((A>>>0)/(z>>>0)|0)>>>0)%60|0)<<16|((((A>>>0)/(l>>>0)|0)>>>0)%60|0)<<8|((A>>>0)%(l>>>0)|0));dz(o,s,r);dz(o,s,r);az(o,0);az(o,0);az(o,e[n+8>>1]|0);az(o,1);az(o,0);az(o,e[n+10>>1]|0);n=c[g>>2]|0;o=c[d>>2]|0;r=Ty(n,0,0,1)|0;s=F;l=ZGb(r,s,c[o+24>>2]|0,0)|0;c[o+28>>2]=l;l=a+28|0;if((c[p>>2]|0)!=0){a=0;do{az(n,e[(c[(c[(c[l>>2]|0)+(a<<2)>>2]|0)+12>>2]|0)+54>>1]|0);az(n,1);a=a+1|0;}while(a>>>0<(c[p>>2]|0)>>>0)}az(n,e[o+110>>1]|0);az(n,1);o=Ty(n,0,0,1)|0;n=ZGb(o,F,r,s)|0;b[f+40>>1]=n;n=c[d>>2]|0;d=c[g>>2]|0;g=Ty(d,0,0,1)|0;s=F;r=ZGb(g,s,c[n+24>>2]|0,0)|0;c[n+32>>2]=r;r=n+56|0;o=n+4|0;a=n+192|0;n=0;A=c[p>>2]|0;do{if((n|0)==(A|0)){B=r}else{B=c[(c[(c[l>>2]|0)+(n<<2)>>2]|0)+12>>2]|0}z=Ty(d,0,0,1)|0;t=F;az(d,0);y=B+54|0;az(d,e[y>>1]|0);az(d,0);az(d,0);Yy(d,c[o>>2]|0);Yy(d,0);Yy(d,0);Yy(d,c[o>>2]|0);Ry(d,2147544,20);fz(d,e[y>>1]|0);y=22;do{Py(d,0);y=y+1|0;}while((y|0)<88);Yy(d,c[B+40>>2]|0);Yy(d,c[B+48>>2]|0);Yy(d,c[B+44>>2]|0);Yy(d,0);do{if((B|0)==(r|0)){Yy(d,c[a>>2]|0);Yy(d,0);Yy(d,0);Yy(d,0);Yy(d,0);Yy(d,0);Yy(d,0);Yy(d,0)}else{y=c[(c[l>>2]|0)+(n<<2)>>2]|0;w=y+8|0;v=c[w>>2]|0;u=c[v+48>>2]|0;if((u|0)==25){Yy(d,(c[v+140>>2]|0)==0?32:0);Yy(d,0);Yy(d,0);Yy(d,0);Yy(d,0);Yy(d,0);Yy(d,0);Yy(d,0);break}else if((u|0)==1|(u|0)==2){q=c[y+12>>2]|0;if((c[v+140>>2]|0)==4){Yy(d,2)}else{Yy(d,1)}Yy(d,(c[q+88>>2]|0)==1|0);Yy(d,3);Yy(d,1);Yy(d,c[q+80>>2]|0);Yy(d,c[q+84>>2]|0);q=c[(c[w>>2]|0)+48>>2]|0;if((q|0)==1){Yy(d,1)}else if((q|0)==2){Yy(d,2)}else{Yy(d,0)}Yy(d,0);break}else if((u|0)==65536){dz(d,0,1072693248);dz(d,0,1072693248);Yy(d,0);Yy(d,0);Yy(d,0);Yy(d,0);break}else{break}}}while(0);u=Ty(d,0,0,1)|0;q=F;Ty(d,z,t,0)|0;w=ZGb(u,q,z,t)|0;az(d,w);Ty(d,u,q,0)|0;n=n+1|0;A=c[p>>2]|0;}while(!(n>>>0>A>>>0));A=Ty(d,0,0,1)|0;d=ZGb(A,F,g,s)|0;b[f+42>>1]=d;d=Ty(h,0,0,1)|0;f=ZGb(d,F,c[m>>2]|0,0)|0;c[k>>2]=f;GD(h,i,j)|0;return}function GD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Ty(a,0,0,1)|0;e=ZGb(d,F,b,c)|0;d=e;e=(d|0)%4|0;if((e|0)==0){f=d}else{d=4-e|0;if((d|0)>0){e=(d|0)<0|0?-1:0;g=d;do{Py(a,0);g=YGb(g,e,-1,-1)|0;e=F;d=0;}while((e|0)>(d|0)|(e|0)==(d|0)&g>>>0>0>>>0)}g=Ty(a,0,0,1)|0;e=ZGb(g,F,b,c)|0;f=e}e=Ty(a,0,0,1)|0;g=F;d=YGb(b,c,6,0)|0;Ty(a,d,F,0)|0;Zy(a,f);Ty(a,e,g,0)|0;a=ZGb(e,g,b,c)|0;return(F=F,a)|0}function HD(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+1024|0;g=c[a+12>>2]|0;j=c[a+16>>2]|0;Py(j,(e[b+52>>1]|0)+128|0);Py(j,d+192|0);k=Ty(j,0,0,1)|0;l=F;fz(j,0);Py(j,76);Py(j,23);Ry(j,2147544,20);fz(j,e[b+54>>1]|0);Py(j,0);a:do{switch(c[b+40>>2]|0){case 5:case 6:{m=c[(c[a+28>>2]|0)+(d<<2)>>2]|0;Py(j,77);Py(j,8);n=(c[(c[m+8>>2]|0)+140>>2]|0)==0;dz(j,n?1073741825:1073741824,n?0:0);break};case 4:case 9:{n=c[(c[a+28>>2]|0)+(d<<2)>>2]|0;m=f|0;o=c[n+12>>2]|0;p=c[o+68>>2]|0;do{if((p|0)!=0){q=c[o+72>>2]|0;r=o+80|0;s=(((q|0)%(p|0)|0|0)!=0)+((q|0)/(p|0)|0)|0;c[r>>2]=s;do{if((q|0)!=0){t=c[o+76>>2]|0;u=(t|0)/(q|0)|0;v=o+84|0;c[v>>2]=u;if(((t|0)%(q|0)|0|0)==0){break}c[v>>2]=u+1}}while(0);if((s|0)>9){c[r>>2]=9}q=o+84|0;if((c[q>>2]|0)<=9){break}c[q>>2]=9}}while(0);p=c[n+8>>2]|0;q=c[p+124>>2]|0;if((q|0)==512|(q|0)==608){w=7}else if((q|0)==480){w=20}else{w=23}u=c[o+80>>2]|0;v=c[o+84>>2]|0;t=(c[p+140>>2]|0)==4?2:1;x=(c[o+88>>2]|0)==1|0;y=Lb(m|0,1024,1985936,(z=i,i=i+56|0,h[z>>3]=+(c[p+72>>2]|0),c[z+8>>2]=u,c[z+16>>2]=v,c[z+24>>2]=t,c[z+32>>2]=x,c[z+40>>2]=w,c[z+48>>2]=(q+15|0)/16|0,z)|0)|0;i=z;if(y>>>0<1024>>>0){Py(j,79);q=y+1|0;Py(j,q);Ry(j,m,q);break a}else{yDb(0,0,1953784,(z=i,i=i+24|0,c[z>>2]=1927160,c[z+8>>2]=1905216,c[z+16>>2]=213,z)|0);i=z;Cd()}break};case 3:{z=c[g+192>>2]<<29|c[g+188>>2]<<30|c[g+172>>2]<<24|c[g+176>>2]<<16|c[g+180>>2]<<8|c[g+184>>2];Py(j,77);Py(j,8);Yy(j,z);Yy(j,0);break};default:{Py(j,77);Py(j,8);dz(j,0,0)}}}while(0);Py(j,78);Py(j,4);Zy(j,0);Py(j,80);Py(j,4);Zy(j,c[b+56>>2]|0);Py(j,81);Py(j,4);Zy(j,c[b+60>>2]|0);Py(j,82);Py(j,4);Zy(j,c[b+64>>2]|0);b=Ty(j,0,0,1)|0;g=F;Ty(j,k,l,0)|0;w=ZGb(-2,0,k,l)|0;l=YGb(w,F,b,g)|0;fz(j,l);Ty(j,b,g,0)|0;i=f;return}function ID(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[a+8>>2]|0;if((b|0)>0){e=c[a+4>>2]|0;a=0;f=0;g=0;h=0;i=0;while(1){j=e+i|0;k=i+1|0;do{if((((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)-1|0)>>>0<255>>>0){l=d[1191992+(d[e+k|0]|0)|0]|0;m=i-1|0;n=e+((m|0)>0?m:0)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;m=$Gb(fe(n|0)|0,o|0,l+24|0)|0;l=m;if((l&-65536|0)!=65536){p=h;q=g;r=f;s=a;break}m=l>>>12&15;o=(m|0)==0?l&8:g;l=(m|0)==(f|0)|0;n=(l^1)+a|0;t=l+h|0;if((o|0)==0){p=t;q=0;r=c[985576+(m<<2)>>2]|0;s=n;break}else{p=t;q=o;r=c[985640+(m<<2)>>2]|0;s=n;break}}else{p=h;q=g;r=f;s=a}}while(0);if((k|0)<(b|0)){a=s;f=r;g=q;h=p;i=k}else{u=s;v=p;break}}}else{u=0;v=0}p=u<<1;if((v|0)>(p+6|0)){w=50;return w|0}w=(v|0)>(p+2|0)?25:0;return w|0}function JD(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[b+8>>2]|0;if((d|0)>0){e=c[b+4>>2]|0;b=0;f=0;g=0;h=0;i=-1;j=-256;k=-1;l=0;while(1){m=a[e+b|0]|0;n=m&255|j;o=i|0;do{if((j&-262144|0)==8388608&(i&255|0)==0){p=(m&255)>>>2&3;q=(j&768|0)!=512|(i&0|0)!=0|(p|0)==0;r=q&1;s=q?l:0;t=p;u=((p|0)!=(k|0)&(k|0)>0&(k|0)<6&1)+h|0;v=r+g|0;w=(r^1)+f|0}else{if(!((j&-8388608|0)==8388608&(i&255|0)==0)){s=l;t=k;u=h;v=g;w=f;break}r=(j>>>18|i<<14)&31;p=(r|0)<(l|0);s=p?l:r;t=k;u=h;v=(p&1)+g|0;w=f}}while(0);m=b+1|0;if((m|0)<(d|0)){b=m;f=w;g=v;h=u;i=o<<8|n>>>24;j=n<<8|0>>>24;k=t;l=s}else{x=w;y=v;z=u;break}}}else{x=0;y=0;z=0}u=y<<1;if((x|0)>(u+3+(z<<1)|0)){A=50;return A|0}A=(x|0)>(u|0)?25:0;return A|0}function KD(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=c[b+8>>2]|0;do{if((e|0)>0){f=c[b+4>>2]|0;g=0;h=0;i=0;j=0;k=0;l=0;m=-256;a:while(1){n=d[f+l|0]|0;o=n|m;do{if((m|0)==256){p=n&31;if((n&128|0)!=0){q=0;r=18;break a}s=(n&96|0)==0;if(!((7744>>>(p>>>0)&1|0)==0|s)){q=0;r=18;break a}if((8608>>>(p>>>0)&1|0)!=0&s){q=0;r=18;break a}s=(-540671>>>(p>>>0)&1)+j|0;if((p|0)==1){t=k+1|0;u=s;v=i;w=h;x=g;break}else if((p|0)==7){if(!((a[f+(l+2)|0]&3)==0)){q=0;r=18;break a}t=k;u=s;v=i;w=h;x=g+1|0;break}else if((p|0)==8){t=k;u=s;v=i;w=h+1|0;x=g;break}else if((p|0)==5){t=k;u=s;v=i+1|0;w=h;x=g;break}else{t=k;u=s;v=i;w=h;x=g;break}}else{t=k;u=j;v=i;w=h;x=g}}while(0);n=l+1|0;if((n|0)<(e|0)){g=x;h=w;i=v;j=u;k=t;l=n;m=o<<8}else{r=14;break}}if((r|0)==14){if((x|0)==0|(w|0)==0){break}if(!((v|0)!=0|(t|0)>3)){break}if((u|0)<(w+x+v|0)){q=51}else{break}return q|0}else if((r|0)==18){return q|0}}}while(0);q=0;return q|0}function LD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=i;d=c[a+12>>2]|0;e=a+32|0;do{if((gb(e|0,511)|0)==0){f=4}else{g=ld()|0;h=(c[g>>2]|0)!=17;yDb(a,h?16:40,2169832,(j=i,i=i+8|0,c[j>>2]=e,j)|0);i=j;if(!h){f=4;break}k=-(c[g>>2]|0)|0;f=39}}while(0);a:do{if((f|0)==4){g=UC(2161696,0,0)|0;if((g|0)==0){l=-1481985528;break}h=a+24|0;m=cEb((c[h>>2]|0)*33888|0)|0;n=m;o=d+20|0;c[o>>2]=n;if((m|0)==0){l=-12;break}m=d+24|0;p=c[m>>2]|0;b:do{if((c[h>>2]|0)==0){q=n;r=p}else{s=a+28|0;t=a+1160|0;u=0;v=p;w=n;x=n+(p*33888|0)|0;while(1){y=c[(c[s>>2]|0)+(u<<2)>>2]|0;z=c[y+8>>2]|0;A=z+72|0;if((c[A>>2]|0)==0){f=9;break}B=c[z+8>>2]|0;if((B|0)==0){if((c[w+(v*33888|0)+33852>>2]|0)==0){C=x}else{z=v+1|0;c[m>>2]=z;C=w+(z*33888|0)|0}c[C+33852>>2]=1;D=C}else if((B|0)==1){if((c[w+(v*33888|0)+33848>>2]|0)==0){E=x}else{B=v+1|0;c[m>>2]=B;E=w+(B*33888|0)|0}c[E+33848>>2]=1;D=E}else{f=17;break}B=D|0;c[B>>2]=(c[B>>2]|0)+(c[A>>2]|0);A=D+8|0;B=c[A>>2]|0;if((B|0)==0){c[D+4>>2]=u;z=tN()|0;if((z|0)==0){l=-12;break a}c[A>>2]=z;c[z+8>>2]=g;A=z+1160|0;F=c[t+4>>2]|0;c[A>>2]=c[t>>2];c[A+4>>2]=F;F=Oy(D+16|0,32768,2,D,0,56,0)|0;c[z+16>>2]=F;if((F|0)==0){l=-12;break a}G=z;H=c[(c[s>>2]|0)+(u<<2)>>2]|0}else{G=B;H=y}c[H+4>>2]=c[m>>2];y=LT(G,0)|0;if((y|0)==0){l=-12;break a}BRa(c[y+8>>2]|0,c[(c[(c[s>>2]|0)+(u<<2)>>2]|0)+8>>2]|0)|0;B=(c[(c[s>>2]|0)+(u<<2)>>2]|0)+80|0;z=y+80|0;y=c[B+4>>2]|0;c[z>>2]=c[B>>2];c[z+4>>2]=y;y=u+1|0;z=c[m>>2]|0;B=c[o>>2]|0;if(y>>>0<(c[h>>2]|0)>>>0){u=y;v=z;w=B;x=B+(z*33888|0)|0}else{q=B;r=z;break b}}if((f|0)==9){yDb(a,16,2155048,(j=i,i=i+8|0,c[j>>2]=u,j)|0);i=j;l=-22;break a}else if((f|0)==17){yDb(a,16,2148048,(j=i,i=i+8|0,c[j>>2]=u,j)|0);i=j;l=-22;break a}}}while(0);if((c[q+(r*33888|0)+8>>2]|0)==0){I=r}else{h=r+1|0;c[m>>2]=h;I=h}c:do{if((I|0)>0){h=d+12|0;g=a;p=a+28|0;n=0;x=q;while(1){w=x+(n*33888|0)|0;v=x+(n*33888|0)+8|0;s=FK(c[v>>2]|0,0)|0;if((s|0)<0){l=s;break a}c[x+(n*33888|0)+12>>2]=1;Sy(c[(c[v>>2]|0)+16>>2]|0);s=c[v>>2]|0;if((c[s+24>>2]|0)!=0){t=x+(n*33888|0)+4|0;z=0;B=s;do{s=(c[(c[B+28>>2]|0)+(z<<2)>>2]|0)+40|0;y=(c[(c[p>>2]|0)+((c[t>>2]|0)+z<<2)>>2]|0)+40|0;F=c[s+4>>2]|0;c[y>>2]=c[s>>2];c[y+4>>2]=F;z=z+1|0;B=c[v>>2]|0;}while(z>>>0<(c[B+24>>2]|0)>>>0)}Lb(x+(n*33888|0)+32784|0,1024,2141512,(j=i,i=i+16|0,c[j>>2]=e,c[j+8>>2]=n,j)|0)|0;i=j;B=RD(a,w,0,0)|0;if((B|0)<0){l=B;break a}do{if((c[x+(n*33888|0)+33852>>2]|0)==0){if((c[h>>2]|0)>=1){break}yDb(g,24,2135592,(j=i,i=i+8|0,c[j>>2]=n,j)|0);i=j}}while(0);c[x+(n*33888|0)+33840>>2]=1;SD(a,w,0)|0;B=n+1|0;if((B|0)>=(c[m>>2]|0)){break c}n=B;x=c[o>>2]|0}}}while(0);k=PD(a,0)|0;f=39}}while(0);do{if((f|0)==39){if((k|0)==0){J=0}else{l=k;break}i=b;return J|0}}while(0);QD(a);J=l;i=b;return J|0}function MD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=b+32|0;h=c[(c[a+28>>2]|0)+(c[g>>2]<<2)>>2]|0;j=c[h+4>>2]|0;k=c[f+20>>2]|0;l=k+(j*33888|0)|0;m=c[k+(j*33888|0)+33840>>2]|0;n=c[f+12>>2]|0;f=gHb(n,(n|0)<0|0?-1:0,m,(m|0)<0|0?-1:0)|0;m=F;n=h+200|0;o=c[n>>2]|0;p=c[n+4>>2]|0;if((o|0)==0&(p|0)==(-2147483648|0)){q=b+16|0;r=c[q>>2]|0;s=c[q+4>>2]|0;c[n>>2]=r;c[n+4>>2]=s;t=s;u=r}else{t=p;u=o}if((c[k+(j*33888|0)+33852>>2]|0)==0){v=5}else{if((c[(c[h+8>>2]|0)+8>>2]|0)==0){v=5}}do{if((v|0)==5){o=b+16|0;p=ZGb(c[o>>2]|0,c[o+4>>2]|0,u,t)|0;c[e>>2]=1;c[e+4>>2]=1e6;if(!((LDb(p,F,h+40|0,f,m,e)|0)>-1)){break}if((c[b+36>>2]&1|0)==0){break}if((c[k+(j*33888|0)+33828>>2]|0)==0){break}p=OD(a,l,0,c[o>>2]|0,c[o+4>>2]|0)|0;if((p|0)<0){w=p}else{break}i=d;return w|0}}while(0);l=k+(j*33888|0)+33828|0;e=c[l>>2]|0;m=b+16|0;if((e|0)==0){f=c[m+4>>2]|0;h=k+(j*33888|0)+33808|0;c[h>>2]=c[m>>2];c[h+4>>2]=f}f=c[m+4>>2]|0;h=k+(j*33888|0)+33816|0;c[h>>2]=c[m>>2];c[h+4>>2]=f;c[l>>2]=e+1;w=OK(c[k+(j*33888|0)+8>>2]|0,(c[g>>2]|0)-(c[k+(j*33888|0)+4>>2]|0)|0,b,a)|0;i=d;return w|0}function ND(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+1024|0;d=b|0;e=c[a+12>>2]|0;f=e+24|0;if((c[f>>2]|0)>0){g=e+20|0;h=0;do{j=c[g>>2]|0;k=j+(h*33888|0)+33816|0;OD(a,j+(h*33888|0)|0,1,c[k>>2]|0,c[k+4>>2]|0)|0;h=h+1|0;}while((h|0)<(c[f>>2]|0))}PD(a,1)|0;if((c[e+16>>2]|0)==0){QD(a);i=b;return 0}e=d|0;d=a+32|0;Lb(e|0,1024,2147192,(h=i,i=i+8|0,c[h>>2]=d,h)|0)|0;i=h;Zd(e|0)|0;if((c[f>>2]|0)>0){g=0;do{Lb(e|0,1024,2079936,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=g,h)|0)|0;i=h;Zd(e|0)|0;g=g+1|0;}while((g|0)<(c[f>>2]|0))}_c(d|0)|0;QD(a);i=b;return 0}function OD(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+1024|0;h=c[a+12>>2]|0;j=b+33828|0;if((c[j>>2]|0)==0){k=0;i=g;return k|0}l=c[(c[(c[a+28>>2]|0)+(c[b+4>>2]<<2)>>2]|0)+4>>2]|0;Sy(c[(c[b+8>>2]|0)+16>>2]|0);c[j>>2]=0;j=b+33824|0;m=Ty(c[j>>2]|0,0,0,1)|0;Ty(c[j>>2]|0,0,0,0)|0;Zy(c[j>>2]|0,m);Sy(c[j>>2]|0);Iz(c[j>>2]|0)|0;c[j>>2]=0;j=g|0;m=b+33840|0;n=c[m>>2]|0;Lb(j|0,1024,2197136,(o=i,i=i+24|0,c[o>>2]=a+32,c[o+8>>2]=l,c[o+16>>2]=n,o)|0)|0;i=o;n=b+32784|0;if((Bc(n|0,j|0)|0)==-1){yDb(a,16,2204736,(o=i,i=i+16|0,c[o>>2]=n,c[o+8>>2]=j,o)|0);i=o;k=-(c[(ld()|0)>>2]|0)|0;i=g;return k|0}o=b+33808|0;n=c[o>>2]|0;l=c[o+4>>2]|0;o=ZGb(e,f,n,l)|0;p=(n|0)==(e|0)&(l|0)==(f|0);q=p?1:o;o=p?0:F;p=b+33832|0;r=b+33836|0;s=c[r>>2]|0;do{if((c[p>>2]|0)<(s|0)){t=7}else{u=(s<<1)+2|0;c[r>>2]=u;if((bEb(b+33844|0,u,4)|0)>=0){t=7;break}c[r>>2]=0;c[p>>2]=0}}while(0);do{if((t|0)==7){r=cEb(1048)|0;if((r|0)==0){break}sAb(r,j,1024)|0;s=r+1024|0;c[s>>2]=n;c[s+4>>2]=l;s=r+1032|0;c[s>>2]=q;c[s+4>>2]=o;s=c[m>>2]|0;c[r+1040>>2]=s;u=c[p>>2]|0;c[p>>2]=u+1;c[(c[b+33844>>2]|0)+(u<<2)>>2]=r;c[m>>2]=s+1}}while(0);m=(d|0)!=0;do{if(m){v=0}else{o=RD(a,b,e,f)|0;if((o|0)<0){k=o}else{v=o;break}i=g;return k|0}}while(0);f=c[h+4>>2]|0;do{if((f|0)==0){if(!m){break}e=c[h+16>>2]|0;if((e|0)==0){break}o=c[p>>2]|0;w=o;x=o-(c[h+8>>2]|0)|0;y=e;t=17}else{e=c[p>>2]|0;o=e-f-(c[h+8>>2]|0)|0;if(!m){z=o;t=18;break}w=e;x=o;y=c[h+16>>2]|0;t=17}}while(0);if((t|0)==17){z=(y|0)==0?x:w;t=18}do{if((t|0)==18){if((z|0)<=0){break}w=b+33844|0;x=0;do{Zd(c[(c[w>>2]|0)+(x<<2)>>2]|0)|0;ZDb(c[(c[w>>2]|0)+(x<<2)>>2]|0);x=x+1|0;}while((x|0)<(z|0));x=(c[p>>2]|0)-z|0;c[p>>2]=x;y=c[w>>2]|0;VGb(y|0,y+(z<<2)|0,x<<2|0)|0}}while(0);if(!((v|0)>-1)){k=v;i=g;return k|0}k=SD(a,b,d)|0;i=g;return k|0}function PD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+2056|0;e=d|0;f=c[a+12>>2]|0;g=f+24|0;if((c[g>>2]|0)>0){j=(c[f+20>>2]|0)+33816|0;k=c[c[a+28>>2]>>2]|0;l=(+((c[j>>2]|0)>>>0)+ +(c[j+4>>2]|0)*4294967296.0)*(+(c[k+40>>2]|0)/+(c[k+44>>2]|0))}else{l=0.0}k=d+8|0;j=a+32|0;Lb(k|0,1024,2147192,(m=i,i=i+8|0,c[m>>2]=j,m)|0)|0;i=m;n=d+1032|0;Lb(n|0,1024,2030008,(m=i,i=i+8|0,c[m>>2]=j,m)|0)|0;i=m;o=Hz(e,n,2,a+1160|0,0)|0;if((o|0)<0){yDb(a,16,1985792,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;p=o;i=d;return p|0}Kz(c[e>>2]|0,1953704,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;Kz(c[e>>2]|0,1927088,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;o=c[e>>2]|0;q=AAb(j)|0;Kz(o,1905160,(m=i,i=i+8|0,c[m>>2]=q,m)|0)|0;i=m;q=(b|0)!=0;Kz(c[e>>2]|0,1884376,(m=i,i=i+8|0,c[m>>2]=q?2342624:2319992,m)|0)|0;i=m;Kz(c[e>>2]|0,2297672,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;if(q){Kz(c[e>>2]|0,2280640,(m=i,i=i+8|0,h[m>>3]=l,m)|0)|0;i=m}a:do{if((c[g>>2]|0)>0){q=f+20|0;b=0;while(1){o=c[q>>2]|0;j=o+(b*33888|0)+33860|0;r=(((c[j>>2]|0)+2|0)/3|0)<<2|1;s=WDb(r)|0;if((s|0)==0){break}HAb(s,r,c[o+(b*33888|0)+33856>>2]|0,c[j>>2]|0)|0;Kz(c[e>>2]|0,2265496,(m=i,i=i+16|0,c[m>>2]=b,c[m+8>>2]=b,m)|0)|0;i=m;Kz(c[e>>2]|0,2250416,(m=i,i=i+24|0,c[m>>2]=(c[o+(b*33888|0)>>2]|0)/1e3|0,c[m+8>>2]=b,c[m+16>>2]=b,m)|0)|0;i=m;Kz(c[e>>2]|0,2236704,(m=i,i=i+8|0,c[m>>2]=s,m)|0)|0;i=m;Kz(c[e>>2]|0,2224024,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;ZDb(s);b=b+1|0;if((b|0)>=(c[g>>2]|0)){break a}}Iz(c[e>>2]|0)|0;p=-12;i=d;return p|0}}while(0);Kz(c[e>>2]|0,2214384,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;Sy(c[e>>2]|0);Iz(c[e>>2]|0)|0;if(!((Bc(n|0,k|0)|0)==-1)){p=0;i=d;return p|0}yDb(a,16,2204736,(m=i,i=i+16|0,c[m>>2]=n,c[m+8>>2]=k,m)|0);i=m;p=-(c[(ld()|0)>>2]|0)|0;i=d;return p|0}function QD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(c[a+12>>2]|0)+20|0;d=b;e=c[d>>2]|0;if((e|0)==0){return}f=a+24|0;a:do{if((c[f>>2]|0)!=0){a=0;g=e;while(1){h=g+(a*33888|0)+33824|0;i=c[h>>2]|0;if((i|0)!=0){Iz(i)|0}c[h>>2]=0;h=g+(a*33888|0)+8|0;i=c[h>>2]|0;do{if((i|0)!=0){if((c[g+(a*33888|0)+12>>2]|0)==0){j=i}else{NK(i)|0;k=c[h>>2]|0;if((k|0)==0){break}else{j=k}}k=c[j+16>>2]|0;if((k|0)==0){l=j}else{ZDb(k);l=c[h>>2]|0}if((l|0)==0){break}bT(l)}}while(0);ZDb(c[g+(a*33888|0)+33856>>2]|0);h=g+(a*33888|0)+33880|0;if((c[h>>2]|0)>0){i=0;do{ZDb(c[g+(a*33888|0)+33864+(i<<2)>>2]|0);i=i+1|0;}while((i|0)<(c[h>>2]|0))}h=g+(a*33888|0)+33832|0;i=g+(a*33888|0)+33844|0;k=c[i>>2]|0;if((c[h>>2]|0)>0){m=0;n=k;while(1){ZDb(c[n+(m<<2)>>2]|0);o=m+1|0;p=c[i>>2]|0;if((o|0)<(c[h>>2]|0)){m=o;n=p}else{q=p;break}}}else{q=k}ZDb(q);n=a+1|0;if(!(n>>>0<(c[f>>2]|0)>>>0)){break a}a=n;g=c[d>>2]|0}}}while(0);$Db(b);return}function RD(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=d+33824|0;h=Hz(g,d+32784|0,2,b+1160|0,0)|0;if((h|0)<0){i=h;return i|0}Zy(c[g>>2]|0,0);Yy(c[g>>2]|0,1952539757);h=d+33880|0;if((c[h>>2]|0)<=0){i=0;return i|0}b=e&255;j=(e>>>8|f<<24)&255;k=(e>>>16|f<<16)&255;l=(e>>>24|f<<8)&127;f=0;while(1){e=d+33864+(f<<2)|0;a[(c[e>>2]|0)+6|0]=b;a[(c[e>>2]|0)+5|0]=j;a[(c[e>>2]|0)+4|0]=k;a[(c[e>>2]|0)+7|0]=l;Ry(c[g>>2]|0,c[e>>2]|0,c[d+33872+(f<<2)>>2]|0);e=f+1|0;if((e|0)<(c[h>>2]|0)){f=e}else{i=0;break}}return i|0}function SD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+2056|0;f=e|0;g=e+8|0;h=e+1032|0;j=c[(c[(c[a+28>>2]|0)+(c[b+4>>2]<<2)>>2]|0)+4>>2]|0;k=c[(c[a+12>>2]|0)+4>>2]|0;l=c[b+33832>>2]|0;if((k|0)==0){m=0}else{n=l-k|0;m=(n|0)>0?n:0}n=b+33832|0;k=l-m|0;o=(d|0)!=0;do{if(o){d=b+33816|0;p=c[d+4>>2]|0;q=c[d>>2]|0}else{if((l|0)==0){p=0;q=0;break}d=(c[(c[b+33844>>2]|0)+(l-1<<2)>>2]|0)+1024|0;p=c[d+4>>2]|0;q=c[d>>2]|0}}while(0);l=g|0;g=a+32|0;Lb(l|0,1024,2079936,(d=i,i=i+16|0,c[d>>2]=g,c[d+8>>2]=j,d)|0)|0;i=d;r=h|0;Lb(r|0,1024,2184912,(d=i,i=i+16|0,c[d>>2]=g,c[d+8>>2]=j,d)|0)|0;i=d;j=Hz(f,r,2,a+1160|0,0)|0;if((j|0)<0){yDb(a,16,1985792,(d=i,i=i+8|0,c[d>>2]=r,d)|0);i=d;s=j;i=e;return s|0}Zy(c[f>>2]|0,0);Yy(c[f>>2]|0,1953718881);Zy(c[f>>2]|0,0);j=b+33840|0;Zy(c[f>>2]|0,(c[j>>2]|0)-1|0);Py(c[f>>2]|0,o?0:32);Zy(c[f>>2]|0,1e3);ez(c[f>>2]|0,q,p);ez(c[f>>2]|0,0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,1);p=Ty(c[f>>2]|0,0,0,1)|0;q=F;Zy(c[f>>2]|0,0);Yy(c[f>>2]|0,1953657697);Zy(c[f>>2]|0,0);Py(c[f>>2]|0,0);Zy(c[f>>2]|0,1);Zy(c[f>>2]|0,1);if(o){t=(c[j>>2]|0)-1|0}else{t=-1}Zy(c[f>>2]|0,t);t=c[f>>2]|0;j=Ty(t,0,0,1)|0;o=F;Ty(t,p,q,0)|0;g=ZGb(j,o,p,q)|0;Zy(t,g);Ty(t,j,o,0)|0;Py(c[f>>2]|0,1);o=Ty(c[f>>2]|0,0,0,1)|0;j=F;Zy(c[f>>2]|0,0);Yy(c[f>>2]|0,1953654369);Zy(c[f>>2]|0,0);Zy(c[f>>2]|0,1e3);Py(c[f>>2]|0,0);Zy(c[f>>2]|0,k);k=c[f>>2]|0;if((m|0)<(c[n>>2]|0)){t=b+33844|0;b=m;m=k;while(1){Zy(m,c[(c[(c[t>>2]|0)+(b<<2)>>2]|0)+1040>>2]|0);g=(c[(c[t>>2]|0)+(b<<2)>>2]|0)+1024|0;ez(c[f>>2]|0,c[g>>2]|0,c[g+4>>2]|0);Zy(c[f>>2]|0,c[(c[(c[t>>2]|0)+(b<<2)>>2]|0)+1032>>2]|0);g=b+1|0;q=c[f>>2]|0;if((g|0)<(c[n>>2]|0)){b=g;m=q}else{u=q;break}}}else{u=k}k=Ty(u,0,0,1)|0;m=F;Ty(u,o,j,0)|0;b=ZGb(k,m,o,j)|0;Zy(u,b);Ty(u,k,m,0)|0;m=c[f>>2]|0;k=Ty(m,0,0,1)|0;u=F;Ty(m,0,0,0)|0;Zy(m,k);Ty(m,k,u,0)|0;Iz(c[f>>2]|0)|0;if(!((Bc(r|0,l|0)|0)==-1)){s=0;i=e;return s|0}yDb(a,16,2204736,(d=i,i=i+16|0,c[d>>2]=r,c[d+8>>2]=l,d)|0);i=d;s=-(c[(ld()|0)>>2]|0)|0;i=e;return s|0}function TD(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=b;h=c[b+33824>>2]|0;do{if((h|0)==0){i=b+33860|0;if((c[i>>2]|0)!=0){break}if((f|0)<13){j=-1094995529;return j|0}if((PGb(e,2129544,3)|0)!=0){j=-1094995529;return j|0}k=f-13|0;a:do{if((k|0)>14){l=b+33880|0;m=b+33856|0;n=k;o=e+13|0;b:while(1){p=a[o]|0;q=(d[o+2|0]|0)<<8|(d[o+1|0]|0)<<16|(d[o+3|0]|0);r=q+15|0;if((r|0)>(n|0)){j=-1094995529;s=21;break}do{if((p-8&255)>>>0<2>>>0){t=c[l>>2]|0;if(t>>>0>1>>>0){j=-1094995529;s=21;break b}c[g+33872+(t<<2)>>2]=r;t=WDb(r)|0;c[g+33864+(c[l>>2]<<2)>>2]=t;t=c[g+33864+(c[l>>2]<<2)>>2]|0;if((t|0)==0){j=-12;s=21;break b}UGb(t|0,o|0,r)|0;c[l>>2]=(c[l>>2]|0)+1}else{if(!(p<<24>>24==18)){break}if((c[m>>2]|0)!=0){j=-1094995529;s=21;break b}c[i>>2]=q;t=WDb(q)|0;c[m>>2]=t;if((t|0)==0){j=-12;s=21;break b}UGb(t|0,o+11|0,c[i>>2]|0)|0}}while(0);q=n-r|0;if((q|0)>14){n=q;o=o+r|0}else{u=m;break a}}if((s|0)==21){return j|0}}else{u=b+33856|0}}while(0);i=(c[u>>2]|0)==0;if(i){j=i?-1094995529:0}else{break}return j|0}else{Ry(h,e,f)}}while(0);j=f;return j|0}function UD(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=(c[a+8>>2]|0)-1|0;a:do{if((b|0)>0){e=c[a+4>>2]|0;f=0;g=0;h=0;i=0;j=0;k=-256;b:while(1){l=d[e+j|0]|0;m=l|k;c:do{if((k|0)==256){if((l&129|0)!=0){n=14;break b}o=j+1|0;if((d[e+o|0]|0)>>>0>7>>>0){n=14;break b}switch(l>>>1&63|0){case 32:{p=i;q=h;r=g;s=f+1|0;t=o;break c;break};case 34:{p=i;q=h+1|0;r=g;s=f;t=o;break c;break};case 33:{p=i;q=h;r=g+1|0;s=f;t=o;break c;break};case 18:case 16:case 17:case 21:case 20:case 19:{p=i+1|0;q=h;r=g;s=f;t=o;break c;break};default:{p=i;q=h;r=g;s=f;t=o;break c}}}else{p=i;q=h;r=g;s=f;t=j+1|0}}while(0);if((t|0)<(b|0)){f=s;g=r;h=q;i=p;j=t;k=m<<8}else{u=s;v=r;w=q;x=p;break a}}if((n|0)==14){return 0}}else{u=0;v=0;w=0;x=0}}while(0);return((u|0)==0|(v|0)==0|(w|0)==0|(x|0)==0?0:51)|0}function VD(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;if((RGb(b,2169792,7)|0)!=0){d=0;return d|0}if((yb(b|0,2161656)|0)!=0){d=100;return d|0}if((yb(b|0,2129472)|0)==0){a=(yb(b|0,2123064)|0)==0;return(a?0:100)|0}else{d=100;return d|0}return 0}function WD(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;d=i;i=i+32|0;e=d|0;f=d+8|0;do{if((c[b+1084>>2]&128|0)==0){g=b+16|0;h=c[(c[g>>2]|0)+20>>2]|0;j=c[b+12>>2]|0;k=j;c[j+52>>2]=b+1160;if((h|0)==0){l=j;m=k;n=g;break}if((c[(c[h+4>>2]|0)+56>>2]|0)==0){l=j;m=k;n=g;break}o=j+56|0;p=o;$Db(o);q=h+8|0;xEb(c[q>>2]|0,2029912,0,p)|0;h=c[p>>2]|0;do{if((h|0)!=0){if((a[h]|0)!=0){break}$Db(o)}}while(0);o=j+60|0;h=o;$Db(o);xEb(c[q>>2]|0,1985712,0,h)|0;p=c[h>>2]|0;do{if((p|0)!=0){if((a[p]|0)!=0){break}$Db(o)}}while(0);o=j+64|0;p=o;$Db(o);xEb(c[q>>2]|0,1953648,0,p)|0;h=c[p>>2]|0;if((h|0)==0){l=j;m=k;n=g;break}if((a[h]|0)!=0){l=j;m=k;n=g;break}$Db(o);l=j;m=k;n=g}else{o=c[b+12>>2]|0;c[o+52>>2]=b+1160;l=o;m=o;n=b+16|0}}while(0);o=aE(m,b+32|0,0,c[n>>2]|0)|0;a:do{if((o|0)<0){r=o}else{n=l;if((c[n>>2]|0)==0){yDb(0,24,1926976,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;r=-541478725;break}h=l+8|0;p=c[h>>2]|0;t=l+12|0;if((p|0)>1){u=19}else{if((c[(c[c[t>>2]>>2]|0)+4348>>2]|0)==0){u=19}else{v=o;w=p}}b:do{if((u|0)==19){x=o;y=0;z=p;while(1){if((y|0)>=(z|0)){v=x;w=z;break b}A=c[(c[t>>2]|0)+(y<<2)>>2]|0;B=aE(m,A|0,A,0)|0;if((B|0)<0){r=B;break a}x=B;y=y+1|0;z=c[h>>2]|0}}}while(0);t=l+4|0;p=c[c[(c[c[t>>2]>>2]|0)+8>>2]>>2]|0;g=c[p+4348>>2]|0;if((g|0)==0){yDb(0,24,1926976,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;r=-541478725;break}if((c[p+4332>>2]|0)!=0){if((g|0)>0){k=c[p+4352>>2]|0;p=0;j=0;q=0;while(1){z=c[k+(q<<2)>>2]|0;y=YGb(c[z>>2]|0,c[z+4>>2]|0,j,p)|0;z=F;x=q+1|0;if((x|0)<(g|0)){p=z;j=y;q=x}else{C=z;D=y;break}}}else{C=0;D=0}q=b+1064|0;c[q>>2]=D;c[q+4>>2]=C}c:do{if((w|0)>0){q=l+12|0;j=0;p=0;g=v;k=w;while(1){y=c[(c[q>>2]|0)+(p<<2)>>2]|0;c[e>>2]=0;z=y+4348|0;if((c[z>>2]|0)==0){E=g;G=j;H=k}else{x=tN()|0;I=y+4240|0;c[I>>2]=x;if((x|0)==0){r=-12;break a}c[y+4236>>2]=p;c[y+4356>>2]=1;c[y+4232>>2]=b;x=c[y+4344>>2]|0;B=y+4364|0;c[B>>2]=x;do{if((c[y+4332>>2]|0)==0){A=c[z>>2]|0;if((A|0)<=3){break}c[B>>2]=A-3+x}}while(0);x=WDb(32768)|0;c[y+4224>>2]=x;B=y+4096|0;Ny(B,x,32768,0,y|0,190,0,0)|0;c[y+4184>>2]=0;J=y+4352|0;K=$S(B,e,(c[c[J>>2]>>2]|0)+8|0,0,0,0)|0;if((K|0)<0){break}c[(c[I>>2]|0)+16>>2]=B;c[y+4328>>2]=j;B=aT(I,(c[c[J>>2]>>2]|0)+8|0,c[e>>2]|0,0)|0;if((B|0)<0){r=B;break a}B=c[I>>2]|0;x=B+20|0;c[x>>2]=c[x>>2]&-2;x=AT(B,0)|0;if((x|0)<0){r=x;break a}if((c[(c[I>>2]|0)+24>>2]|0)==0){L=0}else{B=0;while(1){z=LT(b,0)|0;A=c[(c[(c[I>>2]|0)+28>>2]|0)+(B<<2)>>2]|0;if((z|0)==0){r=-12;break a}c[z+4>>2]=p;MT(z,c[A+188>>2]|0,c[A+40>>2]|0,c[A+44>>2]|0);BRa(c[z+8>>2]|0,c[(c[(c[(c[I>>2]|0)+28>>2]|0)+(B<<2)>>2]|0)+8>>2]|0)|0;z=B+1|0;A=c[(c[I>>2]|0)+24>>2]|0;if(z>>>0<A>>>0){B=z}else{L=A;break}}}E=x;G=L+j|0;H=c[h>>2]|0}B=p+1|0;if((B|0)<(H|0)){j=G;p=B;g=E;k=H}else{M=E;break c}}yDb(b,16,1905080,(s=i,i=i+8|0,c[s>>2]=(c[c[J>>2]>>2]|0)+8,s)|0);i=s;bT(c[I>>2]|0);c[I>>2]=0;r=K;break a}else{M=v}}while(0);if((c[n>>2]|0)>0){h=f|0;k=m|0;g=m+4|0;p=b+28|0;j=0;do{q=c[(c[t>>2]|0)+(j<<2)>>2]|0;B=q|0;Lb(h|0,20,1884368,(s=i,i=i+8|0,c[s>>2]=c[B>>2],s)|0)|0;i=s;y=NT(b,j)|0;if((y|0)==0){r=M;break a}CBb(y+20|0,2342608,h,0)|0;y=q+4|0;A=c[y>>2]|0;if((A|0)>0){z=q+8|0;q=0;N=A;while(1){A=c[(c[z>>2]|0)+(q<<2)>>2]|0;O=c[k>>2]|0;if((O|0)>0){P=c[g>>2]|0;Q=0;R=0;while(1){S=c[P+(Q<<2)>>2]|0;T=c[S+4>>2]|0;U=S+8|0;S=0;while(1){if((S|0)>=(T|0)){V=R;break}if((c[(c[U>>2]|0)+(S<<2)>>2]|0)==(A|0)){u=56;break}else{S=S+1|0}}if((u|0)==56){u=0;V=R+1|0}S=Q+1|0;if((S|0)<(O|0)&(V|0)<2){Q=S;R=V}else{W=V;break}}}else{W=0}R=A+4240|0;if((c[(c[R>>2]|0)+24>>2]|0)==0){X=N}else{Q=A+4328|0;if((W|0)>1){O=0;do{PT(b,j,(c[Q>>2]|0)+O|0);O=O+1|0;}while(O>>>0<(c[(c[R>>2]|0)+24>>2]|0)>>>0)}else{O=0;do{A=(c[Q>>2]|0)+O|0;P=c[(c[p>>2]|0)+(A<<2)>>2]|0;PT(b,j,A);if((c[B>>2]|0)!=0){CBb(P+88|0,2342608,h,0)|0}O=O+1|0;}while(O>>>0<(c[(c[R>>2]|0)+24>>2]|0)>>>0)}X=c[y>>2]|0}R=q+1|0;if((R|0)<(X|0)){q=R;N=X}else{break}}}j=j+1|0;}while((j|0)<(c[n>>2]|0))}c[l+24>>2]=1;n=l+32|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=l+40|0;c[n>>2]=0;c[n+4>>2]=-2147483648;Y=0;i=d;return Y|0}}while(0);_D(m);l=m|0;X=m+4|0;if((c[l>>2]|0)>0){m=0;do{b=c[(c[X>>2]|0)+(m<<2)>>2]|0;$Db(b+8|0);ZDb(b);m=m+1|0;}while((m|0)<(c[l>>2]|0))}$Db(X);c[l>>2]=0;Y=r;i=d;return Y|0}function XD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=f+24|0;if((c[g>>2]|0)!=0){$D(a,1)|0;c[g>>2]=0}g=f+20|0;h=f+8|0;j=f+12|0;k=f+32|0;l=e|0;m=e+4|0;n=f+40|0;o=f+48|0;f=-1;a:while(1){c[g>>2]=0;if((c[h>>2]|0)>0){p=f;q=0}else{r=f;break}while(1){s=c[(c[j>>2]|0)+(q<<2)>>2]|0;b:do{if((c[s+4356>>2]|0)==0){t=s+4272|0}else{u=s+4248|0;v=s+4272|0;if((c[v>>2]|0)!=0){t=v;break}w=s+4240|0;x=gT(c[w>>2]|0,u)|0;c:do{if((x|0)<0){y=x}else{z=s+4264|0;A=s+4280|0;B=s+4284|0;while(1){do{if((c[k>>2]|0)==0&(c[k+4>>2]|0)==(-2147483648|0)){C=c[z>>2]|0;D=c[z+4>>2]|0;if((C|0)==0&(D|0)==(-2147483648|0)){break}E=(c[(c[(c[w>>2]|0)+28>>2]|0)+(c[A>>2]<<2)>>2]|0)+40|0;c[l>>2]=1;c[m>>2]=1e6;G=KDb(C,D,E,e)|0;c[k>>2]=G;c[k+4>>2]=F}}while(0);G=c[n>>2]|0;E=c[n+4>>2]|0;if((G|0)==0&(E|0)==(-2147483648|0)){t=v;break b}D=c[z>>2]|0;C=c[z+4>>2]|0;if((D|0)==0&(C|0)==(-2147483648|0)){H=17;break}I=c[(c[(c[(c[w>>2]|0)+28>>2]|0)+(c[A>>2]<<2)>>2]|0)+44>>2]|0;J=HDb(D,C,1e6,0,I,(I|0)<0|0?-1:0,2)|0;I=ZGb(J,F,G,E)|0;E=F;G=-1;if((E|0)>(G|0)|(E|0)==(G|0)&I>>>0>-1>>>0){if((c[o>>2]&4|0)!=0){H=21;break}if((c[B>>2]&1|0)!=0){H=21;break}}BZ(u);vZ(u);c[v>>2]=0;I=gT(c[w>>2]|0,u)|0;if((I|0)<0){y=I;break c}}if((H|0)==17){H=0;c[n>>2]=0;c[n+4>>2]=-2147483648;t=v;break b}else if((H|0)==21){H=0;c[n>>2]=0;c[n+4>>2]=-2147483648;t=v;break b}}}while(0);if(!((Xy(s+4096|0)|0)!=0|(y|0)==-541478725)){K=y;H=35;break a}vZ(u);c[v>>2]=0;t=v}}while(0);do{if((c[t>>2]|0)==0){L=p}else{if((p|0)<0){L=q;break}w=c[(c[j>>2]|0)+(p<<2)>>2]|0;x=c[s+4364>>2]|0;B=c[w+4364>>2]|0;if((x|0)<(B|0)){L=q;break}if((x|0)!=(B|0)){L=p;break}B=s+4264|0;x=c[B>>2]|0;A=c[B+4>>2]|0;B=w+4264|0;z=c[B>>2]|0;I=c[B+4>>2]|0;B=c[(c[(c[s+4240>>2]|0)+28>>2]|0)+(c[s+4280>>2]<<2)>>2]|0;G=c[(c[(c[w+4240>>2]|0)+28>>2]|0)+(c[w+4280>>2]<<2)>>2]|0;if((x|0)==0&(A|0)==(-2147483648|0)){L=q;break}if((z|0)==0&(I|0)==(-2147483648|0)){L=p;break}w=B+48|0;E=c[w>>2]|0;J=c[w+4>>2]|0;w=(E|0)==0&(J|0)==(-2147483648|0);C=ZGb(x,A,w?0:E,w?0:J)|0;J=F;w=G+48|0;E=c[w>>2]|0;A=c[w+4>>2]|0;w=(E|0)==0&(A|0)==(-2147483648|0);x=ZGb(z,I,w?0:E,w?0:A)|0;A=(LDb(C,J,B+40|0,x,F,G+40|0)|0)<0;L=A?q:p}}while(0);s=q+1|0;if((s|0)<(c[h>>2]|0)){p=L;q=s}else{break}}if((c[g>>2]|0)==0){r=L;break}if(($D(a,0)|0)==0){r=L;break}else{f=L}}if((H|0)==35){i=d;return K|0}if(!((r|0)>-1)){K=-541478725;i=d;return K|0}UGb(b|0,(c[(c[j>>2]|0)+(r<<2)>>2]|0)+4248|0,80)|0;H=c[(c[j>>2]|0)+(r<<2)>>2]|0;r=b+32|0;c[r>>2]=(c[r>>2]|0)+(c[H+4328>>2]|0);vZ(H+4248|0);c[H+4272>>2]=0;K=0;i=d;return K|0}function YD(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;_D(b);a=b;d=b+4|0;b=d;if((c[a>>2]|0)>0){e=0}else{$Db(d);c[a>>2]=0;return 0}do{f=c[(c[b>>2]|0)+(e<<2)>>2]|0;$Db(f+8|0);ZDb(f);e=e+1|0;}while((e|0)<(c[a>>2]|0));$Db(d);c[a>>2]=0;return 0}function ZD(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=c[a+12>>2]|0;if((f&2|0)!=0){h=-38;return h|0}if((c[(c[c[(c[c[g+4>>2]>>2]|0)+8>>2]>>2]|0)+4332>>2]|0)==0){h=-38;return h|0}c[g+48>>2]=f;if((b|0)<0){i=g+40|0;c[i>>2]=d;c[i+4>>2]=e;j=0;k=1e6;l=i;m=e;n=d;o=f&1^3}else{i=c[(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+44>>2]|0;b=i;p=(i|0)<0|0?-1:0;i=f&1^3;f=HDb(d,e,1e6,0,b,p,i)|0;q=F;r=g+40|0;c[r>>2]=f;c[r+4>>2]=q;j=p;k=b;l=r;m=q;n=f;o=i}i=HDb(d,e,1e6,0,k,j,o)|0;o=F;j=a+1064|0;a=c[j+4>>2]|0;if((a|0)<(m|0)|(a|0)==(m|0)&(c[j>>2]|0)>>>0<n>>>0){c[l>>2]=0;c[l+4>>2]=-2147483648;h=-5;return h|0}n=g+8|0;if((c[n>>2]|0)<=0){h=-5;return h|0}j=g+12|0;m=g+32|0;g=0;a=-5;while(1){k=c[(c[j>>2]|0)+(g<<2)>>2]|0;e=c[m>>2]|0;d=c[m+4>>2]|0;f=(e|0)==0&(d|0)==(-2147483648|0);q=k+4228|0;r=c[q>>2]|0;if((r|0)!=0){Ey(r)|0;c[q>>2]=0}q=k+4248|0;BZ(q);vZ(q);c[k+4272>>2]=0;c[k+4148>>2]=0;q=c[k+4100>>2]|0;c[k+4108>>2]=q;c[k+4112>>2]=q;q=k+4136|0;c[q>>2]=0;c[q+4>>2]=0;q=c[k+4348>>2]|0;a:do{if((q|0)>0){r=k+4352|0;b=0;p=f?0:d;s=f?0:e;while(1){t=c[(c[r>>2]|0)+(b<<2)>>2]|0;u=c[t>>2]|0;v=c[t+4>>2]|0;if(!((o|0)<(p|0)|(o|0)==(p|0)&i>>>0<s>>>0)){t=YGb(u,v,s,p)|0;w=F;if((o|0)<(w|0)|(o|0)==(w|0)&i>>>0<t>>>0){break}}t=YGb(u,v,s,p)|0;v=b+1|0;if((v|0)<(q|0)){b=v;p=F;s=t}else{x=18;break a}}c[k+4364>>2]=(c[k+4344>>2]|0)+b;y=0}else{x=18}}while(0);do{if((x|0)==18){x=0;if((a|0)==0){y=0;break}c[l>>2]=0;c[l+4>>2]=-2147483648;y=a}}while(0);k=g+1|0;if((k|0)<(c[n>>2]|0)){g=k;a=y}else{h=y;break}}return h|0}function _D(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a+8|0;d=a+12|0;if((c[b>>2]|0)>0){e=0}else{f=d;$Db(f);g=a+60|0;h=g;$Db(h);i=a+56|0;j=i;$Db(j);c[b>>2]=0;return}do{k=c[(c[d>>2]|0)+(e<<2)>>2]|0;l=k+4348|0;m=k+4352|0;if((c[l>>2]|0)>0){n=0;do{ZDb(c[(c[m>>2]|0)+(n<<2)>>2]|0);n=n+1|0;}while((n|0)<(c[l>>2]|0))}$Db(m);c[l>>2]=0;BZ(k+4248|0);ZDb(c[k+4100>>2]|0);n=c[k+4228>>2]|0;if((n|0)!=0){Ey(n)|0}n=k+4240|0;o=c[n>>2]|0;if((o|0)!=0){c[o+16>>2]=0;KT(n)}ZDb(k|0);e=e+1|0;}while((e|0)<(c[b>>2]|0));f=d;$Db(f);g=a+60|0;h=g;$Db(h);i=a+56|0;j=i;$Db(j);c[b>>2]=0;return}function $D(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=c[a+12>>2]|0;f=e+8|0;g=c[f>>2]|0;if((g|0)>0){h=c[e+12>>2]|0;j=0;while(1){c[(c[h+(j<<2)>>2]|0)+4360>>2]=0;k=j+1|0;l=c[f>>2]|0;if((k|0)<(l|0)){j=k}else{m=l;break}}}else{m=g}g=a+24|0;j=c[g>>2]|0;if((j|0)==0){n=m}else{m=c[a+28>>2]|0;h=e+12|0;l=0;k=j;while(1){j=c[m+(l<<2)>>2]|0;if((c[j+76>>2]|0)<48){c[(c[(c[h>>2]|0)+(c[j+4>>2]<<2)>>2]|0)+4360>>2]=1;o=c[g>>2]|0}else{o=k}j=l+1|0;if(j>>>0<o>>>0){l=j;k=o}else{break}}n=c[f>>2]|0}if((n|0)<=0){p=0;i=d;return p|0}o=e+12|0;k=a;a=e+16|0;if((b|0)==0){b=0;e=0;l=n;while(1){n=c[(c[o>>2]|0)+(e<<2)>>2]|0;do{if((c[n+4360>>2]|0)==0){q=b;r=l}else{g=n+4356|0;if((c[g>>2]|0)!=0){q=b;r=l;break}c[g>>2]=1;c[n+4364>>2]=c[a>>2];c[n+4148>>2]=0;yDb(k,32,2146968,(s=i,i=i+8|0,c[s>>2]=e,s)|0);i=s;q=1;r=c[f>>2]|0}}while(0);n=e+1|0;if((n|0)<(r|0)){b=q;e=n;l=r}else{p=q;break}}i=d;return p|0}else{t=0;u=0}while(1){q=c[(c[o>>2]|0)+(u<<2)>>2]|0;r=q+4356|0;l=(c[r>>2]|0)==0;do{if((c[q+4360>>2]|0)==0){if(l){v=t;break}e=q+4228|0;b=c[e>>2]|0;if((b|0)!=0){Ey(b)|0}c[e>>2]=0;c[r>>2]=0;yDb(k,32,2079800,(s=i,i=i+8|0,c[s>>2]=u,s)|0);i=s;v=1}else{if(!l){v=t;break}c[r>>2]=1;c[q+4364>>2]=c[a>>2];c[q+4148>>2]=0;yDb(k,32,2146968,(s=i,i=i+8|0,c[s>>2]=u,s)|0);i=s;v=1}}while(0);q=u+1|0;if((q|0)<(c[f>>2]|0)){t=v;u=q}else{p=v;break}}i=d;return p|0}function aE(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0.0,ha=0,ia=0,ja=0,ka=0,la=0;g=i;i=i+12408|0;h=g|0;j=g+4120|0;k=g+8216|0;l=g+8224|0;m=g+8232|0;n=g+8240|0;o=g+8264|0;c[h>>2]=f;p=g+8|0;TGb(p|0,0,16)|0;q=g+24|0;TGb(q|0,0,4096)|0;c[l>>2]=0;do{if((f|0)==0){c[m>>2]=0;CBb(m,2297656,2280624,0)|0;CBb(m,2029912,c[b+56>>2]|0,0)|0;CBb(m,1985712,c[b+60>>2]|0,0)|0;CBb(m,1953648,c[b+64>>2]|0,0)|0;r=Hz(h,d,1,c[b+52>>2]|0,m)|0;DBb(m);if((r|0)<0){s=r;i=g;return s|0}else{t=r;u=1;v=c[h>>2]|0;break}}else{t=0;u=0;v=f}}while(0);f=(xEb(v,2184872,1,l)|0)>-1;v=f?c[l>>2]|0:d;d=j|0;f=wz(c[h>>2]|0,d,4096)|0;a:do{if((f|0)>0){m=f;do{m=m-1|0;r=j+m|0;if((EAb(a[r]|0)|0)==0){break a}a[r]=0;}while((m|0)>0)}}while(0);b:do{if((QGb(d,2169792)|0)==0){if((e|0)==0){w=0}else{f=e+4348|0;m=e+4352|0;if((c[f>>2]|0)>0){r=0;do{ZDb(c[(c[m>>2]|0)+(r<<2)>>2]|0);r=r+1|0;}while((r|0)<(c[f>>2]|0))}$Db(m);c[f>>2]=0;c[e+4332>>2]=0;w=e}if((Xy(c[h>>2]|0)|0)==0){r=b+8|0;y=b+12|0;z=o|0;A=o+4096|0;B=o+4106|0;C=o+4108|0;D=n|0;G=0;H=0;I=0;J=0;K=0;L=0;M=0;N=w;while(1){O=wz(c[h>>2]|0,d,4096)|0;c:do{if((O|0)>0){R=O;do{R=R-1|0;S=j+R|0;if((EAb(a[S]|0)|0)==0){break c}a[S]=0;}while((R|0)>0)}}while(0);do{if((qAb(d,2161656,k)|0)==0){if((qAb(d,2155032,k)|0)!=0){TGb(z|0,0,4141)|0;$T(c[k>>2]|0,94,z);O=(QGb(A,2148e3)|0)==0|0;if((RGb(B,2141480,2)|0)==0){T=22}else{if((RGb(B,2135584,2)|0)==0){T=22}else{U=0}}if((T|0)==22){T=0;_T(p,C)|0;U=1}sAb(q,z,4096)|0;V=N;W=U;X=O;Y=J;Z=K;_=I;$=H;ba=G;break}if((qAb(d,2129472,k)|0)!=0){if((N|0)==0){if((eE(b,0,v,0)|0)==0){ca=-12;break b}da=c[(c[y>>2]|0)+((c[r>>2]|0)-1<<2)>>2]|0}else{da=N}O=(gd(c[k>>2]|0)|0)*1e6|0;R=da+4336|0;c[R>>2]=O;c[R+4>>2]=(O|0)<0|0?-1:0;V=da;W=M;X=L;Y=J;Z=K;_=I;$=H;ba=G;break}if((qAb(d,2123064,k)|0)!=0){if((N|0)==0){if((eE(b,0,v,0)|0)==0){ca=-12;break b}ea=c[(c[y>>2]|0)+((c[r>>2]|0)-1<<2)>>2]|0}else{ea=N}c[ea+4344>>2]=gd(c[k>>2]|0)|0;V=ea;W=M;X=L;Y=J;Z=K;_=I;$=H;ba=G;break}if((qAb(d,2117888,k)|0)!=0){if((N|0)==0){V=0;W=M;X=L;Y=J;Z=K;_=I;$=H;ba=G;break}c[N+4332>>2]=1;V=N;W=M;X=L;Y=J;Z=K;_=I;$=H;ba=G;break}if((qAb(d,2107792,k)|0)!=0){fa=+NGb(c[k>>2]|0)*1.0e6;V=N;W=M;X=L;Y=(E=+fa,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Z=~~+fa>>>0;_=I;$=H;ba=1;break}O=(qAb(d,2096344,0)|0)!=0;if(O|(a[d]|0)==0){V=N;W=M;X=L;Y=J;Z=K;_=I;$=H;ba=G;break}if((H|0)==0){ha=I}else{if((eE(b,I,d,v)|0)==0){ca=-12;break b}else{ha=0}}if((G|0)==0){V=N;W=M;X=L;Y=J;Z=K;_=ha;$=0;ba=0;break}if((N|0)==0){if((eE(b,0,v,0)|0)==0){ca=-12;break b}ia=c[(c[y>>2]|0)+((c[r>>2]|0)-1<<2)>>2]|0}else{ia=N}O=WDb(8224)|0;if((O|0)==0){ca=-12;break b}R=O;c[R>>2]=K;c[R+4>>2]=J;c[O+8200>>2]=L;if((M|0)==0){R=ia+4348|0;S=(c[R>>2]|0)+(c[ia+4344>>2]|0)|0;TGb(O+8204|0,0,12)|0;ja=O+8216|0;x=fe(S|0)|0;a[ja]=x;x=x>>8;a[ja+1|0]=x;x=x>>8;a[ja+2|0]=x;x=x>>8;a[ja+3|0]=x;ka=R}else{UGb(O+8204|0,p|0,16)|0;ka=ia+4348|0}MS(O+4104|0,4096,v,q);MS(O+8|0,4096,v,d);gEb(ia+4352|0,ka,O);V=ia;W=M;X=L;Y=J;Z=K;_=ha;$=0;ba=0}else{TGb(D|0,0,20)|0;$T(c[k>>2]|0,300,D);V=N;W=M;X=L;Y=J;Z=K;_=gd(D|0)|0;$=1;ba=G}}while(0);if((Xy(c[h>>2]|0)|0)==0){G=ba;H=$;I=_;J=Y;K=Z;L=X;M=W;N=V}else{la=V;break}}}else{la=w}if((la|0)==0){ca=t;break}N=WFb()|0;M=la+4368|0;c[M>>2]=N;c[M+4>>2]=F;ca=t}else{ca=-1094995529}}while(0);ZDb(c[l>>2]|0);if((u|0)==0){s=ca;i=g;return s|0}Iz(c[h>>2]|0)|0;s=ca;i=g;return s|0}function bE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;f=i;i=i+4200|0;g=f|0;h=f+8|0;j=f+16|0;k=f+56|0;l=f+4192|0;m=b;n=b+4232|0;o=c[(c[n>>2]|0)+12>>2]|0;p=o;q=b+4228|0;r=b+4348|0;s=b+4352|0;t=b+4332|0;u=b+4368|0;v=b+4336|0;w=b+4364|0;x=b+4344|0;y=o+52|0;z=j|0;A=k|0;B=f+96|0;C=o+56|0;D=o+60|0;E=o+64|0;G=b+4376|0;H=b+8472|0;I=k+32|0;k=j+32|0;j=o+20|0;J=o+16|0;o=b+4240|0;K=b+4356|0;L=b+4328|0;M=c[q>>2]|0;a:while(1){if((M|0)==0){N=c[r>>2]|0;if((N|0)>0){O=c[(c[s>>2]|0)+(N-1<<2)>>2]|0}else{O=v}N=c[O+4>>2]|0;P=c[O>>2]|0;b:while(1){do{if((c[t>>2]|0)==0){Q=WFb()|0;R=ZGb(Q,F,c[u>>2]|0,c[u+4>>2]|0)|0;Q=F;if((Q|0)<(N|0)|(Q|0)==(N|0)&R>>>0<P>>>0){S=N;T=P;break}R=aE(p,b,m,0)|0;if((R|0)<0){U=R;V=45;break a}R=eHb(c[v>>2]|0,c[v+4>>2]|0,2,0)|0;S=F;T=R}else{S=N;T=P}}while(0);R=c[w>>2]|0;Q=c[x>>2]|0;if((R|0)<(Q|0)){yDb(0,24,2319920,(W=i,i=i+8|0,c[W>>2]=Q-R,W)|0);i=W;X=c[x>>2]|0;c[w>>2]=X;Y=X;Z=X}else{Y=R;Z=Q}if((Y|0)<((c[r>>2]|0)+Z|0)){break}if((c[t>>2]|0)!=0){U=-541478725;V=45;break a}Q=WFb()|0;R=ZGb(Q,F,c[u>>2]|0,c[u+4>>2]|0)|0;Q=F;if(!((Q|0)<(S|0)|(Q|0)==(S|0)&R>>>0<T>>>0)){N=S;P=T;continue}while(1){if((Ky(c[y>>2]|0)|0)!=0){U=-1414092869;V=45;break a}XFb(1e5)|0;R=WFb()|0;Q=ZGb(R,F,c[u>>2]|0,c[u+4>>2]|0)|0;R=F;if(!((R|0)<(S|0)|(R|0)==(S|0)&Q>>>0<T>>>0)){N=S;P=T;continue b}}}c[g>>2]=0;c[h>>2]=0;P=c[(c[s>>2]|0)+(Y-Z<<2)>>2]|0;CBb(g,2029912,c[C>>2]|0,0)|0;CBb(g,1985712,c[D>>2]|0,0)|0;CBb(g,1953648,c[E>>2]|0,0)|0;CBb(g,2297656,2280624,0)|0;EBb(h,c[g>>2]|0,0);N=c[P+8200>>2]|0;do{if((N|0)==1){Q=P+4104|0;if((QGb(Q,G)|0)!=0){if((Dy(l,Q,1,(c[n>>2]|0)+1160|0,h)|0)==0){if((Gy(c[l>>2]|0,H,16)|0)!=16){yDb(0,16,2265320,(W=i,i=i+8|0,c[W>>2]=Q,W)|0);i=W}Ey(c[l>>2]|0)|0}else{yDb(0,16,2250328,(W=i,i=i+8|0,c[W>>2]=Q,W)|0);i=W}sAb(G,Q,4096)|0}ZT(z,P+8204|0,16,0)|0;ZT(A,H,16,0)|0;a[I]=0;a[k]=0;Q=P+8|0;if((yb(Q|0,2236632)|0)==0){Lb(B|0,4096,2214368,(W=i,i=i+8|0,c[W>>2]=Q,W)|0)|0;i=W}else{Lb(B|0,4096,2223984,(W=i,i=i+8|0,c[W>>2]=Q,W)|0)|0;i=W}Q=By(q,B,1,(c[n>>2]|0)+1160|0)|0;if((Q|0)<0){_=Q;break}rEb(c[(c[q>>2]|0)+8>>2]|0,2204728,A,0)|0;rEb(c[(c[q>>2]|0)+8>>2]|0,2197128,z,0)|0;Q=zy(c[q>>2]|0,g)|0;if((Q|0)>=0){_=0;break}Ey(c[q>>2]|0)|0;c[q>>2]=0;_=Q}else if((N|0)==0){_=Dy(q,P+8|0,1,(c[n>>2]|0)+1160|0,g)|0}else{_=-38}}while(0);DBb(g);DBb(h);if((_|0)<0){U=_;V=45;break}$=c[q>>2]|0}else{$=M}P=Fy($,d,e)|0;if((P|0)>0){U=P;V=45;break}Ey(c[q>>2]|0)|0;c[q>>2]=0;c[w>>2]=(c[w>>2]|0)+1;c[j>>2]=1;c[J>>2]=c[w>>2];P=c[o>>2]|0;do{if((P|0)!=0){N=P+24|0;Q=c[N>>2]|0;if((Q|0)==0){break}R=c[n>>2]|0;X=c[L>>2]|0;if((c[R+24>>2]|0)>>>0<(X+Q|0)>>>0){break}c[K>>2]=0;Q=c[N>>2]|0;if(!(X>>>0<(Q+X|0)>>>0)){V=44;break a}aa=c[R+28>>2]|0;R=X;ba=Q;while(1){if((c[(c[aa+(R<<2)>>2]|0)+76>>2]|0)<48){c[K>>2]=1;ca=c[N>>2]|0}else{ca=ba}Q=R+1|0;if(Q>>>0<(ca+X|0)>>>0){R=Q;ba=ca}else{break}}}}while(0);if((c[K>>2]|0)==0){V=44;break}else{M=0}}if((V|0)==44){yDb(c[n>>2]|0,32,2079800,(W=i,i=i+8|0,c[W>>2]=c[b+4236>>2],W)|0);i=W;U=-541478725;i=f;return U|0}else if((V|0)==45){i=f;return U|0}return 0}function cE(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;if((RGb(b,2075408,d)|0)!=0){return}c[e>>2]=a;c[f>>2]=20;return}function dE(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;if((RGb(b,2090856,d)|0)==0){c[e>>2]=a+4096;c[f>>2]=10;return}if((RGb(b,2085816,d)|0)==0){c[e>>2]=a;c[f>>2]=4096;return}if((RGb(b,2080856,d)|0)!=0){return}c[e>>2]=a+4106;c[f>>2]=35;return}function eE(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=cEb(8488)|0;if((f|0)==0){g=0;return g|0}vZ(f+4248|0);c[f+4272>>2]=0;MS(f,4096,e,d);gEb(a+12|0,a+8|0,f);d=cEb(12)|0;if((d|0)==0){g=0;return g|0}c[d>>2]=b;gEb(a+4|0,a|0,d);gEb(d+8|0,d+4|0,f);g=d;return g|0}function fE(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=b+12|0;f=c[e>>2]|0;h=b+32|0;j=(SGb(h|0)|0)+6|0;c[f+4>>2]=0;k=+g[f+24>>2]*1.0e6;l=(E=+k,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);m=f+40|0;c[m>>2]=~~+k>>>0;c[m+4>>2]=l;l=f+56|0;c[l>>2]=0;c[l+4>>2]=-2147483648;l=b+24|0;if((c[l>>2]|0)==0){n=c[f+48>>2]|0}else{m=c[b+28>>2]|0;o=f+48|0;p=0;q=c[o>>2]|0;while(1){r=((c[(c[(c[m+(p<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==0)+q|0;c[o>>2]=r;s=p+1|0;if(s>>>0<(c[l>>2]|0)>>>0){p=s;q=r}else{n=r;break}}}if((n|0)>1){yDb(b,24,2265216,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}n=UC(2250272,0,0)|0;c[f+16>>2]=n;a:do{if((n|0)==0){t=-1481985528;u=f+92|0}else{q=WDb(j)|0;p=f+92|0;c[p>>2]=q;if((q|0)==0){t=-12;u=p;break}WGb(q|0,h|0)|0;q=c[p>>2]|0;o=cc(q|0,46)|0;if((o|0)==0){v=q}else{a[o]=0;v=c[p>>2]|0}tAb(v,2280592,j)|0;o=c[e>>2]|0;q=tN()|0;c[o+20>>2]=q;if((q|0)==0){t=-12;u=p;break}c[q+8>>2]=c[o+16>>2];o=b+1160|0;m=q+1160|0;r=c[o+4>>2]|0;c[m>>2]=c[o>>2];c[m+4>>2]=r;EBb(q+1140|0,c[b+1140>>2]|0,0);if((c[l>>2]|0)!=0){r=b+28|0;m=0;do{o=LT(q,0)|0;if((o|0)==0){t=-12;u=p;break a}BRa(c[o+8>>2]|0,c[(c[(c[r>>2]|0)+(m<<2)>>2]|0)+8>>2]|0)|0;s=(c[(c[r>>2]|0)+(m<<2)>>2]|0)+80|0;w=o+80|0;o=c[s+4>>2]|0;c[w>>2]=c[s>>2];c[w+4>>2]=o;m=m+1|0;}while(m>>>0<(c[l>>2]|0)>>>0)}m=kE(b)|0;if((m|0)<0){t=m;u=p;break}m=FK(c[f+20>>2]|0,0)|0;if((m|0)<0){x=m;i=d;return x|0}if((m|0)==0){x=0}else{t=m;u=p;break}i=d;return x|0}}while(0);ZDb(c[u>>2]|0);u=c[f+20>>2]|0;if((u|0)==0){x=t;i=d;return x|0}bT(u);x=t;i=d;return x|0}function gE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=f;h=f+20|0;j=c[h>>2]|0;k=b+32|0;l=c[(c[a+28>>2]|0)+(c[k>>2]<<2)>>2]|0;m=f+40|0;n=gHb(c[f+4>>2]|0,0,c[m>>2]|0,c[m+4>>2]|0)|0;m=F;o=f+56|0;p=c[o>>2]|0;q=c[o+4>>2]|0;if((p|0)==0&(q|0)==(-2147483648|0)){r=b+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;c[o>>2]=s;c[o+4>>2]=t;o=c[r+4>>2]|0;u=f+64|0;c[u>>2]=c[r>>2];c[u+4>>2]=o;v=t;w=s}else{v=q;w=p}if((c[f+48>>2]|0)==0){x=1;y=0}else{p=c[(c[l+8>>2]|0)+8>>2]|0;if((p|0)==0){z=c[b+36>>2]&1}else{z=0}x=z;y=(p|0)!=0}p=b+8|0;z=c[p>>2]|0;q=c[p+4>>2]|0;s=(z|0)==0&(q|0)==(-2147483648|0);if(!(s|y)){y=f+64|0;t=ZGb(z,q,c[y>>2]|0,c[y+4>>2]|0)|0;y=c[l+40>>2]|0;q=c[l+44>>2]|0;z=IDb(t,F,y,(y|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;q=f+72|0;c[q>>2]=z;c[q+4>>2]=F}do{if(s|(x|0)==0){A=j}else{q=ZGb(c[p>>2]|0,c[p+4>>2]|0,w,v)|0;c[e>>2]=1;c[e+4>>2]=1e6;if(!((LDb(q,F,l+40|0,n,m,e)|0)>-1)){A=j;break}q=f+72|0;z=iE(g,c[q>>2]|0,c[q+4>>2]|0)|0;if((z|0)!=0){B=z;i=d;return B|0}z=c[p+4>>2]|0;y=f+64|0;c[y>>2]=c[p>>2];c[y+4>>2]=z;c[q>>2]=0;c[q+4>>2]=0;GK(j,0)|0;Iz(c[j+16>>2]|0)|0;q=kE(a)|0;if((q|0)!=0){B=q;i=d;return B|0}q=c[h>>2]|0;z=jE(a,0)|0;if((z|0)<0){B=z}else{A=q;break}i=d;return B|0}}while(0);B=OK(A,c[k>>2]|0,b,a)|0;i=d;return B|0}function hE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=c[b+20>>2]|0;NK(d)|0;Jz(d+16|0)|0;bT(d);ZDb(c[b+92>>2]|0);d=b+72|0;iE(b,c[d>>2]|0,c[d+4>>2]|0)|0;jE(a,1)|0;a=c[b+84>>2]|0;if((a|0)==0){e=b+96|0;f=e;g=c[f>>2]|0;h=Iz(g)|0;return 0}else{i=a}while(1){a=c[i+1028>>2]|0;ZDb(i|0);if((a|0)==0){break}else{i=a}}e=b+96|0;f=e;g=c[f>>2]|0;h=Iz(g)|0;return 0}function iE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=WDb(1032)|0;e=d;if((d|0)==0){f=-12;return f|0}sAb(d,AAb((c[a+20>>2]|0)+32|0)|0,1024)|0;c[d+1024>>2]=b;c[d+1028>>2]=0;d=a+84|0;if((c[d>>2]|0)==0){c[d>>2]=e;g=a+88|0}else{b=a+88|0;c[(c[b>>2]|0)+1028>>2]=e;g=b}c[g>>2]=e;e=a+80|0;g=c[e>>2]|0;if((g|0)<(c[a+28>>2]|0)){c[e>>2]=g+1}else{g=c[d>>2]|0;c[d>>2]=c[g+1028>>2];ZDb(g|0)}g=a+8|0;a=YGb(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=a;c[g+4>>2]=F;f=0;return f|0}function jE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a+12>>2]|0;f=e+96|0;g=Hz(f,a+32|0,2,a+1160|0,0)|0;if((g|0)<0){h=Jz(f)|0;i=d;return g|0}a=e+84|0;j=c[a>>2]|0;if((j|0)==0){k=0}else{l=0;m=j;while(1){j=c[m+1024>>2]|0;n=(l|0)<(j|0)?j:l;j=c[m+1028>>2]|0;if((j|0)==0){k=n;break}else{l=n;m=j}}}Kz(c[f>>2]|0,2079712,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;Kz(c[f>>2]|0,2029800,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;Kz(c[f>>2]|0,1985504,(m=i,i=i+8|0,c[m>>2]=k,m)|0)|0;i=m;k=c[f>>2]|0;l=e+8|0;j=c[e+28>>2]|0;e=ZGb(c[l>>2]|0,c[l+4>>2]|0,j,(j|0)<0|0?-1:0)|0;j=F;l=0;n=(j|0)<(l|0)|(j|0)==(l|0)&e>>>0<0>>>0;Kz(k,1953536,(m=i,i=i+16|0,c[m>>2]=n?0:e,c[m+8>>2]=n?0:j,m)|0)|0;i=m;j=c[a>>2]|0;if((j|0)!=0){a=j;do{Kz(c[f>>2]|0,1926872,(m=i,i=i+8|0,c[m>>2]=c[a+1024>>2],m)|0)|0;i=m;Kz(c[f>>2]|0,1905008,(m=i,i=i+8|0,c[m>>2]=a,m)|0)|0;i=m;a=c[a+1028>>2]|0;}while((a|0)!=0)}if((b|0)==0){h=Jz(f)|0;i=d;return g|0}Kz(c[f>>2]|0,1884328,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;h=Jz(f)|0;i=d;return g|0}function kE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=c[a+12>>2]|0;e=c[d+20>>2]|0;f=e+32|0;g=d+92|0;h=c[d+32>>2]|0;j=d+4|0;d=c[j>>2]|0;if((h|0)==0){k=d}else{k=(d>>>0)%(h>>>0)|0}if((XS(f,1024,c[g>>2]|0,k)|0)<0){yDb(e,16,2342544,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0);i=k;l=-22;i=b;return l|0}c[j>>2]=(c[j>>2]|0)+1;j=Hz(e+16|0,f,2,a+1160|0,0)|0;if((j|0)<0){l=j;i=b;return l|0}if((c[(c[e+8>>2]|0)+36>>2]|0)==0){l=0;i=b;return l|0}j=c[e+12>>2]|0;if((j|0)==0){l=0;i=b;return l|0}rEb(j,2319880,2297568,0)|0;l=0;i=b;return l|0}function lE(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<4){b=0;return b|0}e=c[a+4>>2]|0;b=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==877481544?100:0;return b|0}function mE(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=c[d+12>>2]|0;h=c[d+16>>2]|0;j=g+32|0;c[j>>2]=0;c[j+4>>2]=0;vZ(g+48|0);c[g+72>>2]=0;c[g+76>>2]=0;c[g+40>>2]=0;Vy(h,8,0)|0;j=g+2|0;b[j>>1]=pz(h)|0;k=g+4|0;b[k>>1]=pz(h)|0;c[g+8>>2]=rz(h)|0;c[g+12>>2]=rz(h)|0;c[g+16>>2]=rz(h)|0;b[g+20>>1]=pz(h)|0;b[g+22>>1]=pz(h)|0;c[g+24>>2]=rz(h)|0;Vy(h,32,0)|0;c[g+28>>2]=0;h=b[j>>1]|0;l=b[k>>1]|0;do{if(!((h-320&65535)>>>0>320>>>0)){if((l-150&65535)>>>0>330>>>0){break}a[g]=h<<16>>16==640?74:64;m=LT(d,0)|0;if((m|0)==0){n=-12;i=f;return n|0}o=m+8|0;p=c[o>>2]|0;c[p+8>>2]=0;c[p+48>>2]=174;c[p+52>>2]=0;c[p+120>>2]=e[j>>1]|0;c[p+124>>2]=e[k>>1]|0;p=cEb(1)|0;c[(c[o>>2]|0)+96>>2]=p;p=c[o>>2]|0;c[p+100>>2]=1;a[c[p+96>>2]|0]=a[g]|0;p=m+48|0;c[p>>2]=0;c[p+4>>2]=0;MT(m,33,1,24);n=0;i=f;return n|0}}while(0);yDb(d,16,2029712,(d=i,i=i+16|0,c[d>>2]=h&65535,c[d+8>>2]=l&65535,d)|0);i=d;n=-1094995529;i=f;return n|0}function nE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=e+28|0;if((c[g>>2]|0)==(c[e+12>>2]|0)){h=-541478725;i=d;return h|0}if((c[f+52>>2]|0)!=0){h=-541478725;i=d;return h|0}j=e+40|0;if((c[j>>2]|0)==0){e=qz(f)|0;Vy(f,1,0)|0;c[j>>2]=e-4}e=qz(f)|0;Vy(f,1,0)|0;k=pz(f)|0;Vy(f,2,0)|0;if(!(e>>>0<=(c[j>>2]|0)>>>0&(e|0)!=0)){l=Ty(f,0,0,1)|0;yDb(a,16,2146656,(m=i,i=i+16|0,c[m>>2]=e,c[m+8>>2]=l,m)|0);i=m;Vy(f,(c[j>>2]|0)-8|0,0)|0;c[j>>2]=0}l=k&65535;if((l|0)==17491){Vy(f,e-8|0,0)|0;c[j>>2]=(c[j>>2]|0)-e;h=0;i=d;return h|0}else if((l|0)==19536|(l|0)==23113|(l|0)==21833){Ty(f,-8,-1,1)|0;k=TS(f,b,e)|0;c[j>>2]=(c[j>>2]|0)-e;if(!((l|0)==23113|(l|0)==21833)){h=k;i=d;return h|0}c[g>>2]=(c[g>>2]|0)+1;h=k;i=d;return h|0}else{k=Ty(f,0,0,1)|0;yDb(a,24,2079568,(m=i,i=i+16|0,c[m>>2]=l,c[m+8>>2]=k,m)|0);i=m;Vy(f,e-8|0,0)|0;c[j>>2]=(c[j>>2]|0)-e;h=0;i=d;return h|0}return 0}function oE(a){a=a|0;var b=0;b=c[a+12>>2]|0;if((c[b+76>>2]|0)<=0){return 0}BZ(b+48|0);return 0}function pE(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){e=b+2|0;if(!((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==1)){break}e=b+4|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}else{f=25}return f|0}}while(0);f=0;return f|0}function qE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;Vy(e,4,0)|0;f=pz(e)|0;g=d+4|0;c[g>>2]=f;h=WDb(f*12|0)|0;f=d+8|0;c[f>>2]=h;if((h|0)==0){j=-12;i=b;return j|0}if((c[g>>2]|0)>0){k=0}else{j=0;i=b;return j|0}a:while(1){h=k<<4|6;d=Ty(e,h,(h|0)<0|0?-1:0,0)|0;h=F;l=0;if((h|0)<(l|0)|(h|0)==(l|0)&d>>>0<0>>>0){j=0;m=15;break}d=LT(a,0)|0;if((d|0)==0){j=-12;m=15;break}l=d+8|0;c[(c[l>>2]|0)+8>>2]=0;d=lz(e)|0;c[(c[l>>2]|0)+120>>2]=d;d=lz(e)|0;c[(c[l>>2]|0)+124>>2]=d;d=lz(e)|0;c[(c[f>>2]|0)+(k*12|0)+8>>2]=(d|0)==255?0:d;Vy(e,5,0)|0;d=rz(e)|0;c[(c[f>>2]|0)+(k*12|0)+4>>2]=d;d=rz(e)|0;c[(c[f>>2]|0)+(k*12|0)>>2]=d;h=Ty(e,d,(d|0)<0|0?-1:0,0)|0;d=F;n=0;if((d|0)<(n|0)|(d|0)==(n|0)&h>>>0<0>>>0){j=0;m=15;break}o=rz(e)|0;do{if((o|0)==1196314761){h=c[l>>2]|0;c[h+48>>2]=62;c[h+120>>2]=0;c[h+124>>2]=0}else if((o|0)==40){if((c[(c[f>>2]|0)+(k*12|0)+4>>2]|0)<40){j=-1094995529;m=15;break a}c[(c[l>>2]|0)+48>>2]=79;h=rz(e)|0;if((h|0)!=0){c[(c[l>>2]|0)+120>>2]=h}h=rz(e)|0;if((h|0)==0){break}c[(c[l>>2]|0)+124>>2]=(h|0)/2|0}else{m=13;break a}}while(0);l=k+1|0;if((l|0)<(c[g>>2]|0)){k=l}else{j=0;m=15;break}}if((m|0)==13){DDb(a,2146640,(a=i,i=i+8|0,c[a>>2]=o,a)|0);i=a;j=-1094995529;i=b;return j|0}else if((m|0)==15){i=b;return j|0}return 0}function rE(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=c[b+12>>2]|0;g=c[b+16>>2]|0;h=b+28|0;b=c[c[h>>2]>>2]|0;i=f;j=c[i>>2]|0;if((j|0)>=(c[f+4>>2]|0)){k=-5;return k|0}l=c[f+8>>2]|0;f=c[l+(j*12|0)>>2]|0;m=Ty(g,f,(f|0)<0|0?-1:0,0)|0;f=m;if((f|0)<0){k=f;return k|0}f=l+(j*12|0)+4|0;m=c[f>>2]|0;do{if((c[(c[(c[(c[h>>2]|0)+(c[i>>2]<<2)>>2]|0)+8>>2]|0)+48>>2]|0)==62){n=TS(g,e,m)|0;if((n|0)<0){k=n}else{break}return k|0}else{n=wZ(e,m+14|0)|0;if((n|0)<0){k=n;return k|0}n=c[e+24>>2]|0;a[n]=66;a[n+1|0]=77;o=n+2|0;x=c[e+28>>2]|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=n+10|0;p=n+6|0;q=p|0;x=0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=mz(g,n+14|0,c[f>>2]|0)|0;if((q|0)<0){k=q;return k|0}q=n+28|0;p=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(c[b+8>>2]|0)+792|0;c[q>>2]=p;r=n+46|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;if((s|0)==0){t=p}else{c[l+(j*12|0)+8>>2]=s;t=c[q>>2]|0}q=l+(j*12|0)+8|0;do{if((t|0)<9){if((c[q>>2]|0)!=0){break}s=1<<t;c[q>>2]=s;x=s;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x}}while(0);x=(c[q>>2]<<2)+54|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;r=n+22|0;x=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>1;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x}}while(0);t=c[i>>2]|0;c[i>>2]=t+1;c[e+32>>2]=t;t=e+36|0;c[t>>2]=c[t>>2]|1;k=0;return k|0}function sE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((c[e+88>>2]|0)==0){yDb(a,16,1985432,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}c[d>>2]=0;h=a+24|0;j=d+4|0;c[j>>2]=c[h>>2];az(e,0);az(e,1);Vy(e,2,0)|0;a:do{if((c[h>>2]|0)!=0){k=a+28|0;l=0;while(1){m=c[(c[(c[k>>2]|0)+(l<<2)>>2]|0)+8>>2]|0;n=c[m+48>>2]|0;if((n|0)==79){o=c[m+140>>2]|0;if(!((o|0)==11|(o|0)==46|(o|0)==3|(o|0)==30)){p=7;break}}else if((n|0)==62){if((c[m+140>>2]|0)!=28){p=9;break}}else{p=10;break}q=c[m+120>>2]|0;r=c[m+124>>2]|0;if((q|0)>256|(r|0)>256){p=12;break}Vy(e,16,0)|0;l=l+1|0;if(!(l>>>0<(c[h>>2]|0)>>>0)){break a}}if((p|0)==7){yDb(a,16,1926816,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else if((p|0)==9){yDb(a,16,1904928,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else if((p|0)==10){yDb(a,16,1884304,(f=i,i=i+8|0,c[f>>2]=m+16,f)|0);i=f;g=-22;i=b;return g|0}else if((p|0)==12){yDb(a,16,2342408,(f=i,i=i+16|0,c[f>>2]=q,c[f+8>>2]=r,f)|0);i=f;g=-22;i=b;return g|0}}}while(0);f=cEb((c[j>>2]|0)*12|0)|0;c[d+8>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}Sy(e);g=0;i=b;return g|0}function tE(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=c[e+12>>2]|0;j=c[e+16>>2]|0;k=c[(c[(c[e+28>>2]|0)+(c[f+32>>2]<<2)>>2]|0)+8>>2]|0;l=h;m=c[l>>2]|0;if((m|0)>=(c[h+4>>2]|0)){yDb(e,16,2079536,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-5;i=g;return o|0}c[l>>2]=m+1;l=c[h+8>>2]|0;h=Ty(j,0,0,1)|0;c[l+(m*12|0)>>2]=h;h=k+120|0;a[l+(m*12|0)+8|0]=c[h>>2];p=k+124|0;a[l+(m*12|0)+9|0]=c[p>>2];if((c[k+48>>2]|0)==62){b[l+(m*12|0)+10>>1]=c[k+792>>2];k=f+28|0;c[l+(m*12|0)+4>>2]=c[k>>2];Ry(j,c[f+24>>2]|0,c[k>>2]|0);o=0;i=g;return o|0}k=f+24|0;q=c[k>>2]|0;r=q+14|0;s=r;if((d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)!=40){yDb(e,16,2029696,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}n=q+28|0;b[l+(m*12|0)+10>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=f+28|0;c[l+(m*12|0)+4>>2]=(c[n>>2]|0)-14+((ba((c[h>>2]|0)+7|0,c[p>>2]|0)|0)/8|0);Ry(j,r,8);r=(c[k>>2]|0)+22|0;Yy(j,(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24)<<1);Ry(j,(c[k>>2]|0)+26|0,(c[n>>2]|0)-26|0);if((ba((c[h>>2]|0)+7|0,c[p>>2]|0)|0)>7){t=0}else{o=0;i=g;return o|0}while(1){Py(j,0);n=t+1|0;if((n|0)<((ba((c[h>>2]|0)+7|0,c[p>>2]|0)|0)/8|0|0)){t=n}else{o=0;break}}i=g;return o|0}function uE(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[a+12>>2]|0;f=c[a+16>>2]|0;Ty(f,4,0,0)|0;az(f,c[e>>2]|0);g=e+4|0;h=e+8|0;if((c[g>>2]|0)<=0){$Db(h);return 0}e=h;i=a+28|0;a=0;do{Py(f,d[(c[e>>2]|0)+(a*12|0)+8|0]|0);Py(f,d[(c[e>>2]|0)+(a*12|0)+9|0]|0);j=c[(c[(c[i>>2]|0)+(a<<2)>>2]|0)+8>>2]|0;do{if((c[j+48>>2]|0)==79){if((c[j+140>>2]|0)!=11){k=8;break}l=b[(c[e>>2]|0)+(a*12|0)+10>>1]|0;if(l<<16>>16>7){m=0}else{m=1<<(l<<16>>16)}Py(f,m)}else{k=8}}while(0);if((k|0)==8){k=0;Py(f,0)}Py(f,0);az(f,1);az(f,b[(c[e>>2]|0)+(a*12|0)+10>>1]|0);Yy(f,c[(c[e>>2]|0)+(a*12|0)+4>>2]|0);Yy(f,c[(c[e>>2]|0)+(a*12|0)>>2]|0);a=a+1|0;}while((a|0)<(c[g>>2]|0));$Db(h);return 0}function vE(b,c){b=b|0;c=c|0;var e=0;if((d[b]|0)!=(a[c]|0)){e=0;return e|0}if((d[b+1|0]|0)!=(a[c+1|0]|0)){e=0;return e|0}if((d[b+2|0]|0)!=(a[c+2|0]|0)){e=0;return e|0}if((a[b+3|0]|0)==-1){e=0;return e|0}if((a[b+4|0]|0)==-1){e=0;return e|0}if(!((a[b+6|0]|0)>-1)){e=0;return e|0}if(!((a[b+7|0]|0)>-1)){e=0;return e|0}if(!((a[b+8|0]|0)>-1)){e=0;return e|0}e=(d[b+9|0]|0)>>>7^1;return e|0}function wE(b){b=b|0;return((d[b+7|0]|0)<<14&2080768|(d[b+6|0]|0)<<21&266338304|(d[b+8|0]|0)<<7&16256|a[b+9|0]&127)+((a[b+5|0]&16)==0?10:20)|0}function xE(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0;j=i;i=i+216|0;k=j|0;l=j+8|0;m=j+136|0;n=j+144|0;o=j+152|0;p=j+160|0;q=j+168|0;r=j+176|0;s=j+200|0;t=s|0;u=s+1|0;v=g+1|0;w=s+2|0;x=g+2|0;y=s+3|0;z=s+4|0;A=s+6|0;B=s+7|0;C=s+8|0;D=s+9|0;E=s+5|0;s=k|0;G=m;H=o;I=f;J=k+4|0;K=k+3|0;L=b+52|0;M=(h|0)==0;N=k+1|0;while(1){O=Ty(b,0,0,1)|0;P=F;if((mz(b,t,10)|0)!=10){Q=3;break}if((d[t]|0)!=(a[g]|0)){Q=83;break}if((d[u]|0)!=(a[v]|0)){Q=83;break}if((d[w]|0)!=(a[x]|0)){Q=83;break}k=a[y]|0;if(k<<24>>24==-1){Q=83;break}if((a[z]|0)==-1){Q=83;break}R=a[A]|0;if(!(R<<24>>24>-1)){Q=83;break}S=a[B]|0;if(!(S<<24>>24>-1)){Q=83;break}T=a[C]|0;if(!(T<<24>>24>-1)){Q=83;break}U=a[D]|0;if(!(U<<24>>24>-1)){Q=83;break}V=(S&255)<<14&2080768|(R&255)<<21&266338304|(T&255)<<7&16256|U&127;U=a[E]|0;T=Ty(b,0,0,1)|0;R=YGb(T,F,V,0)|0;T=F;c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;c[p>>2]=0;S=k&255;W=U&255;yDb(I,48,1879504,(X=i,i=i+24|0,c[X>>2]=S,c[X+8>>2]=W,c[X+16>>2]=V,X)|0);i=X;do{if((S|0)==3|(S|0)==4){U=W&128;if((W&64|0)==0){Y=V;Z=10;_=1;$=U;aa=1;Q=19;break}ba=(lz(b)|0)<<7&16256;ca=((lz(b)|0)&127|ba)<<7;ba=(ca|(lz(b)|0)&127)<<7;ca=ba|(lz(b)|0)&127;ba=k<<24>>24==4?ca-4|0:ca;if((ba|0)<0){da=2346936;Q=82;break}Vy(b,ba,(ba|0)<0|0?-1:0)|0;ca=V-4-ba|0;if((ca|0)<0){da=2345632;Q=82}else{Y=ca;Z=10;_=1;$=U;aa=1;Q=19}}else if((S|0)==2){if((W&64|0)!=0){da=2355576;Q=82;break}Y=V;Z=6;_=0;$=W&128;aa=0;Q=19}else{da=2351368;Q=82}}while(0);do{if((Q|0)==19){Q=0;a:do{if((Y|0)>=(Z|0)){V=k<<24>>24==3;U=0;ca=Y;b:while(1){ba=ca;while(1){if(aa){if((mz(b,s,4)|0)<4){break a}a[J]=0;if(V){ea=vz(b)|0}else{fa=(lz(b)|0)<<7&16256;ga=((lz(b)|0)&127|fa)<<7;fa=(ga|(lz(b)|0)&127)<<7;ea=fa|(lz(b)|0)&127}fa=tz(b)|0;ha=fa&2;ia=fa;ja=ea}else{if((mz(b,s,3)|0)<3){break a}a[K]=0;ha=0;ia=0;ja=uz(b)|0}if(ja>>>0>268435456>>>0){break a}ba=ba-Z-ja|0;if((ba|0)<0){break a}fa=Ty(b,0,0,1)|0;ka=YGb(fa,F,ja,0)|0;la=F;if((ja|0)!=0){break}if((a[s]|0)!=0){yDb(I,48,2344096,(X=i,i=i+8|0,c[X>>2]=s,X)|0);i=X}if((ba|0)<(Z|0)){break a}}if((ia&1|0)==0){c[q>>2]=ja;ma=ja}else{if(ja>>>0<4>>>0){break a}c[q>>2]=vz(b)|0;ma=ja-4|0}fa=ia&8;c:do{if((ia&4|0)==0){ga=a[s]|0;do{if(ga<<24>>24==84){na=U}else{if(M){oa=U}else{pa=AE(s,_)|0;if((pa|0)==0){oa=0}else{na=pa;break}}if(ga<<24>>24==0){break b}else{qa=oa;break c}}}while(0);ga=ha|$;pa=(ga|0)==0;ra=(fa|0)==0;do{if((ga|fa|0)!=0){kEb(G,n,ma);if((c[m>>2]|0)!=0){break}yDb(I,16,1909912,(X=i,i=i+8|0,c[X>>2]=ma,X)|0);i=X;qa=na;break c}}while(0);if(pa){sa=b;ta=ma}else{ga=Ty(b,0,0,1)|0;ua=YGb(ga,F,ma,0)|0;ga=F;va=c[m>>2]|0;wa=Ty(b,0,0,1)|0;xa=F;d:do{if((xa|0)<(ga|0)|(xa|0)==(ga|0)&wa>>>0<ua>>>0){ya=YGb(ua,ga,-1,-1)|0;za=F;Aa=va;while(1){if(!((Aa-(c[m>>2]|0)|0)>>>0<ma>>>0)){Ba=Aa;break d}if((c[L>>2]|0)!=0){Ba=Aa;break d}Ca=lz(b)|0;Da=Aa+1|0;a[Aa]=Ca;do{if((Ca&255|0)==255){Ea=Ty(b,0,0,1)|0;Fa=F;if(!((Fa|0)<(za|0)|(Fa|0)==(za|0)&Ea>>>0<ya>>>0)){Ga=Da;break}if(!((Da-(c[m>>2]|0)|0)>>>0<ma>>>0)){Ga=Da;break}if((c[L>>2]|0)!=0){Ga=Da;break}Ea=lz(b)|0;if((Ea&255|0)==0){Ha=(lz(b)|0)&255}else{Ha=Ea&255}a[Da]=Ha;Ga=Aa+2|0}else{Ga=Da}}while(0);Da=Ty(b,0,0,1)|0;Ca=F;if((Ca|0)<(ga|0)|(Ca|0)==(ga|0)&Da>>>0<ua>>>0){Aa=Ga}else{Ba=Ga;break}}}else{Ba=va}}while(0);va=c[m>>2]|0;ua=Ba;Ny(l,va,ua-va|0,0,0,0,0,0)|0;sa=l;ta=ua-(c[m>>2]|0)|0}do{if(ra){Ia=sa;Ja=ta}else{ua=c[q>>2]|0;yDb(I,48,2337616,(X=i,i=i+24|0,c[X>>2]=s,c[X+8>>2]=ta,c[X+16>>2]=ua,X)|0);i=X;kEb(H,p,ua);va=c[o>>2]|0;if((va|0)==0){yDb(I,16,2336056,(X=i,i=i+8|0,c[X>>2]=ua,X)|0);i=X;qa=na;break c}do{if(pa){ua=mz(b,c[m>>2]|0,ta)|0;if((ua|0)<0){yDb(I,16,2331280,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;qa=na;break c}else{Ka=ua;La=c[o>>2]|0;break}}else{Ka=ta;La=va}}while(0);va=Zb(La|0,q|0,c[m>>2]|0,Ka|0)|0;if((va|0)==0){Ny(l,c[o>>2]|0,c[q>>2]|0,0,0,0,0,0)|0;Ia=l;Ja=c[q>>2]|0;break}else{yDb(I,16,2326176,(X=i,i=i+8|0,c[X>>2]=va,X)|0);i=X;qa=na;break c}}}while(0);if((a[s]|0)==84){KE(f,Ia,Ja,e,s);qa=na;break}else{Se[c[na+8>>2]&511](f,Ia,Ja,s,h,_);qa=na;break}}else{yDb(I,24,2339016,(X=i,i=i+16|0,c[X>>2]=(fa|0)==0?2342840:2340168,c[X+8>>2]=s,X)|0);i=X;Vy(b,ma,0)|0;qa=U}}while(0);Ty(b,ka,la,0)|0;if((ba|0)<(Z|0)){break a}else{U=qa;ca=ba}}if((a[N]|0)!=0){yDb(I,24,2324016,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X}Vy(b,ma,0)|0;}}while(0);if(!(k<<24>>24==4)){Ma=T;Na=R;break}ca=(W&16|0)==0;U=YGb(R,T,10,0)|0;Ma=ca?T:F;Na=ca?R:U}else if((Q|0)==82){Q=0;yDb(I,32,2322064,(X=i,i=i+16|0,c[X>>2]=S,c[X+8>>2]=da,X)|0);i=X;Ma=T;Na=R}}while(0);Ty(b,Na,Ma,0)|0;ZDb(c[m>>2]|0);ZDb(c[o>>2]|0)}if((Q|0)==3){Ty(b,O,P,0)|0;}else if((Q|0)==83){Ty(b,O,P,0)|0;}QG(e,0,1205072);QG(e,0,918264);QG(e,0,1204984);P=r|0;TGb(P|0,0,17)|0;O=BBb(c[e>>2]|0,1906992,0,1)|0;do{if((O|0)==0){Q=89}else{b=c[O+4>>2]|0;if((SGb(b|0)|0)==4){Oa=b}else{Q=89;break}while(1){Pa=a[Oa]|0;if((Pa-48&255)>>>0<10>>>0){Oa=Oa+1|0}else{break}}if(Pa<<24>>24==0){Qa=b}else{Q=89}}}while(0);do{if((Q|0)==89){Pa=BBb(c[e>>2]|0,1905424,0,1)|0;if((Pa|0)==0){i=j;return}Oa=c[Pa+4>>2]|0;if((SGb(Oa|0)|0)==4){Ra=Oa}else{i=j;return}while(1){Sa=a[Ra]|0;if((Sa-48&255)>>>0<10>>>0){Ra=Ra+1|0}else{break}}if(Sa<<24>>24==0){Qa=Oa;break}i=j;return}}while(0);sAb(P,Qa,5)|0;CBb(e,1906992,0,0)|0;CBb(e,1905424,0,0)|0;Qa=BBb(c[e>>2]|0,1903480,0,1)|0;do{if((Qa|0)==0){Q=97}else{Sa=c[Qa+4>>2]|0;if((SGb(Sa|0)|0)==4){Ta=Sa}else{Q=97;break}while(1){Ua=a[Ta]|0;if((Ua-48&255)>>>0<10>>>0){Ta=Ta+1|0}else{break}}if(Ua<<24>>24==0){Va=Sa;Q=101}else{Q=97}}}while(0);do{if((Q|0)==97){Ua=BBb(c[e>>2]|0,1902296,0,1)|0;if((Ua|0)==0){break}Ta=c[Ua+4>>2]|0;if((SGb(Ta|0)|0)==4){Wa=Ta}else{break}while(1){Xa=a[Wa]|0;if((Xa-48&255)>>>0<10>>>0){Wa=Wa+1|0}else{break}}if(Xa<<24>>24==0){Va=Ta;Q=101}}}while(0);do{if((Q|0)==101){Lb(r+4|0,13,1901128,(X=i,i=i+16|0,c[X>>2]=Va+2,c[X+8>>2]=Va,X)|0)|0;i=X;CBb(e,1903480,0,0)|0;CBb(e,1902296,0,0)|0;Xa=BBb(c[e>>2]|0,1899752,0,1)|0;do{if((Xa|0)==0){Q=105}else{Wa=c[Xa+4>>2]|0;if((SGb(Wa|0)|0)==4){Ya=Wa}else{Q=105;break}while(1){Za=a[Ya]|0;if((Za-48&255)>>>0<10>>>0){Ya=Ya+1|0}else{break}}if(Za<<24>>24==0){_a=Wa}else{Q=105}}}while(0);if((Q|0)==105){Xa=BBb(c[e>>2]|0,1898344,0,1)|0;if((Xa|0)==0){break}Ta=c[Xa+4>>2]|0;if((SGb(Ta|0)|0)==4){$a=Ta}else{break}while(1){ab=a[$a]|0;if((ab-48&255)>>>0<10>>>0){$a=$a+1|0}else{break}}if(ab<<24>>24==0){_a=Ta}else{break}}Lb(r+10|0,7,1894144,(X=i,i=i+16|0,c[X>>2]=_a,c[X+8>>2]=_a+2,X)|0)|0;i=X;CBb(e,1899752,0,0)|0;CBb(e,1898344,0,0)|0}}while(0);if((a[P]|0)==0){i=j;return}CBb(e,2123056,P,0)|0;i=j;return}function yE(a,b,d){a=a|0;b=b|0;d=d|0;xE(c[a+16>>2]|0,a+1140|0,a,b,d);return}function zE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;c[d>>2]=e;if((e|0)==0){i=b;return}a=d;f=e;do{e=c[f>>2]|0;a:do{if((e|0)==0){g=f}else{do{if((PGb(e,1958672,4)|0)==0){h=918184}else{if((PGb(e,1972936,4)|0)==0){h=918200;break}if((PGb(e,1954088,4)|0)==0){h=918216;break}j=(PGb(e,1951840,4)|0)==0;if(j){h=j?918232:0}else{g=f;break a}}}while(0);me[c[h+12>>2]&511](c[f+4>>2]|0);g=c[d>>2]|0}}while(0);f=c[g+8>>2]|0;$Db(a);c[d>>2]=f;}while((f|0)!=0);i=b;return}function AE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=(b|0)!=0;b=c?4:3;do{if((a|0)==0){d=0}else{if(c){if((PGb(a,1958672,b)|0)==0){d=918184;break}if((PGb(a,1972936,b)|0)==0){d=918200;break}if((PGb(a,1954088,b)|0)==0){d=918216;break}e=(PGb(a,1951840,b)|0)==0;d=e?918232:0;break}else{if((PGb(a,1960552,b)|0)==0){d=918184;break}if((PGb(a,1956328,b)|0)==0){d=918200;break}if((PGb(a,1954088,b)|0)==0){d=918216;break}e=(PGb(a,1951840,b)|0)==0;return(e?918232:0)|0}}}while(0);return d|0}function BE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[b>>2]|0;if((d|0)==0){e=0;return e|0}else{f=d}while(1){if((QGb(c[f>>2]|0,1972936)|0)==0){d=c[f+4>>2]|0;b=LT(a,0)|0;if((b|0)==0){e=-12;g=6;break}h=b+72|0;c[h>>2]=c[h>>2]|1024;h=c[b+8>>2]|0;c[h+8>>2]=0;c[h+48>>2]=c[d+12>>2];h=b+88|0;CBb(h,2319824,c[d+8>>2]|0,0)|0;CBb(h,1967240,c[d+4>>2]|0,0)|0;h=b+104|0;vZ(h);i=d;c[h>>2]=c[i>>2];c[b+128>>2]=c[(c[i>>2]|0)+4>>2];c[b+132>>2]=(c[(c[i>>2]|0)+8>>2]|0)-16;c[b+136>>2]=c[b>>2];h=b+140|0;c[h>>2]=c[h>>2]|1;c[i>>2]=0}i=c[f+8>>2]|0;if((i|0)==0){e=0;g=6;break}else{f=i}}if((g|0)==6){return e|0}return 0}function CE(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+8|0;h=g|0;c[h>>2]=d;if((d|0)<1){i=g;return}j=cEb(20)|0;if((j|0)==0){yDb(a,16,1914656,(k=i,i=i+8|0,c[k>>2]=20,k)|0);i=k;i=g;return}l=cEb(12)|0;m=l;do{if((l|0)==0){yDb(a,16,1914656,(k=i,i=i+8|0,c[k>>2]=12,k)|0);i=k;n=j+4|0}else{o=lz(b)|0;c[h>>2]=d-1;p=j+4|0;q=(JE(a,b,0,p,h)|0)<0;if(q|(c[h>>2]|0)<1){n=p;break}q=o<<24>>24;o=(JE(a,b,q,j+8|0,h)|0)<0;if(o|(c[h>>2]|0)<1){n=p;break}o=JE(a,b,q,j+12|0,h)|0;q=c[h>>2]|0;if((q|o|0)<0){n=p;break}if((q|0)==0){c[j+16>>2]=0;c[j>>2]=0}else{o=WDb(q)|0;c[j+16>>2]=o;if((o|0)==0){yDb(a,16,1909912,(k=i,i=i+8|0,c[k>>2]=q,k)|0);i=k;n=p;break}p=mz(b,o,q)|0;if(p>>>0<q>>>0){yDb(a,24,1908568,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k}c[j>>2]=p}c[l>>2]=1958672;c[l+4>>2]=j;c[l+8>>2]=c[f>>2];c[f>>2]=m;i=g;return}}while(0);yDb(a,16,1932656,(k=i,i=i+8|0,c[k>>2]=e,k)|0);i=k;ZDb(c[n>>2]|0);ZDb(c[j+8>>2]|0);ZDb(c[j+12>>2]|0);ZDb(c[j+16>>2]|0);ZDb(j);ZDb(l);i=g;return}function DE(a){a=a|0;ZDb(c[a+4>>2]|0);ZDb(c[a+8>>2]|0);ZDb(c[a+12>>2]|0);ZDb(c[a+16>>2]|0);ZDb(a);return}function EE(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+88|0;j=f|0;k=f+8|0;l=f+16|0;m=f+80|0;c[k>>2]=e;c[m>>2]=0;n=Ty(d,0,0,1)|0;o=YGb(e,(e|0)<0|0?-1:0,n,F)|0;n=F;do{if((e|0)>=5){c[m>>2]=cEb(12)|0;p=cEb(16)|0;q=(p|0)==0;a:do{if((c[m>>2]|0)==0|q){r=19}else{s=lz(d)|0;t=e-1|0;c[k>>2]=t;u=l|0;if((h|0)==0){mz(d,u,3)|0;a[l+3|0]=0;v=t}else{w=t-(xz(d,t,u,64)|0)|0;c[k>>2]=w;v=w}w=1204600;while(1){x=w+32|0;if((c[x>>2]|0)==0){break}if((zAb(w|0,u,64)|0)==0){r=9;break}else{w=w+36|0}}do{if((r|0)==9){w=c[x>>2]|0;if((w|0)==0){break}c[p+12>>2]=w;w=lz(d)|0;c[k>>2]=v-1;if((w|0)<0|w>>>0>20>>>0){yDb(b,24,1921040,(y=i,i=i+8|0,c[y>>2]=w,y)|0);i=y;z=0}else{z=w}c[p+4>>2]=c[1204512+(z<<2)>>2];w=p+8|0;if((JE(b,d,s,w,k)|0)<0){yDb(b,16,1919208,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;r=19;break a}t=c[k>>2]|0;A=UAb(t+16|0)|0;B=p;c[B>>2]=A;if((A|0)==0){C=B;D=w;break a}if((t|0)==0){r=19;break a}if((mz(d,c[A+4>>2]|0,t)|0)!=(t|0)){r=19;break a}TGb((c[(c[B>>2]|0)+4>>2]|0)+t|0,0,16)|0;c[c[m>>2]>>2]=1972936;c[(c[m>>2]|0)+4>>2]=p;c[(c[m>>2]|0)+8>>2]=c[g>>2];c[g>>2]=c[m>>2];i=f;return}}while(0);yDb(b,24,1922456,(y=i,i=i+8|0,c[y>>2]=u,y)|0);i=y;r=19}}while(0);if((r|0)==19){if(q){break}C=p;D=p+8|0}c[j>>2]=p;XAb(C);$Db(D);$Db(j)}}while(0);$Db(m);Ty(d,o,n,0)|0;i=f;return}function FE(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;XAb(a);$Db(a+8|0);$Db(d);i=b;return}function GE(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+24|0;g=h|0;f=h+8|0;j=h+16|0;c[g>>2]=e;c[f>>2]=0;if((b|0)==0){yDb(0,48,1938952,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=h;return}e=(JE(b,d,0,f,g)|0)<0;k=c[g>>2]|0;if(e|(k|0)<16){i=h;return}e=vz(d)|0;l=vz(d)|0;Vy(d,8,0)|0;m=OT(b,(c[b+1132>>2]|0)+1|0,549272,e,0,l,0,c[f>>2]|0)|0;if((m|0)==0){ZDb(c[f>>2]|0);i=h;return}l=k-16|0;c[g>>2]=l;a:do{if((l|0)>10){k=j|0;e=j+4|0;n=m+32|0;o=l;while(1){if((mz(d,k,4)|0)<4){break a}a[e]=0;p=vz(d)|0;Vy(d,2,0)|0;q=o-10|0;c[g>>2]=q;if((p|0)<0|(p|0)>(q|0)){break a}if((a[k]|0)==84){KE(b,d,p,n,k)}else{Vy(d,p,(p|0)<0|0?-1:0)|0;}r=q-p|0;c[g>>2]=r;if((r|0)>10){o=r}else{s=n;t=15;break}}}else{s=m+32|0;t=15}}while(0);if((t|0)==15){QG(s,0,1205072);QG(s,0,1204984)}ZDb(c[f>>2]|0);i=h;return}function HE(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+24|0;e=g|0;h=g+8|0;j=g+16|0;c[h>>2]=d;d=cEb(12)|0;c[j>>2]=d;k=cEb(12)|0;l=(k|0)==0;do{if(!((d|0)==0|l)){if((JE(a,b,0,k,h)|0)<0){break}m=c[h>>2]|0;n=WDb(m)|0;c[k+4>>2]=n;if((n|0)==0){break}o=k+8|0;c[o>>2]=m;p=mz(b,n,m)|0;if((p|0)!=(c[o>>2]|0)){break}c[c[j>>2]>>2]=1951840;c[(c[j>>2]|0)+4>>2]=k;c[(c[j>>2]|0)+8>>2]=c[f>>2];c[f>>2]=c[j>>2];i=g;return}}while(0);if(!l){c[e>>2]=k;$Db(k);$Db(k+4|0);$Db(e)}$Db(j);i=g;return}function IE(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;$Db(a);$Db(a+4|0);$Db(d);i=b;return}function JE(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+8|0;j=h|0;k=c[g>>2]|0;l=Mz(j)|0;if((l|0)<0){yDb(a,16,1949800,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=l;i=h;return n|0}do{if((e|0)==2){o=k;p=2402;q=5}else if((e|0)==0){if((k|0)==0){r=0;q=35;break}else{s=k}while(1){l=lz(b)|0;do{if(l>>>0<128>>>0){Py(c[j>>2]|0,l&255)}else{t=l>>>0>65535>>>0;u=t?l>>>16:l;v=t?16:0;if((u&65280|0)==0){w=v;x=u}else{w=v|8;x=u>>>8}u=(w+4+(d[1191992+x|0]|0)|0)/5|0;v=(u*6|0)-6|0;Py(c[j>>2]|0,(l>>>(v>>>0)|256-(256>>>(u>>>0)))&255);if((v|0)>5){y=v}else{break}do{y=y-6|0;Py(c[j>>2]|0,l>>>(y>>>0)&63|128);}while((y|0)>5)}}while(0);v=s-1|0;if((v|0)==0|(l|0)==0){z=l;A=v;q=34;break}else{s=v}}}else if((e|0)==3){if((k|0)==0){r=0;q=35;break}else{B=k}while(1){v=lz(b)|0;Py(c[j>>2]|0,v);u=B-1|0;if((u|0)==0|(v|0)==0){z=v;A=u;q=34;break}else{B=u}}}else if((e|0)==1){u=k-2|0;if((u|0)<0){yDb(a,16,1947736,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;Oz(c[j>>2]|0,f)|0;$Db(f);n=-1094995529;i=h;return n|0}v=tz(b)|0;if((v|0)==65279){o=u;p=2402;q=5;break}else if((v|0)==65534){o=u;p=1064;q=5;break}yDb(a,16,1946040,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;Oz(c[j>>2]|0,f)|0;$Db(f);c[g>>2]=u;n=-1094995529;i=h;return n|0}else{yDb(a,24,1944144,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;r=k;q=35}}while(0);if((q|0)==5){a:do{if((o|0)<2){C=1;D=o}else{k=o;while(1){m=k-2|0;do{if((m|0)>-1){a=re[p&4095](b)|0;e=a-55296|0;if(e>>>0<2048>>>0){B=k-4|0;if(!((B|0)>-1)){C=-56320;D=B;break a}s=(re[p&4095](b)|0)-56320|0;if(s>>>0>1023>>>0|e>>>0>1023>>>0){C=s;D=B;break a}E=(e<<10)+65536+s|0;F=B}else{E=a;F=m}if(E>>>0<128>>>0){G=F;H=E;q=25;break}a=E>>>0>65535>>>0;B=a?E>>>16:E;s=a?16:0;if((B&65280|0)==0){I=s;J=B}else{I=s|8;J=B>>>8}B=(I+4+(d[1191992+J|0]|0)|0)/5|0;s=(B*6|0)-6|0;Py(c[j>>2]|0,(E>>>(s>>>0)|256-(256>>>(B>>>0)))&255);if((s|0)>5){K=s}else{L=E;M=F;break}while(1){s=K-6|0;Py(c[j>>2]|0,E>>>(s>>>0)&63|128);if((s|0)>5){K=s}else{L=E;M=F;break}}}else{G=m;H=0;q=25}}while(0);if((q|0)==25){q=0;Py(c[j>>2]|0,H&255);L=H;M=G}if((M|0)<2|(L|0)==0){C=L;D=M;break}else{k=M}}}}while(0);z=C;A=(D|0)<0?D+2|0:D;q=34}if((q|0)==34){if((z|0)==0){N=A}else{r=A;q=35}}if((q|0)==35){Py(c[j>>2]|0,0);N=r}Oz(c[j>>2]|0,f)|0;c[g>>2]=N;n=0;i=h;return n|0}function KE(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+32|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;c[j>>2]=e;c[k>>2]=g;if((e|0)<1){i=h;return}n=lz(d)|0;c[j>>2]=e-1;if((JE(b,d,n,l,j)|0)<0){yDb(b,16,1932656,(o=i,i=i+8|0,c[o>>2]=g,o)|0);i=o;i=h;return}if((QGb(g,2029688)|0)==0){p=6}else{if((QGb(g,1930808)|0)==0){p=6}else{p=10}}do{if((p|0)==6){g=xd(c[l>>2]|0,1929064,(o=i,i=i+8|0,c[o>>2]=m,o)|0)|0;i=o;if((g|0)==1){if(!((c[m>>2]|0)>>>0<148>>>0)){p=10;break}}else{g=xd(c[l>>2]|0,1927448,(o=i,i=i+8|0,c[o>>2]=m,o)|0)|0;i=o;if(!((g|0)==1&(c[m>>2]|0)>>>0<148>>>0)){p=10;break}}$Db(l);g=eEb(c[1205192+(c[m>>2]<<2)>>2]|0)|0;c[l>>2]=g;q=24;r=g}}while(0);a:do{if((p|0)==10){m=c[k>>2]|0;do{if((QGb(m,1925464)|0)==0){p=12}else{if((QGb(m,1924152)|0)==0){p=12;break}g=c[l>>2]|0;if((a[g]|0)!=0){q=24;r=g;break a}$Db(l);s=24}}while(0);do{if((p|0)==12){m=c[l>>2]|0;c[k>>2]=m;if((JE(b,d,n,l,j)|0)>=0){s=28;break}yDb(b,16,1932656,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;$Db(k);i=h;return}}while(0);q=s;r=c[l>>2]|0}}while(0);if((r|0)==0){i=h;return}CBb(f,c[k>>2]|0,r,q)|0;i=h;return}function LE(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+8>>2]|0;if((b|0)<65568){e=0;return e|0}f=c[a+4>>2]|0;a=f;g=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((g|0)==0|g>>>0>1024>>>0){e=0;return e|0}a=f+4|0;h=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((h|0)==0|h>>>0>1024>>>0){e=0;return e|0}a=f+8|0;i=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(i|0)!=0;if(a&(i-8e3|0)>>>0>4e4>>>0){e=0;return e|0}i=f+12|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;if(j>>>0>2>>>0|a&(j|0)==0){e=0;return e|0}j=f+16|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;if(i>>>0>2>>>0|a&(i|0)==0){e=0;return e|0}i=f+65556|0;a=(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)==1?66324:65556;if((a+12|0)>(b|0)){e=1;return e|0}else{e=f+(a|8)|0;a=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==(ba(h,g)|0);return(a?50:1)|0}return 0}function ME(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=a+16|0;e=c[d>>2]|0;f=c[a+12>>2]|0;g=rz(e)|0;h=rz(e)|0;j=rz(e)|0;k=rz(e)|0;l=rz(e)|0;m=a;if((c[(c[d>>2]|0)+52>>2]|0)!=0){yDb(m,16,2029336,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=c[(c[d>>2]|0)+76>>2]|0;p=(o|0)==0?-541478725:o;i=b;return p|0}if((hDb(g,h,0,m)|0)<0){p=-1094995529;i=b;return p|0}do{if((j|0)==0){c[f+28>>2]=0}else{if(j>>>0<14>>>0|(j|0)<0){yDb(m,16,1985096,(n=i,i=i+8|0,c[n>>2]=j,n)|0);i=n;p=-1094995529;i=b;return p|0}if((k|0)==0|k>>>0>2>>>0){yDb(m,16,1953336,(n=i,i=i+8|0,c[n>>2]=k,n)|0);i=n;p=-1094995529;i=b;return p|0}if(!((l|0)==0|l>>>0>2>>>0)){c[f+28>>2]=1;break}yDb(m,16,1926712,(n=i,i=i+8|0,c[n>>2]=l,n)|0);i=n;p=-1094995529;i=b;return p|0}}while(0);n=LT(a,0)|0;if((n|0)==0){p=-12;i=b;return p|0}MT(n,33,1,14);m=n+48|0;c[m>>2]=0;c[m+4>>2]=0;c[f>>2]=c[n>>2];m=c[n+8>>2]|0;c[m+8>>2]=0;c[m+48>>2]=48;c[m+52>>2]=0;c[m+120>>2]=g;c[m+124>>2]=h;h=CT(m,e,65536)|0;if((h|0)<0){p=h;i=b;return p|0}h=f+28|0;if((c[h>>2]|0)!=0){c[h>>2]=1;h=LT(a,0)|0;if((h|0)==0){p=-12;i=b;return p|0}MT(h,63,1,j);a=h+48|0;c[a>>2]=0;c[a+4>>2]=0;c[f+4>>2]=c[h>>2];a=c[h+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=1;c[a+416>>2]=l;h=l>>>0>1>>>0;e=a+448|0;c[e>>2]=h?3:4;c[e+4>>2]=h?0:0;c[a+412>>2]=j;c[a+792>>2]=k<<3;c[a+72>>2]=ba(ba(j<<3,k)|0,l)|0;h=ba(l,k)|0;c[f+16>>2]=h;c[a+432>>2]=h;c[a+48>>2]=(k|0)==1?65541:65536;k=(j>>>0)/14|0;a=ba(h,k)|0;if(((j>>>0)%14|0|0)==0){c[f+12>>2]=a;c[f+8>>2]=a}else{c[f+8>>2]=a;c[f+12>>2]=ba(h,k+1|0)|0}c[f+20>>2]=0}c[f+24>>2]=1;k=Ty(c[d>>2]|0,0,0,1)|0;d=f+32|0;c[d>>2]=k;c[d+4>>2]=F;p=0;i=b;return p|0}function NE(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+1792|0;f=e|0;g=e+768|0;h=c[a+12>>2]|0;j=a+16|0;k=c[j>>2]|0;if((Xy(k)|0)!=0){l=c[(c[j>>2]|0)+76>>2]|0;m=(l|0)==0?-541478725:l;i=e;return m|0}l=h+24|0;do{if((c[l>>2]|0)==0){n=h+20|0;o=c[((c[n>>2]|0)==0?h+8|0:h+12|0)>>2]|0;p=TS(k,b,o)|0;if((p|0)<0){m=p;i=e;return m|0}else{c[b+32>>2]=c[h+4>>2];c[b+48>>2]=(o>>>0)/((c[h+16>>2]|0)>>>0)|0;c[n>>2]=c[n>>2]^1;break}}else{n=rz(k)|0;if((n|0)==2){m=-5;i=e;return m|0}o=(n|0)==1;if(o){n=mz(k,f|0,768)|0;if((n|0)<0){m=n;i=e;return m|0}if((n|0)==768){q=0}else{yDb(a,16,2146208,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=-5;i=e;return m|0}while(1){if((q|0)>=768){s=0;t=11;break}if((d[f+q|0]|0)>>>0>63>>>0){u=0;t=12;break}else{q=q+1|0}}if((t|0)==11){while(1){t=0;n=s*3|0;p=(d[f+(n+1)|0]|0)<<10&64512|(d[f+n|0]|0)<<18|(d[f+(n+2)|0]|0)<<2&252;c[g+(s<<2)>>2]=p>>>6&197379|(p|-16777216);p=s+1|0;if((p|0)<256){s=p;t=11}else{break}}}else if((t|0)==12){while(1){t=0;p=u*3|0;c[g+(u<<2)>>2]=(d[f+(p+1)|0]|0)<<8|(d[f+p|0]|0)<<16|(d[f+(p+2)|0]|0)|-16777216;p=u+1|0;if((p|0)<256){u=p;t=12}else{break}}}}if((c[(c[j>>2]|0)+52>>2]|0)!=0){yDb(a,16,2146208,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=c[(c[j>>2]|0)+76>>2]|0;m=(p|0)==0?-541478725:p;i=e;return m|0}p=rz(k)|0;n=p-4|0;if(n>>>0>2147483639>>>0){yDb(a,16,2079144,(r=i,i=i+8|0,c[r>>2]=p,r)|0);i=r;m=-1094995529;i=e;return m|0}Vy(k,4,0)|0;if(p>>>0<4>>>0){m=-1094995529;i=e;return m|0}p=TS(k,b,n)|0;if((p|0)<0){m=p;i=e;return m|0}if((p|0)!=(n|0)){yDb(a,16,2146208,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;BZ(b);m=-5;i=e;return m|0}do{if(o){n=GZ(b,0,1024)|0;if((n|0)!=0){UGb(n|0,g|0,1024)|0;n=b+36|0;c[n>>2]=c[n>>2]|1;break}BZ(b);m=-12;i=e;return m|0}}while(0);c[b+32>>2]=c[h>>2];c[b+48>>2]=1}}while(0);if((c[h+28>>2]|0)==0){m=0;i=e;return m|0}c[l>>2]=c[l>>2]^1;m=0;i=e;return m|0}function OE(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;f=c[a+12>>2]|0;e=f+32|0;d=c[e>>2]|0;b=c[e+4>>2]|0;e=0;if(!((b|0)>(e|0)|(b|0)==(e|0)&d>>>0>0>>>0)){g=-1;return g|0}e=Ty(c[a+16>>2]|0,d,b,0)|0;b=e;if((b|0)<0){g=b;return g|0}lT(a,c[(c[a+28>>2]|0)+(c[f>>2]<<2)>>2]|0,0,0);c[f+24>>2]=1;c[f+20>>2]=0;g=0;return g|0}function PE(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==4228){a=b+2|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==-1?100:0)|0}else{return 0}return 0}function QE(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;e=b|0;f=c[a+12>>2]|0;if((mz(c[a+16>>2]|0,e|0,8)|0)!=8){g=-5;i=b;return g|0}h=e+6|0;c[f>>2]=(d[h]|d[h+1|0]<<8)<<16>>16&65535;c[f+32>>2]=0;h=f+24|0;c[h>>2]=0;c[h+4>>2]=0;c[f+12>>2]=0;c[f+8>>2]=0;c[f+4>>2]=0;c[f+20>>2]=-1;c[f+16>>2]=-1;f=a+20|0;c[f>>2]=c[f>>2]|1;g=0;i=b;return g|0}function RE(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=i;i=i+8|0;h=g|0;j=h;k=c[d+12>>2]|0;l=d+16|0;m=c[l>>2]|0;n=h;o=h+2|0;p=k+16|0;q=k;r=k+4|0;s=n+2|0;t=k+8|0;u=f+32|0;v=k+24|0;w=f+8|0;y=k+20|0;z=k+12|0;A=f+24|0;B=f+64|0;C=k+32|0;k=m;a:while(1){if((Xy(k)|0)!=0){D=-5;E=30;break}if((mz(m,n,8)|0)!=8){D=-5;E=30;break}G=b[j>>1]|0;H=G&65535;I=e[o>>1]|e[o+2>>1]<<16;if((I|0)<0){D=-1094995529;E=30;break}J=SS(m,I)|0;switch(H|0){case 4113:{break a;break};case 4098:{E=12;break a;break};case 4097:{break};case 4128:case 4129:{E=16;break a;break};default:{E=29;break a}}if((c[p>>2]|0)==-1){I=LT(d,0)|0;if((I|0)==0){D=-12;E=30;break}MT(I,63,1,c[q>>2]|0);c[p>>2]=c[I>>2];K=I+8|0;I=c[K>>2]|0;c[I+8>>2]=0;c[I+48>>2]=39;c[I+52>>2]=0;if((mz(m,n,8)|0)!=8){D=-5;E=30;break}I=e[j>>1]|0;c[r>>2]=I;L=c[K>>2]|0;c[L+120>>2]=I;I=e[s>>1]|0;c[t>>2]=I;c[L+124>>2]=I}else{Vy(m,8,0)|0;}k=c[l>>2]|0}do{if((E|0)==12){if((c[p>>2]|0)<0){D=-1094995529;i=g;return D|0}l=Ty(m,0,0,1)|0;k=F;Vy(m,J,0)|0;if((mz(m,n,8)|0)!=8){D=-5;i=g;return D|0}t=YGb(l,k,-8,-1)|0;k=J+16+(e[o>>1]|e[o+2>>1]<<16)|0;Ty(m,t,F,0)|0;if((TS(m,f,k)|0)!=(k|0)){D=-5;i=g;return D|0}c[u>>2]=c[p>>2];t=c[v>>2]|0;l=c[v+4>>2]|0;s=YGb(t,l,1,0)|0;c[v>>2]=s;c[v+4>>2]=F;c[w>>2]=t;c[w+4>>2]=l;D=k;i=g;return D|0}else if((E|0)==16){if(!((c[y>>2]|0)==-1)){break}k=LT(d,0)|0;if((k|0)==0){D=-12;i=g;return D|0}MT(k,32,1,22050);c[y>>2]=c[k>>2];l=c[k+8>>2]|0;c[l+8>>2]=1;c[l+48>>2]=81920;c[l+52>>2]=0;k=l+416|0;if(G<<16>>16==4129){c[k>>2]=2;t=l+448|0;c[t>>2]=3;c[t+4>>2]=0;M=2}else{c[k>>2]=1;t=l+448|0;c[t>>2]=4;c[t+4>>2]=0;M=1}c[z>>2]=M;c[l+412>>2]=22050;c[l+792>>2]=16;t=c[k>>2]|0;c[l+72>>2]=t*352800|0;c[l+432>>2]=t<<4}else if((E|0)==29){yDb(d,16,2146160,(t=i,i=i+8|0,c[t>>2]=H,t)|0);i=t;D=-1094995529;i=g;return D|0}else if((E|0)==30){i=g;return D|0}}while(0);E=G<<16>>16==4113;do{if(E){if((c[p>>2]|0)<0){D=-1094995529}else{break}i=g;return D|0}}while(0);if((wZ(f,J+8|0)|0)!=0){D=-5;i=g;return D|0}f=c[A>>2]|0;G=c[h+4>>2]|0;H=f|0;x=c[h>>2]|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=f+4|0;x=G;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;if(E){c[u>>2]=c[p>>2];p=c[v>>2]|0;E=c[v+4>>2]|0;H=YGb(p,E,1,0)|0;c[v>>2]=H;c[v+4>>2]=F;c[w>>2]=p;c[w+4>>2]=E}else{c[u>>2]=c[y>>2];y=c[C>>2]|0;c[w>>2]=y;c[w+4>>2]=0;c[C>>2]=y+((J>>>0)/((c[z>>2]|0)>>>0)|0)}z=Ty(m,0,0,1)|0;c[B>>2]=z;c[B+4>>2]=F;B=mz(m,(c[A>>2]|0)+8|0,J)|0;D=(B|0)==(J|0)?B:-5;i=g;return D|0}function SE(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;f=e;c[e>>2]=-61308;c[e+4>>2]=2031615;g=c[b+24>>2]|0;h=b+28|0;j=0;while(1){if(!(j>>>0<g>>>0)){break}k=c[(c[(c[h>>2]|0)+(j<<2)>>2]|0)+8>>2]|0;if((c[k+8>>2]|0)==0){l=4;break}else{j=j+1|0}}if((l|0)==4){if((c[k+104>>2]|0)!=1){yDb(k,16,2146096,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=d;return n|0}l=c[k+108>>2]|0;if(l>>>0>255>>>0){yDb(k,16,2078888,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=d;return n|0}if((l|0)!=30){yDb(k,24,2029272,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}a[f+6|0]=l}l=b+16|0;Ry(c[l>>2]|0,e,8);Sy(c[l>>2]|0);n=0;i=d;return n|0}function TE(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297239878){e=b+8|0;f=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if((f|0)==1482052408|(f|0)==1448293937|(f|0)==1146437965|(f|0)==541934160|(f|0)==1296188225|(f|0)==1346716996|(f|0)==1296190537|(f|0)==943867730|(f|0)==1312966482){g=100}else{break}return g|0}}while(0);g=0;return g|0}function UE(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;i=i+16|0;e=c[b+12>>2]|0;f=b+16|0;g=c[f>>2]|0;h=LT(b,0)|0;if((h|0)==0){j=-12;i=d;return j|0}k=h+8|0;l=c[k>>2]|0;c[l+416>>2]=1;m=l+448|0;c[m>>2]=4;c[m+4>>2]=0;Vy(g,8,0)|0;m=rz(g)|0;c[(c[k>>2]|0)+52>>2]=m;m=e+32|0;l=e+20|0;n=l;o=e+24|0;p=e+28|0;TGb(l|0,-1|0,16)|0;l=e;a:do{if((Xy(g)|0)==0){q=e+8|0;r=e+16|0;s=h+80|0;t=h+84|0;u=d|0;v=e+56|0;w=b+1140|0;y=0;z=0;A=0;b:while(1){B=rz(g)|0;C=vz(g)|0;D=Ty(g,0,0,1)|0;E=F;do{if((B|0)==1312901187){if(C>>>0<4>>>0){j=-1094995529;G=89;break b}H=(vz(g)|0)>>>0<6>>>0;I=c[k>>2]|0;J=I+416|0;if(H){c[J>>2]=1;H=I+448|0;c[H>>2]=4;c[H+4>>2]=0;K=y;L=z;M=A;break}else{c[J>>2]=2;J=I+448|0;c[J>>2]=3;c[J+4>>2]=0;K=y;L=z;M=A;break}}else if((B|0)==1145589058){c[(c[k>>2]|0)+8>>2]=0;if(C>>>0<9>>>0){j=-1094995529;G=89;break b}J=tz(g)|0;c[(c[k>>2]|0)+120>>2]=J;J=tz(g)|0;c[(c[k>>2]|0)+124>>2]=J;Vy(g,4,0)|0;J=lz(g)|0;c[(c[k>>2]|0)+792>>2]=J;if(!(C>>>0>9>>>0)){K=y;L=z;M=A;break}J=lz(g)|0;if(!(C>>>0>10>>>0)){K=y;L=J;M=A;break}c[m>>2]=lz(g)|0;if(!(C>>>0>13>>>0)){K=y;L=J;M=A;break}Vy(g,1,0)|0;I=tz(g)|0;if(!(C>>>0>15>>>0)){K=I;L=J;M=A;break}c[s>>2]=lz(g)|0;c[t>>2]=lz(g)|0;K=I;L=J;M=A}else if((B|0)==1279610948){if(!(C>>>0>3>>>0&(C&3|0)==0)){j=-1094995529;G=89;break b}J=mz(g,u,16)|0;if((J|0)<0){j=J;G=89;break b}if((J|0)!=16){G=43;break b}if((PGb(u,1402688,16)|0)==0){c[(c[k>>2]|0)+140>>2]=2;K=y;L=z;M=A;break}if((PGb(u,1402672,16)|0)==0){c[(c[k>>2]|0)+140>>2]=28;K=y;L=z;M=A;break}if((PGb(u,1402704,16)|0)==0){c[(c[k>>2]|0)+140>>2]=30;K=y;L=z;M=A;break}if((PGb(u,1402720,16)|0)==0){c[(c[k>>2]|0)+140>>2]=27;K=y;L=z;M=A;break}if((PGb(u,1402736,16)|0)!=0){G=43;break b}c[(c[k>>2]|0)+140>>2]=29;K=y;L=z;M=A}else if((B|0)==1380206678){c[(c[k>>2]|0)+8>>2]=1;if(C>>>0<14>>>0){j=-1094995529;G=89;break b}Vy(g,12,0)|0;J=tz(g)|0;c[(c[k>>2]|0)+412>>2]=J;if(!(C>>>0>15>>>0)){K=y;L=z;M=A;break}Vy(g,1,0)|0;c[n>>2]=lz(g)|0;K=y;L=z;M=A}else if((B|0)==1213486401){N=1904784;G=53}else if((B|0)==539583272){N=1884128;G=53}else if((B|0)==1279412036){c[(c[k>>2]|0)+8>>2]=0;if(C>>>0<8>>>0){j=-1094995529;G=89;break b}J=tz(g)|0;c[(c[k>>2]|0)+120>>2]=J;J=tz(g)|0;c[(c[k>>2]|0)+124>>2]=J;c[m>>2]=tz(g)|0;c[s>>2]=lz(g)|0;c[t>>2]=lz(g)|0;c[(c[k>>2]|0)+792>>2]=24;K=y;L=z;M=A}else if((B|0)==1129270340){if(C>>>0<4>>>0){j=-1094995529;G=89;break b}J=tz(g)|0;c[(c[k>>2]|0)+120>>2]=J;J=tz(g)|0;c[(c[k>>2]|0)+124>>2]=J;K=y;L=z;M=A}else if((B|0)==1162690894){N=2342216;G=53}else if((B|0)==1330531905|(B|0)==1415071060){N=1926672;G=53}else if((B|0)==1128552020){if(C>>>0<32>>>0){j=-1094995529;G=89;break b}J=mz(g,v,32)|0;if((J|0)<0){j=J;G=89;break b}else{K=y;L=z;M=A}}else if((B|0)==1414087233|(B|0)==1497648962|(B|0)==1146044996|(B|0)==1413563469){J=Ty(g,0,0,1)|0;I=F;c[l>>2]=J;c[l+4>>2]=I;H=YGb(J,I,C,0)|0;c[q>>2]=H;c[q+4>>2]=F;c[r>>2]=C;K=y;L=z;M=A}else if((B|0)==1196245315){if(C>>>0<4>>>0){j=-1094995529;G=89;break b}K=y;L=z;M=vz(g)|0}else if((B|0)==1346456899){if(!((C-3|0)>>>0<766>>>0&((C>>>0)%3|0|0)==0)){G=21;break b}c[(c[k>>2]|0)+100>>2]=C+41;H=WDb(C+57|0)|0;c[(c[k>>2]|0)+96>>2]=H;H=c[(c[k>>2]|0)+96>>2]|0;if((H|0)==0){j=-12;G=89;break b}if((mz(g,H+41|0,C)|0)<0){j=-5;G=89;break b}else{K=y;L=z;M=A}}else if((B|0)==1380206669){c[(c[k>>2]|0)+8>>2]=1;if(C>>>0<32>>>0){j=-1094995529;G=89;break b}Vy(g,4,0)|0;c[o>>2]=tz(g)|0;Vy(g,2,0)|0;H=vz(g)|0;I=tz(g)|0;if((I|0)==0){j=-1094995529;G=89;break b}Vy(g,2,0)|0;c[(c[k>>2]|0)+412>>2]=(H>>>0)/(I>>>0)|0;I=tz(g)|0;c[(c[k>>2]|0)+416>>2]=I;c[p>>2]=tz(g)|0;I=c[k>>2]|0;H=c[I+416>>2]|0;if((H|0)==2){J=I+448|0;c[J>>2]=3;c[J+4>>2]=0;K=y;L=z;M=A;break}else if((H|0)==1){H=I+448|0;c[H>>2]=4;c[H+4>>2]=0;K=y;L=z;M=A;break}else{K=y;L=z;M=A;break}}else{K=y;L=z;M=A}}while(0);if((G|0)==53){G=0;B=C+1|0;if((B|0)==0){O=-12;break}P=WDb(B)|0;if((P|0)==0){O=-12;break}if((mz(c[f>>2]|0,P,C)|0)!=(C|0)){G=56;break}a[P+C|0]=0;CBb(w,N,P,8)|0;K=y;L=z;M=A}B=Ty(g,0,0,1)|0;H=F;I=YGb(C,0,D,E)|0;J=YGb(I,F,C&1,0)|0;I=ZGb(J,F,B,H)|0;Vy(g,I,F)|0;if((Xy(g)|0)==0){y=K;z=L;A=M}else{Q=K;R=L;S=M;break a}}if((G|0)==21){yDb(b,16,1984296,(T=i,i=i+8|0,c[T>>2]=C,T)|0);i=T;j=-1094995529;i=d;return j|0}else if((G|0)==43){DDb(b,1953264,(T=i,i=i+8|0,c[T>>2]=u,T)|0);i=T;j=-1163346256;i=d;return j|0}else if((G|0)==56){ZDb(P);O=-5}else if((G|0)==89){i=d;return j|0}yDb(b,16,2319648,(T=i,i=i+8|0,c[T>>2]=N,T)|0);i=T;j=O;i=d;return j|0}else{Q=0;R=0;S=0}}while(0);Ty(g,c[l>>2]|0,c[l+4>>2]|0,0)|0;l=c[k>>2]|0;g=c[l+8>>2]|0;if((g|0)==1){MT(h,32,1,c[l+412>>2]|0);h=c[k>>2]|0;O=c[h+52>>2]|0;do{if((O|0)==1448293937){c[h+48>>2]=1347637264;U=1347637264}else if((O|0)==1146437965){N=c[o>>2]|0;do{if((N|0)==8){if((c[p>>2]|0)==0){c[h+48>>2]=65541;V=65541;G=73;break}P=c[p>>2]|0;if((P|0)==2){c[h+48>>2]=65543;V=65543;G=73;break}else if((P|0)==3){c[h+48>>2]=65542;V=65542;G=73;break}else{W=P;break}}else if((N|0)==16){if((c[p>>2]|0)!=0){G=68;break}c[h+48>>2]=65537;V=65537;G=73}else{G=68}}while(0);if((G|0)==68){W=c[p>>2]|0}else if((G|0)==73){u=u0a(V)|0;P=c[k>>2]|0;c[P+792>>2]=u;c[P+432>>2]=(ba(c[P+416>>2]|0,u)|0)/8|0;U=c[P+48>>2]|0;break}DDb(b,2297368,(T=i,i=i+16|0,c[T>>2]=W,c[T+8>>2]=N,T)|0);i=T;j=-1163346256;i=d;return j|0}else{P=c[n>>2]|0;if((P|0)==0){c[h+48>>2]=65563;U=65563;break}else if((P|0)==1){c[h+48>>2]=86072;U=86072;break}else if((P|0)==2){c[h+48>>2]=86071;U=86071;break}else{yDb(b,16,2280392,(T=i,i=i+8|0,c[T>>2]=P,T)|0);i=T;j=-1;i=d;return j|0}}}while(0);b=u0a(U)|0;U=c[k>>2]|0;c[U+792>>2]=b;h=c[U+416>>2]|0;c[U+72>>2]=ba(ba(c[U+412>>2]|0,h)|0,b)|0;c[U+432>>2]=ba(b,h)|0;j=0;i=d;return j|0}else if((g|0)==0){g=l+792|0;h=c[g>>2]|0;b=e+36|0;c[b>>2]=h;if((S&2048|0)!=0&h>>>0<9>>>0){c[e+40>>2]=h>>>0>6>>>0?6:4;c[g>>2]=24}if((S&128|0)==0){X=0}else{X=(c[b>>2]|0)>>>0<9>>>0|0}S=e+44|0;c[S>>2]=X;X=e+52|0;c[X>>2]=R;R=e+48|0;c[R>>2]=Q;Q=c[l+96>>2]|0;do{if((Q|0)==0){c[l+100>>2]=41;g=WDb(57)|0;c[(c[k>>2]|0)+96>>2]=g;g=c[k>>2]|0;h=c[g+96>>2]|0;if((h|0)==0){j=-12}else{Y=g;Z=h;break}i=d;return j|0}else{Y=l;Z=Q}}while(0);if((c[Y+100>>2]|0)<=40){yDb(0,0,2146064,(T=i,i=i+24|0,c[T>>2]=2265072,c[T+8>>2]=2029232,c[T+16>>2]=418,T)|0);i=T;Cd();return 0}T=Z;x=10496;a[T]=x;x=x>>8;a[T+1|0]=x;a[Z+2|0]=c[m>>2];a[Z+3|0]=c[b>>2];a[Z+4|0]=c[e+40>>2];a[Z+5|0]=c[S>>2];S=Z+6|0;x=de(c[R>>2]&65535|0)|0;a[S]=x;x=x>>8;a[S+1|0]=x;a[Z+8|0]=c[X>>2];UGb(Z+9|0,e+56|0,32)|0;c[(c[k>>2]|0)+48>>2]=137;j=0;i=d;return j|0}else{j=-1;i=d;return j|0}return 0}function VE(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=c[b+12>>2]|0;g=c[b+16>>2]|0;h=c[c[b+28>>2]>>2]|0;b=Ty(g,0,0,1)|0;j=F;k=f+8|0;l=c[k>>2]|0;m=c[k+4>>2]|0;if(!((j|0)<(m|0)|(j|0)==(m|0)&b>>>0<l>>>0)){n=-541478725;i=e;return n|0}k=c[h+8>>2]|0;h=c[k+8>>2]|0;do{if((h|0)==0){o=f+16|0;if((wZ(d,(c[o>>2]|0)+2|0)|0)<0){n=-12;i=e;return n|0}p=c[d+24>>2]|0;q=p;x=512;a[q]=x;x=x>>8;a[q+1|0]=x;q=mz(g,p+2|0,c[o>>2]|0)|0;if((q|0)<0){BZ(d);r=q;break}if(!(q>>>0<(c[o>>2]|0)>>>0)){r=q;break}yZ(d,q+2|0);r=q}else if((h|0)==1){if((c[k+52>>2]|0)==1146437965){q=ZGb(l,m,b,j)|0;o=F;p=c[k+432>>2]<<10;s=(p|0)<0|0?-1:0;r=TS(g,d,(o|0)>(s|0)|(o|0)==(s|0)&q>>>0>p>>>0?p:q)|0;break}else{r=TS(g,d,c[f+16>>2]|0)|0;break}}else{yDb(0,0,2146064,(q=i,i=i+24|0,c[q>>2]=2078864,c[q+8>>2]=2029232,c[q+16>>2]=470,q)|0);i=q;Cd();return 0}}while(0);g=f;if((b|0)==(c[g>>2]|0)&(j|0)==(c[g+4>>2]|0)){g=d+36|0;c[g>>2]=c[g>>2]|1}if((r|0)<0){n=r;i=e;return n|0}c[d+32>>2]=0;n=r;i=e;return n|0}function WE(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,678112,6)|0)==0;return(b?100:0)|0}function XE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;mz(c[a+16>>2]|0,d,9)|0;e=LT(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=e+8|0;h=c[g>>2]|0;c[h+48>>2]=86076;c[h+412>>2]=8e3;c[h+416>>2]=1;c[h+8>>2]=1;h=e+48|0;c[h>>2]=0;c[h+4>>2]=0;MT(e,64,1,8e3);if((PGb(d,678112,9)|0)==0){e=c[g>>2]|0;c[e+432>>2]=38;c[e+72>>2]=15200;f=0;i=b;return f|0}if((PGb(d,678048,9)|0)==0){d=c[g>>2]|0;c[d+432>>2]=50;c[d+72>>2]=13333;f=0;i=b;return f|0}else{yDb(a,16,1926640,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-1094995529;i=b;return f|0}return 0}function YE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+432|0;e=wZ(b,c[d>>2]|0)|0;if((e|0)<0){f=e;return f|0}c[b+32>>2]=0;e=a+16|0;a=Ty(c[e>>2]|0,0,0,1)|0;g=b+64|0;c[g>>2]=a;c[g+4>>2]=F;c[b+48>>2]=(c[d>>2]|0)==38?160:240;g=mz(c[e>>2]|0,c[b+24>>2]|0,c[d>>2]|0)|0;if((g|0)==(c[d>>2]|0)){f=0;return f|0}BZ(b);f=(g|0)<0?g:-5;return f|0}function ZE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+16>>2]|0;if((c[a+24>>2]|0)!=1){yDb(a,16,2029136,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}g=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[g+48>>2]|0)!=86076){yDb(a,16,1984224,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}h=c[g+432>>2]|0;if((h|0)==50){Ry(d,678048,9)}else if((h|0)==38){Ry(d,678112,9)}else{yDb(a,16,1953216,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}Sy(d);f=0;i=b;return f|0}function _E(a,b){a=a|0;b=b|0;Ry(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function $E(a){a=a|0;var b=0,d=0,e=0,f=0;b=cc(a|0,46)|0;if((b|0)==0){d=0;return d|0}a=b+1|0;b=913696;while(1){e=b|0;if((c[e>>2]|0)==0){d=0;f=6;break}if((yAb(a,c[b+4>>2]|0)|0)==0){break}else{b=b+8|0}}if((f|0)==6){return d|0}d=c[e>>2]|0;return d|0}function aF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=b|0;b=c[d>>2]|0;if((b|0)==0){e=0;return e|0}if(($E(b)|0)==0){e=0;return e|0}if((WS(c[d>>2]|0)|0)!=0){e=100;return e|0}b=c[d>>2]|0;f=Vb(b|0,37)|0;a:do{if((f|0)!=0){g=f;while(1){h=g+1|0;if((a[h]|0)==37){i=g+2|0}else{if((qd(h|0,2066240)|0)==0){i=h}else{e=100;break}}g=Vb(i|0,37)|0;if((g|0)==0){break a}}return e|0}}while(0);if((TC(b,2062144)|0)==0){b=(TC(c[d>>2]|0,2058584)|0)==0;return(b?50:5)|0}else{e=5;return e|0}return 0}function bF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=i;i=i+1024|0;e=d|0;f=c[b+12>>2]|0;g=b+20|0;c[g>>2]=c[g>>2]|1;g=LT(b,0)|0;if((g|0)==0){h=-12;i=d;return h|0}j=f+1060|0;k=c[j>>2]|0;do{if((k|0)==0){l=-1}else{m=_Eb(k)|0;if(!((m|0)==-1)){l=m;break}yDb(b,16,2107560,(n=i,i=i+8|0,c[n>>2]=c[j>>2],n)|0);i=n;h=-22;i=d;return h|0}}while(0);j=f+36|0;sAb(j,b+32|0,1024)|0;k=f+12|0;c[k>>2]=0;c[f+24>>2]=0;m=f+28|0;if((c[(c[b+4>>2]|0)+8>>2]&1|0)==0){c[m>>2]=1;c[g+236>>2]=1}else{c[m>>2]=0}o=f+1140|0;if((c[o>>2]|0)==0){MT(g,64,c[f+1076>>2]|0,c[f+1072>>2]|0)}else{MT(g,64,1,1)}p=c[f+1064>>2]|0;do{if((p|0)!=0){q=f+1068|0;if((c[q>>2]|0)==0){break}r=c[g+8>>2]|0;c[r+120>>2]=p;c[r+124>>2]=c[q>>2]}}while(0);do{if((c[m>>2]|0)==0){p=f+1084|0;q=c[p>>2]|0;a:do{if((q|0)==0){r=Vb(j|0,37)|0;b:do{if((r|0)==0){s=21}else{t=r;while(1){u=t+1|0;if((a[u]|0)==37){v=t+2|0}else{if((qd(u|0,2066240)|0)==0){v=u}else{break}}u=Vb(v|0,37)|0;if((u|0)==0){s=21;break b}else{t=u}}c[f+1088>>2]=1;yDb(b,24,2096176,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;t=eEb(j)|0;u=a[t]|0;c:do{if(u<<24>>24==0){w=j}else{x=j;y=t;z=j;A=u;while(1){if((z-x|0)>>>0>1021>>>0){w=z;break c}if(A<<24>>24==37){B=y+1|0;if((qd(B|0,2090776)|0)==0){s=27}else{C=z;D=B}}else{s=27}do{if((s|0)==27){s=0;if((qd(y|0,2085704)|0)==0){C=z;D=y;break}a[z]=92;C=z+1|0;D=y}}while(0);B=D+1|0;E=C+1|0;a[C]=a[D]|0;F=a[B]|0;if(F<<24>>24==0){w=E;break}else{y=B;z=E;A=F}}}}while(0);a[w]=0;ZDb(t);u=f+1092|0;if((Wd(j|0,16,0,u|0)|0)==0){A=(c[u>>2]|0)-1|0;u=c[p>>2]|0;if((u|0)==0){G=A;break}else{H=A;I=u;s=33;break a}}else{h=-2;i=d;return h|0}}}while(0);if((s|0)==21){c[f+1088>>2]=0;G=0}if((c[f+1088>>2]|0)==0){s=34}else{J=G;K=0}}else{H=0;I=q;s=33}}while(0);do{if((s|0)==33){if((I|0)==2){s=34;break}else if((I|0)==0){J=H;K=0;break}else if((I|0)!=1){yDb(b,16,2075296,(n=i,i=i+8|0,c[n>>2]=I,n)|0);i=n;h=-22;i=d;return h|0}q=f+1092|0;if((Wd(j|0,16,0,q|0)|0)==0){p=(c[q>>2]|0)-1|0;c[f+1088>>2]=1;J=p;K=0;break}else{h=-2;i=d;return h|0}}}while(0);d:do{if((s|0)==34){p=f+1128|0;q=c[p>>2]|0;r=f+1132|0;u=e|0;A=(c[r>>2]|0)+q|0;z=q;while(1){if((z|0)>=(A|0)){s=38;break}q=(XS(u,1024,j,z)|0)<0;L=Jy(u,1)|0;if(q){s=44;break}if((L|0)>0){s=38;break}else{z=z+1|0}}e:do{if((s|0)==38){if((z|0)==(A|0)){break}else{M=z}while(1){q=0;while(1){N=(q|0)!=0;y=N?q<<1:1;if((XS(u,1024,j,y+M|0)|0)<0){break e}if((Jy(u,1)|0)<1){break}if((y|0)>1073741823){break e}else{q=y}}if(N){M=q+M|0}else{J=M;K=z;break d}}}else if((s|0)==44){if((L|0)>=1){J=1;K=1;break d}}}while(0);z=c[p>>2]|0;u=z-1+(c[r>>2]|0)|0;yDb(b,16,2080616,(n=i,i=i+24|0,c[n>>2]=j,c[n+8>>2]=z,c[n+16>>2]=u,n)|0);i=n;h=-2;i=d;return h|0}}while(0);c[f+4>>2]=K;c[f+8>>2]=J;c[k>>2]=K;if((c[o>>2]|0)!=0){break}u=g+48|0;c[u>>2]=0;c[u+4>>2]=0;u=1-K+J|0;z=g+56|0;c[z>>2]=u;c[z+4>>2]=(u|0)<0|0?-1:0}}while(0);J=c[b+1112>>2]|0;do{if((J|0)==0){K=c[b+1116>>2]|0;if((K|0)!=0){o=c[g+8>>2]|0;c[o+8>>2]=1;c[o+48>>2]=K;O=o;break}o=cc(j|0,46)|0;if((o|0)==0){P=0}else{P=(yAb(o+1|0,2070784)|0)==0|0}c[f+32>>2]=P;o=g+8|0;c[(c[o>>2]|0)+8>>2]=0;K=$E(j)|0;k=c[o>>2]|0;o=k+48|0;c[o>>2]=K;if((K|0)!=10){O=k;break}c[o>>2]=8;O=k}else{k=c[g+8>>2]|0;c[k+8>>2]=0;c[k+48>>2]=J;O=k}}while(0);if((c[O+8>>2]|0)!=0|(l|0)==-1){h=0;i=d;return h|0}c[O+140>>2]=l;h=0;i=d;return h|0}function cF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;e=i;i=i+1152|0;f=e+1024|0;g=e+1040|0;h=e+1056|0;j=e+1072|0;k=c[b+12>>2]|0;l=e|0;TGb(f|0,0,12)|0;TGb(g|0,0,12)|0;TGb(h|0,0,12)|0;m=b+28|0;n=c[(c[c[m>>2]>>2]|0)+8>>2]|0;o=k+28|0;a:do{if((c[o>>2]|0)==0){p=k+12|0;q=c[p>>2]|0;r=c[k+8>>2]|0;if((c[k+1080>>2]|0)!=0&(q|0)>(r|0)){s=c[k+4>>2]|0;c[p>>2]=s;t=s}else{t=q}q=k+12|0;if((t|0)>(r|0)){u=-541478725;i=e;return u|0}do{if((c[k+1088>>2]|0)==0){if((XS(l,1024,k+36|0,t)|0)>=0){v=l;break}if((c[q>>2]|0)>1){u=-5}else{v=l;break}i=e;return u|0}else{v=c[(c[k+1096>>2]|0)+(t<<2)>>2]|0}}while(0);q=b+1160|0;r=k+32|0;s=h|0;if((Hz(s,v,1,q,0)|0)<0){yDb(b,16,2117776,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;u=-5;i=e;return u|0}p=Wy(c[s>>2]|0)|0;s=p;c[f>>2]=s;do{if((c[r>>2]|0)==0){w=0;x=0}else{a[v+((SGb(v|0)|0)-1)|0]=85;p=h+4|0;if((Hz(p,v,1,q,0)|0)<0){w=0;x=0;break}y=Wy(c[p>>2]|0)|0;p=y;c[f+4>>2]=p;if((c[r>>2]|0)==0){w=p;x=0;break}a[v+((SGb(v|0)|0)-1)|0]=86;y=h+8|0;if((Hz(y,v,1,q,0)|0)<0){w=p;x=0;break}z=Wy(c[y>>2]|0)|0;y=z;c[f+8>>2]=y;if((c[r>>2]|0)==0){w=p;x=y;break}a[v+((SGb(v|0)|0)-1)|0]=87;w=p;x=y}}while(0);if((c[n+48>>2]|0)!=14){A=v;B=s;C=w;D=x;break}r=n+120|0;if((c[r>>2]|0)!=0){A=v;B=s;C=w;D=x;break}q=n+124|0;y=0;while(1){if(!(y>>>0<9>>>0)){A=v;B=s;C=w;D=x;break a}E=c[435856+(y<<3)>>2]|0;G=c[435860+(y<<3)>>2]|0;if((ba(G,E)|0)==(s|0)){break}else{y=y+1|0}}c[r>>2]=E;c[q>>2]=G;A=v;B=s;C=w;D=x}else{y=c[b+16>>2]|0;c[h>>2]=y;if((Xy(y)|0)!=0){u=-5;i=e;return u|0}y=c[k+1136>>2]|0;p=f|0;if((y|0)>0){c[p>>2]=y;A=l;B=y;C=0;D=0;break}else{c[p>>2]=4096;A=l;B=4096;C=0;D=0;break}}}while(0);l=f|0;b=f+4|0;x=f+8|0;if((wZ(d,C+B+D|0)|0)<0){u=-12;i=e;return u|0}c[d+32>>2]=0;D=d+36|0;c[D>>2]=c[D>>2]|1;do{if((c[k+1140>>2]|0)==0){if((c[o>>2]|0)!=0){break}D=k+16|0;B=c[D+4>>2]|0;C=d+8|0;c[C>>2]=c[D>>2];c[C+4>>2]=B}else{if((Nb(A|0,j|0)|0)==0){B=c[j+56>>2]|0;C=B;D=(B|0)<0|0?-1:0;B=d+8|0;c[B>>2]=C;c[B+4>>2]=D;B=c[k+12>>2]|0;jT(c[c[m>>2]>>2]|0,B,(B|0)<0|0?-1:0,C,D,0,0,1)|0;break}else{u=-5;i=e;return u|0}}}while(0);m=d+28|0;c[m>>2]=0;j=d+24|0;A=h|0;D=c[A>>2]|0;do{if((D|0)!=0){C=mz(D,c[j>>2]|0,c[l>>2]|0)|0;c[g>>2]=C;if((c[o>>2]|0)==0){Iz(c[A>>2]|0)|0}if((C|0)<=0){break}c[m>>2]=(c[m>>2]|0)+C}}while(0);A=h+4|0;l=c[A>>2]|0;do{if((l|0)!=0){D=mz(l,(c[j>>2]|0)+(c[m>>2]|0)|0,c[b>>2]|0)|0;c[g+4>>2]=D;if((c[o>>2]|0)==0){Iz(c[A>>2]|0)|0}if((D|0)<=0){break}c[m>>2]=(c[m>>2]|0)+D}}while(0);A=h+8|0;h=c[A>>2]|0;do{if((h|0)!=0){b=mz(h,(c[j>>2]|0)+(c[m>>2]|0)|0,c[x>>2]|0)|0;c[g+8>>2]=b;if((c[o>>2]|0)==0){Iz(c[A>>2]|0)|0}if((b|0)<=0){break}c[m>>2]=(c[m>>2]|0)+b}}while(0);do{if((c[g>>2]|0)>=1){if((c[g+4>>2]|0)<0){break}if((c[g+8>>2]|0)<0){break}m=k+24|0;c[m>>2]=(c[m>>2]|0)+1;m=k+12|0;c[m>>2]=(c[m>>2]|0)+1;m=k+16|0;A=YGb(c[m>>2]|0,c[m+4>>2]|0,1,0)|0;c[m>>2]=A;c[m+4>>2]=F;u=0;i=e;return u|0}}while(0);BZ(d);u=-5;i=e;return u|0}function dF(a){a=a|0;var b=0;b=c[a+12>>2]|0;if((c[b+1088>>2]|0)==0){return 0}Bd(b+1092|0);return 0}function eF(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;b=c[a+12>>2]|0;g=c[c[a+28>>2]>>2]|0;if((c[b+1140>>2]|0)!=0){a=oT(g,d,e,f)|0;if((a|0)<0){h=-1;return h|0}c[b+12>>2]=c[(c[g+400>>2]|0)+(a*24|0)>>2];h=0;return h|0}a=0;if((e|0)<(a|0)|(e|0)==(a|0)&d>>>0<0>>>0){h=-1;return h|0}a=c[b+8>>2]|0;g=c[b+4>>2]|0;do{if((c[b+1080>>2]|0)==0){f=a-g|0;i=(f|0)<0|0?-1:0;if((i|0)<(e|0)|(i|0)==(e|0)&f>>>0<d>>>0){h=-1}else{break}return h|0}}while(0);f=a+1-g|0;a=fHb(d,e,f,(f|0)<0|0?-1:0)|0;f=YGb(a,F,g,0)|0;c[b+12>>2]=f;f=b+16|0;c[f>>2]=d;c[f+4>>2]=e;h=0;return h|0}function fF(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[b+12>>2]|0;f=(c[c[b+28>>2]>>2]|0)+8|0;g=bFb(c[(c[f>>2]|0)+140>>2]|0)|0;h=e+16|0;sAb(h,b+32|0,1024)|0;c[e+8>>2]=c[(c[b+8>>2]|0)+28>>2]&1^1;i=c[(c[f>>2]|0)+48>>2]|0;if((i|0)==98){c[e+1048>>2]=2297216;return 0}else if((i|0)==14){i=cc(h|0,46)|0;do{if((i|0)==0){j=0}else{if((yAb(i+1|0,2280216)|0)!=0){j=0;break}if((c[b+24>>2]|0)!=1|(g|0)==0){j=0;break}if((a[g+7|0]&16)==0){j=0;break}j=(d[g+4|0]|0)>>>0>2>>>0|0}}while(0);c[e+12>>2]=j;return 0}else{return 0}return 0}function gF(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+1136|0;h=g|0;j=g+16|0;k=g+1040|0;l=g+1048|0;m=g+1128|0;n=c[e+12>>2]|0;o=f+32|0;p=e+28|0;q=c[(c[(c[p>>2]|0)+(c[o>>2]<<2)>>2]|0)+8>>2]|0;r=bFb(c[q+140>>2]|0)|0;s=n+8|0;a:do{if((c[s>>2]|0)==0){do{if((c[n+1040>>2]|0)==0){if((c[n+1044>>2]|0)!=0){ee(k|0)|0;if((Ac(j|0,1024,n+16|0,ub(k|0)|0)|0)!=0){break}yDb(e,16,1983824,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-22;i=g;return u|0}v=n+16|0;w=n+4|0;if((XS(j|0,1024,v,c[w>>2]|0)|0)>=0){break}x=c[w>>2]|0;if((x|0)<=1){break}yDb(e,16,1952904,(t=i,i=i+16|0,c[t>>2]=x,c[t+8>>2]=v,t)|0);i=t;u=-22;i=g;return u|0}else{sAb(j|0,n+16|0,1024)|0}}while(0);v=j|0;x=e+1160|0;w=n+12|0;y=r+4|0;do{if((Hz(h|0,v,2,x,0)|0)>=0){if((c[w>>2]|0)==0){z=w;break a}if(!((d[y]|0)>>>0>1>>>0)){z=w;break a}a[j+((SGb(v|0)|0)-1)|0]=85;if((Hz(h+4|0,v,2,x,0)|0)<0){break}if((c[w>>2]|0)==0){z=w;break a}if(!((d[y]|0)>>>0>2>>>0)){z=w;break a}a[j+((SGb(v|0)|0)-1)|0]=86;if((Hz(h+8|0,v,2,x,0)|0)<0){break}if((c[w>>2]|0)==0){z=w;break a}if(!((d[y]|0)>>>0>3>>>0)){z=w;break a}a[j+((SGb(v|0)|0)-1)|0]=65;if((Hz(h+12|0,v,2,x,0)|0)<0){break}if((c[w>>2]|0)==0){z=w;break a}if(!((d[y]|0)>>>0>4>>>0)){z=w;break a}a[j+((SGb(v|0)|0)-1)|0]=120;z=w;break a}}while(0);yDb(e,16,1926464,(t=i,i=i+8|0,c[t>>2]=v,t)|0);i=t;u=-5;i=g;return u|0}else{c[h>>2]=c[e+16>>2];z=n+12|0}}while(0);b:do{if((c[z>>2]|0)==0){j=n+1048|0;if((c[j>>2]|0)==0){Ry(c[h>>2]|0,c[f+24>>2]|0,c[f+28>>2]|0);break}TGb(l|0,0,80)|0;c[m>>2]=0;if((c[z>>2]|0)!=0){yDb(0,0,1883968,(t=i,i=i+24|0,c[t>>2]=2341968,c[t+8>>2]=2319208,c[t+16>>2]=137,t)|0);i=t;Cd();return 0}k=EK(m,0,c[j>>2]|0,e+32|0)|0;if((k|0)<0){u=k;i=g;return u|0}k=LT(c[m>>2]|0,0)|0;if((k|0)==0){bT(c[m>>2]|0);u=-12;i=g;return u|0}c[k+4>>2]=c[o>>2];c[(c[m>>2]|0)+16>>2]=c[h>>2];j=EZ(l,f)|0;do{if((j|0)<0){A=j}else{w=CZ(l)|0;if((w|0)<0){A=w;break}w=BRa(c[k+8>>2]|0,c[(c[c[p>>2]>>2]|0)+8>>2]|0)|0;if((w|0)<0){A=w;break}w=FK(c[m>>2]|0,0)|0;if((w|0)<0){A=w;break}w=MK(c[m>>2]|0,l)|0;if((w|0)<0){A=w;break}w=NK(c[m>>2]|0)|0;if((w|0)<0){A=w;break}BZ(l);bT(c[m>>2]|0);break b}}while(0);BZ(l);bT(c[m>>2]|0);u=A;i=g;return u|0}else{k=c[q+120>>2]|0;j=c[q+124>>2]|0;v=ba(j,k)|0;w=ba(-j>>(d[r+6|0]|0),-k>>(d[r+5|0]|0))|0;if((b[r+8>>1]&16384)>>>0>14336>>>0){B=w<<1;C=v<<1}else{B=w;C=v}v=f+24|0;Ry(c[h>>2]|0,c[v>>2]|0,C);w=h+4|0;Ry(c[w>>2]|0,(c[v>>2]|0)+C|0,B);k=h+8|0;Ry(c[k>>2]|0,(c[v>>2]|0)+(B+C)|0,B);Iz(c[w>>2]|0)|0;Iz(c[k>>2]|0)|0;if(!((d[r+4|0]|0)>>>0>3>>>0)){break}k=h+12|0;Ry(c[k>>2]|0,(c[v>>2]|0)+((B<<1)+C)|0,C);Iz(c[k>>2]|0)|0}}while(0);C=h|0;Sy(c[C>>2]|0);if((c[s>>2]|0)==0){Iz(c[C>>2]|0)|0}C=n+4|0;c[C>>2]=(c[C>>2]|0)+1;u=0;i=g;return u|0}function hF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a+16|0;if((rz(c[e>>2]|0)|0)!=1196444237){f=-5;i=d;return f|0}g=rz(c[e>>2]|0)|0;h=pz(c[e>>2]|0)|0;j=pz(c[e>>2]|0)|0;Vy(c[e>>2]|0,8,0)|0;Vy(c[e>>2]|0,2,0)|0;k=pz(c[e>>2]|0)|0;l=pz(c[e>>2]|0)|0;Vy(c[e>>2]|0,22,0)|0;yDb(a,48,2077624,(a=i,i=i+40|0,c[a>>2]=g,c[a+8>>2]=h,c[a+16>>2]=j,c[a+24>>2]=k,c[a+32>>2]=l,a)|0);i=a;a=TS(c[e>>2]|0,b,g)|0;if((a|0)<0){f=a;i=d;return f|0}c[b+32>>2]=0;f=a;i=d;return f|0}function iF(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[b+4>>2]|0;e=d+((c[b+8>>2]|0)-22)|0;b=d;while(1){if((a[b]|0)==73){if((PGb(b,437560,22)|0)==0){f=100;g=5;break}}d=b+1|0;if(d>>>0<e>>>0){b=d}else{f=0;g=5;break}}if((g|0)==5){return f|0}return 0}function jF(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+112|0;f=e|0;g=e+80|0;h=e+88|0;j=c[b+12>>2]|0;k=j;l=c[b+16>>2]|0;m=h|0;mz(l,m,22)|0;n=h+1|0;o=h+21|0;while(1){if((PGb(m,437560,22)|0)==0){break}VGb(m|0,n|0,21)|0;a[o]=lz(l)|0;if((Xy(l)|0)!=0){p=-541478725;q=17;break}}if((q|0)==17){i=e;return p|0}c[j+1088>>2]=0;q=j+32|0;c[q>>2]=0;c[q+4>>2]=0;q=j+1136|0;c[q>>2]=0;c[q+4>>2]=0;q=j+1120|0;c[q>>2]=0;c[q+4>>2]=0;q=j+1104|0;c[q>>2]=0;c[q+4>>2]=0;q=Ty(l,0,0,1)|0;o=YGb(q,F,4,0)|0;q=j+1152|0;c[q>>2]=o;c[q+4>>2]=F;q=j+40|0;o=0;do{c[q+(o<<2)>>2]=-16777216;o=o+1|0;}while((o|0)<256);if((lF(k,l,f)|0)!=2){p=-1094995529;i=e;return p|0}if((mz(l,g|0,4)|0)!=4){p=-5;i=e;return p|0}o=g+2|0;g=(d[o]|d[o+1|0]<<8)<<16>>16;Ty(l,-4,-1,1)|0;do{if(g<<16>>16==3){c[j+1084>>2]=0}else{if((lF(k,l,f)|0)==0){break}else{p=-1094995529}i=e;return p|0}}while(0);f=LT(b,0)|0;if((f|0)==0){p=-12;i=e;return p|0}MT(f,63,1,1e6);c[j+1092>>2]=c[f>>2];l=c[f+8>>2]|0;c[l+8>>2]=0;c[l+48>>2]=40;c[l+52>>2]=0;c[l+120>>2]=c[j+20>>2];c[l+124>>2]=c[j+24>>2];c[l+792>>2]=c[j+16>>2];l=j+1084|0;if((c[l>>2]|0)==0){p=0;i=e;return p|0}f=LT(b,0)|0;if((f|0)==0){p=-12;i=e;return p|0}b=j+1080|0;MT(f,32,1,c[b>>2]|0);c[j+1096>>2]=c[f>>2];k=c[f+8>>2]|0;c[k+8>>2]=1;f=c[l>>2]|0;c[k+48>>2]=f;c[k+52>>2]=0;l=c[j+1076>>2]|0;c[k+416>>2]=l;g=(l|0)==1;o=k+448|0;c[o>>2]=g?4:3;c[o+4>>2]=g?0:0;g=c[b>>2]|0;c[k+412>>2]=g;b=c[j+1072>>2]|0;c[k+792>>2]=b;j=ba(ba(g,l)|0,b)|0;if((f|0)==81921){r=(j|0)/2|0}else{r=j}c[k+72>>2]=r;c[k+432>>2]=ba(b,l)|0;p=0;i=e;return p|0}function kF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;while(1){a=lF(d,e,b)|0;if((a|0)==65535){f=-1094995529;g=6;break}else if((a|0)==65533){g=3;break}else if((a|0)==3){g=4;break}else if((a|0)==65534){h=-5;break}if(!((a|0)==2|(a|0)==0)){f=-1;g=6;break}}if((g|0)==3){h=-12}else if((g|0)==4){h=0}else if((g|0)==6){h=f}return h|0}function lF(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;j=i;i=i+8|0;k=j|0;l=i;i=i+4|0;i=i+7&-8;m=l|0;n=i;i=i+1024|0;o=n|0;p=n;q=n;r=n;s=mF(f,g,h)|0;if((s|0)!=65532){t=s;i=j;return t|0}if((Xy(g)|0)!=0){t=65534;i=j;return t|0}if((mz(g,k,4)|0)!=4){t=65535;i=j;return t|0}s=b[k>>1]|0;u=b[k+2>>1]|0;k=(u&65535)>>>0<6>>>0?u&65535:65535;a:do{if(!(s<<16>>16==0|(k|0)==65535)){u=l;v=l+3|0;w=l+2|0;x=n;y=n+4|0;z=f+8|0;A=f+1080|0;B=p+2|0;C=f+1076|0;D=f+1072|0;E=f+1084|0;G=f+20|0;H=f+24|0;I=f+16|0;J=p+6|0;K=f+1068|0;L=f+1104|0;M=f+1112|0;N=f+1064|0;O=f+1136|0;P=f+1144|0;Q=f+1120|0;R=f+1128|0;S=s&65535;b:while(1){if((Xy(g)|0)!=0){T=65534;U=55;break}if((mz(g,u,4)|0)!=4){T=65535;U=55;break}V=b[m>>1]|0;W=V&65535;X=a[v]|0;S=S-4-W|0;if((S|0)<0){T=65535;U=55;break}c:do{switch(d[w]|0){case 5:{if((X&255)>>>0>2>>>0){U=36;break b}if((V-4&65535)>>>0>4>>>0){U=36;break b}if(X<<24>>24==2&(V&65535)>>>0<8>>>0){U=36;break b}if((mz(g,x,W)|0)!=(W|0)){U=36;break b}Y=e[q>>1]<<3;Z=e[B>>1]<<3;if((Y|0)!=(c[G>>2]|0)){c[G>>2]=Y;c[K>>2]=(c[K>>2]|0)+1}if((Z|0)!=(c[H>>2]|0)){c[H>>2]=Z;c[K>>2]=(c[K>>2]|0)+1}do{if(!((X&255)>>>0<2>>>0)){if((b[J>>1]|0)==0){break}c[I>>2]=16;break c}}while(0);c[I>>2]=8;break};case 0:{Vy(g,V&65535,0)|0;break};case 12:{if((V-4&65535)>>>0>768>>>0){U=36;break b}if((mz(g,x,W)|0)!=(W|0)){U=36;break b}Z=b[q>>1]|0;Y=Z&65535;_=Y-1+(e[B>>1]|0)|0;if((Z&65535)>>>0>255>>>0|(_|0)>255){U=36;break b}if((((_-Y|0)*3|0)+7|0)>(W|0)){U=36;break b}if((Y|0)<=(_|0)){Z=4;$=Y;while(1){Y=(a[r+(Z+1)|0]<<2&255)<<8|(a[r+Z|0]<<2&255)<<16|a[r+(Z+2)|0]<<2&255;c[f+40+($<<2)>>2]=Y|Y>>>6&197379|-16777216;Y=$+1|0;if((Y|0)>(_|0)){break}else{Z=Z+3|0;$=Y}}}c[N>>2]=1;break};case 10:{Vy(g,V&65535,0)|0;break};case 11:{Vy(g,V&65535,0)|0;break};case 17:{$=Ty(g,0,0,1)|0;c[Q>>2]=$;c[Q+4>>2]=F;c[R>>2]=W;Vy(g,V&65535,0)|0;break};case 15:{$=Ty(g,0,0,1)|0;c[O>>2]=$;c[O+4>>2]=F;c[P>>2]=W;Vy(g,V&65535,0)|0;break};case 6:case 14:case 16:case 18:case 19:case 20:case 21:{Vy(g,V&65535,0)|0;break};case 7:{Vy(g,V&65535,0)|0;break};case 13:{Vy(g,V&65535,0)|0;break};case 3:{if((X&255)>>>0>1>>>0){U=36;break b}if((V-6&65535)>>>0>4>>>0){U=36;break b}if((mz(g,x,W)|0)!=(W|0)){U=36;break b}c[A>>2]=e[y>>1]|0;$=e[B>>1]|0;c[C>>2]=($&1)+1;Z=($>>>1<<3&8)+8|0;c[D>>2]=Z;do{if(X<<24>>24==1){if(($&4|0)==0){break}c[E>>2]=81921;break c}}while(0);if((Z|0)==16){c[E>>2]=65536;break c}else{c[E>>2]=65541;break c}break};case 2:{if(!(X<<24>>24==0&V<<16>>16==6)){U=36;break b}if((mz(g,x,W)|0)!=(W|0)){U=36;break b}$=gHb(e[y>>1]|0,0,c[o>>2]|0,0)|0;c[z>>2]=$;c[z+4>>2]=F;break};case 4:{Vy(g,V&65535,0)|0;break};case 1:{Vy(g,V&65535,0)|0;break};case 8:{$=Ty(g,0,0,1)|0;c[L>>2]=$;c[L+4>>2]=F;c[M>>2]=W;Vy(g,V&65535,0)|0;break};case 9:{Vy(g,V&65535,0)|0;break};default:{U=36;break b}}}while(0);if((S|0)<1|(k|0)==65535){break a}}if((U|0)==36){S=Ty(g,0,0,1)|0;M=f+1152|0;c[M>>2]=S;c[M+4>>2]=F;t=65535;i=j;return t|0}else if((U|0)==55){M=Ty(g,0,0,1)|0;S=f+1152|0;c[S>>2]=M;c[S+4>>2]=F;t=T;i=j;return t|0}}}while(0);T=Ty(g,0,0,1)|0;U=f+1152|0;c[U>>2]=T;c[U+4>>2]=F;if(!((k|0)==3|(k|0)==1)){t=k;i=j;return t|0}t=mF(f,g,h)|0;i=j;return t|0}function mF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=a+1104|0;g=c[f>>2]|0;h=c[f+4>>2]|0;do{if(!((g|0)==0&(h|0)==0)){j=a+1076|0;if((c[j>>2]|0)==0){break}k=a+1072|0;if((c[k>>2]|0)==0){break}l=a+1084|0;m=c[l>>2]|0;if((m|0)==81921){n=h;o=g;p=a+1112|0}else if((m|0)==0){yDb(0,16,2144200,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;q=65535;i=e;return q|0}else{m=YGb(g,h,6,0)|0;r=F;c[f>>2]=m;c[f+4>>2]=r;s=a+1112|0;c[s>>2]=(c[s>>2]|0)-6;n=r;o=m;p=s}Ty(b,o,n,0)|0;c[f>>2]=0;c[f+4>>2]=0;s=c[p>>2]|0;if((s|0)!=(TS(b,d,s)|0)){q=65534;i=e;return q|0}c[d+32>>2]=c[a+1096>>2];s=a+1088|0;m=c[s>>2]|0;r=d+8|0;c[r>>2]=m;c[r+4>>2]=0;r=c[p>>2]|0;if((c[l>>2]|0)==81921){l=c[j>>2]|0;t=((r-6-l|0)>>>0)/(l>>>0)|0}else{t=(((r>>>0)/((c[j>>2]|0)>>>0)|0)>>>0)/((c[k>>2]|0)>>>3>>>0)|0}c[s>>2]=m+t;q=3;i=e;return q|0}}while(0);t=a+1136|0;if((c[t>>2]|0)==0&(c[t+4>>2]|0)==0){p=a+1152|0;Ty(b,c[p>>2]|0,c[p+4>>2]|0,0)|0;q=65532;i=e;return q|0}p=a+1144|0;f=a+1128|0;if((wZ(d,(c[f>>2]|0)+(c[p>>2]|0)|0)|0)!=0){q=65533;i=e;return q|0}n=a+1064|0;do{if((c[n>>2]|0)!=0){o=GZ(d,0,1024)|0;if((o|0)==0){break}UGb(o|0,a+40|0,1024)|0;c[n>>2]=0}}while(0);n=a+1068|0;if((c[n>>2]|0)!=0){fU(d,0,0,0,0,c[a+20>>2]|0,c[a+24>>2]|0)|0;c[n>>2]=0}n=c[t+4>>2]|0;o=d+64|0;c[o>>2]=c[t>>2];c[o+4>>2]=n;Ty(b,c[t>>2]|0,c[t+4>>2]|0,0)|0;c[t>>2]=0;c[t+4>>2]=0;t=d+24|0;n=mz(b,c[t>>2]|0,c[p>>2]|0)|0;if((n|0)!=(c[p>>2]|0)){BZ(d);q=65534;i=e;return q|0}n=a+1120|0;Ty(b,c[n>>2]|0,c[n+4>>2]|0,0)|0;c[n>>2]=0;c[n+4>>2]=0;n=mz(b,(c[t>>2]|0)+(c[p>>2]|0)|0,c[f>>2]|0)|0;if((n|0)==(c[f>>2]|0)){c[d+32>>2]=c[a+1092>>2];f=a+32|0;n=c[f+4>>2]|0;p=d+8|0;c[p>>2]=c[f>>2];c[p+4>>2]=n;n=a+8|0;a=YGb(c[f>>2]|0,c[f+4>>2]|0,c[n>>2]|0,c[n+4>>2]|0)|0;c[f>>2]=a;c[f+4>>2]=F;q=3;i=e;return q|0}else{BZ(d);q=65534;i=e;return q|0}return 0}function nF(b){b=b|0;var e=0,f=0,g=0;e=c[b+4>>2]|0;b=a[e]|0;do{if(b<<24>>24==100){if(!((a[e+1|0]|0)==-93)){break}if((a[e+3|0]|0)!=0){break}f=a[e+2|0]|0;if(f<<24>>24!=0&(f&255)>>>0<5>>>0){g=75}else{break}return g|0}}while(0);do{if((a[e+3|0]|0)==100){if(!((a[e+2|0]|0)==-93&b<<24>>24==0)){break}f=a[e+1|0]|0;if(!(f<<24>>24!=0&(f&255)>>>0<4>>>0)){break}f=e+4|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)==0){break}f=e+8|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)==0){break}else{g=75}return g|0}}while(0);g=0;return g|0}function oF(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,l=0,m=0,n=0,o=0;b=i;d=a+16|0;e=rz(c[d>>2]|0)|0;f=0;while(1){if((f|0)>=7){h=-1094995529;j=12;break}if((e|0)==(c[213104+(f<<3)>>2]|0)){break}else{f=f+1|0}}if((j|0)==12){i=b;return h|0}j=c[213108+(f<<3)>>2]|0;if((j|0)==1){f=rz(c[d>>2]|0)|0;e=rz(c[d>>2]|0)|0;l=1240488;m=rz(c[d>>2]|0)|0;n=e;o=f}else if((j|0)==0){j=vz(c[d>>2]|0)|0;f=vz(c[d>>2]|0)|0;l=1240560;m=vz(c[d>>2]|0)|0;n=f;o=j}else{h=-1094995529;i=b;return h|0}j=~~(c[k>>2]=o,+g[k>>2]);if((n|0)==0|(j|0)==0){h=-1094995529;i=b;return h|0}o=LT(a,0)|0;if((o|0)==0){h=-12;i=b;return h|0}f=o+8|0;e=c[f>>2]|0;c[e+8>>2]=1;c[e+416>>2]=n;c[e+412>>2]=j;j=vT(l,m)|0;c[(c[f>>2]|0)+48>>2]=j;if((j|0)==0){yDb(a,16,2077544,(a=i,i=i+8|0,c[a>>2]=m,a)|0);i=a;h=-1094995529;i=b;return h|0}else{a=u0a(j)|0;j=c[f>>2]|0;c[j+792>>2]=a;c[j+432>>2]=(ba(c[j+416>>2]|0,a)|0)/8|0;MT(o,64,1,c[j+412>>2]|0);Vy(c[d>>2]|0,1008,0)|0;h=0;i=b;return h|0}return 0}function pF(a){a=a|0;var b=0,d=0,e=0,f=0,h=0;b=i;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[a+24>>2]|0)!=1){yDb(a,16,2077448,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}h=uT(1240488,c[d+48>>2]|0)|0;if((h|0)==0){yDb(a,16,2028152,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}else{e=a+16|0;Yy(c[e>>2]|0,107364);Yy(c[e>>2]|0,(g[k>>2]=+(c[d+412>>2]|0),c[k>>2]|0));Yy(c[e>>2]|0,c[d+416>>2]|0);Yy(c[e>>2]|0,h);Qy(c[e>>2]|0,0,1008);f=0;i=b;return f|0}return 0}function qF(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=a[b]|0;e=(c|0)==0;a:do{if(d<<24>>24!=0&e){c=0;while(1){if(!(c>>>0<139>>>0)){break a}if((QGb(b,672128+(c<<2)|0)|0)==0){f=c;break}else{c=c+1|0}}return f|0}}while(0);if(e){f=-1;return f|0}e=d<<24>>24==0?1964640:b;b=(a[e]|0)-96&255;if((b&255)>>>0>31>>>0){f=-1;return f|0}d=(a[e+1|0]|0)-96&255;if((d&255)>>>0>31>>>0){f=-1;return f|0}c=(a[e+2|0]|0)-96&255;if((c&255)>>>0>31>>>0){f=-1;return f|0}f=c&255|(d&255|(b&255)<<5)<<5;return f|0}function rF(b,c){b=b|0;c=c|0;var e=0,f=0;e=c;x=0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;if(b>>>0>1023>>>0&(b|0)!=32767){a[c+2|0]=b&31|96;a[c+1|0]=b>>>5&31|96;a[c]=b>>>10&31|96;f=1;return f|0}if(b>>>0>138>>>0){f=0;return f|0}c=672128+(b<<2)|0;if((a[c|0]|0)==0){f=0;return f|0}b=c;x=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;f=1;return f|0}function sF(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=0;c=4;while(1){if((c|0)==0){d=b;e=4;break}f=lz(a)|0;g=f&127|b<<7;if((f&128|0)==0){d=g;e=4;break}else{b=g;c=c-1|0}}if((e|0)==4){return d|0}return 0}function tF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;c[d>>2]=lz(b)|0;d=0;a=4;while(1){if((a|0)==0){e=d;f=4;break}g=lz(b)|0;h=g&127|d<<7;if((g&128|0)==0){e=h;f=4;break}else{d=h;a=a-1|0}}if((f|0)==4){return e|0}return 0}function uF(a,b){a=a|0;b=b|0;var d=0;d=tz(a)|0;if((b|0)!=0){c[b>>2]=d}d=lz(a)|0;if((d&128|0)!=0){tz(a)|0}if((d&64|0)!=0){b=lz(a)|0;Vy(a,b,(b|0)<0|0?-1:0)|0;}if((d&32|0)==0){return}tz(a)|0;return}function vF(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+48|0;g=f|0;h=lz(d)|0;lz(d)|0;uz(d)|0;vz(d)|0;vz(d)|0;j=b+8|0;if((o0a(c[j>>2]|0)|0)!=0){yDb(a,48,2241744,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-1;i=f;return k|0}a=vT(1181928,h)|0;c[(c[j>>2]|0)+48>>2]=a;a=lz(d)|0;h=0;b=4;while(1){if((b|0)==0){l=h;break}m=lz(d)|0;n=m&127|h<<7;if((m&128|0)==0){l=n;break}else{h=n;b=b-1|0}}if((a|0)!=5){k=0;i=f;return k|0}if((l|0)==0|l>>>0>1073741824>>>0){k=-1;i=f;return k|0}ZDb(c[(c[j>>2]|0)+96>>2]|0);a=CT(c[j>>2]|0,d,l)|0;if((a|0)<0){k=a;i=f;return k|0}a=c[j>>2]|0;if((c[a+48>>2]|0)!=86018){k=0;i=f;return k|0}TGb(g|0,0,44)|0;QMa(g,c[a+96>>2]|0,c[a+100>>2]<<3,1)|0;a=c[j>>2]|0;c[a+416>>2]=c[g+36>>2];l=g|0;do{if((c[l>>2]|0)==29){d=c[g+4>>2]|0;if((d|0)>=3){o=13;break}c[a+412>>2]=e[1743632+(d<<1)>>1]|0}else{o=13}}while(0);do{if((o|0)==13){d=c[g+28>>2]|0;if((d|0)==0){c[a+412>>2]=c[g+8>>2];break}else{c[a+412>>2]=d;break}}}while(0);a=vT(670968,c[l>>2]|0)|0;l=(c[j>>2]|0)+48|0;c[l>>2]=a;if((a|0)!=0){k=0;i=f;return k|0}c[l>>2]=86018;k=0;i=f;return k|0}function wF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=673392;while(1){f=e|0;g=c[f>>2]|0;h=c[f+4>>2]|0;if((g|0)==0&(h|0)==0){break}if((g|0)==(b|0)&(h|0)==(d|0)){i=4;break}else{e=e+16|0}}do{if((i|0)==4){d=c[e+8>>2]|0;if((d|0)==0){break}Zy(a,d);Zy(a,0);Zy(a,0);return}}while(0);Zy(a,65536);Zy(a,b);Zy(a,0);return}function xF(a){a=a|0;var b=0;b=(RGb(c[a+4>>2]|0,1926160,15)|0)==0;return(b?100:0)|0}function yF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;d=i;i=i+40|0;e=d|0;f=d+24|0;g=d+32|0;h=c[b+12>>2]|0;j=c[b+16>>2]|0;k=e|0;l=0;while(1){m=(lz(j)|0)&255;n=m<<24>>24!=0;if(m<<24>>24==32|n^1){o=n;p=l;break}q=l+1|0;a[e+l|0]=m;if((q|0)<19){l=q}else{r=3;break}}if((r|0)==3){while(1){r=0;l=(lz(j)|0)&255;m=l<<24>>24!=0;if(l<<24>>24==32|m^1){o=m;p=q;break}else{r=3}}}if(!o){lz(j)|0}a[e+p|0]=0;p=0;while(1){o=(lz(j)|0)&255;q=o<<24>>24!=0;if(o<<24>>24==32|q^1){s=q;t=p;break}u=p+1|0;a[e+p|0]=o;if((u|0)<19){p=u}else{r=9;break}}if((r|0)==9){while(1){r=0;p=(lz(j)|0)&255;o=p<<24>>24!=0;if(p<<24>>24==32|o^1){s=o;t=u;break}else{r=9}}}if(!s){lz(j)|0}a[e+t|0]=0;t=h;s=xd(k|0,2143744,(u=i,i=i+8|0,c[u>>2]=h,u)|0)|0;i=u;if((s|0)==1){v=0}else{yDb(b,16,2077352,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;w=-1094995529;i=d;return w|0}while(1){s=(lz(j)|0)&255;o=s<<24>>24!=0;if(s<<24>>24==32|o^1){x=o;y=v;break}z=v+1|0;a[e+v|0]=s;if((z|0)<19){v=z}else{r=16;break}}if((r|0)==16){while(1){r=0;v=(lz(j)|0)&255;s=v<<24>>24!=0;if(v<<24>>24==32|s^1){x=s;y=z;break}else{r=16}}}if(!x){lz(j)|0}a[e+y|0]=0;y=0;while(1){x=(lz(j)|0)&255;z=x<<24>>24!=0;if(x<<24>>24==32|z^1){A=z;B=y;break}C=y+1|0;a[e+y|0]=x;if((C|0)<19){y=C}else{r=22;break}}if((r|0)==22){while(1){r=0;y=(lz(j)|0)&255;x=y<<24>>24!=0;if(y<<24>>24==32|x^1){A=x;B=C;break}else{r=22}}}if(!A){lz(j)|0}a[e+B|0]=0;B=0;while(1){A=(lz(j)|0)&255;C=A<<24>>24!=0;if(A<<24>>24==32|C^1){D=C;E=B;break}F=B+1|0;a[e+B|0]=A;if((F|0)<19){B=F}else{r=28;break}}if((r|0)==28){while(1){r=0;B=(lz(j)|0)&255;A=B<<24>>24!=0;if(B<<24>>24==32|A^1){D=A;E=F;break}else{r=28}}}if(!D){lz(j)|0}a[e+E|0]=0;E=xd(k|0,2143744,(u=i,i=i+8|0,c[u>>2]=f,u)|0)|0;i=u;if((E|0)==1){G=0}else{yDb(b,16,2028096,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;w=-1094995529;i=d;return w|0}while(1){E=(lz(j)|0)&255;D=E<<24>>24!=0;if(E<<24>>24==32|D^1){H=D;I=G;break}J=G+1|0;a[e+G|0]=E;if((J|0)<19){G=J}else{r=35;break}}if((r|0)==35){while(1){r=0;G=(lz(j)|0)&255;E=G<<24>>24!=0;if(G<<24>>24==32|E^1){H=E;I=J;break}else{r=35}}}if(!H){lz(j)|0}a[e+I|0]=0;I=0;while(1){H=(lz(j)|0)&255;J=H<<24>>24!=0;if(H<<24>>24==32|J^1){K=J;L=I;break}M=I+1|0;a[e+I|0]=H;if((M|0)<19){I=M}else{r=41;break}}if((r|0)==41){while(1){r=0;I=(lz(j)|0)&255;H=I<<24>>24!=0;if(I<<24>>24==32|H^1){K=H;L=M;break}else{r=41}}}if(!K){lz(j)|0}a[e+L|0]=0;L=xd(k|0,2143744,(u=i,i=i+8|0,c[u>>2]=g,u)|0)|0;i=u;if((L|0)==1){N=0}else{yDb(b,16,1983528,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;w=-1094995529;i=d;return w|0}while(1){L=(lz(j)|0)&255;k=L<<24>>24!=0;if(L<<24>>24==32|k^1){O=k;P=N;break}Q=N+1|0;a[e+N|0]=L;if((Q|0)<19){N=Q}else{r=48;break}}if((r|0)==48){while(1){r=0;N=(lz(j)|0)&255;L=N<<24>>24!=0;if(N<<24>>24==32|L^1){O=L;P=Q;break}else{r=48}}}if(!O){lz(j)|0}a[e+P|0]=0;P=0;while(1){O=(lz(j)|0)&255;Q=O<<24>>24!=0;if(O<<24>>24==32|Q^1){R=Q;S=P;break}T=P+1|0;a[e+P|0]=O;if((T|0)<19){P=T}else{r=54;break}}if((r|0)==54){while(1){r=0;P=(lz(j)|0)&255;O=P<<24>>24!=0;if(P<<24>>24==32|O^1){R=O;S=T;break}else{r=54}}}if(!R){lz(j)|0}a[e+S|0]=0;S=0;while(1){R=(lz(j)|0)&255;T=R<<24>>24!=0;if(R<<24>>24==32|T^1){U=T;V=S;break}W=S+1|0;a[e+S|0]=R;if((W|0)<19){S=W}else{r=60;break}}if((r|0)==60){while(1){r=0;S=(lz(j)|0)&255;R=S<<24>>24!=0;if(S<<24>>24==32|R^1){U=R;V=W;break}else{r=60}}}if(!U){lz(j)|0}a[e+V|0]=0;V=c[t>>2]|0;if((V|0)<1){yDb(b,16,1952584,(u=i,i=i+8|0,c[u>>2]=V,u)|0);i=u;w=-1094995529;i=d;return w|0}u=Ty(j,0,0,1)|0;c[h+4>>2]=u;u=LT(b,0)|0;if((u|0)==0){w=-12;i=d;return w|0}b=c[u+8>>2]|0;c[b+8>>2]=1;c[b+48>>2]=69659;h=b+416|0;if((c[f>>2]|0)==0){c[h>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;X=1}else{c[h>>2]=2;h=b+448|0;c[h>>2]=3;c[h+4>>2]=0;X=2}h=b+412|0;c[h>>2]=44100;f=c[g>>2]|0;if((f|0)>0){g=44100/(f|0)|0;c[h>>2]=g;Y=g}else{Y=44100}c[b+792>>2]=4;c[b+72>>2]=(ba(Y,X)|0)<<2;c[b+432>>2]=c[t>>2];MT(u,32,1,Y);w=0;i=d;return w|0}function zF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=a+16|0;f=d;g=TS(c[e>>2]|0,b,c[f>>2]|0)|0;if((g|0)!=(c[f>>2]|0)){h=-5;return h|0}c[b+32>>2]=0;f=Ty(c[e>>2]|0,0,0,1)|0;e=c[d+4>>2]|0;d=ZGb(f,F,e,(e|0)<0|0?-1:0)|0;e=F;f=b+8|0;c[f>>2]=d;c[f+4>>2]=e;b=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+416>>2]|0;if((b|0)<=0){h=0;return h|0}a=b<<1;b=eHb(d,e,a,(a|0)<0|0?-1:0)|0;c[f>>2]=b;c[f+4>>2]=F;h=0;return h|0}function AF(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==1){if((a[d+1|0]|0)!=1){break}if((a[d+2|0]|0)!=3){break}if(!((a[d+3|0]|0)==-72)){break}if(!((a[d+4|0]|0)==-128)){break}if((a[d+5|0]|0)==96){e=98}else{break}return e|0}}while(0);e=0;return e|0}function BF(a){a=a|0;var b=0,d=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=13;c[b+236>>2]=1;MT(b,64,1,9e4);d=0;return d|0}function CF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=a+16|0;f=b+8|0;g=b+64|0;h=0;j=0;a:while(1){if((h|0)!=0){break}while(1){k=tz(c[e>>2]|0)|0;l=tz(c[e>>2]|0)|0;m=tz(c[e>>2]|0)|0;tz(c[e>>2]|0)|0;n=vz(c[e>>2]|0)|0;vz(c[e>>2]|0)|0;o=l-12|0;if((o|0)<1){p=-1;q=14;break a}r=m&128;if((k|0)!=258){break}Vy(c[e>>2]|0,o,(o|0)<0|0?-1:0)|0;}k=c[e>>2]|0;if((j|0)==0){m=TS(k,b,o)|0;if((m|0)<0){p=m;q=14;break}c[f>>2]=n;c[f+4>>2]=(n|0)<0|0?-1:0;l=YGb(c[g>>2]|0,c[g+4>>2]|0,-16,-1)|0;c[g>>2]=l;c[g+4>>2]=F;s=1;t=m}else{u=VS(k,b,o)|0;if((u|0)<0){q=10;break}else{s=j;t=u}}if((t|0)<(o|0)){q=12;break}else{h=r;j=s}}if((q|0)==10){yDb(a,16,2143440,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;BZ(b);p=u;i=d;return p|0}else if((q|0)==12){yDb(a,16,2077160,(v=i,i=i+16|0,c[v>>2]=t,c[v+8>>2]=o,v)|0);i=v;v=b+36|0;c[v>>2]=c[v>>2]|2}else if((q|0)==14){i=d;return p|0}c[b+32>>2]=0;p=0;i=d;return p|0}function DF(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1179208516){e=b+4|0;if(!((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0)){break}e=b+6|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==32){f=98}else{break}return f|0}}while(0);f=0;return f|0}function EF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a+16|0;rz(c[d>>2]|0)|0;pz(c[d>>2]|0)|0;pz(c[d>>2]|0)|0;e=LT(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=e+8|0;c[(c[g>>2]|0)+8>>2]=0;h=rz(c[d>>2]|0)|0;c[(c[g>>2]|0)+52>>2]=h;j=vT(1240808,h)|0;c[(c[g>>2]|0)+48>>2]=j;j=pz(c[d>>2]|0)|0;c[(c[g>>2]|0)+120>>2]=j;j=pz(c[d>>2]|0)|0;c[(c[g>>2]|0)+124>>2]=j;j=rz(c[d>>2]|0)|0;g=rz(c[d>>2]|0)|0;h=sz(c[d>>2]|0)|0;d=e+56|0;c[d>>2]=h;c[d+4>>2]=F;c[e+236>>2]=2;if((j|0)==0|(g|0)==0){yDb(a,16,2143152,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-1094995529;i=b;return f|0}else{MT(e,64,g,j);f=0;i=b;return f|0}return 0}function FF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+16|0;a=rz(c[d>>2]|0)|0;e=sz(c[d>>2]|0)|0;f=F;g=TS(c[d>>2]|0,b,a)|0;c[b+32>>2]=0;a=b+8|0;c[a>>2]=e;c[a+4>>2]=f;f=b+64|0;b=YGb(c[f>>2]|0,c[f+4>>2]|0,-12,-1)|0;c[f>>2]=b;c[f+4>>2]=F;return g|0}function GF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+16>>2]|0;if((c[a+24>>2]|0)!=1){yDb(a,16,2143016,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}g=a+28|0;h=c[(c[c[g>>2]>>2]|0)+8>>2]|0;do{if((c[h+8>>2]|0)==0){if((c[h+48>>2]|0)!=141){break}Ry(d,2027584,4);az(d,0);az(d,32);j=c[h+52>>2]|0;Yy(d,(j|0)==0?808996950:j);az(d,c[h+120>>2]|0);az(d,c[h+124>>2]|0);Yy(d,c[(c[c[g>>2]>>2]|0)+44>>2]|0);Yy(d,c[(c[c[g>>2]>>2]|0)+40>>2]|0);j=(c[c[g>>2]>>2]|0)+56|0;dz(d,c[j>>2]|0,c[j+4>>2]|0);f=0;i=b;return f|0}}while(0);yDb(a,16,2076720,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}function HF(a,b){a=a|0;b=b|0;var d=0,e=0;d=c[a+16>>2]|0;a=b+28|0;Yy(d,c[a>>2]|0);e=b+8|0;dz(d,c[e>>2]|0,c[e+4>>2]|0);Ry(d,c[b+24>>2]|0,c[a>>2]|0);return 0}function IF(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=c[b+4>>2]|0;k=j+(c[b+8>>2]|0)|0;b=((d[j+1|0]|0)<<8|(d[j]|0)<<16|(d[j+2|0]|0)|0)==15711167?j+3|0:j;if(b>>>0<k>>>0){l=b}else{m=0;i=e;return m|0}while(1){b=a[l]|0;if(b<<24>>24==32|(b-9&255)>>>0<5>>>0){l=l+1|0;continue}if(!(b<<24>>24==35)){break}b=hc(l|0,2196840)|0;j=a[l+b|0]|0;if(j<<24>>24==13){n=b+1|0;o=n;p=a[l+n|0]|0}else{o=b;p=j}j=l+((p<<24>>24==10)+o)|0;if(j>>>0<k>>>0){l=j}else{m=0;q=11;break}}if((q|0)==11){i=e;return m|0}q=xd(l|0,2213888,(k=i,i=i+8|0,c[k>>2]=f,k)|0)|0;i=k;if((q|0)==1){m=51;i=e;return m|0}q=xd(l|0,2204408,(k=i,i=i+24|0,c[k>>2]=g,c[k+8>>2]=h,c[k+16>>2]=f,k)|0)|0;i=k;if((q|0)!=3){m=0;i=e;return m|0}m=(c[g>>2]|0)<(c[h>>2]|0)?51:0;i=e;return m|0}function JF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;d=i;i=i+1680|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+72|0;p=d+80|0;q=d+88|0;r=d+96|0;s=d+104|0;t=d+112|0;u=d+120|0;v=d+128|0;w=d+136|0;x=d+144|0;y=d+1168|0;z=c[b+16>>2]|0;A=c[b+12>>2]|0;B=LT(b,0)|0;if((B|0)==0){C=-12;i=d;return C|0}MT(B,64,1,100);b=B+8|0;B=c[b>>2]|0;c[B+8>>2]=3;c[B+48>>2]=1246975298;B=A+4|0;c[B>>2]=30;IAb(x,1040,4096);a:do{if((Xy(z)|0)==0){D=y|0;E=A;G=A+8|0;H=0;I=0;b:while(1){J=Ty(z,0,0,1)|0;K=F;L=wz(z,D,512)|0;M=D;while(1){N=a[M]|0;O=M+1|0;if(N<<24>>24==32|(N-9&255)>>>0<5>>>0){M=O}else{break}}c:do{if((H|0)==0){N=xd(M|0,2213888,(P=i,i=i+8|0,c[P>>2]=j,P)|0)|0;i=P;if((N|0)==1){Q=10;break}N=xd(M|0,2204408,(P=i,i=i+24|0,c[P>>2]=k,c[P+8>>2]=l,c[P+16>>2]=j,P)|0)|0;i=P;if((N|0)==3){if((c[k>>2]|0)<(c[l>>2]|0)){Q=10;break}}if((a[M]|0)!=35){R=I;S=0;break}N=a[O]|0;T=(N-97|0)>>>0<26>>>0?N^32:N;N=0;while(1){if(!(N>>>0<10>>>0)){R=I;S=0;break c}U=c[1484448+(N<<2)>>2]|0;if((T|0)==(a[U]|0)){break}else{N=N+1|0}}if((N|0)==-1){R=I;S=0;break}T=SGb(U|0)|0;if((zAb(O,U,T)|0)==0){V=M+(T+1)|0}else{V=M+2|0}while(1){T=a[V]|0;if(T<<24>>24==32|(T-9&255)>>>0<5>>>0){V=V+1|0}else{break}}N=a[U]|0;if((N|0)==84){T=kb(V|0,0,10)|0;c[B>>2]=T;if((T|0)==0){c[B>>2]=30;R=I;S=0;break}else{KAb(x,2027528,(P=i,i=i+8|0,c[P>>2]=V,P)|0);i=P;R=I;S=0;break}}else if((N|0)!=83){R=I;S=0;break}if((I|0)==0){N=c[B>>2]|0;c[e>>2]=0;c[f>>2]=0;c[g>>2]=0;c[h>>2]=0;T=xd(V|0,1926056,(P=i,i=i+32|0,c[P>>2]=e,c[P+8>>2]=f,c[P+16>>2]=g,c[P+24>>2]=h,P)|0)|0;i=P;W=c[e>>2]|0;if((a[V]|0)==45|(W|0)<0){X=(W|0)>-1?W:-W|0;c[e>>2]=X;Y=-1;Z=X}else{Y=1;Z=W}if((T|0)==3){W=ba((c[f>>2]|0)+(Z*60|0)|0,N)|0;_=ba(W+(c[g>>2]|0)|0,Y)|0}else if((T|0)==2){W=ba(Z,N)|0;_=ba((c[f>>2]|0)+W|0,Y)|0}else if((T|0)==4){T=ba(((c[f>>2]|0)*60|0)+(Z*3600|0)+(c[g>>2]|0)|0,N)|0;_=ba(T+(c[h>>2]|0)|0,Y)|0}else{_=0}c[E>>2]=_;$=1}else{$=I}KAb(x,2076648,(P=i,i=i+8|0,c[P>>2]=V,P)|0);i=P;R=$;S=0}else{Q=10}}while(0);do{if((Q|0)==10){Q=0;M=uR(G,D,L,H)|0;if((M|0)==0){C=-12;break b}T=M+64|0;c[T>>2]=J;c[T+4>>2]=K;if((L|0)<=1){R=I;S=0;break}R=I;S=(QGb(y+(L-2)|0,2142936)|0)==0|0}}while(0);if((Xy(z)|0)==0){H=S;I=R}else{break a}}i=d;return C|0}}while(0);R=e1a(c[b>>2]|0,x)|0;if((R|0)<0){C=R;i=d;return C|0}R=A+8|0;x=A+12|0;if((c[x>>2]|0)>0){b=R;S=A;A=0;do{z=c[b>>2]|0;y=c[z+(A*80|0)+24>>2]|0;$=z+(A*80|0)+8|0;V=z+(A*80|0)+48|0;z=xd(y|0,1983240,(P=i,i=i+72|0,c[P>>2]=n,c[P+8>>2]=o,c[P+16>>2]=p,c[P+24>>2]=q,c[P+32>>2]=r,c[P+40>>2]=s,c[P+48>>2]=t,c[P+56>>2]=u,c[P+64>>2]=m,P)|0)|0;i=P;do{if((z|0)==8){_=c[B>>2]|0;Y=ba(((c[o>>2]|0)*60|0)+((c[n>>2]|0)*3600|0)+(c[p>>2]|0)|0,_)|0;h=Y+(c[q>>2]|0)|0;c[v>>2]=h;Y=ba(((c[s>>2]|0)*60|0)+((c[r>>2]|0)*3600|0)+(c[t>>2]|0)|0,_)|0;g=Y+(c[u>>2]|0)|0;c[w>>2]=g;aa=h;ca=_;da=g;Q=43}else{g=xd(y|0,1952416,(P=i,i=i+24|0,c[P>>2]=v,c[P+8>>2]=w,c[P+16>>2]=m,P)|0)|0;i=P;if((g|0)!=2){break}aa=c[v>>2]|0;ca=c[B>>2]|0;da=c[w>>2]|0;Q=43}}while(0);if((Q|0)==43){Q=0;y=c[S>>2]|0;z=(((y+aa|0)*100|0)>>>0)/(ca>>>0)|0;c[v>>2]=z;g=(((y+da|0)*100|0)>>>0)/(ca>>>0)|0;c[w>>2]=g;c[$>>2]=z;c[$+4>>2]=(z|0)<0|0?-1:0;c[V>>2]=g+z}A=A+1|0;}while((A|0)<(c[x>>2]|0))}vR(R);C=0;i=d;return C|0}function KF(a,b){a=a|0;b=b|0;return yR((c[a+12>>2]|0)+8|0,b)|0}function LF(a){a=a|0;AR((c[a+12>>2]|0)+8|0);return 0}function MF(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR((c[a+12>>2]|0)+8|0,a,b,d,e,f,g,h,i,j)|0}function NF(a){a=a|0;var b=0,d=0,e=0;b=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;d=c[b+100>>2]|0;if((d|0)==0){return 0}e=a+16|0;Ry(c[e>>2]|0,c[b+96>>2]|0,d-1|0);Sy(c[e>>2]|0);return 0}function OF(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==74){if((a[d+1|0]|0)!=86){break}if(!(((c[b+8>>2]|0)-4|0)>>>0>74>>>0)){break}if((PGb(d+4|0,2076344,75)|0)==0){e=100}else{break}return e|0}}while(0);e=0;return e|0}function PF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;b=i;d=a+12|0;e=c[d>>2]|0;f=c[a+16>>2]|0;Vy(f,80,0)|0;g=LT(a,0)|0;h=LT(a,0)|0;if((g|0)==0|(h|0)==0){j=-12;i=b;return j|0}k=h+8|0;l=c[k>>2]|0;c[l+8>>2]=0;c[l+48>>2]=150;c[l+52>>2]=0;l=pz(f)|0;c[(c[k>>2]|0)+120>>2]=l;l=pz(f)|0;c[(c[k>>2]|0)+124>>2]=l;l=pz(f)|0;k=g+404|0;c[k>>2]=l;m=l;n=(l|0)<0|0?-1:0;l=h+64|0;c[l>>2]=m;c[l+4>>2]=n;l=h+56|0;c[l>>2]=m;c[l+4>>2]=n;MT(h,64,pz(f)|0,1e3);Vy(f,4,0)|0;h=g+8|0;n=c[h>>2]|0;c[n+8>>2]=1;c[n+48>>2]=65541;c[n+52>>2]=0;n=pz(f)|0;l=c[h>>2]|0;c[l+412>>2]=n;c[l+416>>2]=1;h=l+448|0;c[h>>2]=4;c[h+4>>2]=0;MT(g,64,1,n);Vy(f,10,0)|0;n=WDb((c[k>>2]|0)*24|0)|0;h=g+400|0;c[h>>2]=n;if((n|0)==0){j=-12;i=b;return j|0}n=WDb(c[k>>2]<<4)|0;g=n;l=e;c[l>>2]=g;if((n|0)==0){j=-12;i=b;return j|0}n=c[k>>2]|0;a:do{if((n|0)>0){m=(n<<4)+104|0;o=a+1156|0;p=a;q=(m|0)<0|0?-1:0;r=m;m=0;s=0;t=0;u=g;while(1){v=c[h>>2]|0;w=(rz(f)|0)<<2;x=v+(m*24|0)+16|0;c[x>>2]=c[x>>2]&3|w;y=v+(m*24|0)+8|0;c[y>>2]=m;c[y+4>>2]=(m|0)<0|0?-1:0;z=v+(m*24|0)|0;c[z>>2]=r;c[z+4>>2]=q;z=w>>2;w=YGb(z,(z|0)<0|0?-1:0,r,q)|0;z=F;v=u+(m<<4)|0;c[v>>2]=rz(f)|0;A=u+(m<<4)+4|0;c[A>>2]=rz(f)|0;B=(lz(f)|0)!=0;C=B?768:0;B=u+(m<<4)+8|0;c[B>>2]=C;D=c[A>>2]|0;E=c[v>>2]|0;if((E|D)>>>0>16777215>>>0){G=8}else{if(((c[x>>2]>>2)-(E+D+C)|0)<0){G=8}}if((G|0)==8){G=0;if((c[o>>2]&8|0)!=0){break}c[B>>2]=0;c[A>>2]=0;c[v>>2]=0}if((lz(f)|0)!=0){yDb(p,24,2142808,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A}A=u+(m<<4)+12|0;c[A>>2]=lz(f)|0;Vy(f,1,0)|0;B=c[v>>2]|0;v=(B|0)!=0;c[y>>2]=v?t:0;c[y+4>>2]=v?s:-2147483648;c[x>>2]=c[x>>2]&-4|(c[A>>2]|0)!=1;A=m+1|0;if((A|0)>=(c[k>>2]|0)){break a}x=YGb(B,(B|0)<0|0?-1:0,t,s)|0;q=z;r=w;m=A;s=F;t=x;u=c[l>>2]|0}$Db(c[d>>2]|0);j=-1094995529;i=b;return j|0}}while(0);c[e+4>>2]=0;j=0;i=b;return j|0}function QF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0;e=c[b+12>>2]|0;f=b+16|0;g=c[f>>2]|0;h=c[c[b+28>>2]>>2]|0;a:do{if((Xy(g)|0)==0){b=e+8|0;i=h+404|0;j=h+400|0;k=e;l=e+4|0;while(1){m=c[b>>2]|0;n=c[b+4>>2]|0;o=c[i>>2]|0;p=(o|0)<0|0?-1:0;if(!((n|0)<(p|0)|(n|0)==(p|0)&m>>>0<o>>>0)){break a}q=c[j>>2]|0;r=m;s=c[k>>2]|0;m=s+(r<<4)|0;o=c[l>>2]|0;if((o|0)==1){t=9}else if((o|0)==2){u=c[s+(r<<4)+4>>2]|0;v=c[s+(r<<4)+8>>2]|0;t=17}else if((o|0)==0){c[l>>2]=1;w=c[m>>2]|0;if((w|0)==0){t=9}else{t=7;break}}if((t|0)==9){t=0;c[l>>2]=2;y=s+(r<<4)+4|0;z=c[y>>2]|0;A=c[s+(r<<4)+8>>2]|0;if((z|A|0)==0){u=0;v=0;t=17}else{break}}if((t|0)==17){t=0;o=(c[q+(r*24|0)+16>>2]>>2)-(c[m>>2]|0)-u-v|0;m=(o|0)>0;Vy(g,m?o:0,m?(o|0)<0|0?-1:0:0)|0;c[l>>2]=0;o=YGb(c[b>>2]|0,c[b+4>>2]|0,1,0)|0;c[b>>2]=o;c[b+4>>2]=F}if((Xy(c[f>>2]|0)|0)!=0){break a}}if((t|0)==7){if((TS(c[f>>2]|0,d,w)|0)<0){B=-12;return B|0}c[d+32>>2]=0;l=q+(r*24|0)+8|0;k=c[l+4>>2]|0;j=d+8|0;c[j>>2]=c[l>>2];c[j+4>>2]=k;k=d+36|0;c[k>>2]=c[k>>2]|1;B=0;return B|0}k=A+z|0;if((wZ(d,k+5|0)|0)!=0){B=-12;return B|0}j=d+24|0;l=c[j>>2]|0;x=c[y>>2]|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=s+(r<<4)+12|0;a[(c[j>>2]|0)+4|0]=c[l>>2];i=mz(g,(c[j>>2]|0)+5|0,k)|0;if((i|0)<0){B=i;return B|0}if((i|0)<(k|0)){k=i+5|0;TGb((c[j>>2]|0)+k|0,0,16)|0;j=d+36|0;c[j>>2]=c[j>>2]|2;C=k}else{C=i+5|0}c[d+28>>2]=C;c[d+32>>2]=1;i=c[b+4>>2]|0;k=d+8|0;c[k>>2]=c[b>>2];c[k+4>>2]=i;if((c[l>>2]|0)==1){B=0;return B|0}l=d+36|0;c[l>>2]=c[l>>2]|1;B=0;return B|0}}while(0);B=(c[(c[f>>2]|0)+52>>2]|0)==0?-5:-541478725;return B|0}function RF(a){a=a|0;$Db(c[a+12>>2]|0);return 0}function SF(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[a+12>>2]|0;h=c[c[a+28>>2]>>2]|0;if((f&10|0)!=0){i=-38;return i|0}if((b|0)==0){j=oT(h,d,e,f)|0}else if((b|0)==1){j=d}else{i=0;return i|0}if((j|0)<0){i=0;return i|0}if((j|0)>=(c[h+404>>2]|0)){i=0;return i|0}d=(c[h+400>>2]|0)+(j*24|0)|0;h=Ty(c[a+16>>2]|0,c[d>>2]|0,c[d+4>>2]|0,0)|0;d=F;a=0;if((d|0)<(a|0)|(d|0)==(a|0)&h>>>0<0>>>0){i=-1;return i|0}c[g+4>>2]=0;h=g+8|0;c[h>>2]=j;c[h+4>>2]=(j|0)<0|0?-1:0;i=0;return i|0}function TF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+48|0;d=b|0;e=c[a+12>>2]|0;f=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[f+48>>2]|0)==86066){g=0;i=b;return g|0}a=c[f+100>>2]|0;if((a|0)<=0){g=0;i=b;return g|0}h=c[f+96>>2]|0;if((a|0)>1024){yDb(e,16,1952336,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;g=-1094995529;i=b;return g|0}f=QMa(d,h,a<<3,1)|0;c[e+4>>2]=f;if((f|0)<0){g=-1094995529;i=b;return g|0}a=e+12|0;do{if((c[a>>2]|0)==36){if((f&7|0)==0){break}yDb(e,16,1925896,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;g=-1094995529;i=b;return g|0}}while(0);f=c[d>>2]|0;if((f|0)<6|(f|0)==36){c[e+8>>2]=c[d+12>>2];c[a>>2]=f;g=0;i=b;return g|0}else{yDb(e,16,1903968,(j=i,i=i+8|0,c[j>>2]=f,j)|0);i=j;g=-1094995529;i=b;return g|0}return 0}function UF(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;f=i;i=i+56|0;g=f|0;h=f+24|0;j=f+48|0;k=j;l=c[b+12>>2]|0;m=c[b+16>>2]|0;c[j>>2]=57430;n=c[b+28>>2]|0;o=c[(c[n>>2]|0)+8>>2]|0;if((c[o+48>>2]|0)==86066){p=lO(b,e)|0;i=f;return p|0}q=e+28|0;r=c[q>>2]|0;s=(r|0)>2;do{if(s){t=c[e+24>>2]|0;if(!((a[t]|0)==-1)){break}if(!((a[t+1|0]&-16)<<24>>24==-16)){break}yDb(b,16,2027400,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;p=-1094995529;i=f;return p|0}}while(0);if((c[o+96>>2]|0)==0){if(!s){p=-1094995529;i=f;return p|0}s=c[e+24>>2]|0;if((a[s]|0)!=86){p=-1094995529;i=f;return p|0}o=s+1|0;if(!((a[o]&-16)<<24>>24==-32)){p=-1094995529;i=f;return p|0}s=o;if((((de((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&8191)+3|0)!=(r|0)){p=-1094995529;i=f;return p|0}p=lO(b,e)|0;i=f;return p|0}do{if((r|0)<=8191){s=l+24|0;o=r+2048|0;t=(o|0)<0;v=t?0:s;w=t?0:o;c[h+20>>2]=w<<3;o=h+8|0;c[o>>2]=v;c[h+16>>2]=v+w;w=h+12|0;c[w>>2]=v;v=h+4|0;c[v>>2]=32;t=h|0;c[t>>2]=0;y=c[(c[n>>2]|0)+8>>2]|0;z=l+16|0;A=(c[z>>2]|0)!=0|0;c[t>>2]=A;c[v>>2]=31;B=c[z>>2]|0;if((B|0)==0){c[t>>2]=A<<15|8192;c[v>>2]=16;do{if((c[l+12>>2]|0)==36){A=c[l+4>>2]>>3;M_(h,(c[y+96>>2]|0)+A|0,(c[y+100>>2]|0)-A|0)}else{A=y+96|0;C=l+4|0;M_(h,c[A>>2]|0,(c[C>>2]|0)+3|0);if((c[l+8>>2]|0)!=0){break}D=c[A>>2]|0;A=c[y+100>>2]|0;E=A>>>0>268435455>>>0?-8:A<<3;A=E>>>0>2147483639>>>0|(D|0)==0;F=A?0:D;D=A?0:E;c[g>>2]=F;c[g+12>>2]=D;E=D+8|0;c[g+16>>2]=E;c[g+4>>2]=F+(D>>3);D=g+8|0;c[D>>2]=0;F=(c[C>>2]|0)+3|0;if((F|0)<0){G=0}else{G=(E|0)<(F|0)?E:F}c[D>>2]=G;RMa(h,g)|0}}while(0);y=c[t>>2]|0;D=c[v>>2]|0;if((D|0)>3){H=D-3|0;I=y<<3}else{F=fe(y<<D|0)|0;y=c[w>>2]|0;x=F;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;H=D+29|0;I=0}c[t>>2]=I;c[v>>2]=H;if((H|0)>8){J=H-8|0;K=I<<8|255}else{D=fe(255>>>((8-H|0)>>>0)|I<<H|0)|0;y=c[w>>2]|0;x=D;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;J=H+24|0;K=255}c[t>>2]=K;c[v>>2]=J;if((J|0)>1){L=J-1|0;M=K<<1}else{y=fe(K<<J|0)|0;D=c[w>>2]|0;x=y;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;L=J+31|0;M=0}c[t>>2]=M;c[v>>2]=L;if((L|0)>1){N=L-1|0;O=M<<1}else{D=fe(M<<L|0)|0;y=c[w>>2]|0;x=D;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;N=L+31|0;O=0}c[t>>2]=O;c[v>>2]=N;P=c[z>>2]|0}else{P=B}c[z>>2]=(P+1|0)%(c[l+20>>2]|0)|0;y=c[q>>2]|0;D=c[t>>2]|0;F=c[v>>2]|0;if((y-255|0)<0){Q=0;R=y;S=D;T=F}else{E=0;C=D;D=F;F=y;while(1){if((D|0)>8){U=D-8|0;V=C<<8|255;W=F}else{y=fe(255>>>((8-D|0)>>>0)|C<<D|0)|0;A=c[w>>2]|0;x=y;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;U=D+24|0;V=255;W=c[q>>2]|0}c[t>>2]=V;c[v>>2]=U;A=E+255|0;if((A|0)>(W-255|0)){Q=A;R=W;S=V;T=U;break}else{E=A;C=V;D=U;F=W}}}F=R-Q|0;if((T|0)>8){X=T-8|0;Y=S<<8|F;Z=R}else{D=fe(F>>>((8-T|0)>>>0)|S<<T|0)|0;C=c[w>>2]|0;x=D;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;X=T+24|0;Y=F;Z=c[q>>2]|0}c[t>>2]=Y;c[v>>2]=X;F=e+24|0;C=c[F>>2]|0;do{if((Z|0)==0){_=48}else{D=d[C]|0;if((D&225|0)!=129){_=48;break}E=D&254;if((X|0)>8){$=X-8|0;aa=Y<<8|E;ba=C;ca=Z}else{D=fe(Y<<X|E>>>((8-X|0)>>>0)|0)|0;z=c[w>>2]|0;x=D;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;$=X+24|0;aa=E;ba=c[F>>2]|0;ca=c[q>>2]|0}c[t>>2]=aa;c[v>>2]=$;M_(h,ba+1|0,(ca<<3)-8|0)}}while(0);if((_|0)==48){M_(h,C,Z<<3)}K_(h);F=c[v>>2]|0;if((F|0)<32){E=c[t>>2]<<F;c[t>>2]=E;F=E>>>24&255;while(1){E=c[w>>2]|0;c[w>>2]=E+1;a[E]=F;E=c[t>>2]|0;c[t>>2]=E<<8;z=(c[v>>2]|0)+8|0;c[v>>2]=z;if((z|0)<32){F=E>>>16&255}else{break}}}c[v>>2]=32;c[t>>2]=0;F=(c[w>>2]|0)-(c[o>>2]|0)|0;C=F<<3;E=C>>3;if((C|0)>65528){break}C=k+1|0;a[C]=d[C]|F>>>8&31;F=k+2|0;a[F]=d[F]|E;Ry(m,j,3);Ry(m,s,E);p=0;i=f;return p|0}}while(0);yDb(b,16,1983104,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;p=-1094995529;i=f;return p|0}function VF(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+4>>2]|0;a=b+2|0;e=(d[a]|d[a+1|0]<<8)<<16>>16;a=de(e|0)|0;f=b+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=fe(g|0)|0;h=b;do{if(f>>>0<1048577>>>0&(((a&65535)>>>0>4>>>0|(d[h]|d[h+1|0]<<8)<<16>>16<<16>>16!=0|(g|0)==0|e<<16>>16==768)^1)){i=b+8|0;if(e<<16>>16==1024){j=i;k=((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-4;l=k?33:0;return l|0}else{if(((d[b+9|0]|0)<<8|(d[i]|0)<<16|(d[b+10|0]|0)|0)==1){l=20}else{break}return l|0}}}while(0);l=0;return l|0}function WF(a){a=a|0;var b=0,d=0,e=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=0;c[e+48>>2]=13;c[b+236>>2]=2;MT(b,64,1001,3e4);b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86016;c[b+236>>2]=2;d=0;return d|0}function XF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=c[a+16>>2]|0;tz(e)|0;f=tz(e)|0;g=vz(e)|0;if(f>>>0>4>>>0|(f|0)==3){yDb(a,16,2142648,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-5;i=d;return j|0}if((g-9|0)>>>0>1048567>>>0){yDb(a,16,2076184,(h=i,i=i+8|0,c[h>>2]=g,h)|0);i=h;j=-5;i=d;return j|0}h=TS(e,b,g-8|0)|0;if((h|0)<1){j=-5;i=d;return j|0}Vy(e,-g&511,0)|0;if((f|0)==4){c[b+32>>2]=1;j=h;i=d;return j|0}else if((f|0)==0){c[b+36>>2]=1}else if(!((f|0)==1|(f|0)==2)){j=h;i=d;return j|0}c[b+32>>2]=0;j=h;i=d;return j|0}function YF(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+4>>2]|0;e=(c[a+8>>2]|0)-3|0;a=b+e|0;do{if((e|0)>0){f=a;g=0;h=b;i=0;do{a:do{if(h>>>0<a>>>0){j=0;k=h;while(1){l=(d[k+1|0]|0)<<8;if((l&57344|(d[k]|0)<<16|0)!=5693440){m=j;n=k;break a}o=(d[k+2|0]|0|l&7936)+3|0;if(o>>>0<7>>>0){m=j;n=k;break a}l=f-k|0;p=k+((o|0)>(l|0)?l:o)|0;o=j+1|0;if(p>>>0<a>>>0){j=o;k=p}else{m=o;n=p;break}}}else{m=0;n=h}}while(0);i=(i|0)>(m|0)?i:m;g=(h|0)==(b|0)?m:g;h=n+1|0;}while(h>>>0<a>>>0);if((g|0)>2){q=51;return q|0}if((i|0)>100){q=50}else{r=i;break}return q|0}else{r=0}}while(0);q=(r|0)>2?25:0;return q|0}function ZF(a){a=a|0;var b=0,d=0,e=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[b+236>>2]=1463898624;MT(b,64,1,28224e3);d=0;return d|0}function _F(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1179014732){a=b+16|0;b=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;return((b|0)==0|b>>>0>256>>>0?12:50)|0}else{return 0}return 0}function $F(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a+16|0;Vy(c[d>>2]|0,16,0)|0;e=rz(c[d>>2]|0)|0;if((e|0)==0){f=-1094995529;i=b;return f|0}if(e>>>0>2>>>0){DDb(a,2142600,(g=i,i=i+8|0,c[g>>2]=e,g)|0);i=g;f=-1163346256;i=b;return f|0}Vy(c[d>>2]|0,1012,0)|0;if((Xy(c[d>>2]|0)|0)!=0){f=-541478725;i=b;return f|0}while(1){h=rz(c[d>>2]|0)|0;e=rz(c[d>>2]|0)|0;j=Ty(c[d>>2]|0,0,0,1)|0;k=YGb(j,F,e,0)|0;e=F;if((h|0)==0){l=10;break}else if((h|0)==1835413552){j=LT(a,0)|0;if((j|0)==0){f=-12;l=13;break}m=j+8|0;c[(c[m>>2]|0)+8>>2]=0;Vy(c[d>>2]|0,4,0)|0;n=rz(c[d>>2]|0)|0;c[(c[m>>2]|0)+120>>2]=n;n=rz(c[d>>2]|0)|0;c[(c[m>>2]|0)+124>>2]=n;Vy(c[d>>2]|0,4,0)|0;n=rz(c[d>>2]|0)|0;c[(c[m>>2]|0)+52>>2]=n;o=vT(1240808,n)|0;c[(c[m>>2]|0)+48>>2]=o;MT(j,32,1,1e3)}else if((h|0)==1835413808){j=LT(a,0)|0;if((j|0)==0){f=-12;l=13;break}o=j+8|0;c[(c[o>>2]|0)+8>>2]=1;m=pz(c[d>>2]|0)|0;c[(c[o>>2]|0)+52>>2]=m;m=pz(c[d>>2]|0)|0;c[(c[o>>2]|0)+416>>2]=m;m=pz(c[d>>2]|0)|0;c[(c[o>>2]|0)+412>>2]=m;Vy(c[d>>2]|0,8,0)|0;m=lz(c[d>>2]|0)|0;n=c[o>>2]|0;c[n+792>>2]=m;m=vT(1238064,c[n+52>>2]|0)|0;c[(c[o>>2]|0)+48>>2]=m;MT(j,32,1,1e3)}else{l=11;break}Ty(c[d>>2]|0,k,e,0)|0;if((Xy(c[d>>2]|0)|0)!=0){f=-541478725;l=13;break}}if((l|0)==10){Ty(c[d>>2]|0,2056,0,0)|0;f=0;i=b;return f|0}else if((l|0)==11){DDb(a,2076160,(g=i,i=i+8|0,c[g>>2]=h,g)|0);i=g;f=-1163346256;i=b;return f|0}else if((l|0)==13){i=b;return f|0}return 0}function aG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=a+16|0;a=Ty(c[d>>2]|0,0,0,1)|0;e=F;while(1){if((Xy(c[d>>2]|0)|0)!=0){f=-541478725;g=11;break}h=rz(c[d>>2]|0)|0;i=rz(c[d>>2]|0)|0;if((i|0)==-1){f=-541478725;g=11;break}if((h|0)==1667510320){j=0;break}else if((h|0)==1651978544){g=5;break}h=Vy(c[d>>2]|0,i,0)|0;k=h;if((k|0)<0){f=k;g=11;break}}if((g|0)==5){j=1}else if((g|0)==11){return f|0}if(i>>>0<8>>>0){f=-1094995529;return f|0}g=rz(c[d>>2]|0)|0;k=rz(c[d>>2]|0)|0;h=TS(c[d>>2]|0,b,i-8|0)|0;if((k&4096|0)!=0){k=b+36|0;c[k>>2]=c[k>>2]|1}c[b+32>>2]=j;j=b+8|0;c[j>>2]=g;c[j+4>>2]=0;j=b+64|0;c[j>>2]=a;c[j+4>>2]=e;f=h;return f|0}function bG(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,2318784,8)|0)==0;return(b?100:0)|0}function cG(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+120|0;e=b|0;f=c[a+12>>2]|0;g=a+16|0;h=c[g>>2]|0;j=eG(a)|0;if((j|0)<0){k=j;i=b;return k|0}if((j|0)!=120){yDb(a,16,2296816,(l=i,i=i+16|0,c[l>>2]=120,c[l+8>>2]=j,l)|0);i=l;k=-1094995529;i=b;return k|0}j=mz(h,e|0,120)|0;if((j|0)!=120){k=(j|0)<0?j:-541478725;i=b;return k|0}j=LT(a,0)|0;if((j|0)==0){k=-12;i=b;return k|0}h=e+32|0;m=j+56|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=0;m=e+40|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+56|0;n=(d[m]|d[m+1|0]<<8)<<16>>16;m=e+58|0;o=(d[m]|d[m+1|0]<<8)<<16>>16;m=e+116|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+8|0;p=c[m>>2]|0;c[p+8>>2]=0;c[p+72>>2]=(h>>>14&255)*1e6|0;q=h&15;c[p+52>>2]=q;p=vT(687384,q)|0;c[(c[m>>2]|0)+48>>2]=p;c[j+236>>2]=2;j=a;p=n&65535;yDb(j,48,2279816,(l=i,i=i+32|0,c[l>>2]=p,c[l+8>>2]=(p&127)+1900,c[l+16>>2]=p>>>7&15,c[l+24>>2]=p>>>11,l)|0);i=l;p=o&65535;yDb(j,48,2264640,(l=i,i=i+32|0,c[l>>2]=p,c[l+8>>2]=(p&127)+1900,c[l+16>>2]=p>>>7&15,c[l+24>>2]=p>>>11,l)|0);i=l;if((h&4194304|0)!=0){yDb(j,24,2249664,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}l=f;c[l>>2]=1<<(e>>>4&3)+1;e=LT(a,0)|0;if((e|0)==0){k=-12;i=b;return k|0}a=c[e+8>>2]|0;c[a+8>>2]=1;c[a+412>>2]=48e3;c[a+416>>2]=c[l>>2];MT(e,64,1,48e3);Vy(c[g>>2]|0,c[f+16>>2]|0,0)|0;k=0;i=b;return k|0}function dG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=eG(a)|0;if((g|0)<0){h=g;i=d;return h|0}j=c[e+12>>2]|0;if(j>>>0>1>>>0){yDb(a,24,2142528,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;h=-11;i=d;return h|0}do{if((j|0)==1){if(!((c[a+24>>2]|0)>>>0<2>>>0)){break}yDb(a,16,2076088,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;h=-1094995529;i=d;return h|0}}while(0);k=wZ(b,g)|0;if((k|0)<0){h=k;i=d;return h|0}k=mz(f,c[b+24>>2]|0,g)|0;if((k|0)!=(g|0)){BZ(b);h=(k|0)<0?k:-541478725;i=d;return h|0}c[b+32>>2]=j;if((j|0)!=0){h=g;i=d;return h|0}if((c[e+8>>2]&8388608)>>>0<8388608>>>0){j=b+36|0;c[j>>2]=c[j>>2]|1}j=e+4|0;e=c[j>>2]|0;c[j>>2]=e+1;j=b+16|0;c[j>>2]=e;c[j+4>>2]=(e|0)<0|0?-1:0;h=g;i=d;return h|0}function eG(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+264|0;f=e|0;g=e+8|0;h=g|0;j=c[b+12>>2]|0;k=b+16|0;l=c[k>>2]|0;m=g;n=g+8|0;o=n;p=f|0;q=mz(l,p,8)|0;if((q|0)!=8){r=(q|0)<0?q:-541478725;i=e;return r|0}a:do{if((PGb(p,2318784,8)|0)!=0){q=f+1|0;s=f+7|0;while(1){if((Xy(c[k>>2]|0)|0)!=0){r=-541478725;break}VGb(p|0,q|0,7)|0;a[s]=lz(c[k>>2]|0)|0;if((PGb(p,2318784,8)|0)==0){break a}}i=e;return r|0}}while(0);c[h>>2]=1414088012;c[h+4>>2]=18499;h=mz(l,o,8)|0;if((h|0)!=8){r=(h|0)<0?h:-541478725;i=e;return r|0}h=c[n>>2]|0;n=g+16|0;g=n;p=c[o+4>>2]|0;if(h>>>0>1>>>0){DDb(b,2027336,(t=i,i=i+8|0,c[t>>2]=h,t)|0);i=t}o=(h|0)!=0;if(!(p>>>0<257>>>0&p>>>0>=(o?72:60)>>>0&(p&3|0)==0)){yDb(b,16,1983056,(t=i,i=i+8|0,c[t>>2]=p,t)|0);i=t;r=-1094995529;i=e;return r|0}k=p-16|0;f=mz(l,g,k)|0;if((f|0)!=(k|0)){r=(f|0)<0?f:-541478725;i=e;return r|0}do{if((p|0)>0){f=0;s=0;do{s=(c[m+f>>2]|0)+s|0;f=f+4|0;}while((f|0)<(p|0));if((s|0)==0){break}yDb(b,16,1952304,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}}while(0);p=c[n>>2]|0;c[j+12>>2]=p;n=o?24:16;o=g+n|0;m=j+16|0;c[m>>2]=0;if((p|0)==0){f=n|4;c[j+8>>2]=c[o>>2];j=c[g+f>>2]|0;q=YGb(c[g+(f+16)>>2]|0,0,c[g+(f+8)>>2]|0,0)|0;Vy(l,q,F)|0;r=j;i=e;return r|0}else if((p|0)==1){if((c[b+24>>2]|0)>>>0<2>>>0){yDb(b,32,1925816,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;r=k;i=e;return r|0}k=(h|0)==0?g+(n+8)|0:o;h=c[k>>2]|0;p=k+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+8|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+28|0;q=c[p>>2]|0;l=h>>>6&63;f=c[(c[q+4>>2]|0)+8>>2]|0;c[f+792>>2]=l;if((l|0)!=(h&63|0)){yDb(b,24,1903832,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;r=-1163346256;i=e;return r|0}if((l|0)==20){c[f+48>>2]=65561}else if((l|0)==24){c[f+48>>2]=407917392}else if((l|0)==32){c[f+48>>2]=542135120}else if((l|0)==16){c[f+48>>2]=65554}else{yDb(b,24,1883560,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;r=-1163346256;i=e;return r|0}f=(k<<3|0)/(l|0)|0;if((f|0)==8008){MT(c[q>>2]|0,64,1001,3e4)}else if((f|0)==1920){u=q;v=34}else{yDb(b,24,2341600,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=c[p>>2]|0;v=34}if((v|0)==34){MT(c[u>>2]|0,64,1,25)}u=j-(j>>>1&1431655765)|0;j=(u>>>2&858993459)+(u&858993459)|0;u=(j>>>4)+j&252645135;j=(u>>>8)+u|0;r=ba((j>>>16)+j&63,k)|0;i=e;return r|0}else{k=n|4;n=c[g+k>>2]|0;if((c[o>>2]|0)!=1){r=n;i=e;return r|0}c[m>>2]=c[g+(k+4)>>2];r=n;i=e;return r|0}return 0}function fG(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[a+8>>2]|0;if((b|0)>0){e=c[a+4>>2]|0;a=-256;f=0;g=0;h=0;i=0;j=0;k=0;while(1){l=d[e+k|0]|0|a;do{if((a|0)==256){if((l|0)==437){m=j;n=i+1|0;o=h;p=g;q=f;break}else if((l|0)==438){m=j;n=i;o=h+1|0;p=g;q=f;break}else{if(l>>>0<288>>>0){m=j;n=i;o=h;p=g;q=f+1|0;break}if(l>>>0<304>>>0){m=j;n=i;o=h;p=g+1|0;q=f;break}else{m=(((l-432|0)>>>0<7>>>0|(l-442|0)>>>0<10>>>0)&1^1)+j|0;n=i;o=h;p=g;q=f;break}}}else{m=j;n=i;o=h;p=g;q=f}}while(0);r=k+1|0;if((r|0)<(b|0)){a=l<<8;f=q;g=p;h=o;i=n;j=m;k=r}else{s=q;t=p;u=o;v=n;w=m;break}}}else{s=0;t=0;u=0;v=0;w=0}if((u|0)<(v|0)|(u|0)<(t|0)){x=0;return x|0}if(!((s|0)>=(t|0)&(t|0)>0&(w|0)==0)){x=0;return x|0}x=(u+s|0)>3?50:25;return x|0}function gG(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+4>>2]|0;e=b;if(!((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==-1545648870)){f=0;return f|0}e=d[b+4|0]|0;g=0;if((e&128|0)==0&(g&0|0)==0){do{if((e&64|0)==0&(g&0|0)==0){if(!((e&32|0)==0&(g&0|0)==0)){h=3;i=0;j=287;break}if(!((e&16|0)==0&(g&0|0)==0)){h=4;i=0;j=271;break}if(!((e&8|0)==0&(g&0|0)==0)){h=5;i=0;j=263;break}if(!((e&4|0)==0&(g&0|0)==0)){h=6;i=0;j=259;break}if(!((e&2|0)==0&(g&0|0)==0)){h=7;i=0;j=257;break}if((e&1|0)==0&(g&0|0)==0){f=0}else{h=8;i=0;j=256;break}return f|0}else{h=2;i=0;j=319}}while(0);k=i&g;i=j&e;j=1;while(1){l=j+1|0;m=d[b+(j+4)|0]|0|(i<<8|0>>>24);n=k<<8|i>>>24|0;if((l|0)<(h|0)){k=n;i=m;j=l}else{o=n;p=m;q=h;break}}}else{o=g&0;p=e&127;q=1}e=c[a+8>>2]|0;a=(e|0)<0|0?-1:0;g=q+4|0;q=YGb(p,o,g,0)|0;h=F;if(a>>>0<h>>>0|a>>>0==h>>>0&e>>>0<q>>>0){f=0;return f|0}e=0;a:do{if(!(o>>>0<e>>>0|o>>>0==e>>>0&p>>>0<8>>>0)){a=YGb(q,h,-8,-1)|0;j=F;i=g;while(1){k=(i|0)<0|0?-1:0;if(k>>>0>j>>>0|k>>>0==j>>>0&i>>>0>a>>>0){break a}if((PGb(b+i|0,1953984,8)|0)==0){f=100;break}else{i=i+1|0}}return f|0}}while(0);e=0;if(o>>>0<e>>>0|o>>>0==e>>>0&p>>>0<4>>>0){f=50;return f|0}p=YGb(q,h,-4,-1)|0;h=F;q=g;while(1){g=(q|0)<0|0?-1:0;if(g>>>0>h>>>0|g>>>0==h>>>0&q>>>0>p>>>0){f=50;r=13;break}if((PGb(b+q|0,1951792,4)|0)==0){f=100;r=13;break}else{q=q+1|0}}if((r|0)==13){return f|0}return 0}function hG(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ca=0,da=0,ea=0.0,fa=0.0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0;e=i;i=i+288|0;f=e|0;g=e+32|0;j=e+40|0;k=e+80|0;l=e+208|0;m=e+216|0;n=e+248|0;o=e+256|0;p=e+264|0;q=e+272|0;r=e+280|0;s=b+12|0;t=c[s>>2]|0;u=t;v=t+320|0;w=t+328|0;y=j;TGb(y|0,0,40)|0;z=t;c[z>>2]=b;A=(mG(u,1344192,y)|0)!=0;B=j|0;C=c[B>>2]|0;D=c[B+4>>2]|0;B=0;do{if(!(A|(D>>>0>B>>>0|D>>>0==B>>>0&C>>>0>1>>>0))){G=j+8|0;H=c[G+4>>2]|0;I=0;if(H>>>0>I>>>0|H>>>0==I>>>0&(c[G>>2]|0)>>>0>8>>>0){break}G=j+16|0;I=c[G+4>>2]|0;H=0;if(I>>>0>H>>>0|I>>>0==H>>>0&(c[G>>2]|0)>>>0>4>>>0){break}G=j+32|0;H=c[G>>2]|0;I=c[G+4>>2]|0;G=0;if(I>>>0>G>>>0|I>>>0==G>>>0&H>>>0>3>>>0){break}G=j+24|0;J=c[G>>2]|0;if((J|0)==0){break}if((H|0)==3&(I|0)==0){yDb(c[z>>2]|0,24,2129136,(K=i,i=i+40|0,c[K>>2]=C,c[K+8>>2]=D,c[K+16>>2]=J,c[K+24>>2]=3,c[K+32>>2]=0,K)|0);i=K;L=c[G>>2]|0}else{L=J}J=0;while(1){if(!(J>>>0<2>>>0)){M=13;break}if((QGb(L,c[682760+(J<<2)>>2]|0)|0)==0){M=12;break}else{J=J+1|0}}if((M|0)==12){if(J>>>0>1>>>0){M=13}}do{if((M|0)==13){yDb(b,24,2122824,(K=i,i=i+8|0,c[K>>2]=L,K)|0);i=K;if((c[(c[z>>2]|0)+1156>>2]&8|0)==0){break}oG(1344192,y);N=-1094995529;i=e;return N|0}}while(0);oG(1344192,y);J=Ty(c[(c[z>>2]|0)+16>>2]|0,0,0,1)|0;G=F;I=(mG(u,681904,t)|0)==1;H=c[(c[z>>2]|0)+16>>2]|0;a:do{if(I){O=H}else{R=t+268|0;S=t+4|0;T=G;U=J;V=H;b:while(1){c[R>>2]=0;c[S>>2]=0;W=YGb(U,T,1,0)|0;X=Ty(V,W,F,0)|0;W=F;Y=0;if((W|0)<(Y|0)|(W|0)==(Y|0)&X>>>0<0>>>0){break}X=vz(V)|0;if((Xy(V)|0)==0){Z=X}else{break}while(1){if((Z|0)==524531317|(Z|0)==475249515|(Z|0)==423732329|(Z|0)==374648427|(Z|0)==357149030|(Z|0)==307544935|(Z|0)==290298740|(Z|0)==272869232){break}X=lz(V)|0|Z<<8;if((Xy(V)|0)==0){Z=X}else{break b}}c[R>>2]=Z;X=Ty(c[(c[z>>2]|0)+16>>2]|0,0,0,1)|0;Y=F;W=(mG(u,681952,t)|0)==1;_=c[(c[z>>2]|0)+16>>2]|0;if(W){O=_;break a}else{T=Y;U=X;V=_}}c[t+380>>2]=1;N=-541478725;i=e;return N|0}}while(0);H=Ty(O,0,0,1)|0;J=F;G=c[z>>2]|0;c:do{if((c[(c[G+16>>2]|0)+88>>2]|0)!=0){if((c[G+1084>>2]&2|0)!=0){break}I=t+352|0;V=c[I>>2]|0;if((V|0)<=0){break}U=t+356|0;T=t+400|0;R=0;S=V;d:while(1){V=c[U>>2]|0;_=V+(R<<4)+8|0;X=c[_+4>>2]|0;do{if(X>>>0>J>>>0|X>>>0==J>>>0&(c[_>>2]|0)>>>0>H>>>0){Y=V+(R<<4)|0;if((c[Y>>2]|0)==475249515&(c[Y+4>>2]|0)==0){c[T>>2]=1;$=S;break}if((sG(u,R)|0)<0){break d}$=c[I>>2]|0}else{$=S}}while(0);V=R+1|0;if((V|0)<($|0)){R=V;S=$}else{break c}}c[T>>2]=-1}}while(0);H=t+272|0;J=c[H>>2]|0;G=c[H+4>>2]|0;if((J|0)==0&(G|0)==0){c[H>>2]=1e6;c[H+4>>2]=0;ca=0;da=1e6}else{ca=G;da=J}J=t+280|0;ea=+h[J>>3];if(ea!=0.0){fa=ea*(+(da>>>0)+ +(ca>>>0)*4294967296.0)*1.0e3/1.0e6;G=(E=+fa,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);S=(c[z>>2]|0)+1064|0;c[S>>2]=~~+fa>>>0;c[S+4>>2]=G}G=b+1140|0;CBb(G,2117640,c[t+288>>2]|0,0)|0;CBb(G,2107096,c[t+292>>2]|0,0)|0;do{if((c[t+296>>2]|0)==8){S=c[t+300>>2]|0;R=S|0;I=S+4|0;S=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;I=fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0;R=fe(S|0)|0;S=f|0;U=eHb(R,I|0,1e9,0)|0;I=YGb(U,F,978307200,0)|0;c[g>>2]=I;I=mc(g|0)|0;if((I|0)==0){break}Ac(S|0,32,1958536,I|0)|0;CBb(G,1956240,S,0)|0}}while(0);S=c[t+316>>2]|0;I=t+312|0;e:do{if((c[I>>2]|0)>0){U=t+432|0;R=m|0;V=b+28|0;_=p|0;X=p+4|0;Y=q|0;W=q+4|0;ha=n|0;ia=n+4|0;ja=o|0;ka=o+4|0;la=l;ma=0;f:while(1){na=S+(ma*296|0)+260|0;oa=c[na>>2]|0;c[l>>2]=0;pa=S+(ma*296|0)+16|0;qa=c[pa>>2]|0;ra=c[pa+4>>2]|0;do{if((qa|0)==1&(ra|0)==0|(qa|0)==2&(ra|0)==0|(qa|0)==17&(ra|0)==0|(qa|0)==33&(ra|0)==0){sa=S+(ma*296|0)+28|0;if((c[sa>>2]|0)==0){break}ta=2;ua=0;do{if((qa|0)==1&(ra|0)==0){va=S+(ma*296|0)+64|0;do{if((c[va>>2]|0)==0&(c[va+4>>2]|0)==0){fa=+h[S+(ma*296|0)+104>>3];if(!(fa>0.0)){break}ea=1.0e9/fa;wa=(E=+ea,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[va>>2]=~~+ea>>>0;c[va+4>>2]=wa}}while(0);va=S+(ma*296|0)+112|0;if((c[va>>2]|0)==(-1|0)&(c[va+4>>2]|0)==(-1|0)){wa=S+(ma*296|0)+128|0;xa=c[wa+4>>2]|0;c[va>>2]=c[wa>>2];c[va+4>>2]=xa}xa=S+(ma*296|0)+120|0;if((c[xa>>2]|0)==(-1|0)&(c[xa+4>>2]|0)==(-1|0)){va=S+(ma*296|0)+136|0;wa=c[va+4>>2]|0;c[xa>>2]=c[va>>2];c[xa+4>>2]=wa}if((c[S+(ma*296|0)+144>>2]|0)!=4){ya=0;break}wa=c[S+(ma*296|0)+148>>2]|0;ya=d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0}else if((qa|0)==(ta|0)&(ra|0)==(ua|0)){wa=S+(ma*296|0)+184|0;if(+h[wa>>3]!=0.0){ya=0;break}h[wa>>3]=+h[S+(ma*296|0)+176>>3];ya=0}else{ya=0}}while(0);ua=c[S+(ma*296|0)+256>>2]|0;do{if((ua|0)>1){yDb(c[z>>2]|0,16,2090664,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;za=0}else{if((ua|0)!=1){za=0;break}ta=oa+8|0;if(!((c[ta>>2]|0)==0&(c[ta+4>>2]|0)==0)){ta=oa+48|0;wa=c[ta>>2]|0;if((wa|0)<=0){xa=oa;c[xa>>2]=0;c[xa+4>>2]=0;yDb(c[z>>2]|0,16,2085608,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;za=0;break}xa=((wa+2|0)/3|0)<<2|1;wa=WDb(xa)|0;c[l>>2]=wa;if((wa|0)==0){N=-12;M=253;break f}HAb(wa,xa,c[oa+52>>2]|0,c[ta>>2]|0)|0;za=0;break}ta=oa+16|0;xa=c[ta>>2]|0;wa=c[ta+4>>2]|0;if(!((xa|0)==0&(wa|0)==0|(xa|0)==2&(wa|0)==0|(xa|0)==3&(wa|0)==0)){wa=oa;c[wa>>2]=0;c[wa+4>>2]=0;yDb(c[z>>2]|0,16,2085608,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;za=0;break}wa=S+(ma*296|0)+32|0;if((c[wa>>2]|0)==0){za=0;break}xa=oa;if((c[xa>>2]&2|0)==0&(c[xa+4>>2]&0|0)==0){za=0;break}xa=S+(ma*296|0)+36|0;ta=c[xa>>2]|0;if((pG(xa,wa,c[na>>2]|0)|0)<0){c[xa>>2]=0;c[wa>>2]=0;yDb(c[z>>2]|0,16,2080520,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}if((ta|0)==(c[xa>>2]|0)){za=0;break}ZDb(ta);za=0}}while(0);while(1){ua=c[1185856+(za*28|0)>>2]|0;if((ua|0)==0){Aa=0;break}ta=1185832+(za*28|0)|0;xa=c[sa>>2]|0;if((RGb(ta,xa,SGb(ta|0)|0)|0)==0){Aa=ua;break}else{za=za+1|0}}ua=LT(b,0)|0;c[S+(ma*296|0)+264>>2]=ua;Ba=c[l>>2]|0;if((ua|0)==0){M=77;break f}if((Ba|0)!=0){CBb(ua+88|0,2075248,Ba,0)|0;$Db(la)}ta=c[sa>>2]|0;do{if((QGb(ta,2070704)|0)==0){if((c[S+(ma*296|0)+32>>2]|0)<=39){M=84;break}xa=c[S+(ma*296|0)+36>>2]|0;if((xa|0)==0){M=84;break}c[S+(ma*296|0)+280>>2]=1;wa=xa+14|0;va=(d[wa]|d[wa+1|0]<<8)<<16>>16&65535;wa=xa+16|0;xa=d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0;Ca=vT(1240808,xa)|0;Da=va;Ea=xa;Fa=40;M=149}else{M=84}}while(0);g:do{if((M|0)==84){M=0;do{if((QGb(ta,2066200)|0)==0){xa=S+(ma*296|0)+32|0;va=c[xa>>2]|0;if((va|0)<=13){break}wa=c[S+(ma*296|0)+36>>2]|0;if((wa|0)==0){break}Ny(k,wa,va,0,0,0,0,0)|0;va=ua+8|0;wa=AO(k,c[va>>2]|0,c[xa>>2]|0)|0;if((wa|0)<0){N=wa;M=253;break f}wa=c[xa>>2]|0;Ca=c[(c[va>>2]|0)+48>>2]|0;Da=-1;Ea=ya;Fa=(wa|0)>18?18:wa;M=149;break g}}while(0);do{if((QGb(ta,2062032)|0)==0){if((c[S+(ma*296|0)+32>>2]|0)<=85){break}wa=S+(ma*296|0)+36|0;va=c[wa>>2]|0;if((va|0)==0){break}xa=va+4|0;va=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;xa=vT(1240080,va)|0;Ga=c[wa>>2]|0;if((vT(1240080,d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)==0){Ca=xa;Da=-1;Ea=va;Fa=0;M=149;break g}va=c[wa>>2]|0;wa=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;Ca=vT(1240080,wa)|0;Da=-1;Ea=wa;Fa=0;M=149;break g}}while(0);do{if((QGb(ta,2058512)|0)==0){if((c[S+(ma*296|0)+32>>2]|0)<=20){M=101;break}wa=S+(ma*296|0)+36|0;va=c[wa>>2]|0;if((va|0)==0){M=101;break}xa=va+4|0;va=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;xa=vT(1238728,va)|0;Ga=c[wa>>2]|0;if((vT(1238728,d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)==0){Ha=xa;Ia=va}else{va=c[wa>>2]|0;xa=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;Ha=vT(1238728,xa)|0;Ia=xa}if((Ha|0)!=0){Ja=Ha;Ka=Ia;break}xa=(c[wa>>2]|0)+4|0;Ca=(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)==541674835?24:0;Da=-1;Ea=Ia;Fa=0;M=149;break g}else{M=101}}while(0);h:do{if((M|0)==101){M=0;do{if((Aa|0)==65536){xa=S+(ma*296|0)+192|0;wa=c[xa>>2]|0;va=c[xa+4>>2]|0;xa=32;Ga=0;La=24;Ma=0;if((wa|0)==8&(va|0)==0){Ja=65541;Ka=ya;break h}else if((wa|0)==(La|0)&(va|0)==(Ma|0)){Ja=65548;Ka=ya;break h}else if((wa|0)==(xa|0)&(va|0)==(Ga|0)){Ja=65544;Ka=ya;break h}else{Ja=65536;Ka=ya;break h}}else if((Aa|0)==65557){Ga=S+(ma*296|0)+192|0;if((c[Ga>>2]|0)==64&(c[Ga+4>>2]|0)==0){Ja=65559;Ka=ya;break h}}else if((Aa|0)==86018){if((c[S+(ma*296|0)+32>>2]|0)==0){Na=0}else{break}while(1){if(!(Na>>>0<3>>>0)){M=113;break}Ga=Na+1|0;if((yb(ta|0,c[684664+(Na<<2)>>2]|0)|0)==0){Na=Ga}else{Oa=Ga;break}}if((M|0)==113){M=0;Oa=Na+1|0}Ga=~~+h[S+(ma*296|0)+176>>3];va=0;while(1){if(!(va>>>0<16>>>0)){break}if((c[1743568+(va<<2)>>2]|0)==(Ga|0)){break}else{va=va+1|0}}Ga=cEb(21)|0;if((Ga|0)==0){N=-12;M=253;break f}a[Ga]=va>>>1&7|Oa<<3;a[Ga+1|0]=c[S+(ma*296|0)+200>>2]<<3|0>>>29|va<<7;if((yb(c[sa>>2]|0,2041248)|0)==0){Pa=86018;Qa=2;Ra=Ga;M=148;break}xa=~~+h[S+(ma*296|0)+184>>3];wa=0;while(1){if(!(wa>>>0<16>>>0)){break}if((c[1743568+(wa<<2)>>2]|0)==(xa|0)){break}else{wa=wa+1|0}}a[Ga+2|0]=86;a[Ga+3|0]=-27;a[Ga+4|0]=wa<<3|128;Pa=86018;Qa=5;Ra=Ga;M=148}else if((Aa|0)==65537){xa=S+(ma*296|0)+192|0;va=c[xa>>2]|0;Ma=c[xa+4>>2]|0;xa=32;La=0;Sa=8;Ta=0;if((va|0)==24&(Ma|0)==0){Ja=65549;Ka=ya;break h}else if((va|0)==(xa|0)&(Ma|0)==(La|0)){Ja=65545;Ka=ya;break h}else if((va|0)==(Sa|0)&(Ma|0)==(Ta|0)){Ja=65541;Ka=ya;break h}else{Ja=65537;Ka=ya;break h}}else if((Aa|0)==86032){Ta=S+(ma*296|0)+32|0;Ma=c[Ta>>2]|0;if(!((Ma|0)!=0&(Ma|0)<2147483619)){break}Sa=Ma+12|0;va=cEb(Ma+28|0)|0;if((va|0)==0){N=-12;M=253;break f}Ma=va;x=fe(Sa|0)|0;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;Ma=va+4|0;x=1667329121;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;Ma=va+8|0;x=0;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;UGb(va+12|0,c[S+(ma*296|0)+36>>2]|0,c[Ta>>2]|0)|0;Pa=86032;Qa=Sa;Ra=va;M=148}else if((Aa|0)==86038){va=cEb(46)|0;if((va|0)==0){N=-12;M=253;break f}Ny(k,va,30,1,0,0,0,0)|0;Ry(k,2034616,4);az(k,1);az(k,c[S+(ma*296|0)+200>>2]|0);az(k,c[S+(ma*296|0)+192>>2]|0);Sa=S+(ma*296|0)+184|0;ea=+h[Sa>>3];if(ea<0.0|ea>2147483647.0){N=-1094995529;M=253;break f}Yy(k,~~ea);ea=+h[J>>3]*(+((c[H>>2]|0)>>>0)+ +((c[H+4>>2]|0)>>>0)*4294967296.0);Ta=(E=+ea,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);fa=+h[Sa>>3];Sa=IDb(~~+ea>>>0,Ta,~~+fa>>>0,(E=+fa,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0),1e9,0)|0;Yy(k,Sa);Pa=86038;Qa=30;Ra=va;M=148}}while(0);if((M|0)==148){M=0;Ua=Ra;Va=Qa;Wa=0;Xa=ya;Ya=-1;Za=Pa;_a=S+(ma*296|0)+32|0;break g}if((Aa-6|0)>>>0<2>>>0|(Aa|0)==69|(Aa|0)==70){Ca=Aa;Da=-1;Ea=ya;Fa=26;M=149;break g}if((Aa|0)==77824){h[S+(ma*296|0)+184>>3]=8.0e3;va=S+(ma*296|0)+200|0;c[va>>2]=1;c[va+4>>2]=0;Ja=77824;Ka=ya;break}else if(!((Aa|0)==86058|(Aa|0)==86047|(Aa|0)==86036|(Aa|0)==77825)){Ca=Aa;Da=-1;Ea=ya;Fa=0;M=149;break g}va=c[S+(ma*296|0)+36>>2]|0;if((va|0)==0){Ca=Aa;Da=-1;Ea=ya;Fa=0;M=149;break g}Sa=S+(ma*296|0)+32|0;Ny(k,va,c[Sa>>2]|0,0,0,0,0,0)|0;Vy(k,22,0)|0;va=tz(k)|0;Ta=S+(ma*296|0)+208|0;c[Ta>>2]=vz(k)|0;Vy(k,12,0)|0;Ma=S+(ma*296|0)+212|0;c[Ma>>2]=tz(k)|0;La=S+(ma*296|0)+216|0;c[La>>2]=tz(k)|0;xa=tz(k)|0;$a=S+(ma*296|0)+220|0;c[$a>>2]=xa;if((va|0)<0){N=-1094995529;M=253;break f}if((c[Ta>>2]|0)<1){N=-1094995529;M=253;break f}ab=c[Ma>>2]|0;if((ab|0)<1){N=-1094995529;M=253;break f}Ma=c[La>>2]|0;if((Ma|0)<1|(xa|0)<1){N=-1094995529;M=253;break f}if((Ma|0)==0){M=140;break f}if(!((2147483647/(Ma>>>0)|0)>>>0>ab>>>0)){M=140;break f}xa=WDb(ba(Ma,ab)|0)|0;c[S+(ma*296|0)+240>>2]=xa;if((xa|0)==0){N=-12;M=253;break f}if((Aa|0)==77825){c[(c[ua+8>>2]|0)+432>>2]=c[Ta>>2];c[Sa>>2]=0;Ja=77825;Ka=ya;break}else if((Aa|0)==86058){M=144}do{if((M|0)==144){M=0;if((va|0)>=4){break}c[$a>>2]=d[1138112+va|0]|0;c[(c[ua+8>>2]|0)+72>>2]=c[682288+(va<<2)>>2]}}while(0);c[(c[ua+8>>2]|0)+432>>2]=c[$a>>2];Ca=Aa;Da=-1;Ea=ya;Fa=78;M=149;break g}}while(0);Ua=0;Va=0;Wa=0;Xa=Ka;Ya=-1;Za=Ja;_a=S+(ma*296|0)+32|0}}while(0);do{if((M|0)==149){M=0;ta=S+(ma*296|0)+32|0;c[ta>>2]=(c[ta>>2]|0)-Fa;if((Ca|0)!=0){Ua=0;Va=0;Wa=Fa;Xa=Ea;Ya=Da;Za=Ca;_a=ta;break}yDb(c[z>>2]|0,32,2030392,(K=i,i=i+8|0,c[K>>2]=c[sa>>2],K)|0);i=K;Ua=0;Va=0;Wa=Fa;Xa=Ea;Ya=Da;Za=0;_a=ta}}while(0);ta=S+(ma*296|0)+56|0;fa=+h[ta>>3];if(fa<.01){h[ta>>3]=1.0;bb=1.0}else{bb=fa}MT(ua,64,~~((+((c[H>>2]|0)>>>0)+ +((c[H+4>>2]|0)>>>0)*4294967296.0)*bb),1e9);ta=ua+8|0;c[(c[ta>>2]|0)+48>>2]=Za;va=c[S+(ma*296|0)+48>>2]|0;Sa=ua+88|0;if((QGb(va,2141296)|0)!=0){CBb(Sa,2026416,va,0)|0}CBb(Sa,2117640,c[S+(ma*296|0)+24>>2]|0,0)|0;va=S+(ma*296|0)+72|0;if(!((c[va>>2]|0)==0&(c[va+4>>2]|0)==0)){va=ua+72|0;c[va>>2]=c[va>>2]|1}va=S+(ma*296|0)+80|0;if(!((c[va>>2]|0)==0&(c[va+4>>2]|0)==0)){va=ua+72|0;c[va>>2]=c[va>>2]|64}va=c[ta>>2]|0;Ta=va+96|0;do{if((c[Ta>>2]|0)==0){if((Ua|0)!=0){c[Ta>>2]=Ua;c[(c[ta>>2]|0)+100>>2]=Va;break}xa=S+(ma*296|0)+36|0;if((c[xa>>2]|0)==0){break}ab=c[_a>>2]|0;if((ab|0)<=0){break}if((BT(va,ab)|0)!=0){N=-12;M=253;break f}UGb(c[(c[ta>>2]|0)+96>>2]|0,(c[xa>>2]|0)+Wa|0,c[_a>>2]|0)|0}}while(0);va=c[pa>>2]|0;Ta=c[pa+4>>2]|0;xa=2;ab=0;if((va|0)==1&(Ta|0)==0){Ma=c[S+(ma*296|0)+252>>2]|0;La=c[ta>>2]|0;c[La+8>>2]=0;c[La+52>>2]=Xa;if((Ya|0)>-1){c[La+792>>2]=Ya}cb=c[S+(ma*296|0)+128>>2]|0;c[La+120>>2]=cb;db=c[S+(ma*296|0)+136>>2]|0;c[La+124>>2]=db;La=S+(ma*296|0)+112|0;eb=gHb(db,(db|0)<0|0?-1:0,c[La>>2]|0,c[La+4>>2]|0)|0;La=F;db=S+(ma*296|0)+120|0;fb=gHb(cb,(cb|0)<0|0?-1:0,c[db>>2]|0,c[db+4>>2]|0)|0;iFb(ua+80|0,ua+84|0,eb,La,fb,F,255,0)|0;if((c[(c[ta>>2]|0)+48>>2]|0)!=1211250229){c[ua+236>>2]=2}fb=S+(ma*296|0)+64|0;La=c[fb>>2]|0;eb=c[fb+4>>2]|0;do{if(!((La|0)==0&(eb|0)==0)){fb=ua+92|0;db=fb|0;cb=ua+96|0;iFb(db,cb,1e9,0,La,eb,3e4,0)|0;if((c[db>>2]|0)>=((c[cb>>2]|0)*1e3|0|0)){break}cb=fb;fb=ua+412|0;db=c[cb+4>>2]|0;c[fb>>2]=c[cb>>2];c[fb+4>>2]=db}}while(0);eb=S+(ma*296|0)+160|0;La=c[eb>>2]|0;db=c[eb+4>>2]|0;eb=0;if(((La|0)!=0|(db|0)!=0)&(db>>>0<eb>>>0|db>>>0==eb>>>0&La>>>0<15>>>0)){CBb(Sa,2022960,c[1191088+(La<<2)>>2]|0,0)|0}La=S+(ma*296|0)+168|0;if(!((c[La>>2]|0)==0&(c[La+4>>2]|0)==0)){CBb(Sa,2019696,2015512,0)|0}La=S+(ma*296|0)+248|0;if((c[La>>2]|0)>0){gb=0}else{break}do{eb=Ma+(gb<<4)+8|0;db=c[eb>>2]|0;fb=c[eb+4>>2]|0;eb=0;i:do{if(!(fb>>>0>eb>>>0|fb>>>0==eb>>>0&db>>>0>2>>>0)){Lb(R|0,32,2012080,(K=i,i=i+16|0,c[K>>2]=c[1191072+(db<<2)>>2],c[K+8>>2]=ma,K)|0)|0;i=K;cb=c[I>>2]|0;hb=Ma+(gb<<4)|0;ib=0;while(1){if((ib|0)>=(cb|0)){break i}jb=S+(ib*296|0)+8|0;if((c[hb>>2]|0)==(c[jb>>2]|0)&(c[hb+4>>2]|0)==(c[jb+4>>2]|0)){break}else{ib=ib+1|0}}CBb((c[(c[V>>2]|0)+(ib<<2)>>2]|0)+88|0,2022960,R,0)|0}}while(0);gb=gb+1|0;}while((gb|0)<(c[La>>2]|0))}else if((va|0)==(xa|0)&(Ta|0)==(ab|0)){La=c[ta>>2]|0;c[La+8>>2]=1;Ma=La+412|0;c[Ma>>2]=~~+h[S+(ma*296|0)+184>>3];c[La+416>>2]=c[S+(ma*296|0)+200>>2];Sa=La+792|0;if((c[Sa>>2]|0)==0){c[Sa>>2]=c[S+(ma*296|0)+192>>2]}if((c[La+48>>2]|0)!=86018){c[ua+236>>2]=2}Sa=S+(ma*296|0)+88|0;db=c[Sa>>2]|0;eb=c[Sa+4>>2]|0;if((db|0)==0&(eb|0)==0){kb=La}else{c[ha>>2]=1;c[ia>>2]=1e9;c[ja>>2]=1;c[ka>>2]=c[Ma>>2];Ma=KDb(db,eb,n,o)|0;eb=c[ta>>2]|0;c[eb+116>>2]=Ma;kb=eb}eb=S+(ma*296|0)+96|0;Ma=c[eb>>2]|0;db=c[eb+4>>2]|0;if((Ma|0)==0&(db|0)==0){break}c[_>>2]=1;c[X>>2]=1e9;c[Y>>2]=1;c[W>>2]=c[kb+412>>2];eb=KDb(Ma,db,p,q)|0;j0a(kb,eb);break}else{if((Za|0)!=1465275476){if(!((va|0)==17&(Ta|0)==0)){break}eb=c[ta>>2]|0;c[eb+8>>2]=3;db=c[eb+48>>2]|0;if(!((db|0)==94212|(db|0)==1095979808)){break}c[U>>2]=1;break}c[(c[ta>>2]|0)+8>>2]=3;db=c[sa>>2]|0;if((QGb(db,2004088)|0)==0){eb=ua+72|0;c[eb>>2]=c[eb>>2]|65536;break}if((QGb(db,1996576)|0)==0){eb=ua+72|0;c[eb>>2]=c[eb>>2]|131072;break}if((QGb(db,1993360)|0)!=0){break}db=ua+72|0;c[db>>2]=c[db>>2]|262144;break}}else{yDb(c[z>>2]|0,32,2096104,(K=i,i=i+16|0,c[K>>2]=qa,c[K+8>>2]=ra,K)|0);i=K}}while(0);ra=ma+1|0;if((ra|0)<(c[I>>2]|0)){ma=ra}else{break e}}if((M|0)==77){ZDb(Ba);N=-12;i=e;return N|0}else if((M|0)==140){c[S+(ma*296|0)+240>>2]=0;N=-12;i=e;return N|0}else if((M|0)==253){i=e;return N|0}}}while(0);S=c[t+324>>2]|0;I=v;j:do{if((c[I>>2]|0)>0){H=0;do{J=S+(H*40|0)+8|0;do{if((c[J>>2]|0)==0){M=209}else{U=S+(H*40|0)+12|0;if((c[U>>2]|0)==0){M=209;break}W=S+(H*40|0)+20|0;if((c[W>>2]|0)==0){M=209;break}Y=S+(H*40|0)+16|0;if((c[Y>>2]|0)<=0){M=209;break}X=LT(b,0)|0;if((X|0)==0){break j}_=X+88|0;CBb(_,1986208,c[J>>2]|0,0)|0;CBb(_,1982552,c[U>>2]|0,0)|0;_=X+8|0;ka=c[_>>2]|0;c[ka+48>>2]=0;c[ka+8>>2]=4;if((BT(ka,c[Y>>2]|0)|0)!=0){break j}UGb(c[(c[_>>2]|0)+96>>2]|0,c[W>>2]|0,c[Y>>2]|0)|0;Y=0;while(1){lb=c[1185512+(Y*36|0)>>2]|0;if((lb|0)==0){break}W=1185480+(Y*36|0)|0;ka=c[U>>2]|0;if((RGb(W,ka,SGb(W|0)|0)|0)==0){M=215;break}else{Y=Y+1|0}}if((M|0)==215){M=0;c[(c[_>>2]|0)+48>>2]=lb}c[S+(H*40|0)+32>>2]=X}}while(0);if((M|0)==209){M=0;yDb(c[z>>2]|0,16,1989824,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}H=H+1|0;}while((H|0)<(c[I>>2]|0))}}while(0);I=c[t+332>>2]|0;S=w;H=c[S>>2]|0;if((H|0)>0){ma=r|0;J=r+4|0;Y=0;U=0;ua=0;sa=H;while(1){H=I+(Y<<5)|0;ta=c[H>>2]|0;Ta=c[H+4>>2]|0;do{if((ta|0)==0&(Ta|0)==(-2147483648|0)){mb=U;nb=ua;ob=sa}else{va=I+(Y<<5)+16|0;ab=c[va>>2]|0;if((ab|0)==0&(c[va+4>>2]|0)==0){mb=U;nb=ua;ob=sa;break}if(!((ua|0)==0&(U|0)==0|(Ta>>>0>U>>>0|Ta>>>0==U>>>0&ta>>>0>ua>>>0))){mb=U;nb=ua;ob=sa;break}c[ma>>2]=1;c[J>>2]=1e9;va=I+(Y<<5)+8|0;xa=I+(Y<<5)+24|0;W=OT(b,ab,r,ta,Ta,c[va>>2]|0,c[va+4>>2]|0,c[xa>>2]|0)|0;c[I+(Y<<5)+28>>2]=W;CBb(W+32|0,2117640,c[xa>>2]|0,0)|0;mb=c[H+4>>2]|0;nb=c[H>>2]|0;ob=c[S>>2]|0}}while(0);H=Y+1|0;if((H|0)<(ob|0)){Y=H;U=mb;ua=nb;sa=ob}else{break}}}tG(u);sa=c[s>>2]|0;ua=c[sa+348>>2]|0;U=sa+344|0;if((c[U>>2]|0)<=0){N=0;i=e;return N|0}Y=sa+316|0;S=sa+312|0;I=sa+332|0;J=sa+328|0;ma=sa+324|0;H=sa+320|0;sa=0;while(1){Ta=ua+(sa*48|0)+32|0;ta=c[Ta>>2]|0;xa=c[Ta+4>>2]|0;k:do{if((ta|0)==0&(xa|0)==0){W=ua+(sa*48|0)+24|0;va=c[W>>2]|0;ab=c[W+4>>2]|0;if(!((va|0)==0&(ab|0)==0)){ka=c[I>>2]|0;ja=c[J>>2]|0;if((ja|0)<=0){break}ia=ua+(sa*48|0)+40|0;ha=0;R=ja;ja=ab;ab=va;while(1){va=ka+(ha<<5)+16|0;do{if((c[va>>2]|0)==(ab|0)&(c[va+4>>2]|0)==(ja|0)){V=c[ka+(ha<<5)+28>>2]|0;if((V|0)==0){pb=R;break}uG(b,ia,V+32|0,0);pb=c[J>>2]|0}else{pb=R}}while(0);va=ha+1|0;if((va|0)>=(pb|0)){break k}ha=va;R=pb;ja=c[W+4>>2]|0;ab=c[W>>2]|0}}W=ua+(sa*48|0)+16|0;ab=c[W>>2]|0;ja=c[W+4>>2]|0;if((ab|0)==0&(ja|0)==0){uG(b,ua+(sa*48|0)+40|0,G,c[ua+(sa*48|0)>>2]|0);break}R=c[Y>>2]|0;ha=c[S>>2]|0;if((ha|0)<=0){break}ia=ua+(sa*48|0)+40|0;ka=0;va=ha;ha=ja;ja=ab;while(1){ab=R+(ka*296|0)+8|0;do{if((c[ab>>2]|0)==(ja|0)&(c[ab+4>>2]|0)==(ha|0)){X=c[R+(ka*296|0)+264>>2]|0;if((X|0)==0){qb=va;break}uG(b,ia,X+88|0,0);qb=c[S>>2]|0}else{qb=va}}while(0);ab=ka+1|0;if((ab|0)>=(qb|0)){break k}ka=ab;va=qb;ha=c[W+4>>2]|0;ja=c[W>>2]|0}}else{W=c[ma>>2]|0;ja=c[H>>2]|0;if((ja|0)<=0){break}ha=ua+(sa*48|0)+40|0;va=0;ka=ja;ja=xa;ia=ta;while(1){R=W+(va*40|0)|0;do{if((c[R>>2]|0)==(ia|0)&(c[R+4>>2]|0)==(ja|0)){ab=c[W+(va*40|0)+32>>2]|0;if((ab|0)==0){rb=ka;break}uG(b,ha,ab+88|0,0);rb=c[H>>2]|0}else{rb=ka}}while(0);R=va+1|0;if((R|0)>=(rb|0)){break k}va=R;ka=rb;ja=c[Ta+4>>2]|0;ia=c[Ta>>2]|0}}}while(0);Ta=sa+1|0;if((Ta|0)<(c[U>>2]|0)){sa=Ta}else{N=0;break}}i=e;return N|0}}while(0);rb=c[j+24>>2]|0;b=j+32|0;j=c[b>>2]|0;qb=c[b+4>>2]|0;yDb(c[z>>2]|0,16,2129136,(K=i,i=i+40|0,c[K>>2]=C,c[K+8>>2]=D,c[K+16>>2]=rb,c[K+24>>2]=j,c[K+32>>2]=qb,K)|0);i=K;oG(1344192,y);N=-1163346256;i=e;return N|0}function iG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[a+12>>2]|0;a=d;e=d+372|0;a:do{if((c[e>>2]|0)<=0){f=d;g=d+380|0;h=d+268|0;i=d+4|0;while(1){j=Ty(c[(c[f>>2]|0)+16>>2]|0,0,0,1)|0;k=F;if((c[g>>2]|0)!=0){l=-541478725;break}b:do{if((lG(a)|0)<0){m=c[(c[f>>2]|0)+16>>2]|0;c[h>>2]=0;c[i>>2]=0;n=YGb(j,k,1,0)|0;o=Ty(m,n,F,0)|0;n=F;p=0;c:do{if(!((n|0)<(p|0)|(n|0)==(p|0)&o>>>0<0>>>0)){q=vz(m)|0;if((Xy(m)|0)==0){r=q}else{break}while(1){if((r|0)==524531317|(r|0)==475249515|(r|0)==423732329|(r|0)==374648427|(r|0)==357149030|(r|0)==307544935|(r|0)==290298740|(r|0)==272869232){break}q=lz(m)|0|r<<8;if((Xy(m)|0)==0){r=q}else{break c}}c[h>>2]=r;break b}}while(0);c[g>>2]=1}}while(0);if((c[e>>2]|0)>0){break a}}return l|0}}while(0);r=d+368|0;a=r;UGb(b|0,c[c[a>>2]>>2]|0,80)|0;ZDb(c[c[a>>2]>>2]|0);b=c[e>>2]|0;do{if((b|0)>1){g=c[a>>2]|0;VGb(g|0,g+4|0,(b<<2)-4|0)|0;g=XDb(c[a>>2]|0,(c[e>>2]<<2)-4|0)|0;if((g|0)==0){break}c[a>>2]=g}else{$Db(r);c[d+376>>2]=0}}while(0);c[e>>2]=(c[e>>2]|0)-1;l=0;return l|0}function jG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+12>>2]|0;a=b+312|0;d=c[b+316>>2]|0;c[b+376>>2]=0;e=b+368|0;f=e;g=c[f>>2]|0;if((g|0)!=0){h=b+372|0;do{if((c[h>>2]|0)>0){BZ(c[g>>2]|0);ZDb(c[c[f>>2]>>2]|0);if((c[h>>2]|0)>1){i=1}else{break}do{BZ(c[(c[f>>2]|0)+(i<<2)>>2]|0);ZDb(c[(c[f>>2]|0)+(i<<2)>>2]|0);i=i+1|0;}while((i|0)<(c[h>>2]|0))}}while(0);$Db(e);c[h>>2]=0}h=a;a=c[h>>2]|0;if((a|0)>0){j=0;k=a}else{l=b+416|0;oG(683464,l);oG(681952,b);return 0}while(1){a=d+(j*296|0)+16|0;if((c[a>>2]|0)==2&(c[a+4>>2]|0)==0){ZDb(c[d+(j*296|0)+240>>2]|0);m=c[h>>2]|0}else{m=k}a=j+1|0;if((a|0)<(m|0)){j=a;k=m}else{break}}l=b+416|0;oG(683464,l);oG(681952,b);return 0}function kG(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=c[a+12>>2]|0;h=g;i=g+312|0;j=c[g+316>>2]|0;k=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=g+400|0;if((c[b>>2]|0)>0){c[b>>2]=0;l=c[g+356>>2]|0;m=c[g+352>>2]|0;n=0;while(1){if((n|0)>=(m|0)){break}o=l+(n<<4)|0;if((c[o>>2]|0)==475249515&(c[o+4>>2]|0)==0){break}else{n=n+1|0}}if((sG(h,n)|0)<0){c[b>>2]=-1}tG(h)}n=k+404|0;do{if((c[n>>2]|0)==0){l=g+368|0;p=g+376|0;q=l;r=l}else{l=k+400|0;m=(c[l>>2]|0)+8|0;o=c[m>>2]|0;s=c[m+4>>2]|0;m=(s|0)<(e|0)|(s|0)==(e|0)&o>>>0<d>>>0;t=m?d:o;o=m?e:s;s=oT(k,t,o,f)|0;a:do{if((s|0)<0){m=(c[l>>2]|0)+(((c[n>>2]|0)-1|0)*24|0)|0;Ty(c[a+16>>2]|0,c[m>>2]|0,c[m+4>>2]|0,0)|0;c[g+268>>2]=0;m=g+376|0;u=g+368|0;v=u;w=g+372|0;while(1){x=oT(k,t,o,f)|0;if((x|0)>=0){y=x;z=m;A=u;B=v;break a}c[m>>2]=0;C=c[v>>2]|0;if((C|0)!=0){do{if((c[w>>2]|0)>0){BZ(c[C>>2]|0);ZDb(c[c[v>>2]>>2]|0);if((c[w>>2]|0)>1){D=1}else{break}do{BZ(c[(c[v>>2]|0)+(D<<2)>>2]|0);ZDb(c[(c[v>>2]|0)+(D<<2)>>2]|0);D=D+1|0;}while((D|0)<(c[w>>2]|0))}}while(0);$Db(u);c[w>>2]=0}if((lG(h)|0)<0){y=x;z=m;A=u;B=v;break}}}else{v=g+368|0;y=s;z=g+376|0;A=v;B=v}}while(0);c[z>>2]=0;s=c[B>>2]|0;if((s|0)!=0){v=g+372|0;do{if((c[v>>2]|0)>0){BZ(c[s>>2]|0);ZDb(c[c[B>>2]>>2]|0);if((c[v>>2]|0)>1){E=1}else{break}do{BZ(c[(c[B>>2]|0)+(E<<2)>>2]|0);ZDb(c[(c[B>>2]|0)+(E<<2)>>2]|0);E=E+1|0;}while((E|0)<(c[v>>2]|0))}}while(0);$Db(A);c[v>>2]=0}if((y|0)<0){p=z;q=A;r=B;break}if((c[b>>2]|0)<0){if((y|0)==((c[n>>2]|0)-1|0)){p=z;q=A;r=B;break}}s=i;if((c[s>>2]|0)>0){u=g+272|0;m=0;w=y;while(1){c[j+(m*296|0)+228>>2]=0;c[j+(m*296|0)+224>>2]=0;C=j+(m*296|0)+232|0;c[C>>2]=0;c[C+4>>2]=-2147483648;C=j+(m*296|0)+272|0;c[C>>2]=0;c[C+4>>2]=0;C=j+(m*296|0)+16|0;b:do{if((c[C>>2]|0)==17&(c[C+4>>2]|0)==0){G=j+(m*296|0)+264|0;H=c[G>>2]|0;if((c[H+76>>2]|0)==48){I=w;break}J=(c[l>>2]|0)+(y*24|0)+8|0;K=oT(H,c[J>>2]|0,c[J+4>>2]|0,1)|0;J=w;while(1){if(!((J|K|0)>-1)){I=J;break b}H=c[(c[G>>2]|0)+400>>2]|0;L=H+(K*24|0)|0;M=c[L+4>>2]|0;N=c[l>>2]|0;O=N+(J*24|0)|0;P=c[O+4>>2]|0;if(!((M|0)<(P|0)|(M|0)==(P|0)&(c[L>>2]|0)>>>0<(c[O>>2]|0)>>>0)){I=J;break b}O=N+(y*24|0)+8|0;N=H+(K*24|0)+8|0;H=ZGb(c[O>>2]|0,c[O+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;N=F;O=hHb(-64771072,6,c[u>>2]|0,c[u+4>>2]|0)|0;L=F;if(N>>>0<L>>>0|N>>>0==L>>>0&H>>>0<O>>>0){J=J-1|0}else{I=J;break}}}else{I=w}}while(0);C=m+1|0;if((C|0)<(c[s>>2]|0)){m=C;w=I}else{Q=I;break}}}else{Q=y}w=(c[l>>2]|0)+(Q*24|0)|0;Ty(c[a+16>>2]|0,c[w>>2]|0,c[w+4>>2]|0,0)|0;c[g+268>>2]=0;w=k+444|0;if((f&4|0)==0){c[w>>2]=1;m=c[l>>2]|0;s=m+(y*24|0)+8|0;u=c[s+4>>2]|0;v=g+392|0;c[v>>2]=c[s>>2];c[v+4>>2]=u;R=m}else{c[w>>2]=0;w=g+392|0;c[w>>2]=t;c[w+4>>2]=o;R=c[l>>2]|0}c[g+384>>2]=1;c[g+380>>2]=0;c[g+4>>2]=0;w=R+(y*24|0)+8|0;lT(a,k,c[w>>2]|0,c[w+4>>2]|0);S=0;return S|0}}while(0);c[p>>2]=0;p=c[r>>2]|0;if((p|0)!=0){a=g+372|0;do{if((c[a>>2]|0)>0){BZ(c[p>>2]|0);ZDb(c[c[r>>2]>>2]|0);if((c[a>>2]|0)>1){T=1}else{break}do{BZ(c[(c[r>>2]|0)+(T<<2)>>2]|0);ZDb(c[(c[r>>2]|0)+(T<<2)>>2]|0);T=T+1|0;}while((T|0)<(c[a>>2]|0))}}while(0);$Db(q);c[a>>2]=0}c[g+268>>2]=0;c[g+384>>2]=0;c[k+444>>2]=0;c[g+380>>2]=0;c[g+4>>2]=0;S=-1;return S|0}function lG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+16|0;d=b|0;e=d;TGb(e|0,0,16)|0;if((c[a+432>>2]|0)!=0){f=Ty(c[(c[a>>2]|0)+16>>2]|0,0,0,1)|0;g=F;c[a+376>>2]=0;h=(c[a+268>>2]|0)==0;j=YGb(f,g,-4,-1)|0;k=h?f:j;j=h?g:F;g=mG(a,682912,e)|0;h=c[d+12>>2]|0;f=d+8|0;l=c[f>>2]|0;if((l|0)>0){m=d|0;d=0;n=g;o=l;while(1){l=c[h+(d*72|0)+24>>2]|0;do{if((l|0)>0){p=c[h+(d*72|0)+28>>2]|0;if((p|0)==0){q=n;r=o;break}s=h+(d*72|0)+16|0;if((c[s>>2]|0)==0&(c[s+4>>2]|0)==0){t=-1}else{s=h+(d*72|0)+8|0;t=(c[s>>2]|0)==0&(c[s+4>>2]|0)==0&1}s=h+(d*72|0)+32|0;u=h+(d*72|0)|0;v=h+(d*72|0)+64|0;w=nG(a,p,l,c[s>>2]|0,c[s+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0,t,0,0,0,0,k,j,c[v>>2]|0,c[v+4>>2]|0)|0;q=w;r=c[f>>2]|0}else{q=n;r=o}}while(0);l=d+1|0;if((l|0)<(r|0)){d=l;n=q;o=r}else{x=q;break}}}else{x=g}oG(683464,e);y=x;i=b;return y|0}x=a+416|0;e=x;g=mG(a,683056,e)|0;do{if((g|0)==1){q=a+408|0;r=a|0;do{if(!((c[q>>2]|0)==0&(c[q+4>>2]|0)==0)){o=Ty(c[(c[r>>2]|0)+16>>2]|0,0,0,1)|0;n=a+4|0;d=c[n>>2]|0;if((d|0)<=0){break}f=d-1|0;d=a+8+(f<<4)|0;j=ZGb(o,F,c[d>>2]|0,c[d+4>>2]|0)|0;d=F;o=a+8+(f<<4)+8|0;k=c[o+4>>2]|0;if(d>>>0<k>>>0|d>>>0==k>>>0&j>>>0<(c[o>>2]|0)>>>0){if((c[a+268>>2]|0)==0){break}}c[n>>2]=f}}while(0);oG(683464,e);TGb(e|0,0,16)|0;c[a+404>>2]=0;f=Ty(c[(c[r>>2]|0)+16>>2]|0,0,0,1)|0;n=F;c[q>>2]=f;c[q+4>>2]=n;c[a+376>>2]=0;if((c[a+268>>2]|0)!=0){o=YGb(f,n,-4,-1)|0;c[q>>2]=o;c[q+4>>2]=F}o=mG(a,682768,e)|0;if((o|0)!=1){z=o;break}z=mG(a,683056,e)|0}else{z=g}}while(0);if((z|0)!=0){y=z;i=b;return y|0}z=a+404|0;g=c[a+424>>2]|0;if((c[z>>2]|0)>=(g|0)){y=0;i=b;return y|0}e=c[a+428>>2]|0;c[z>>2]=g;z=g-1|0;g=c[e+(z*72|0)+24>>2]|0;if((g|0)<=0){y=0;i=b;return y|0}o=c[e+(z*72|0)+28>>2]|0;if((o|0)==0){y=0;i=b;return y|0}n=e+(z*72|0)+16|0;f=(c[n>>2]|0)==0&(c[n+4>>2]|0)==0;if(f){A=-1}else{n=e+(z*72|0)+8|0;A=(c[n>>2]|0)==0&(c[n+4>>2]|0)==0&1}n=c[e+(z*72|0)+48>>2]|0;if((n|0)>0){B=c[e+(z*72|0)+52>>2]|0}else{B=0}j=e+(z*72|0)|0;if(f){c[j>>2]=0;c[j+4>>2]=0;C=0;D=0}else{C=c[j+4>>2]|0;D=c[j>>2]|0}j=e+(z*72|0)+32|0;f=x|0;x=e+(z*72|0)+40|0;k=a+408|0;d=e+(z*72|0)+64|0;y=nG(a,o,g,c[j>>2]|0,c[j+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0,D,C,A,B,c[x>>2]|0,c[x+4>>2]|0,n,c[k>>2]|0,c[k+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0;i=b;return y|0}function mG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+8|0;f=e|0;g=a+268|0;h=c[g>>2]|0;do{if((h|0)==0){j=qG(a,c[(c[a>>2]|0)+16>>2]|0,4,f)|0;if((j|0)<0){k=j;i=e;return k|0}else{l=c[f>>2]|1<<(j*7|0);c[g>>2]=l;m=l;break}}else{m=h}}while(0);h=0;while(1){n=b+(h*24|0)|0;g=c[n>>2]|0;o=(g|0)==0;if(o|(g|0)==(m|0)){break}else{h=h+1|0}}do{if(o&(m|0)==524531317){h=c[a+4>>2]|0;if((h|0)<=0){break}b=a+8+(h-1<<4)+8|0;if((c[b>>2]|0)==(-1|0)&(c[b+4>>2]|0)==16777215){k=0}else{break}i=e;return k|0}}while(0);do{if(o){if((m|0)==236|(m|0)==191){break}b=a|0;yDb(c[b>>2]|0,32,2204376,(h=i,i=i+8|0,c[h>>2]=m,h)|0);i=h;if((c[(c[b>>2]|0)+1156>>2]&8|0)==0){break}else{k=-1094995529}i=e;return k|0}}while(0);k=rG(a,n,d)|0;i=e;return k|0}function nG(b,e,f,g,j,k,l,m,n,o,p,q,r,s,t,u,v,w){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;w=w|0;var y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0;y=i;i=i+448|0;z=y|0;A=y+128|0;B=y+136|0;C=y+264|0;D=y+272|0;E=y+280|0;G=y+288|0;H=y+296|0;I=y+304|0;J=y+312|0;K=y+440|0;Ny(J,e,f,0,0,0,0,0)|0;L=qG(b,J,f>>>0>8>>>0?8:f,K)|0;if((L|0)<0){yDb(c[b>>2]|0,16,2142424,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=L;i=y;return N|0}J=e+L|0;O=f-L|0;f=c[K>>2]|0;P=c[K+4>>2]|0;K=f;Q=c[b+316>>2]|0;R=c[b+312>>2]|0;S=K;T=(K|0)<0|0?-1:0;U=0;while(1){if((U|0)>=(R|0)){V=6;break}W=Q+(U*296|0)|0;X=W|0;if((c[X>>2]|0)==(S|0)&(c[X+4>>2]|0)==(T|0)){V=7;break}else{U=U+1|0}}do{if((V|0)==6){yDb(c[b>>2]|0,16,2236272,(M=i,i=i+8|0,c[M>>2]=K,M)|0);i=M}else if((V|0)==7){if((W|0)==0){break}T=Q+(U*296|0)+264|0;S=c[T>>2]|0;if((S|0)==0){break}if((O|0)<4){N=0;i=y;return N|0}if((c[S+76>>2]|0)>47){N=0;i=y;return N|0}R=J;X=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=e+(L+3)|0;Y=d[e+(L+2)|0]|0;Z=O-3|0;_=(o|0)==-1?Y>>>7:o;$=(k|0)!=(-1|0)|(l|0)!=(-1|0);do{if($){if(!(X<<16>>16>-1)){aa=-(X<<16>>16)|0;ca=(aa|0)<0|0?-1:0;if(ca>>>0>l>>>0|ca>>>0==l>>>0&aa>>>0>k>>>0){da=_;ea=-2147483648;fa=0;break}}aa=YGb(X<<16>>16,X<<16>>16<0|0?-1:0,k,l)|0;ca=F;ga=Q+(U*296|0)+16|0;if((c[ga>>2]|0)==17&(c[ga+4>>2]|0)==0){ga=Q+(U*296|0)+272|0;ha=c[ga+4>>2]|0;ia=ca>>>0<ha>>>0|ca>>>0==ha>>>0&aa>>>0<(c[ga>>2]|0)>>>0?0:_}else{ia=_}if((ia|0)==0){da=0;ea=ca;fa=aa;break}jT(S,t,u,aa,ca,0,0,1)|0;da=ia;ea=ca;fa=aa}else{da=_;ea=-2147483648;fa=0}}while(0);_=b+384|0;do{if((c[_>>2]|0)!=0){aa=Q+(U*296|0)+16|0;if((c[aa>>2]|0)==17&(c[aa+4>>2]|0)==0){break}aa=b+392|0;ca=c[aa+4>>2]|0;if(ea>>>0<ca>>>0|ea>>>0==ca>>>0&fa>>>0<(c[aa>>2]|0)>>>0){N=0;i=y;return N|0}if((da|0)!=0){c[_>>2]=0;break}if((c[S+444>>2]|0)!=0){break}yDb(c[b>>2]|0,16,2027120,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;c[_>>2]=0}}while(0);_=Y>>>1&3;a:do{if((_|0)==0){aa=cEb(4)|0;ca=aa;if((aa|0)==0){ja=-12;ka=ca;break}c[ca>>2]=Z;la=R;ma=Z;na=ca;oa=1;V=56}else{if((Z|0)<=0){yDb(0,0,2279784,(M=i,i=i+24|0,c[M>>2]=2264624,c[M+8>>2]=2249584,c[M+16>>2]=2080,M)|0);i=M;Cd();return 0}ca=a[R]|0;aa=ca&255;ga=aa+1|0;ha=L+4|0;pa=e+ha|0;qa=O-4|0;ra=cEb(ga<<2)|0;sa=ra;if((ra|0)==0){ja=-12;ka=0;break}b:do{if((_|0)==1){c:do{if(ca<<24>>24==0){ta=qa;ua=pa;va=0;wa=0;xa=0}else{ra=0;ya=0;za=pa;Aa=qa;d:while(1){Ba=sa+(ya<<2)|0;Ca=ra;Da=za;Ea=Aa;while(1){if(!(Ea>>>0>Ca>>>0)){break d}Fa=a[Da]|0;Ga=Fa&255;Ha=Ga+Ca|0;c[Ba>>2]=(c[Ba>>2]|0)+Ga;Ia=Da+1|0;Ja=Ea-1|0;if(Fa<<24>>24==-1){Ca=Ha;Da=Ia;Ea=Ja}else{break}}Ba=ya+1|0;if((Ba|0)<(aa|0)){ra=Ha;ya=Ba;za=Ia;Aa=Ja}else{ta=Ja;ua=Ia;va=Ba;wa=0;xa=Ha;break c}}ta=Ea;ua=Da;va=ya+1|0;wa=-1094995529;xa=Ca}}while(0);if(!(ta>>>0>xa>>>0)){ja=-1094995529;ka=sa;break a}c[sa+(va<<2)>>2]=ta-xa;Ka=wa;La=ta;Ma=ua}else if((_|0)==2){if(((qa|0)%(ga|0)|0|0)!=0){ja=-1094995529;ka=sa;break a}Aa=(qa|0)/(ga|0)|0;za=0;while(1){c[sa+(za<<2)>>2]=Aa;ra=za+1|0;if((ra|0)<(ga|0)){za=ra}else{la=pa;ma=qa;na=sa;oa=ga;V=56;break a}}}else if((_|0)==3){Ny(B,pa,qa,0,0,0,0,0)|0;za=qG(b,B,qa>>>0>8>>>0?8:qa,C)|0;Aa=(za|0)<0;do{if(!Aa){ra=c[C>>2]|0;Ba=c[C+4>>2]|0;Fa=0;if(Ba>>>0>Fa>>>0|Ba>>>0==Fa>>>0&ra>>>0>2147483647>>>0){break}Fa=e+(ha+za)|0;Ga=qa-za|0;c[sa>>2]=ra;Na=ra|0;ra=Ba&0;e:do{if((ca&255)>>>0>1>>>0){Ba=Ga;Oa=Fa;Pa=1;Qa=ra;Ra=Na;while(1){Ny(z,Oa,Ba,0,0,0,0,0)|0;Sa=qG(b,z,Ba>>>0>8>>>0?8:Ba,A)|0;if((Sa|0)<0){Ta=Sa;break}Ua=c[A>>2]|0;Va=c[A+4>>2]|0;Wa=_Gb(-1|0,-1|0,(Sa*7|0)-1|0)|0;Xa=YGb(Wa,F,1,0)|0;Wa=YGb(Xa,F,Ua,Va)|0;Va=YGb(Wa,F,c[sa+(Pa-1<<2)>>2]|0,0)|0;Wa=F;Ua=0;if(Wa>>>0>Ua>>>0|Wa>>>0==Ua>>>0&Va>>>0>2147483647>>>0){Ta=-1094995529;break}Ua=Oa+Sa|0;Xa=Ba-Sa|0;c[sa+(Pa<<2)>>2]=Va;Sa=YGb(Va|0,Wa&0,Ra,Qa)|0;Wa=F;Va=Pa+1|0;if((Va|0)<(aa|0)){Ba=Xa;Oa=Ua;Pa=Va;Qa=Wa;Ra=Sa}else{Ya=0;Za=Xa;_a=Ua;$a=Wa;ab=Sa;break e}}yDb(c[b>>2]|0,32,2142424,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;Ya=Ta;Za=Ba;_a=Oa;$a=Qa;ab=Ra}else{Ya=0;Za=Ga;_a=Fa;$a=ra;ab=Na}}while(0);Na=Za;ra=(Za|0)<0|0?-1:0;if(!(ra>>>0>$a>>>0|ra>>>0==$a>>>0&Na>>>0>ab>>>0)){ja=-1094995529;ka=sa;break a}Fa=ZGb(Na,ra,ab,$a)|0;c[sa+(aa<<2)>>2]=Fa;Ka=Ya;La=Za;Ma=_a;break b}}while(0);yDb(c[b>>2]|0,32,2142424,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;Ka=Aa?za:-1094995529;La=qa;Ma=pa}else{la=pa;ma=qa;na=sa;oa=ga;V=56;break a}}while(0);if((Ka|0)==0){la=Ma;ma=La;na=sa;oa=ga;V=56}else{ja=Ka;ka=sa}}}while(0);f:do{if((V|0)==56){bb=+h[Q+(U*296|0)+176>>3];do{if(bb==8.0e3){_=c[S+8>>2]|0;if((c[_+48>>2]|0)!=86019){V=60;break}if(bb!=+(c[_+412>>2]|0)){cb=n;db=m;break}if((c[_+424>>2]|0)!=0&((m|0)==0&(n|0)==0)){V=61}else{cb=n;db=m}}else{V=60}}while(0);if((V|0)==60){if((m|0)==0&(n|0)==0){V=61}else{cb=n;db=m}}if((V|0)==61){sa=Q+(U*296|0)+64|0;ga=gHb(c[sa>>2]|0,c[sa+4>>2]|0,oa,(oa|0)<0|0?-1:0)|0;sa=b+272|0;_=hHb(ga,F,c[sa>>2]|0,c[sa+4>>2]|0)|0;cb=F;db=_}do{if($){if(!(X<<16>>16>-1)){_=-(X<<16>>16)|0;sa=(_|0)<0|0?-1:0;if(sa>>>0>l>>>0|sa>>>0==l>>>0&_>>>0>k>>>0){break}}_=Q+(U*296|0)+272|0;sa=c[_>>2]|0;ga=c[_+4>>2]|0;R=YGb(db,cb,fa,ea)|0;Z=F;Y=ga>>>0>Z>>>0|ga>>>0==Z>>>0&sa>>>0>R>>>0;c[_>>2]=Y?sa:R;c[_+4>>2]=Y?ga:Z}}while(0);Z=oa;ga=(oa|0)<0|0?-1:0;Y=S+8|0;_=S|0;R=b+368|0;sa=b+372|0;qa=b+376|0;pa=G;aa=Q+(U*296|0)+260|0;ca=D;ha=b|0;Fa=(s|0)>0;ra=s+8|0;Na=fe(q|0)|0;Ga=fe(r|0)|0;ya=Na|0;Na=(v|0)==0&(w|0)==0;Pa=Q+(U*296|0)+280|0;Sa=Q+(U*296|0)+16|0;Wa=b+272|0;Ua=H|0;Xa=H+4|0;Va=I|0;eb=I+4|0;fb=Q+(U*296|0)+220|0;gb=Q+(U*296|0)+208|0;hb=Q+(U*296|0)+212|0;ib=Q+(U*296|0)+224|0;jb=Q+(U*296|0)+216|0;kb=Q+(U*296|0)+228|0;lb=Q+(U*296|0)+232|0;mb=Q+(U*296|0)+240|0;nb=la;ob=ma;pb=ea;qb=fa;rb=0;g:while(1){sb=rb+1|0;tb=gHb(sb,(sb|0)<0|0?-1:0,db,cb)|0;ub=hHb(tb,F,Z,ga)|0;tb=F;vb=gHb(rb,(rb|0)<0|0?-1:0,db,cb)|0;wb=hHb(vb,F,Z,ga)|0;vb=F;xb=ZGb(ub,tb,wb,vb)|0;yb=F;zb=na+(rb<<2)|0;Ab=c[zb>>2]|0;if(Ab>>>0>ob>>>0){V=68;break}Bb=c[Y>>2]|0;Cb=c[Bb+48>>2]|0;do{if((Cb|0)==1465275476){V=101}else if((Cb|0)==77825|(Cb|0)==86036|(Cb|0)==86058|(Cb|0)==86047){Db=c[Bb+432>>2]|0;if((Db|0)==0){V=129;break}Eb=c[fb>>2]|0;if((Eb|0)==0){if((Cb|0)==1465275476){V=101;break}else{V=129;break}}Fb=c[gb>>2]|0;Gb=c[hb>>2]|0;Hb=c[ib>>2]|0;Ib=c[jb>>2]|0;do{if((c[kb>>2]|0)==0){if((Hb|0)==0){c[lb>>2]=qb;c[lb+4>>2]=pb}do{if((Cb|0)==77825){if(((ba(Gb,Fb)|0)/2|0|0)>(Ab|0)){V=79;break g}Jb=(Gb|0)/2|0;if((Gb|0)<=1){break}Kb=Ib<<1;Mb=ba(Hb,Fb)|0;Nb=0;do{UGb((c[mb>>2]|0)+((ba(Kb,Nb)|0)+Mb)|0,nb+(ba(Nb,Fb)|0)|0,Fb)|0;Nb=Nb+1|0;}while((Nb|0)<(Jb|0))}else if((Cb|0)==86058){if((Ib|0)>(Ab|0)){V=82;break g}UGb((c[mb>>2]|0)+(ba(Ib,Hb)|0)|0,nb|0,Ib)|0}else{if((Ib|0)>(Ab|0)|(Gb|0)<1){V=88;break g}if(((Ib|0)%(Eb|0)|0|0)!=0){V=88;break g}Jb=(Ib|0)/(Eb|0)|0;if((Jb|0)<=0){break}Nb=(((Gb+1|0)/2|0)&-(Hb&1))+(Hb>>1)|0;Mb=0;do{UGb((c[mb>>2]|0)+(ba(Nb+(ba(Mb,Gb)|0)|0,Eb)|0)|0,nb+(ba(Mb,Eb)|0)|0,Eb)|0;Mb=Mb+1|0;}while((Mb|0)<(Jb|0))}}while(0);Ra=(c[ib>>2]|0)+1|0;c[ib>>2]=Ra;if((Ra|0)<(Gb|0)){V=94;break}if((c[(c[Y>>2]|0)+48>>2]|0)==86058){gP(c[mb>>2]|0,Gb,Ib)}c[ib>>2]=0;Ra=(ba(Ib,Gb)|0)/(Db|0)|0;c[kb>>2]=Ra;Ob=Ra;V=95}else{V=96}}while(0);while(1){if((V|0)==94){V=0;Ob=c[kb>>2]|0;V=95;continue}else if((V|0)==95){V=0;if((Ob|0)==0){break}else{V=96;continue}}else if((V|0)==96){V=0;Eb=cEb(80)|0;if((Eb|0)==0){Pb=0;V=98;break g}if((wZ(Eb,Db)|0)<0){Pb=Eb;V=98;break g}Hb=c[Eb+24>>2]|0;Fb=c[mb>>2]|0;Ra=(ba(Ib,Gb)|0)/(Db|0)|0;Qa=c[kb>>2]|0;c[kb>>2]=Qa-1;UGb(Hb|0,Fb+(ba(Ra-Qa|0,Db)|0)|0,Db)|0;Qa=c[lb+4>>2]|0;Ra=Eb+8|0;c[Ra>>2]=c[lb>>2];c[Ra+4>>2]=Qa;c[lb>>2]=0;c[lb+4>>2]=-2147483648;Qa=Eb+64|0;c[Qa>>2]=g;c[Qa+4>>2]=j;c[Eb+32>>2]=c[_>>2];gEb(R,sa,Eb);V=94;continue}}}else{V=129}}while(0);if((V|0)==101){V=0;if((Ab|0)<1){ja=-1094995529;ka=na;break f}Cb=nb+Ab|0;Bb=nb;while(1){Qb=a[Bb]|0;if((Qb<<24>>24|0)==13|(Qb<<24>>24|0)==10){V=104;break}za=Bb+1|0;if(za>>>0<Cb>>>0){Bb=za}else{Rb=-1;Sb=za;break}}if((V|0)==104){V=0;Rb=Bb-nb|0;Sb=Qb<<24>>24==13?Bb+1|0:Bb}if(!(Sb>>>0<Cb>>>0)){ja=-1094995529;ka=na;break f}if((a[Sb]|0)!=10){ja=-1094995529;ka=na;break f}za=Sb+1|0;h:do{if(za>>>0<Cb>>>0){Aa=za;while(1){Tb=a[Aa]|0;if((Tb<<24>>24|0)==13|(Tb<<24>>24|0)==10){break}Db=Aa+1|0;if(Db>>>0<Cb>>>0){Aa=Db}else{Ub=-1;Vb=Db;break h}}Ub=Aa-za|0;Vb=Tb<<24>>24==13?Aa+1|0:Aa}else{Ub=-1;Vb=za}}while(0);if(!(Vb>>>0<Cb>>>0)){ja=-1094995529;ka=na;break f}if((a[Vb]|0)!=10){ja=-1094995529;ka=na;break f}Bb=Vb+1|0;Db=Cb-Bb|0;if((Db|0)>0){Wb=Db}else{ja=-1094995529;ka=na;break f}while(1){Db=Wb-1|0;Gb=a[Vb+Wb|0]|0;if(!((Gb<<24>>24|0)==13|(Gb<<24>>24|0)==10)){break}if((Db|0)>0){Wb=Db}else{ja=-1094995529;ka=na;break f}}if((Wb|0)<1){ja=-1094995529;ka=na;break f}Xb=cEb(80)|0;Cb=Xb;Yb=wZ(Cb,Wb)|0;if((Yb|0)<0){V=128;break}UGb(c[Xb+24>>2]|0,Bb|0,Wb)|0;if((Rb|0)>0){Db=GZ(Cb,75,Rb)|0;if((Db|0)==0){V=121;break}UGb(Db|0,nb|0,Rb)|0}if((Ub|0)>0){Db=GZ(Cb,76,Ub)|0;if((Db|0)==0){V=125;break}UGb(Db|0,za|0,Ub)|0}c[Xb+32>>2]=c[_>>2];Db=Xb+8|0;c[Db>>2]=qb;c[Db+4>>2]=pb;c[Xb+48>>2]=xb;Db=Xb+64|0;c[Db>>2]=g;c[Db+4>>2]=j;gEb(R,sa,Xb);c[qa>>2]=Cb}else if((V|0)==129){V=0;Cb=(rb|0)!=0?0:da;c[E>>2]=Ab;Db=c[aa>>2]|0;c[G>>2]=nb;do{if((Db|0)==0){V=133}else{Gb=Db+8|0;if(!((c[Gb>>2]|0)==0&(c[Gb+4>>2]|0)==0)){V=133;break}Gb=Db;if((c[Gb>>2]&1|0)==0&(c[Gb+4>>2]&0|0)==0){V=133;break}Gb=pG(G,E,Db)|0;if((Gb|0)<0){Zb=Gb}else{V=133}}}while(0);i:do{if((V|0)==133){V=0;Db=c[(c[Y>>2]|0)+48>>2]|0;j:do{if((Db|0)==86041){Ab=c[G>>2]|0;c[D>>2]=0;za=c[E>>2]|0;k:do{if((za|0)<12){_b=-1094995529}else{Bb=c[(c[T>>2]|0)+8>>2]|0;if((c[Bb+100>>2]|0)<2){_b=-1094995529;break}Gb=c[Bb+96>>2]|0;Bb=(d[Gb]|d[Gb+1|0]<<8)<<16>>16;Gb=Ab;Ib=d[Gb]|d[Gb+1|0]<<8|d[Gb+2|0]<<16|d[Gb+3|0]<<24|0;Gb=za-4|0;do{if((Gb|0)>7){Eb=0;Qa=Gb;Ra=0;Fb=Ab+4|0;while(1){Hb=Fb;Oa=d[Hb]|d[Hb+1|0]<<8|d[Hb+2|0]<<16|d[Hb+3|0]<<24|0;Hb=Fb+4|0;Ba=d[Hb]|d[Hb+1|0]<<8|d[Hb+2|0]<<16|d[Hb+3|0]<<24|0;Hb=Fb+8|0;Jb=Qa-8|0;if((Oa&6144|0)==6144){$b=Jb;ac=Jb;bc=Hb}else{if((Jb|0)<4){cc=-1094995529;V=146;break}Jb=Hb;Hb=d[Jb]|d[Jb+1|0]<<8|d[Jb+2|0]<<16|d[Jb+3|0]<<24|0;Jb=Qa-12|0;if(Hb>>>0>Jb>>>0){cc=-1094995529;V=146;break}$b=Jb;ac=Hb;bc=Fb+12|0}Hb=XDb(c[D>>2]|0,Ra+32+ac|0)|0;if((Hb|0)==0){cc=-12;V=146;break}c[D>>2]=Hb;Jb=ac+32|0;dc=Jb+Ra|0;Mb=Hb+Eb|0;x=1802532471;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;Mb=(c[D>>2]|0)+(Eb+4)|0;x=ac+24|0;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;Mb=(c[D>>2]|0)+(Eb+8)|0;x=Bb;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;Mb=(c[D>>2]|0)+(Eb+10)|0;x=0;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;Mb=(c[D>>2]|0)+(Eb+12)|0;x=0;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;Mb=(c[D>>2]|0)+(Eb+16)|0;x=0;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;Mb=(c[D>>2]|0)+(Eb+20)|0;x=Ib;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;Mb=(c[D>>2]|0)+(Eb+24)|0;x=Oa;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;Mb=(c[D>>2]|0)+(Eb+28)|0;x=Ba;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;UGb((c[D>>2]|0)+(Eb+32)|0,bc|0,ac)|0;Mb=$b-ac|0;if((Mb|0)>7){Eb=Jb+Eb|0;Qa=Mb;Ra=dc;Fb=bc+ac|0}else{V=145;break}}if((V|0)==145){V=0;ec=dc;fc=c[D>>2]|0;gc=c[G>>2]|0;break}else if((V|0)==146){V=0;$Db(ca);_b=cc;break k}}else{ec=0;fc=0;gc=Ab}}while(0);c[E>>2]=ec;if((gc|0)!=(nb|0)){$Db(pa)}c[G>>2]=fc;hc=c[(c[Y>>2]|0)+48>>2]|0;ic=ec;V=151;break j}}while(0);yDb(c[ha>>2]|0,16,1952128,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;jc=_b}else{hc=Db;ic=c[E>>2]|0;V=151}}while(0);do{if((V|0)==151){V=0;Db=(hc|0)==149?8:0;Aa=cEb(80)|0;Ab=Aa;if((wZ(Ab,Db+ic|0)|0)<0){ZDb(Aa);jc=-12;break}za=Aa+24|0;if((c[(c[Y>>2]|0)+48>>2]|0)==149){Ib=c[za>>2]|0;Bb=Ib;x=fe(ic|0)|0;a[Bb]=x;x=x>>8;a[Bb+1|0]=x;x=x>>8;a[Bb+2|0]=x;x=x>>8;a[Bb+3|0]=x;Bb=Ib+4|0;x=1718641513;a[Bb]=x;x=x>>8;a[Bb+1|0]=x;x=x>>8;a[Bb+2|0]=x;x=x>>8;a[Bb+3|0]=x}UGb((c[za>>2]|0)+Db|0,c[G>>2]|0,ic)|0;if((c[G>>2]|0)!=(nb|0)){$Db(pa)}c[Aa+36>>2]=Cb;c[Aa+32>>2]=c[_>>2];do{if(Fa){Db=GZ(Ab,74,ra)|0;if((Db|0)==0){BZ(Ab);ZDb(Aa);Zb=-12;break i}else{Bb=Db;Ib=Bb|0;x=Ga;a[Ib]=x;x=x>>8;a[Ib+1|0]=x;x=x>>8;a[Ib+2|0]=x;x=x>>8;a[Ib+3|0]=x;Ib=Bb+4|0;x=ya;a[Ib]=x;x=x>>8;a[Ib+1|0]=x;x=x>>8;a[Ib+2|0]=x;x=x>>8;a[Ib+3|0]=x;UGb(Db+8|0,p|0,s)|0;break}}}while(0);do{if(!Na){Db=GZ(Ab,70,10)|0;if((Db|0)==0){BZ(Ab);ZDb(Aa);Zb=-12;break i}else{Ib=Db;x=0;a[Ib]=x;x=x>>8;a[Ib+1|0]=x;x=x>>8;a[Ib+2|0]=x;x=x>>8;a[Ib+3|0]=x;c[Ua>>2]=1;c[Xa>>2]=1e9;c[Va>>2]=1;c[eb>>2]=c[(c[Y>>2]|0)+412>>2];Ib=KDb(v,w,H,I)|0;Bb=Db+4|0;x=Ib;a[Bb]=x;x=x>>8;a[Bb+1|0]=x;x=x>>8;a[Bb+2|0]=x;x=x>>8;a[Bb+3|0]=x;break}}}while(0);if((c[Pa>>2]|0)==0){Bb=Aa+8|0;c[Bb>>2]=qb;c[Bb+4>>2]=pb}else{Bb=Aa+16|0;c[Bb>>2]=qb;c[Bb+4>>2]=pb}Bb=Aa+64|0;c[Bb>>2]=g;c[Bb+4>>2]=j;Bb=c[(c[Y>>2]|0)+48>>2]|0;if((Bb|0)==1397909872){Ib=Aa+72|0;c[Ib>>2]=xb;c[Ib+4>>2]=yb}Ib=0;if((c[Sa>>2]|0)!=17|(c[Sa+4>>2]|0)!=0|(yb>>>0<Ib>>>0|yb>>>0==Ib>>>0&xb>>>0<-2147483648>>>0)){c[Aa+48>>2]=xb}l:do{if((Bb|0)==94212){Ib=c[za>>2]|0;Db=Aa+28|0;Gb=c[Db>>2]|0;Fb=Ib+(Gb-1)|0;Ra=Ib;while(1){kc=a[Ra]|0;lc=Ra+1|0;if(kc<<24>>24!=44&Ra>>>0<Fb>>>0){Ra=lc}else{break}}Qa=kc<<24>>24==44?lc:Ra;Eb=Qa;while(1){if((a[Eb]|0)==44){break}if(Eb>>>0<Fb>>>0){Eb=Eb+1|0}else{break l}}Fb=Eb+1|0;Ra=Aa+8|0;Mb=c[Ra>>2]|0;Jb=c[Ra+4>>2]|0;Ra=YGb(Mb,Jb,xb,yb)|0;Ba=F;Oa=c[Wa>>2]|0;Hb=c[Wa+4>>2]|0;Nb=gHb(Oa,Hb,Mb,Jb)|0;Jb=hHb(Nb,F,1e7,0)|0;Nb=Jb;Jb=gHb(Oa,Hb,Ra,Ba)|0;Ba=hHb(Jb,F,1e7,0)|0;Jb=Ba;Ba=(Nb|0)/36e4|0;Ra=(Ba*-36e4|0)+Nb|0;Nb=(Ra|0)/6e3|0;Hb=Ra+(Nb*-6e3|0)|0;Ra=(Hb|0)/100|0;Oa=(Jb|0)/36e4|0;Mb=(Oa*-36e4|0)+Jb|0;Jb=(Mb|0)/6e3|0;Kb=Mb+(Jb*-6e3|0)|0;Mb=(Kb|0)/100|0;a[Eb]=0;mc=Ib+(Gb+50)-Fb+16|0;nc=UAb(mc)|0;if((nc|0)==0){break}oc=nc+4|0;Lb(c[oc>>2]|0,mc|0,1925752,(M=i,i=i+80|0,c[M>>2]=Qa,c[M+8>>2]=Ba,c[M+16>>2]=Nb,c[M+24>>2]=Ra,c[M+32>>2]=Hb+(Ra*-100|0),c[M+40>>2]=Oa,c[M+48>>2]=Jb,c[M+56>>2]=Mb,c[M+64>>2]=Kb+(Mb*-100|0),c[M+72>>2]=Fb,M)|0)|0;i=M;Fb=Aa;XAb(Fb);c[Fb>>2]=nc;c[za>>2]=c[oc>>2];c[Db>>2]=SGb(c[oc>>2]|0)|0}}while(0);Bb=c[qa>>2]|0;do{if(!((Bb|0)==0|(qb|0)==0&(pb|0)==(-2147483648|0))){oc=Bb+8|0;if(!((c[oc>>2]|0)==(qb|0)&(c[oc+4>>2]|0)==(pb|0))){break}if((c[Bb+32>>2]|0)!=(c[_>>2]|0)){break}if((c[(c[Y>>2]|0)+48>>2]|0)!=94212){break}oc=Aa+28|0;if((zZ(Bb,c[oc>>2]|0)|0)<0){Zb=0;break i}nc=c[oc>>2]|0;UGb((c[Bb+24>>2]|0)+((c[Bb+28>>2]|0)-nc)|0,c[za>>2]|0,nc)|0;BZ(Ab);ZDb(Aa);Zb=0;break i}}while(0);gEb(R,sa,Aa);c[qa>>2]=Ab;Zb=0;break i}}while(0);if((c[G>>2]|0)==(nb|0)){Zb=jc;break}$Db(pa);Zb=jc}}while(0);if((Zb|0)!=0){ja=Zb;ka=na;break f}}if((qb|0)==0&(pb|0)==(-2147483648|0)){pc=-2147483648;qc=0}else{Cb=(ub|0)==(wb|0)&(tb|0)==(vb|0);za=YGb(xb,yb,qb,pb)|0;pc=Cb?-2147483648:F;qc=Cb?0:za}za=c[zb>>2]|0;if((sb|0)>=(oa|0)){ja=0;ka=na;break f}nb=nb+za|0;ob=ob-za|0;pb=pc;qb=qc;rb=sb}if((V|0)==68){yDb(c[ha>>2]|0,16,1982984,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;ja=0;ka=na;break}else if((V|0)==79){yDb(c[ha>>2]|0,16,2341552,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;ja=-1094995529;ka=na;break}else if((V|0)==82){yDb(c[ha>>2]|0,16,2318736,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;ja=-1094995529;ka=na;break}else if((V|0)==88){yDb(c[ha>>2]|0,16,2296768,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;ja=-1094995529;ka=na;break}else if((V|0)==98){ZDb(Pb);ja=-12;ka=na;break}else if((V|0)==121){ZDb(Xb);ja=-12;ka=na;break}else if((V|0)==125){ZDb(Xb);ja=-12;ka=na;break}else if((V|0)==128){ZDb(Xb);ja=-Yb|0;ka=na;break}}}while(0);ZDb(ka);N=ja;i=y;return N|0}}while(0);yDb(c[b>>2]|0,32,2075944,(M=i,i=i+24|0,c[M>>2]=f,c[M+8>>2]=P,c[M+16>>2]=O,M)|0);i=M;N=-1094995529;i=y;return N|0}function oG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[a>>2]|0)==0){return}else{d=0}do{e=c[a+(d*24|0)+12>>2]|0;f=b+e|0;g=c[a+(d*24|0)+4>>2]|0;do{if((g|0)==3|(g|0)==4){$Db(f)}else if((g|0)==5){$Db(b+(e+4)|0)}else if((g|0)==6){h=a+(d*24|0)+8|0;if((c[h>>2]|0)==0){oG(c[a+(d*24|0)+16>>2]|0,f);break}i=b+(e+4)|0;j=f;if((c[j>>2]|0)>0){k=a+(d*24|0)+16|0;l=0;m=c[i>>2]|0;while(1){oG(c[k>>2]|0,m);n=l+1|0;if((n|0)<(c[j>>2]|0)){l=n;m=m+(c[h>>2]|0)|0}else{break}}}ZDb(c[i>>2]|0)}}while(0);d=d+1|0;}while((c[a+(d*24|0)>>2]|0)!=0);return}function pG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+72|0;f=e|0;g=e+8|0;h=e+16|0;j=c[a>>2]|0;k=c[b>>2]|0;c[f>>2]=k;if(k>>>0>9999999>>>0){l=-1094995529;i=e;return l|0}m=d+16|0;n=c[m>>2]|0;o=c[m+4>>2]|0;m=0;p=0;q=2;r=0;a:do{if((n|0)==3&(o|0)==0){s=c[d+24>>2]|0;t=c[d+28>>2]|0;u=(s|0)!=0;if(u&(t|0)==0){yDb(0,16,1903752,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;l=-1;i=e;return l|0}if(!u){l=0;i=e;return l|0}u=s+k|0;v=WDb(u)|0;if((v|0)==0){l=-12;i=e;return l|0}else{UGb(v|0,t|0,s)|0;UGb(v+s|0,j|0,c[f>>2]|0)|0;w=v;x=u;y=19;break}}else if((n|0)==(m|0)&(o|0)==(p|0)){TGb(h|0,0,56)|0;if((Qd(h|0,1883552,56)|0)!=0){l=-1;i=e;return l|0}c[h>>2]=j;c[h+4>>2]=c[f>>2];u=h+20|0;v=h+16|0;s=h+12|0;t=0;z=k;while(1){A=z*3|0;B=XDb(t,A)|0;if((B|0)==0){y=15;break}C=c[u>>2]|0;c[v>>2]=A-C;c[s>>2]=B+C;D=$c(h|0,0)|0;if((D|0)==0&(A|0)<1e7){t=B;z=A}else{break}}if((y|0)==15){he(h|0)|0;E=t;F=0;y=20;break}z=c[u>>2]|0;he(h|0)|0;if((D|0)==1){w=B;x=z;y=19;break}else if((D|0)==(-4|0)){E=B;F=-12;y=20;break}E=B;F=-1094995529;y=20}else if((n|0)==(q|0)&(o|0)==(r|0)){z=0;s=k;while(1){G=s*3|0;c[g>>2]=G;H=XDb(z,G+12|0)|0;if((H|0)==0){E=z;F=-12;y=20;break a}I=FDb(H,g,j,f)|0;if((I|0)==2&(G|0)<1e7){z=H;s=G}else{break}}if((I|0)!=0){E=H;F=-1094995529;y=20;break}w=H;x=G-(c[g>>2]|0)|0;y=19}else{l=-1094995529;i=e;return l|0}}while(0);if((y|0)==19){c[a>>2]=w;c[b>>2]=x;l=0;i=e;return l|0}else if((y|0)==20){ZDb(E);l=F;i=e;return l|0}return 0}function qG(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;h=lz(b)|0;if((h|0)==0){if((Xy(b)|0)!=0){j=-541478725;i=g;return j|0}k=Ty(b,0,0,1)|0;l=F;yDb(c[a>>2]|0,16,2223376,(m=i,i=i+32|0,c[m>>2]=k,c[m+8>>2]=l,c[m+16>>2]=k,c[m+24>>2]=l,m)|0);i=m;l=c[b+76>>2]|0;j=(l|0)==0?-5:l;i=g;return j|0}l=d[1191992+h|0]|0;k=8-l|0;if((k|0)>(e|0)){e=Ty(b,0,0,1)|0;n=YGb(e,F,-1,-1)|0;e=F;yDb(c[a>>2]|0,16,2213720,(m=i,i=i+40|0,c[m>>2]=h&255,c[m+8>>2]=n,c[m+16>>2]=e,c[m+24>>2]=n,c[m+32>>2]=e,m)|0);i=m;j=-1094995529;i=g;return j|0}m=1<<l^h;h=m;l=(m|0)<0|0?-1:0;if((k|0)>1){m=1;e=l;n=h;while(1){a=m+1|0;o=lz(b)|0;p=o|(n<<8|0>>>24);q=((o|0)<0|0?-1:0)|(e<<8|n>>>24);if((a|0)<(k|0)){m=a;e=q;n=p}else{r=q;s=p;break}}}else{r=l;s=h}c[f>>2]=s;c[f+4>>2]=r;j=k;i=g;return j|0}function rG(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+8|0;j=f|0;l=b|0;m=c[(c[l>>2]|0)+16>>2]|0;n=c[d>>2]|0;o=c[d+12>>2]|0;p=e+o|0;q=d+8|0;r=c[q>>2]|0;do{if((r|0)==0){s=p}else{t=e+(o+4)|0;u=p;v=aEb(c[t>>2]|0,(c[u>>2]|0)+1|0,r)|0;if((v|0)==0){w=-12;i=f;return w|0}else{c[t>>2]=v;t=c[q>>2]|0;x=v+(ba(t,c[u>>2]|0)|0)|0;TGb(x|0,0,t|0)|0;c[u>>2]=(c[u>>2]|0)+1;s=x;break}}}while(0);q=d+4|0;r=c[q>>2]|0;do{if((r-7|0)>>>0<2>>>0){y=r}else{c[b+268>>2]=0;p=qG(b,m,8,j)|0;do{if((p|0)>0){o=YGb(c[j>>2]|0,c[j+4>>2]|0,1,0)|0;e=F;x=_Gb(1,0,p*7|0|0)|0;if(!((o|0)==(x|0)&(e|0)==(F|0))){break}c[j>>2]=-1;c[j+4>>2]=16777215}else{if((p|0)<0){w=p}else{break}i=f;return w|0}}while(0);p=c[q>>2]|0;e=1344240+(p<<3)|0;x=c[e>>2]|0;o=c[e+4>>2]|0;if(!((p-1|0)>>>0<5>>>0)){y=p;break}e=c[j>>2]|0;u=c[j+4>>2]|0;if(!(u>>>0>o>>>0|u>>>0==o>>>0&e>>>0>x>>>0)){y=p;break}yDb(c[l>>2]|0,16,2196784,(z=i,i=i+40|0,c[z>>2]=e,c[z+8>>2]=u,c[z+16>>2]=x,c[z+24>>2]=o,c[z+32>>2]=p,z)|0);i=z;w=-1094995529;i=f;return w|0}}while(0);a:do{switch(y|0){case 7:{q=c[d+16>>2]|0;r=0;while(1){A=q+(r*24|0)|0;p=c[A>>2]|0;B=(p|0)==0;if(B|(p|0)==(n|0)){break}else{r=r+1|0}}do{if(B&(n|0)==524531317){r=c[b+4>>2]|0;if((r|0)<=0){break}q=b+8+(r-1<<4)+8|0;if((c[q>>2]|0)==(-1|0)&(c[q+4>>2]|0)==16777215){w=0}else{break}i=f;return w|0}}while(0);do{if(B){if((n|0)==236|(n|0)==191){break}yDb(c[l>>2]|0,32,2204376,(z=i,i=i+8|0,c[z>>2]=n,z)|0);i=z;if((c[(c[l>>2]|0)+1156>>2]&8|0)==0){break}else{w=-1094995529}i=f;return w|0}}while(0);w=rG(b,A,s)|0;i=f;return w|0};case 3:case 4:{q=c[j>>2]|0;r=s;p=WDb(q+1|0)|0;if((p|0)==0){w=-12;i=f;return w|0}if((mz(m,p,q)|0)!=(q|0)){ZDb(p);C=61;break a}a[p+q|0]=0;ZDb(c[r>>2]|0);c[r>>2]=p;w=0;i=f;return w|0};case 1:{p=c[j>>2]|0;r=s;if((p|0)>8){C=60;break a}c[r>>2]=0;c[r+4>>2]=0;if((p|0)>0){D=0;E=0;G=0}else{w=0;i=f;return w|0}while(1){q=G+1|0;o=lz(m)|0;x=o|(E<<8|0>>>24);u=((o|0)<0|0?-1:0)|(D<<8|E>>>24);c[r>>2]=x;c[r+4>>2]=u;if((q|0)<(p|0)){D=u;E=x;G=q}else{w=0;break}}i=f;return w|0};case 8:{w=1;i=f;return w|0};case 5:{p=c[j>>2]|0;r=s+4|0;q=r;x=s;O$a(r,x,p);if((c[q>>2]|0)==0){w=-12;i=f;return w|0}c[x>>2]=p;u=Ty(m,0,0,1)|0;o=s+8|0;c[o>>2]=u;c[o+4>>2]=F;if((mz(m,c[q>>2]|0,p)|0)==(p|0)){w=0;i=f;return w|0}else{$Db(r);c[x>>2]=0;C=61;break a}break};case 6:{x=c[l>>2]|0;r=b+4|0;p=c[r>>2]|0;if((p|0)>15){yDb(x,16,2161368,(z=i,i=i+8|0,c[z>>2]=16,z)|0);i=z;w=-38;i=f;return w|0}q=c[j>>2]|0;o=c[j+4>>2]|0;u=c[x+16>>2]|0;c[r>>2]=p+1;x=Ty(u,0,0,1)|0;u=b+8+(p<<4)|0;c[u>>2]=x;c[u+4>>2]=F;u=b+8+(p<<4)+8|0;c[u>>2]=q;c[u+4>>2]=o;if((n|0)==408125543){o=Ty(c[(c[l>>2]|0)+16>>2]|0,0,0,1)|0;u=b+360|0;c[u>>2]=o;c[u+4>>2]=F}u=c[d+16>>2]|0;b:do{if((c[u>>2]|0)!=0){o=0;c:while(1){q=c[u+(o*24|0)+4>>2]|0;do{if((q|0)==1){p=u+(o*24|0)+16|0;x=c[p+4>>2]|0;e=s+(c[u+(o*24|0)+12>>2]|0)|0;c[e>>2]=c[p>>2];c[e+4>>2]=x}else if((q|0)==3|(q|0)==4){x=c[u+(o*24|0)+16>>2]|0;if((x|0)==0){break}e=s+(c[u+(o*24|0)+12>>2]|0)|0;p=eEb(x)|0;c[e>>2]=p;if((p|0)==0){w=-12;break c}}else if((q|0)==2){h[s+(c[u+(o*24|0)+12>>2]|0)>>3]=+h[u+(o*24|0)+16>>3]}}while(0);o=o+1|0;if((c[u+(o*24|0)>>2]|0)==0){break b}}i=f;return w|0}}while(0);o=b+268|0;while(1){q=Ty(c[(c[l>>2]|0)+16>>2]|0,0,0,1)|0;p=c[r>>2]|0;if((p|0)>0){H=p-1|0;p=b+8+(H<<4)|0;e=ZGb(q,F,c[p>>2]|0,c[p+4>>2]|0)|0;p=F;q=b+8+(H<<4)+8|0;x=c[q+4>>2]|0;if(!(p>>>0<x>>>0|p>>>0==x>>>0&e>>>0<(c[q>>2]|0)>>>0)){break}if((c[o>>2]|0)!=0){break}}q=mG(b,u,s)|0;if((q|0)!=0){w=q;C=62;break}}if((C|0)==62){i=f;return w|0}c[r>>2]=H;w=0;i=f;return w|0};case 2:{u=c[j>>2]|0;o=s;if((u|0)==8){q=Az(m)|0;e=F;h[o>>3]=(c[k>>2]=q,c[k+4>>2]=e,+h[k>>3]);w=0;i=f;return w|0}else if((u|0)==4){e=vz(m)|0;h[o>>3]=(c[k>>2]=e,+g[k>>2]);w=0;i=f;return w|0}else if((u|0)==0){h[o>>3]=0.0;w=0;i=f;return w|0}else{C=60;break a}break};case 9:{o=c[j>>2]|0;u=s;if((o|0)>8){C=60;break a}if((o|0)==0){c[u>>2]=0;c[u+4>>2]=0;w=0;i=f;return w|0}e=(lz(m)|0)<<24>>24;q=e;x=(e|0)<0|0?-1:0;c[u>>2]=q;c[u+4>>2]=x;if((o|0)>1){I=x;J=q;K=1}else{w=0;i=f;return w|0}while(1){q=K+1|0;x=lz(m)|0;e=x|(J<<8|0>>>24);p=((x|0)<0|0?-1:0)|(I<<8|J>>>24);c[u>>2]=e;c[u+4>>2]=p;if((q|0)<(o|0)){I=p;J=e;K=q}else{w=0;break}}i=f;return w|0};default:{o=c[j>>2]|0;u=c[j+4>>2]|0;r=SS(m,o)|0;if(!((r|0)==(o|0)&(((r|0)<0|0?-1:0)|0)==(u|0))){w=-5;i=f;return w|0}r=Vy(m,o,u)|0;u=F;o=0;w=(u|0)<(o|0)|(u|0)==(o|0)&r>>>0<0>>>0?-5:0;i=f;return w|0}}}while(0);if((C|0)==60){yDb(c[l>>2]|0,16,2184e3,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;w=-1094995529;i=f;return w|0}else if((C|0)==61){yDb(c[l>>2]|0,16,2168936,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;w=-5;i=f;return w|0}return 0}function sG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;e=c[a+356>>2]|0;f=a+264|0;g=c[f>>2]|0;h=a|0;j=Ty(c[(c[h>>2]|0)+16>>2]|0,0,0,1)|0;k=F;l=a+268|0;m=c[l>>2]|0;if((c[a+352>>2]|0)<=(b|0)){n=0;i=d;return n|0}o=e;e=o+(b<<4)|0;p=c[e>>2]|0;q=c[e+4>>2]|0;if((p|0)==290298740&(q|0)==0|(p|0)==524531317&(q|0)==0){n=0;i=d;return n|0}q=o+(b<<4)+8|0;b=a+360|0;o=YGb(c[b>>2]|0,c[b+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;q=F;b=Ty(c[(c[h>>2]|0)+16>>2]|0,o,q,0)|0;a:do{if((b|0)==(o|0)&(F|0)==(q|0)){p=a+4|0;e=c[p>>2]|0;if((e|0)==16){yDb(c[h>>2]|0,32,2147688,(r=i,i=i+8|0,c[r>>2]=16,r)|0);i=r;s=-1094995529;break}r=a+8+(e<<4)|0;c[r>>2]=0;c[r+4>>2]=0;r=a+8+(e<<4)+8|0;c[r>>2]=-1;c[r+4>>2]=-1;c[p>>2]=(c[p>>2]|0)+1;c[l>>2]=0;r=mG(a,681952,a)|0;e=c[p>>2]|0;while(1){if((e|0)==0){s=r;break a}t=e-1|0;c[p>>2]=t;u=a+8+(t<<4)+8|0;if((c[u>>2]|0)==(-1|0)&(c[u+4>>2]|0)==(-1|0)){s=r;break}else{e=t}}}else{s=0}}while(0);Ty(c[(c[h>>2]|0)+16>>2]|0,j,k,0)|0;c[f>>2]=g;c[l>>2]=m;n=s;i=d;return n|0}function tG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;d=c[a+340>>2]|0;e=d;f=a+336|0;g=c[f>>2]|0;if((g|0)==0){i=b;return}h=d;d=a+272|0;if(+((c[h>>2]|0)>>>0)+ +((c[h+4>>2]|0)>>>0)*4294967296.0>1.0e14/(+((c[d>>2]|0)>>>0)+ +((c[d+4>>2]|0)>>>0)*4294967296.0)){yDb(c[a>>2]|0,24,2154744,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=c[d>>2]|0;k=(h|0)<0|0?-1:0;l=h;m=c[f>>2]|0}else{k=0;l=1;m=g}if((m|0)<=0){i=b;return}g=a+316|0;h=a+312|0;d=a+360|0;n=a|0;a=0;o=m;while(1){m=c[e+(a<<4)+12>>2]|0;p=e+(a<<4)+8|0;if((c[p>>2]|0)>0){q=e+(a<<4)|0;r=0;do{s=c[m+(r<<4)>>2]|0;t=c[g>>2]|0;u=c[h>>2]|0;v=s;w=(s|0)<0|0?-1:0;x=0;while(1){if((x|0)>=(u|0)){y=11;break}z=t+(x*296|0)|0;A=z|0;if((c[A>>2]|0)==(v|0)&(c[A+4>>2]|0)==(w|0)){y=12;break}else{x=x+1|0}}do{if((y|0)==11){y=0;yDb(c[n>>2]|0,16,2236272,(j=i,i=i+8|0,c[j>>2]=s,j)|0);i=j}else if((y|0)==12){y=0;if((z|0)==0){break}w=c[t+(x*296|0)+264>>2]|0;if((w|0)==0){break}v=m+(r<<4)+8|0;u=YGb(c[d>>2]|0,c[d+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;v=F;A=hHb(c[q>>2]|0,c[q+4>>2]|0,l,k)|0;jT(w,u,v,A,F,0,0,1)|0}}while(0);r=r+1|0;}while((r|0)<(c[p>>2]|0));B=c[f>>2]|0}else{B=o}p=a+1|0;if((p|0)<(B|0)){a=p;o=B}else{break}}i=b;return}function uG(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1024|0;g=c[b+4>>2]|0;h=b|0;if((c[h>>2]|0)<=0){QG(d,0,1185808);i=f;return}b=a;j=f|0;if((e|0)==0){k=0;do{l=c[g+(k<<5)+8>>2]|0;if((l|0)==0){m=0}else{n=(QGb(l,2141296)|0)==0;m=n?0:l}l=c[g+(k<<5)>>2]|0;do{if((l|0)==0){yDb(b,24,1979616,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}else{sAb(j,l,1024)|0;n=g+(k<<5)+16|0;p=(m|0)==0;do{if((c[n>>2]|0)!=0|(c[n+4>>2]|0)!=0|p){CBb(d,j,c[g+(k<<5)+4>>2]|0,0)|0;q=g+(k<<5)+24|0;if((c[q>>2]|0)==0){break}uG(a,q,d,j)}}while(0);if(p){break}tAb(j,1974576,1024)|0;tAb(j,m,1024)|0;CBb(d,j,c[g+(k<<5)+4>>2]|0,0)|0;n=g+(k<<5)+24|0;if((c[n>>2]|0)==0){break}uG(a,n,d,j)}}while(0);k=k+1|0;}while((k|0)<(c[h>>2]|0));QG(d,0,1185808);i=f;return}else{k=0;do{m=c[g+(k<<5)+8>>2]|0;if((m|0)==0){r=0}else{l=(QGb(m,2141296)|0)==0;r=l?0:m}m=c[g+(k<<5)>>2]|0;do{if((m|0)==0){yDb(b,24,1979616,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}else{Lb(j|0,1024,1976888,(o=i,i=i+16|0,c[o>>2]=e,c[o+8>>2]=m,o)|0)|0;i=o;l=g+(k<<5)+16|0;n=(r|0)==0;do{if((c[l>>2]|0)!=0|(c[l+4>>2]|0)!=0|n){CBb(d,j,c[g+(k<<5)+4>>2]|0,0)|0;q=g+(k<<5)+24|0;if((c[q>>2]|0)==0){break}uG(a,q,d,j)}}while(0);if(n){break}tAb(j,1974576,1024)|0;tAb(j,r,1024)|0;CBb(d,j,c[g+(k<<5)+4>>2]|0,0)|0;l=g+(k<<5)+24|0;if((c[l>>2]|0)==0){break}uG(a,l,d,j)}}while(0);k=k+1|0;}while((k|0)<(c[h>>2]|0));QG(d,0,1185808);i=f;return}}function vG(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0.0,Wb=0.0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0;b=i;i=i+856|0;e=b|0;f=b+264|0;g=b+280|0;j=b+296|0;l=b+320|0;m=b+336|0;n=b+352|0;o=b+368|0;p=b+376|0;q=b+384|0;r=b+432|0;s=b+448|0;t=b+464|0;u=b+472|0;v=b+480|0;w=b+496|0;x=b+504|0;y=b+520|0;z=b+536|0;A=b+552|0;B=b+568|0;C=b+584|0;D=b+848|0;G=a+12|0;H=c[G>>2]|0;I=a+16|0;J=c[I>>2]|0;K=a+8|0;L=(QGb(c[c[K>>2]>>2]|0,2027008)|0)==0;M=H+4|0;c[M>>2]=L?2:1;L=a+1204|0;if((c[L>>2]|0)<0){c[L>>2]=1}L=a+24|0;N=c[L>>2]|0;do{if((N|0)==0){O=0}else{R=c[a+28>>2]|0;S=0;while(1){T=c[(c[(c[R+(S<<2)>>2]|0)+8>>2]|0)+48>>2]|0;if((T|0)==86047|(T|0)==86036|(T|0)==77825|(T|0)==86058|(T|0)==6|(T|0)==7){break}U=S+1|0;if(U>>>0<N>>>0){S=U}else{V=8;break}}if((V|0)==8){O=N<<3;break}S=H0a(T)|0;yDb(a,16,2034560,(W=i,i=i+8|0,c[W>>2]=S,W)|0);i=W;X=-1163346256;i=b;return X|0}}while(0);T=cEb(O)|0;c[H+96>>2]=T;if((T|0)==0){X=-12;i=b;return X|0}FG(y,J,440786851,0,0);T=y|0;O=c[T>>2]|0;N=c[T+4>>2]|0;T=c[y+8>>2]|0;y=d[1192058]|0;S=(y+20|0)>>>0<7>>>0;do{if(S){EG(J,1,0,0);Py(J,1);V=17}else{R=(y+7|0)/7|0;while(1){Py(J,17030>>>(R<<3>>>0)&255);if((R|0)==0){break}else{R=R-1|0}}EG(J,1,0,0);Py(J,1);if(S){EG(J,1,0,0);Py(J,1);V=21;break}R=(y+7|0)/7|0;while(1){Py(J,17143>>>(R<<3>>>0)&255);if((R|0)==0){V=17;break}else{R=R-1|0}}}}while(0);do{if((V|0)==17){EG(J,1,0,0);Py(J,1);if(S){EG(J,1,0,0);Py(J,4);V=25;break}R=(y+7|0)/7|0;while(1){Py(J,17138>>>(R<<3>>>0)&255);if((R|0)==0){V=21;break}else{R=R-1|0}}}}while(0);do{if((V|0)==21){EG(J,1,0,0);Py(J,4);if(S){EG(J,1,0,0);Py(J,8);GG(J,17026,c[c[K>>2]>>2]|0);V=29;break}R=(y+7|0)/7|0;while(1){Py(J,17139>>>(R<<3>>>0)&255);if((R|0)==0){V=25;break}else{R=R-1|0}}}}while(0);do{if((V|0)==25){EG(J,1,0,0);Py(J,8);GG(J,17026,c[c[K>>2]>>2]|0);if(S){EG(J,1,0,0);Py(J,4);break}R=(y+7|0)/7|0;while(1){Py(J,17031>>>(R<<3>>>0)&255);if((R|0)==0){V=29;break}else{R=R-1|0}}}}while(0);do{if((V|0)==29){EG(J,1,0,0);Py(J,4);if(S){break}K=(y+7|0)/7|0;while(1){Py(J,17029>>>(K<<3>>>0)&255);if((K|0)==0){break}else{K=K-1|0}}}}while(0);EG(J,1,0,0);Py(J,2);y=Ty(J,0,0,1)|0;S=F;K=ZGb(O,N,T,(T|0)<0|0?-1:0)|0;R=Ty(J,K,F,0)|0;K=F;U=0;if(!((K|0)<(U|0)|(K|0)==(U|0)&R>>>0<0>>>0)){R=ZGb(y,S,O,N)|0;EG(J,R,F,T);Ty(J,y,S,0)|0;}S=H+16|0;FG(z,J,408125543,0,0);y=z;c[S>>2]=c[y>>2];c[S+4>>2]=c[y+4>>2];c[S+8>>2]=c[y+8>>2];c[S+12>>2]=c[y+12>>2];y=Ty(J,0,0,1)|0;S=F;z=H+32|0;c[z>>2]=y;c[z+4>>2]=S;T=cEb(32)|0;if((T|0)==0){c[H+88>>2]=0;X=-12;i=b;return X|0}R=T+8|0;c[R>>2]=y;c[R+4>>2]=S;S=Ty(J,0,0,1)|0;y=T;c[y>>2]=S;c[y+4>>2]=F;c[T+16>>2]=223;y=T+20|0;c[y>>2]=10;CG(J,223,0);S=H+88|0;c[S>>2]=T;N=Ty(J,0,0,1)|0;O=F;U=T+24|0;K=c[y>>2]|0;y=T+28|0;T=c[y>>2]|0;if(!((K|0)<1|(K|0)>(T|0))){X=-1;i=b;return X|0}K=aEb(c[U>>2]|0,T+1|0,16)|0;T=K;if((K|0)==0){X=-12;i=b;return X|0}c[U>>2]=T;c[T+(c[y>>2]<<4)>>2]=357149030;U=ZGb(N,O,c[R>>2]|0,c[R+4>>2]|0)|0;R=c[y>>2]|0;c[y>>2]=R+1;y=T+(R<<4)+8|0;c[y>>2]=U;c[y+4>>2]=F;FG(A,J,357149030,0,0);y=A|0;U=c[y>>2]|0;R=c[y+4>>2]|0;y=c[A+8>>2]|0;A=d[1192034]|0;if(!((A+28|0)>>>0<7>>>0)){T=(A+15|0)/7|0;while(1){Py(J,2807729>>>(T<<3>>>0)&255);if((T|0)==0){break}else{T=T-1|0}}}EG(J,3,0,0);Py(J,15);Py(J,66);Py(J,64);T=a+1140|0;A=BBb(c[T>>2]|0,2122816,0,0)|0;if((A|0)!=0){GG(J,31657,c[A+4>>2]|0)}A=a+28|0;if((c[(c[(c[c[A>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)==0){oDb(C,hFb()|0);O=C+256|0;N=c[O>>2]|0;c[C+((N&63)<<2)>>2]=(c[C+((N+9&63)<<2)>>2]|0)+(c[C+((N+40&63)<<2)>>2]|0);N=c[O>>2]|0;K=N+1|0;c[O>>2]=K;c[B>>2]=c[C+((N&63)<<2)>>2];c[C+((K&63)<<2)>>2]=(c[C+((N+10&63)<<2)>>2]|0)+(c[C+((N+41&63)<<2)>>2]|0);N=c[O>>2]|0;K=N+1|0;c[O>>2]=K;c[B+4>>2]=c[C+((N&63)<<2)>>2];c[C+((K&63)<<2)>>2]=(c[C+((N+10&63)<<2)>>2]|0)+(c[C+((N+41&63)<<2)>>2]|0);N=c[O>>2]|0;K=N+1|0;c[O>>2]=K;c[B+8>>2]=c[C+((N&63)<<2)>>2];c[C+((K&63)<<2)>>2]=(c[C+((N+10&63)<<2)>>2]|0)+(c[C+((N+41&63)<<2)>>2]|0);N=c[O>>2]|0;c[O>>2]=N+1;c[B+12>>2]=c[C+((N&63)<<2)>>2];GG(J,19840,2030320);N=BBb(c[T>>2]|0,2026392,0,0)|0;if((N|0)==0){GG(J,22337,2030320)}else{GG(J,22337,c[N+4>>2]|0)}N=B;B=d[1192107]|0;if(!((B+20|0)>>>0<7>>>0)){C=(B+7|0)/7|0;while(1){Py(J,29604>>>(C<<3>>>0)&255);if((C|0)==0){break}else{C=C-1|0}}}Py(J,144);Ry(J,N,16)}else{GG(J,19840,2022920);GG(J,22337,2022920)}N=BBb(c[T>>2]|0,2019680,0,0)|0;if((N|0)!=0){C=bU(c[N+4>>2]|0)|0;N=gHb(C,F,1e9,0)|0;C=YGb(N,F,-288686080,-227779896)|0;N=F;B=fe(C|0)|0;C=D;c[D>>2]=fe(N|0)|0;c[D+4>>2]=B;B=d[1192060]|0;if(!((B+20|0)>>>0<7>>>0)){D=(B+7|0)/7|0;while(1){Py(J,17505>>>(D<<3>>>0)&255);if((D|0)==0){break}else{D=D-1|0}}}Py(J,136);Ry(J,C,8)}C=H+80|0;c[C>>2]=0;c[C+4>>2]=0;C=Ty(J,0,0,1)|0;D=H+72|0;c[D>>2]=C;c[D+4>>2]=F;CG(J,11,0);D=Ty(J,0,0,1)|0;C=F;B=ZGb(U,R,y,(y|0)<0|0?-1:0)|0;N=Ty(J,B,F,0)|0;B=F;O=0;if(!((B|0)<(O|0)|(B|0)==(O|0)&N>>>0<0>>>0)){N=ZGb(D,C,U,R)|0;EG(J,N,F,y);Ty(J,D,C,0)|0;}C=w;D=c[G>>2]|0;y=c[I>>2]|0;N=c[D+88>>2]|0;R=Ty(y,0,0,1)|0;U=F;O=N+24|0;B=c[N+20>>2]|0;K=N+28|0;Y=c[K>>2]|0;a:do{if((B|0)<1|(B|0)>(Y|0)){Z=aEb(c[O>>2]|0,Y+1|0,16)|0;_=Z;if((Z|0)==0){$=-12;break}c[O>>2]=_;c[_+(c[K>>2]<<4)>>2]=374648427;Z=N+8|0;ba=ZGb(R,U,c[Z>>2]|0,c[Z+4>>2]|0)|0;Z=c[K>>2]|0;c[K>>2]=Z+1;ca=_+(Z<<4)+8|0;c[ca>>2]=ba;c[ca+4>>2]=F;FG(r,y,374648427,0,0);ca=r|0;ba=c[ca>>2]|0;Z=c[ca+4>>2]|0;ca=c[r+8>>2]|0;_=c[L>>2]|0;b:do{if((_|0)!=0){da=c[A>>2]|0;ea=0;fa=0;do{ea=c[(c[da+(fa<<2)>>2]|0)+72>>2]&1|ea;fa=fa+1|0;}while(fa>>>0<_>>>0);fa=D+184|0;ha=a;ia=q+8|0;ja=q+28|0;ka=s|0;la=s+8|0;ma=d[1192208]|0;na=(ma+12|0)>>>0<7>>>0;oa=d[1192107]|0;pa=(oa+20|0)>>>0<7>>>0;qa=d[1192149]|0;ra=(qa+12|0)>>>0<7>>>0;sa=D+4|0;ta=(ea|0)==0;ua=t|0;va=t+4|0;wa=u|0;xa=u+4|0;ya=d[1192078]|0;za=(ya+20|0)>>>0<7>>>0;Aa=(ya+7|0)/7|0;ya=d[1192091]|0;Ba=(ya+20|0)>>>0<7>>>0;Ca=(ya+7|0)/7|0;ya=m|0;Da=n|0;Ea=n+4|0;Fa=m+4|0;Ga=m+8|0;Ha=n+8|0;Ia=d[1192124]|0;Ja=(Ia+12|0)>>>0<7>>>0;Ka=(Ia-1|0)/7|0;Ia=x|0;La=x+8|0;Ma=d[1192152]|0;Na=(Ma+12|0)>>>0<7>>>0;Oa=d[1192174]|0;Pa=(Oa+12|0)>>>0<7>>>0;Qa=(Oa-1|0)/7|0;Oa=d[1192090]|0;Ra=(Oa+20|0)>>>0<7>>>0;Sa=(Oa+7|0)/7|0;Oa=d[1192112]|0;Ta=(Oa+20|0)>>>0<7>>>0;Ua=(Oa+7|0)/7|0;Oa=(Ma-1|0)/7|0;Ma=d[1192027]|0;Va=(Ma+28|0)>>>0<7>>>0;Wa=(Ma+15|0)/7|0;Ma=v|0;Xa=v+8|0;Ya=d[1192169]|0;Za=(Ya+12|0)>>>0<7>>>0;_a=d[1192179]|0;$a=(_a+12|0)>>>0<7>>>0;ab=d[1192076]|0;bb=(ab+20|0)>>>0<7>>>0;cb=(ab+7|0)/7|0;ab=d[1192038]|0;db=(ab+28|0)>>>0<7>>>0;eb=(ab+15|0)/7|0;ab=d[1192075]|0;fb=(ab+20|0)>>>0<7>>>0;gb=(ab+7|0)/7|0;ab=(_a-1|0)/7|0;_a=(Ya-1|0)/7|0;Ya=D+96|0;hb=d[1192077]|0;ib=(hb+20|0)>>>0<7>>>0;jb=(hb+7|0)/7|0;hb=d[1192129]|0;kb=(hb+12|0)>>>0<7>>>0;lb=(hb-1|0)/7|0;hb=(qa-1|0)/7|0;qa=(oa+7|0)/7|0;oa=(ma-1|0)/7|0;ma=0;mb=da;c:while(1){nb=c[mb+(ma<<2)>>2]|0;ob=c[nb+8>>2]|0;pb=ob+48|0;qb=u0a(c[pb>>2]|0)|0;rb=ob+412|0;sb=c[rb>>2]|0;tb=ob+8|0;if((c[tb>>2]|0)==4){c[fa>>2]=1;ub=ma+1|0}else{do{if((qb|0)==0){if((c[pb>>2]|0)!=69643){vb=(BFb(c[ob+420>>2]|0)|0)<<3;if((vb|0)!=0){wb=vb;break}}wb=c[ob+792>>2]|0}else{wb=qb}}while(0);do{if((c[pb>>2]|0)==86018){if((QMa(q,c[ob+96>>2]|0,c[ob+100>>2]<<3,1)|0)<0){yDb(ha,24,1927272,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;xb=0;yb=sb;break}else{xb=c[ja>>2]|0;yb=c[ia>>2]|0;break}}else{xb=0;yb=sb}}while(0);FG(s,y,174,0,0);sb=c[ka>>2]|0;qb=c[ka+4>>2]|0;vb=c[la>>2]|0;zb=ma+1|0;Ab=zb;Bb=(zb|0)<0|0?-1:0;Cb=Bb;Db=Ab;Eb=1;while(1){Fb=Db>>>8|Cb<<24;Gb=Cb>>>8|0<<24;if((Fb|0)==0&(Gb|0)==0){break}else{Cb=Gb;Db=Fb;Eb=Eb+1|0}}if(!na){Db=oa;while(1){Py(y,215>>>(Db<<3>>>0)&255);if((Db|0)==0){break}else{Db=Db-1|0}}}EG(y,Eb,(Eb|0)<0|0?-1:0,0);if((Eb|0)>0){Db=Eb;while(1){Cb=Db-1|0;Fb=$Gb(Ab|0,Bb|0,Cb<<3|0)|0;Py(y,Fb&255);if((Cb|0)>0){Db=Cb}else{Hb=Bb;Ib=Ab;Jb=1;break}}}else{Hb=Bb;Ib=Ab;Jb=1}while(1){Db=Ib>>>8|Hb<<24;Eb=Hb>>>8|0<<24;if((Db|0)==0&(Eb|0)==0){break}else{Hb=Eb;Ib=Db;Jb=Jb+1|0}}if(!pa){Db=qa;while(1){Py(y,29637>>>(Db<<3>>>0)&255);if((Db|0)==0){break}else{Db=Db-1|0}}}EG(y,Jb,(Jb|0)<0|0?-1:0,0);if((Jb|0)>0){Db=Jb;do{Db=Db-1|0;Eb=$Gb(Ab|0,Bb|0,Db<<3|0)|0;Py(y,Eb&255);}while((Db|0)>0)}if(!ra){Db=hb;while(1){Py(y,156>>>(Db<<3>>>0)&255);if((Db|0)==0){break}else{Db=Db-1|0}}}Py(y,129);Py(y,0);Db=nb+88|0;Bb=BBb(c[Db>>2]|0,2122816,0,0)|0;if((Bb|0)!=0){GG(y,21358,c[Bb+4>>2]|0)}Bb=BBb(c[Db>>2]|0,1982536,0,0)|0;do{if((c[sa>>2]|0)==2){if((c[pb>>2]|0)!=1465275476){V=93;break}if((Bb|0)==0){break}Ab=c[Bb+4>>2]|0;if((Ab|0)==0){break}GG(y,2274716,Ab)}else{V=93}}while(0);if((V|0)==93){V=0;if((Bb|0)==0){Kb=2117632}else{Kb=c[Bb+4>>2]|0}GG(y,2274716,Kb)}Ab=nb+72|0;do{if(!ta){if((c[Ab>>2]&1|0)!=0){break}if(!kb){Eb=lb;while(1){Py(y,136>>>(Eb<<3>>>0)&255);if((Eb|0)==0){break}else{Eb=Eb-1|0}}}Py(y,129);Py(y,0)}}while(0);if((c[Ab>>2]&64|0)!=0){if(!ib){Bb=jb;while(1){Py(y,21930>>>(Bb<<3>>>0)&255);if((Bb|0)==0){break}else{Bb=Bb-1|0}}}Py(y,129);Py(y,1)}do{if((c[sa>>2]|0)==2){if((c[pb>>2]|0)!=1465275476){Lb=0;V=114;break}Bb=c[Ab>>2]|0;do{if((Bb&65536|0)==0){if((Bb&131072|0)!=0){Mb=1976864;Nb=33;break}Eb=Bb&262144;Mb=(Eb|0)==0?1972856:1974552;Nb=(Eb>>>14)+17|0}else{Mb=1979560;Nb=17}}while(0);GG(y,134,Mb);Ob=Nb}else{Lb=0;V=114}}while(0);d:do{if((V|0)==114){while(1){V=0;Ab=c[1185856+(Lb*28|0)>>2]|0;if((Ab|0)==0){Ob=0;break d}if((Ab|0)==(c[pb>>2]|0)){break}else{Lb=Lb+1|0;V=114}}GG(y,134,1185832+(Lb*28|0)|0);Ob=1}}while(0);if((c[pb>>2]|0)==1330664787){Ab=c[ob+116>>2]|0;c[ua>>2]=1;c[va>>2]=c[rb>>2];c[wa>>2]=1;c[xa>>2]=1e9;Bb=KDb(Ab,(Ab|0)<0|0?-1:0,t,u)|0;Ab=F;Eb=Ab;Cb=Bb;Fb=1;while(1){Gb=Cb>>>8|Eb<<24;Pb=Eb>>>8|0<<24;if((Gb|0)==0&(Pb|0)==0){break}else{Eb=Pb;Cb=Gb;Fb=Fb+1|0}}if(!za){Cb=Aa;while(1){Py(y,22186>>>(Cb<<3>>>0)&255);if((Cb|0)==0){break}else{Cb=Cb-1|0}}}EG(y,Fb,(Fb|0)<0|0?-1:0,0);if((Fb|0)>0){Cb=Fb;do{Cb=Cb-1|0;Eb=$Gb(Bb|0,Ab|0,Cb<<3|0)|0;Py(y,Eb&255);}while((Cb|0)>0)}if(!za){Cb=Aa;while(1){Py(y,22203>>>(Cb<<3>>>0)&255);if((Cb|0)==0){break}else{Cb=Cb-1|0}}}Py(y,132);Py(y,4);Py(y,196);Py(y,180);Py(y,0)}Cb=(c[sa>>2]|0)==2;do{if(Cb){Ab=c[pb>>2]|0;if((Ab|0)==141|(Ab|0)==169|(Ab|0)==86021|(Ab|0)==1465275476){break}else if((Ab|0)!=1330664787){V=130;break c}if(!((c[ob+680>>2]|0)<-1)){V=130;break c}}}while(0);Ab=c[tb>>2]|0;do{if((Ab|0)==3){if((Ob|0)==0){V=251;break c}if(Cb){if((c[pb>>2]|0)==1465275476){Qb=Ob}else{V=254}}else{V=254}if((V|0)==254){V=0;Qb=17}Bb=Qb;Fb=(Qb|0)<0|0?-1:0;Eb=Fb;rb=Bb;Gb=1;while(1){Pb=rb>>>8|Eb<<24;Rb=Eb>>>8|0<<24;if((Pb|0)==0&(Rb|0)==0){break}else{Eb=Rb;rb=Pb;Gb=Gb+1|0}}if(!Ja){rb=Ka;while(1){Py(y,131>>>(rb<<3>>>0)&255);if((rb|0)==0){break}else{rb=rb-1|0}}}EG(y,Gb,(Gb|0)<0|0?-1:0,0);if((Gb|0)>0){Sb=Gb}else{Tb=0;Ub=Qb;break}while(1){rb=Sb-1|0;Eb=$Gb(Bb|0,Fb|0,rb<<3|0)|0;Py(y,Eb&255);if((rb|0)>0){Sb=rb}else{Tb=0;Ub=Qb;break}}}else if((Ab|0)==0){if(!Ja){Fb=Ka;while(1){Py(y,131>>>(Fb<<3>>>0)&255);if((Fb|0)==0){break}else{Fb=Fb-1|0}}}Py(y,129);Py(y,1);Fb=c[nb+92>>2]|0;do{if((Fb|0)==0){V=144}else{Bb=c[nb+96>>2]|0;if((Bb|0)==0){V=144;break}Vb=+(Fb|0)/+(Bb|0);if(!(1.0/Vb>+(c[ob+104>>2]|0)/+(c[ob+108>>2]|0))){V=144;break}Wb=1.0e9/Vb;Bb=~~+Wb>>>0;Gb=(E=+Wb,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);rb=Gb;Eb=Bb;Pb=1;while(1){Rb=Eb>>>8|rb<<24;Xb=rb>>>8|0<<24;if((Rb|0)==0&(Xb|0)==0){break}else{rb=Xb;Eb=Rb;Pb=Pb+1|0}}if(!Va){Eb=Wa;while(1){Py(y,2352003>>>(Eb<<3>>>0)&255);if((Eb|0)==0){break}else{Eb=Eb-1|0}}}EG(y,Pb,(Pb|0)<0|0?-1:0,0);if((Pb|0)>0){Yb=Pb}else{break}do{Yb=Yb-1|0;Eb=$Gb(Bb|0,Gb|0,Yb<<3|0)|0;Py(y,Eb&255);}while((Yb|0)>0)}}while(0);do{if((V|0)==144){V=0;Wb=+(c[ob+104>>2]|0)/+(c[ob+108>>2]|0)*1.0e9;Fb=~~+Wb>>>0;Gb=(E=+Wb,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Bb=Gb;Pb=Fb;Eb=1;while(1){rb=Pb>>>8|Bb<<24;Rb=Bb>>>8|0<<24;if((rb|0)==0&(Rb|0)==0){break}else{Bb=Rb;Pb=rb;Eb=Eb+1|0}}if(!Va){Pb=Wa;while(1){Py(y,2352003>>>(Pb<<3>>>0)&255);if((Pb|0)==0){break}else{Pb=Pb-1|0}}}EG(y,Eb,(Eb|0)<0|0?-1:0,0);if((Eb|0)>0){Zb=Eb}else{break}do{Zb=Zb-1|0;Pb=$Gb(Fb|0,Gb|0,Zb<<3|0)|0;Py(y,Pb&255);}while((Zb|0)>0)}}while(0);e:do{if((Ob|0)==0){do{if((uT(1238728,c[pb>>2]|0)|0)!=0){if((uT(1240808,c[pb>>2]|0)|0)!=0){Gb=c[pb>>2]|0;if(!((Gb|0)==23|(Gb|0)==24|(Gb|0)==44)){break}}GG(y,134,1960448);_b=1;break e}}while(0);GG(y,134,1958520);c[(c[Ya>>2]|0)+(ma<<3)>>2]=1;_b=0}else{_b=0}}while(0);FG(v,y,224,0,0);Gb=c[Ma>>2]|0;Fb=c[Ma+4>>2]|0;Eb=c[Xa>>2]|0;Pb=ob+120|0;Bb=c[Pb>>2]|0;rb=Bb;Rb=(Bb|0)<0|0?-1:0;Bb=Rb;Xb=rb;$b=1;while(1){ac=Xb>>>8|Bb<<24;bc=Bb>>>8|0<<24;if((ac|0)==0&(bc|0)==0){break}else{Bb=bc;Xb=ac;$b=$b+1|0}}if(!Za){Xb=_a;while(1){Py(y,176>>>(Xb<<3>>>0)&255);if((Xb|0)==0){break}else{Xb=Xb-1|0}}}EG(y,$b,($b|0)<0|0?-1:0,0);if(($b|0)>0){Xb=$b;do{Xb=Xb-1|0;Bb=$Gb(rb|0,Rb|0,Xb<<3|0)|0;Py(y,Bb&255);}while((Xb|0)>0)}Xb=ob+124|0;Rb=c[Xb>>2]|0;rb=Rb;$b=(Rb|0)<0|0?-1:0;Rb=$b;Bb=rb;ac=1;while(1){bc=Bb>>>8|Rb<<24;cc=Rb>>>8|0<<24;if((bc|0)==0&(cc|0)==0){break}else{Rb=cc;Bb=bc;ac=ac+1|0}}if(!$a){Bb=ab;while(1){Py(y,186>>>(Bb<<3>>>0)&255);if((Bb|0)==0){break}else{Bb=Bb-1|0}}}EG(y,ac,(ac|0)<0|0?-1:0,0);if((ac|0)>0){Bb=ac;do{Bb=Bb-1|0;Rb=$Gb(rb|0,$b|0,Bb<<3|0)|0;Py(y,Rb&255);}while((Bb|0)>0)}Bb=BBb(c[Db>>2]|0,1986176,0,0)|0;if((Bb|0)==0){$b=BBb(c[T>>2]|0,1986176,0,0)|0;if(($b|0)==0){dc=1;ec=1}else{fc=$b;V=170}}else{fc=Bb;V=170}do{if((V|0)==170){V=0;Bb=fc+4|0;$b=0;while(1){if(($b|0)>=15){gc=0;hc=15;break}if((QGb(c[Bb>>2]|0,c[1191088+($b<<2)>>2]|0)|0)==0){V=173;break}else{$b=$b+1|0}}if((V|0)==173){V=0;gc=($b|0)<0|0?-1:0;hc=$b}if((c[sa>>2]|0)==2){Bb=0;rb=0;if((gc>>>0>Bb>>>0|gc>>>0==Bb>>>0&hc>>>0>3>>>0)&((hc|0)!=11|(gc|0)!=0)|(gc>>>0>rb>>>0|gc>>>0==rb>>>0&hc>>>0>14>>>0)){V=177;break c}else{ic=gc;jc=hc;kc=1}}else{rb=0;if(gc>>>0>rb>>>0|gc>>>0==rb>>>0&hc>>>0>14>>>0){V=177;break c}else{ic=gc;jc=hc;kc=1}}while(1){rb=jc>>>8|ic<<24;Bb=ic>>>8|0<<24;if((rb|0)==0&(Bb|0)==0){break}else{ic=Bb;jc=rb;kc=kc+1|0}}if(!fb){$b=gb;while(1){Py(y,21432>>>($b<<3>>>0)&255);if(($b|0)==0){break}else{$b=$b-1|0}}}EG(y,kc,(kc|0)<0|0?-1:0,0);if((kc|0)>0){$b=kc;do{$b=$b-1|0;rb=$Gb(hc|0,gc|0,$b<<3|0)|0;Py(y,rb&255);}while(($b|0)>0)}$b=7;rb=0;Bb=6;ac=0;Rb=3;bc=0;cc=2;lc=0;if((hc|0)==1&(gc|0)==0|(hc|0)==8&(gc|0)==0|(hc|0)==9&(gc|0)==0|(hc|0)==11&(gc|0)==0){dc=1;ec=2;break}else if((hc|0)==(cc|0)&(gc|0)==(lc|0)|(hc|0)==(Rb|0)&(gc|0)==(bc|0)|(hc|0)==(Bb|0)&(gc|0)==(ac|0)|(hc|0)==($b|0)&(gc|0)==(rb|0)){dc=2;ec=1;break}else{dc=1;ec=1;break}}}while(0);do{if((BBb(c[Db>>2]|0,1953952,0,0)|0)==0){if((BBb(c[T>>2]|0,1953952,0,0)|0)!=0){V=189;break}if((c[ob+140>>2]|0)==35){V=189}}else{V=189}}while(0);if((V|0)==189){V=0;if(!fb){rb=gb;while(1){Py(y,21440>>>(rb<<3>>>0)&255);if((rb|0)==0){break}else{rb=rb-1|0}}}Py(y,129);Py(y,1)}rb=c[nb+80>>2]|0;do{if((rb|0)==0){if((ec|0)==1&(dc|0)==1){break}$b=(c[Pb>>2]|0)/(ec|0)|0;ac=$b;Bb=($b|0)<0|0?-1:0;$b=Bb;bc=ac;Rb=1;while(1){lc=bc>>>8|$b<<24;cc=$b>>>8|0<<24;if((lc|0)==0&(cc|0)==0){break}else{$b=cc;bc=lc;Rb=Rb+1|0}}if(!bb){bc=cb;while(1){Py(y,21680>>>(bc<<3>>>0)&255);if((bc|0)==0){break}else{bc=bc-1|0}}}EG(y,Rb,(Rb|0)<0|0?-1:0,0);if((Rb|0)>0){bc=Rb;do{bc=bc-1|0;$b=$Gb(ac|0,Bb|0,bc<<3|0)|0;Py(y,$b&255);}while((bc|0)>0)}bc=(c[Xb>>2]|0)/(dc|0)|0;Bb=bc;ac=(bc|0)<0|0?-1:0;bc=ac;Rb=Bb;$b=1;while(1){lc=Rb>>>8|bc<<24;cc=bc>>>8|0<<24;if((lc|0)==0&(cc|0)==0){break}else{bc=cc;Rb=lc;$b=$b+1|0}}if(!bb){Rb=cb;while(1){Py(y,21690>>>(Rb<<3>>>0)&255);if((Rb|0)==0){break}else{Rb=Rb-1|0}}}EG(y,$b,($b|0)<0|0?-1:0,0);if(($b|0)>0){mc=$b}else{break}do{mc=mc-1|0;Rb=$Gb(Bb|0,ac|0,mc<<3|0)|0;Py(y,Rb&255);}while((mc|0)>0)}else{ac=c[Pb>>2]|0;Bb=c[nb+84>>2]|0;$b=IDb(ac,(ac|0)<0|0?-1:0,rb,(rb|0)<0|0?-1:0,Bb,(Bb|0)<0|0?-1:0)|0;Bb=F;ac=0;if((Bb|0)>(ac|0)|(Bb|0)==(ac|0)&$b>>>0>2147483647>>>0){V=194;break c}ac=eHb($b,Bb,ec,0)|0;Bb=F;$b=Bb;Rb=ac;bc=1;while(1){lc=Rb>>>8|$b<<24;cc=$b>>>8|0<<24;if((lc|0)==0&(cc|0)==0){break}else{$b=cc;Rb=lc;bc=bc+1|0}}if(!bb){Rb=cb;while(1){Py(y,21680>>>(Rb<<3>>>0)&255);if((Rb|0)==0){break}else{Rb=Rb-1|0}}}EG(y,bc,(bc|0)<0|0?-1:0,0);if((bc|0)>0){Rb=bc;do{Rb=Rb-1|0;$b=$Gb(ac|0,Bb|0,Rb<<3|0)|0;Py(y,$b&255);}while((Rb|0)>0)}Rb=(c[Xb>>2]|0)/(dc|0)|0;Bb=Rb;ac=(Rb|0)<0|0?-1:0;Rb=ac;bc=Bb;$b=1;while(1){lc=bc>>>8|Rb<<24;cc=Rb>>>8|0<<24;if((lc|0)==0&(cc|0)==0){break}else{Rb=cc;bc=lc;$b=$b+1|0}}if(!bb){bc=cb;while(1){Py(y,21690>>>(bc<<3>>>0)&255);if((bc|0)==0){break}else{bc=bc-1|0}}}EG(y,$b,($b|0)<0|0?-1:0,0);if(($b|0)>0){nc=$b}else{break}do{nc=nc-1|0;bc=$Gb(Bb|0,ac|0,nc<<3|0)|0;Py(y,bc&255);}while((nc|0)>0)}}while(0);if((c[pb>>2]|0)==14){c[w>>2]=c[ob+52>>2];if(!db){Xb=eb;while(1){Py(y,3061028>>>(Xb<<3>>>0)&255);if((Xb|0)==0){break}else{Xb=Xb-1|0}}}Py(y,132);Ry(y,C,4)}Xb=Ty(y,0,0,1)|0;rb=F;Pb=ZGb(Gb,Fb,Eb,(Eb|0)<0|0?-1:0)|0;ac=Ty(y,Pb,F,0)|0;Pb=F;Bb=0;if((Pb|0)<(Bb|0)|(Pb|0)==(Bb|0)&ac>>>0<0>>>0){Tb=_b;Ub=Ob;break}ac=ZGb(Xb,rb,Gb,Fb)|0;EG(y,ac,F,Eb);Ty(y,Xb,rb,0)|0;Tb=_b;Ub=Ob}else if((Ab|0)==1){if(!Ja){rb=Ka;while(1){Py(y,131>>>(rb<<3>>>0)&255);if((rb|0)==0){break}else{rb=rb-1|0}}}Py(y,129);Py(y,2);if((Ob|0)==0){GG(y,134,1949688)}FG(x,y,225,0,0);rb=c[Ia>>2]|0;Eb=c[Ia+4>>2]|0;Fb=c[La>>2]|0;Gb=c[ob+416>>2]|0;Xb=Gb;ac=(Gb|0)<0|0?-1:0;Gb=ac;Bb=Xb;Pb=1;while(1){$b=Bb>>>8|Gb<<24;bc=Gb>>>8|0<<24;if(($b|0)==0&(bc|0)==0){break}else{Gb=bc;Bb=$b;Pb=Pb+1|0}}if(!Na){Bb=Oa;while(1){Py(y,159>>>(Bb<<3>>>0)&255);if((Bb|0)==0){break}else{Bb=Bb-1|0}}}EG(y,Pb,(Pb|0)<0|0?-1:0,0);if((Pb|0)>0){Bb=Pb;do{Bb=Bb-1|0;Gb=$Gb(Xb|0,ac|0,Bb<<3|0)|0;Py(y,Gb&255);}while((Bb|0)>0)}Wb=+(yb|0);if(!Pa){Bb=Qa;while(1){Py(y,181>>>(Bb<<3>>>0)&255);if((Bb|0)==0){break}else{Bb=Bb-1|0}}}Py(y,136);h[k>>3]=Wb;ez(y,c[k>>2]|0,c[k+4>>2]|0);if((xb|0)!=0){Vb=+(xb|0);if(!Ta){Bb=Ua;while(1){Py(y,30901>>>(Bb<<3>>>0)&255);if((Bb|0)==0){break}else{Bb=Bb-1|0}}}Py(y,136);h[k>>3]=Vb;ez(y,c[k>>2]|0,c[k+4>>2]|0)}do{if((wb|0)!=0){Bb=wb;ac=(wb|0)<0|0?-1:0;Xb=ac;Pb=Bb;Gb=1;while(1){$b=Pb>>>8|Xb<<24;bc=Xb>>>8|0<<24;if(($b|0)==0&(bc|0)==0){break}else{Xb=bc;Pb=$b;Gb=Gb+1|0}}if(!Ra){Pb=Sa;while(1){Py(y,25188>>>(Pb<<3>>>0)&255);if((Pb|0)==0){break}else{Pb=Pb-1|0}}}EG(y,Gb,(Gb|0)<0|0?-1:0,0);if((Gb|0)>0){oc=Gb}else{break}do{oc=oc-1|0;Pb=$Gb(Bb|0,ac|0,oc<<3|0)|0;Py(y,Pb&255);}while((oc|0)>0)}}while(0);ac=Ty(y,0,0,1)|0;Bb=F;Gb=ZGb(rb,Eb,Fb,(Fb|0)<0|0?-1:0)|0;Pb=Ty(y,Gb,F,0)|0;Gb=F;Xb=0;if((Gb|0)<(Xb|0)|(Gb|0)==(Xb|0)&Pb>>>0<0>>>0){Tb=0;Ub=Ob;break}Pb=ZGb(ac,Bb,rb,Eb)|0;EG(y,Pb,F,Fb);Ty(y,ac,Bb,0)|0;Tb=0;Ub=Ob}else{V=261;break c}}while(0);if((c[sa>>2]|0)==2){if((c[pb>>2]|0)!=1465275476){V=264}}else{V=264}if((V|0)==264){V=0;Ab=Mz(o)|0;if((Ab|0)<0){$=Ab;break a}f:do{if((Ub|0)==0){Db=c[tb>>2]|0;if((Db|0)==1){Cb=uT(1238064,c[pb>>2]|0)|0;if((Cb|0)==0){Bb=H0a(c[pb>>2]|0)|0;yDb(ha,16,1930656,(W=i,i=i+8|0,c[W>>2]=Bb,W)|0);i=W;pc=-22}else{pc=Ab}Bb=ob+52|0;if((c[Bb>>2]|0)==0){c[Bb>>2]=Cb}GO(c[o>>2]|0,ob)|0;qc=pc;break}else if((Db|0)!=0){qc=Ab;break}if((Tb|0)==0){if((uT(1240808,c[pb>>2]|0)|0)==0){Db=H0a(c[pb>>2]|0)|0;yDb(ha,24,1938552,(W=i,i=i+8|0,c[W>>2]=Db,W)|0);i=W}Db=ob+52|0;do{if((c[Db>>2]|0)==0){Cb=uT(1240808,c[pb>>2]|0)|0;c[Db>>2]=Cb;if((Cb|0)!=0){rc=Ab;break}Cb=H0a(c[pb>>2]|0)|0;yDb(ha,16,1932568,(W=i,i=i+8|0,c[W>>2]=Cb,W)|0);i=W;rc=-22}else{rc=Ab}}while(0);JO(c[o>>2]|0,ob,1240808,0,0);qc=rc;break}Db=ob+52|0;Fb=c[Db>>2]|0;if((Fb|0)==0){Eb=uT(1238728,c[pb>>2]|0)|0;c[Db>>2]=Eb;sc=Eb}else{sc=Fb}Fb=ob+100|0;if((c[Fb>>2]|0)==0){qc=Ab;break}Eb=vT(1238728,sc)|0;rb=ob+96|0;do{if((Eb|0)==(c[pb>>2]|0)){Cb=(c[rb>>2]|0)+4|0;Bb=vT(1238728,d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0;if((Bb|0)==(c[pb>>2]|0)){break}Zy(c[o>>2]|0,(c[Fb>>2]|0)+90|0);Yy(c[o>>2]|0,c[Db>>2]|0);Bb=0;do{Py(c[o>>2]|0,0);Bb=Bb+1|0;}while((Bb|0)<82)}}while(0);Ry(c[o>>2]|0,c[rb>>2]|0,c[Fb>>2]|0);qc=Ab}else{Db=c[pb>>2]|0;if((Db|0)==86021|(Db|0)==31){Eb=c[o>>2]|0;if((Bdb(c[ob+96>>2]|0,c[ob+100>>2]|0,(Db|0)==86021?30:42,ya,Da)|0)<0){yDb(ha,16,1928984,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;qc=-1;break}else{Py(Eb,2);Bb=c[Da>>2]|0;Qy(Eb,255,(Bb|0)/255|0);Py(Eb,(Bb|0)%255|0);Bb=c[Ea>>2]|0;Qy(Eb,255,(Bb|0)/255|0);Py(Eb,(Bb|0)%255|0);Ry(Eb,c[ya>>2]|0,c[Da>>2]|0);Ry(Eb,c[Fa>>2]|0,c[Ea>>2]|0);Ry(Eb,c[Ga>>2]|0,c[Ha>>2]|0);qc=0;break}}else if((Db|0)==86028){qc=BC(c[o>>2]|0,ob,1)|0;break}else if((Db|0)==86041){Eb=c[o>>2]|0;Bb=c[ob+96>>2]|0;do{if((Bb|0)!=0){if((c[ob+100>>2]|0)!=2){break}Ry(Eb,Bb,2);qc=0;break f}}while(0);az(Eb,1027);qc=0;break}else if((Db|0)==28){qc=cX(c[o>>2]|0,c[ob+96>>2]|0,c[ob+100>>2]|0)|0;break}else if((Db|0)==1211250229){qc=iX(c[o>>2]|0,c[ob+96>>2]|0,c[ob+100>>2]|0,0)|0;break}else{Bb=c[ob+100>>2]|0;if((Db|0)!=86032){if((Bb|0)==0|(Db|0)==86038){qc=Ab;break}Ry(c[o>>2]|0,c[ob+96>>2]|0,Bb);qc=Ab;break}if((Bb|0)<36){yDb(ha,16,1944040,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;qc=-1094995529;break}else{Ry(c[o>>2]|0,(c[ob+96>>2]|0)+12|0,Bb-12|0);qc=Ab;break}}}}while(0);Ab=Oz(c[o>>2]|0,p)|0;if((Ab|0)!=0){ob=c[p>>2]|0;if(!Ba){tb=Ca;while(1){Py(y,25506>>>(tb<<3>>>0)&255);if((tb|0)==0){break}else{tb=tb-1|0}}}EG(y,Ab,(Ab|0)<0|0?-1:0,0);Ry(y,ob,Ab)}ZDb(c[p>>2]|0);if((qc|0)<0){$=qc;break a}}tb=Ty(y,0,0,1)|0;Bb=F;Fb=ZGb(sb,qb,vb,(vb|0)<0|0?-1:0)|0;rb=Ty(y,Fb,F,0)|0;Fb=F;Cb=0;if(!((Fb|0)<(Cb|0)|(Fb|0)==(Cb|0)&rb>>>0<0>>>0)){rb=ZGb(tb,Bb,sb,qb)|0;EG(y,rb,F,vb);Ty(y,tb,Bb,0)|0;}MT(nb,64,1,1e3);ub=zb}if(!(ub>>>0<(c[L>>2]|0)>>>0)){break b}ma=ub;mb=c[A>>2]|0}if((V|0)==130){yDb(ha,16,1966616,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;$=-22;break a}else if((V|0)==177){yDb(ha,16,1956192,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;$=-22;break a}else if((V|0)==194){yDb(ha,16,1951760,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;$=-22;break a}else if((V|0)==251){yDb(ha,16,1947664,(W=i,i=i+8|0,c[W>>2]=c[pb>>2],W)|0);i=W;$=-38;break a}else if((V|0)==261){yDb(ha,16,1945872,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;$=-22;break a}}}while(0);_=Ty(y,0,0,1)|0;mb=F;ma=ZGb(ba,Z,ca,(ca|0)<0|0?-1:0)|0;Ca=Ty(y,ma,F,0)|0;ma=F;Ba=0;if((ma|0)<(Ba|0)|(ma|0)==(Ba|0)&Ca>>>0<0>>>0){$=0;break}Ca=ZGb(_,mb,ba,Z)|0;EG(y,Ca,F,ca);Ty(y,_,mb,0)|0;$=0}else{$=-1}}while(0);if(($|0)<0){X=$;i=b;return X|0}$=a+1132|0;if((c[$>>2]|0)!=0){y=H+216|0;pb=c[a+1136>>2]|0;ub=0;qc=c[y>>2]|0;do{p=0;o=c[c[pb+(ub<<2)>>2]>>2]|0;sc=ZGb(1,0,o,(o|0)<0|0?-1:0)|0;o=F;qc=(p|0)>(o|0)|(p|0)==(o|0)&qc>>>0>sc>>>0?qc:sc;c[y>>2]=qc;ub=ub+1|0;}while(ub>>>0<(c[$>>2]|0)>>>0)}do{if((c[M>>2]|0)!=2){ub=AG(a)|0;if((ub|0)<0){X=ub;i=b;return X|0}ub=l;qc=c[G>>2]|0;c[ub>>2]=c[169576];c[ub+4>>2]=c[169577];c[ub+8>>2]=c[169578];c[ub+12>>2]=c[169579];RG(a,1185808,0);ub=c[T>>2]|0;y=BBb(ub,9203176,0,2)|0;g:do{if((y|0)!=0){pb=y;while(1){sc=pb|0;if((yAb(c[sc>>2]|0,2122816)|0)!=0){if((yAb(c[sc>>2]|0,1986176)|0)!=0){break}}pb=BBb(ub,9203176,pb,2)|0;if((pb|0)==0){break g}}pb=IG(a,c[T>>2]|0,0,0,l)|0;if((pb|0)<0){X=pb}else{break}i=b;return X|0}}while(0);h:do{if((c[L>>2]|0)!=0){ub=0;i:while(1){y=(c[(c[A>>2]|0)+(ub<<2)>>2]|0)+88|0;ca=c[y>>2]|0;Z=BBb(ca,9203176,0,2)|0;j:do{if((Z|0)!=0){ba=Z;while(1){pb=ba|0;if((yAb(c[pb>>2]|0,2122816)|0)!=0){if((yAb(c[pb>>2]|0,1986176)|0)!=0){break}}ba=BBb(ca,9203176,ba,2)|0;if((ba|0)==0){break j}}ba=IG(a,c[y>>2]|0,25541,ub+1|0,l)|0;if((ba|0)<0){X=ba;break i}}}while(0);ub=ub+1|0;if(!(ub>>>0<(c[L>>2]|0)>>>0)){break h}}i=b;return X|0}}while(0);k:do{if((c[$>>2]|0)!=0){ub=a+1136|0;y=qc+216|0;ca=0;l:while(1){Z=c[(c[ub>>2]|0)+(ca<<2)>>2]|0;zb=Z+32|0;nb=c[zb>>2]|0;vb=BBb(nb,9203176,0,2)|0;m:do{if((vb|0)!=0){qb=vb;while(1){sb=qb|0;if((yAb(c[sb>>2]|0,2122816)|0)!=0){if((yAb(c[sb>>2]|0,1986176)|0)!=0){break}}qb=BBb(nb,9203176,qb,2)|0;if((qb|0)==0){break m}}qb=IG(a,c[zb>>2]|0,25540,(c[y>>2]|0)+(c[Z>>2]|0)|0,l)|0;if((qb|0)<0){X=qb;break l}}}while(0);ca=ca+1|0;if(!(ca>>>0<(c[$>>2]|0)>>>0)){break k}}i=b;return X|0}}while(0);qc=l|0;ca=c[qc>>2]|0;y=c[qc+4>>2]|0;do{if(!((ca|0)==0&(y|0)==0)){qc=c[I>>2]|0;ub=c[l+8>>2]|0;Z=Ty(qc,0,0,1)|0;zb=F;nb=ZGb(ca,y,ub,(ub|0)<0|0?-1:0)|0;vb=Ty(qc,nb,F,0)|0;nb=F;qb=0;if((nb|0)<(qb|0)|(nb|0)==(qb|0)&vb>>>0<0>>>0){break}vb=ZGb(Z,zb,ca,y)|0;EG(qc,vb,F,ub);Ty(qc,Z,zb,0)|0;}}while(0);y=j|0;ca=c[G>>2]|0;zb=c[I>>2]|0;n:do{if((c[ca+184>>2]|0)==0){tc=0}else{oDb(e,hFb()|0);Z=c[ca+88>>2]|0;qc=Ty(zb,0,0,1)|0;ub=F;vb=Z+24|0;qb=c[Z+20>>2]|0;nb=Z+28|0;sb=c[nb>>2]|0;if(!((qb|0)<1|(qb|0)>(sb|0))){tc=-1;break}qb=aEb(c[vb>>2]|0,sb+1|0,16)|0;sb=qb;if((qb|0)==0){tc=-12;break}c[vb>>2]=sb;c[sb+(c[nb>>2]<<4)>>2]=423732329;vb=Z+8|0;Z=ZGb(qc,ub,c[vb>>2]|0,c[vb+4>>2]|0)|0;vb=c[nb>>2]|0;c[nb>>2]=vb+1;nb=sb+(vb<<4)+8|0;c[nb>>2]=Z;c[nb+4>>2]=F;FG(f,zb,423732329,0,0);nb=f|0;Z=c[nb>>2]|0;vb=c[nb+4>>2]|0;nb=c[f+8>>2]|0;o:do{if((c[L>>2]|0)!=0){sb=g|0;ub=g+8|0;qc=e+256|0;qb=a;Ab=d[1192062]|0;ob=(Ab+20|0)>>>0<7>>>0;ba=(Ab+7|0)/7|0;Ab=j;Db=0;p:while(1){Eb=c[(c[A>>2]|0)+(Db<<2)>>2]|0;pb=Eb+8|0;do{if((c[(c[pb>>2]|0)+8>>2]|0)==4){FG(g,zb,24999,0,0);ha=c[sb>>2]|0;sc=c[sb+4>>2]|0;o=c[ub>>2]|0;p=Eb+88|0;rc=BBb(c[p>>2]|0,2122816,0,0)|0;if((rc|0)!=0){GG(zb,18046,c[rc+4>>2]|0)}rc=BBb(c[p>>2]|0,2015496,0,0)|0;if((rc|0)==0){V=354;break p}GG(zb,18030,c[rc+4>>2]|0);rc=BBb(c[p>>2]|0,2004072,0,0)|0;if((rc|0)==0){p=c[pb>>2]|0;Tb=c[p+48>>2]|0;if((Tb|0)==0){V=362;break p}else{uc=0}while(1){pc=c[1185512+(uc*36|0)>>2]|0;if((pc|0)==0){V=362;break p}if((pc|0)==(Tb|0)){break}else{uc=uc+1|0}}vc=1185480+(uc*36|0)|0;wc=p}else{Tb=c[rc+4>>2]|0;if((Tb|0)==0){V=362;break p}vc=Tb;wc=c[pb>>2]|0}if((c[wc+88>>2]&8388608|0)==0){Tb=c[qc>>2]|0;c[e+((Tb&63)<<2)>>2]=(c[e+((Tb+9&63)<<2)>>2]|0)+(c[e+((Tb+40&63)<<2)>>2]|0);Tb=c[qc>>2]|0;c[qc>>2]=Tb+1;xc=0;yc=c[e+((Tb&63)<<2)>>2]|0}else{Tb=JFb()|0;if((Tb|0)==0){tc=-12;break n}KFb(Tb,160)|0;pc=c[pb>>2]|0;NFb(Tb,c[pc+96>>2]|0,c[pc+100>>2]|0);OFb(Tb,y);ZDb(Tb);xc=c[Ab+4>>2]|0;yc=c[Ab>>2]|0}yDb(qb,40,1993320,(W=i,i=i+24|0,c[W>>2]=yc,c[W+8>>2]=xc,c[W+16>>2]=Db,W)|0);i=W;GG(zb,18016,vc);Tb=c[pb>>2]|0;pc=c[Tb+96>>2]|0;Ub=c[Tb+100>>2]|0;if(!ob){Tb=ba;while(1){Py(zb,18012>>>(Tb<<3>>>0)&255);if((Tb|0)==0){break}else{Tb=Tb-1|0}}}EG(zb,Ub,(Ub|0)<0|0?-1:0,0);Ry(zb,pc,Ub);Tb=xc;rc=yc;p=1;while(1){Ob=rc>>>8|Tb<<24;oc=Tb>>>8|0<<24;if((Ob|0)==0&(oc|0)==0){break}else{Tb=oc;rc=Ob;p=p+1|0}}if(!ob){rc=ba;while(1){Py(zb,18094>>>(rc<<3>>>0)&255);if((rc|0)==0){break}else{rc=rc-1|0}}}EG(zb,p,(p|0)<0|0?-1:0,0);if((p|0)>0){rc=p;do{rc=rc-1|0;Tb=$Gb(yc|0,xc|0,rc<<3|0)|0;Py(zb,Tb&255);}while((rc|0)>0)}rc=Ty(zb,0,0,1)|0;p=F;Tb=ZGb(ha,sc,o,(o|0)<0|0?-1:0)|0;Ub=Ty(zb,Tb,F,0)|0;Tb=F;pc=0;if((Tb|0)<(pc|0)|(Tb|0)==(pc|0)&Ub>>>0<0>>>0){break}Ub=ZGb(rc,p,ha,sc)|0;EG(zb,Ub,F,o);Ty(zb,rc,p,0)|0;}}while(0);pb=Db+1|0;if(pb>>>0<(c[L>>2]|0)>>>0){Db=pb}else{break o}}if((V|0)==354){yDb(qb,16,2012032,(W=i,i=i+8|0,c[W>>2]=Db,W)|0);i=W;tc=-22;break n}else if((V|0)==362){yDb(qb,16,1996488,(W=i,i=i+8|0,c[W>>2]=Db,W)|0);i=W;tc=-22;break n}}}while(0);ba=Ty(zb,0,0,1)|0;ob=F;Ab=ZGb(Z,vb,nb,(nb|0)<0|0?-1:0)|0;qc=Ty(zb,Ab,F,0)|0;Ab=F;ub=0;if((Ab|0)<(ub|0)|(Ab|0)==(ub|0)&qc>>>0<0>>>0){tc=0;break}qc=ZGb(ba,ob,Z,vb)|0;EG(zb,qc,F,nb);Ty(zb,ba,ob,0)|0;tc=0}}while(0);if((tc|0)<0){X=tc}else{break}i=b;return X|0}}while(0);if((c[(c[I>>2]|0)+88>>2]|0)==0){DG(J,c[S>>2]|0)}S=c[z>>2]|0;I=c[z+4>>2]|0;z=cEb(16)|0;if((z|0)==0){c[H+92>>2]=0;X=-12;i=b;return X|0}tc=z;c[tc>>2]=S;c[tc+4>>2]=I;c[H+92>>2]=z;z=J+88|0;do{if((c[z>>2]|0)!=0){I=H+188|0;if((c[I>>2]|0)==0){break}tc=Ty(J,0,0,1)|0;S=H+200|0;c[S>>2]=tc;c[S+4>>2]=F;S=c[I>>2]|0;CG(J,S,(S|0)<0|0?-1:0)}}while(0);vZ(H+104|0);c[H+132>>2]=0;S=H+56|0;c[S>>2]=-1;c[S+4>>2]=-1;Sy(J);J=H+208|0;S=c[J+4>>2]|0;I=0;tc=(S|0)<(I|0)|(S|0)==(I|0)&(c[J>>2]|0)>>>0<0>>>0;if((c[z>>2]|0)==0){if(tc){c[J>>2]=1e3;c[J+4>>2]=0}z=H+192|0;if((c[z>>2]|0)>=0){X=0;i=b;return X|0}c[z>>2]=32768;X=0;i=b;return X|0}else{if(tc){c[J>>2]=5e3;c[J+4>>2]=0}J=H+192|0;if((c[J>>2]|0)>=0){X=0;i=b;return X|0}c[J>>2]=5242880;X=0;i=b;return X|0}return 0}function wG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a+12|0;h=c[g>>2]|0;j=a+16|0;k=c[j>>2]|0;l=(c[k+88>>2]|0)==0;if(l){m=c[h+8>>2]|0}else{m=k}if((b|0)==0){n=h+56|0;if((c[n>>2]|0)==(-1|0)&(c[n+4>>2]|0)==(-1|0)){o=0;i=d;return o|0}p=Ty(m,0,0,1)|0;q=F;yDb(a,48,2041208,(r=i,i=i+16|0,c[r>>2]=p,c[r+8>>2]=q,r)|0);i=r;q=h+40|0;p=c[q>>2]|0;s=c[q+4>>2]|0;q=c[h+48>>2]|0;t=Ty(m,0,0,1)|0;u=F;v=ZGb(p,s,q,(q|0)<0|0?-1:0)|0;w=Ty(m,v,F,0)|0;v=F;x=0;if(!((v|0)<(x|0)|(v|0)==(x|0)&w>>>0<0>>>0)){w=ZGb(t,u,p,s)|0;EG(m,w,F,q);Ty(m,t,u,0)|0;}c[n>>2]=-1;c[n+4>>2]=-1;do{if((c[h+8>>2]|0)!=0){n=(c[g>>2]|0)+8|0;u=c[n>>2]|0;if((u|0)==0){break}t=Oz(u,f)|0;Ry(c[j>>2]|0,c[f>>2]|0,t);ZDb(c[f>>2]|0);c[n>>2]=0}}while(0);Sy(c[j>>2]|0);o=0;i=d;return o|0}f=c[b+32>>2]|0;n=c[(c[(c[(c[a+28>>2]|0)+(f<<2)>>2]|0)+8>>2]|0)+8>>2]|0;t=c[b+36>>2]&1;if((c[(c[h+96>>2]|0)+(f<<3)>>2]|0)==0){f=b+8|0;u=h+64|0;m=ZGb(c[f>>2]|0,c[f+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;y=F;z=m}else{m=b+16|0;u=h+64|0;f=ZGb(c[m>>2]|0,c[m+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;y=F;z=f}if(l){l=c[h+8>>2]|0;f=Ty(l,0,0,1)|0;u=h+56|0;A=l;B=f;C=c[u+4>>2]|0;D=c[u>>2]|0}else{u=Ty(k,0,0,1)|0;f=h+56|0;l=c[f>>2]|0;m=c[f+4>>2]|0;f=ZGb(u,F,l,m)|0;A=k;B=f;C=m;D=l}l=h+56|0;a:do{if(!((D|0)==(-1|0)&(C|0)==(-1|0))){do{if((B|0)<=(c[h+192>>2]|0)){m=h+208|0;f=c[m+4>>2]|0;if((y|0)>(f|0)|(y|0)==(f|0)&z>>>0>(c[m>>2]|0)>>>0){break}if(!((t|0)!=0&(n|0)==0&(B|0)>4096)){break a}}}while(0);m=Ty(A,0,0,1)|0;f=F;k=b+8|0;u=c[k>>2]|0;q=c[k+4>>2]|0;k=b+16|0;w=c[k>>2]|0;s=c[k+4>>2]|0;yDb(a,48,2037800,(r=i,i=i+48|0,c[r>>2]=m,c[r+8>>2]=f,c[r+16>>2]=u,c[r+24>>2]=q,c[r+32>>2]=w,c[r+40>>2]=s,r)|0);i=r;s=h+40|0;w=c[s>>2]|0;q=c[s+4>>2]|0;s=c[h+48>>2]|0;u=Ty(A,0,0,1)|0;f=F;m=ZGb(w,q,s,(s|0)<0|0?-1:0)|0;k=Ty(A,m,F,0)|0;m=F;p=0;if(!((m|0)<(p|0)|(m|0)==(p|0)&k>>>0<0>>>0)){k=ZGb(u,f,w,q)|0;EG(A,k,F,s);Ty(A,u,f,0)|0;}c[l>>2]=-1;c[l+4>>2]=-1;do{if((c[h+8>>2]|0)!=0){f=(c[g>>2]|0)+8|0;u=c[f>>2]|0;if((u|0)==0){break}s=Oz(u,e)|0;Ry(c[j>>2]|0,c[e>>2]|0,s);ZDb(c[e>>2]|0);c[f>>2]=0}}while(0);Sy(c[j>>2]|0)}}while(0);j=h+104|0;e=j;do{if((c[h+132>>2]|0)>0){g=zG(a,e)|0;BZ(e);if((g|0)>=0){break}yDb(a,16,2204328,(r=i,i=i+8|0,c[r>>2]=g,r)|0);i=r;o=g;i=d;return o|0}}while(0);if((n|0)!=1){o=zG(a,b)|0;i=d;return o|0}UGb(j|0,b|0,80)|0;a=c[b>>2]|0;if((a|0)==0){E=CZ(e)|0}else{b=WAb(a)|0;c[j>>2]=b;E=(b|0)!=0?0:-12}if((c[h+148>>2]|0)<=0){o=E;i=d;return o|0}o=AZ(e,e)|0;i=d;return o|0}function xG(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0;b=i;i=i+8|0;e=b|0;f=a+12|0;g=c[f>>2]|0;j=a+16|0;l=c[j>>2]|0;m=g+104|0;do{if((c[g+132>>2]|0)>0){n=zG(a,m)|0;BZ(m);if((n|0)>=0){break}yDb(a,16,2204328,(o=i,i=i+8|0,c[o>>2]=n,o)|0);i=o;p=n;i=b;return p|0}}while(0);m=c[g+8>>2]|0;do{if((m|0)==0){n=g+56|0;if((c[n>>2]|0)==(-1|0)&(c[n+4>>2]|0)==(-1|0)){break}n=g+40|0;q=c[n>>2]|0;r=c[n+4>>2]|0;n=c[g+48>>2]|0;s=Ty(l,0,0,1)|0;t=F;u=ZGb(q,r,n,(n|0)<0|0?-1:0)|0;v=Ty(l,u,F,0)|0;u=F;w=0;if((u|0)<(w|0)|(u|0)==(w|0)&v>>>0<0>>>0){break}v=ZGb(s,t,q,r)|0;EG(l,v,F,n);Ty(l,s,t,0)|0;}else{t=g+40|0;s=c[t>>2]|0;n=c[t+4>>2]|0;t=c[g+48>>2]|0;v=Ty(m,0,0,1)|0;r=F;q=ZGb(s,n,t,(t|0)<0|0?-1:0)|0;w=Ty(m,q,F,0)|0;q=F;u=0;if(!((q|0)<(u|0)|(q|0)==(u|0)&w>>>0<0>>>0)){w=ZGb(v,r,s,n)|0;EG(m,w,F,t);Ty(m,v,r,0)|0;}r=(c[f>>2]|0)+8|0;v=c[r>>2]|0;if((v|0)==0){break}t=Oz(v,e)|0;Ry(c[j>>2]|0,c[e>>2]|0,t);ZDb(c[e>>2]|0);c[r>>2]=0}}while(0);do{if((c[g+4>>2]|0)!=2){e=AG(a)|0;if((e|0)<0){p=e}else{break}i=b;return p|0}}while(0);if((c[l+88>>2]|0)!=0){e=g+92|0;j=c[e>>2]|0;do{if((c[j+12>>2]|0)==0){x=g+88|0}else{f=g+188|0;if((c[f>>2]|0)==0){m=BG(l,j,c[g+96>>2]|0,c[a+24>>2]|0)|0;y=F;z=m}else{m=Ty(l,0,0,1)|0;r=F;t=g+200|0;Ty(l,c[t>>2]|0,c[t+4>>2]|0,0)|0;t=BG(l,c[e>>2]|0,c[g+96>>2]|0,c[a+24>>2]|0)|0;v=F;w=Ty(l,0,0,1)|0;n=F;s=c[f>>2]|0;f=s;u=(s|0)<0|0?-1:0;q=YGb(f,u,t,v)|0;A=F;if((n|0)>(A|0)|(n|0)==(A|0)&w>>>0>q>>>0){B=ZGb(w,n,t,v)|0;C=F;yDb(a,16,2196712,(o=i,i=i+24|0,c[o>>2]=s,c[o+8>>2]=B,c[o+16>>2]=C,o)|0);i=o;p=-22;i=b;return p|0}if((n|0)<(A|0)|(n|0)==(A|0)&w>>>0<q>>>0){q=ZGb(t,v,w,n)|0;n=YGb(q,F,f,u)|0;CG(l,n,F)}Ty(l,m,r,0)|0;y=v;z=t}t=g+88|0;v=c[t>>2]|0;r=v+24|0;m=c[v+20>>2]|0;n=v+28|0;u=c[n>>2]|0;if(!((m|0)<1|(m|0)>(u|0))){p=-1;i=b;return p|0}m=aEb(c[r>>2]|0,u+1|0,16)|0;u=m;if((m|0)==0){p=-12;i=b;return p|0}else{c[r>>2]=u;c[u+(c[n>>2]<<4)>>2]=475249515;r=v+8|0;v=ZGb(z,y,c[r>>2]|0,c[r+4>>2]|0)|0;r=c[n>>2]|0;c[n>>2]=r+1;n=u+(r<<4)+8|0;c[n>>2]=v;c[n+4>>2]=F;x=t;break}}}while(0);DG(l,c[x>>2]|0);x=g+80|0;y=c[x+4>>2]|0;yDb(a,48,2183976,(o=i,i=i+16|0,c[o>>2]=c[x>>2],c[o+8>>2]=y,o)|0);i=o;o=Ty(l,0,0,1)|0;y=F;a=g+72|0;Ty(l,c[a>>2]|0,c[a+4>>2]|0,0)|0;D=+((c[x>>2]|0)>>>0)+ +(c[x+4>>2]|0)*4294967296.0;x=d[1192060]|0;if(!((x+20|0)>>>0<7>>>0)){a=(x+7|0)/7|0;while(1){Py(l,17545>>>(a<<3>>>0)&255);if((a|0)==0){break}else{a=a-1|0}}}Py(l,136);h[k>>3]=D;ez(l,c[k>>2]|0,c[k+4>>2]|0);Ty(l,o,y,0)|0;}y=g+16|0;o=c[y>>2]|0;a=c[y+4>>2]|0;y=c[g+24>>2]|0;x=Ty(l,0,0,1)|0;z=F;e=ZGb(o,a,y,(y|0)<0|0?-1:0)|0;j=Ty(l,e,F,0)|0;e=F;t=0;if(!((e|0)<(t|0)|(e|0)==(t|0)&j>>>0<0>>>0)){j=ZGb(x,z,o,a)|0;EG(l,j,F,y);Ty(l,x,z,0)|0;}$Db(g+96|0);z=g+92|0;$Db((c[z>>2]|0)+8|0);$Db(z);p=0;i=b;return p|0}function yG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=0;while(1){e=c[1185856+(d*28|0)>>2]|0;if((e|0)==0){break}if((e|0)==(a|0)){f=1;g=7;break}else{d=d+1|0}}if((g|0)==7){return f|0}do{if((b|0)<0){if((d1a(a)|0)>>>0<2>>>0){f=1}else{break}return f|0}}while(0);f=0;return f|0}function zG(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;f=i;i=i+2360|0;g=f|0;h=f+8|0;j=f+16|0;k=f+32|0;l=f+40|0;m=f+48|0;n=f+56|0;o=f+64|0;p=f+72|0;q=f+80|0;r=f+88|0;s=f+96|0;t=f+176|0;u=f+192|0;v=f+200|0;w=f+208|0;x=f+216|0;y=f+224|0;z=f+232|0;A=f+240|0;B=f+248|0;C=f+256|0;D=f+264|0;E=f+2312|0;G=f+2328|0;H=f+2344|0;I=b+12|0;J=c[I>>2]|0;K=b+16|0;L=c[K>>2]|0;M=e+32|0;N=c[M>>2]|0;O=b+28|0;P=c[(c[(c[O>>2]|0)+(N<<2)>>2]|0)+8>>2]|0;Q=c[e+36>>2]&1;R=e+48|0;S=c[R>>2]|0;T=e+16|0;U=e+8|0;V=(c[(c[J+96>>2]|0)+(N<<3)>>2]|0)==0?U:T;N=c[V>>2]|0;W=c[V+4>>2]|0;if((N|0)==0&(W|0)==(-2147483648|0)){yDb(b,16,2107048,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;Y=-22;i=f;return Y|0}do{if((c[L+88>>2]|0)==0){V=J+8|0;Z=c[V>>2]|0;if((Z|0)!=0){_=Z;break}Z=Mz(V)|0;if((Z|0)>=0){_=c[V>>2]|0;break}yDb(b,16,2095992,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;Y=Z;i=f;return Y|0}else{_=L}}while(0);L=J+56|0;if((c[L>>2]|0)==(-1|0)&(c[L+4>>2]|0)==(-1|0)){Z=Ty(c[K>>2]|0,0,0,1)|0;c[L>>2]=Z;c[L+4>>2]=F;Z=J+40|0;FG(G,_,524531317,0,0);V=G;c[Z>>2]=c[V>>2];c[Z+4>>2]=c[V+4>>2];c[Z+8>>2]=c[V+8>>2];c[Z+12>>2]=c[V+12>>2];V=0;G=(W|0)<(V|0)|(W|0)==(V|0)&N>>>0<0>>>0;V=G?0:N;$=G?0:W;G=$;aa=V;ca=1;while(1){da=aa>>>8|G<<24;ea=G>>>8|0<<24;if((da|0)==0&(ea|0)==0){break}else{G=ea;aa=da;ca=ca+1|0}}aa=d[1192224]|0;if(!((aa+12|0)>>>0<7>>>0)){G=(aa-1|0)/7|0;while(1){Py(_,231>>>(G<<3>>>0)&255);if((G|0)==0){break}else{G=G-1|0}}}EG(_,ca,(ca|0)<0|0?-1:0,0);if((ca|0)>0){G=ca;do{G=G-1|0;ca=$Gb(V|0,$|0,G<<3|0)|0;Py(_,ca&255);}while((G|0)>0)}G=J+64|0;c[G>>2]=V;c[G+4>>2]=$;fa=Z}else{fa=J+40|0}Z=Ty(c[K>>2]|0,0,0,1)|0;K=fa;fa=ZGb(Z,F,c[K>>2]|0,c[K+4>>2]|0)|0;K=F;Z=P+8|0;a:do{if((c[Z>>2]|0)==3){$=c[P+48>>2]|0;if(($|0)==94216){UGb(s|0,e|0,80)|0;G=s+24|0;V=0;ca=c[G>>2]|0;do{aa=xd(ca|0,2080440,(X=i,i=i+64|0,c[X>>2]=k,c[X+8>>2]=l,c[X+16>>2]=m,c[X+24>>2]=n,c[X+32>>2]=o,c[X+40>>2]=p,c[X+48>>2]=q,c[X+56>>2]=r,X)|0)|0;i=X;if((aa|0)==8){aa=(c[l>>2]|0)+((c[k>>2]|0)*60|0)|0;c[l>>2]=aa;da=(c[p>>2]|0)+((c[o>>2]|0)*60|0)|0;c[p>>2]=da;ea=(c[m>>2]|0)+(aa*60|0)|0;c[m>>2]=ea;aa=(c[q>>2]|0)+(da*60|0)|0;c[q>>2]=aa;da=(c[n>>2]|0)+(ea*1e3|0)|0;c[n>>2]=da;ea=(c[r>>2]|0)+(aa*1e3|0)|0;c[r>>2]=ea;ga=ea-da|0}else{ga=0}da=c[G>>2]|0;ea=hc(da|0,2075232)|0;aa=a[da+ea|0]|0;if(aa<<24>>24==13){ha=ea+1|0;ia=ha;ja=a[da+ha|0]|0}else{ia=ea;ja=aa}ca=da+((ja<<24>>24==10)+ia)|0;c[G>>2]=ca;V=V+1|0;}while((V|0)<2&(ga|0)==0);V=s+28|0;G=(c[e+24>>2]|0)-ca+(c[V>>2]|0)|0;c[V>>2]=G;V=G+4|0;da=YGb(V,(V|0)<0|0?-1:0,1,0)|0;V=F;aa=1;while(1){ea=$Gb(da|0,V|0,aa*7|0|0)|0;if((ea|0)==0&(F|0)==0){break}else{aa=aa+1|0}}V=G+14+aa|0;da=YGb(V,(V|0)<0|0?-1:0,1,0)|0;ca=F;ea=1;while(1){ha=$Gb(da|0,ca|0,ea*7|0|0)|0;if((ha|0)==0&(F|0)==0){break}else{ea=ea+1|0}}ca=ga;da=(ga|0)<0|0?-1:0;aa=V+1+ea|0;FG(t,_,160,aa,(aa|0)<0|0?-1:0);aa=t|0;G=c[aa>>2]|0;ha=c[aa+4>>2]|0;aa=c[t+8>>2]|0;HG(b,_,161,s,0);ka=da;la=ca;ma=1;while(1){na=la>>>8|ka<<24;oa=ka>>>8|0<<24;if((na|0)==0&(oa|0)==0){break}else{ka=oa;la=na;ma=ma+1|0}}la=d[1192148]|0;if(!((la+12|0)>>>0<7>>>0)){ka=(la-1|0)/7|0;while(1){Py(_,155>>>(ka<<3>>>0)&255);if((ka|0)==0){break}else{ka=ka-1|0}}}EG(_,ma,(ma|0)<0|0?-1:0,0);if((ma|0)>0){ka=ma;do{ka=ka-1|0;la=$Gb(ca|0,da|0,ka<<3|0)|0;Py(_,la&255);}while((ka|0)>0)}ka=Ty(_,0,0,1)|0;da=F;ca=ZGb(G,ha,aa,(aa|0)<0|0?-1:0)|0;ma=Ty(_,ca,F,0)|0;ca=F;la=0;if((ca|0)<(la|0)|(ca|0)==(la|0)&ma>>>0<0>>>0){pa=ga;break}ma=ZGb(ka,da,G,ha)|0;EG(_,ma,F,aa);Ty(_,ka,da,0)|0;pa=ga;break}else if(($|0)==94212){da=D|0;ka=c[I>>2]|0;c[C>>2]=0;ma=c[e+28>>2]|0;if((ma|0)==0){pa=0;break}la=b;ca=E|0;ea=E+8|0;V=d[1192154]|0;na=(V+12|0)>>>0<7>>>0;oa=ka+64|0;ka=d[1192148]|0;qa=(ka+12|0)>>>0<7>>>0;ra=(ka-1|0)/7|0;ka=(V-1|0)/7|0;V=0;sa=ma;ma=c[e+24>>2]|0;while(1){ta=xd(ma|0,2058472,(X=i,i=i+64|0,c[X>>2]=u,c[X+8>>2]=v,c[X+16>>2]=w,c[X+24>>2]=x,c[X+32>>2]=y,c[X+40>>2]=z,c[X+48>>2]=A,c[X+56>>2]=B,X)|0)|0;i=X;if((ta|0)==8){ua=(((c[z>>2]|0)-(c[v>>2]|0)|0)*6e4|0)+(ba((c[y>>2]|0)-(c[u>>2]|0)|0,36e5)|0)+(((c[A>>2]|0)-(c[w>>2]|0)|0)*1e3|0)+(((c[B>>2]|0)-(c[x>>2]|0)|0)*10|0)|0}else{ua=0}ta=(ua|0)>(V|0)?ua:V;va=Ib(ma|0,10,sa|0)|0;if((va|0)==0){wa=0;xa=sa;ya=ma}else{za=ma;wa=(a[va-1|0]|0)==13?2:1;xa=1-za+va|0;ya=za}za=xa-wa|0;va=Ib(ma|0,44,za|0)|0;if((va|0)==0){pa=ta;break a}Aa=va+1|0;va=za+ya|0;za=Ib(Aa|0,44,va-Aa|0)|0;if((za|0)==0){pa=ta;break a}Aa=za+1|0;za=Ib(Aa|0,44,va-Aa|0)|0;if((za|0)==0){pa=ta;break a}Aa=za+1|0;xd(ma|0,2070640,(X=i,i=i+8|0,c[X>>2]=C,X)|0)|0;i=X;za=(c[(c[O>>2]|0)+(c[M>>2]<<2)>>2]|0)+64|0;Ba=c[za+4>>2]|0;Ca=c[C>>2]|0;Da=Lb(da|0,2048,2066104,(X=i,i=i+24|0,c[X>>2]=c[za>>2],c[X+8>>2]=Ba,c[X+16>>2]=Ca,X)|0)|0;i=X;Ca=va-Aa+Da|0;va=Ca>>>0>2048>>>0?2048:Ca;UGb(D+Da|0,Aa|0,va-Da|0)|0;Da=Ty(_,0,0,1)|0;Aa=F;Ca=c[U>>2]|0;Ba=c[U+4>>2]|0;yDb(la,48,2061920,(X=i,i=i+48|0,c[X>>2]=Da,c[X+8>>2]=Aa,c[X+16>>2]=va,c[X+24>>2]=Ca,c[X+32>>2]=Ba,c[X+40>>2]=ua,X)|0);i=X;Ba=va+4|0;Ca=Ba;Aa=(Ba|0)<0|0?-1:0;Ba=YGb(Ca,Aa,1,0)|0;Da=F;za=1;while(1){Ea=$Gb(Ba|0,Da|0,za*7|0|0)|0;if((Ea|0)==0&(F|0)==0){break}else{za=za+1|0}}Da=va+14+za|0;Ba=YGb(Da,(Da|0)<0|0?-1:0,1,0)|0;Ea=F;Fa=1;while(1){Ga=$Gb(Ba|0,Ea|0,Fa*7|0|0)|0;if((Ga|0)==0&(F|0)==0){break}else{Fa=Fa+1|0}}Ea=Da+1+Fa|0;FG(E,_,160,Ea,(Ea|0)<0|0?-1:0);Ea=c[ca>>2]|0;Ba=c[ca+4>>2]|0;za=c[ea>>2]|0;if(!na){Ga=ka;while(1){Py(_,161>>>(Ga<<3>>>0)&255);if((Ga|0)==0){break}else{Ga=Ga-1|0}}}EG(_,Ca,Aa,0);Py(_,(c[M>>2]|0)+1|128);Ga=ZGb(c[U>>2]|0,c[U+4>>2]|0,c[oa>>2]|0,c[oa+4>>2]|0)|0;fz(_,Ga);Py(_,0);Ry(_,da,va);Ga=ua;Fa=(ua|0)<0|0?-1:0;Da=Fa;Ha=Ga;Ia=1;while(1){Ja=Ha>>>8|Da<<24;Ka=Da>>>8|0<<24;if((Ja|0)==0&(Ka|0)==0){break}else{Da=Ka;Ha=Ja;Ia=Ia+1|0}}if(!qa){Ha=ra;while(1){Py(_,155>>>(Ha<<3>>>0)&255);if((Ha|0)==0){break}else{Ha=Ha-1|0}}}EG(_,Ia,(Ia|0)<0|0?-1:0,0);if((Ia|0)>0){Ha=Ia;do{Ha=Ha-1|0;Da=$Gb(Ga|0,Fa|0,Ha<<3|0)|0;Py(_,Da&255);}while((Ha|0)>0)}Ha=Ty(_,0,0,1)|0;Fa=F;Ga=ZGb(Ea,Ba,za,(za|0)<0|0?-1:0)|0;Ia=Ty(_,Ga,F,0)|0;Ga=F;Da=0;if(!((Ga|0)<(Da|0)|(Ga|0)==(Da|0)&Ia>>>0<0>>>0)){Ia=ZGb(Ha,Fa,Ea,Ba)|0;EG(_,Ia,F,za);Ty(_,Ha,Fa,0)|0;}if((sa|0)==(xa|0)){pa=ta;break}else{V=ta;sa=sa-xa|0;ma=ma+xa|0}}}else if(($|0)==1465275476){ma=c[I>>2]|0;sa=(c[(c[ma+96>>2]|0)+(c[M>>2]<<3)>>2]|0)==0?U:T;V=c[sa>>2]|0;ra=c[sa+4>>2]|0;c[g>>2]=0;sa=HZ(e,75,g)|0;c[h>>2]=0;qa=HZ(e,76,h)|0;da=e+28|0;oa=(c[g>>2]|0)+2+(c[h>>2]|0)+(c[da>>2]|0)|0;ka=Ty(_,0,0,1)|0;na=F;ea=c[U>>2]|0;ca=c[U+4>>2]|0;la=c[T>>2]|0;aa=c[T+4>>2]|0;ha=c[R>>2]|0;yDb(b,48,2090480,(X=i,i=i+72|0,c[X>>2]=ka,c[X+8>>2]=na,c[X+16>>2]=oa,c[X+24>>2]=ea,c[X+32>>2]=ca,c[X+40>>2]=la,c[X+48>>2]=aa,c[X+56>>2]=ha,c[X+64>>2]=0,X)|0);i=X;ha=oa+4|0;aa=ha;la=(ha|0)<0|0?-1:0;ha=YGb(aa,la,1,0)|0;ca=F;ea=1;while(1){na=$Gb(ha|0,ca|0,ea*7|0|0)|0;if((na|0)==0&(F|0)==0){break}else{ea=ea+1|0}}ca=oa+14+ea|0;ha=YGb(ca,(ca|0)<0|0?-1:0,1,0)|0;$=F;na=1;while(1){ka=$Gb(ha|0,$|0,na*7|0|0)|0;if((ka|0)==0&(F|0)==0){break}else{na=na+1|0}}$=ca+1+na|0;FG(j,_,160,$,($|0)<0|0?-1:0);$=j|0;ha=c[$>>2]|0;ea=c[$+4>>2]|0;$=c[j+8>>2]|0;oa=d[1192154]|0;if(!((oa+12|0)>>>0<7>>>0)){ka=(oa-1|0)/7|0;while(1){Py(_,161>>>(ka<<3>>>0)&255);if((ka|0)==0){break}else{ka=ka-1|0}}}EG(_,aa,la,0);Py(_,(c[M>>2]|0)+1|128);ka=ma+64|0;na=ZGb(V,ra,c[ka>>2]|0,c[ka+4>>2]|0)|0;fz(_,na);Py(_,0);na=c[h>>2]|0;ka=c[da>>2]|0;ca=c[e+24>>2]|0;Kz(_,2085560,(X=i,i=i+48|0,c[X>>2]=c[g>>2],c[X+8>>2]=sa,c[X+16>>2]=na,c[X+24>>2]=qa,c[X+32>>2]=ka,c[X+40>>2]=ca,X)|0)|0;i=X;ca=c[R>>2]|0;ka=ca;na=(ca|0)<0|0?-1:0;ca=na;oa=ka;G=1;while(1){Fa=oa>>>8|ca<<24;Ha=ca>>>8|0<<24;if((Fa|0)==0&(Ha|0)==0){break}else{ca=Ha;oa=Fa;G=G+1|0}}oa=d[1192148]|0;if(!((oa+12|0)>>>0<7>>>0)){ca=(oa-1|0)/7|0;while(1){Py(_,155>>>(ca<<3>>>0)&255);if((ca|0)==0){break}else{ca=ca-1|0}}}EG(_,G,(G|0)<0|0?-1:0,0);if((G|0)>0){ca=G;do{ca=ca-1|0;oa=$Gb(ka|0,na|0,ca<<3|0)|0;Py(_,oa&255);}while((ca|0)>0)}ca=Ty(_,0,0,1)|0;na=F;ka=ZGb(ha,ea,$,($|0)<0|0?-1:0)|0;G=Ty(_,ka,F,0)|0;ka=F;oa=0;if(!((ka|0)<(oa|0)|(ka|0)==(oa|0)&G>>>0<0>>>0)){G=ZGb(ca,na,ha,ea)|0;EG(_,G,F,$);Ty(_,ca,na,0)|0;}pa=c[R>>2]|0;break}else{na=c[e+28>>2]|0;ca=na+4|0;G=YGb(ca,(ca|0)<0|0?-1:0,1,0)|0;ca=F;oa=1;while(1){ka=$Gb(G|0,ca|0,oa*7|0|0)|0;if((ka|0)==0&(F|0)==0){break}else{oa=oa+1|0}}ca=na+14+oa|0;G=YGb(ca,(ca|0)<0|0?-1:0,1,0)|0;$=F;ea=1;while(1){ha=$Gb(G|0,$|0,ea*7|0|0)|0;if((ha|0)==0&(F|0)==0){break}else{ea=ea+1|0}}$=ca+1+ea|0;FG(H,_,160,$,($|0)<0|0?-1:0);$=e+72|0;G=c[$>>2]|0;oa=c[$+4>>2]|0;$=0;na=(oa|0)>($|0)|(oa|0)==($|0)&G>>>0>0>>>0?G:S;HG(b,_,161,e,0);G=na;$=(na|0)<0|0?-1:0;oa=$;ha=G;ka=1;while(1){qa=ha>>>8|oa<<24;sa=oa>>>8|0<<24;if((qa|0)==0&(sa|0)==0){break}else{oa=sa;ha=qa;ka=ka+1|0}}ha=d[1192148]|0;if(!((ha+12|0)>>>0<7>>>0)){oa=(ha-1|0)/7|0;while(1){Py(_,155>>>(oa<<3>>>0)&255);if((oa|0)==0){break}else{oa=oa-1|0}}}EG(_,ka,(ka|0)<0|0?-1:0,0);if((ka|0)>0){oa=ka;do{oa=oa-1|0;ha=$Gb(G|0,$|0,oa<<3|0)|0;Py(_,ha&255);}while((oa|0)>0)}oa=H|0;$=c[oa>>2]|0;G=c[oa+4>>2]|0;oa=c[H+8>>2]|0;ka=Ty(_,0,0,1)|0;ha=F;ea=ZGb($,G,oa,(oa|0)<0|0?-1:0)|0;ca=Ty(_,ea,F,0)|0;ea=F;qa=0;if((ea|0)<(qa|0)|(ea|0)==(qa|0)&ca>>>0<0>>>0){pa=na;break}ca=ZGb(ka,ha,$,G)|0;EG(_,ca,F,oa);Ty(_,ka,ha,0)|0;pa=na;break}}else{HG(b,_,163,e,Q<<7);pa=S}}while(0);S=c[Z>>2]|0;Z=(S|0)==3;do{if((Q|0)!=0&(S|0)==0|Z){e=c[J+92>>2]|0;_=c[M>>2]|0;b=c[L>>2]|0;H=c[L+4>>2]|0;R=pa;X=(pa|0)<0|0?-1:0;g=e+8|0;h=0;if((W|0)<(h|0)|(W|0)==(h|0)&N>>>0<0>>>0){La=X;Ma=R;break}h=e+12|0;j=aEb(c[g>>2]|0,(c[h>>2]|0)+1|0,40)|0;T=j;if((j|0)==0){Y=-12;i=f;return Y|0}else{c[g>>2]=T;g=c[h>>2]|0;j=T+(g*40|0)|0;c[j>>2]=N;c[j+4>>2]=W;c[T+(g*40|0)+8>>2]=_+1;_=e|0;e=ZGb(b,H,c[_>>2]|0,c[_+4>>2]|0)|0;_=c[h>>2]|0;H=T+(_*40|0)+16|0;c[H>>2]=e;c[H+4>>2]=F;H=T+(_*40|0)+24|0;c[H>>2]=fa;c[H+4>>2]=K;c[h>>2]=_+1;h=T+(_*40|0)+32|0;c[h>>2]=Z?R:-1;c[h+4>>2]=Z?X:-1;La=X;Ma=R;break}}else{La=(pa|0)<0|0?-1:0;Ma=pa}}while(0);pa=J+80|0;J=c[pa>>2]|0;Z=c[pa+4>>2]|0;K=YGb(Ma,La,N,W)|0;W=F;N=(Z|0)>(W|0)|(Z|0)==(W|0)&J>>>0>K>>>0;c[pa>>2]=N?J:K;c[pa+4>>2]=N?Z:W;Y=0;i=f;return Y|0}function AG(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+64|0;e=b|0;f=b+16|0;g=b+32|0;h=b+48|0;j=c[a+12>>2]|0;k=c[a+16>>2]|0;l=a+1132|0;if((c[l>>2]|0)==0){m=0;i=b;return m|0}n=j+220|0;if((c[n>>2]|0)!=0){m=0;i=b;return m|0}o=c[j+88>>2]|0;p=Ty(k,0,0,1)|0;q=F;r=o+24|0;s=c[o+20>>2]|0;t=o+28|0;u=c[t>>2]|0;if(!((s|0)<1|(s|0)>(u|0))){m=-1;i=b;return m|0}s=aEb(c[r>>2]|0,u+1|0,16)|0;u=s;if((s|0)==0){m=-12;i=b;return m|0}c[r>>2]=u;c[u+(c[t>>2]<<4)>>2]=272869232;r=o+8|0;o=ZGb(p,q,c[r>>2]|0,c[r+4>>2]|0)|0;r=c[t>>2]|0;c[t>>2]=r+1;t=u+(r<<4)+8|0;c[t>>2]=o;c[t+4>>2]=F;FG(e,k,272869232,0,0);t=e|0;o=c[t>>2]|0;r=c[t+4>>2]|0;t=c[e+8>>2]|0;FG(f,k,17849,0,0);e=f|0;u=c[e>>2]|0;q=c[e+4>>2]|0;e=c[f+8>>2]|0;f=d[1192061]|0;p=(f+20|0)>>>0<7>>>0;do{if(p){EG(k,1,0,0);Py(k,1)}else{s=(f+7|0)/7|0;while(1){Py(k,17883>>>(s<<3>>>0)&255);if((s|0)==0){break}else{s=s-1|0}}EG(k,1,0,0);Py(k,1);if(p){break}s=(f+7|0)/7|0;while(1){Py(k,17853>>>(s<<3>>>0)&255);if((s|0)==0){break}else{s=s-1|0}}}}while(0);EG(k,1,0,0);Py(k,0);if((c[l>>2]|0)!=0){s=a+1136|0;a=g|0;v=g+8|0;w=j+216|0;j=d[1192107]|0;x=(j+20|0)>>>0<7>>>0;y=d[1192138]|0;z=(y+12|0)>>>0<7>>>0;A=d[1192139]|0;B=(A+12|0)>>>0<7>>>0;C=d[1192145]|0;D=(C+12|0)>>>0<7>>>0;E=h|0;G=h+8|0;H=(f+7|0)/7|0;f=(C-1|0)/7|0;C=(A-1|0)/7|0;A=(y-1|0)/7|0;y=(j+7|0)/7|0;j=0;do{I=c[(c[s>>2]|0)+(j<<2)>>2]|0;FG(g,k,182,0,0);J=c[a>>2]|0;K=c[a+4>>2]|0;L=c[v>>2]|0;M=(c[w>>2]|0)+(c[I>>2]|0)|0;N=0;O=N;P=M;Q=1;while(1){R=P>>>8|O<<24;S=O>>>8|0<<24;if((R|0)==0&(S|0)==0){break}else{O=S;P=R;Q=Q+1|0}}if(!x){P=y;while(1){Py(k,29636>>>(P<<3>>>0)&255);if((P|0)==0){break}else{P=P-1|0}}}EG(k,Q,(Q|0)<0|0?-1:0,0);if((Q|0)>0){P=Q;do{P=P-1|0;O=$Gb(M|0,N|0,P<<3|0)|0;Py(k,O&255);}while((P|0)>0)}P=I+16|0;N=I+4|0;M=KDb(c[P>>2]|0,c[P+4>>2]|0,N,678320)|0;P=F;Q=P;O=M;R=1;while(1){S=O>>>8|Q<<24;T=Q>>>8|0<<24;if((S|0)==0&(T|0)==0){break}else{Q=T;O=S;R=R+1|0}}if(!z){O=A;while(1){Py(k,145>>>(O<<3>>>0)&255);if((O|0)==0){break}else{O=O-1|0}}}EG(k,R,(R|0)<0|0?-1:0,0);if((R|0)>0){O=R;do{O=O-1|0;Q=$Gb(M|0,P|0,O<<3|0)|0;Py(k,Q&255);}while((O|0)>0)}O=I+24|0;P=KDb(c[O>>2]|0,c[O+4>>2]|0,N,678320)|0;O=F;M=O;R=P;Q=1;while(1){S=R>>>8|M<<24;T=M>>>8|0<<24;if((S|0)==0&(T|0)==0){break}else{M=T;R=S;Q=Q+1|0}}if(!B){R=C;while(1){Py(k,146>>>(R<<3>>>0)&255);if((R|0)==0){break}else{R=R-1|0}}}EG(k,Q,(Q|0)<0|0?-1:0,0);if((Q|0)>0){R=Q;do{R=R-1|0;M=$Gb(P|0,O|0,R<<3|0)|0;Py(k,M&255);}while((R|0)>0)}if(!D){R=f;while(1){Py(k,152>>>(R<<3>>>0)&255);if((R|0)==0){break}else{R=R-1|0}}}EG(k,1,0,0);Py(k,0);if(!p){R=H;while(1){Py(k,17816>>>(R<<3>>>0)&255);if((R|0)==0){break}else{R=R-1|0}}}EG(k,1,0,0);Py(k,1);R=BBb(c[I+32>>2]|0,2122816,0,0)|0;do{if((R|0)!=0){FG(h,k,128,0,0);O=c[E>>2]|0;P=c[E+4>>2]|0;Q=c[G>>2]|0;GG(k,133,c[R+4>>2]|0);GG(k,17276,2117632);M=Ty(k,0,0,1)|0;N=F;S=ZGb(O,P,Q,(Q|0)<0|0?-1:0)|0;T=Ty(k,S,F,0)|0;S=F;U=0;if((S|0)<(U|0)|(S|0)==(U|0)&T>>>0<0>>>0){break}T=ZGb(M,N,O,P)|0;EG(k,T,F,Q);Ty(k,M,N,0)|0;}}while(0);R=Ty(k,0,0,1)|0;I=F;N=ZGb(J,K,L,(L|0)<0|0?-1:0)|0;M=Ty(k,N,F,0)|0;N=F;Q=0;if(!((N|0)<(Q|0)|(N|0)==(Q|0)&M>>>0<0>>>0)){M=ZGb(R,I,J,K)|0;EG(k,M,F,L);Ty(k,R,I,0)|0;}j=j+1|0;}while(j>>>0<(c[l>>2]|0)>>>0)}l=Ty(k,0,0,1)|0;j=F;G=ZGb(u,q,e,(e|0)<0|0?-1:0)|0;E=Ty(k,G,F,0)|0;G=F;h=0;if(!((G|0)<(h|0)|(G|0)==(h|0)&E>>>0<0>>>0)){E=ZGb(l,j,u,q)|0;EG(k,E,F,e);Ty(k,l,j,0)|0;}j=Ty(k,0,0,1)|0;l=F;e=ZGb(o,r,t,(t|0)<0|0?-1:0)|0;E=Ty(k,e,F,0)|0;e=F;q=0;if(!((e|0)<(q|0)|(e|0)==(q|0)&E>>>0<0>>>0)){E=ZGb(j,l,o,r)|0;EG(k,E,F,t);Ty(k,j,l,0)|0;}c[n>>2]=1;m=0;i=b;return m|0}function BG(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;g=i;i=i+48|0;h=g|0;j=g+16|0;k=g+32|0;l=Ty(a,0,0,1)|0;m=F;FG(h,a,475249515,0,0);n=h|0;o=c[n>>2]|0;p=c[n+4>>2]|0;n=c[h+8>>2]|0;h=b+12|0;a:do{if((c[h>>2]|0)>0){q=b+8|0;r=(f*42|0)+12|0;s=r;t=(r|0)<0|0?-1:0;r=j|0;u=j+8|0;v=d[1192172]|0;w=(v+12|0)>>>0<7>>>0;x=(f|0)>0;y=k|0;z=k+8|0;A=d[1192240]|0;B=(A+12|0)>>>0<7>>>0;C=d[1192234]|0;D=(C+12|0)>>>0<7>>>0;E=d[1192233]|0;G=(E+12|0)>>>0<7>>>0;H=d[1192171]|0;I=(H+12|0)>>>0<7>>>0;J=(H-1|0)/7|0;H=(E-1|0)/7|0;E=(C-1|0)/7|0;C=(A-1|0)/7|0;A=(v-1|0)/7|0;v=0;b:while(1){K=c[q>>2]|0;L=K+(v*40|0)|0;M=c[L>>2]|0;N=c[L+4>>2]|0;FG(j,a,187,s,t);L=c[r>>2]|0;O=c[r+4>>2]|0;P=c[u>>2]|0;Q=N;R=M;S=1;while(1){T=R>>>8|Q<<24;U=Q>>>8|0<<24;if((T|0)==0&(U|0)==0){break}else{Q=U;R=T;S=S+1|0}}if(!w){R=A;while(1){Py(a,179>>>(R<<3>>>0)&255);if((R|0)==0){break}else{R=R-1|0}}}EG(a,S,(S|0)<0|0?-1:0,0);if((S|0)>0){R=S;do{R=R-1|0;Q=$Gb(M|0,N|0,R<<3|0)|0;Py(a,Q&255);}while((R|0)>0)}if(x){R=0;do{c[e+(R<<3)+4>>2]=0;R=R+1|0;}while((R|0)<(f|0))}c:do{if(((c[h>>2]|0)-v|0)>0){R=0;while(1){S=R+v|0;Q=K+(S*40|0)|0;if(!((c[Q>>2]|0)==(M|0)&(c[Q+4>>2]|0)==(N|0))){V=R;break c}Q=K+(S*40|0)+8|0;T=c[Q>>2]|0;U=T-1|0;if(!((T|0)>0&(U|0)<(f|0))){break b}T=e+(U<<3)+4|0;do{if((c[T>>2]|0)==0){c[T>>2]=1;FG(k,a,183,42,0);U=c[y>>2]|0;W=c[y+4>>2]|0;X=c[z>>2]|0;Y=c[Q>>2]|0;Z=Y;_=(Y|0)<0|0?-1:0;Y=_;$=Z;aa=1;while(1){ba=$>>>8|Y<<24;ca=Y>>>8|0<<24;if((ba|0)==0&(ca|0)==0){break}else{Y=ca;$=ba;aa=aa+1|0}}if(!B){$=C;while(1){Py(a,247>>>($<<3>>>0)&255);if(($|0)==0){break}else{$=$-1|0}}}EG(a,aa,(aa|0)<0|0?-1:0,0);if((aa|0)>0){$=aa;do{$=$-1|0;Y=$Gb(Z|0,_|0,$<<3|0)|0;Py(a,Y&255);}while(($|0)>0)}$=K+(S*40|0)+16|0;_=c[$>>2]|0;Z=c[$+4>>2]|0;$=Z;aa=_;Y=1;while(1){ba=aa>>>8|$<<24;ca=$>>>8|0<<24;if((ba|0)==0&(ca|0)==0){break}else{$=ca;aa=ba;Y=Y+1|0}}if(!D){aa=E;while(1){Py(a,241>>>(aa<<3>>>0)&255);if((aa|0)==0){break}else{aa=aa-1|0}}}EG(a,Y,(Y|0)<0|0?-1:0,0);if((Y|0)>0){aa=Y;do{aa=aa-1|0;$=$Gb(_|0,Z|0,aa<<3|0)|0;Py(a,$&255);}while((aa|0)>0)}aa=K+(S*40|0)+24|0;Z=c[aa>>2]|0;_=c[aa+4>>2]|0;aa=_;Y=Z;$=1;while(1){ba=Y>>>8|aa<<24;ca=aa>>>8|0<<24;if((ba|0)==0&(ca|0)==0){break}else{aa=ca;Y=ba;$=$+1|0}}if(!G){Y=H;while(1){Py(a,240>>>(Y<<3>>>0)&255);if((Y|0)==0){break}else{Y=Y-1|0}}}EG(a,$,($|0)<0|0?-1:0,0);if(($|0)>0){Y=$;do{Y=Y-1|0;aa=$Gb(Z|0,_|0,Y<<3|0)|0;Py(a,aa&255);}while((Y|0)>0)}Y=K+(S*40|0)+32|0;_=c[Y>>2]|0;Z=c[Y+4>>2]|0;do{if(!((_|0)==(-1|0)&(Z|0)==(-1|0))){Y=Z;$=_;aa=1;while(1){ba=$>>>8|Y<<24;ca=Y>>>8|0<<24;if((ba|0)==0&(ca|0)==0){break}else{Y=ca;$=ba;aa=aa+1|0}}if(!I){$=J;while(1){Py(a,178>>>($<<3>>>0)&255);if(($|0)==0){break}else{$=$-1|0}}}EG(a,aa,(aa|0)<0|0?-1:0,0);if((aa|0)>0){da=aa}else{break}do{da=da-1|0;$=$Gb(_|0,Z|0,da<<3|0)|0;Py(a,$&255);}while((da|0)>0)}}while(0);Z=Ty(a,0,0,1)|0;_=F;aa=ZGb(U,W,X,(X|0)<0|0?-1:0)|0;$=Ty(a,aa,F,0)|0;aa=F;Y=0;if((aa|0)<(Y|0)|(aa|0)==(Y|0)&$>>>0<0>>>0){break}$=ZGb(Z,_,U,W)|0;EG(a,$,F,X);Ty(a,Z,_,0)|0;}}while(0);S=R+1|0;if((S|0)<((c[h>>2]|0)-v|0)){R=S}else{V=S;break}}}else{V=0}}while(0);K=Ty(a,0,0,1)|0;N=F;M=ZGb(L,O,P,(P|0)<0|0?-1:0)|0;R=Ty(a,M,F,0)|0;M=F;S=0;if(!((M|0)<(S|0)|(M|0)==(S|0)&R>>>0<0>>>0)){R=ZGb(K,N,L,O)|0;EG(a,R,F,P);Ty(a,K,N,0)|0;}v=V+v|0;if((v|0)>=(c[h>>2]|0)){break a}}yDb(0,0,2168904,(v=i,i=i+24|0,c[v>>2]=2129056,c[v+8>>2]=2154712,c[v+16>>2]=446,v)|0);i=v;Cd();return 0}}while(0);h=Ty(a,0,0,1)|0;V=F;da=ZGb(o,p,n,(n|0)<0|0?-1:0)|0;k=Ty(a,da,F,0)|0;da=F;e=0;if((da|0)<(e|0)|(da|0)==(e|0)&k>>>0<0>>>0){i=g;return(F=m,l)|0}k=ZGb(h,V,o,p)|0;EG(a,k,F,n);Ty(a,h,V,0)|0;i=g;return(F=m,l)|0}function CG(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=Ty(a,0,0,1)|0;h=F;j=0;if(!(e>>>0>j>>>0|e>>>0==j>>>0&b>>>0>1>>>0)){yDb(0,0,2168904,(j=i,i=i+24|0,c[j>>2]=2135360,c[j+8>>2]=2154712,c[j+16>>2]=251,j)|0);i=j;Cd()}j=d[1192229]|0;if(!((j+12|0)>>>0<7>>>0)){k=(j-1|0)/7|0;while(1){Py(a,236>>>(k<<3>>>0)&255);if((k|0)==0){break}else{k=k-1|0}}}k=0;if(e>>>0<k>>>0|e>>>0==k>>>0&b>>>0<10>>>0){k=YGb(b,e,-1,-1)|0;EG(a,k,F,0)}else{k=YGb(b,e,-9,-1)|0;EG(a,k,F,8)}k=YGb(g,h,b,e)|0;e=F;b=Ty(a,0,0,1)|0;h=ZGb(k,e,b,F)|0;Qy(a,0,h);i=f;return}function DG(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+32|0;f=e|0;g=e+16|0;h=Ty(a,0,0,1)|0;j=F;k=b+16|0;l=c[k>>2]|0;do{if((l|0)>0){m=b|0;n=Ty(a,c[m>>2]|0,c[m+4>>2]|0,0)|0;m=F;o=0;if((m|0)<(o|0)|(m|0)==(o|0)&n>>>0<0>>>0){p=b+24|0;q=p;$Db(q);r=b;ZDb(r);i=e;return}else{s=c[k>>2]|0;break}}else{s=l}}while(0);FG(f,a,290298740,s,(s|0)<0|0?-1:0);s=f|0;l=c[s>>2]|0;n=c[s+4>>2]|0;s=c[f+8>>2]|0;f=b+28|0;if((c[f>>2]|0)>0){o=b+24|0;m=g|0;t=g+8|0;u=d[1192075]|0;v=(u+20|0)>>>0<7>>>0;w=(u+7|0)/7|0;u=0;do{x=c[o>>2]|0;FG(g,a,19899,21,0);y=c[m>>2]|0;z=c[m+4>>2]|0;A=c[t>>2]|0;if(!v){B=w;while(1){Py(a,21419>>>(B<<3>>>0)&255);if((B|0)==0){break}else{B=B-1|0}}}B=x+(u<<4)|0;C=(c[B>>2]|0)+1|0;D=C>>>0>65535>>>0;E=D?C>>>16:C;C=D?16:0;if((E&65280|0)==0){G=C;H=E}else{G=C|8;H=E>>>8}E=((G-1+(d[1191992+H|0]|0)|0)/7|0)+1|0;EG(a,E,(E|0)<0|0?-1:0,0);E=c[B>>2]|0;B=E+1|0;C=B>>>0>65535>>>0;D=C?B>>>16:B;B=C?16:0;if((D&65280|0)==0){I=B;J=D}else{I=B|8;J=D>>>8}D=I-1+(d[1191992+J|0]|0)|0;if(!((D+13|0)>>>0<7>>>0)){B=(D|0)/7|0;while(1){Py(a,E>>>(B<<3>>>0)&255);if((B|0)==0){break}else{B=B-1|0}}}B=x+(u<<4)+8|0;E=c[B>>2]|0;D=c[B+4>>2]|0;B=D;C=E;K=1;while(1){L=C>>>8|B<<24;M=B>>>8|0<<24;if((L|0)==0&(M|0)==0){break}else{B=M;C=L;K=K+1|0}}if(!v){C=w;while(1){Py(a,21420>>>(C<<3>>>0)&255);if((C|0)==0){break}else{C=C-1|0}}}EG(a,K,(K|0)<0|0?-1:0,0);if((K|0)>0){C=K;do{C=C-1|0;B=$Gb(E|0,D|0,C<<3|0)|0;Py(a,B&255);}while((C|0)>0)}C=Ty(a,0,0,1)|0;D=F;E=ZGb(y,z,A,(A|0)<0|0?-1:0)|0;K=Ty(a,E,F,0)|0;E=F;B=0;if(!((E|0)<(B|0)|(E|0)==(B|0)&K>>>0<0>>>0)){K=ZGb(C,D,y,z)|0;EG(a,K,F,A);Ty(a,C,D,0)|0;}u=u+1|0;}while((u|0)<(c[f>>2]|0))}f=Ty(a,0,0,1)|0;u=F;w=ZGb(l,n,s,(s|0)<0|0?-1:0)|0;v=Ty(a,w,F,0)|0;w=F;J=0;if(!((w|0)<(J|0)|(w|0)==(J|0)&v>>>0<0>>>0)){v=ZGb(f,u,l,n)|0;EG(a,v,F,s);Ty(a,f,u,0)|0;}u=c[k>>2]|0;if((u|0)<=0){p=b+24|0;q=p;$Db(q);r=b;ZDb(r);i=e;return}k=b|0;f=YGb(c[k>>2]|0,c[k+4>>2]|0,u,(u|0)<0|0?-1:0)|0;u=F;k=Ty(a,0,0,1)|0;s=ZGb(f,u,k,F)|0;CG(a,s,F);Ty(a,h,j,0)|0;p=b+24|0;q=p;$Db(q);r=b;ZDb(r);i=e;return}function EG(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=YGb(b,d,1,0)|0;h=F;j=1;while(1){k=$Gb(g|0,h|0,j*7|0|0)|0;if((k|0)==0&(F|0)==0){break}else{j=j+1|0}}h=16777215;if(!(d>>>0<h>>>0|d>>>0==h>>>0&b>>>0<-1>>>0)){yDb(0,0,2168904,(l=i,i=i+24|0,c[l>>2]=2161336,c[l+8>>2]=2154712,c[l+16>>2]=182,l)|0);i=l;Cd()}h=(e|0)==0?j:e;if((h|0)<(j|0)){yDb(0,0,2168904,(l=i,i=i+24|0,c[l>>2]=2147624,c[l+8>>2]=2154712,c[l+16>>2]=189,l)|0);i=l;Cd()}l=_Gb(1,0,h*7|0|0)|0;j=l|b;b=F|d;if((h|0)>0){m=h}else{i=f;return}do{m=m-1|0;h=$Gb(j|0,b|0,m<<3|0)|0;Py(a,h&255);}while((m|0)>0);i=f;return}function FG(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;if((f|0)==0&(g|0)==0){j=8}else{k=YGb(f,g,1,0)|0;g=F;f=1;while(1){l=$Gb(k|0,g|0,f*7|0|0)|0;if((l|0)==0&(F|0)==0){j=f;break}else{f=f+1|0}}}f=e+1|0;g=f>>>0>65535>>>0;k=g?f>>>16:f;f=g?16:0;if((k&65280|0)==0){m=f;n=k}else{m=f|8;n=k>>>8}k=m-1+(d[1191992+n|0]|0)|0;if(!((k+13|0)>>>0<7>>>0)){n=(k|0)/7|0;while(1){Py(b,e>>>(n<<3>>>0)&255);if((n|0)==0){break}else{n=n-1|0}}}if((j|0)<9){Py(b,511>>>(j>>>0));Qy(b,255,j-1|0);n=Ty(b,0,0,1)|0;b=a|0;c[b>>2]=n;c[b+4>>2]=F;c[a+8>>2]=j;i=h;return}else{yDb(0,0,2168904,(h=i,i=i+24|0,c[h>>2]=2141280,c[h+8>>2]=2154712,c[h+16>>2]=156,h)|0);i=h;Cd()}}function GG(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=SGb(c|0)|0;f=b+1|0;g=f>>>0>65535>>>0;h=g?f>>>16:f;f=g?16:0;if((h&65280|0)==0){i=f;j=h}else{i=f|8;j=h>>>8}h=i-1+(d[1191992+j|0]|0)|0;if((h+13|0)>>>0<7>>>0){k=e;l=(e|0)<0|0?-1:0;EG(a,k,l,0);Ry(a,c,e);return}j=(h|0)/7|0;while(1){Py(a,b>>>(j<<3>>>0)&255);if((j|0)==0){break}else{j=j-1|0}}k=e;l=(e|0)<0|0?-1:0;EG(a,k,l,0);Ry(a,c,e);return}function HG(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;j=i;i=i+136|0;k=j|0;l=j+8|0;m=j+48|0;n=j+56|0;o=j+64|0;p=j+72|0;q=j+80|0;r=j+88|0;s=j+104|0;t=j+120|0;u=c[b+12>>2]|0;v=g+32|0;w=c[v>>2]|0;y=c[(c[(c[b+28>>2]|0)+(w<<2)>>2]|0)+8>>2]|0;c[m>>2]=0;z=g+28|0;A=c[z>>2]|0;c[n>>2]=A;c[o>>2]=0;B=g+16|0;C=g+8|0;D=(c[(c[u+96>>2]|0)+(w<<3)>>2]|0)==0?C:B;w=c[D>>2]|0;E=c[D+4>>2]|0;D=b;b=Ty(e,0,0,1)|0;G=F;H=c[z>>2]|0;z=c[C>>2]|0;I=c[C+4>>2]|0;C=c[B>>2]|0;J=c[B+4>>2]|0;B=c[g+48>>2]|0;yDb(D,48,2090480,(K=i,i=i+72|0,c[K>>2]=b,c[K+8>>2]=G,c[K+16>>2]=H,c[K+24>>2]=z,c[K+32>>2]=I,c[K+40>>2]=C,c[K+48>>2]=J,c[K+56>>2]=B,c[K+64>>2]=h,K)|0);i=K;B=y+48|0;J=c[B>>2]|0;a:do{if((J|0)==1211250229){L=7}else if((J|0)==28){if((c[y+100>>2]|0)<=0){L=11;break}C=c[y+96>>2]|0;do{if(((d[C+1|0]|0)<<8|(d[C]|0)<<16|(d[C+2|0]|0)|0)!=1){I=C;if((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)==16777216){break}if((J|0)==1211250229){L=7;break a}else{L=12;break a}}}while(0);bX(c[g+24>>2]|0,m,n)|0}else{L=12}}while(0);do{if((L|0)==7){if((c[y+100>>2]|0)<=6){L=11;break}C=c[y+96>>2]|0;if(((d[C+1|0]|0)<<8|(d[C]|0)<<16|(d[C+2|0]|0)|0)!=1){I=C;if((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)!=16777216){L=12;break}}hX(c[g+24>>2]|0,m,n,0,0)|0}}while(0);b:do{if((L|0)==11){M=c[g+24>>2]|0;L=28}else if((L|0)==12){I=c[g+24>>2]|0;if((J|0)!=86041){M=I;L=28;break}C=k;z=WDb(A)|0;c[k>>2]=z;c:do{if((z|0)!=0){do{if((A|0)>31){H=l|0;G=l+28|0;b=l+20|0;N=l+24|0;O=l+32|0;P=l+16|0;Q=I;R=A;S=0;while(1){T=OV(l,Q)|0;if((T|0)<0){U=T;L=26;break}T=Q+32|0;V=R-32|0;if(V>>>0<(c[H>>2]|0)>>>0){U=-1094995529;L=26;break}if((c[G>>2]|0)==0){W=S}else{X=(c[k>>2]|0)+S|0;x=c[P>>2]|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;W=S+4|0}X=(c[k>>2]|0)+W|0;x=c[b>>2]|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=(c[k>>2]|0)+(W+4)|0;x=c[N>>2]|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=W+8|0;if((c[G>>2]|0)==0){L=22}else{if((c[O>>2]|0)==0){L=22}else{Y=X}}if((L|0)==22){L=0;Z=(c[k>>2]|0)+X|0;x=c[H>>2]|0;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;Y=W+12|0}UGb((c[k>>2]|0)+Y|0,T|0,c[H>>2]|0)|0;T=c[H>>2]|0;Z=V-T|0;_=T+Y|0;if((Z|0)>31){Q=Q+(T+32)|0;R=Z;S=_}else{L=24;break}}if((L|0)==24){$=_;aa=c[k>>2]|0;break}else if((L|0)==26){$Db(C);if((U|0)<0){break c}else{break b}}}else{$=0;aa=z}}while(0);c[m>>2]=aa;c[n>>2]=$;break b}}while(0);yDb(D,16,2049744,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;i=j;return}}while(0);if((L|0)==28){c[m>>2]=M}if((c[B>>2]|0)==149){c[n>>2]=(c[n>>2]|0)-8;ba=8}else{ba=0}B=HZ(g,70,o)|0;if((B|0)!=0&(c[o>>2]|0)>9){M=B+4|0;B=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;c[p>>2]=1;c[p+4>>2]=c[y+412>>2];c[q>>2]=1;c[q+4>>2]=1e9;y=KDb(B,0,p,q)|0;ca=F;da=y}else{ca=0;da=0}y=HZ(g,74,o)|0;if((y|0)==0){ea=0;fa=0;ga=c[o>>2]|0}else{q=y;p=q|0;B=q+4|0;q=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;p=fe(q|0)|0;q=(c[o>>2]|0)-8|0;c[o>>2]=q;ea=(p|0)==1&(B|0)==0;fa=y+8|0;ga=q}if((da|0)==0&(ca|0)==0&((ga|0)!=0&ea^1)){ha=f;ia=0;ja=0;ka=0}else{FG(r,e,160,0,0);f=r|0;ha=161;ia=c[f+4>>2]|0;ja=c[f>>2]|0;ka=c[r+8>>2]|0}r=ha+1|0;f=r>>>0>65535>>>0;ga=f?r>>>16:r;r=f?16:0;if((ga&65280|0)==0){la=r;ma=ga}else{la=r|8;ma=ga>>>8}ga=la-1+(d[1191992+ma|0]|0)|0;if(!((ga+13|0)>>>0<7>>>0)){ma=(ga|0)/7|0;while(1){Py(e,ha>>>(ma<<3>>>0)&255);if((ma|0)==0){break}else{ma=ma-1|0}}}ma=(c[n>>2]|0)+4|0;EG(e,ma,(ma|0)<0|0?-1:0,0);Py(e,(c[v>>2]|0)+1|128);v=u+64|0;u=ZGb(w,E,c[v>>2]|0,c[v+4>>2]|0)|0;fz(e,u);Py(e,h);Ry(e,(c[m>>2]|0)+ba|0,c[n>>2]|0);n=c[m>>2]|0;if((n|0)!=(c[g+24>>2]|0)){ZDb(n)}n=(da|0)!=0|(ca|0)!=0;do{if(n){g=(ca>>31|((ca|0)<0|0?-1:0)<<1)^da;m=((((ca|0)<0|0?-1:0)>>31|((ca|0)<0|0?-1:0)<<1)^ca)<<1|g>>>31;ba=g<<1|0>>>31;g=1;while(1){h=ba>>>8|m<<24;u=m>>>8|0<<24;if((h|0)==0&(u|0)==0){break}else{m=u;ba=h;g=g+1|0}}ba=d[1192109]|0;if(!((ba+20|0)>>>0<7>>>0)){m=(ba+7|0)/7|0;while(1){Py(e,30114>>>(m<<3>>>0)&255);if((m|0)==0){break}else{m=m-1|0}}}EG(e,g,(g|0)<0|0?-1:0,0);if((g|0)>0){na=g}else{break}do{na=na-1|0;m=aHb(da|0,ca|0,na<<3|0)|0;Py(e,m&255);}while((na|0)>0)}}while(0);do{if((c[o>>2]|0)!=0&ea){FG(s,e,30113,0,0);na=s|0;ca=c[na>>2]|0;da=c[na+4>>2]|0;na=c[s+8>>2]|0;FG(t,e,166,0,0);g=t|0;m=c[g>>2]|0;ba=c[g+4>>2]|0;g=c[t+8>>2]|0;h=d[1192231]|0;if(!((h+12|0)>>>0<7>>>0)){u=(h-1|0)/7|0;while(1){Py(e,238>>>(u<<3>>>0)&255);if((u|0)==0){break}else{u=u-1|0}}}EG(e,1,0,0);Py(e,1);u=d[1192158]|0;if(!((u+12|0)>>>0<7>>>0)){h=(u-1|0)/7|0;while(1){Py(e,165>>>(h<<3>>>0)&255);if((h|0)==0){break}else{h=h-1|0}}}h=c[o>>2]|0;EG(e,h,(h|0)<0|0?-1:0,0);Ry(e,fa,c[o>>2]|0);h=Ty(e,0,0,1)|0;u=F;v=ZGb(m,ba,g,(g|0)<0|0?-1:0)|0;E=Ty(e,v,F,0)|0;v=F;w=0;if(!((v|0)<(w|0)|(v|0)==(w|0)&E>>>0<0>>>0)){E=ZGb(h,u,m,ba)|0;EG(e,E,F,g);Ty(e,h,u,0)|0;}u=Ty(e,0,0,1)|0;h=F;E=ZGb(ca,da,na,(na|0)<0|0?-1:0)|0;w=Ty(e,E,F,0)|0;E=F;v=0;if((E|0)<(v|0)|(E|0)==(v|0)&w>>>0<0>>>0){break}w=ZGb(u,h,ca,da)|0;EG(e,w,F,na);Ty(e,u,h,0)|0;}}while(0);if(!((c[o>>2]|0)!=0&ea|n)){i=j;return}n=Ty(e,0,0,1)|0;ea=F;o=ZGb(ja,ia,ka,(ka|0)<0|0?-1:0)|0;fa=Ty(e,o,F,0)|0;o=F;t=0;if((o|0)<(t|0)|(o|0)==(t|0)&fa>>>0<0>>>0){i=j;return}fa=ZGb(n,ea,ja,ia)|0;EG(e,fa,F,ka);Ty(e,n,ea,0)|0;i=j;return}function IG(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;j=i;i=i+72|0;k=j|0;l=j+8|0;m=j+24|0;n=j+40|0;o=j+56|0;p=h|0;do{if((c[p>>2]|0)==0&(c[p+4>>2]|0)==0){q=c[(c[b+12>>2]|0)+88>>2]|0;r=b+16|0;s=Ty(c[r>>2]|0,0,0,1)|0;t=F;u=q+24|0;v=c[q+20>>2]|0;w=q+28|0;x=c[w>>2]|0;if(!((v|0)<1|(v|0)>(x|0))){y=-1;i=j;return y|0}v=aEb(c[u>>2]|0,x+1|0,16)|0;x=v;if((v|0)==0){y=-12;i=j;return y|0}else{c[u>>2]=x;c[x+(c[w>>2]<<4)>>2]=307544935;u=q+8|0;q=ZGb(s,t,c[u>>2]|0,c[u+4>>2]|0)|0;u=c[w>>2]|0;c[w>>2]=u+1;w=x+(u<<4)+8|0;c[w>>2]=q;c[w+4>>2]=F;FG(m,c[r>>2]|0,307544935,0,0);w=h;q=m;c[w>>2]=c[q>>2];c[w+4>>2]=c[q+4>>2];c[w+8>>2]=c[q+8>>2];c[w+12>>2]=c[q+12>>2];z=r;break}}else{z=b+16|0}}while(0);FG(n,c[z>>2]|0,29555,0,0);b=n|0;m=c[b>>2]|0;h=c[b+4>>2]|0;b=c[n+8>>2]|0;FG(o,c[z>>2]|0,25536,0,0);n=o|0;p=c[n>>2]|0;r=c[n+4>>2]|0;n=c[o+8>>2]|0;do{if((f|0)!=0){o=c[z>>2]|0;q=g;w=0;u=w;x=q;t=1;while(1){s=x>>>8|u<<24;v=u>>>8|0<<24;if((s|0)==0&(v|0)==0){break}else{u=v;x=s;t=t+1|0}}x=f+1|0;u=x>>>0>65535>>>0;s=u?x>>>16:x;x=u?16:0;if((s&65280|0)==0){A=x;B=s}else{A=x|8;B=s>>>8}s=A-1+(d[1191992+B|0]|0)|0;if(!((s+13|0)>>>0<7>>>0)){x=(s|0)/7|0;while(1){Py(o,f>>>(x<<3>>>0)&255);if((x|0)==0){break}else{x=x-1|0}}}EG(o,t,(t|0)<0|0?-1:0,0);if((t|0)>0){C=t}else{break}do{C=C-1|0;x=$Gb(q|0,w|0,C<<3|0)|0;Py(o,x&255);}while((C|0)>0)}}while(0);C=c[z>>2]|0;f=Ty(C,0,0,1)|0;B=F;A=ZGb(p,r,n,(n|0)<0|0?-1:0)|0;g=Ty(C,A,F,0)|0;A=F;o=0;if(!((A|0)<(o|0)|(A|0)==(o|0)&g>>>0<0>>>0)){g=ZGb(f,B,p,r)|0;EG(C,g,F,n);Ty(C,f,B,0)|0;}B=BBb(e,9203176,0,2)|0;if((B|0)!=0){f=k;C=l|0;n=l+8|0;g=B;do{B=g|0;do{if((yAb(c[B>>2]|0,2122816)|0)!=0){if((yAb(c[B>>2]|0,1986176)|0)==0){break}if((yAb(c[B>>2]|0,2026392)|0)==0){break}r=c[z>>2]|0;p=eEb(c[B>>2]|0)|0;c[k>>2]=p;o=cc(p|0,45)|0;do{if((o|0)==0){D=0}else{p=Vz(o+1|0,0)|0;if((p|0)==0){D=0;break}a[o]=0;D=p}}while(0);o=c[k>>2]|0;a:while(1){p=a[o]|0;do{if((p<<24>>24|0)==32){a[o]=95}else if((p<<24>>24|0)==0){break a}else{if(!((p-97&255)>>>0<26>>>0)){break}a[o]=p-32}}while(0);o=o+1|0}FG(l,r,26568,0,0);o=c[C>>2]|0;p=c[C+4>>2]|0;A=c[n>>2]|0;GG(r,17827,c[k>>2]|0);if((D|0)!=0){GG(r,17530,D)}GG(r,17543,c[g+4>>2]|0);w=Ty(r,0,0,1)|0;q=F;t=ZGb(o,p,A,(A|0)<0|0?-1:0)|0;x=Ty(r,t,F,0)|0;t=F;s=0;if(!((t|0)<(s|0)|(t|0)==(s|0)&x>>>0<0>>>0)){x=ZGb(w,q,o,p)|0;EG(r,x,F,A);Ty(r,w,q,0)|0;}$Db(f)}}while(0);g=BBb(e,9203176,g,2)|0;}while((g|0)!=0)}g=c[z>>2]|0;z=Ty(g,0,0,1)|0;e=F;f=ZGb(m,h,b,(b|0)<0|0?-1:0)|0;D=Ty(g,f,F,0)|0;f=F;k=0;if((f|0)<(k|0)|(f|0)==(k|0)&D>>>0<0>>>0){y=0;i=j;return y|0}D=ZGb(z,e,m,h)|0;EG(g,D,F,b);Ty(g,z,e,0)|0;y=0;i=j;return y|0}function JG(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;a=b+4|0;d=YCb(a,c[b+8>>2]|0)|0;if((d|0)<0){e=d;return e|0}ZCb(c[a>>2]|0);e=0;return e|0}function KG(a,b){a=a|0;b=b|0;_Cb(c[(c[a+12>>2]|0)+4>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function LG(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+256|0;d=b|0;e=(c[a+12>>2]|0)+4|0;sAb(d,WCb(c[e>>2]|0)|0,56)|0;tAb(d,2236216,56)|0;PG(a,d);aDb(e);i=b;return 0}function MG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+12>>2]|0;e=d+4|0;f=YCb(e,c[d+8>>2]|0)|0;if((f|0)<0){g=f;i=b;return g|0}f=a+16|0;Kz(c[f>>2]|0,1883488,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0)|0;i=d;Kz(c[f>>2]|0,2341504,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0)|0;i=d;h=c[f>>2]|0;j=WCb(c[e>>2]|0)|0;Kz(h,2318672,(d=i,i=i+8|0,c[d>>2]=j,d)|0)|0;i=d;YC(a)|0;Kz(c[f>>2]|0,2296600,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0)|0;i=d;g=0;i=b;return g|0}function NG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+256|0;e=(c[a+12>>2]|0)+4|0;ZCb(c[e>>2]|0);f=b+28|0;_Cb(c[e>>2]|0,c[b+24>>2]|0,c[f>>2]|0);e=d|0;g=b+16|0;h=c[g>>2]|0;j=c[g+4>>2]|0;g=b+8|0;k=c[g>>2]|0;l=c[g+4>>2]|0;g=c[b+48>>2]|0;m=c[f>>2]|0;Lb(e|0,192,2026776,(f=i,i=i+56|0,c[f>>2]=c[b+32>>2],c[f+8>>2]=h,c[f+16>>2]=j,c[f+24>>2]=k,c[f+32>>2]=l,c[f+40>>2]=g,c[f+48>>2]=m,f)|0)|0;i=f;PG(a,e);i=d;return 0}function OG(a){a=a|0;aDb((c[a+12>>2]|0)+4|0);return 0}function PG(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b+12>>2]|0;j=SGb(e|0)|0;k=h+4|0;h=XCb(c[k>>2]|0)|0;if(!((h|0)>0&h>>>0<65>>>0)){yDb(0,0,1982824,(l=i,i=i+24|0,c[l>>2]=1951984,c[l+8>>2]=1925672,c[l+16>>2]=41,l)|0);i=l;Cd()}$Cb(c[k>>2]|0,g|0);k=j+(h<<1)|0;m=j;n=0;o=j;while(1){Lb(e+o|0,3,1903656,(l=i,i=i+8|0,c[l>>2]=d[g+n|0]|0,l)|0)|0;i=l;j=m+2|0;p=n+1|0;if((p|0)<(h|0)){m=j;n=p;o=j}else{break}}a[e+k|0]=10;a[e+(k+1)|0]=0;k=b+16|0;b=c[k>>2]|0;Ry(b,e,SGb(e|0)|0);Sy(c[k>>2]|0);i=f;return}function QG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;if((b|0)==(d|0)|(a|0)==0){i=e;return}g=BBb(c[a>>2]|0,9203144,0,2)|0;a:do{if((g|0)!=0){h=(b|0)==0;if((d|0)==0){j=g;while(1){k=c[j>>2]|0;b:do{if(h){l=k}else{m=b;while(1){n=m|0;if((c[n>>2]|0)==0){l=k;break b}if((yAb(k,c[m+4>>2]|0)|0)==0){break}else{m=m+8|0}}l=c[n>>2]|0}}while(0);CBb(f,l,c[j+4>>2]|0,0)|0;j=BBb(c[a>>2]|0,9203144,j,2)|0;if((j|0)==0){break a}}}if(h){j=g;while(1){k=c[j>>2]|0;m=d;while(1){o=c[m>>2]|0;if((o|0)==0){p=k;break}if((yAb(k,o)|0)==0){q=12;break}else{m=m+8|0}}if((q|0)==12){q=0;p=c[m+4>>2]|0}CBb(f,p,c[j+4>>2]|0,0)|0;j=BBb(c[a>>2]|0,9203144,j,2)|0;if((j|0)==0){break a}}}else{r=g}do{j=c[r>>2]|0;h=d;while(1){k=c[h>>2]|0;if((k|0)==0){s=j;break}if((yAb(j,k)|0)==0){q=18;break}else{h=h+8|0}}if((q|0)==18){q=0;s=c[h+4>>2]|0}j=b;while(1){t=j|0;if((c[t>>2]|0)==0){u=s;break}if((yAb(s,c[j+4>>2]|0)|0)==0){q=22;break}else{j=j+8|0}}if((q|0)==22){q=0;u=c[t>>2]|0}CBb(f,u,c[r+4>>2]|0,0)|0;r=BBb(c[a>>2]|0,9203144,r,2)|0;}while((r|0)!=0)}}while(0);DBb(a);c[a>>2]=c[f>>2];i=e;return}function RG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;QG(a+1140|0,b,d);e=a+24|0;if((c[e>>2]|0)!=0){f=a+28|0;g=0;do{QG((c[(c[f>>2]|0)+(g<<2)>>2]|0)+88|0,b,d);g=g+1|0;}while(g>>>0<(c[e>>2]|0)>>>0)}e=a+1132|0;if((c[e>>2]|0)!=0){g=a+1136|0;f=0;do{QG((c[(c[g>>2]|0)+(f<<2)>>2]|0)+32|0,b,d);f=f+1|0;}while(f>>>0<(c[e>>2]|0)>>>0)}e=a+1104|0;if((c[e>>2]|0)==0){return}f=a+1108|0;a=0;do{QG((c[(c[f>>2]|0)+(a<<2)>>2]|0)+20|0,b,d);a=a+1|0;}while(a>>>0<(c[e>>2]|0)>>>0);return}function SG(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=234881024){return 0}a=b+4|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1342177280){a=b+12|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==872415232?100:0)|0}else{return 0}return 0}function TG(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,l=0,m=0;b=i;i=i+8|0;d=b|0;e=c[a+16>>2]|0;Vy(e,4,0)|0;if((vz(e)|0)!=80){f=-5;i=b;return f|0}Vy(e,20,0)|0;h=LT(a,0)|0;if((h|0)==0){f=-12;i=b;return f|0}c[h+236>>2]=2;a=h+48|0;c[a>>2]=0;c[a+4>>2]=0;a=vz(e)|0;j=0;l=h+56|0;c[l>>2]=a;c[l+4>>2]=j;l=h+64|0;c[l>>2]=a;c[l+4>>2]=j;j=vz(e)|0;lFb(d,(c[k>>2]=j,+g[k>>2]),2147483647);j=c[d>>2]|0;l=c[d+4>>2]|0;d=vz(e)|0;a=h+8|0;c[(c[a>>2]|0)+120>>2]=d;d=vz(e)|0;c[(c[a>>2]|0)+124>>2]=d;Vy(e,12,0)|0;c[(c[a>>2]|0)+8>>2]=0;d=vz(e)|0;c[(c[a>>2]|0)+52>>2]=d;m=vT(1240808,d)|0;c[(c[a>>2]|0)+48>>2]=m;MT(h,64,l,j);Vy(e,20,0)|0;f=0;i=b;return f|0}function UG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+16>>2]|0;if((Xy(d)|0)!=0){e=-541478725;return e|0}Vy(d,4,0)|0;a=vz(d)|0;Vy(d,4,0)|0;f=vz(d)|0;if(a>>>0<(f+16|0)>>>0){e=-5;return e|0}g=TS(d,b,f)|0;if((g|0)<0){e=g;return e|0}f=b+64|0;h=YGb(c[f>>2]|0,c[f+4>>2]|0,-16,-1)|0;c[f>>2]=h;c[f+4>>2]=F;c[b+48>>2]=1;Vy(d,a-16-g|0,0)|0;e=g;return e|0}function VG(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+8|0;f=e|0;g=c[b+4>>2]|0;b=((d[g+1|0]|0)<<8|(d[g]|0)<<16|(d[g+2|0]|0)|0)==15711167?g+3|0:g;g=xd(b|0,1883440,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;do{if((g|0)!=1){j=xd(b|0,2341448,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((j|0)==1){break}j=xd(b|0,1982760,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((j|0)==1){break}else{k=0}i=e;return k|0}}while(0);g=hc(b|0,2141800)|0;j=a[b+g|0]|0;if(j<<24>>24==13){l=g+1|0;m=l;n=a[b+l|0]|0}else{m=g;n=j}j=(n<<24>>24==10)+m|0;m=b+j|0;n=xd(m|0,1883440,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;do{if((n|0)!=1){g=xd(m|0,2341448,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((g|0)==1){break}g=xd(m|0,1982760,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((g|0)==1){break}else{k=0}i=e;return k|0}}while(0);n=hc(m|0,2141800)|0;m=a[b+(j+n)|0]|0;if(m<<24>>24==13){g=n+1|0;o=g;p=a[b+(j+g)|0]|0}else{o=n;p=m}m=b+(j+((p<<24>>24==10)+o))|0;o=xd(m|0,1883440,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;do{if((o|0)!=1){p=xd(m|0,2341448,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((p|0)==1){break}p=xd(m|0,1982760,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((p|0)==1){break}else{k=0}i=e;return k|0}}while(0);k=100;i=e;return k|0}function WG(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,Q=0.0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;i=i+2112|0;e=d|0;f=d+8|0;g=d+16|0;j=d+24|0;k=d+32|0;l=d+2080|0;m=d+2088|0;n=d+2096|0;o=d+2104|0;p=c[b+12>>2]|0;q=LT(b,0)|0;if((q|0)==0){r=-12;i=d;return r|0}s=b+16|0;a:do{if((Xy(c[s>>2]|0)|0)==0){t=k|0;u=o|0;v=o+4|0;w=q+8|0;x=k+11|0;y=b;z=p;A=0;B=2997;C=125;b:while(1){D=Ty(c[s>>2]|0,0,0,1)|0;E=F;if((wz(c[s>>2]|0,t,2048)|0)==0){G=B;H=C;I=z;J=w;break a}a[k+(hc(t|0,2141800)|0)|0]=0;K=A+1|0;do{if((A|0)<3){L=xd(t|0,2075536,(M=i,i=i+16|0,c[M>>2]=l,c[M+8>>2]=m,M)|0)|0;i=M;do{if((L|0)==2){if((c[l>>2]|0)>=2){N=C;O=B;break}P=+h[m>>3];if(P>3.0&P<100.0){Q=P;R=11}else{N=C;O=B}}else{S=xd(t|0,2026696,(M=i,i=i+16|0,c[M>>2]=l,c[M+8>>2]=m,M)|0)|0;i=M;P=+h[m>>3];if((S|0)==2&(c[l>>2]|0)<2&P>3.0&P<100.0){Q=P;R=11}else{N=C;O=B}}}while(0);if((R|0)==11){R=0;lFb(o,Q,1e5);N=c[v>>2]|0;O=c[u>>2]|0}if((c[(c[w>>2]|0)+96>>2]|0)!=0){T=N;U=O;R=17;break}L=xd(t|0,1982760,(M=i,i=i+8|0,c[M>>2]=n,M)|0)|0;i=M;if((L|0)!=1){T=N;U=O;R=17;break}L=eEb(x)|0;c[(c[w>>2]|0)+96>>2]=L;L=c[w>>2]|0;S=c[L+96>>2]|0;if((S|0)==0){r=-12;R=29;break b}c[L+100>>2]=(SGb(S|0)|0)+1;V=N;W=O}else{T=C;U=B;R=17}}while(0);do{if((R|0)==17){R=0;S=Vb(t|0,125)|0;if((S|0)==0){yDb(y,24,1951920,(M=i,i=i+16|0,c[M>>2]=t,c[M+8>>2]=K,M)|0);i=M;V=T;W=U;break}L=Vb(S+1|0,125)|0;if((L|0)==0){yDb(y,24,1951920,(M=i,i=i+16|0,c[M>>2]=t,c[M+8>>2]=K,M)|0);i=M;V=T;W=U;break}S=L+1|0;if((a[S]|0)==0){V=T;W=U;break}L=uR(z,S,SGb(S|0)|0,0)|0;if((L|0)==0){r=-12;R=29;break b}S=L+64|0;c[S>>2]=D;c[S+4>>2]=E;S=xd(t|0,1903608,(M=i,i=i+16|0,c[M>>2]=g,c[M+8>>2]=j,M)|0)|0;i=M;if((S|0)==2){S=c[g>>2]|0;X=(S|0)<0|0?-1:0;Y=S}else{X=-2147483648;Y=0}S=L+8|0;c[S>>2]=Y;c[S+4>>2]=X;S=xd(t|0,1925624,(M=i,i=i+16|0,c[M>>2]=e,c[M+8>>2]=f,M)|0)|0;i=M;if((S|0)==2){Z=(c[f>>2]|0)-(c[e>>2]|0)|0}else{Z=-1}c[L+48>>2]=Z;V=T;W=U}}while(0);if((Xy(c[s>>2]|0)|0)==0){A=K;B=W;C=V}else{G=W;H=V;I=z;J=w;break a}}if((R|0)==29){i=d;return r|0}}else{G=2997;H=125;I=p;J=q+8|0}}while(0);vR(I);MT(q,64,H,G);G=c[J>>2]|0;c[G+8>>2]=3;c[G+48>>2]=1833195076;r=0;i=d;return r|0}function XG(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function YG(a){a=a|0;AR(c[a+12>>2]|0);return 0}function ZG(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function _G(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a+28|0;e=c[c[d>>2]>>2]|0;f=c[e+8>>2]|0;g=c[f+104>>2]|0;h=c[f+108>>2]|0;do{if((c[a+24>>2]|0)==1){if((c[f+48>>2]|0)!=1833195076){break}j=f+96|0;do{if((c[j>>2]|0)==0){k=e}else{l=f+100|0;if((c[l>>2]|0)<=0){k=e;break}m=a+16|0;Ry(c[m>>2]|0,1903592,11);Ry(c[m>>2]|0,c[j>>2]|0,c[l>>2]|0);Sy(c[m>>2]|0);k=c[c[d>>2]>>2]|0}}while(0);MT(k,64,g,h);n=0;i=b;return n|0}}while(0);yDb(a,16,1925584,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;n=-1;i=b;return n|0}function $G(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a+16|0;a=b+8|0;f=c[a+4>>2]|0;Kz(c[e>>2]|0,2026656,(g=i,i=i+16|0,c[g>>2]=c[a>>2],c[g+8>>2]=f,g)|0)|0;i=g;f=c[b+48>>2]|0;h=c[e>>2]|0;if((f|0)<0){Ry(h,1982752,2)}else{j=YGb(c[a>>2]|0,c[a+4>>2]|0,f,(f|0)<0|0?-1:0)|0;f=F;Kz(h,2026656,(g=i,i=i+16|0,c[g>>2]=j,c[g+8>>2]=f,g)|0)|0;i=g}Ry(c[e>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);Ry(c[e>>2]|0,1951912,1);i=d;return 0}function aH(a){a=a|0;Ry(c[a+16>>2]|0,2026632,21);MT(c[c[a+28>>2]>>2]|0,64,1,1e3);return 0}function bH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+256|0;if((c[b+32>>2]|0)!=0){yDb(a,24,2141672,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}f=d|0;g=b+16|0;b=c[g+4>>2]|0;Lb(f|0,256,2075496,(e=i,i=i+16|0,c[e>>2]=c[g>>2],c[e+8>>2]=b,e)|0)|0;i=e;e=c[a+16>>2]|0;Ry(e,f,SGb(f|0)|0);i=d;return 0}function cH(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;if((c[a+8>>2]|0)<30){b=0;return b|0}e=c[a+4>>2]|0;a=e;if(!((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0)){b=0;return b|0}a=e+2|0;f=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((f|0)==24|(f|0)==22)){b=0;return b|0}a=e+8|0;g=(d[a]|d[a+1|0]<<8)<<16>>16;a=e+12|0;h=(d[a]|d[a+1|0]<<8)<<16>>16;a=e+14|0;i=(d[a]|d[a+1|0]<<8)<<16>>16;if(g<<16>>16==0|(g&65535)>>>0>60>>>0){b=0;return b|0}if(h<<16>>16==0|(h&65535)>>>0>2048>>>0){b=0;return b|0}if(i<<16>>16==0|(i&65535)>>>0>2048>>>0){b=0;return b|0}i=e+f|0;f=(d[i]|d[i+1|0]<<8)<<16>>16;b=f<<16>>16==0|(f&65535)>>>0>49>>>0?0:50;return b|0}function dH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=pz(d)|0;f=rz(d)|0;if((e|0)!=0){g=-1094995529;return g|0}pz(d)|0;e=pz(d)|0;pz(d)|0;h=pz(d)|0;i=pz(d)|0;Vy(d,f-10|0,0)|0;d=LT(a,0)|0;if((d|0)==0){g=-12;return g|0}j=c[d+8>>2]|0;c[j+8>>2]=0;c[j+48>>2]=81;c[j+52>>2]=0;c[j+120>>2]=h;c[j+124>>2]=i;MT(d,64,1,e);do{if((f|0)==24){e=LT(a,0)|0;if((e|0)==0){g=-12;return g|0}else{d=c[e+8>>2]|0;c[d+8>>2]=1;c[d+52>>2]=0;c[d+48>>2]=65541;c[d+416>>2]=1;i=d+448|0;c[i>>2]=4;c[i+4>>2]=0;c[d+412>>2]=8e3;MT(e,64,1,8e3);break}}}while(0);c[b>>2]=0;c[b+4>>2]=0;g=0;return g|0}function eH(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+8|0;g=f|0;h=g|0;j=c[d+12>>2]|0;k=d+16|0;l=c[k>>2]|0;m=g;if((mz(l,m,6)|0)!=6){n=-5;i=f;return n|0}o=g+2|0;g=d;a:while(1){p=b[h>>1]|0;d=p&65535;q=b[o>>1]|0;r=q&65535;switch(d|0){case 21:{s=8;break a;break};case 49:case 5:case 8:case 12:case 13:case 14:case 15:{s=4;break a;break};default:{}}yDb(g,32,2141640,(t=i,i=i+8|0,c[t>>2]=d,t)|0);i=t;Vy(l,q&65535,0)|0;if((mz(l,m,6)|0)!=6){n=-5;s=11;break}}if((s|0)==4){g=r+6|0;if((wZ(e,g)|0)!=0){n=-12;i=f;return n|0}o=e+24|0;h=c[o>>2]|0;a[h]=a[m]|0;a[h+1|0]=a[m+1|0]|0;a[h+2|0]=a[m+2|0]|0;a[h+3|0]=a[m+3|0]|0;a[h+4|0]=a[m+4|0]|0;a[h+5|0]=a[m+5|0]|0;if((mz(l,(c[o>>2]|0)+6|0,r)|0)!=(r|0)){n=-5;i=f;return n|0}c[e+28>>2]=g;c[e+32>>2]=0;g=j+4|0;o=c[g>>2]|0;l=e+8|0;c[l>>2]=o;c[l+4>>2]=0;if(p<<16>>16==49){n=0;i=f;return n|0}c[g>>2]=o+1;n=0;i=f;return n|0}else if((s|0)==8){if((TS(c[k>>2]|0,e,r)|0)<0){n=-12;i=f;return n|0}c[e+32>>2]=1;r=j;j=c[r>>2]|0;c[r>>2]=j+1;r=e+8|0;c[r>>2]=j;c[r+4>>2]=0;n=0;i=f;return n|0}else if((s|0)==11){i=f;return n|0}return 0}function fH(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==77){if((a[d+1|0]|0)!=77){break}if((a[d+2|0]|0)!=77){break}if((a[d+3|0]|0)!=68){break}if((a[d+8|0]|0)!=67){break}if((a[d+9|0]|0)!=78){break}if((a[d+10|0]|0)!=84){break}if((a[d+11|0]|0)==73){e=100}else{break}return e|0}}while(0);e=0;return e|0}function gH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((rz(e)|0)!=1145916749){f=-1094995529;i=b;return f|0}Vy(e,4,0)|0;while(1){g=rz(e)|0;h=vz(e)|0;if(!((g|0)==1230261827|(g|0)==1094996047)){break}Vy(e,h,0)|0;}h=g&16777215;if((h|0)==5395521){lz(e)|0;lz(e)|0;j=lz(e)|0;k=j&15;if(k>>>0>4>>>0){yDb(a,16,2213616,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;f=-1094995529;i=b;return f|0}m=c[678232+(k<<2)>>2]|0;lz(e)|0;lz(e)|0;lz(e)|0;while(1){n=rz(e)|0;o=vz(e)|0;p=0;if(!((n|0)==1903391809|(n|0)==1232106305)){break}Vy(e,o,p)|0;}if((n&16777215|0)!=6387521){yDb(a,16,2204272,(l=i,i=i+8|0,c[l>>2]=n,l)|0);i=l;f=-1094995529;i=b;return f|0}n=Ty(e,0,0,1)|0;e=YGb(n,F,o,p)|0;p=d+24|0;c[p>>2]=e;c[p+4>>2]=F;p=LT(a,0)|0;if((p|0)==0){f=-12;i=b;return f|0}e=c[p+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=69646;c[e+412>>2]=m;d=j>>7;c[e+416>>2]=d+1;j=(d|0)!=0;d=e+448|0;c[d>>2]=j?3:4;c[d+4>>2]=j?0:0;c[e+792>>2]=4;c[e+72>>2]=m<<2;MT(p,64,1,m);f=0;i=b;return f|0}else if((h|0)==5395533){yDb(a,16,2236152,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;f=-1163346256;i=b;return f|0}else{yDb(a,16,2223184,(l=i,i=i+8|0,c[l>>2]=g,l)|0);i=l;f=-1163346256;i=b;return f|0}return 0}function hH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=(c[a+12>>2]|0)+24|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=a+16|0;a=Ty(c[d>>2]|0,0,0,1)|0;g=ZGb(e,f,a,F)|0;a=F;f=0;e=(a|0)>(f|0)|(a|0)==(f|0)&g>>>0>4096>>>0;f=e?4096:g;g=e?0:a;a=0;if((Xy(c[d>>2]|0)|0)!=0|((g|0)<(a|0)|(g|0)==(a|0)&f>>>0<1>>>0)){h=-541478725;return h|0}a=TS(c[d>>2]|0,b,f)|0;if((a|0)<0){h=a;return h|0}c[b+32>>2]=0;h=a;return h|0}function iH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=a+28|0;g=c[(c[c[f>>2]>>2]|0)+8>>2]|0;h=(c[g+88>>2]&8388608|0)!=0?1982728:1951888;j=c[g+412>>2]|0;k=0;while(1){if((k|0)>=5){break}if((c[678232+(k<<2)>>2]|0)==(j|0)){l=4;break}else{k=k+1|0}}do{if((l|0)==4){if((k|0)<0){break}m=(c[g+416>>2]|0)>1;n=d+32|0;c[n>>2]=m&1;do{if(m){if(!((c[g+680>>2]|0)>-2)){break}yDb(a,16,1903512,(o=i,i=i+8|0,c[o>>2]=-2,o)|0);i=o;p=-22;i=b;return p|0}}while(0);Yy(e,1145916749);Zy(e,0);m=EO(e,2341440)|0;q=F;Py(e,0);Py(e,1);Py(e,1);Py(e,0);Py(e,0);r=Ty(e,0,0,1)|0;s=F;t=YGb(m,q,-4,-1)|0;Ty(e,t,F,0)|0;t=ZGb(r,s,m,q)|0;Zy(e,t);Ty(e,r,s,0)|0;s=EO(e,2318640)|0;r=F;Ry(e,h,SGb(h|0)|0);t=Ty(e,0,0,1)|0;q=F;m=YGb(s,r,-4,-1)|0;Ty(e,m,F,0)|0;m=ZGb(t,q,s,r)|0;Zy(e,m);Ty(e,t,q,0)|0;Ry(e,2296536,4);Zy(e,0);q=Ty(e,0,0,1)|0;t=d;c[t>>2]=q;c[t+4>>2]=F;Py(e,0);Py(e,0);Py(e,k|c[n>>2]<<7|16);Py(e,0);Py(e,2);Py(e,2);Yy(e,1903391809);Zy(e,16);t=Ty(e,0,0,1)|0;q=d+8|0;c[q>>2]=t;c[q+4>>2]=F;Ry(e,9203536,16);q=EO(e,2249384)|0;t=d+16|0;c[t>>2]=q;c[t+4>>2]=F;t=c[c[f>>2]>>2]|0;MT(t,64,1,c[(c[t+8>>2]|0)+412>>2]|0);Sy(e);p=0;i=b;return p|0}}while(0);yDb(a,16,1925504,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;p=-22;i=b;return p|0}function jH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+16>>2]|0;d=c[a+12>>2]|0;if((c[b+88>>2]|0)==0){return 0}e=d+16|0;f=c[e>>2]|0;g=c[e+4>>2]|0;h=Ty(b,0,0,1)|0;i=F;j=YGb(f,g,-4,-1)|0;Ty(b,j,F,0)|0;j=ZGb(h,i,f,g)|0;Zy(b,j);Ty(b,h,i,0)|0;i=d;h=c[i>>2]|0;j=c[i+4>>2]|0;i=Ty(b,0,0,1)|0;g=F;f=YGb(h,j,-4,-1)|0;Ty(b,f,F,0)|0;f=ZGb(i,g,h,j)|0;Zy(b,f);Ty(b,i,g,0)|0;g=Ty(b,0,0,1)|0;i=F;Ty(b,4,0,0)|0;f=YGb(g,i,-8,0)|0;Zy(b,f);Ty(b,g,i,0)|0;i=Ty(b,0,0,1)|0;g=F;f=ZGb(i,g,c[e>>2]|0,c[e+4>>2]|0)|0;e=F;j=d+8|0;Ty(b,c[j>>2]|0,c[j+4>>2]|0,0)|0;Py(b,0);Py(b,c[d+32>>2]<<6|1);d=gHb(f,e,500,0)|0;e=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+412>>2]|0;a=eHb(d,F,e,(e|0)<0|0?-1:0)|0;e=a;if((e|0)<128){Py(b,e);Py(b,e)}else{a=e-128|0;e=a>>7|128;Py(b,e);d=a&127;Py(b,d);Py(b,e);Py(b,d)}Ry(b,2075456,2);Ry(b,9203256,4);Ty(b,i,g,0)|0;Sy(b);return 0}function kH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e|0;d=c[a+24>>2]|0;if((d|0)==0){i=e;return 0}g=c[(c[a+28>>2]|0)+(d-1<<2)>>2]|0;vz(b)|0;tF(a,b,f)|0;if((c[f>>2]|0)==3){uF(b,0)}else{tz(b)|0}tF(a,b,f)|0;if((c[f>>2]|0)!=4){i=e;return 0}vF(a,g,b)|0;i=e;return 0}function lH(a,b){a=a|0;b=b|0;return wT(a,b&1,b&2,b<<29>>31)|0}function mH(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;g=i;i=i+32|0;j=g|0;l=g+16|0;m=a+4|0;n=c[m>>2]|0;o=c[n+24>>2]|0;if((o|0)==0){p=0;i=g;return p|0}q=c[(c[n+28>>2]|0)+(o-1<<2)>>2]|0;o=q+12|0;n=c[o>>2]|0;r=n;s=e+52|0;a:do{if((f|0)>0){t=l|0;u=l+8|0;v=q+8|0;w=n+136|0;x=n+152|0;y=n+1200|0;z=n+140|0;A=a+40|0;B=n+128|0;C=n+124|0;D=n+64|0;E=j|0;G=j+8|0;H=n+164|0;I=n+168|0;J=0;b:while(1){if((c[s>>2]|0)!=0){break a}c[t>>2]=1685288051;c[u>>2]=0;c[u+4>>2]=0;K=Ty(e,0,0,1)|0;L=F;M=vz(e)|0;N=M;O=0;P=rz(e)|0;if(M>>>0>15>>>0){vz(e)|0;tz(e)|0;Q=tz(e)|0}else{if(M>>>0<8>>>0){R=8;break}else{Q=1}}M=c[(c[v>>2]|0)+52>>2]|0;S=Ty(e,0,0,1)|0;T=F;U=YGb(N,O,K,L)|0;V=F;W=ZGb(U,V,S,T)|0;T=vT(1238728,P)|0;do{if((M|0)==0|(M|0)==(P|0)){R=13}else{S=c[m>>2]|0;X=c[S+1112>>2]|0;if((X|0)==0){if((M|0)==1734701162){R=16;break}}else{if((T|0)==(X|0)){R=13;break}}yDb(S,24,2338960,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;S=W;Vy(e,S,(S|0)<0|0?-1:0)|0;}}while(0);do{if((R|0)==13){R=0;if(!((M|0)==828601953|(M|0)==828601960|(M|0)==829842792)){R=16;break}yDb(c[m>>2]|0,24,2325992,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;R=16}}while(0);do{if((R|0)==16){R=0;c[w>>2]=(c[(c[v>>2]|0)+52>>2]|0)!=0?-1:J;c[x>>2]=Q;M=vT(1240080,P)|0;do{if((M|0)<1){W=P&65535;if((W|0)==29549|(W|0)==21332){Z=vT(1238064,(fe(P|0)|0)&65535)|0;R=20;break}else{W=c[v>>2]|0;_=M;$=W;aa=c[W+8>>2]|0;R=22;break}}else{Z=M;R=20}}while(0);do{if((R|0)==20){R=0;M=c[v>>2]|0;W=M+8|0;T=c[W>>2]|0;if(!((T|0)!=0&(Z|0)>0)){_=Z;$=M;aa=T;R=22;break}c[W>>2]=1;ca=Z;da=M}}while(0);c:do{if((R|0)==22){R=0;if((aa|0)==1){ca=_;da=$;break}if((P|0)==1932816493|(P|0)==0){ca=_;da=$;break}M=vT(1238728,P)|0;do{if((M|0)<1){W=vT(1240808,P)|0;T=c[v>>2]|0;S=T+8|0;if((W|0)>0){ea=W;fa=S;ga=T;break}X=c[S>>2]|0;if((X|0)==3){if((c[T+48>>2]|0)!=0){ca=W;da=T;break c}}else if((X|0)!=2){ca=W;da=T;break c}T=vT(1240048,P)|0;W=c[v>>2]|0;if((T|0)<=0){ca=T;da=W;break c}c[W+8>>2]=3;ca=T;da=W;break c}else{W=c[v>>2]|0;ea=M;fa=W+8|0;ga=W}}while(0);c[fa>>2]=0;ca=ea;da=ga}}while(0);c[da+52>>2]=P;M=c[da+8>>2]|0;do{if((M|0)==0){c[da+48>>2]=ca;tz(e)|0;tz(e)|0;vz(e)|0;vz(e)|0;vz(e)|0;W=tz(e)|0;c[(c[v>>2]|0)+120>>2]=W;W=tz(e)|0;c[(c[v>>2]|0)+124>>2]=W;vz(e)|0;vz(e)|0;vz(e)|0;tz(e)|0;W=lz(e)|0;T=W>>>0>31>>>0?31:W;yH(e,T,(c[v>>2]|0)+16|0,32);if(T>>>0<31>>>0){Vy(e,31-T|0,0)|0;}T=c[v>>2]|0;W=T+16|0;X=T+52|0;do{if((PGb(W,2341368,25)|0)==0){c[X>>2]=808596553;S=T+120|0;c[S>>2]=c[S>>2]&-2;S=T+124|0;c[S>>2]=c[S>>2]&-2}else{if((c[X>>2]|0)!=859189832){break}if((PGb(W,2340112,13)|0)!=0){break}c[T+48>>2]=22}}while(0);T=tz(e)|0;c[(c[v>>2]|0)+792>>2]=T;T=tz(e)|0;W=c[v>>2]|0;X=W+792|0;S=c[X>>2]|0;ha=S&31;ia=(S&32|0)!=0;if(ia){if((c[W+48>>2]|0)==44){break}}if(!((ha|0)==8|(ha|0)==4|(ha|0)==2)){break}d:do{if(ia){c[X>>2]=ha;W=1<<ha;S=256/((W-1|0)>>>0)|0;ja=0;ka=255;while(1){la=ka&255;c[r+176+(ja<<2)>>2]=la|la<<8|la<<16|-16777216;la=ka-S|0;ma=ja+1|0;if(ma>>>0<W>>>0){ja=ma;ka=(la|0)<0?0:la}else{break}}}else{if((T|0)==0){ka=vz(e)|0;tz(e)|0;ja=tz(e)|0;if((ja|ka)>>>0>255>>>0|ka>>>0>ja>>>0){break}else{na=ka}while(1){ka=lz(e)|0;lz(e)|0;W=lz(e)|0;lz(e)|0;S=lz(e)|0;lz(e)|0;la=lz(e)|0;lz(e)|0;c[r+176+(na<<2)>>2]=W<<16&16711680|ka<<24|S<<8&65280|la&255;na=na+1|0;if(na>>>0>ja>>>0){break d}}}ja=1<<ha;if((ha|0)==4){oa=1153568}else if((ha|0)==2){oa=1152784}else{oa=1152800}la=0;do{S=la*3|0;c[r+176+(la<<2)>>2]=(d[oa+S|0]|0)<<16|(d[oa+(S+1)|0]|0)<<8|(d[oa+(S+2)|0]|0)|-16777216;la=la+1|0;}while(la>>>0<ja>>>0)}}while(0);c[y>>2]=1}else if((M|0)==3){c[da+48>>2]=ca;ha=Ty(e,0,0,1)|0;T=ZGb(U,V,ha,F)|0;c[E>>2]=0;ha=T;c[G>>2]=ha;c[G+4>>2]=(ha|0)<0|0?-1:0;ha=c[v>>2]|0;if((c[ha+52>>2]|0)==1932816493){pa=ha}else{KH(a,e,j)|0;pa=c[v>>2]|0}c[pa+120>>2]=c[H>>2];c[pa+124>>2]=c[I>>2]}else if((M|0)==1){c[da+48>>2]=ca;ha=tz(e)|0;T=BBb(c[(c[m>>2]|0)+1140>>2]|0,1886288,0,1)|0;tz(e)|0;vz(e)|0;X=tz(e)|0;c[(c[v>>2]|0)+416>>2]=X;X=tz(e)|0;c[(c[v>>2]|0)+792>>2]=X;b[z>>1]=tz(e)|0;tz(e)|0;X=(vz(e)|0)>>>16;ia=c[v>>2]|0;c[ia+412>>2]=X;do{if((c[A>>2]|0)==0){R=58}else{if((T|0)==0){qa=ia;break}if((yb(c[T+4>>2]|0,1898312)|0)==0){qa=ia}else{R=58}}}while(0);do{if((R|0)==58){R=0;T=ha&65535;if((T|0)==1){c[B>>2]=vz(e)|0;vz(e)|0;c[C>>2]=vz(e)|0;vz(e)|0;qa=c[v>>2]|0;break}else if((T|0)!=2){qa=ia;break}vz(e)|0;T=Az(e)|0;X=F;c[(c[v>>2]|0)+412>>2]=~~(c[k>>2]=T,c[k+4>>2]=X,+h[k>>3]);X=vz(e)|0;c[(c[v>>2]|0)+416>>2]=X;vz(e)|0;X=vz(e)|0;c[(c[v>>2]|0)+792>>2]=X;X=vz(e)|0;c[C>>2]=vz(e)|0;c[B>>2]=vz(e)|0;T=c[v>>2]|0;if((c[T+52>>2]|0)!=1835233388){qa=T;break}ja=wT(c[T+792>>2]|0,X&1,X&2,X<<29>>31)|0;X=c[v>>2]|0;c[X+48>>2]=ja;qa=X}}while(0);ia=qa+48|0;ha=c[ia>>2]|0;do{if((ha|0)==69632){c[B>>2]=64;c[C>>2]=(c[qa+416>>2]|0)*34|0;ra=69632}else if((ha|0)==86034){c[B>>2]=160;c[C>>2]=33;ra=86034}else if((ha|0)==65536|(ha|0)==65537){X=c[qa+792>>2]|0;if((X|0)==8){c[ia>>2]=65540;ra=65540;break}else if((X|0)==24){X=(ha|0)==65537?65549:65548;c[ia>>2]=X;ra=X;break}else{ra=ha;break}}else if((ha|0)==65540|(ha|0)==65541){if((c[qa+792>>2]|0)!=16){ra=ha;break}c[ia>>2]=65537;ra=65537}else if((ha|0)==86025){c[B>>2]=6;c[C>>2]=c[qa+416>>2]<<1;ra=86025}else if((ha|0)==86026){c[B>>2]=6;c[C>>2]=c[qa+416>>2];ra=86026}else{ra=ha}}while(0);ha=u0a(ra)|0;if((ha|0)==0){break}ia=c[v>>2]|0;c[ia+792>>2]=ha;c[D>>2]=ba(c[ia+416>>2]|0,ha>>3)|0}else{ha=Ty(e,0,0,1)|0;ia=ZGb(U,V,ha,F)|0;ha=ia;ia=c[v>>2]|0;if((c[ia+52>>2]|0)!=1684237684){Vy(e,ha,(ha|0)<0|0?-1:0)|0;break}if((CT(ia,e,ha)|0)<0){p=-12;R=109;break b}if((ha|0)<=16){break}ha=c[o>>2]|0;ia=c[v>>2]|0;X=c[ia+96>>2]|0;ja=X+4|0;T=fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0;c[ha+1216>>2]=T;if((T&1|0)!=0){T=ia+92|0;c[T>>2]=c[T>>2]|8192}c[ia+108>>2]=d[X+16|0]|0;c[ia+104>>2]=1}}while(0);M=Ty(e,0,0,1)|0;ia=ZGb(K,L,M,F)|0;M=YGb(ia,F,N,O)|0;ia=F;c[u>>2]=M;c[u+4>>2]=ia;X=0;if((ia|0)>(X|0)|(ia|0)==(X|0)&M>>>0>8>>>0){X=nH(a,e,l)|0;if((X|0)<0){p=X;R=109;break b}else{break}}X=0;if(!((ia|0)>(X|0)|(ia|0)==(X|0)&M>>>0>0>>>0)){break}Vy(e,M,ia)|0;}}while(0);J=J+1|0;if((J|0)>=(f|0)){break a}}if((R|0)==8){yDb(c[m>>2]|0,16,2236672,(Y=i,i=i+16|0,c[Y>>2]=N,c[Y+8>>2]=O,Y)|0);i=Y;p=-1094995529;i=g;return p|0}else if((R|0)==109){i=g;return p|0}}}while(0);if((c[s>>2]|0)!=0){p=-541478725;i=g;return p|0}s=q+8|0;R=c[s>>2]|0;O=R+8|0;do{if((c[O>>2]|0)==1){N=R+412|0;if((c[N>>2]|0)!=0){break}f=c[n+92>>2]|0;if((f|0)<=1){break}c[N>>2]=f}}while(0);f=c[R+48>>2]|0;if((f|0)==73729){c[R+416>>2]=1;c[R+412>>2]=16e3;p=0;i=g;return p|0}else if((f|0)==86016|(f|0)==86017){c[O>>2]=1;c[q+236>>2]=1;p=0;i=g;return p|0}else if((f|0)==86034|(f|0)==69638|(f|0)==69633|(f|0)==86076|(f|0)==86025|(f|0)==86026|(f|0)==86035){c[R+432>>2]=c[n+124>>2];p=0;i=g;return p|0}else if((f|0)==86032){if((c[R+100>>2]|0)!=36){p=0;i=g;return p|0}O=c[R+96>>2]|0;c[R+416>>2]=d[O+21|0]|0;N=O+32|0;c[R+412>>2]=fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0;p=0;i=g;return p|0}else if((f|0)==86019|(f|0)==1|(f|0)==71){c[q+236>>2]=1;p=0;i=g;return p|0}else if((f|0)==86022){q=tN()|0;c[a+36>>2]=q;N=wB(q)|0;c[a+32>>2]=N;if((N|0)==0){yDb(c[m>>2]|0,16,2344008,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;p=-12;i=g;return p|0}else{c[n+132>>2]=1;c[(c[s>>2]|0)+48>>2]=65536;p=0;i=g;return p|0}}else if((f|0)==86040){c[R+416>>2]=1;if((c[R+52>>2]|0)!=1886151505){c[R+412>>2]=8e3}c[n+128>>2]=160;s=n+124|0;if((c[s>>2]|0)!=0){p=0;i=g;return p|0}c[s>>2]=35;p=0;i=g;return p|0}else if((f|0)==73728){c[R+416>>2]=1;c[R+412>>2]=8e3;p=0;i=g;return p|0}else{p=0;i=g;return p|0}return 0}function nH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+16|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e|0;g=d+8|0;h=c[g>>2]|0;j=c[g+4>>2]|0;k=0;if((j|0)<(k|0)|(j|0)==(k|0)&h>>>0<0>>>0){c[g>>2]=-1;c[g+4>>2]=2147483647;l=2147483647;m=-1;n=4}else{g=0;if((j|0)<(g|0)|(j|0)==(g|0)&h>>>0<8>>>0){o=0;p=0;q=j;r=h}else{l=j;m=h;n=4}}a:do{if((n|0)==4){h=f+8|0;j=f|0;g=0;k=(l|0)>(g|0)|(l|0)==(g|0)&m>>>0>7>>>0;g=c[d>>2]|0;s=a+24|0;t=a+4|0;u=a+28|0;v=b+88|0;w=0;x=0;y=0;z=8;b:while(1){if((Xy(b)|0)!=0){o=w;p=x;q=l;r=m;break a}c[h>>2]=m;c[h+4>>2]=l;c[j>>2]=0;do{if(k){c[h>>2]=vz(b)|0;c[h+4>>2]=0;A=rz(b)|0;c[j>>2]=A;if(!((g|0)==1953460082|(g|0)==1987014509)){if((A|0)==1801548404|(A|0)==1952539757){n=9;break b}}A=c[h>>2]|0;B=c[h+4>>2]|0;if(!((A|0)==1&(B|0)==0)){C=y;D=z;E=B;G=A;break}A=Az(b)|0;B=YGb(A,F,-8,-1)|0;A=F;c[h>>2]=B;c[h+4>>2]=A;H=YGb(x,w,16,0)|0;C=F;D=H;E=A;G=B}else{C=w;D=x;E=l;G=m}}while(0);if((G|0)==0&(E|0)==0){B=ZGb(8,0,D,C)|0;A=YGb(B,F,m,l)|0;B=F;c[h>>2]=A;c[h+4>>2]=B;I=B;J=A}else{I=E;J=G}A=YGb(J,I,-8,-1)|0;B=F;c[h>>2]=A;c[h+4>>2]=B;H=0;if((B|0)<(H|0)|(B|0)==(H|0)&A>>>0<0>>>0){o=C;p=D;q=l;r=m;break a}H=ZGb(m,l,D,C)|0;K=F;L=(B|0)>(K|0)|(B|0)==(K|0)&A>>>0>H>>>0;M=L?H:A;A=L?K:B;c[h>>2]=M;c[h+4>>2]=A;B=c[j>>2]|0;K=0;while(1){if((K|0)==65){n=19;break}if((c[672688+(K<<3)>>2]|0)==(B|0)){n=18;break}else{K=K+1|0}}do{if((n|0)==18){n=0;N=c[672692+(K<<3)>>2]|0;n=21}else if((n|0)==19){n=0;if((g|0)==1635017845|(g|0)==1953721449){N=266;n=21;break}Vy(b,M,A)|0;}}while(0);do{if((n|0)==21){n=0;O=Ty(b,0,0,1)|0;P=F;A=ze[N&511](a,b,f)|0;if((A|0)<0){Q=A;n=37;break b}do{if((c[s>>2]|0)!=0){if((c[u>>2]|0)==0){break}if((c[v>>2]|0)==0){break b}if((c[(c[t>>2]|0)+1084>>2]&2|0)!=0){n=28;break b}A=YGb(c[h>>2]|0,c[h+4>>2]|0,O,P)|0;M=F;K=Wy(b)|0;if((A|0)==(K|0)&(M|0)==(F|0)){n=27;break b}}}while(0);M=c[h>>2]|0;K=c[h+4>>2]|0;A=Ty(b,0,0,1)|0;B=ZGb(M,K,A,F)|0;A=YGb(B,F,O,P)|0;B=F;K=0;if((B|0)>(K|0)|(B|0)==(K|0)&A>>>0>0>>>0){Vy(b,A,B)|0;break}K=0;if(!((B|0)<(K|0)|(B|0)==(K|0)&A>>>0<0>>>0)){break}K=c[t>>2]|0;M=ZGb(0,0,A,B)|0;L=F;yDb(K,24,2196664,(R=i,i=i+24|0,c[R>>2]=f,c[R+8>>2]=M,c[R+16>>2]=L,R)|0);i=R;Ty(b,A,B,1)|0;}}while(0);B=YGb(c[h>>2]|0,c[h+4>>2]|0,D,C)|0;A=F;L=YGb(B,A,8,0)|0;M=F;if((M|0)>(l|0)|(M|0)==(l|0)&L>>>0>m>>>0){o=A;p=B;q=l;r=m;break a}else{w=A;x=B;y=M;z=L}}if((n|0)==9){yDb(c[t>>2]|0,16,2204224,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;Vy(b,-8,-1)|0;Q=0;i=e;return Q|0}else if((n|0)==27){if((c[v>>2]|0)!=0){n=28}}else if((n|0)==37){i=e;return Q|0}do{if((n|0)==28){if((c[(c[t>>2]|0)+1084>>2]&2|0)==0){Q=0}else{break}i=e;return Q|0}}while(0);t=YGb(c[h>>2]|0,c[h+4>>2]|0,O,P)|0;v=a+112|0;c[v>>2]=t;c[v+4>>2]=F;Q=0;i=e;return Q|0}}while(0);a=0;if(!(((o|0)<(q|0)|(o|0)==(q|0)&p>>>0<r>>>0)&((q|0)<(a|0)|(q|0)==(a|0)&r>>>0<524287>>>0))){Q=0;i=e;return Q|0}a=ZGb(r,q,p,o)|0;Vy(b,a,F)|0;Q=0;i=e;return Q|0}function oH(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=i;e=c[a+8>>2]|0;if(e>>>0<8>>>0){f=0;i=b;return f|0}g=c[a+4>>2]|0;h=0;j=0;k=0;l=-1;a:while(1){m=h;n=j;o=k;b:while(1){p=m;q=n;while(1){r=q;s=g+(r+4)|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;if((t|0)==1987014509){u=6;break b}else if((t|0)==2003395685|(t|0)==1701079415|(t|0)==1701147238|(t|0)==1802401130|(t|0)==1952672112){u=13;break}else if((t|0)==2105508482|(t|0)==1885956979|(t|0)==1684632949|(t|0)==1818653296){u=14;break}else if((t|0)==538988650|(t|0)==1952539757|(t|0)==1953459824|(t|0)==1635017845|(t|0)==1887007846){v=l;break b}t=g+r|0;s=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=s>>>0<4>>>0;w=YGb(t?4:s,t?0:0,q,p)|0;t=F;s=YGb(w,t,8,0)|0;x=F;y=0;if((x|0)>(y|0)|(x|0)==(y|0)&s>>>0>e>>>0){z=o;A=l;break a}else{p=t;q=w}}if((u|0)==13){u=0;w=g+r|0;t=fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;w=t>>>0<4>>>0;B=(o|0)>95?o:95;C=w?0:0;D=w?4:t}else if((u|0)==14){u=0;t=g+r|0;w=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=w>>>0<4>>>0;B=(o|0)>50?o:50;C=t?0:0;D=t?4:w}w=YGb(D,C,q,p)|0;t=F;s=YGb(w,t,8,0)|0;y=F;x=0;if((y|0)>(x|0)|(y|0)==(x|0)&s>>>0>e>>>0){z=B;A=l;break a}else{m=t;n=w;o=B}}if((u|0)==6){u=0;n=YGb(q,p,4,0)|0;v=n}n=g+r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=fe(m|0)|0;c:do{if(n>>>0<8>>>0){do{if((m|0)==16777216){w=YGb(q,p,12,0)|0;t=F;s=0;if((t|0)>(s|0)|(t|0)==(s|0)&w>>>0>e>>>0){break}w=g+(r+8)|0;s=w|0;t=w+4|0;w=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;if(!((fe(w|0)|0)==0&(t|0)==0)){E=100;break c}}}while(0);E=(o|0)>50?o:50}else{E=100}}while(0);o=n>>>0<4>>>0;m=YGb(o?4:n,o?0:0,q,p)|0;o=F;t=YGb(m,o,8,0)|0;w=F;s=0;if((w|0)>(s|0)|(w|0)==(s|0)&t>>>0>e>>>0){z=E;A=v;break}else{h=o;j=m;k=E;l=v}}if((z|0)<51|(A|0)==-1){f=z;i=b;return f|0}v=e-16|0;if((A|0)>=(v|0)){f=z;i=b;return f|0}e=c[a+4>>2]|0;a=(A|0)<0|0?-1:0;l=A;d:while(1){A=l;E=e+A|0;do{if((d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)==1919706216){k=e+(A+8)|0;if((d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)!=1919707245){break}k=e+(A+12)|0;if((d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)==1195724877){break d}}}while(0);A=YGb(l,a,2,0)|0;E=F;n=(v|0)<0|0?-1:0;if((E|0)<(n|0)|(E|0)==(n|0)&A>>>0<v>>>0){a=E;l=A}else{f=z;u=25;break}}if((u|0)==25){i=b;return f|0}yDb(0,24,2264392,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;f=5;i=b;return f|0}function pH(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;d=i;i=i+72|0;e=d|0;f=d+24|0;g=d+40|0;h=d+48|0;j=d+56|0;k=b+12|0;l=c[k>>2]|0;m=b+16|0;n=c[m>>2]|0;c[j>>2]=1953460082;o=j+8|0;c[o>>2]=0;c[o+4>>2]=0;p=l+4|0;c[p>>2]=b;q=n+88|0;if((c[q>>2]|0)==0){r=2147483647;s=-1}else{t=Wy(n)|0;r=F;s=t}c[o>>2]=s;c[o+4>>2]=r;r=nH(l,n,j)|0;if((r|0)<0){yDb(b,16,1925472,(u=i,i=i+8|0,c[u>>2]=r,u)|0);i=u;rH(b)|0;v=r;i=d;return v|0}if((c[l+24>>2]|0)==0){yDb(b,16,1903488,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;rH(b)|0;v=-1094995529;i=d;return v|0}do{if((c[q>>2]|0)==0){w=c[b+24>>2]|0;y=38}else{a:do{if((c[l+100>>2]|0)>0){r=h;j=b+24|0;n=c[j>>2]|0;o=b+28|0;s=(c[k>>2]|0)+100|0;t=0;while(1){if(!(t>>>0<n>>>0)){break}z=c[(c[o>>2]|0)+(t<<2)>>2]|0;if((c[z+4>>2]|0)==(c[s>>2]|0)){y=14;break}else{t=t+1|0}}do{if((y|0)==14){if((z|0)==0){break}c[z+76>>2]=48;t=c[z+12>>2]|0;s=Ty(c[t>>2]|0,0,0,1)|0;o=F;n=z+404|0;A=c[n>>2]|0;b:do{if((A|0)>0){B=z+400|0;C=z+40|0;D=z+56|0;E=0;G=A;while(1){H=c[B>>2]|0;I=E+1|0;if((I|0)<(G|0)){J=H+(I*24|0)+8|0}else{J=D}K=c[J>>2]|0;L=c[J+4>>2]|0;M=H+(E*24|0)|0;N=Ty(c[t>>2]|0,c[M>>2]|0,c[M+4>>2]|0,0)|0;if(!((N|0)==(c[M>>2]|0)&(F|0)==(c[M+4>>2]|0))){break}M=tz(c[t>>2]|0)|0;if((M|0)<=((c[H+(E*24|0)+16>>2]>>2)-2|0)){N=M<<1|1;O=cEb(N)|0;c[h>>2]=O;if((O|0)==0){break b}do{if((M|0)==0){a[O]=0}else{P=tz(c[t>>2]|0)|0;Q=P&65535;if((Q|0)==65534){yz(c[t>>2]|0,M,c[h>>2]|0,N)|0;break}else if((Q|0)==65279){zz(c[t>>2]|0,M,c[h>>2]|0,N)|0;break}else{Q=de(P&65535|0)|0;P=c[h>>2]|0;x=Q;a[P]=x;x=x>>8;a[P+1|0]=x;P=M-1|0;if(P>>>0<2>>>0){a[(c[h>>2]|0)+M|0]=0;break}else{xz(c[t>>2]|0,2147483647,(c[h>>2]|0)+2|0,P)|0;break}}}}while(0);M=H+(E*24|0)+8|0;OT(b,E,C,c[M>>2]|0,c[M+4>>2]|0,K,L,c[h>>2]|0)|0;$Db(r)}M=c[n>>2]|0;if((I|0)<(M|0)){E=I;G=M}else{break b}}yDb(b,16,2279568,(u=i,i=i+8|0,c[u>>2]=E,u)|0);i=u}}while(0);Ty(c[t>>2]|0,s,o,0)|0;R=j;break a}}while(0);yDb(b,16,2296496,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;R=j}else{R=b+24|0}}while(0);if((c[R>>2]|0)==0){S=0;T=b+24|0;break}r=b+28|0;n=f|0;A=g|0;G=g+4|0;C=b;D=0;while(1){B=c[(c[r>>2]|0)+(D<<2)>>2]|0;M=B+8|0;do{if((c[(c[M>>2]|0)+52>>2]|0)==1684237684){N=c[B+12>>2]|0;O=N;P=Ty(c[O>>2]|0,0,0,1)|0;Q=F;if((c[B+404>>2]|0)==0){break}U=c[B+400>>2]|0;Ty(c[O>>2]|0,c[U>>2]|0,c[U+4>>2]|0,0)|0;U=vz(c[m>>2]|0)|0;V=c[N+1216>>2]|0;N=V&1;W=(V&2|0)==0?N:N|2;N=c[M>>2]|0;c[A>>2]=c[N+108>>2];c[G>>2]=c[N+104>>2];if((cGb(e,g,(V&4|0)==0?W:W|4,0,C)|0)>=0){CBb(B+88|0,2341424,_Fb(e,n,U)|0,0)|0}Ty(c[O>>2]|0,P,Q,0)|0;}}while(0);B=D+1|0;M=c[R>>2]|0;if(B>>>0<M>>>0){D=B}else{w=M;y=38;break}}}}while(0);do{if((y|0)==38){R=b+24|0;if((w|0)==0){S=0;T=R;break}e=b+28|0;g=0;m=w;do{f=c[e>>2]|0;h=c[f+(g<<2)>>2]|0;J=c[(c[h+12>>2]|0)+156>>2]|0;do{if(!((J|0)<1|(m|0)==0)){z=-1;k=0;do{z=(c[(c[f+(k<<2)>>2]|0)+4>>2]|0)==(J|0)?k:z;k=k+1|0;}while(k>>>0<m>>>0);if((z|0)<0|(z|0)==(g|0)){break}k=BBb(c[(c[f+(z<<2)>>2]|0)+88>>2]|0,2341424,0,0)|0;if((k|0)==0){break}CBb(h+88|0,2341424,c[k+4>>2]|0,0)|0}}while(0);g=g+1|0;m=c[R>>2]|0;}while(g>>>0<m>>>0);c:do{if((m|0)==0){X=0}else{g=b+28|0;e=0;h=m;f=m;d:while(1){J=c[g>>2]|0;k=c[J+(e<<2)>>2]|0;o=e+1|0;e:do{if((c[(c[k+8>>2]|0)+52>>2]|0)==1684237684){if((h|0)!=0){s=0;do{t=c[J+(s<<2)>>2]|0;if((c[(c[t+8>>2]|0)+8>>2]|0)==0){if((c[(c[t+12>>2]|0)+156>>2]|0)==(o|0)){Y=h;Z=f;break e}}s=s+1|0;}while(s>>>0<h>>>0)}_=BBb(c[k+88>>2]|0,2341424,0,0)|0;if((_|0)!=0){break d}s=c[R>>2]|0;Y=s;Z=s}else{Y=h;Z=f}}while(0);if(o>>>0<Y>>>0){e=o;h=Y;f=Z}else{X=Z;break c}}CBb(b+1140|0,2341424,c[_+4>>2]|0,0)|0;X=c[R>>2]|0}}while(0);if((X|0)==0){S=0;T=R;break}m=b+28|0;f=l+8|0;h=0;while(1){e=c[(c[m>>2]|0)+(h<<2)>>2]|0;g=c[e+12>>2]|0;k=g+92|0;do{if((c[k>>2]|0)<1){yDb(c[p>>2]|0,24,2318608,(u=i,i=i+8|0,c[u>>2]=c[g+8>>2],u)|0);i=u;J=c[f>>2]|0;c[k>>2]=J;if((J|0)>=1){break}c[k>>2]=1}}while(0);J=c[e+8>>2]|0;z=c[J+8>>2]|0;do{if((z|0)==1){if((c[J+48>>2]|0)!=86018){break}c[e+448>>2]=c[g+1232>>2];if((z|0)==0){y=71}}else if((z|0)==0){y=71}}while(0);do{if((y|0)==71){y=0;z=c[g+1244>>2]|0;if((z|0)<=0){break}J=g+1248|0;s=c[J>>2]|0;E=c[J+4>>2]|0;J=0;if(!((E|0)>(J|0)|(E|0)==(J|0)&s>>>0>0>>>0)){break}J=c[k>>2]|0;t=gHb(J,(J|0)<0|0?-1:0,z,(z|0)<0|0?-1:0)|0;iFb(e+92|0,e+96|0,t,F,s,E,2147483647,0)|0}}while(0);e=h+1|0;k=c[R>>2]|0;if(e>>>0<k>>>0){h=e}else{S=k;T=R;break}}}}while(0);if(!((c[l+88>>2]|0)==0|(S|0)==0)){y=c[b+28>>2]|0;u=0;p=S;while(1){S=c[y+(u<<2)>>2]|0;X=c[S+12>>2]|0;_=S+56|0;Z=c[_>>2]|0;Y=c[_+4>>2]|0;_=0;if((Y|0)>(_|0)|(Y|0)==(_|0)&Z>>>0>0>>>0){_=X+1208|0;w=c[_>>2]|0;R=c[X+92>>2]|0;X=gHb(w<<3|0>>>29,c[_+4>>2]<<3|w>>>29,R,(R|0)<0|0?-1:0)|0;R=eHb(X,F,Z,Y)|0;c[(c[S+8>>2]|0)+72>>2]=R;$=c[T>>2]|0}else{$=p}R=u+1|0;if(R>>>0<$>>>0){u=R;p=$}else{break}}}$=l+124|0;p=c[$>>2]|0;f:do{if((p|0)>0){u=l+120|0;y=b+28|0;R=0;S=p;while(1){if(!(R>>>0<(c[T>>2]|0)>>>0)){break f}Y=c[(c[u>>2]|0)+(R<<2)>>2]|0;if((Y|0)==0){aa=S}else{c[(c[(c[(c[y>>2]|0)+(R<<2)>>2]|0)+8>>2]|0)+72>>2]=Y;aa=c[$>>2]|0}Y=R+1|0;if((Y|0)<(aa|0)){R=Y;S=aa}else{break}}}}while(0);ET(b);v=0;i=d;return v|0}function qH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;d=i;i=i+16|0;e=d|0;f=c[a+12>>2]|0;g=f;h=f+4|0;c[h>>2]=a;j=a+24|0;k=f+28|0;l=f+112|0;m=a+16|0;n=e|0;o=e+8|0;p=a+28|0;a=b+32|0;q=b+16|0;r=b+48|0;s=b+8|0;t=f+32|0;f=b+24|0;u=b+28|0;v=b+64|0;w=0;a:while(1){x=c[j>>2]|0;do{if((x|0)==0){y=w}else{z=c[p>>2]|0;A=0;B=2147483647;C=-1;D=0;E=w;while(1){G=c[z+(A<<2)>>2]|0;H=c[G+12>>2]|0;I=c[H>>2]|0;b:do{if((I|0)==0){J=D;K=B;L=C;M=E}else{N=c[H+120>>2]|0;if((N|0)>=(c[G+404>>2]|0)){J=D;K=B;L=C;M=E;break}O=c[G+400>>2]|0;P=O+(N*24|0)|0;Q=O+(N*24|0)+8|0;N=c[H+92>>2]|0;O=IDb(c[Q>>2]|0,c[Q+4>>2]|0,1e6,0,N,(N|0)<0|0?-1:0)|0;N=F;do{if((D|0)!=0){Q=c[m>>2]|0;if((c[Q+88>>2]|0)==0){R=P|0;S=c[R+4>>2]|0;T=D|0;U=c[T+4>>2]|0;if((S|0)<(U|0)|(S|0)==(U|0)&(c[R>>2]|0)>>>0<(c[T>>2]|0)>>>0){break}else{J=D;K=B;L=C;M=E;break b}}T=(N|0)<(B|0)|(N|0)==(B|0)&O>>>0<C>>>0;if((I|0)!=(Q|0)&T){break}if((I|0)!=(Q|0)){J=D;K=B;L=C;M=E;break b}Q=ZGb(C,B,O,N)|0;R=F;U=-1;S=(R|0)>(U|0)|(R|0)==(U|0)&Q>>>0>-1>>>0;U=ZGb(0,0,Q,R)|0;V=S?R:F;R=0;if((V|0)<(R|0)|(V|0)==(R|0)&(S?Q:U)>>>0<1000001>>>0){U=P|0;Q=c[U+4>>2]|0;S=D|0;R=c[S+4>>2]|0;if((Q|0)<(R|0)|(Q|0)==(R|0)&(c[U>>2]|0)>>>0<(c[S>>2]|0)>>>0){break}else{J=D;K=B;L=C;M=E;break b}}else{if(T){break}else{J=D;K=B;L=C;M=E;break b}}}}while(0);J=P;K=N;L=O;M=G}}while(0);G=A+1|0;if(G>>>0<x>>>0){A=G;B=K;C=L;D=J;E=M}else{break}}if((J|0)==0){y=M;break}W=c[M+12>>2]|0;E=W+120|0;c[E>>2]=(c[E>>2]|0)+1;D=c[l>>2]|0;C=c[l+4>>2]|0;if(!((D|0)==0&(C|0)==0)){B=J|0;A=c[B>>2]|0;z=c[B+4>>2]|0;G=(z|0)>(C|0)|(z|0)==(C|0)&A>>>0>D>>>0;I=G?D:A;A=G?C:z;c[B>>2]=I;c[B+4>>2]=A;B=J+16|0;z=c[B>>2]|0;C=z>>2;G=(C|0)<0|0?-1:0;D=ZGb(c[l>>2]|0,c[l+4>>2]|0,I,A)|0;A=F;c[B>>2]=((G|0)>(A|0)|(G|0)==(A|0)&C>>>0>D>>>0?D:C)<<2|z&3}z=M+76|0;do{if((c[z>>2]|0)!=48){C=W;D=J|0;A=Ty(c[C>>2]|0,c[D>>2]|0,c[D+4>>2]|0,0)|0;X=c[D>>2]|0;Y=c[D+4>>2]|0;if(!((A|0)==(X|0)&(F|0)==(Y|0))){Z=24;break a}A=TS(c[C>>2]|0,b,c[J+16>>2]>>2)|0;if((A|0)<0){_=A;Z=45;break a}A=W+1200|0;do{if((c[A>>2]|0)!=0){C=GZ(b,0,1024)|0;if((C|0)==0){yDb(c[h>>2]|0,16,1951848,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;break}else{UGb(C|0,W+176|0,1024)|0;c[A>>2]=0;break}}}while(0);A=c[t>>2]|0;if((A|0)==0){break}if((c[W+132>>2]|0)==0){break}yB(A,b,c[f>>2]|0,c[u>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;ZDb(c[f>>2]|0);c[u>>2]=0;A=xB(c[t>>2]|0,b)|0;if((A|0)<0){_=A;Z=45;break a}}}while(0);c[a>>2]=c[W+8>>2];A=J+8|0;C=c[A>>2]|0;D=c[A+4>>2]|0;c[q>>2]=C;c[q+4>>2]=D;A=c[W+36>>2]|0;do{if((A|0)==0){Z=39}else{G=W+56|0;B=c[G>>2]|0;if(!(B>>>0<(c[W+32>>2]|0)>>>0)){Z=39;break}I=c[W+172>>2]|0;H=YGb(I,(I|0)<0|0?-1:0,C,D)|0;I=c[A+(B<<3)+4>>2]|0;T=YGb(H,F,I,(I|0)<0|0?-1:0)|0;c[s>>2]=T;c[s+4>>2]=F;T=W+60|0;I=(c[T>>2]|0)+1|0;c[T>>2]=I;if((c[A+(B<<3)>>2]|0)==(I|0)){c[G>>2]=B+1;c[T>>2]=0}if((c[W+160>>2]|0)==0){break}c[q>>2]=0;c[q+4>>2]=-2147483648}}while(0);if((Z|0)==39){Z=0;A=c[E>>2]|0;if((A|0)<(c[M+404>>2]|0)){aa=(c[M+400>>2]|0)+(A*24|0)+8|0}else{aa=M+56|0}A=ZGb(c[aa>>2]|0,c[aa+4>>2]|0,C,D)|0;c[r>>2]=A;c[s>>2]=C;c[s+4>>2]=D}if((c[z>>2]|0)==48){w=M;continue a}else{Z=44;break a}}}while(0);c[k>>2]=0;x=c[l>>2]|0;A=c[l+4>>2]|0;if((x|0)==0&(A|0)==0){_=-541478725;Z=45;break}Ty(c[m>>2]|0,x,A,0)|0;c[l>>2]=0;c[l+4>>2]=0;A=c[m>>2]|0;c[n>>2]=1953460082;c[o>>2]=-1;c[o+4>>2]=2147483647;if((nH(g,A,e)|0)<0){_=-541478725;Z=45;break}if((Xy(c[m>>2]|0)|0)==0){w=y}else{_=-541478725;Z=45;break}}if((Z|0)==24){yDb(c[h>>2]|0,16,1982688,($=i,i=i+24|0,c[$>>2]=c[W+8>>2],c[$+8>>2]=X,c[$+16>>2]=Y,$)|0);i=$;_=-1094995529;i=d;return _|0}else if((Z|0)==44){$=b+36|0;c[$>>2]=c[$>>2]|c[J+16>>2]&1;$=J|0;J=c[$+4>>2]|0;c[v>>2]=c[$>>2];c[v+4>>2]=J;_=0;i=d;return _|0}else if((Z|0)==45){i=d;return _|0}return 0}function rH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+12>>2]|0;d=a+24|0;if((c[d>>2]|0)!=0){e=a+28|0;a=0;do{f=c[(c[(c[e>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;$Db(f+36|0);g=f+144|0;h=f+148|0;if((c[g>>2]|0)!=0){i=h;j=0;do{$Db((c[i>>2]|0)+(j*108|0)+4|0);$Db((c[i>>2]|0)+(j*108|0)+8|0);j=j+1|0;}while(j>>>0<(c[g>>2]|0)>>>0)}$Db(h);g=f;if((c[f+4>>2]|0)==0){Iz(c[g>>2]|0)|0}c[g>>2]=0;$Db(f+20|0);$Db(f+44|0);$Db(f+76|0);$Db(f+88|0);$Db(f+28|0);$Db(f+52|0);$Db(f+1240|0);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0)}d=b+32|0;if((c[d>>2]|0)==0){k=b+88|0;$Db(k);l=b+120|0;$Db(l);return 0}a=b+36|0;e=a;g=c[e>>2]|0;if((c[g+24>>2]|0)!=0){j=0;i=g;do{$Db((c[(c[i+28>>2]|0)+(j<<2)>>2]|0)+8|0);$Db((c[(c[e>>2]|0)+28>>2]|0)+(j<<2)|0);j=j+1|0;i=c[e>>2]|0;}while(j>>>0<(c[i+24>>2]|0)>>>0)}$Db(a);$Db(d);k=b+88|0;$Db(k);l=b+120|0;$Db(l);return 0}function sH(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=a+24|0;if(!((c[g>>2]|0)>>>0>b>>>0)){h=-1094995529;return h|0}i=a+28|0;a=c[(c[i>>2]|0)+(b<<2)>>2]|0;j=c[a+12>>2]|0;k=oT(a,d,e,f)|0;do{if((k|0)<0){if((c[a+404>>2]|0)==0){h=-1094995529;return h|0}l=(c[a+400>>2]|0)+8|0;m=c[l+4>>2]|0;n=(m|0)>(e|0)|(m|0)==(e|0)&(c[l>>2]|0)>>>0>d>>>0?0:k;if((n|0)<0){h=-1094995529}else{o=n;break}return h|0}else{o=k}}while(0);c[j+120>>2]=o;k=c[j+36>>2]|0;do{if((k|0)!=0){n=c[j+32>>2]|0;l=0;m=0;while(1){if(!(l>>>0<n>>>0)){break}p=(c[k+(l<<3)>>2]|0)+m|0;if((p|0)>(o|0)){q=9;break}else{l=l+1|0;m=p}}if((q|0)==9){c[j+56>>2]=l;c[j+60>>2]=o-m}if((o|0)<0){h=o}else{break}return h|0}}while(0);j=(c[a+400>>2]|0)+(o*24|0)+8|0;o=c[j>>2]|0;a=c[j+4>>2]|0;if((c[g>>2]|0)==0){h=0;return h|0}j=0;if((e|0)<(j|0)|(e|0)==(j|0)&d>>>0<1>>>0){d=0;while(1){j=c[i>>2]|0;e=c[j+(d<<2)>>2]|0;c[e+448>>2]=c[(c[e+12>>2]|0)+1232>>2];a:do{if((d|0)!=(b|0)){q=KDb(o,a,(c[j+(b<<2)>>2]|0)+40|0,e+40|0)|0;k=F;n=c[e+12>>2]|0;p=oT(e,q,k,f)|0;if((p|0)<0){if((c[e+404>>2]|0)==0){break}r=(c[e+400>>2]|0)+8|0;s=c[r+4>>2]|0;t=(s|0)>(k|0)|(s|0)==(k|0)&(c[r>>2]|0)>>>0>q>>>0?0:p;if((t|0)<0){break}else{u=t}}else{u=p}c[n+120>>2]=u;p=c[n+36>>2]|0;if((p|0)==0){break}t=c[n+32>>2]|0;q=0;r=0;while(1){if(!(q>>>0<t>>>0)){break a}k=(c[p+(q<<3)>>2]|0)+r|0;if((k|0)>(u|0)){break}else{q=q+1|0;r=k}}c[n+56>>2]=q;c[n+60>>2]=u-r}}while(0);e=d+1|0;if(e>>>0<(c[g>>2]|0)>>>0){d=e}else{h=0;break}}return h|0}else{d=0;while(1){u=c[i>>2]|0;e=c[u+(d<<2)>>2]|0;c[e+448>>2]=0;b:do{if((d|0)!=(b|0)){j=KDb(o,a,(c[u+(b<<2)>>2]|0)+40|0,e+40|0)|0;m=F;l=c[e+12>>2]|0;p=oT(e,j,m,f)|0;if((p|0)<0){if((c[e+404>>2]|0)==0){break}t=(c[e+400>>2]|0)+8|0;k=c[t+4>>2]|0;s=(k|0)>(m|0)|(k|0)==(m|0)&(c[t>>2]|0)>>>0>j>>>0?0:p;if((s|0)<0){break}else{v=s}}else{v=p}c[l+120>>2]=v;p=c[l+36>>2]|0;if((p|0)==0){break}s=c[l+32>>2]|0;j=0;t=0;while(1){if(!(j>>>0<s>>>0)){break b}m=(c[p+(j<<3)>>2]|0)+t|0;if((m|0)>(v|0)){break}else{j=j+1|0;t=m}}c[l+56>>2]=j;c[l+60>>2]=v-t}}while(0);e=d+1|0;if(e>>>0<(c[g>>2]|0)>>>0){d=e}else{h=0;break}}return h|0}return 0}function tH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;f=i;i=i+3200|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f|0;h=f+2128|0;j=f+2136|0;k=f+2144|0;l=f+2152|0;m=f+3176|0;n=f+3192|0;c[n>>2]=0;o=(c[b+96>>2]|0)==0;p=c[e>>2]|0;if((p|0)==757935405&(o^1)){q=c[b+4>>2]|0;r=e+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;r=f+80|0;u=f+1104|0;TGb(r|0,0,1024)|0;TGb(u|0,0,1024)|0;v=c[q+24>>2]|0;if((v|0)==0){w=0;i=f;return w|0}x=c[(c[(c[q+28>>2]|0)+(v-1<<2)>>2]|0)+12>>2]|0;v=0;if((t|0)<(v|0)|(t|0)==(v|0)&s>>>0<9>>>0){w=0;i=f;return w|0}v=vz(d)|0;q=rz(d)|0;if((q|0)==1635017060){vz(d)|0;vz(d)|0;y=YGb(s,t,-16,-1)|0;z=u;A=v-16|0;B=F;C=y;D=8}else if((q|0)==1701667182){vz(d)|0;q=YGb(s,t,-12,-1)|0;z=r;A=v-12|0;B=F;C=q;D=8}else{E=0;G=t;H=s;I=v-8|0}if((D|0)==8){v=A>>>0<1023>>>0;s=v?A:1023;t=v?0:0;v=(t|0)>(B|0)|(t|0)==(B|0)&s>>>0>C>>>0;q=v?C:s;v?B:t;t=q;mz(d,z,t)|0;a[z+t|0]=0;E=t;G=B;H=C;I=A}A=ZGb(H,G,I,(I|0)<0|0?-1:0)|0;G=F;if((I|0)>(E|0)){H=I-E|0;Vy(d,H,(H|0)<0|0?-1:0)|0;}H=vz(d)|0;E=rz(d)|0;if((E|0)==1635017060){vz(d)|0;vz(d)|0;I=YGb(A,G,-16,-1)|0;J=u;K=H-16|0;L=F;M=I;D=21}else if((E|0)==1701667182){vz(d)|0;E=YGb(A,G,-12,-1)|0;J=r;K=H-12|0;L=F;M=E;D=21}else{N=0;O=G;P=A;Q=H-8|0}if((D|0)==21){H=K>>>0<1023>>>0;A=H?K:1023;G=H?0:0;H=(G|0)>(L|0)|(G|0)==(L|0)&A>>>0>M>>>0;E=H?M:A;H?L:G;G=E;mz(d,J,G)|0;a[J+G|0]=0;N=G;O=L;P=M;Q=K}K=ZGb(P,O,Q,(Q|0)<0|0?-1:0)|0;O=F;if((Q|0)>(N|0)){P=Q-N|0;Vy(d,P,(P|0)<0|0?-1:0)|0;}P=vz(d)|0;N=rz(d)|0;if((N|0)==1701667182){vz(d)|0;Q=YGb(K,O,-12,-1)|0;R=r;S=P-12|0;T=F;U=Q;D=28}else if((N|0)==1635017060){vz(d)|0;vz(d)|0;N=YGb(K,O,-16,-1)|0;R=u;S=P-16|0;T=F;U=N;D=28}else{V=0;W=P-8|0}if((D|0)==28){P=S>>>0<1023>>>0;N=P?S:1023;O=P?0:0;P=(O|0)>(T|0)|(O|0)==(T|0)&N>>>0>U>>>0;K=P?U:N;P?T:O;O=K;mz(d,R,O)|0;a[R+O|0]=0;V=O;W=S}if((W|0)>(V|0)){S=W-V|0;Vy(d,S,(S|0)<0|0?-1:0)|0;}do{if((a[r]|0)!=0){if((a[u]|0)==0){break}do{if((QGb(r,1979512)|0)==0){S=xd(u|0,1976816,(X=i,i=i+24|0,c[X>>2]=h,c[X+8>>2]=j,c[X+16>>2]=k,X)|0)|0;i=X;if((S|0)!=3){break}S=c[h>>2]|0;if(!((S-1|0)>>>0<16383>>>0)){w=1;i=f;return w|0}c[x+1232>>2]=S;w=1;i=f;return w|0}}while(0);if((QGb(r,1974512)|0)==0){w=1}else{break}i=f;return w|0}}while(0);w=0;i=f;return w|0}if((p|0)==1414676833){Y=2161320;Z=0}else if((p|0)==1953658793){Y=2154656;Z=0}else if((p|0)==1651270057){Y=2122800;Z=0}else if((p|0)==1869575337|(p|0)==1920431017){Y=2095976;Z=0}else if((p|0)==1668179369){Y=2095976;Z=0}else if((p|0)==1953849769|(p|0)==1414676905){Y=2168888;Z=0}else if((p|0)==1885431664){Y=2022864;Z=530}else if((p|0)==1297240128){r=c[e+8>>2]|0;x=WDb(r+1|0)|0;if((x|0)==0){w=-12;i=f;return w|0}mz(d,x,r)|0;a[x+r|0]=0;w=CBb((c[b+4>>2]|0)+1140|0,2019496,x,8)|0;i=f;return w|0}else if((p|0)==2054781097){Y=2080360;Z=0}else if((p|0)==1668506980){Y=2075216;Z=0}else if((p|0)==1801547177){Y=2090472;Z=0}else if((p|0)==1685024169){Y=2085528;Z=0}else if((p|0)==1920560297){Y=2135352;Z=0}else if((p|0)==1953325993|(p|0)==1718512041){Y=2129032;Z=0}else if((p|0)==1852139433){Y=2107040;Z=0}else if((p|0)==1701998183){Y=2107040;Z=594}else if((p|0)==1853060724){Y=2034504;Z=20}else if((p|0)==1802073203){Y=2030232;Z=530}else if((p|0)==1685480552){Y=2026336;Z=530}else if((p|0)==1852143220){Y=2061888;Z=0}else if((p|0)==1852733044){Y=2058416;Z=0}else if((p|0)==1835101865){Y=2183968;Z=0}else if((p|0)==2036425897){Y=2117624;Z=0}else if((p|0)==1364348992){x=c[e+8>>2]|0;r=WDb(x+1|0)|0;if((r|0)==0){w=-12;i=f;return w|0}mz(d,r,x)|0;a[r+x|0]=0;w=CBb((c[b+4>>2]|0)+1140|0,2015360,r,8)|0;i=f;return w|0}else if((p|0)==1953656931|(p|0)==2037408681){Y=2147576;Z=0}else if((p|0)==1886545833){Y=2141264;Z=0}else if((p|0)==1852535412){Y=2049720;Z=520}else if((p|0)==1802725732){Y=2041152;Z=520}else if((p|0)==1936029300){Y=2037752;Z=20}else if((p|0)==1936024684){Y=2070624;Z=0}else if((p|0)==1752397428){Y=2066088;Z=0}else{Y=0;Z=0}r=e+8|0;x=c[r>>2]|0;h=c[r+4>>2]|0;k=0;a:do{if(((h|0)>(k|0)|(h|0)==(k|0)&x>>>0>8>>>0)&(o^1)){j=vz(d)|0;if((rz(d)|0)!=1635017060){w=0;i=f;return w|0}u=vz(d)|0;vz(d)|0;S=j-16|0;j=YGb(x,h,-16,-1)|0;V=F;c[r>>2]=j;c[r+4>>2]=V;if((p|0)!=1920364387){_=0;$=u;aa=S;ba=V;ca=j;break}W=g;if((u|0)==27){da=79}else if((u|0)==14){da=62}else if((u|0)==13){da=8}else{yDb(c[b+4>>2]|0,24,1993264,(X=i,i=i+8|0,c[X>>2]=u,X)|0);i=X;Vy(d,S,(S|0)<0|0?-1:0)|0;_=0;$=u;aa=S;ba=V;ca=j;break}O=b+4|0;R=LT(c[O>>2]|0,0)|0;do{if((R|0)==0){ea=-12}else{K=cEb(1256)|0;if((K|0)==0){ea=-12;break}c[R+12>>2]=K;K=TS(d,g,S)|0;if((K|0)<0){ea=K;break}K=R+72|0;c[K>>2]=c[K>>2]|1024;UGb(R+104|0,W|0,80)|0;c[R+136>>2]=c[R>>2];K=R+140|0;c[K>>2]=c[K>>2]|1;K=c[R+8>>2]|0;c[K+8>>2]=0;c[K+48>>2]=da;_=0;$=u;aa=S;ba=V;ca=j;break a}}while(0);yDb(c[O>>2]|0,16,2011968,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;w=ea;i=f;return w|0}else{j=0;if((h|0)<(j|0)|(h|0)==(j|0)&x>>>0<5>>>0|(Y|0)==0|o^1){_=0;$=0;aa=x;ba=h;ca=x;break}else{j=e+8|0;V=tz(d)|0;S=(tz(d)|0)&65535;rF(S,n)|0;u=YGb(x,h,-4,-1)|0;R=F;c[j>>2]=u;c[j+4>>2]=R;_=S;$=0;aa=V;ba=R;ca=u;break}}}while(0);if((Y|0)==0){w=0;i=f;return w|0}h=0;if((ba|0)<(h|0)|(ba|0)==(h|0)&ca>>>0<0>>>0){w=-1094995529;i=f;return w|0}h=aa>>>0<1023>>>0;x=h?aa:1023;aa=h?0:0;h=(aa|0)>(ba|0)|(aa|0)==(ba|0)&x>>>0>ca>>>0;h?ba:aa;aa=h?ca:x;if((Z|0)!=0){_e[Z&1023](b,d,aa,Y)|0;w=0;i=f;return w|0}if(($|0)==0){if(_>>>0<1024>>>0|(_|0)==32767){D=88}else{D=89}}else if(($|0)==3){D=88}else{D=89}do{if((D|0)==88){yH(d,aa,l|0,1024)}else if((D|0)==89){$=mz(d,l|0,aa)|0;if(($|0)==(aa|0)){a[l+aa|0]=0;break}w=($|0)<0?$:-1094995529;i=f;return w|0}}while(0);aa=b+4|0;b=l|0;CBb((c[aa>>2]|0)+1140|0,Y,b,0)|0;l=n;if((a[l]|0)==0){w=0;i=f;return w|0}if((QGb(l,2004040)|0)==0){w=0;i=f;return w|0}l=m|0;Lb(l|0,16,1996416,(X=i,i=i+16|0,c[X>>2]=Y,c[X+8>>2]=n,X)|0)|0;i=X;CBb((c[aa>>2]|0)+1140|0,l,b,0)|0;w=0;i=f;return w|0}function uH(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;d=i;i=i+24|0;lz(b)|0;f=(lz(b)|0)<<16;if((f-65536|0)>>>0>9568256>>>0){i=d;return 0}b=d|0;Lb(b|0,20,1982416,(g=i,i=i+8|0,c[g>>2]=c[1205192+((f>>16)-1<<2)>>2],g)|0)|0;i=g;CBb((c[a+4>>2]|0)+1140|0,e,b,0)|0;i=d;return 0}function vH(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+16|0;g=f|0;tz(b)|0;h=tz(b)|0;do{if(d>>>0>5>>>0){j=(tz(b)|0)&65535;k=g|0;l=h<<16>>16;if(j<<16>>16==0){m=k;n=l;break}Lb(k|0,16,1986032,(o=i,i=i+16|0,c[o>>2]=l,c[o+8>>2]=j<<16>>16,o)|0)|0;i=o;p=k;q=a+4|0;r=c[q>>2]|0;s=r+1140|0;t=CBb(s,e,p,0)|0;i=f;return 0}else{m=g|0;n=h<<16>>16}}while(0);Lb(m|0,16,1989768,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;p=m;q=a+4|0;r=c[q>>2]|0;s=r+1140|0;t=CBb(s,e,p,0)|0;i=f;return 0}function wH(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;d=i;i=i+16|0;lz(b)|0;lz(b)|0;lz(b)|0;f=d|0;g=lz(b)|0;Lb(f|0,16,1989768,(b=i,i=i+8|0,c[b>>2]=g,b)|0)|0;i=b;CBb((c[a+4>>2]|0)+1140|0,e,f,0)|0;i=d;return 0}function xH(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;d=i;i=i+16|0;f=d|0;g=lz(b)|0;Lb(f|0,16,1989768,(b=i,i=i+8|0,c[b>>2]=g,b)|0)|0;i=b;CBb((c[a+4>>2]|0)+1140|0,e,f,0)|0;i=d;return 0}function yH(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=f+(g-1)|0;if((e|0)>0){i=0;j=f}else{k=f;a[k]=0;return}while(1){f=lz(b)|0;g=f&255;l=j>>>0<h>>>0;a:do{if(g>>>0<128>>>0&l){a[j]=f;m=j+1|0}else{if(!l){m=j;break}n=c[686576+(g-128<<2)>>2]|0;o=(n&65280|0)==0;p=(((d[1191992+(o?n:n>>>8)|0]|0)+4+(o?0:8)|0)>>>0)/5|0;o=(p*6|0)-6|0;a[j]=n>>>(o>>>0)|256-(256>>>(p>>>0));p=j;q=o;while(1){r=p+1|0;if(!(r>>>0<h>>>0)){s=q;break}if((q|0)<=5){m=r;break a}o=q-6|0;a[r]=n>>>(o>>>0)&63|128;p=r;q=o}while(1){if((s|0)<=5){m=r;break a}s=s-6|0}}}while(0);g=i+1|0;if((g|0)<(e|0)){i=g;j=m}else{k=m;break}}a[k]=0;return}function zH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=vI(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,1096176969)|0;i=e;return g|0}function AH(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=c[a+4>>2]|0;h=c[g+24>>2]|0;do{if((h|0)!=0){j=c[(c[(c[g+28>>2]|0)+(h-1<<2)>>2]|0)+8>>2]|0;if((c[j+52>>2]|0)!=1852397121){break}if((c[j+48>>2]|0)!=28){break}k=e+8|0;l=c[k+4>>2]|0;m=0;if(!((l|0)>(m|0)|(l|0)==(m|0)&(c[k>>2]|0)>>>0>11>>>0)){break}Vy(b,10,0)|0;if((tz(b)|0)!=3405){n=0;i=f;return n|0}c[j+120>>2]=1440;n=0;i=f;return n|0}}while(0);h=e|0;g=e+8|0;e=g|0;j=g+4|0;n=vI(a,b,d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0,d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0,d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0,1096176969)|0;i=f;return n|0}function BH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=vI(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,83)|0;i=e;return g|0}function CH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+272|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f|0;h=f+264|0;j=e+8|0;e=YGb(c[j>>2]|0,c[j+4>>2]|0,-5,-1)|0;k=F;c[j>>2]=e;c[j+4>>2]=k;l=0;if((k|0)<(l|0)|(k|0)==(l|0)&e>>>0<0>>>0){i=f;return 0}l=lz(d)|0;uz(d)|0;if((l|0)!=0){vz(d)|0}l=lz(d)|0;if((l|0)<=0){i=f;return 0}m=g|0;n=b+4|0;b=h|0;o=h+4|0;p=0;q=k;k=e;while(1){e=0;if((q|0)<(e|0)|(q|0)==(e|0)&k>>>0<9>>>0){r=9;break}e=Az(d)|0;s=F;t=lz(d)|0;u=t+9|0;v=ZGb(k,q,u,(u|0)<0|0?-1:0)|0;u=F;c[j>>2]=v;c[j+4>>2]=u;w=0;if((u|0)<(w|0)|(u|0)==(w|0)&v>>>0<0>>>0){r=9;break}mz(d,m,t)|0;a[g+t|0]=0;t=c[n>>2]|0;c[b>>2]=1;c[o>>2]=1e7;OT(t,p,h,e,s,0,-2147483648,m)|0;s=p+1|0;if((s|0)<(l|0)){p=s;q=u;k=v}else{r=9;break}}if((r|0)==9){i=f;return 0}return 0}function DH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}h=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;lz(b)|0;uz(b)|0;a=vz(b)|0;if((a|0)==0){g=0;i=e;return g|0}if(a>>>0>536870910>>>0){g=-1094995529;i=e;return g|0}f=WDb(a<<3)|0;j=h+20|0;c[j>>2]=f;if((f|0)==0){g=-12;i=e;return g|0}f=h+16|0;c[f>>2]=a;h=c[d>>2]|0;a:do{if((h|0)==1868788851){d=b+52|0;k=0;while(1){if((c[d>>2]|0)!=0){l=k;break a}m=vz(b)|0;n=(c[j>>2]|0)+(k<<3)|0;c[n>>2]=m;c[n+4>>2]=0;n=k+1|0;if(n>>>0<a>>>0){k=n}else{l=n;break}}}else if((h|0)==875982691){k=b+52|0;d=0;while(1){if((c[k>>2]|0)!=0){l=d;break a}n=Az(b)|0;m=(c[j>>2]|0)+(d<<3)|0;c[m>>2]=n;c[m+4>>2]=F;m=d+1|0;if(m>>>0<a>>>0){d=m}else{l=m;break}}}else{g=-1094995529;i=e;return g|0}}while(0);c[f>>2]=l;g=(c[b+52>>2]|0)==0?0:-541478725;i=e;return g|0}function EH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;a=c[f>>2]|0;d=c[a+24>>2]|0;if((d|0)==0){g=0;i=e;return g|0}h=c[(c[(c[a+28>>2]|0)+(d-1<<2)>>2]|0)+12>>2]|0;lz(b)|0;uz(b)|0;d=vz(b)|0;if((d|0)==0){g=0;i=e;return g|0}if(d>>>0>536870910>>>0){g=-1094995529;i=e;return g|0}a=WDb(d<<3)|0;j=h+36|0;k=j;c[k>>2]=a;if((a|0)==0){g=-12;i=e;return g|0}a=b+52|0;l=h+172|0;m=0;while(1){if((c[a>>2]|0)!=0){n=m;o=12;break}p=vz(b)|0;q=vz(b)|0;r=c[k>>2]|0;c[r+(m<<3)>>2]=p;c[r+(m<<3)+4>>2]=q;r=-q|0;p=m+2|0;if((((q|0)>-1?q:r)|0)>268435456&p>>>0<d>>>0){o=8;break}if(p>>>0<d>>>0&(q|0)<0){q=c[l>>2]|0;c[l>>2]=(q|0)>(r|0)?q:r}r=m+1|0;if(r>>>0<d>>>0){m=r}else{n=r;o=12;break}}if((o|0)==8){yDb(c[f>>2]|0,24,2345568,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;$Db(j);c[h+32>>2]=0;g=0;i=e;return g|0}else if((o|0)==12){c[h+32>>2]=n;g=(c[a>>2]|0)==0?0:-541478725;i=e;return g|0}return 0}function FH(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;h=f;f=i;i=i+16|0;c[f>>2]=c[h>>2];c[f+4>>2]=c[h+4>>2];c[f+8>>2]=c[h+8>>2];c[f+12>>2]=c[h+12>>2];h=d+4|0;d=c[h>>2]|0;j=c[d+24>>2]|0;if((j|0)==0){k=0;i=g;return k|0}l=c[(c[(c[d+28>>2]|0)+(j-1<<2)>>2]|0)+12>>2]|0;vz(e)|0;j=vz(e)|0;d=(j|0)<0|0?-1:0;m=f+8|0;f=YGb(c[m>>2]|0,c[m+4>>2]|0,-1,-1)|0;m=eHb(f,F,12,0)|0;f=YGb(m,F,1,0)|0;m=F;if((d|0)>(m|0)|(d|0)==(m|0)&j>>>0>f>>>0|j>>>0>39768214>>>0){k=-1094995529;i=g;return k|0}f=l+148|0;ZDb(c[f>>2]|0);m=l+144|0;c[m>>2]=0;l=cEb(j*108|0)|0;d=l;c[f>>2]=d;if((l|0)==0){k=-12;i=g;return k|0}c[m>>2]=j;if((j|0)==0){k=0;i=g;return k|0}else{n=0;o=d}a:while(1){d=vz(e)|0;j=Ty(e,0,0,1)|0;l=F;p=YGb(d,0,-4,-1)|0;q=YGb(p,F,j,l)|0;l=F;if(d>>>0<12>>>0){k=-1094995529;r=33;break}j=o+(n*108|0)|0;c[j>>2]=rz(e)|0;vz(e)|0;b:do{if((c[j>>2]|0)==1936288865&d>>>0>150>>>0){Vy(e,10,0)|0;p=lz(e)|0;s=(p&65532)>>>0>27>>>0?27:p&65535;p=o+(n*108|0)+12|0;mz(e,p,27)|0;a[o+(n*108|0)+12+s|0]=0;yDb(c[h>>2]|0,48,1882248,(t=i,i=i+16|0,c[t>>2]=p,c[t+8>>2]=s,t)|0);i=t;Vy(e,12,0)|0;u=lz(e)|0;v=(u&65472)>>>0>63>>>0?63:u&65535;u=o+(n*108|0)+40|0;mz(e,u,63)|0;a[o+(n*108|0)+40+v|0]=0;yDb(c[h>>2]|0,48,1880952,(t=i,i=i+16|0,c[t>>2]=u,c[t+8>>2]=v,t)|0);i=t;Vy(e,16,0)|0;v=o+(n*108|0)+106|0;b[v>>1]=tz(e)|0;u=(tz(e)|0)&65535;b[o+(n*108|0)+104>>1]=u;yDb(c[h>>2]|0,48,1879408,(t=i,i=i+16|0,c[t>>2]=b[v>>1]|0,c[t+8>>2]=u<<16>>16,t)|0);i=t;Vy(e,16,0)|0;u=o+(n*108|0)+4|0;v=o+(n*108|0)+8|0;do{w=Ty(e,0,0,1)|0;x=F;if(!((x|0)<(l|0)|(x|0)==(l|0)&w>>>0<q>>>0)){break b}if((Xy(e)|0)!=0){k=-541478725;r=33;break a}w=(tz(e)|0)&65535;x=tz(e)|0;yDb(c[h>>2]|0,48,2355528,(t=i,i=i+16|0,c[t>>2]=w<<16>>16,c[t+8>>2]=x&65535,t)|0);i=t;if((x&1|0)==0){y=x&65535}else{y=x+1&65535}if((w<<16>>16|0)==2){ZDb(c[u>>2]|0);x=y&65535;z=cEb(x+1|0)|0;c[u>>2]=z;if((z|0)==0){k=-12;r=33;break a}mz(e,z,x)|0;do{if(x>>>0>s>>>0){z=c[u>>2]|0;if((RGb(z,p,s)|0)!=0){A=y;break}B=x-s|0;C=B&65535;VGb(z|0,z+s|0,C|0)|0;a[(c[u>>2]|0)+C|0]=0;A=B&65535}else{A=y}}while(0);x=A&65535;if(!(A<<16>>16==0)){B=0;do{C=(c[u>>2]|0)+B|0;if((a[C]|0)==58){a[C]=47}B=B+1|0;}while((B|0)<(x|0))}yDb(c[h>>2]|0,48,2351160,(t=i,i=i+8|0,c[t>>2]=c[u>>2],t)|0);i=t}else if((w<<16>>16|0)==0){ZDb(c[v>>2]|0);x=y&65535;B=WDb(x+1|0)|0;c[v>>2]=B;if((B|0)==0){k=-12;r=33;break a}if((mz(e,B,x)|0)!=(x|0)){k=-1094995529;r=33;break a}a[(c[v>>2]|0)+x|0]=0;if(!(y<<16>>16==0)){B=0;do{C=(c[v>>2]|0)+B|0;if((a[C]|0)==58){a[C]=47}B=B+1|0;}while((B|0)<(x|0))}yDb(c[h>>2]|0,48,2346856,(t=i,i=i+8|0,c[t>>2]=c[v>>2],t)|0);i=t}else{Vy(e,y&65535,0)|0;}}while(!(w<<16>>16==-1))}}while(0);Ty(e,q,l,0)|0;d=n+1|0;if(!(d>>>0<(c[m>>2]|0)>>>0)){k=0;r=33;break}n=d;o=c[f>>2]|0}if((r|0)==33){i=g;return k|0}return 0}function GH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;g=c[f>>2]|0;h=c[g+24>>2]|0;if((h|0)==0){j=0;i=e;return j|0}if((c[a+108>>2]|0)!=0){j=0;i=e;return j|0}a=c[(c[(c[g+28>>2]|0)+(h-1<<2)>>2]|0)+12>>2]|0;h=lz(b)|0;uz(b)|0;g=vz(b)|0;k=gHb(g,(g|0)<0|0?-1:0,12,0)|0;l=YGb(k,F,8,0)|0;k=F;m=d+8|0;d=c[m+4>>2]|0;if(k>>>0>d>>>0|k>>>0==d>>>0&l>>>0>(c[m>>2]|0)>>>0){j=-1094995529;i=e;return j|0}if((g|0)<=0){j=0;i=e;return j|0}m=a+96|0;l=a+104|0;if((h|0)==1){h=0;a=0;d=0;while(1){k=Az(b)|0;n=F;o=Az(b)|0;p=F;vz(b)|0;do{if((h|0)==0&((o|0)==(-1|0)&(p|0)==(-1|0))){c[m>>2]=k;c[m+4>>2]=n;q=d;r=1}else{s=-1;if(!((h|0)==(a|0)&((p|0)>(s|0)|(p|0)==(s|0)&o>>>0>-1>>>0))){q=1;r=a;break}c[l>>2]=o;c[l+4>>2]=p;q=d;r=a}}while(0);p=h+1|0;if((p|0)<(g|0)){h=p;a=r;d=q}else{t=q;break}}}else{q=0;d=0;r=0;while(1){a=vz(b)|0;h=vz(b)|0;p=h;o=(h|0)<0|0?-1:0;vz(b)|0;do{if((q|0)==0&(h|0)==-1){c[m>>2]=a;c[m+4>>2]=0;u=r;v=1}else{if(!((q|0)==(d|0)&(h|0)>-1)){u=1;v=d;break}c[l>>2]=p;c[l+4>>2]=o;u=r;v=d}}while(0);o=q+1|0;if((o|0)<(g|0)){q=o;d=v;r=u}else{t=u;break}}}if((t|0)==0){j=0;i=e;return j|0}yDb(c[f>>2]|0,24,1883272,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;j=0;i=e;return j|0}function HH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;do{if((a|0)!=0){d=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;if(((tz(b)|0)&255|0)!=1){break}g=(c[d+8>>2]|0)+48|0;d=c[g>>2]|0;if((d|0)==65558){c[g>>2]=65559;break}else if((d|0)==65556){c[g>>2]=65557;break}else if((d|0)==65549){c[g>>2]=65548;break}else if((d|0)==65545){c[g>>2]=65544;break}else{break}}}while(0);i=e;return 0}function IH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}h=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;a=d+8|0;d=c[a+4>>2]|0;f=0;if((d|0)<(f|0)|(d|0)==(f|0)&(c[a>>2]|0)>>>0<2>>>0){g=-1094995529;i=e;return g|0}a=tz(b)|0;b=a&65280;do{if((b|0)==512){f=a&255;if((f|0)==6){j=3;break}else if((f|0)==9){j=4;break}else if((f|0)==1){j=2;break}else if((f|0)==14){j=5;break}else{k=8;break}}else if((b|0)==256){j=1}else{k=8}}while(0);do{if((k|0)==8){if((a|0)==0){j=0;break}yDb(0,16,1884472,(b=i,i=i+8|0,c[b>>2]=a,b)|0);i=b;j=0}}while(0);c[(c[h+8>>2]|0)+408>>2]=j;g=0;i=e;return g|0}function JH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+32|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f+16|0;h=f+24|0;TGb(h|0,0,5)|0;mz(d,h,4)|0;if((QGb(h,1898312)|0)!=0){c[b+40>>2]=1}j=b+4|0;yDb(c[j>>2]|0,48,1893856,(b=i,i=i+8|0,c[b>>2]=h,b)|0);i=b;CBb((c[j>>2]|0)+1140|0,1889536,h,0)|0;h=vz(d)|0;k=f|0;Lb(k|0,11,1989768,(b=i,i=i+8|0,c[b>>2]=h,b)|0)|0;i=b;CBb((c[j>>2]|0)+1140|0,1887608,k,0)|0;k=e+8|0;e=YGb(c[k>>2]|0,c[k+4>>2]|0,-8,0)|0;k=e;if((k|0)<0){l=-1094995529;i=f;return l|0}e=WDb(k+1|0)|0;c[g>>2]=e;if((e|0)==0){l=-12;i=f;return l|0}mz(d,e,k)|0;a[e+k|0]=0;CBb((c[j>>2]|0)+1140|0,1886288,e,0)|0;$Db(g);l=0;i=f;return l|0}function KH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;g=c[f+24>>2]|0;if((g|0)==0){h=0;i=e;return h|0}j=c[(c[f+28>>2]|0)+(g-1<<2)>>2]|0;g=d+8|0;f=c[g>>2]|0;k=c[g+4>>2]|0;g=0;if(k>>>0>g>>>0|k>>>0==g>>>0&f>>>0>1073741824>>>0){h=-1094995529;i=e;return h|0}g=0;do{if((k|0)>(g|0)|(k|0)==(g|0)&f>>>0>9>>>0){l=vz(b)|0;m=rz(b)|0;Ty(b,-8,-1,1)|0;if((m|0)!=1818585446){break}if(!((l|0)==(f|0)&0==(k|0))){break}h=nH(a,b,d)|0;i=e;return h|0}}while(0);d=j+8|0;ZDb(c[(c[d>>2]|0)+96>>2]|0);h=(CT(c[d>>2]|0,b,f)|0)>>31&-12;i=e;return h|0}function LH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f|0;h=c[b+4>>2]|0;j=c[h+24>>2]|0;if((j|0)==0){k=0;i=f;return k|0}l=c[(c[h+28>>2]|0)+(j-1<<2)>>2]|0;lz(d)|0;uz(d)|0;rz(d)|0;j=rz(d)|0;if((j|0)==1853190003){c[(c[l+8>>2]|0)+8>>2]=1}else if((j|0)==1885564003|(j|0)==1885500787){c[(c[l+8>>2]|0)+8>>2]=3}else if((j|0)==543240557){c[(c[l+8>>2]|0)+48>>2]=86016}else if((j|0)==1701079414){c[(c[l+8>>2]|0)+8>>2]=0}vz(d)|0;vz(d)|0;vz(d)|0;j=e+8|0;e=YGb(c[j>>2]|0,c[j+4>>2]|0,-24,0)|0;j=e;if((j|0)<=0){k=0;i=f;return k|0}e=WDb(j+1|0)|0;c[g>>2]=e;if((e|0)==0){k=-12;i=f;return k|0}mz(d,e,j)|0;a[e+j|0]=0;d=a[e]|0;if(!(d<<24>>24==0)){if((c[b+40>>2]|0)==0){m=(d<<24>>24|0)==(j-1|0)|0}else{m=0}CBb(l+88|0,1899672,e+m|0,0)|0}$Db(g);k=0;i=f;return k|0}function MH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+96|0;c[f>>2]=1;g=nH(a,b,d)|0;c[f>>2]=0;i=e;return g|0}function NH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=vI(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,89)|0;i=e;return g|0}function OH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=d;d=i;i=i+16|0;c[d>>2]=c[e>>2];c[d+4>>2]=c[e+4>>2];c[d+8>>2]=c[e+8>>2];c[d+12>>2]=c[e+12>>2];e=d+8|0;if((c[e>>2]|0)==0&(c[e+4>>2]|0)==0){i=b;return 0}c[a+28>>2]=1;i=b;return 0}function PH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+48|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e+32|0;d=e+40|0;c[d>>2]=0;g=a+4|0;a=c[g>>2]|0;h=c[a+24>>2]|0;if((h|0)==0){j=0;i=e;return j|0}k=c[(c[a+28>>2]|0)+(h-1<<2)>>2]|0;h=(c[k+12>>2]|0)+92|0;if((c[h>>2]|0)!=0){yDb(a,16,1903408,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=-1094995529;i=e;return j|0}a=lz(b)|0;if((a|0)>1){DDb(c[g>>2]|0,1902240,(l=i,i=i+8|0,c[l>>2]=a,l)|0);i=l;j=-1163346256;i=e;return j|0}uz(b)|0;l=(a|0)==1;if(l){a=Az(b)|0;g=F;Az(b)|0;m=g;n=a}else{a=vz(b)|0;vz(b)|0;m=0;n=a}a=k+88|0;g=e|0;do{if(!((n|0)==0&(m|0)==0)){o=0;if((m|0)>(o|0)|(m|0)==(o|0)&n>>>0>2082844799>>>0){o=YGb(n,m,-2082844800,0)|0;p=o}else{p=n}c[f>>2]=p;o=mc(f|0)|0;if((o|0)==0){break}Ac(g|0,32,1908496,o|0)|0;CBb(a,1906904,g,0)|0}}while(0);c[h>>2]=vz(b)|0;if(l){l=Az(b)|0;q=F;r=l}else{q=0;r=vz(b)|0}l=k+56|0;c[l>>2]=r;c[l+4>>2]=q;q=d;if((rF(tz(b)|0,q)|0)!=0){CBb(a,1901088,q,0)|0}tz(b)|0;j=0;i=e;return j|0}function QH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=c[f+4>>2]|0;h=c[f>>2]|0;while(1){j=0;if(!((g|0)>(j|0)|(g|0)==(j|0)&h>>>0>8>>>0)){k=0;l=5;break}j=rz(b)|0;m=YGb(h,g,-4,-1)|0;n=F;c[f>>2]=m;c[f+4>>2]=n;if((j|0)==1919706216){break}else{g=n;h=m}}if((l|0)==5){i=e;return k|0}Ty(b,-8,-1,1)|0;l=YGb(h,g,4,0)|0;c[f>>2]=l;c[f+4>>2]=F;k=nH(a,b,d)|0;i=e;return k|0}function RH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=Ty(b,0,0,1)|0;g=YGb(f,F,-8,-1)|0;f=a+64|0;c[f>>2]=g;c[f+4>>2]=F;f=nH(a,b,d)|0;i=e;return f|0}function SH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+24|0;if((c[f>>2]|0)!=0){yDb(c[a+4>>2]|0,24,1905272,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;g=d+8|0;Vy(b,c[g>>2]|0,c[g+4>>2]|0)|0;h=0;i=e;return h|0}g=nH(a,b,d)|0;if((g|0)<0){h=g;i=e;return h|0}c[f>>2]=1;h=0;i=e;return h|0}function TH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+40|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e+32|0;d=lz(b)|0;uz(b)|0;g=(d|0)==1;if(g){d=Az(b)|0;h=F;Az(b)|0;j=h;k=d}else{d=vz(b)|0;vz(b)|0;j=0;k=d}d=a+4|0;h=(c[d>>2]|0)+1140|0;l=e|0;do{if(!((k|0)==0&(j|0)==0)){m=0;if((j|0)>(m|0)|(j|0)==(m|0)&k>>>0>2082844799>>>0){m=YGb(k,j,-2082844800,0)|0;n=m}else{n=k}c[f>>2]=n;m=mc(f|0)|0;if((m|0)==0){break}Ac(l|0,32,1908496,m|0)|0;CBb(h,1906904,l,0)|0}}while(0);l=a+8|0;c[l>>2]=vz(b)|0;if(g){g=Az(b)|0;o=F;p=g}else{o=0;p=vz(b)|0}g=a+16|0;c[g>>2]=p;c[g+4>>2]=o;g=c[l>>2]|0;do{if((g|0)>0){if((c[a+88>>2]|0)!=0){break}l=IDb(p,o,1e6,0,g,(g|0)<0|0?-1:0)|0;h=(c[d>>2]|0)+1064|0;c[h>>2]=l;c[h+4>>2]=F}}while(0);vz(b)|0;tz(b)|0;Vy(b,10,0)|0;Vy(b,36,0)|0;vz(b)|0;vz(b)|0;vz(b)|0;vz(b)|0;vz(b)|0;vz(b)|0;vz(b)|0;i=e;return 0}function UH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=vI(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,24)|0;i=e;return g|0}function VH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=vI(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,86032)|0;i=e;return g|0}function WH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=vz(b)|0;d=vz(b)|0;b=c[a+4>>2]|0;a=c[b+24>>2]|0;if((a|0)==0){i=e;return 0}g=c[(c[b+28>>2]|0)+(a-1<<2)>>2]|0;a=g+80|0;h=g+84|0;g=c[h>>2]|0;if((g|0)==1){if((c[a>>2]|0)!=0){j=4}}else{j=4}do{if((j|0)==4){k=c[a>>2]|0;if((d|0)==(g|0)&(f|0)==(k|0)){break}yDb(b,24,1909776,(l=i,i=i+32|0,c[l>>2]=k,c[l+8>>2]=g,c[l+16>>2]=f,c[l+24>>2]=d,l)|0);i=l;i=e;return 0}}while(0);if((d|0)==0){i=e;return 0}c[a>>2]=f;c[h>>2]=d;i=e;return 0}function XH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}d=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;vz(b)|0;a=vz(b)|0;if(a>>>0>1073741822>>>0){g=-1094995529;i=e;return g|0}f=WDb(a<<2)|0;h=d+52|0;c[h>>2]=f;if((f|0)==0){g=-12;i=e;return g|0}f=b+52|0;a:do{if((a|0)==0){j=0}else{k=0;while(1){if((c[f>>2]|0)!=0){j=k;break a}l=vz(b)|0;c[(c[h>>2]|0)+(k<<2)>>2]=l;l=k+1|0;if(l>>>0<a>>>0){k=l}else{j=l;break}}}}while(0);c[d+48>>2]=j;g=(c[f>>2]|0)==0?0:-541478725;i=e;return g|0}function YH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}h=d+8|0;d=c[h>>2]|0;j=c[h+4>>2]|0;h=0;if((j|0)<(h|0)|(j|0)==(h|0)&d>>>0<41>>>0){g=0;i=e;return g|0}h=0;if(j>>>0>h>>>0|j>>>0==h>>>0&d>>>0>1073741824>>>0){g=-1094995529;i=e;return g|0}h=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;Vy(b,40,0)|0;a=h+8|0;ZDb(c[(c[a>>2]|0)+96>>2]|0);h=c[a>>2]|0;a=YGb(d,j,-40,0)|0;g=(CT(h,b,a)|0)>>31&-12;i=e;return g|0}function ZH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}d=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;lz(b)|0;uz(b)|0;a=vz(b)|0;if((a|0)==0){g=0;i=e;return g|0}if(a>>>0>357913940>>>0){g=-1094995529;i=e;return g|0}f=WDb(a*12|0)|0;h=d+44|0;c[h>>2]=f;if((f|0)==0){g=-12;i=e;return g|0}f=b+52|0;j=0;while(1){if((c[f>>2]|0)!=0){k=j;break}l=vz(b)|0;c[(c[h>>2]|0)+(j*12|0)>>2]=l;l=vz(b)|0;c[(c[h>>2]|0)+(j*12|0)+4>>2]=l;l=vz(b)|0;c[(c[h>>2]|0)+(j*12|0)+8>>2]=l;l=j+1|0;if(l>>>0<a>>>0){j=l}else{k=l;break}}c[d+40>>2]=k;g=(c[f>>2]|0)==0?0:-541478725;i=e;return g|0}function _H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];lz(b)|0;uz(b)|0;f=mH(a,b,vz(b)|0)|0;i=e;return f|0}function $H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}d=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;a=c[d+12>>2]|0;lz(b)|0;uz(b)|0;f=vz(b)|0;if((f|0)==0){c[a+80>>2]=1;h=d+236|0;if((c[h>>2]|0)!=0){g=0;i=e;return g|0}if((c[(c[d+8>>2]|0)+8>>2]|0)!=0){g=0;i=e;return g|0}c[h>>2]=2;g=0;i=e;return g|0}if(f>>>0>1073741822>>>0){g=-1094995529;i=e;return g|0}h=WDb(f<<2)|0;d=a+88|0;c[d>>2]=h;if((h|0)==0){g=-12;i=e;return g|0}h=b+52|0;j=0;while(1){if((c[h>>2]|0)!=0){k=j;break}l=vz(b)|0;c[(c[d>>2]|0)+(j<<2)>>2]=l;l=j+1|0;if(l>>>0<f>>>0){j=l}else{k=l;break}}c[a+84>>2]=k;g=(c[h>>2]|0)==0?0:-541478725;i=e;return g|0}function aI(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=a+4|0;a=c[g>>2]|0;h=c[a+24>>2]|0;if((h|0)==0){j=0;i=f;return j|0}k=c[(c[(c[a+28>>2]|0)+(h-1<<2)>>2]|0)+12>>2]|0;lz(b)|0;uz(b)|0;do{if((c[e>>2]|0)==2054386803){h=vz(b)|0;a=k+64|0;if((c[a>>2]|0)==0){c[a>>2]=h}c[k+68>>2]=h;a=vz(b)|0;l=k+72|0;c[l>>2]=a;if((h|0)==0){m=l;n=a;o=32;break}else{j=0}i=f;return j|0}else{uz(b)|0;a=lz(b)|0;l=vz(b)|0;h=k+72|0;c[h>>2]=l;if((a|0)==32|(a|0)==16|(a|0)==8|(a|0)==4){m=h;n=l;o=a;break}yDb(c[g>>2]|0,16,1914360,(l=i,i=i+8|0,c[l>>2]=a,l)|0);i=l;j=-1094995529;i=f;return j|0}}while(0);if((n|0)==0){j=0;i=f;return j|0}if(n>>>0>1073741822>>>0){j=-1094995529;i=f;return j|0}if(!(n>>>0<(4294967291/(o>>>0)|0)>>>0)){j=-1094995529;i=f;return j|0}g=WDb(n<<2)|0;e=k+76|0;l=e;c[l>>2]=g;if((g|0)==0){j=-12;i=f;return j|0}g=((ba(n,o)|0)+4|0)>>>3;a=WDb(g+16|0)|0;if((a|0)==0){$Db(e);j=-12;i=f;return j|0}if((mz(b,a,g)|0)>>>0<g>>>0){$Db(e);ZDb(a);j=-1094995529;i=f;return j|0}e=g<<3;g=e>>>0>2147483639>>>0;h=g?0:a;p=g?8:e+8|0;e=b+52|0;b=(o|0)==0;g=k+1208|0;k=(o|0)<26;q=32-o|0;r=o-16|0;s=48-o|0;t=0;u=0;while(1){if((c[e>>2]|0)!=0){v=u;break}do{if(b){w=0;x=t}else{y=h+(t>>>3)|0;z=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(t&7);if(k){y=t+o|0;w=z>>>(q>>>0);x=p>>>0>y>>>0?y:p;break}else{y=t+16|0;A=p>>>0>y>>>0?y:p;y=h+(A>>>3)|0;B=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(A&7)>>>(s>>>0);y=A+r|0;w=B|z>>>16<<r;x=p>>>0>y>>>0?y:p;break}}}while(0);c[(c[l>>2]|0)+(u<<2)>>2]=w;y=YGb(c[g>>2]|0,c[g+4>>2]|0,w,(w|0)<0|0?-1:0)|0;c[g>>2]=y;c[g+4>>2]=F;y=u+1|0;if(y>>>0<n>>>0){t=x;u=y}else{v=y;break}}c[m>>2]=v;if((c[e>>2]|0)!=0){j=-541478725;i=f;return j|0}ZDb(a);j=0;i=f;return j|0}function bI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;a=c[f>>2]|0;d=c[a+24>>2]|0;if((d|0)==0){g=0;i=e;return g|0}h=c[(c[a+28>>2]|0)+(d-1<<2)>>2]|0;d=c[h+12>>2]|0;lz(b)|0;uz(b)|0;a=vz(b)|0;if(a>>>0>536870910>>>0){g=-1;i=e;return g|0}j=d+28|0;ZDb(c[j>>2]|0);k=WDb(a<<3)|0;c[j>>2]=k;if((k|0)==0){g=-12;i=e;return g|0}k=b+52|0;a:do{if((a|0)==0){l=0;m=0;n=0;o=0;p=0}else{q=0;r=0;s=0;t=0;u=0;while(1){if((c[k>>2]|0)!=0){l=q;m=r;n=s;o=t;p=u;break a}v=vz(b)|0;w=vz(b)|0;if((w|0)<0){x=c[f>>2]|0;y=(c[x+24>>2]|0)-1|0;yDb(x,16,1920920,(z=i,i=i+24|0,c[z>>2]=w,c[z+8>>2]=q,c[z+16>>2]=y,z)|0);i=z;A=1}else{A=w}if((v|0)<0){break}w=c[j>>2]|0;c[w+(q<<3)>>2]=v;c[w+(q<<3)+4>>2]=A;w=q+1|0;y=0;if((w|0)==(a|0)&(q|0)!=0&(v|0)==1&((t|0)>(y|0)|(t|0)==(y|0)&u>>>0>100>>>0)){y=(A|0)/10|0;x=(y|0)<0|0?-1:0;B=eHb(s,r,u,t)|0;C=F;D=(x|0)>(C|0)|(x|0)==(C|0)&y>>>0>B>>>0?B:A}else{D=A}B=v;y=(v|0)<0|0?-1:0;C=gHb(D,(D|0)<0|0?-1:0,B,y)|0;x=YGb(C,F,s,r)|0;C=F;E=YGb(B,y,u,t)|0;y=F;if(w>>>0<a>>>0){q=w;r=C;s=x;t=y;u=E}else{l=w;m=C;n=x;o=y;p=E;break a}}yDb(c[f>>2]|0,16,1919144,(z=i,i=i+8|0,c[z>>2]=v,z)|0);i=z;g=-1094995529;i=e;return g|0}}while(0);c[d+24>>2]=l;l=d+1248|0;z=YGb(c[l>>2]|0,c[l+4>>2]|0,n,m)|0;c[l>>2]=z;c[l+4>>2]=F;l=d+1244|0;z=YGb(c[l>>2]|0,0,p,o)|0;c[l>>2]=z;if((c[k>>2]|0)!=0){g=-541478725;i=e;return g|0}k=h+64|0;c[k>>2]=p;c[k+4>>2]=o;if(!((n|0)==0&(m|0)==0)){o=h+56|0;c[o>>2]=n;c[o+4>>2]=m}o=d+1224|0;c[o>>2]=n;c[o+4>>2]=m;g=0;i=e;return g|0}function cI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+8|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e|0;d=c[a+4>>2]|0;a=c[d+24>>2]|0;if((a|0)==0){i=e;return 0}g=c[(c[d+28>>2]|0)+(a-1<<2)>>2]|0;a=c[g+12>>2]|0;d=lz(b)|0;h=(uz(b)|0)&1;j=g+72|0;c[j>>2]=c[j>>2]|h;h=(d|0)==1;if(h){Az(b)|0;Az(b)|0;}else{vz(b)|0;vz(b)|0}c[g+4>>2]=vz(b)|0;vz(b)|0;if(h){Az(b)|0;}else{vz(b)|0}vz(b)|0;vz(b)|0;tz(b)|0;tz(b)|0;tz(b)|0;tz(b)|0;h=vz(b)|0;d=vz(b)|0;vz(b)|0;j=vz(b)|0;k=vz(b)|0;vz(b)|0;l=vz(b)|0;m=vz(b)|0;vz(b)|0;n=vz(b)|0;o=vz(b)|0;c[a+164>>2]=n>>16;c[a+168>>2]=o>>16;if((j|0)==-65536&(d|0)==65536){CBb(g+88|0,1927240,1925408,0)|0}if((h|0)==-65536&(k|0)==-65536){CBb(g+88|0,1927240,1924104,0)|0}if((j|0)==65536&(d|0)==-65536){CBb(g+88|0,1927240,1922424,0)|0}if((n|0)==0|(o|0)==0){i=e;return 0}if(!(((k|0)!=65536|(h|0)!=65536)&(d|0)==0&(j|0)==0&(l|0)==0&(m|0)==0)){i=e;return 0}m=gHb(h,(h|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;h=F;l=gHb(k,(k|0)<0|0?-1:0,o,(o|0)<0|0?-1:0)|0;lFb(f,+(o|0)*(+(m>>>0)+ +(h|0)*4294967296.0)/(+(n|0)*(+(l>>>0)+ +(F|0)*4294967296.0)),2147483647);l=g+80|0;g=c[f+4>>2]|0;c[l>>2]=c[f>>2];c[l+4>>2]=g;i=e;return 0}function dI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];lz(b)|0;f=uz(b)|0;d=vz(b)|0;if((d|0)==0){g=-1094995529;i=e;return g|0}c[a+48>>2]=d;h=c[a+92>>2]|0;j=a+88|0;k=0;while(1){if(!(k>>>0<h>>>0)){break}l=c[j>>2]|0;m=l+(k*20|0)|0;if((c[m>>2]|0)==(d|0)){n=5;break}else{k=k+1|0}}do{if((n|0)==5){if((m|0)==0){break}if((f&1|0)==0){d=a+64|0;o=c[d+4>>2]|0;p=c[d>>2]|0}else{d=Az(b)|0;o=F;p=d}d=a+56|0;c[d>>2]=p;c[d+4>>2]=o;if((f&2|0)==0){q=c[l+(k*20|0)+4>>2]|0}else{q=vz(b)|0}c[a+72>>2]=q;if((f&8|0)==0){r=c[l+(k*20|0)+8>>2]|0}else{r=vz(b)|0}c[a+76>>2]=r;if((f&16|0)==0){s=c[l+(k*20|0)+12>>2]|0}else{s=vz(b)|0}c[a+80>>2]=s;if((f&32|0)==0){t=c[l+(k*20|0)+16>>2]|0}else{t=vz(b)|0}c[a+84>>2]=t;g=0;i=e;return g|0}}while(0);yDb(c[a+4>>2]|0,16,1928936,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-1094995529;i=e;return g|0}function eI(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0;g=i;i=i+1032|0;h=f;f=i;i=i+16|0;c[f>>2]=c[h>>2];c[f+4>>2]=c[h+4>>2];c[f+8>>2]=c[h+8>>2];c[f+12>>2]=c[h+12>>2];h=g|0;j=g+1024|0;k=j;l=d+4|0;m=LT(c[l>>2]|0,0)|0;if((m|0)==0){n=-12;i=g;return n|0}c[m+4>>2]=c[(c[l>>2]|0)+24>>2];o=cEb(1256)|0;if((o|0)==0){n=-12;i=g;return n|0}p=m+12|0;c[p>>2]=o;q=m+8|0;c[(c[q>>2]|0)+8>>2]=2;r=m|0;s=o+8|0;c[s>>2]=c[r>>2];t=nH(d,e,f)|0;if((t|0)<0){n=t;i=g;return n|0}a:do{if((c[o+16>>2]|0)!=0){do{if((c[o+24>>2]|0)!=0){if((c[o+40>>2]|0)==0){break}if((c[o+64>>2]|0)!=0){break a}if((c[o+72>>2]|0)!=0){break a}}}while(0);yDb(c[l>>2]|0,16,1953872,(u=i,i=i+8|0,c[u>>2]=c[r>>2],u)|0);i=u;n=0;i=g;return n|0}}while(0);t=o+92|0;f=c[t>>2]|0;do{if((f|0)<1){yDb(c[l>>2]|0,24,2318608,(u=i,i=i+8|0,c[u>>2]=c[s>>2],u)|0);i=u;e=c[d+8>>2]|0;c[t>>2]=e;if((e|0)>=1){v=e;break}c[t>>2]=1;v=1}else{v=f}}while(0);MT(m,64,1,v);v=c[p>>2]|0;p=v+96|0;f=c[p>>2]|0;s=c[p+4>>2]|0;e=(f|0)==0&(s|0)==0;if(e){w=v+104|0;if((c[w>>2]|0)==0&(c[w+4>>2]|0)==0){x=0;y=0}else{z=15}}else{z=15}do{if((z|0)==15){w=c[d+8>>2]|0;if((w|0)<=0){x=0;y=0;break}if(e){A=0;B=0}else{C=c[v+92>>2]|0;D=IDb(f,s,C,(C|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=F;c[p>>2]=D;c[p+4>>2]=w;A=w;B=D}D=v+104|0;w=ZGb(c[D>>2]|0,c[D+4>>2]|0,B,A)|0;D=F;C=v+112|0;c[C>>2]=w;c[C+4>>2]=D;C=ZGb(0,0,w,D)|0;D=F;if((c[v+32>>2]|0)==0){x=D;y=C;break}if((c[v+24>>2]|0)==0){x=D;y=C;break}w=c[(c[v+28>>2]|0)+4>>2]|0;if(((c[(c[v+36>>2]|0)+4>>2]|0)/(((w|0)>1?w:1)|0)|0|0)<=16){x=D;y=C;break}c[v+160>>2]=1;c[(c[q>>2]|0)+176>>2]=1;x=D;y=C}}while(0);b:do{if((c[(c[q>>2]|0)+8>>2]|0)==1){if((c[v+24>>2]|0)!=1){z=27;break}if((c[(c[v+28>>2]|0)+4>>2]|0)!=1){z=27;break}A=v+40|0;B=c[A>>2]|0;c:do{if((B|0)==0){E=0}else{p=c[v+44>>2]|0;s=v+16|0;f=B-1|0;e=c[v+128>>2]|0;C=e>>>0>159>>>0;D=e>>>0>1>>>0;w=(e|0)==0;G=0;H=0;d:while(1){I=c[p+(G*12|0)+4>>2]|0;do{if((G|0)==(f|0)){z=87}else{if(w){z=91;break}if(((I>>>0)%(e>>>0)|0|0)==0){z=87}else{break d}}}while(0);do{if((z|0)==87){z=0;if(C){J=(I>>>0)/(e>>>0)|0;break}if(!D){z=91;break}K=1024-(1024%(e>>>0)|0)|0;J=((I-1+K|0)>>>0)/(K>>>0)|0}}while(0);if((z|0)==91){z=0;J=(I+1023|0)>>>10}if(G>>>0<f>>>0){K=G+1|0;L=(c[p+(K*12|0)>>2]|0)-(c[p+(G*12|0)>>2]|0)|0;M=K}else{L=(c[s>>2]|0)+1-(c[p+(G*12|0)>>2]|0)|0;M=G+1|0}K=(ba(L,J)|0)+H|0;if(M>>>0<B>>>0){G=M;H=K}else{E=K;break c}}yDb(c[l>>2]|0,16,1932536,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break b}}while(0);B=m+404|0;H=c[B>>2]|0;if(!(E>>>0<(178956970-H|0)>>>0)){break}G=m+400|0;if((bEb(G,H+E|0,24)|0)<0){c[B>>2]=0;break}c[m+408>>2]=((c[B>>2]|0)+E|0)*24|0;H=v+16|0;p=c[H>>2]|0;if((p|0)==0){break}s=v+20|0;f=v+44|0;e=v+128|0;D=v+124|0;C=v+64|0;w=0;K=0;N=x;O=y;P=p;e:while(1){p=(c[s>>2]|0)+(w<<3)|0;Q=K+1|0;if(Q>>>0<(c[A>>2]|0)>>>0){R=c[f>>2]|0;S=(w+1|0)==(c[R+(Q*12|0)>>2]|0)?Q:K;T=R}else{S=K;T=c[f>>2]|0}R=c[T+(S*12|0)+4>>2]|0;if((R|0)==0){U=N;V=O;W=P}else{Q=R;R=N;X=O;Y=c[p+4>>2]|0;Z=c[p>>2]|0;while(1){p=c[e>>2]|0;do{if(p>>>0>159>>>0){_=p;$=c[D>>2]|0}else{if(p>>>0>1>>>0){aa=1024-(1024%(p>>>0)|0)|0;ca=aa>>>0>Q>>>0?Q:aa;_=ca;$=ba(c[D>>2]|0,(ca>>>0)/(p>>>0)|0)|0;break}else{ca=Q>>>0<1024>>>0?Q:1024;_=ca;$=ba(c[C>>2]|0,ca)|0;break}}}while(0);p=c[B>>2]|0;if(!(p>>>0<E>>>0)){break e}c[B>>2]=p+1;I=c[G>>2]|0;ca=I+(p*24|0)|0;c[ca>>2]=Z;c[ca+4>>2]=Y;ca=I+(p*24|0)+8|0;c[ca>>2]=X;c[ca+4>>2]=R;c[I+(p*24|0)+20>>2]=0;c[I+(p*24|0)+16>>2]=$<<2|1;p=YGb($,0,Z,Y)|0;I=F;da=YGb(_,0,X,R)|0;ea=F;if((Q|0)==(_|0)){break}else{Q=Q-_|0;R=ea;X=da;Y=I;Z=p}}U=ea;V=da;W=c[H>>2]|0}Z=w+1|0;if(Z>>>0<W>>>0){w=Z;K=S;N=U;O=V;P=W}else{break b}}yDb(c[l>>2]|0,16,1930632,(u=i,i=i+8|0,c[u>>2]=E,u)|0);i=u}else{z=27}}while(0);f:do{if((z|0)==27){E=v+1236|0;if((c[E>>2]|0)==0){fa=0}else{fa=(c[v+1240>>2]|0)!=0}W=v+84|0;if((c[W>>2]|0)==0){z=31}else{if((c[c[v+88>>2]>>2]|0)>0){ga=1}else{z=31}}do{if((z|0)==31){if((c[v+48>>2]|0)==0){ga=0;break}ga=(c[c[v+52>>2]>>2]|0)!=0|0}}while(0);V=c[v+172>>2]|0;U=ZGb(y,x,V,(V|0)<0|0?-1:0)|0;V=F;S=v+72|0;da=c[S>>2]|0;if((da|0)==0){break}ea=m+404|0;_=c[ea>>2]|0;if(!((_|0)==0&da>>>0<(178956970-_|0)>>>0)){break}_=m+400|0;if((bEb(_,da,24)|0)<0){c[ea>>2]=0;break}c[m+408>>2]=((c[S>>2]|0)+(c[ea>>2]|0)|0)*24|0;da=v+16|0;$=c[da>>2]|0;g:do{if(($|0)==0){ha=0;ia=0}else{T=v+20|0;M=v+44|0;J=v+40|0;L=v+64|0;P=v+68|0;O=v+80|0;N=v+88|0;K=v+1240|0;w=v+76|0;H=v+136|0;G=v+28|0;B=v+24|0;C=v+48|0;D=v+52|0;e=0;f=0;A=0;s=0;Z=0;Y=0;X=0;R=0;Q=0;p=0;I=0;ca=0;aa=V;ja=U;ka=$;h:while(1){la=Z+1|0;ma=c[T>>2]|0;if(la>>>0<ka>>>0){na=ma+(la<<3)|0;oa=c[na+4>>2]|0;pa=c[na>>2]|0}else{oa=2147483647;pa=-1}na=ma+(Z<<3)|0;ma=c[na>>2]|0;qa=c[na+4>>2]|0;na=c[J>>2]|0;ra=I;while(1){sa=ra+1|0;if(!(sa>>>0<na>>>0)){break}if((la|0)==(c[(c[M>>2]|0)+(sa*12|0)>>2]|0)){ra=sa}else{break}}do{if((oa|0)>(qa|0)|(oa|0)==(qa|0)&pa>>>0>ma>>>0){na=c[L>>2]|0;if((na|0)==0){z=50;break}sa=c[P>>2]|0;if(!(na>>>0<sa>>>0)){ta=sa;break}na=c[(c[M>>2]|0)+(ra*12|0)+4>>2]|0;ua=gHb(na,(na|0)<0|0?-1:0,sa,0)|0;na=F;va=ZGb(pa,oa,ma,qa)|0;wa=F;if(!((na|0)>(wa|0)|(na|0)==(wa|0)&ua>>>0>va>>>0)){z=50;break}yDb(c[l>>2]|0,24,1945816,(u=i,i=i+8|0,c[u>>2]=sa,u)|0);i=u;sa=c[L>>2]|0;c[P>>2]=sa;ta=sa}else{z=50}}while(0);if((z|0)==50){z=0;ta=c[P>>2]|0}do{if((ta|0)!=0){if(!(ta>>>0<(c[L>>2]|0)>>>0)){break}yDb(c[l>>2]|0,24,1943984,(u=i,i=i+8|0,c[u>>2]=ta,u)|0);i=u;c[P>>2]=c[L>>2]}}while(0);sa=c[M>>2]|0;i:do{if((c[sa+(ra*12|0)+4>>2]|0)==0){xa=e;ya=f;za=A;Aa=s;Ba=Y;Ca=X;Da=R;Ea=Q;Fa=p;Ga=ca;Ha=aa;Ia=ja}else{va=1;ua=e;wa=f;na=A;Ja=s;Ka=Y;La=X;Ma=R;Na=Q;Oa=p;Pa=ca;Qa=aa;Ra=ja;Sa=qa;Ta=ma;Ua=sa;while(1){if(!(na>>>0<(c[S>>2]|0)>>>0)){break h}Va=(c[O>>2]|0)==0;do{if(Va){Wa=c[W>>2]|0;if((Wa|0)!=0){if((na+ga|0)!=(c[(c[N>>2]|0)+(Oa<<2)>>2]|0)){z=61;break}}Xa=Oa+1|0;Ya=1;Za=Xa>>>0<Wa>>>0?Xa:Oa;_a=Na}else{z=61}}while(0);do{if((z|0)==61){z=0;Xa=c[C>>2]|0;if((Xa|0)==0){Ya=0;Za=Oa;_a=Na;break}if((na+ga|0)!=(c[(c[D>>2]|0)+(Na<<2)>>2]|0)){Ya=0;Za=Oa;_a=Na;break}Wa=Na+1|0;Ya=1;Za=Oa;_a=Wa>>>0<Xa>>>0?Wa:Na}}while(0);do{if(fa){if(!(La>>>0<(c[E>>2]|0)>>>0)){$a=Ya;ab=Ma;bb=La;break}Wa=c[K>>2]|0;Xa=Ma+1|0;cb=(Xa|0)==(c[Wa+(La<<3)>>2]|0);$a=(c[Wa+(La<<3)+4>>2]|0)==0?Ya:1;ab=cb?0:Xa;bb=(cb&1)+La|0}else{$a=Ya;ab=Ma;bb=La}}while(0);do{if(Va){db=$a}else{if((c[C>>2]|0)!=0|fa){db=$a;break}db=(c[(c[q>>2]|0)+8>>2]|0)==1?1:$a}}while(0);Va=(db|0)!=0;cb=Va?0:Ka;Xa=c[P>>2]|0;if((Xa|0)==0){eb=c[(c[w>>2]|0)+(na<<2)>>2]|0}else{eb=Xa}Xa=c[H>>2]|0;if((Xa|0)==-1){z=74}else{if(((c[Ua+(ra*12|0)+8>>2]|0)-1|0)==(Xa|0)){z=74}}do{if((z|0)==74){z=0;Xa=c[ea>>2]|0;c[ea>>2]=Xa+1;Wa=c[_>>2]|0;fb=Wa+(Xa*24|0)|0;c[fb>>2]=Ta;c[fb+4>>2]=Sa;fb=Wa+(Xa*24|0)+8|0;c[fb>>2]=Ra;c[fb+4>>2]=Qa;c[Wa+(Xa*24|0)+20>>2]=cb;c[Wa+(Xa*24|0)+16>>2]=eb<<2|Va&1;if((c[(c[q>>2]|0)+8>>2]|0)!=0){break}if((c[ea>>2]|0)>=100){break}DT(c[l>>2]|0,m,Ra,Qa)|0}}while(0);Va=eb;Xa=0;Wa=YGb(Va,Xa,Ta,Sa)|0;fb=F;gb=YGb(Va,Xa,wa,ua)|0;Xa=F;Va=c[G>>2]|0;hb=c[Va+(Pa<<3)+4>>2]|0;ib=YGb(hb,(hb|0)<0|0?-1:0,Ra,Qa)|0;hb=F;jb=cb+1|0;kb=Ja+1|0;lb=na+1|0;mb=Pa+1|0;if(mb>>>0<(c[B>>2]|0)>>>0){nb=(kb|0)==(c[Va+(Pa<<3)>>2]|0);ob=nb?mb:Pa;pb=nb?0:kb}else{ob=Pa;pb=kb}kb=c[M>>2]|0;if(!(va>>>0<(c[kb+(ra*12|0)+4>>2]|0)>>>0)){xa=Xa;ya=gb;za=lb;Aa=pb;Ba=jb;Ca=bb;Da=ab;Ea=_a;Fa=Za;Ga=ob;Ha=hb;Ia=ib;break i}va=va+1|0;ua=Xa;wa=gb;na=lb;Ja=pb;Ka=jb;La=bb;Ma=ab;Na=_a;Oa=Za;Pa=ob;Qa=hb;Ra=ib;Sa=fb;Ta=Wa;Ua=kb}}}while(0);sa=c[da>>2]|0;if(la>>>0<sa>>>0){e=xa;f=ya;A=za;s=Aa;Z=la;Y=Ba;X=Ca;R=Da;Q=Ea;p=Fa;I=ra;ca=Ga;aa=Ha;ja=Ia;ka=sa}else{ha=xa;ia=ya;break g}}yDb(c[l>>2]|0,16,1938528,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break f}}while(0);da=m+56|0;ea=c[da>>2]|0;_=c[da+4>>2]|0;da=0;if(!((_|0)>(da|0)|(_|0)==(da|0)&ea>>>0>0>>>0)){break}da=c[v+92>>2]|0;E=gHb(ia<<3|0>>>29,ha<<3|ia>>>29,da,(da|0)<0|0?-1:0)|0;da=hHb(E,F,ea,_)|0;c[(c[q>>2]|0)+72>>2]=da}}while(0);ia=(c[o+152>>2]|0)-1|0;j:do{if(ia>>>0<(c[o+144>>2]|0)>>>0){ha=c[o+148>>2]|0;v=ha+(ia*108|0)+4|0;ya=c[v>>2]|0;if((ya|0)==0){z=133;break}xa=o;Ia=c[l>>2]|0;Ha=Ia+32|0;Ga=Ia+1160|0;Fa=c[d+104>>2]|0;Ea=h|0;Da=ha+(ia*108|0)+104|0;Ca=b[Da>>1]|0;do{if(Ca<<16>>16>0){Ba=ha+(ia*108|0)+106|0;Aa=b[Ba>>1]|0;if(!(Aa<<16>>16>0)){z=130;break}za=cc(Ha|0,47)|0;ob=(za|0)==0?Ha:za+1|0;za=(Ca<<16>>16)-1|0;Za=SGb(ya|0)|0;_a=0;k:while(1){qb=Za;while(1){rb=qb-1|0;if(!((rb|0)>-1)){z=124;break k}if((a[ya+rb|0]|0)==47){break}else{qb=rb}}if((_a|0)==(za|0)){break}else{Za=rb;_a=_a+1|0}}if((z|0)==124){if((_a|0)!=(za|0)){break}}Za=ob-Ha|0;if(!(Za>>>0<1024>>>0)){break}UGb(Ea|0,Ha|0,Za)|0;a[h+Za|0]=0;if(Aa<<16>>16>1){Za=1;do{tAb(Ea,1949680,1024)|0;Za=Za+1|0;}while((Za|0)<(b[Ba>>1]|0));sb=c[v>>2]|0}else{sb=ya}tAb(Ea,sb+qb|0,1024)|0;if((Hz(xa,Ea,1,Ga,0)|0)==0){break j}}else{z=130}}while(0);do{if((z|0)==130){if((Fa|0)==0){break}yDb(Ia,24,1947584,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;if((Hz(xa,c[v>>2]|0,1,Ga,0)|0)==0){break j}}}while(0);Ga=c[v>>2]|0;xa=c[ha+(ia*108|0)+8>>2]|0;Ia=b[ha+(ia*108|0)+106>>1]|0;Fa=b[Da>>1]|0;yDb(c[l>>2]|0,16,1951648,(u=i,i=i+56|0,c[u>>2]=c[r>>2],c[u+8>>2]=Ga,c[u+16>>2]=xa,c[u+24>>2]=ha+(ia*108|0)+40,c[u+32>>2]=ha+(ia*108|0)+12,c[u+40>>2]=Ia,c[u+48>>2]=Fa,u)|0);i=u}else{z=133}}while(0);if((z|0)==133){c[o>>2]=c[(c[l>>2]|0)+16>>2];c[o+4>>2]=1}l=c[q>>2]|0;do{if((c[l+8>>2]|0)==0){z=m+80|0;do{if((c[z>>2]|0)==0){u=c[l+120>>2]|0;ia=c[o+164>>2]|0;r=c[l+124>>2]|0;qb=c[o+168>>2]|0;if((u|0)==(ia|0)&(r|0)==(qb|0)){break}lFb(k,+(r|0)*+(ia|0)/(+(u|0)*+(qb|0)),2147483647);qb=z;u=c[j+4>>2]|0;c[qb>>2]=c[j>>2];c[qb+4>>2]=u}}while(0);z=c[o+24>>2]|0;if((z|0)==1){tb=c[o+28>>2]|0}else if((z|0)==2){z=c[o+28>>2]|0;if((c[z+8>>2]|0)==1){tb=z}else{break}}else{break}z=c[t>>2]|0;ha=c[tb+4>>2]|0;iFb(m+412|0,m+416|0,z,(z|0)<0|0?-1:0,ha,(ha|0)<0|0?-1:0,2147483647,0)|0}}while(0);tb=c[q>>2]|0;do{if((c[tb+100>>2]|0)==0){if((c[tb+48>>2]|0)!=28){ub=tb;break}t=c[tb+52>>2]|0;if(!((t|0)==1882548577|(t|0)==1899325793|(t|0)==842361185|(t|0)==859138401|(t|0)==892692833|(t|0)==909470049|(t|0)==1882286433|(t|0)==1899063649|(t|0)==842099041|(t|0)==858876257|(t|0)==892430689|(t|0)==909207905|(t|0)==1852397121)){ub=tb;break}t=iU(m)|0;if((t|0)<0){n=t;i=g;return n|0}else{ub=c[q>>2]|0;break}}else{ub=tb}}while(0);tb=c[ub+48>>2]|0;if((tb|0)==4|(tb|0)==5|(tb|0)==13){c[ub+120>>2]=0;c[ub+124>>2]=0}$Db(o+20|0);$Db(o+44|0);$Db(o+76|0);$Db(o+88|0);$Db(o+28|0);$Db(o+52|0);$Db(o+1240|0);n=0;i=g;return n|0}function fI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=-1094995529;i=e;return g|0}d=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;c[d+156>>2]=vz(b)|0;g=0;i=e;return g|0}function gI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];c[a+100>>2]=vz(b)|0;i=e;return 0}function hI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+92|0;d=c[f>>2]|0;g=YGb(d,0,1,0)|0;h=F;j=0;if(h>>>0>j>>>0|h>>>0==j>>>0&g>>>0>214748363>>>0){k=-1094995529;i=e;return k|0}g=a+88|0;j=bEb(g,d+1|0,20)|0;if((j|0)<0){c[f>>2]=0;k=j;i=e;return k|0}else{j=(c[a+4>>2]|0)+1064|0;c[j>>2]=0;c[j+4>>2]=-2147483648;j=c[f>>2]|0;c[f>>2]=j+1;f=c[g>>2]|0;lz(b)|0;uz(b)|0;c[f+(j*20|0)>>2]=vz(b)|0;c[f+(j*20|0)+4>>2]=vz(b)|0;c[f+(j*20|0)+8>>2]=vz(b)|0;c[f+(j*20|0)+12>>2]=vz(b)|0;c[f+(j*20|0)+16>>2]=vz(b)|0;k=0;i=e;return k|0}return 0}function iI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+84|0;d=c[f>>2]|0;g=c[a+4>>2]|0;h=c[g+24>>2]|0;j=g+28|0;k=a+48|0;l=0;while(1){if(!(l>>>0<h>>>0)){m=5;break}n=c[(c[j>>2]|0)+(l<<2)>>2]|0;o=c[n+4>>2]|0;if((o|0)==(c[k>>2]|0)){m=4;break}else{l=l+1|0}}do{if((m|0)==4){if((n|0)==0){p=o;break}l=c[n+12>>2]|0;j=c[l+136>>2]|0;if(!((j+1|0)==(c[a+72>>2]|0)|(j|0)==-1)){q=0;i=e;return q|0}lz(b)|0;j=uz(b)|0;h=vz(b)|0;r=l+32|0;s=c[r>>2]|0;do{if((s|0)==0){t=l+72|0;if((c[t>>2]|0)==0){u=0;break}v=XDb(0,8)|0;w=v;if((v|0)==0){q=-12;i=e;return q|0}else{c[l+36>>2]=w;c[w+(c[r>>2]<<3)>>2]=c[t>>2];c[w+(c[r>>2]<<3)+4>>2]=0;w=(c[r>>2]|0)+1|0;c[r>>2]=w;u=w;break}}else{u=s}}while(0);s=YGb(u,0,h,0)|0;w=F;t=0;if(w>>>0>t>>>0|w>>>0==t>>>0&s>>>0>536870910>>>0){q=-1094995529;i=e;return q|0}s=l+36|0;t=s;w=bEb(s,u+h|0,8)|0;if((w|0)<0){c[r>>2]=0;q=w;i=e;return q|0}if((j&1|0)==0){x=0;y=0}else{w=vz(b)|0;x=(w|0)<0|0?-1:0;y=w}if((j&4|0)==0){z=d}else{z=vz(b)|0}w=l+1224|0;s=l+112|0;v=ZGb(c[w>>2]|0,c[w+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;A=F;B=a+56|0;C=YGb(c[B>>2]|0,c[B+4>>2]|0,y,x)|0;B=F;D=b+52|0;a:do{if((h|0)==0){E=A;G=v;H=B;I=C}else{J=a+80|0;K=a+76|0;L=(j&256|0)==0;M=(j&512|0)==0;N=(j&1024|0)==0;O=(j&2048|0)==0;P=l+172|0;Q=n+8|0;R=l+1208|0;S=l+1248|0;T=l+1244|0;U=A;V=v;W=B;X=C;Y=0;Z=0;_=0;while(1){if((c[D>>2]|0)!=0){q=-541478725;break}$=c[J>>2]|0;if((Z|0)==0){aa=z}else{aa=c[f>>2]|0}if(L){ba=c[K>>2]|0}else{ba=vz(b)|0}if(M){ca=$}else{ca=vz(b)|0}if(N){da=aa}else{da=vz(b)|0}$=c[t>>2]|0;c[$+(c[r>>2]<<3)>>2]=1;if(O){ea=0;fa=$}else{$=vz(b)|0;ea=$;fa=c[t>>2]|0}c[fa+(c[r>>2]<<3)+4>>2]=ea;$=c[r>>2]|0;ga=c[fa+($<<3)+4>>2]|0;if((ga|0)<0){ha=c[P>>2]|0;ia=-ga|0;c[P>>2]=(ha|0)>(ia|0)?ha:ia}c[r>>2]=$+1;do{if((c[(c[Q>>2]|0)+8>>2]|0)==1){ja=1;ka=_}else{if((_|0)!=0){ja=0;ka=_;break}$=(da&16842752|0)==0;ja=$;ka=$&1}}while(0);$=ja?0:Y;jT(n,X,W,V,U,ca,$,ja&1)|0;ia=ba;ha=0;ga=YGb(ia,ha,V,U)|0;la=F;ma=ca;na=0;oa=YGb(ma,na,X,W)|0;pa=F;qa=YGb(c[R>>2]|0,c[R+4>>2]|0,ma,na)|0;c[R>>2]=qa;c[R+4>>2]=F;qa=YGb(c[S>>2]|0,c[S+4>>2]|0,ia,ha)|0;c[S>>2]=qa;c[S+4>>2]=F;c[T>>2]=(c[T>>2]|0)+1;qa=Z+1|0;if(qa>>>0<h>>>0){U=la;V=ga;W=pa;X=oa;Y=$+1|0;Z=qa;_=ka}else{E=la;G=ga;H=pa;I=oa;break a}}i=e;return q|0}}while(0);if((c[D>>2]|0)!=0){q=-541478725;i=e;return q|0}h=a+64|0;c[h>>2]=I;c[h+4>>2]=H;h=YGb(c[s>>2]|0,c[s+4>>2]|0,G,E)|0;r=F;c[w>>2]=h;c[w+4>>2]=r;t=n+56|0;c[t>>2]=h;c[t+4>>2]=r;q=0;i=e;return q|0}else if((m|0)==5){p=c[k>>2]|0}}while(0);yDb(g,16,1956144,(g=i,i=i+8|0,c[g>>2]=p,g)|0);i=g;q=-1094995529;i=e;return q|0}function jI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;g=c[f+24>>2]|0;if((g|0)==0){h=0;i=e;return h|0}j=d+8|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if(l>>>0>j>>>0|l>>>0==j>>>0&k>>>0>1073741824>>>0){h=-1094995529;i=e;return h|0}j=(c[(c[f+28>>2]|0)+(g-1<<2)>>2]|0)+8|0;g=c[j>>2]|0;f=c[g+48>>2]|0;do{if((f|0)==86035|(f|0)==86067|(f|0)==86052){ZDb(c[g+96>>2]|0);if((CT(c[j>>2]|0,b,k)|0)<0){h=-12}else{break}i=e;return h|0}else{m=0;if(!((l|0)>(m|0)|(l|0)==(m|0)&k>>>0>8>>>0)){Vy(b,k,l)|0;break}m=nH(a,b,d)|0;if((m|0)<0){h=m}else{break}i=e;return h|0}}while(0);h=0;i=e;return h|0}function kI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];kH(c[a+4>>2]|0,b,d)|0;i=e;return 0}function lI(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+32|0;g=d;d=i;i=i+16|0;c[d>>2]=c[g>>2];c[d+4>>2]=c[g+4>>2];c[d+8>>2]=c[g+8>>2];c[d+12>>2]=c[g+12>>2];g=f|0;d=c[a+4>>2]|0;a=c[d+24>>2]|0;if((a|0)==0){i=f;return 0}h=c[(c[d+28>>2]|0)+(a-1<<2)>>2]|0;a=uz(b)|0;b=a>>>14&7;d=a>>>11&7;j=a>>>10&1;c[g>>2]=2;c[g+4>>2]=1;c[g+8>>2]=2;c[g+12>>2]=3;c[g+16>>2]=3;c[g+20>>2]=4;c[g+24>>2]=4;c[g+28>>2]=5;a=j+(c[g+(d<<2)>>2]|0)|0;g=c[h+8>>2]|0;c[g+416>>2]=a;h=e[1746384+(d<<1)>>1]|0;d=0;k=g+448|0;l=(j|0)==0;c[k>>2]=l?h:h|8;c[k+4>>2]=l?d:d|0;d=g+464|0;c[d>>2]=b;if(!((a|0)>1&(b|0)==7)){i=f;return 0}c[d>>2]=8;i=f;return 0}function mI(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=d;d=i;i=i+16|0;c[d>>2]=c[g>>2];c[d+4>>2]=c[g+4>>2];c[d+8>>2]=c[g+8>>2];c[d+12>>2]=c[g+12>>2];g=c[a+4>>2]|0;a=c[g+24>>2]|0;if((a|0)==0){i=f;return 0}d=c[(c[g+28>>2]|0)+(a-1<<2)>>2]|0;tz(b)|0;a=uz(b)|0;b=a>>>12&31;g=e[1746384+((a>>>9&7)<<1)>>1]|0;h=0;j=d+8|0;d=(c[j>>2]|0)+448|0;k=(a&256|0)==0;a=k?g:g|8;g=k?h:h|0;c[d>>2]=a;c[d+4>>2]=g;d=hBb(a,g)|0;g=c[j>>2]|0;c[g+416>>2]=d;j=g+464|0;c[j>>2]=b;if(!((d|0)>1&(b|0)==7)){i=f;return 0}c[j>>2]=8;i=f;return 0}function nI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=c[f>>2]|0;h=c[f+4>>2]|0;j=0;if((h|0)<(j|0)|(h|0)==(j|0)&g>>>0<8>>>0){i=e;return 0}if((vz(b)|0)!=0){j=YGb(g,h,-4,-1)|0;Vy(b,j,F)|0;i=e;return 0}j=rz(b)|0;c[d>>2]=j;d=YGb(g,h,-8,-1)|0;h=F;c[f>>2]=d;c[f+4>>2]=h;if((j|0)!=1952539757){Vy(b,d,h)|0;i=e;return 0}if((d|0)==0&(h|0)==0){i=e;return 0}c[a+28>>2]=1;i=e;return 0}function oI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;a=c[f>>2]|0;g=c[a+24>>2]|0;if((g|0)==0){i=e;return 0}if((AO(b,c[(c[(c[a+28>>2]|0)+(g-1<<2)>>2]|0)+8>>2]|0,c[d+8>>2]|0)|0)>=0){i=e;return 0}yDb(c[f>>2]|0,24,1958496,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=e;return 0}function pI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+136|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e|0;g=e+128|0;vz(b)|0;if((rz(b)|0)!=1836016484){h=-1094995529;i=e;return h|0}if((rz(b)|0)!=1651076218){yDb(c[a+4>>2]|0,16,1960352,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-1094995529;i=e;return h|0}vz(b)|0;if((rz(b)|0)!=1685482851){h=-1094995529;i=e;return h|0}j=vz(b)|0;c[g>>2]=j;k=d+8|0;l=YGb(c[k>>2]|0,c[k+4>>2]|0,-24,0)|0;m=l;l=WDb(m)|0;if((l|0)==0){h=-12;i=e;return h|0}n=WDb(j)|0;if((n|0)==0){ZDb(l);h=-12;i=e;return h|0}mz(b,l,m)|0;do{if((Zb(n|0,g|0,l|0,m|0)|0)==0){if((Ny(f,n,c[g>>2]|0,0,0,0,0,0)|0)!=0){o=-1;break}c[d>>2]=1987014509;b=c[g>>2]|0;c[k>>2]=b;c[k+4>>2]=(b|0)<0|0?-1:0;o=nH(a,f,d)|0}else{o=-1}}while(0);ZDb(n);ZDb(l);h=o;i=e;return h|0}function qI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;a=c[f>>2]|0;g=c[a+24>>2]|0;if((g|0)==0){i=e;return 0}h=d+8|0;d=c[h>>2]|0;j=c[h+4>>2]|0;h=0;if((j|0)<(h|0)|(j|0)==(h|0)&d>>>0<16>>>0){i=e;return 0}h=c[(c[a+28>>2]|0)+(g-1<<2)>>2]|0;Vy(b,4,0)|0;g=c[f>>2]|0;f=YGb(d,j,-4,-1)|0;xI(g,b,h,f,F)|0;i=e;return 0}function rI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}h=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;a=d+8|0;d=c[a>>2]|0;f=c[a+4>>2]|0;a=YGb(d,f,-7,-1)|0;j=F;k=0;if(j>>>0>k>>>0|j>>>0==k>>>0&a>>>0>268435448>>>0){g=-1094995529;i=e;return g|0}if(((lz(b)|0)&240|0)!=192){g=0;i=e;return g|0}Ty(b,6,0,1)|0;a=h+8|0;ZDb(c[(c[a>>2]|0)+96>>2]|0);h=c[a>>2]|0;a=YGb(d,f,-7,0)|0;f=CT(h,b,a)|0;g=(f|0)<0?f:0;i=e;return g|0}function sI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}d=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;a=lz(b)|0;uz(b)|0;if((rz(b)|0)!=544235890){g=0;i=e;return g|0}if((a&255|0)==1){vz(b)|0}a=vz(b)|0;if((a|0)==0){g=0;i=e;return g|0}if(a>>>0>536870910>>>0){g=-1094995529;i=e;return g|0}f=WDb(a<<3)|0;h=d+1240|0;c[h>>2]=f;if((f|0)==0){g=-12;i=e;return g|0}f=b+52|0;j=0;while(1){if((c[f>>2]|0)!=0){k=j;break}l=vz(b)|0;c[(c[h>>2]|0)+(j<<3)>>2]=l;l=vz(b)|0;c[(c[h>>2]|0)+(j<<3)+4>>2]=l;l=j+1|0;if(l>>>0<a>>>0){j=l}else{k=l;break}}c[d+1236>>2]=k;g=(c[f>>2]|0)!=0?-541478725:0;i=e;return g|0}function tI(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+24|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f+16|0;h=e+8|0;e=c[h>>2]|0;j=c[h+4>>2]|0;h=0;if((j|0)<(h|0)|(j|0)==(h|0)&e>>>0<16>>>0|(e|0)==(-1|0)&(j|0)==2147483647){k=-1094995529;i=f;return k|0}h=f|0;l=mz(d,h,16)|0;if((l|0)<0){k=l;i=f;return k|0}if((l|0)!=16){k=-1094995529;i=f;return k|0}if((PGb(h,671880,16)|0)!=0){k=0;i=f;return k|0}h=YGb(e,j,-16,0)|0;j=h;if(j>>>0<4>>>0){k=-1094995529;i=f;return k|0}Vy(d,4,0)|0;h=j-4|0;e=cEb(j-3|0)|0;if((e|0)==0){k=-12;i=f;return k|0}j=mz(d,e,h)|0;if((j|0)<0){ZDb(e);k=j;i=f;return k|0}if((j|0)!=(h|0)){ZDb(e);k=-1094995529;i=f;return k|0}h=rAb(e,1966600)|0;a:do{if((h|0)!=0){j=b+124|0;d=b+120|0;l=h;while(1){m=l+15|0;n=(c[j>>2]|0)+1|0;c[j>>2]=n;o=YDb(c[d>>2]|0,n,4)|0;c[d>>2]=o;if((o|0)==0){break}o=ld()|0;c[o>>2]=0;n=kb(m|0,g|0,10)|0;do{if((n|0)<0){p=18}else{if((c[o>>2]|0)!=0){p=18;break}if((a[c[g>>2]|0]|0)!=34){p=18;break}c[(c[d>>2]|0)+((c[j>>2]|0)-1<<2)>>2]=n}}while(0);if((p|0)==18){p=0;c[(c[d>>2]|0)+((c[j>>2]|0)-1<<2)>>2]=0}l=rAb(m,1966600)|0;if((l|0)==0){break a}}c[j>>2]=0;ZDb(e);k=-12;i=f;return k|0}}while(0);ZDb(e);k=0;i=f;return k|0}function uI(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=e+8|0;h=vI(a,b,c[e>>2]|0,c[g>>2]|0,c[g+4>>2]|0,1412575542)|0;if((h|0)!=0){i=f;return h|0}g=c[a+4>>2]|0;a=c[g+24>>2]|0;if((a|0)==0){i=f;return h|0}e=c[(c[(c[g+28>>2]|0)+(a-1<<2)>>2]|0)+8>>2]|0;if((c[e+100>>2]|0)<=39){i=f;return h|0}a=c[e+96>>2]|0;g=a+36|0;c[e+124>>2]=(de((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;g=a+38|0;c[e+120>>2]=(de((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;i=f;return h|0}function vI(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;k=b+4|0;b=c[k>>2]|0;l=c[b+24>>2]|0;if((l|0)==0){m=0;i=j;return m|0}n=(c[(c[b+28>>2]|0)+(l-1<<2)>>2]|0)+8|0;l=c[n>>2]|0;if((c[l+48>>2]|0)!=(h|0)){m=0;i=j;return m|0}h=c[l+100>>2]|0;b=YGb(h,(h|0)<0|0?-1:0,f,g)|0;h=F;o=YGb(b,h,8,0)|0;p=YGb(b,h,24,0)|0;h=F;b=0;q=0;if(h>>>0>b>>>0|h>>>0==b>>>0&p>>>0>2147483647>>>0|(g>>>0>q>>>0|g>>>0==q>>>0&f>>>0>2147483647>>>0)){m=-1094995529;i=j;return m|0}q=_Db(l+96|0,p)|0;p=c[n>>2]|0;if((q|0)<0){c[p+100>>2]=0;m=q;i=j;return m|0}q=c[p+96>>2]|0;l=p+100|0;p=c[l>>2]|0;c[l>>2]=o;o=YGb(f,g,8,0)|0;l=q+p|0;x=fe(o|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=q+(p+4)|0;x=e;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=p+8|0;p=mz(d,q+l|0,f)|0;if((p|0)<0){m=p;i=j;return m|0}d=p;e=(p|0)<0|0?-1:0;if((e|0)<(g|0)|(e|0)==(g|0)&d>>>0<f>>>0){yDb(c[k>>2]|0,24,1972832,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;k=(c[n>>2]|0)+100|0;n=c[k>>2]|0;o=ZGb(d,e,f,g)|0;g=YGb(o,F,n,0)|0;c[k>>2]=g}TGb(q+(p+l)|0,0,16)|0;m=0;i=j;return m|0}function wI(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=0;while(1){if((f|0)==15){break}if((c[673216+(f<<3)>>2]|0)==(a|0)){g=4;break}else{f=f+1|0}}a:do{if((g|0)==4){a=c[673220+(f<<3)>>2]|0;h=hBb(b,d)|0;i=(h|0)>9?0:h;h=c[675544+(i<<2)>>2]|0;j=c[a>>2]|0;if((j|0)==0){break}k=h|0;l=0;m=j;b:while(1){c:do{if((m&65535|0)==(i|0)){j=c[k>>2]|0;if((j|0)==0){break}else{n=0;o=j}while(1){if((o|0)==(m|0)){j=h+(n<<4)+8|0;if((c[j>>2]|0)==(b|0)&(c[j+4>>2]|0)==(d|0)){break}}n=n+1|0;o=c[h+(n<<4)>>2]|0;if((o|0)==0){break c}}if((m|0)!=0){p=m;q=0;break b}}}while(0);l=l+1|0;m=c[a+(l<<2)>>2]|0;if((m|0)==0){break a}}c[e>>2]=q;return p|0}}while(0);o=0;n=((b|0)!=0|(d|0)!=0)&(d>>>0<o>>>0|d>>>0==o>>>0&b>>>0<262144>>>0);p=n?65536:0;q=n?b:0;c[e>>2]=q;return p|0}function xI(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=0;if((f|0)<(a|0)|(f|0)==(a|0)&e>>>0<12>>>0){g=-1094995529;return g|0}a=vz(b)|0;h=vz(b)|0;i=vz(b)|0;j=gHb(i,0,20,0)|0;k=YGb(j,F,12,0)|0;j=F;if(j>>>0>f>>>0|j>>>0==f>>>0&k>>>0>e>>>0){g=0;return g|0}a:do{if((i|0)==0){l=f;m=e;n=0;o=12}else{if((a|0)==0){p=0;q=0;r=f;s=e}else{k=0;j=f;t=e;while(1){vz(b)|0;vz(b)|0;rz(b)|0;rz(b)|0;rz(b)|0;u=YGb(t,j,-20,-1)|0;v=F;w=k+1|0;if(w>>>0<i>>>0){k=w;j=v;t=u}else{l=v;m=u;n=0;o=12;break a}}}while(1){t=vz(b)|0;vz(b)|0;rz(b)|0;rz(b)|0;rz(b)|0;j=YGb(s,r,-20,-1)|0;k=F;if((t|0)==0){x=k;y=j;break a}do{if(t>>>0<19>>>0){z=1<<t-1}else{if((t|0)==38){z=536870912;break}else if((t|0)!=39){l=k;m=j;n=0;o=12;break a}z=1073741824}}while(0);t=z|p;u=q+1|0;if(u>>>0<i>>>0){p=t;q=u;r=k;s=j}else{l=k;m=j;n=t;o=12;break}}}}while(0);do{if((o|0)==12){if((a|0)==0){if((n|0)==0){x=l;y=m;break}s=(c[d+8>>2]|0)+448|0;c[s>>2]=n;c[s+4>>2]=0;x=l;y=m;break}else if((a|0)==65536){s=h>>>0<262144>>>0;A=s?0:0;B=s?h:0}else{s=a&65535;r=c[675544+((s>>>0>9>>>0?0:s)<<2)>>2]|0;s=0;while(1){q=c[r+(s<<4)>>2]|0;if((q|0)==0|(q|0)==(a|0)){break}else{s=s+1|0}}q=r+(s<<4)+8|0;A=c[q+4>>2]|0;B=c[q>>2]|0}q=(c[d+8>>2]|0)+448|0;c[q>>2]=B;c[q+4>>2]=A;x=l;y=m}}while(0);m=YGb(y,x,-12,-1)|0;Vy(b,m,F)|0;g=0;return g|0}function yI(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[b+12>>2]|0;l=c[b+16>>2]|0;m=f+32|0;n=c[m>>2]|0;o=c[k+48>>2]|0;p=c[o+(n<<8)+76>>2]|0;q=f+28|0;c[h>>2]=c[q>>2];c[j>>2]=0;r=o+(n<<8)+4|0;s=c[r>>2]|0;do{if((s|0)!=0){t=f+16|0;u=c[t>>2]|0;v=c[t+4>>2]|0;w=o+(n<<8)+88|0;x=(c[w>>2]|0)+((s-1|0)*40|0)+8|0;y=ZGb(u,v,c[x>>2]|0,c[x+4>>2]|0)|0;x=F;z=0;if(!(x>>>0>z>>>0|x>>>0==z>>>0&y>>>0>2147483647>>>0)){break}yDb(b,16,1951200,(A=i,i=i+32|0,c[A>>2]=y,c[A+8>>2]=x,c[A+16>>2]=u,c[A+24>>2]=v,A)|0);i=A;v=(c[w>>2]|0)+(((c[r>>2]|0)-1|0)*40|0)+8|0;w=YGb(c[v>>2]|0,c[v+4>>2]|0,1,0)|0;c[t>>2]=w;c[t+4>>2]=F;t=f+8|0;c[t>>2]=0;c[t+4>>2]=-2147483648}}while(0);s=k+52|0;do{if((c[s>>2]&2|0)==0){B=l}else{if((c[k+72>>2]|0)>0){t=o+(n<<8)+180|0;w=c[t>>2]|0;if((w|0)!=0){B=w;break}w=Mz(t)|0;if((w|0)<0){C=w;i=g;return C|0}else{B=c[t>>2]|0;break}}else{t=k+92|0;w=c[t>>2]|0;if((w|0)!=0){B=w;break}w=Mz(t)|0;if((w|0)<0){C=w;i=g;return C|0}else{B=c[t>>2]|0;break}}}}while(0);l=p+48|0;t=c[l>>2]|0;do{if((t|0)==69638|(t|0)==69633){D=c[p+424>>2]|0}else if((t|0)==73728){w=c[h>>2]|0;if((w|0)<=0){D=0;break}v=c[f+24>>2]|0;u=0;x=0;do{x=(e[1183984+(((d[v+x|0]|0)>>>3&15)<<1)>>1]|0)+x|0;u=u+1|0;}while((x|0)<(w|0)&u>>>0<100>>>0);if(!(u>>>0>1>>>0)){D=u;break}yDb(b,16,2235880,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;C=-1;i=g;return C|0}else{w=c[o+(n<<8)+40>>2]|0;if((w|0)==0){D=1;break}D=(c[h>>2]|0)/(w|0)|0}}while(0);w=o+(n<<8)+80|0;do{if((c[w>>2]|0)==0){x=c[p+100>>2]|0;if((x|0)<=0){E=t;break}c[w>>2]=x;v=WDb(x)|0;c[o+(n<<8)+84>>2]=v;UGb(v|0,c[p+96>>2]|0,c[w>>2]|0)|0;E=c[l>>2]|0}else{E=t}}while(0);do{if((E|0)==86018){if((c[q>>2]|0)<=2){G=45;break}t=c[f+24>>2]|0;if(!(((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&-16)<<16>>16==-16)){G=45;break}t=(c[(c[b+28>>2]|0)+(c[m>>2]<<2)>>2]|0)+64|0;p=b;if(!((c[t>>2]|0)==0&(c[t+4>>2]|0)==0)){yDb(p,24,2075168,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;H=c[l>>2]|0;G=30;break}yDb(p,16,2141072,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;C=-1;i=g;return C|0}else{H=E;G=30}}while(0);a:do{if((G|0)==30){do{if((H|0)==28){if((c[w>>2]|0)<=0){G=45;break a}if((a[c[o+(n<<8)+84>>2]|0]|0)==1){if((H|0)==1211250229){break}else{G=45;break a}}E=c[o+(n<<8)+120>>2]|0;do{if((E|0)>-1){if((E|0)>=(c[k+16>>2]|0)){break}bX(c[f+24>>2]|0,j,h)|0;Ry(B,c[j>>2]|0,c[h>>2]|0);break a}}while(0);c[h>>2]=aX(B,c[f+24>>2]|0,c[q>>2]|0)|0;break a}else if((H|0)!=1211250229){G=45;break a}}while(0);if((c[w>>2]|0)<=6){G=45;break}u=c[o+(n<<8)+84>>2]|0;if((d[u+1|0]<<8|d[u]<<16|d[u+2|0]|0)!=1){E=u;if((d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)!=16777216){G=45;break}}E=c[o+(n<<8)+120>>2]|0;do{if((E|0)>-1){if((E|0)>=(c[k+16>>2]|0)){break}hX(c[f+24>>2]|0,j,h,0,0)|0;Ry(B,c[j>>2]|0,c[h>>2]|0);break a}}while(0);c[h>>2]=gX(B,c[f+24>>2]|0,c[q>>2]|0,0,0)|0}}while(0);if((G|0)==45){Ry(B,c[f+24>>2]|0,c[h>>2]|0)}H=c[l>>2]|0;do{if((H|0)==100|(H|0)==86019){if((c[w>>2]|0)!=0){break}c[w>>2]=c[h>>2];E=WDb(c[h>>2]|0)|0;c[o+(n<<8)+84>>2]=E;if((E|0)==0){C=-12;i=g;return C|0}else{UGb(E|0,c[f+24>>2]|0,c[h>>2]|0)|0;break}}}while(0);w=c[r>>2]|0;H=o+(n<<8)+92|0;do{if(w>>>0<(c[H>>2]|0)>>>0){I=o+(n<<8)+88|0}else{E=(w<<1)+2048|0;u=o+(n<<8)+88|0;if((bEb(u,E,40)|0)==0){c[H>>2]=E;I=u;break}else{C=-12;i=g;return C|0}}}while(0);H=Ty(B,0,0,1)|0;B=c[h>>2]|0;w=ZGb(H,F,B,(B|0)<0|0?-1:0)|0;B=c[r>>2]|0;H=c[I>>2]|0;u=H+(B*40|0)|0;c[u>>2]=w;c[u+4>>2]=F;c[H+(B*40|0)+20>>2]=D;c[H+((c[r>>2]|0)*40|0)+24>>2]=0;c[H+((c[r>>2]|0)*40|0)+16>>2]=c[h>>2];c[H+((c[r>>2]|0)*40|0)+28>>2]=D;B=f+16|0;u=c[B+4>>2]|0;w=c[r>>2]|0;E=H+(w*40|0)+8|0;c[E>>2]=c[B>>2];c[E+4>>2]=u;u=o+(n<<8)+112|0;do{if((w|0)==0){E=c[u>>2]|0;m=c[u+4>>2]|0;if(!((E|0)==0&(m|0)==(-2147483648|0))){p=o+(n<<8)+24|0;t=YGb(c[p>>2]|0,c[p+4>>2]|0,E,m)|0;m=H+8|0;c[m>>2]=t;c[m+4>>2]=F;if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==(-2147483648|0))){break}}m=c[k+96>>2]|0;if((m|0)<0){if((c[s>>2]&2|0)==0){break}}else{if((m|0)>0){break}}c[u>>2]=0;c[u+4>>2]=0;m=H+8|0;c[m>>2]=0;c[m+4>>2]=0}}while(0);H=c[u>>2]|0;s=c[u+4>>2]|0;if((H|0)==0&(s|0)==(-2147483648|0)){w=c[B>>2]|0;m=c[B+4>>2]|0;c[u>>2]=w;c[u+4>>2]=m;J=m;K=w}else{J=s;K=H}H=ZGb(c[B>>2]|0,c[B+4>>2]|0,K,J)|0;J=c[f+48>>2]|0;K=YGb(H,F,J,(J|0)<0|0?-1:0)|0;J=o+(n<<8)+24|0;c[J>>2]=K;c[J+4>>2]=F;c[o+(n<<8)+32>>2]=0;J=f+8|0;K=c[J>>2]|0;H=c[J+4>>2]|0;do{if((K|0)==0&(H|0)==(-2147483648|0)){yDb(b,24,2026296,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;s=c[B>>2]|0;w=c[B+4>>2]|0;c[J>>2]=s;c[J+4>>2]=w;L=w;M=s;N=w;O=s}else{s=c[B>>2]|0;w=c[B+4>>2]|0;if((s|0)==(K|0)&(w|0)==(H|0)){L=w;M=s;N=H;O=K;break}m=o+(n<<8)+52|0;c[m>>2]=c[m>>2]|1;L=w;M=s;N=H;O=K}}while(0);K=ZGb(O,N,M,L)|0;L=c[I>>2]|0;c[L+((c[r>>2]|0)*40|0)+32>>2]=K;c[L+((c[r>>2]|0)*40|0)+36>>2]=0;K=c[l>>2]|0;b:do{if((K|0)==71){l=c[k+72>>2]|0;I=c[f+24>>2]|0;M=c[q>>2]|0;N=I+M|0;O=c[f+36>>2]&1;H=N;c:do{if((M|0)<4){P=0;Q=0}else{B=-1;J=I;while(1){if(!(J>>>0<N>>>0)){P=0;Q=0;break c}A=B<<8;if((A|0)==256){break}else{B=d[J]|A;J=J+1|0}}B=J-3|0;if(!(B>>>0<N>>>0)){P=0;Q=0;break}A=o+(n<<8)+248|0;s=B;B=0;w=0;while(1){m=s;u=w;d:while(1){t=m;while(1){E=t+4|0;e:do{if((H-E|0)<4){R=N}else{p=-1;v=E;while(1){if(!(v>>>0<N>>>0)){R=N;break e}x=p<<8;if((x|0)==256){break}else{p=d[v]|x;v=v+1|0}}R=v-3|0}}while(0);E=t;p=fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0;if((p|0)==271){break d}else if((p|0)==270){break}else if((p|0)==267){c[A>>2]=1}if(R>>>0<N>>>0){t=R}else{P=u;Q=B;break c}}if(R>>>0<N>>>0){m=R;u=1}else{P=1;Q=B;break c}}if(R>>>0<N>>>0){s=R;B=1;w=u}else{P=u;Q=1;break}}}}while(0);N=c[r>>2]|0;H=(l|0)==0;do{if((N|l|0)==0){c[o+(n<<8)+232>>2]=Q;c[o+(n<<8)+236>>2]=P}else{I=(Q|0)!=0;if(I){if((c[o+(n<<8)+240>>2]|0)!=0){G=88}}else{G=88}if((G|0)==88){if((P|0)==0){break}if((c[o+(n<<8)+244>>2]|0)!=0){break}}if((N|0)>0){M=0;do{w=L+(M*40|0)+36|0;c[w>>2]=c[w>>2]&-2;M=M+1|0;}while((M|0)<(c[r>>2]|0))}M=o+(n<<8)+48|0;c[M>>2]=0;if(I){c[o+(n<<8)+240>>2]=1}w=(P|0)!=0;if(w){c[o+(n<<8)+244>>2]=1}if(!H){break}if(I){if((c[o+(n<<8)+232>>2]|0)==0){break}}if(w){if((c[o+(n<<8)+236>>2]|0)==0){break}}w=L+36|0;c[w>>2]=c[w>>2]|1;c[M>>2]=1}}while(0);H=(c[o+(n<<8)+244>>2]|0)==0;do{if((c[o+(n<<8)+240>>2]|0)==0){S=H?O:P}else{if(H){S=Q;break}if((Q|0)==0){break b}else{S=P}}}while(0);if((S|0)==0){break}H=L+((c[r>>2]|0)*40|0)+36|0;c[H>>2]=c[H>>2]|1;H=o+(n<<8)+48|0;c[H>>2]=(c[H>>2]|0)+1}else{if((c[f+36>>2]&1|0)==0){break}H=c[r>>2]|0;O=L+(H*40|0)+36|0;do{if((c[k+4>>2]|0)==2&(K|0)==2&(H|0)>0){N=(c[q>>2]|0)-4|0;f:do{if((N|0)>0){l=c[f+24>>2]|0;M=0;w=0;B=-256;while(1){s=d[l+M|0]|B;if((s|0)==440){T=(d[l+(M+4)|0]|0)>>>6&1}else if((s|0)==256){break}else{T=w}A=M+1|0;if((A|0)<(N|0)){M=A;w=T;B=s<<8}else{break f}}if(((d[l+(M+2)|0]|0)>>>6|d[l+(M+1)|0]<<2|0)!=0&(w|0)==0){c[O>>2]=2;break}else{c[O>>2]=1;break}}}while(0);N=c[r>>2]|0;if((c[L+(N*40|0)+36>>2]&2|0)==0){U=N;break}I=o+(n<<8)+52|0;c[I>>2]=c[I>>2]|2;U=N}else{c[O>>2]=1;U=c[r>>2]|0}}while(0);if((c[L+(U*40|0)+36>>2]&1|0)==0){break}O=o+(n<<8)+48|0;c[O>>2]=(c[O>>2]|0)+1}}while(0);U=(c[r>>2]|0)+1|0;c[r>>2]=U;r=o+(n<<8)+36|0;c[r>>2]=(c[r>>2]|0)+D;D=c[h>>2]|0;h=k+40|0;r=YGb(c[h>>2]|0,c[h+4>>2]|0,D,(D|0)<0|0?-1:0)|0;c[h>>2]=r;c[h+4>>2]=F;h=c[o+(n<<8)+120>>2]|0;do{if((h|0)>-1){if((h|0)>=(c[k+16>>2]|0)){break}YI(b,f,h,U,c[j>>2]|0,D)|0}}while(0);ZDb(c[j>>2]|0);C=0;i=g;return C|0}function zI(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0;e=i;i=i+328|0;f=e|0;g=e+152|0;h=e+160|0;j=e+168|0;k=e+176|0;l=e+200|0;m=e+280|0;n=e+288|0;o=e+296|0;p=e+320|0;q=b+16|0;r=c[q>>2]|0;s=b+12|0;t=c[s>>2]|0;u=t;v=b+1140|0;w=BBb(c[v>>2]|0,2129552,0,0)|0;y=t+4|0;c[y>>2]=1;z=c[b+8>>2]|0;do{if((z|0)==0){A=1}else{B=c[z>>2]|0;if((QGb(1925320,B)|0)==0){c[y>>2]=4;A=4;break}if((QGb(2213496,B)|0)==0){c[y>>2]=20;A=20;break}if((QGb(1982400,B)|0)==0){c[y>>2]=2;A=2;break}if((QGb(2264248,B)|0)==0){c[y>>2]=8;A=8;break}if((QGb(2183960,B)|0)==0){c[y>>2]=32;A=32;break}if((QGb(2147568,B)|0)==0){c[y>>2]=64;A=64;break}if((QGb(2122712,B)|0)!=0){A=1;break}c[y>>2]=128;A=128}}while(0);z=t+76|0;do{if((c[z>>2]|0)==0){if((c[t+84>>2]|0)!=0){C=19;break}B=c[t+52>>2]|0;if((B&44|0)==0){D=B}else{C=19}}else{C=19}}while(0);if((C|0)==19){B=t+52|0;E=c[B>>2]|2;c[B>>2]=E;D=E}E=t+52|0;if((A|0)==64){A=D|22;c[E>>2]=A;G=A}else{G=D}a:do{if((G&128|0)==0){H=G}else{do{if((G&2|0)==0){if((c[b+1084>>2]&128|0)!=0){break}c[t+104>>2]=-1;H=G;break a}}while(0);yDb(b,24,2128928,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;D=c[E>>2]&-129;c[E>>2]=D;H=D}}while(0);G=c[t+96>>2]|0;if((G|0)<0){if((H&2|0)!=0){C=30}}else{if((G|0)<=0){C=30}}do{if((C|0)==30){G=b+1204|0;if((c[G>>2]|0)>=0){break}c[G>>2]=2}}while(0);do{if((c[(c[q>>2]|0)+88>>2]|0)==0){if((c[E>>2]&2|0)!=0){if((c[t+88>>2]|0)==0){break}}yDb(b,16,2128384,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-22;i=e;return J|0}}while(0);q=c[s>>2]|0;G=Ty(r,0,0,1)|0;H=F;D=b+24|0;A=c[D>>2]|0;if((A|0)==0){K=0;L=0}else{B=c[b+28>>2]|0;M=0;N=0;O=0;while(1){P=c[(c[B+(N<<2)>>2]|0)+8>>2]|0;Q=(c[P+8>>2]|0)==0?1:M;R=(c[P+48>>2]|0)==28?1:O;P=N+1|0;if(P>>>0<A>>>0){M=Q;N=P;O=R}else{K=Q;L=R;break}}}Zy(r,0);Yy(r,1887007846);O=c[q+120>>2]|0;do{if((O|0)==0){C=42}else{if(!((SGb(O|0)|0)>>>0>3>>>0)){C=42;break}Yy(r,d[O+1|0]<<8|d[O]|d[O+2|0]<<16|d[O+3|0]<<24);S=512;T=q+4|0}}while(0);b:do{if((C|0)==42){O=q+4|0;N=c[O>>2]|0;if((N|0)==4){M=(L|0)!=0;A=M?2085848:2085488;Yy(r,d[A+1|0]<<8|d[A]|d[A+2|0]<<16|d[A+3|0]<<24);S=M?256:512;T=O;break}if((N&16|0)!=0){M=(L|0)!=0;A=M?2085144:2084760;Yy(r,d[A+1|0]<<8|d[A]|d[A+2|0]<<16|d[A+3|0]<<24);S=M?131072:65536;T=O;break}switch(N|0){case 8:{Yy(r,1447973709);S=512;T=O;break b;break};case 1:{Yy(r,1836020585);S=512;T=O;break b;break};case 32:{N=(K|0)!=0?2083240:2082264;Yy(r,d[N+1|0]<<8|d[N]|d[N+2|0]<<16|d[N+3|0]<<24);S=512;T=O;break b;break};case 64:{Yy(r,1819112297);S=512;T=O;break b;break};case 128:{Yy(r,544617574);S=512;T=O;break b;break};default:{Yy(r,538997873);S=512;T=O;break b}}}}while(0);Zy(r,S);S=c[T>>2]|0;do{if((S|0)==2){Yy(r,538997873)}else if((S|0)==64){Yy(r,1717987696);Yy(r,846164841)}else{Yy(r,1836020585);Yy(r,846164841);if((L|0)==0){break}Yy(r,828601953)}}while(0);S=c[T>>2]|0;do{if((S|0)==4){T=(L|0)!=0?2085848:2085488;Yy(r,d[T+1|0]<<8|d[T]|d[T+2|0]<<16|d[T+3|0]<<24)}else{if((S&16|0)!=0){T=(L|0)!=0?2085144:2084760;Yy(r,d[T+1|0]<<8|d[T]|d[T+2|0]<<16|d[T+3|0]<<24);break}if((S|0)==8){Yy(r,1447973709);break}else if((S|0)==1){Yy(r,825520237);break}else{break}}}while(0);S=Ty(r,0,0,1)|0;L=F;Ty(r,G,H,0)|0;T=ZGb(S,L,G,H)|0;Zy(r,T);Ty(r,S,L,0)|0;L=c[y>>2]|0;c:do{if((L|0)==8){S=c[D>>2]|0;do{if((S|0)!=0){T=c[b+28>>2]|0;H=0;G=0;K=0;q=0;while(1){O=c[(c[(c[T+(q<<2)>>2]|0)+8>>2]|0)+8>>2]|0;if((O|0)==0){U=K+1|0;V=G;W=H}else if((O|0)==1){U=K;V=G+1|0;W=H}else{U=K;V=G;W=H+1|0}O=q+1|0;if(O>>>0<S>>>0){H=W;G=V;K=U;q=O}else{break}}if(!((U|0)==1&(V|0)==1&(W|0)==0)){break}q=c[b+28>>2]|0;K=c[(c[q>>2]|0)+8>>2]|0;G=c[(c[q+4>>2]|0)+8>>2]|0;q=c[G+412>>2]|0;H=(c[K+108>>2]<<16|0)/(c[K+104>>2]|0)|0;T=(c[G+72>>2]|0)/1e3|0;O=(c[K+72>>2]|0)/1e3|0;N=800-T|0;M=(O|0)>(N|0)?N:O;Zy(r,148);Yy(r,1684632949);Yy(r,1179603536);Zy(r,567431118);Zy(r,-1148688036);Zy(r,-87439552);Zy(r,0);Zy(r,3);Zy(r,20);Yy(r,1179799622);Zy(r,0);Zy(r,0);Zy(r,0);Zy(r,44);Yy(r,1179799617);Zy(r,0);Zy(r,2);Yy(r,1630826605);Zy(r,527);Zy(r,0);Zy(r,T);Zy(r,T);Zy(r,q);Zy(r,c[G+416>>2]|0);Zy(r,52);Yy(r,1179799638);Zy(r,0);Zy(r,1);if((c[K+48>>2]|0)==28){Yy(r,828601953);fz(r,333);fz(r,21)}else{Yy(r,1983148141);fz(r,0);fz(r,259)}Zy(r,0);Zy(r,M);Zy(r,M);Zy(r,H);Zy(r,H);fz(r,c[K+120>>2]|0);fz(r,c[K+124>>2]|0);Zy(r,65537);X=c[y>>2]|0;break c}}while(0);yDb(b,16,2128040,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-22;i=e;return J|0}else{X=L}}while(0);L=c[D>>2]|0;W=t+16|0;c[W>>2]=L;do{if((X&35|0)==0){Y=L}else{if((c[b+1132>>2]|0)==0){Y=L;break}V=L+1|0;c[W>>2]=V;c[t+24>>2]=L;Y=V}}while(0);do{if((c[E>>2]&1|0)==0){Z=0;_=Y}else{L=c[D>>2]|0;if((L|0)==0){Z=Y;_=Y;break}V=c[b+28>>2]|0;U=0;S=Y;K=L;while(1){if((c[(c[(c[V+(U<<2)>>2]|0)+8>>2]|0)+8>>2]|0)>>>0<2>>>0){L=S+1|0;c[W>>2]=L;$=L;aa=c[D>>2]|0}else{$=S;aa=K}L=U+1|0;if(L>>>0<aa>>>0){U=L;S=$;K=aa}else{Z=Y;_=$;break}}}}while(0);if((X|0)==2){if((c[D>>2]|0)==0){ca=0;da=t+20|0}else{X=b+28|0;$=(w|0)==0;Y=t+20|0;aa=0;while(1){K=c[(c[X>>2]|0)+(aa<<2)>>2]|0;do{if((c[(c[K+8>>2]|0)+8>>2]|0)==0){if($){if((BBb(c[K+88>>2]|0,2129552,0,0)|0)==0){break}}c[Y>>2]=(c[Y>>2]|0)+1}}while(0);K=aa+1|0;S=c[D>>2]|0;if(K>>>0<S>>>0){aa=K}else{ca=S;da=Y;break}}}Y=c[da>>2]|0;do{if((Y|0)==0){ea=0}else{if((ca|0)==0){ea=Y;break}aa=b+28|0;$=b;X=0;S=Y;K=ca;while(1){if((c[(c[(c[(c[aa>>2]|0)+(X<<2)>>2]|0)+8>>2]|0)+52>>2]|0)==1684237684){yDb($,24,2127512,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;c[da>>2]=0;fa=0;ga=c[D>>2]|0}else{fa=S;ga=K}U=X+1|0;if(U>>>0<ga>>>0){X=U;S=fa;K=ga}else{ea=fa;break}}}}while(0);fa=(c[W>>2]|0)+ea|0;c[W>>2]=fa;ha=_;ia=fa}else{ha=0;ia=_}_=cEb((ia<<8)+256|0)|0;ia=_;fa=t+48|0;c[fa>>2]=ia;if((_|0)==0){J=-12;i=e;return J|0}d:do{if((c[D>>2]|0)==0){ja=0;C=251}else{_=b+28|0;ea=b;ga=p;da=p;ca=ga+4|0;Y=t+100|0;K=b+32|0;S=0;X=ia;e:while(1){$=c[(c[_>>2]|0)+(S<<2)>>2]|0;aa=BBb(c[$+88>>2]|0,2127232,0,0)|0;ka=$+8|0;U=X+(S<<8)+76|0;c[U>>2]=c[ka>>2];V=X+(S<<8)+72|0;c[V>>2]=$;if((aa|0)==0){la=2221296}else{la=c[aa+4>>2]|0}aa=qF(la,(c[y>>2]|0)!=2|0)|0;c[X+(S<<8)+60>>2]=(aa|0)<0?0:aa;aa=c[y>>2]|0;L=X+(S<<8)|0;c[L>>2]=aa;f:do{if((aa|0)==1|(aa|0)==8){H=c[U>>2]|0;M=c[H+52>>2]|0;if((uT(1181928,c[H+48>>2]|0)|0)==0){C=206;break e}H=c[U>>2]|0;G=c[H+48>>2]|0;if((G|0)==1211250229){ma=829842792;C=205;break}else if((G|0)==86019){ma=858612577;C=205;break}else if((G|0)==117){ma=1667330660;C=205;break}else if((G|0)==94213){ma=1731426420;C=205;break}else if((G|0)==71){ma=825058166;C=205;break}else if((G|0)==28){ma=828601953;C=205;break}else{G=c[H+8>>2]|0;if((G|0)==0){ma=1983148141;C=205;break}na=(G|0)==1?1630826605:M;C=207;break}}else if((aa|0)==64){M=c[U>>2]|0;G=c[M+52>>2]|0;H=(uT(1181928,c[M+48>>2]|0)|0)==0;M=c[U>>2]|0;q=c[M+48>>2]|0;do{if(!H){if((q|0)==1211250229){ma=829842792;C=205;break f}else if((q|0)==86019){ma=858612577;C=205;break f}else if((q|0)==117){ma=1667330660;C=205;break f}else if((q|0)==94213){ma=1731426420;C=205;break f}else if((q|0)==28){ma=828601953;C=205;break f}else if((q|0)==71){ma=825058166;C=205;break f}else{T=c[M+8>>2]|0;if((T|0)==0){ma=1983148141;C=205;break f}O=(T|0)==1?1630826605:G;if((O|0)==0){break}else{ma=O;C=205;break f}}}}while(0);na=(q|0)==86054?543255927:0;C=207}else if((aa|0)==32){G=c[U>>2]|0;M=c[G+52>>2]|0;if((c[G+8>>2]|0)==3){if((M|0)==1954047348|(M|0)==1731426420){oa=M}else{C=131}}else{C=131}if((C|0)==131){C=0;oa=uT(1462776,c[G+48>>2]|0)|0}if((TC(K,2090952)|0)!=0){na=oa;C=207;break}if((TC(K,2090464)|0)!=0){na=oa;C=207;break}yDb(ea,24,2089968,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;na=oa;C=207}else{if((aa&4|0)!=0){na=uT(1470456,c[(c[U>>2]|0)+48>>2]|0)|0;C=207;break}G=c[U>>2]|0;if((aa|0)==128){na=uT(1462840,c[G+48>>2]|0)|0;C=207;break}M=c[G+52>>2]|0;do{if((M|0)==0){pa=G}else{if(!((c[G+680>>2]|0)>-1)){ma=M;C=205;break f}H=c[G+48>>2]|0;if((H|0)==25|(H|0)==14|(H|0)==5|(H|0)==2){pa=G;break}if((u0a(H)|0)==0){na=M;C=207;break f}pa=c[U>>2]|0}}while(0);G=c[pa+48>>2]|0;if((G|0)==2){q=c[pa+52>>2]|0;H=(c[pa+408>>2]|0)>>>0>1>>>0;O=c[V>>2]|0;T=c[O+8>>2]|0;c[da>>2]=c[T+108>>2];c[ca>>2]=c[T+104>>2];if((bGb(ga)|0)<0){T=c[ca>>2]|0;N=O+92|0;A=c[N>>2]|0;B=c[O+96>>2]|0;yDb(ea,48,2155464,(I=i,i=i+32|0,c[I>>2]=c[da>>2],c[I+8>>2]=T,c[I+16>>2]=A,c[I+24>>2]=B,I)|0);i=I;B=N;N=c[B>>2]|0;A=c[B+4>>2]|0;c[p>>2]=N;c[p+4>>2]=A;qa=N;ra=A}else{qa=c[p>>2]|0;ra=c[p+4>>2]|0}A=~~(+(qa|0)/+(ra|0));N=(q|0)==0?829829741:q;q=c[U>>2]|0;B=c[q+140>>2]|0;if((B|0)==4){T=c[q+120>>2]|0;if((T|0)==1280){if((c[q+124>>2]|0)!=720|H){ma=N;C=205;break}if((A|0)==25){ma=892691576;C=205;break}else if((A|0)==30){ma=825582712;C=205;break}else if((A|0)==50){ma=1630889080;C=205;break}else if((A|0)==24){ma=875914360;C=205;break}else{ma=(A|0)==60?959800440:N;C=205;break}}else if((T|0)!=1920){ma=N;C=205;break}if((c[q+124>>2]|0)!=1080){ma=N;C=205;break}if(H){if((A|0)==25){ma=1664443512;C=205;break}ma=(A|0)==30?1647666296:N;C=205;break}if((A|0)==25){ma=1697997944;C=205;break}else if((A|0)==24){ma=1681220728;C=205;break}else{ma=(A|0)==30?1714775160:N;C=205;break}}else if((B|0)!=0){ma=N;C=205;break}B=c[q+120>>2]|0;if((B|0)==1280){if((c[q+124>>2]|0)!=720|H){ma=N;C=205;break}if((A|0)==25){ma=896951416;C=205;break}else if((A|0)==30){ma=829842552;C=205;break}else if((A|0)==50){ma=1635148920;C=205;break}else if((A|0)==24){ma=880174200;C=205;break}else{ma=(A|0)==60?964060280:N;C=205;break}}else if((B|0)==1440){if((c[q+124>>2]|0)!=1080){ma=N;C=205;break}if(H){if((A|0)==25){ma=863396984;C=205;break}ma=(A|0)==30?846619768:N;C=205;break}if((A|0)==25){ma=930505848;C=205;break}else if((A|0)==24){ma=913728632;C=205;break}else{ma=(A|0)==30?947283064:N;C=205;break}}else if((B|0)==1920){if((c[q+124>>2]|0)!=1080){ma=N;C=205;break}if(H){if((A|0)==25){ma=1668703352;C=205;break}ma=(A|0)==30?1651926136:N;C=205;break}if((A|0)==25){ma=1702257784;C=205;break}else if((A|0)==24){ma=1685480568;C=205;break}else{ma=(A|0)==30?1719035e3:N;C=205;break}}else{ma=N;C=205;break}}else if((G|0)==14){N=c[pa+52>>2]|0;A=c[pa+140>>2]|0;H=pa+792|0;q=N;B=0;while(1){if((A|0)==(c[671896+(B*12|0)>>2]|0)){T=c[671900+(B*12|0)>>2]|0;c[H>>2]=c[671904+(B*12|0)>>2];if((N|0)==(T|0)){na=N;C=207;break f}else{sa=T}}else{sa=q}T=B+1|0;if(T>>>0<15>>>0){q=sa;B=T}else{na=sa;C=207;break}}}else if((G|0)==25){B=c[pa+124>>2]|0;if((c[pa+120>>2]|0)!=720){if((B|0)==1080){ma=(c[pa+108>>2]|0)==25?896038500:912815716;C=205;break}else if((B|0)==720){ma=(c[pa+108>>2]|0)==50?1902671460:1885894244;C=205;break}else{C=153;break e}}q=c[pa+140>>2]|0;N=(q|0)==4;if((B|0)==480){ma=N?1848997476:543389284;C=205;break}if(N){ma=1882551908;C=205;break}ma=(q|0)==0?1885566564:1886418532;C=205;break}else{q=c[pa+8>>2]|0;if((q|0)==0){N=uT(1238728,G)|0;if((N|0)!=0){ma=N;C=205;break}N=uT(1240808,c[(c[U>>2]|0)+48>>2]|0)|0;if((N|0)==0){C=206;break e}yDb(ea,24,2092120,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;ma=N;C=205;break}else if((q|0)==1){N=uT(1240080,G)|0;if((N|0)!=0){ma=N;C=205;break}N=uT(1238064,c[(c[U>>2]|0)+48>>2]|0)|0;if((N|0)==0){C=206;break e}yDb(ea,24,2091512,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;ma=N<<24|N>>>8<<16&16711680|29549;C=205;break}else if((q|0)==3){na=uT(1240048,G)|0;C=207;break}else{na=M;C=207;break}}}}while(0);if((C|0)==205){C=0;V=X+(S<<8)+68|0;c[V>>2]=ma;ta=V}else if((C|0)==207){C=0;V=X+(S<<8)+68|0;c[V>>2]=na;if((na|0)==0){break}else{ta=V}}c[X+(S<<8)+120>>2]=-1;V=X+(S<<8)+112|0;c[V>>2]=0;c[V+4>>2]=-2147483648;V=c[ka>>2]|0;aa=c[V+8>>2]|0;do{if((aa|0)==2){c[X+(S<<8)+8>>2]=c[V+108>>2]}else if((aa|0)==0){q=c[ta>>2]|0;if((q|0)==1882421357|(q|0)==1848866925|(q|0)==1882486893|(q|0)==1848932461|(q|0)==1882552429|(q|0)==1848997997){if((c[V+120>>2]|0)!=720){C=213;break e}N=c[V+124>>2]|0;if(!((N|0)==608|(N|0)==512)){C=213;break e}c[X+(S<<8)+100>>2]=(q&-16777216|0)==1845493760?486:576}q=c[Y>>2]|0;if((q|0)==0){N=c[V+108>>2]|0;while(1){if(N>>>0<1e4>>>0){N=N<<1}else{break}}c[X+(S<<8)+8>>2]=N;ua=N}else{c[X+(S<<8)+8>>2]=q;ua=q}if(!((c[L>>2]|0)==2&ua>>>0>1e5>>>0)){break}yDb(ea,24,2123648,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}else if((aa|0)==1){M=X+(S<<8)+8|0;c[M>>2]=c[V+412>>2];do{if((c[V+424>>2]|0)==0){if((u0a(c[V+48>>2]|0)|0)==0){yDb(ea,24,2123320,(I=i,i=i+8|0,c[I>>2]=S,I)|0);i=I;c[X+(S<<8)+96>>2]=1;va=c[ka>>2]|0;break}else{wa=c[ka>>2]|0;C=226;break}}else{wa=V;C=226}}while(0);do{if((C|0)==226){C=0;q=c[wa+48>>2]|0;if((q|0)==69638|(q|0)==69633|(q|0)==86076){N=c[wa+432>>2]|0;if((N|0)==0){C=228;break e}c[X+(S<<8)+40>>2]=N;va=wa;break}if((c[wa+424>>2]|0)>1){c[X+(S<<8)+96>>2]=1;va=wa;break}else{N=(u0a(q)|0)>>3;q=c[ka>>2]|0;c[X+(S<<8)+40>>2]=ba(c[q+416>>2]|0,N)|0;va=q;break}}}while(0);q=c[va+48>>2]|0;if((q|0)==86076|(q|0)==69632){c[X+(S<<8)+96>>2]=1}if((c[L>>2]|0)==2){break}xa=c[U>>2]|0;if((c[xa+48>>2]|0)!=86017){break}if((c[M>>2]|0)>>>0<16e3>>>0){C=238;break e}}else if((aa|0)==3){c[X+(S<<8)+8>>2]=c[V+108>>2]}else{c[X+(S<<8)+8>>2]=1e3}}while(0);V=X+(S<<8)+100|0;if((c[V>>2]|0)==0){c[V>>2]=c[(c[ka>>2]|0)+124>>2]}V=X+(S<<8)+8|0;if((c[y>>2]|0)==64){c[V>>2]=1e7;ya=1e7}else{ya=c[V>>2]|0}MT($,64,1,ya);V=c[(c[ka>>2]|0)+100>>2]|0;if((V|0)!=0){aa=X+(S<<8)+80|0;c[aa>>2]=V;U=WDb(V)|0;c[X+(S<<8)+84>>2]=U;UGb(U|0,c[(c[ka>>2]|0)+96>>2]|0,c[aa>>2]|0)|0}aa=S+1|0;U=c[D>>2]|0;if(!(aa>>>0<U>>>0)){ja=U;C=251;break d}S=aa;X=c[fa>>2]|0}if((C|0)==153){yDb(ea,16,2091176,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;C=206}else if((C|0)==213){yDb(ea,16,2124312,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;za=-22;break}else if((C|0)==228){yDb(ea,16,2123104,(I=i,i=i+8|0,c[I>>2]=S,I)|0);i=I;za=-22;break}else if((C|0)==238){Y=c[xa+412>>2]|0;yDb(ea,16,2122736,(I=i,i=i+16|0,c[I>>2]=S,c[I+8>>2]=Y,I)|0);i=I;za=-22;break}if((C|0)==206){c[X+(S<<8)+68>>2]=0}Y=H0a(c[(c[ka>>2]|0)+48>>2]|0)|0;yDb(ea,16,2125760,(I=i,i=i+16|0,c[I>>2]=Y,c[I+8>>2]=S,I)|0);i=I;za=-22}}while(0);g:do{if((C|0)==251){ka=n|0;xa=c[s>>2]|0;TGb(ka|0,0,5)|0;TGb(o|0,-1|0,20)|0;if((ja|0)==0){Aa=xa+48|0;C=261}else{ya=c[b+28>>2]|0;va=xa+48|0;xa=0;wa=ja;while(1){ua=c[ya+(xa<<2)>>2]|0;ta=c[(c[ua+8>>2]|0)+8>>2]|0;do{if(ta>>>0>4>>>0){Ba=wa}else{na=o+(ta<<2)|0;if((c[na>>2]|0)<0){c[na>>2]=xa}if((c[ua+72>>2]&1|0)==0){Ba=wa;break}na=(c[va>>2]|0)+(xa<<8)+52|0;c[na>>2]=c[na>>2]|4;a[n+ta|0]=1;Ba=c[D>>2]|0}}while(0);ta=xa+1|0;if(ta>>>0<Ba>>>0){xa=ta;wa=Ba}else{break}}if((a[ka]|0)==0){Aa=va;C=261}else{Ca=va}}do{if((C|0)==261){wa=c[o>>2]|0;if(!((wa|0)>-1)){Ca=Aa;break}xa=(c[Aa>>2]|0)+(wa<<8)+52|0;c[xa>>2]=c[xa>>2]|4;Ca=Aa}}while(0);do{if((a[n+1|0]|0)==0){va=c[o+4>>2]|0;if(!((va|0)>-1)){break}ka=(c[Ca>>2]|0)+(va<<8)+52|0;c[ka>>2]=c[ka>>2]|4}}while(0);do{if((a[n+3|0]|0)==0){ka=c[o+12>>2]|0;if(!((ka|0)>-1)){break}va=(c[Ca>>2]|0)+(ka<<8)+52|0;c[va>>2]=c[va>>2]|4}}while(0);va=t+104|0;do{if((c[va>>2]|0)!=0){ka=Ty(r,0,0,1)|0;xa=t+112|0;c[xa>>2]=ka;c[xa+4>>2]=F;xa=c[va>>2]|0;if((xa|0)<=0){break}Vy(r,xa,(xa|0)<0|0?-1:0)|0;}}while(0);va=c[E>>2]|0;do{if((va&2|0)==0){if((va&128|0)!=0){xa=Ty(r,0,0,1)|0;ka=t+112|0;c[ka>>2]=xa;c[ka+4>>2]=F}Zy(r,8);ka=(c[y>>2]|0)==2?2093168:1884464;Yy(r,d[ka+1|0]<<8|d[ka]|d[ka+2|0]<<16|d[ka+3|0]<<24);ka=Ty(r,0,0,1)|0;xa=t+32|0;c[xa>>2]=ka;c[xa+4>>2]=F;Zy(r,0);Yy(r,1952539757)}else{if((va&40|0)!=0){break}if((c[z>>2]|0)!=0){break}if((c[t+84>>2]|0)!=0){break}c[E>>2]=va|8}}while(0);va=BBb(c[v>>2]|0,2122328,0,0)|0;if((va|0)==0){xa=t+8|0;Da=c[xa+4>>2]|0;Ea=c[xa>>2]|0}else{xa=bU(c[va+4>>2]|0)|0;va=F;ka=t+8|0;c[ka>>2]=xa;c[ka+4>>2]=va;Da=va;Ea=xa}if(!((Ea|0)==0&(Da|0)==0)){xa=t+8|0;va=YGb(Ea,Da,2082844800,0)|0;c[xa>>2]=va;c[xa+4>>2]=F}xa=c[t+24>>2]|0;if((xa|0)!=0){va=CI(b,xa)|0;if((va|0)<0){za=va;break}}do{if((c[E>>2]&1|0)!=0){va=c[D>>2]|0;if((va|0)==0){break}xa=b+28|0;ka=Z;wa=0;ya=va;while(1){if((c[(c[(c[(c[xa>>2]|0)+(wa<<2)>>2]|0)+8>>2]|0)+8>>2]|0)>>>0<2>>>0){va=XI(b,ka,wa)|0;if((va|0)<0){za=va;break g}Fa=ka+1|0;Ga=c[D>>2]|0}else{Fa=ka;Ga=ya}va=wa+1|0;if(va>>>0<Ga>>>0){ka=Fa;wa=va;ya=Ga}else{break}}}}while(0);do{if((c[t+20>>2]|0)!=0){if((c[D>>2]|0)==0){break}ya=b+28|0;wa=(w|0)==0;ka=l;xa=m;va=l+28|0;S=l+32|0;ea=l+36|0;X=j;ta=j;ua=X+4|0;$=b;na=k+4|0;ma=m;pa=xa+4|0;sa=l+24|0;ra=k|0;qa=ha;p=0;while(1){oa=c[(c[ya>>2]|0)+(p<<2)>>2]|0;do{if((c[(c[oa+8>>2]|0)+8>>2]|0)==0){if(wa){la=BBb(c[oa+88>>2]|0,2129552,0,0)|0;if((la|0)==0){Ha=qa;break}Ia=la;Ja=c[(c[ya>>2]|0)+(p<<2)>>2]|0}else{Ia=w;Ja=oa}la=c[Ia+4>>2]|0;ia=c[s>>2]|0;Y=ia+48|0;da=c[Y>>2]|0;TGb(ka|0,0,80)|0;c[va>>2]=4;c[S>>2]=qa;c[ea>>2]=1;ca=c[Ja+8>>2]|0;c[ta>>2]=c[ca+108>>2];c[ua>>2]=c[ca+104>>2];if((bGb(X)|0)<0){ca=c[ua>>2]|0;ga=Ja+92|0;K=c[ga>>2]|0;_=c[Ja+96>>2]|0;yDb($,48,2155464,(I=i,i=i+32|0,c[I>>2]=c[ta>>2],c[I+8>>2]=ca,c[I+16>>2]=K,c[I+24>>2]=_,I)|0);i=I;_=ga;ga=c[_>>2]|0;K=c[_+4>>2]|0;c[j>>2]=ga;c[j+4>>2]=K;Ka=K;La=ga}else{Ka=c[j+4>>2]|0;La=c[j>>2]|0}c[m>>2]=La;c[m+4>>2]=Ka;ga=dGb(k,xa,la,$)|0;if((ga|0)<0){Ma=ga}else{c[da+(qa<<8)>>2]=c[ia+4>>2];ia=da+(qa<<8)+68|0;c[ia>>2]=1684237684;c[da+(qa<<8)+124>>2]=p;c[da+(qa<<8)+8>>2]=c[(c[Y>>2]|0)+(p<<8)+8>>2];if((c[na>>2]&1|0)!=0){Y=da+(qa<<8)+56|0;c[Y>>2]=c[Y>>2]|1}Y=ARa(0)|0;c[da+(qa<<8)+76>>2]=Y;c[Y+8>>2]=2;c[Y+52>>2]=c[ia>>2];ia=Y+104|0;Y=c[ma>>2]|0;c[ia>>2]=c[pa>>2];c[ia+4>>2]=Y;Y=WDb(c[va>>2]|0)|0;c[sa>>2]=Y;ia=Y;x=fe(c[ra>>2]|0)|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=yI(b,l)|0;ZDb(c[sa>>2]|0);Ma=ia}if((Ma|0)<0){za=Ma;break g}Ha=qa+1|0}else{Ha=qa}}while(0);oa=p+1|0;if(oa>>>0<(c[D>>2]|0)>>>0){qa=Ha;p=oa}else{break}}}}while(0);Sy(r);p=c[E>>2]|0;if((p&64|0)==0){Na=p}else{p=Ty(r,0,0,1)|0;qa=F;Zy(r,0);Yy(r,1684632949);Ry(r,671768,16);Zy(r,0);Kz(r,2122e3,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;Kz(r,2121616,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;Kz(r,2121232,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;Kz(r,212e4,(I=i,i=i+8|0,c[I>>2]=2263312,I)|0)|0;i=I;Kz(r,2118840,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;Kz(r,2118400,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;Kz(r,2118112,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;sa=c[W>>2]|0;if((sa|0)>0){ra=f|0;va=0;pa=sa;while(1){sa=va+1|0;ma=(c[fa>>2]|0)+(va<<8)+76|0;na=c[ma>>2]|0;$=c[na+8>>2]|0;if(($|0)==1){Oa=2117616;C=317}else if(($|0)==0){Oa=2117920;C=317}else{Pa=pa}if((C|0)==317){C=0;$=c[na+72>>2]|0;Kz(r,2117216,(I=i,i=i+16|0,c[I>>2]=Oa,c[I+8>>2]=$,I)|0)|0;i=I;$=c[(c[ma>>2]|0)+72>>2]|0;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2116928,c[I+8>>2]=$,I)|0)|0;i=I;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2116624,c[I+8>>2]=sa,I)|0)|0;i=I;$=c[ma>>2]|0;na=c[$+48>>2]|0;if((c[$+8>>2]|0)==0){if((na|0)==71){Kz(r,2094664,(I=i,i=i+16|0,c[I>>2]=2113952,c[I+8>>2]=2110168,I)|0)|0;i=I;xa=c[ma>>2]|0;ta=c[xa+100>>2]|0;ua=ta>>>0<74>>>0?ta:74;ZT(ra,c[xa+96>>2]|0,ua,0)|0;a[f+(ua<<1)|0]=0;Kz(r,2094664,(I=i,i=i+16|0,c[I>>2]=2116240,c[I+8>>2]=ra,I)|0)|0;i=I}else if((na|0)==28){c[h>>2]=c[$+100>>2];if((dX(c[$+96>>2]|0,g,h)|0)==0){$=c[g>>2]|0;if(($|0)==0){Qa=c[(c[ma>>2]|0)+96>>2]|0}else{Qa=$}$=c[h>>2]|0;ua=$>>>0<74>>>0?$:74;ZT(ra,Qa,ua,0)|0;a[f+(ua<<1)|0]=0;Kz(r,2094664,(I=i,i=i+16|0,c[I>>2]=2116240,c[I+8>>2]=ra,I)|0)|0;i=I;ZDb(c[g>>2]|0)}Kz(r,2094664,(I=i,i=i+16|0,c[I>>2]=2113952,c[I+8>>2]=2111976,I)|0)|0;i=I}ua=c[(c[ma>>2]|0)+120>>2]|0;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2108832,c[I+8>>2]=ua,I)|0)|0;i=I;ua=c[(c[ma>>2]|0)+124>>2]|0;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2107872,c[I+8>>2]=ua,I)|0)|0;i=I;ua=c[(c[ma>>2]|0)+120>>2]|0;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2107024,c[I+8>>2]=ua,I)|0)|0;i=I;ua=c[(c[ma>>2]|0)+124>>2]|0;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2105328,c[I+8>>2]=ua,I)|0)|0;i=I}else{if((na|0)==86018){Kz(r,2094664,(I=i,i=i+16|0,c[I>>2]=2113952,c[I+8>>2]=2103960,I)|0)|0;i=I}else if((na|0)==86054){Kz(r,2094664,(I=i,i=i+16|0,c[I>>2]=2113952,c[I+8>>2]=2103280,I)|0)|0;i=I}na=c[ma>>2]|0;ua=c[na+100>>2]|0;$=ua>>>0<74>>>0?ua:74;ZT(ra,c[na+96>>2]|0,$,0)|0;a[f+($<<1)|0]=0;Kz(r,2094664,(I=i,i=i+16|0,c[I>>2]=2116240,c[I+8>>2]=ra,I)|0)|0;i=I;$=uT(1238064,c[(c[ma>>2]|0)+48>>2]|0)|0;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2102e3,c[I+8>>2]=$,I)|0)|0;i=I;$=c[(c[ma>>2]|0)+416>>2]|0;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2099624,c[I+8>>2]=$,I)|0)|0;i=I;$=c[(c[ma>>2]|0)+412>>2]|0;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2098112,c[I+8>>2]=$,I)|0)|0;i=I;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2097152,c[I+8>>2]=16,I)|0)|0;i=I;$=c[(c[ma>>2]|0)+432>>2]|0;Kz(r,2094368,(I=i,i=i+16|0,c[I>>2]=2096824,c[I+8>>2]=($|0)==0?4:$,I)|0)|0;i=I}Kz(r,2096392,(I=i,i=i+8|0,c[I>>2]=Oa,I)|0)|0;i=I;Pa=c[W>>2]|0}if((sa|0)<(Pa|0)){va=sa;pa=Pa}else{break}}}Kz(r,2095960,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;Kz(r,2095408,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;Kz(r,2095064,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;pa=Ty(r,0,0,1)|0;va=F;Ty(r,p,qa,0)|0;ra=ZGb(pa,va,p,qa)|0;Zy(r,ra);Ty(r,pa,va,0)|0;Na=c[E>>2]|0}if((Na&4|0)==0){J=0;i=e;return J|0}DI(r,u,b);va=t+72|0;c[va>>2]=(c[va>>2]|0)+1;J=0;i=e;return J|0}}while(0);GI(c[s>>2]|0);J=za;i=e;return J|0}function AI(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+88|0;f=e|0;g=e+80|0;if((d|0)==0){EI(a);h=1;i=e;return h|0}j=c[a+12>>2]|0;if((c[d+28>>2]|0)==0){h=0;i=e;return h|0}k=j+16|0;l=c[k>>2]|0;a:do{if((l|0)>0){m=j+48|0;n=d+16|0;o=g;p=f+28|0;q=f+24|0;r=f+8|0;s=f+16|0;t=f+48|0;u=f+32|0;v=0;w=l;b:while(1){x=c[m>>2]|0;do{if((c[(c[x+(v<<8)+76>>2]|0)+48>>2]|0)==94213){y=x+(v<<8)+24|0;z=c[y>>2]|0;A=c[y+4>>2]|0;y=c[n+4>>2]|0;if(!((A|0)<(y|0)|(A|0)==(y|0)&z>>>0<(c[n>>2]|0)>>>0)){B=w;break}if((c[x+(v<<8)+4>>2]|0)!=0){if((c[x+(v<<8)+32>>2]|0)!=0){B=w;break}}b[g>>1]=0;vZ(f);c[p>>2]=2;c[q>>2]=o;c[r>>2]=z;c[r+4>>2]=A;c[s>>2]=z;c[s+4>>2]=A;c[t>>2]=0;c[u>>2]=v;A=WI(a,f)|0;BZ(f);if((A|0)<0){h=A;break b}c[x+(v<<8)+32>>2]=1;B=c[k>>2]|0}else{B=w}}while(0);x=v+1|0;if((x|0)<(B|0)){v=x;w=B}else{break a}}i=e;return h|0}}while(0);h=WI(a,d)|0;i=e;return h|0}function BI(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=i;i=i+136|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+120|0;m=d+128|0;n=a+12|0;o=c[n>>2]|0;p=o;q=a+16|0;r=c[q>>2]|0;s=o+16|0;t=c[s>>2]|0;if((t|0)>0){u=o+48|0;v=l;w=k+28|0;x=k+24|0;y=k+8|0;z=k+16|0;A=k+48|0;B=k+32|0;C=0;D=t;while(1){E=c[u>>2]|0;do{if((c[(c[E+(C<<8)+76>>2]|0)+48>>2]|0)==94213){G=E+(C<<8)+32|0;if((c[G>>2]|0)!=0){H=D;break}I=E+(C<<8)+24|0;J=c[I>>2]|0;K=c[I+4>>2]|0;b[l>>1]=0;vZ(k);c[w>>2]=2;c[x>>2]=v;c[y>>2]=J;c[y+4>>2]=K;c[z>>2]=J;c[z+4>>2]=K;c[A>>2]=0;c[B>>2]=C;WI(a,k)|0;BZ(k);c[G>>2]=1;H=c[s>>2]|0}else{H=D}}while(0);E=C+1|0;if((E|0)<(H|0)){C=E;D=H}else{L=H;break}}}else{L=t}t=o+24|0;H=o+52|0;do{if((c[t>>2]|0)==0){if((c[H>>2]&2|0)!=0){M=0;N=12;break}if((c[o+4>>2]&35|0)==0){M=0;N=12;break}if((c[a+1132>>2]|0)==0){M=0;N=12;break}c[s>>2]=L+1;c[t>>2]=L;D=CI(a,L)|0;if((D|0)<0){O=D}else{M=D;N=12}}else{M=0;N=12}}while(0);do{if((N|0)==12){do{if((c[H>>2]&2|0)==0){L=Ty(r,0,0,1)|0;t=F;D=o+40|0;C=YGb(c[D>>2]|0,c[D+4>>2]|0,8,0)|0;k=F;B=1;A=o+32|0;z=c[A>>2]|0;y=c[A+4>>2]|0;if(k>>>0<B>>>0|k>>>0==B>>>0&C>>>0<0>>>0){Ty(r,z,y,0)|0;C=YGb(c[D>>2]|0,c[D+4>>2]|0,8,0)|0;Zy(r,C)}else{C=YGb(z,y,-8,-1)|0;Ty(r,C,F,0)|0;Zy(r,1);Yy(r,1952539757);C=YGb(c[D>>2]|0,c[D+4>>2]|0,16,0)|0;ez(r,C,F)}C=o+104|0;if((c[C>>2]|0)>0){D=o+112|0;P=c[D+4>>2]|0;Q=c[D>>2]|0}else{P=t;Q=L}Ty(r,Q,P,0)|0;if((c[H>>2]&128|0)==0){D=(c[C>>2]|0)>0;DI(r,p,a);if(!D){R=M;break}D=c[C>>2]|0;C=Ty(r,0,0,1)|0;y=o+112|0;z=ZGb(c[y>>2]|0,c[y+4>>2]|0,C,F)|0;C=YGb(z,F,D,(D|0)<0|0?-1:0)|0;D=F;z=0;if((D|0)<(z|0)|(D|0)==(z|0)&C>>>0<8>>>0){z=ZGb(8,0,C,D)|0;y=F;yDb(a,16,1886176,(S=i,i=i+16|0,c[S>>2]=z,c[S+8>>2]=y,S)|0);i=S;T=-1;i=d;return T|0}Zy(r,C);Yy(r,1701147238);y=0;do{Py(r,0);y=y+1|0;z=(y|0)<0|0?-1:0;}while((z|0)<(D|0)|(z|0)==(D|0)&y>>>0<C>>>0);Ty(r,L,t,0)|0;R=M;break}C=a;yDb(C,32,1887528,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;y=c[n>>2]|0;Ty(c[q>>2]|0,0,0,1)|0;D=c[n>>2]|0;z=Pz(f)|0;do{if((z|0)<0){U=z}else{DI(c[f>>2]|0,D,a);B=Rz(c[f>>2]|0)|0;if((B|0)<0){U=B;break}k=D+16|0;A=c[k>>2]|0;if((A|0)>0){v=B;x=(B|0)<0|0?-1:0;w=c[D+48>>2]|0;l=0;do{u=w+(l<<8)+184|0;E=YGb(c[u>>2]|0,c[u+4>>2]|0,v,x)|0;c[u>>2]=E;c[u+4>>2]=F;l=l+1|0;}while((l|0)<(A|0))}A=c[n>>2]|0;l=Pz(e)|0;if((l|0)<0){U=l;break}DI(c[e>>2]|0,A,a);A=Rz(c[e>>2]|0)|0;l=(A|0)<0;do{if(!(l|(A|0)==(B|0))){x=c[k>>2]|0;if((x|0)<=0){break}v=A-B|0;w=v;u=(v|0)<0|0?-1:0;v=c[D+48>>2]|0;E=0;do{G=v+(E<<8)+184|0;K=YGb(c[G>>2]|0,c[G+4>>2]|0,w,u)|0;c[G>>2]=K;c[G+4>>2]=F;E=E+1|0;}while((E|0)<(x|0))}}while(0);if(l){U=A;break}B=WDb(A<<1)|0;if((B|0)==0){U=-12;break}c[g>>2]=B;k=B+A|0;c[g+4>>2]=k;Sy(c[q>>2]|0);x=a+32|0;E=Gz(j,x,1)|0;if((E|0)<0){yDb(C,16,2130416,(S=i,i=i+8|0,c[S>>2]=x,S)|0);i=S}else{x=Ty(c[q>>2]|0,0,0,1)|0;u=F;w=c[q>>2]|0;v=y+112|0;G=YGb(c[v>>2]|0,c[v+4>>2]|0,A,(A|0)<0|0?-1:0)|0;Ty(w,G,F,0)|0;Ty(c[j>>2]|0,c[v>>2]|0,c[v+4>>2]|0,0)|0;v=Ty(c[j>>2]|0,0,0,1)|0;G=F;c[h>>2]=mz(c[j>>2]|0,B,A)|0;w=1;K=G;G=v;v=k;do{c[h+(w<<2)>>2]=mz(c[j>>2]|0,v,A)|0;w=w^1;k=c[h+(w<<2)>>2]|0;if((k|0)<1){break}v=c[g+(w<<2)>>2]|0;Ry(c[q>>2]|0,v,k);G=YGb(k,(k|0)<0|0?-1:0,G,K)|0;K=F;}while((K|0)<(u|0)|(K|0)==(u|0)&G>>>0<x>>>0);Iz(c[j>>2]|0)|0}ZDb(B);U=E}}while(0);if((U|0)!=0){R=U;break}y=o+112|0;Ty(c[q>>2]|0,c[y>>2]|0,c[y+4>>2]|0,0)|0;DI(r,p,a);R=0}else{EI(a);y=Ty(r,0,0,1)|0;C=F;Zy(r,0);Yy(r,1634887277);if((c[H>>2]&64|0)!=0){D=Ty(r,0,0,1)|0;z=F;Ty(r,y,C,0)|0;t=ZGb(D,z,y,C)|0;Zy(r,t);Ty(r,D,z,0)|0;R=M;break}z=c[s>>2]|0;if((z|0)>0){D=o+48|0;t=0;L=z;while(1){z=c[D>>2]|0;x=z+(t<<8)+208|0;if((c[x>>2]|0)==0){V=L}else{G=Ty(r,0,0,1)|0;u=F;Zy(r,0);Yy(r,1634887284);Py(r,1);hz(r,0);Zy(r,c[z+(t<<8)+64>>2]|0);Zy(r,0);Zy(r,c[x>>2]|0);if((c[x>>2]|0)>0){K=z+(t<<8)+212|0;z=0;do{v=(c[K>>2]|0)+(z<<5)+8|0;ez(r,c[v>>2]|0,c[v+4>>2]|0);v=(c[K>>2]|0)+(z<<5)|0;ez(r,c[v>>2]|0,c[v+4>>2]|0);Py(r,1);Py(r,1);Py(r,1);z=z+1|0;}while((z|0)<(c[x>>2]|0))}x=Ty(r,0,0,1)|0;z=F;Ty(r,G,u,0)|0;K=ZGb(x,z,G,u)|0;Zy(r,K);Ty(r,x,z,0)|0;V=c[s>>2]|0}z=t+1|0;if((z|0)<(V|0)){t=z;L=V}else{break}}}Zy(r,16);Yy(r,1869768301);Zy(r,0);L=Ty(r,0,0,1)|0;t=F;D=ZGb(4,0,y,C)|0;z=YGb(D,F,L,t)|0;Zy(r,z);z=Ty(r,0,0,1)|0;t=F;Ty(r,y,C,0)|0;L=ZGb(z,t,y,C)|0;Zy(r,L);Ty(r,z,t,0)|0;R=M}}while(0);if((c[s>>2]|0)<=0){O=R;break}t=o+48|0;z=m|0;L=0;while(1){do{if((c[H>>2]&2|0)!=0){D=(c[t>>2]|0)+(L<<8)+224|0;if((c[D>>2]|0)==0&(c[D+4>>2]|0)==0){break}if((c[(c[q>>2]|0)+88>>2]|0)==0){break}D=Ty(r,0,0,1)|0;x=F;if(!((FI((c[t>>2]|0)+(L<<8)|0,z)|0)>-1)){break}K=(c[t>>2]|0)+(L<<8)+224|0;Ty(r,c[K>>2]|0,c[K+4>>2]|0,0)|0;Ry(r,z,7);Ty(r,D,x,0)|0;}}while(0);C=L+1|0;if((C|0)<(c[s>>2]|0)){L=C}else{O=R;break}}}}while(0);GI(c[n>>2]|0);T=O;i=d;return T|0}function CI(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+112|0;f=e|0;g=e+8|0;h=e+88|0;j=e+96|0;k=e+104|0;l=c[b+12>>2]|0;m=c[l+48>>2]|0;TGb(g|0,0,80)|0;c[g+32>>2]=d;c[g+36>>2]=1;c[m+(d<<8)>>2]=c[l+4>>2];c[m+(d<<8)+68>>2]=1954047348;c[m+(d<<8)+8>>2]=1e3;l=ARa(0)|0;n=m+(d<<8)+76|0;c[n>>2]=l;if((l|0)==0){o=-12;i=e;return o|0}c[l+8>>2]=3;do{if((Mz(f)|0)>-1){Zy(c[f>>2]|0,1);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);fz(c[f>>2]|0,0);fz(c[f>>2]|0,0);fz(c[f>>2]|0,0);fz(c[f>>2]|0,0);fz(c[f>>2]|0,0);fz(c[f>>2]|0,0);fz(c[f>>2]|0,1);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Py(c[f>>2]|0,0);Zy(c[f>>2]|0,13);Yy(c[f>>2]|0,1650553958);fz(c[f>>2]|0,1);fz(c[f>>2]|0,1);Py(c[f>>2]|0,0);l=Oz(c[f>>2]|0,h)|0;if((l|0)>0){c[(c[n>>2]|0)+96>>2]=c[h>>2];c[(c[n>>2]|0)+100>>2]=l;break}else{ZDb(h);break}}}while(0);h=b+1132|0;if((c[h>>2]|0)==0){o=0;i=e;return o|0}n=b+1136|0;f=j|0;l=j+4|0;d=k|0;m=k+4|0;p=g+16|0;q=g+8|0;r=g+48|0;s=g+28|0;t=g+24|0;u=t;v=0;while(1){w=c[(c[n>>2]|0)+(v<<2)>>2]|0;y=w+24|0;z=c[y>>2]|0;A=c[y+4>>2]|0;y=w+4|0;c[f>>2]=1;c[l>>2]=1e3;B=KDb(z,A,y,j)|0;A=F;z=w+16|0;C=c[z>>2]|0;D=c[z+4>>2]|0;c[d>>2]=1;c[m>>2]=1e3;z=KDb(C,D,y,k)|0;y=F;c[p>>2]=z;c[p+4>>2]=y;c[q>>2]=z;c[q+4>>2]=y;D=ZGb(B,A,z,y)|0;c[r>>2]=D;D=BBb(c[w+32>>2]|0,2323920,0,0)|0;if((D|0)!=0){w=D+4|0;D=SGb(c[w>>2]|0)|0;y=D+2|0;c[s>>2]=y;z=WDb(y)|0;c[t>>2]=z;if((z|0)==0){o=-12;E=12;break}y=z;x=de(D&65535|0)|0;a[y]=x;x=x>>8;a[y+1|0]=x;UGb(z+2|0,c[w>>2]|0,D)|0;yI(b,g)|0;$Db(u)}D=v+1|0;if(D>>>0<(c[h>>2]|0)>>>0){v=D}else{o=0;E=12;break}}if((E|0)==12){i=e;return o|0}return 0}function DI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;e=i;i=i+1024|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=Ty(a,0,0,1)|0;l=F;Zy(a,0);Yy(a,1987014509);m=b+16|0;n=c[m>>2]|0;if((n|0)>0){o=c[b+48>>2]|0;p=b+52|0;q=b+8|0;r=0;while(1){s=o+(r<<8)+4|0;t=c[s>>2]|0;do{if((t|0)<1){if((c[p>>2]&2|0)!=0){u=6;break}v=r+1|0}else{u=6}}while(0);do{if((u|0)==6){u=0;w=c[q+4>>2]|0;x=o+(r<<8)+16|0;c[x>>2]=c[q>>2];c[x+4>>2]=w;w=r+1|0;c[o+(r<<8)+64>>2]=w;if((t|0)==0){v=w;break}x=c[o+(r<<8)+88>>2]|0;y=c[x+16>>2]|0;c[x+24>>2]=1;z=o+(r<<8)+44|0;if((c[z>>2]|0)!=0){v=w;break}c[z>>2]=1;if((c[s>>2]|0)<=1){v=w;break}A=1;B=x;C=0;D=y;y=1;while(1){E=B|0;G=YGb(c[E>>2]|0,c[E+4>>2]|0,D,C)|0;E=x+(A*40|0)|0;H=c[x+(A*40|0)+16>>2]|0;do{if((G|0)==(c[E>>2]|0)&(F|0)==(c[E+4>>2]|0)){I=YGb(H,0,D,C)|0;J=F;K=0;if(!(J>>>0<K>>>0|J>>>0==K>>>0&I>>>0<1048576>>>0)){u=13;break}K=B+20|0;c[K>>2]=(c[K>>2]|0)+(c[x+(A*40|0)+28>>2]|0);L=J;M=I;N=B;O=y}else{u=13}}while(0);if((u|0)==13){u=0;c[x+(A*40|0)+24>>2]=(c[B+24>>2]|0)+1;E=y+1|0;c[z>>2]=E;L=0;M=H;N=x+(A*40|0)|0;O=E}E=A+1|0;if((E|0)<(c[s>>2]|0)){A=E;B=N;C=L;D=M;y=O}else{v=w;break}}}}while(0);s=c[m>>2]|0;if((v|0)<(s|0)){r=v}else{P=s;break}}}else{P=n}n=b+24|0;do{if((c[n>>2]|0)==0){Q=P}else{v=d+24|0;if((c[v>>2]|0)==0){Q=P;break}r=c[b+48>>2]|0;O=0;do{c[r+(O<<8)+104>>2]=1885431907;c[r+(O<<8)+108>>2]=c[r+(c[n>>2]<<8)+64>>2];O=O+1|0;}while(O>>>0<(c[v>>2]|0)>>>0);Q=c[m>>2]|0}}while(0);do{if((Q|0)>0){n=c[b+48>>2]|0;P=0;v=Q;while(1){if((c[n+(P<<8)+68>>2]|0)==544240754){c[n+(P<<8)+104>>2]=1953393e3;c[n+(P<<8)+108>>2]=c[n+(c[n+(P<<8)+124>>2]<<8)+64>>2];R=c[m>>2]|0}else{R=v}O=P+1|0;if((O|0)<(R|0)){P=O;v=R}else{break}}if((R|0)<=0){S=1;T=0;U=0;V=0;u=39;break}v=c[b+48>>2]|0;P=0;n=R;while(1){if((c[v+(P<<8)+68>>2]|0)==1684237684){O=c[v+(P<<8)+124>>2]|0;c[v+(O<<8)+104>>2]=1684237684;c[v+(O<<8)+108>>2]=c[v+(P<<8)+64>>2];r=v+(O<<8)+24|0;O=c[r+4>>2]|0;M=v+(P<<8)+24|0;c[M>>2]=c[r>>2];c[M+4>>2]=O;W=c[m>>2]|0}else{W=n}O=P+1|0;if((O|0)<(W|0)){P=O;n=W}else{break}}if((W|0)<=0){S=1;T=0;U=0;V=0;u=39;break}n=c[b+48>>2]|0;P=0;v=0;O=0;M=1;while(1){do{if((c[n+(P<<8)+4>>2]|0)>0){r=c[n+(P<<8)+8>>2]|0;if((r|0)==0){X=M;Y=v;Z=O;break}L=n+(P<<8)+24|0;N=HDb(c[L>>2]|0,c[L+4>>2]|0,1e3,0,r,0,3)|0;r=F;L=(v|0)<(r|0)|(v|0)==(r|0)&O>>>0<N>>>0;o=c[n+(P<<8)+64>>2]|0;X=(M|0)<(o|0)?o:M;Y=L?r:v;Z=L?N:O}else{X=M;Y=v;Z=O}}while(0);N=P+1|0;if((N|0)<(W|0)){P=N;v=Y;O=Z;M=X}else{break}}M=0;O=(Y|0)>(M|0)|(Y|0)==(M|0)&Z>>>0>-2>>>0;M=O&1;if(!O){S=X;T=Y;U=Z;V=M;u=39;break}Zy(a,120);_=X;$=Y;aa=Z;ca=1;da=M}else{S=1;T=0;U=0;V=0;u=39}}while(0);if((u|0)==39){Zy(a,108);_=S;$=T;aa=U;ca=0;da=V}Yy(a,1684567661);Py(a,da);hz(a,0);da=b+8|0;V=c[da>>2]|0;if(ca){ez(a,V,c[da+4>>2]|0);ez(a,c[da>>2]|0,c[da+4>>2]|0);Zy(a,1e3);ez(a,aa,$)}else{Zy(a,V);Zy(a,c[da>>2]|0);Zy(a,1e3);Zy(a,aa)}Zy(a,65536);fz(a,256);fz(a,0);Zy(a,0);Zy(a,0);Zy(a,65536);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,65536);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,1073741824);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,_+1|0);_=b+4|0;do{if((c[_>>2]|0)!=2){if((c[b+60>>2]|0)!=0){break}aa=Ty(a,0,0,1)|0;da=F;V=c[b+68>>2]|0;$=c[b+64>>2]|0;ca=c[m>>2]|0;if((ca|0)>0){U=c[b+48>>2]|0;T=0;S=0;Z=0;while(1){if((c[U+(Z<<8)+4>>2]|0)>0){Y=c[(c[U+(Z<<8)+76>>2]|0)+8>>2]|0;ea=(Y|0)==0|S;fa=(Y|0)==1|T}else{ea=S;fa=T}Y=Z+1|0;if((Y|0)<(ca|0)){T=fa;S=ea;Z=Y}else{ga=fa;ha=ea;break}}}else{ga=0;ha=0}Zy(a,0);Yy(a,1935961961);Zy(a,0);Py(a,16);Py(a,128);Py(a,128);Py(a,128);Py(a,7);fz(a,79);Py(a,255);Py(a,255);Py(a,(V|0)<0?255-ga|0:V);Py(a,($|0)<0?255-ha|0:$);Py(a,255);Z=Ty(a,0,0,1)|0;S=F;Ty(a,aa,da,0)|0;T=ZGb(Z,S,aa,da)|0;Zy(a,T);Ty(a,Z,S,0)|0;}}while(0);ha=c[m>>2]|0;a:do{if((ha|0)>0){ga=b+48|0;ea=d+24|0;fa=d+28|0;S=b+96|0;Z=b+52|0;T=j|0;ca=0;U=ha;while(1){Y=c[ga>>2]|0;X=Y+(ca<<8)+4|0;if((c[X>>2]|0)>0){u=56}else{if((c[Z>>2]&2|0)==0){ia=U}else{u=56}}if((u|0)==56){u=0;W=Y+(ca<<8)|0;if(ca>>>0<(c[ea>>2]|0)>>>0){ja=c[(c[fa>>2]|0)+(ca<<2)>>2]|0}else{ja=0}R=Ty(a,0,0,1)|0;Q=F;Zy(a,0);Yy(a,1801548404);M=Y+(ca<<8)+24|0;O=Y+(ca<<8)+8|0;v=HDb(c[M>>2]|0,c[M+4>>2]|0,1e3,0,c[O>>2]|0,0,3)|0;P=F;n=0;N=W|0;L=(c[N>>2]|0)==64?1:((P|0)>(n|0)|(P|0)==(n|0)&v>>>0>2147483646>>>0)&1;n=(L|0)==1;if(n){Zy(a,104)}else{Zy(a,92)}Yy(a,1684564852);Py(a,L);hz(a,(c[Y+(ca<<8)+52>>2]|0)>>>2&1|2);L=Y+(ca<<8)+16|0;r=c[L>>2]|0;if(n){ez(a,r,c[L+4>>2]|0);ez(a,c[L>>2]|0,c[L+4>>2]|0)}else{Zy(a,r);Zy(a,c[L>>2]|0)}r=Y+(ca<<8)+64|0;Zy(a,c[r>>2]|0);Zy(a,0);do{if((c[X>>2]|0)==0){if(n){ez(a,-1,-1);break}else{Zy(a,-1);break}}else{if(n){ez(a,v,P);break}else{Zy(a,v);break}}}while(0);Zy(a,0);Zy(a,0);fz(a,0);v=(ja|0)!=0;if(v){ka=c[(c[ja+8>>2]|0)+8>>2]|0}else{ka=0}fz(a,ka);P=Y+(ca<<8)+76|0;if((c[(c[P>>2]|0)+8>>2]|0)==1){fz(a,256)}else{fz(a,0)}fz(a,0);do{if(v){n=c[ja+88>>2]|0;do{if((n|0)==0){u=84}else{o=BBb(n,2133512,0,0)|0;if((o|0)==0){u=84;break}q=c[o+4>>2]|0;if((q|0)==0){u=84;break}o=gd(q|0)|0;if((o|0)==90){q=c[(c[P>>2]|0)+124>>2]|0;Zy(a,0);Zy(a,65536);Zy(a,0);Zy(a,-65536);Zy(a,0);Zy(a,0);Zy(a,q<<16);Zy(a,0);Zy(a,1073741824);break}else if((o|0)==180){q=c[P>>2]|0;p=c[q+120>>2]|0;s=c[q+124>>2]|0;Zy(a,-65536);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,-65536);Zy(a,0);Zy(a,p<<16);Zy(a,s<<16);Zy(a,1073741824);break}else if((o|0)==270){o=c[(c[P>>2]|0)+120>>2]|0;Zy(a,0);Zy(a,-65536);Zy(a,0);Zy(a,65536);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,o<<16);Zy(a,1073741824);break}else{u=84;break}}}while(0);if((u|0)==84){u=0;Zy(a,65536);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,65536);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,1073741824)}n=c[P>>2]|0;H=c[n+8>>2]|0;if(!((H|0)==0|(H|0)==3)){u=93;break}if((c[N>>2]|0)==2){Zy(a,c[n+120>>2]<<16);Zy(a,c[Y+(ca<<8)+100>>2]<<16);break}la=+(c[ja+80>>2]|0)/+(c[ja+84>>2]|0);H=Y+(ca<<8)+100|0;if(la!=0.0){if((c[H>>2]|0)==(c[n+124>>2]|0)){ma=la}else{u=90}}else{u=90}if((u|0)==90){u=0;ma=1.0}Zy(a,~~(ma*+(c[n+120>>2]|0)*65536.0));Zy(a,c[H>>2]<<16)}else{Zy(a,65536);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,65536);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,1073741824);u=93}}while(0);if((u|0)==93){u=0;Zy(a,0);Zy(a,0)}v=c[S>>2]|0;if((v|0)<0){if((c[Z>>2]&2|0)==0){u=97}}else{if((v|0)>0){u=97}}if((u|0)==97){u=0;v=c[O>>2]|0;H=0;n=HDb(c[M>>2]|0,c[M+4>>2]|0,1e3,0,v,H,3)|0;o=F;s=0;p=Y+(ca<<8)+88|0;q=c[p>>2]|0;t=c[q+32>>2]|0;w=t;y=(t|0)<0|0?-1:0;t=q+8|0;q=YGb(c[t>>2]|0,c[t+4>>2]|0,w,y)|0;t=HDb(q,F,1e3,0,v,H,2)|0;H=F;v=0;q=((H|0)>(v|0)|(H|0)==(v|0)&t>>>0>2147483646>>>0)&1|((o|0)>(s|0)|(o|0)==(s|0)&n>>>0>2147483646>>>0)&1;s=(q|0)==1;v=0;D=(H|0)>(v|0)|(H|0)==(v|0)&t>>>0>0>>>0;v=D?2:1;C=ba(s?20:12,v)|0;Zy(a,C+24|0);Yy(a,1937007717);Zy(a,C+16|0);Yy(a,1953721445);Py(a,q);hz(a,0);Zy(a,v);if(D){if(s){ez(a,t,H);ez(a,-1,-1)}else{Zy(a,t);Zy(a,-1)}Zy(a,65536);na=y;oa=w;pa=o;qa=n}else{w=(c[p>>2]|0)+8|0;p=c[w>>2]|0;y=c[w+4>>2]|0;w=HDb(p,y,1e3,0,c[O>>2]|0,0,2)|0;D=F;v=0;if(!((D|0)<(v|0)|(D|0)==(v|0)&w>>>0<1>>>0)){break}w=0;v=(y|0)>(w|0)|(y|0)==(w|0)&p>>>0>0>>>0;w=ZGb(0,0,p,y)|0;y=v?0:F;p=YGb(t,H,n,o)|0;na=y;oa=v?0:w;pa=F;qa=p}if(s){ez(a,qa,pa);ez(a,oa,na)}else{Zy(a,qa);Zy(a,oa)}Zy(a,65536)}s=Y+(ca<<8)+104|0;if((c[s>>2]|0)!=0){Zy(a,20);Yy(a,1717924468);Zy(a,12);Yy(a,c[s>>2]|0);Zy(a,c[Y+(ca<<8)+108>>2]|0)}s=Ty(a,0,0,1)|0;p=F;Zy(a,0);Yy(a,1634296941);w=c[M+4>>2]|0;v=0;y=(c[N>>2]|0)==64?1:((w|0)>(v|0)|(w|0)==(v|0)&(c[M>>2]|0)>>>0>2147483646>>>0)&1;v=(y|0)==1;if(v){Zy(a,44)}else{Zy(a,32)}Yy(a,1684563053);Py(a,y);hz(a,0);w=c[L>>2]|0;if(v){ez(a,w,c[L+4>>2]|0);ez(a,c[L>>2]|0,c[L+4>>2]|0)}else{Zy(a,w);Zy(a,c[L>>2]|0)}Zy(a,c[O>>2]|0);do{if((c[X>>2]|0)==0){if(v){ez(a,-1,-1);break}else{Zy(a,-1);break}}else{w=c[M>>2]|0;if(v){ez(a,w,c[M+4>>2]|0);break}else{Zy(a,w);break}}}while(0);fz(a,c[Y+(ca<<8)+60>>2]|0);fz(a,0);do{if((y|0)!=0){if((c[N>>2]|0)!=2){break}yDb(0,16,2136072,(ra=i,i=i+1|0,i=i+7&-8,c[ra>>2]=0,ra)|0);i=ra}}while(0);PI(a,W);y=Ty(a,0,0,1)|0;M=F;Zy(a,0);Yy(a,1718511981);v=c[(c[P>>2]|0)+8>>2]|0;do{if((v|0)==0){Zy(a,20);Yy(a,1684565366);Zy(a,1);ez(a,0,0)}else if((v|0)==1){Zy(a,16);Yy(a,1684565363);Zy(a,0);fz(a,0);fz(a,0)}else{X=c[Y+(ca<<8)+68>>2]|0;if((v|0)==3){if((X|0)==1954047348|(X|0)==942683747){QI(a,W);break}else{Zy(a,12);Yy(a,1684565358);Zy(a,0);break}}else{if((X|0)==544240754){Zy(a,28);Yy(a,1684565352);Zy(a,0);fz(a,0);fz(a,0);Zy(a,0);Zy(a,0);Zy(a,0);break}else if((X|0)==1684237684){QI(a,W);break}else{break}}}}while(0);if((c[N>>2]|0)==2){PI(a,0)}v=Ty(a,0,0,1)|0;X=F;Zy(a,0);Yy(a,1718511972);Zy(a,28);Yy(a,1717924452);Zy(a,0);Zy(a,1);Zy(a,12);Yy(a,543978101);Zy(a,1);O=Ty(a,0,0,1)|0;L=F;Ty(a,v,X,0)|0;w=ZGb(O,L,v,X)|0;Zy(a,w);Ty(a,O,L,0)|0;RI(a,W);L=Ty(a,0,0,1)|0;O=F;Ty(a,y,M,0)|0;w=ZGb(L,O,y,M)|0;Zy(a,w);Ty(a,L,O,0)|0;O=Ty(a,0,0,1)|0;L=F;Ty(a,s,p,0)|0;w=ZGb(O,L,s,p)|0;Zy(a,w);Ty(a,O,L,0)|0;if((c[N>>2]|0)==8){Zy(a,52);Yy(a,1684632949);Yy(a,1414353749);Zy(a,567431118);Zy(a,-1148688036);Zy(a,-87439552);Zy(a,28);Yy(a,1413764173);Zy(a,65554);Zy(a,10);Zy(a,1438908416);Zy(a,1);Zy(a,0)}if((c[Y+(ca<<8)+68>>2]|0)==544240754){L=c[Y+(ca<<8)+128>>2]|0;TGb(T|0,0,1e3)|0;_P(T,1e3,c[c[L+28>>2]>>2]|0,c[Y+(ca<<8)+124>>2]|0,0,0,0,0,L);uAb(T,1e3,2204784,(ra=i,i=i+8|0,c[ra>>2]=c[r>>2],ra)|0)|0;i=ra;L=SGb(T|0)|0;Zy(a,L+24|0);Yy(a,1635017845);Zy(a,L+16|0);Yy(a,1769238120);Zy(a,L+8|0);Yy(a,544236659);Ry(a,T,L)}L=c[P>>2]|0;do{if((c[L+8>>2]|0)==0){if((c[N>>2]|0)!=2){break}O=c[ja+80>>2]|0;if(!((O|0)!=0&+(O|0)/+(c[ja+84>>2]|0)!=1.0)){break}O=c[L+224>>2]|0;w=c[L+120>>2]|0;X=c[L+228>>2]|0;v=IDb(O,(O|0)<0|0?-1:0,w,(w|0)<0|0?-1:0,X,(X|0)<0|0?-1:0)|0;X=Ty(a,0,0,1)|0;w=F;Zy(a,0);Yy(a,1953522036);Zy(a,20);Yy(a,1717922915);Zy(a,0);O=v<<16;Zy(a,O);Zy(a,c[(c[P>>2]|0)+124>>2]<<16);Zy(a,20);Yy(a,1718579824);Zy(a,0);Zy(a,O);Zy(a,c[(c[P>>2]|0)+124>>2]<<16);Zy(a,20);Yy(a,1718578789);Zy(a,0);Zy(a,c[(c[P>>2]|0)+120>>2]<<16);Zy(a,c[(c[P>>2]|0)+124>>2]<<16);O=Ty(a,0,0,1)|0;v=F;Ty(a,X,w,0)|0;o=ZGb(O,v,X,w)|0;Zy(a,o);Ty(a,O,v,0)|0;}}while(0);P=Ty(a,0,0,1)|0;L=F;Ty(a,R,Q,0)|0;N=ZGb(P,L,R,Q)|0;Zy(a,N);Ty(a,P,L,0)|0;ia=c[m>>2]|0}L=ca+1|0;if((L|0)<(ia|0)){ca=L;U=ia}else{sa=Z;break a}}yDb(0,0,2345536,(ra=i,i=i+24|0,c[ra>>2]=2134128,c[ra+8>>2]=2342720,c[ra+16>>2]=1872,ra)|0);i=ra;Cd()}else{sa=b+52|0}}while(0);if((c[sa>>2]&2|0)!=0){sa=Ty(a,0,0,1)|0;ra=F;Zy(a,0);Yy(a,2019915373);if((c[m>>2]|0)>0){ia=b+48|0;ja=0;do{oa=c[ia>>2]|0;Zy(a,32);Yy(a,2019914356);Zy(a,0);Zy(a,c[oa+(ja<<8)+64>>2]|0);Zy(a,1);Zy(a,0);Zy(a,0);Zy(a,0);ja=ja+1|0;}while((ja|0)<(c[m>>2]|0))}m=Ty(a,0,0,1)|0;ja=F;Ty(a,sa,ra,0)|0;ia=ZGb(m,ja,sa,ra)|0;Zy(a,ia);Ty(a,m,ja,0)|0;}if((c[_>>2]|0)==8){ja=BBb(c[d+1140>>2]|0,2323920,0,0)|0;if((ja|0)==0){ta=0;ua=0;va=Ty(a,ta,ua,1)|0;wa=F;xa=Ty(a,k,l,0)|0;ya=F;za=ZGb(va,wa,k,l)|0;Aa=F;Ba=za;Ca=Ba;Zy(a,Ca);Da=Ty(a,va,wa,0)|0;Ea=F;i=e;return}m=Ty(a,0,0,1)|0;ia=F;Zy(a,0);Yy(a,1684632949);Yy(a,1414353749);Zy(a,567431118);Zy(a,-1148688036);Zy(a,-87439552);ra=Ty(a,0,0,1)|0;sa=F;Zy(a,0);Yy(a,1413764173);fz(a,4);fz(a,12);Zy(a,11);fz(a,21956);fz(a,0);fz(a,540);OI(a,2213592,2215656,4);OI(a,c[ja+4>>2]|0,2215656,1);OI(a,2212824,2221296,3);ja=Ty(a,0,0,1)|0;oa=F;Ty(a,ra,sa,0)|0;qa=ZGb(ja,oa,ra,sa)|0;Zy(a,qa);Ty(a,ja,oa,0)|0;oa=Ty(a,0,0,1)|0;ja=F;Ty(a,m,ia,0)|0;qa=ZGb(oa,ja,m,ia)|0;Zy(a,qa);Ty(a,oa,ja,0)|0;ta=0;ua=0;va=Ty(a,ta,ua,1)|0;wa=F;xa=Ty(a,k,l,0)|0;ya=F;za=ZGb(va,wa,k,l)|0;Aa=F;Ba=za;Ca=Ba;Zy(a,Ca);Da=Ty(a,va,wa,0)|0;Ea=F;i=e;return}ja=c[d+24>>2]|0;oa=b+48|0;b=0;while(1){if(!(b>>>0<ja>>>0)){break}if((c[(c[(c[oa>>2]|0)+(b<<8)+76>>2]|0)+88>>2]&8388608|0)==0){b=b+1|0}else{u=182;break}}if((u|0)==182){ta=0;ua=0;va=Ty(a,ta,ua,1)|0;wa=F;xa=Ty(a,k,l,0)|0;ya=F;za=ZGb(va,wa,k,l)|0;Aa=F;Ba=za;Ca=Ba;Zy(a,Ca);Da=Ty(a,va,wa,0)|0;Ea=F;i=e;return}if((Mz(g)|0)<0){ta=0;ua=0;va=Ty(a,ta,ua,1)|0;wa=F;xa=Ty(a,k,l,0)|0;ya=F;za=ZGb(va,wa,k,l)|0;Aa=F;Ba=za;Ca=Ba;Zy(a,Ca);Da=Ty(a,va,wa,0)|0;Ea=F;i=e;return}u=c[_>>2]|0;do{if((u&4|0)==0){_=c[g>>2]|0;if((u|0)==2){KI(d,_,2296456,2331080,0)|0;KI(d,c[g>>2]|0,2295208,2323920,0)|0;KI(d,c[g>>2]|0,2294064,2320160,0)|0;KI(d,c[g>>2]|0,2292920,2306664,0)|0;KI(d,c[g>>2]|0,2291536,2297936,0)|0;KI(d,c[g>>2]|0,2288472,2284560,0)|0;KI(d,c[g>>2]|0,2283352,2313128,0)|0;KI(d,c[g>>2]|0,2281864,2313128,0)|0;KI(d,c[g>>2]|0,2280800,2316448,0)|0;KI(d,c[g>>2]|0,2279536,2300848,0)|0;break}b=Ty(_,0,0,1)|0;oa=F;Zy(_,0);Yy(_,1635018093);Zy(_,0);Zy(_,33);Yy(_,1919706216);Zy(_,0);Zy(_,0);Yy(_,1919509613);Yy(_,1819308129);Zy(_,0);Zy(_,0);Py(_,0);ja=Ty(_,0,0,1)|0;qa=F;Zy(_,0);Yy(_,1953721449);KI(d,_,2295208,2323920,1)|0;KI(d,_,2296456,2331080,1)|0;KI(d,_,2272200,2269152,1)|0;KI(d,_,2268096,2266736,1)|0;KI(d,_,2292920,2306664,1)|0;KI(d,_,2291536,2297936,1)|0;if((KI(d,_,2265640,2264280,1)|0)==0){LI(_,2265640,2263312,0,1)|0}KI(d,_,2281864,2313128,1)|0;KI(d,_,2280800,2316448,1)|0;KI(d,_,2279536,2300848,1)|0;KI(d,_,2261920,2260720,1)|0;KI(d,_,2259776,2256936,1)|0;KI(d,_,2253624,2252560,1)|0;KI(d,_,2251360,2250568,1)|0;KI(d,_,2249320,2248280,1)|0;KI(d,_,2247328,2246328,1)|0;KI(d,_,2245328,2242560,1)|0;MI(d,_,2239456,2238408,4);MI(d,_,2237688,2236800,4);MI(d,_,2236040,2235384,1);MI(d,_,2234536,2233648,1);MI(d,_,2232816,2230120,1);ia=d+1140|0;NI(_,c[ia>>2]|0,0);NI(_,c[ia>>2]|0,1);m=BBb(c[ia>>2]|0,2227528,0,0)|0;do{if((m|0)!=0){ia=gd(c[m+4>>2]|0)|0;if((ia|0)==0){break}Zy(_,26);Yy(_,1869639028);Zy(_,18);Yy(_,1635017060);Zy(_,21);Zy(_,0);fz(_,ia)}}while(0);m=Ty(_,0,0,1)|0;ia=F;Ty(_,ja,qa,0)|0;sa=ZGb(m,ia,ja,qa)|0;Zy(_,sa);Ty(_,m,ia,0)|0;ia=Ty(_,0,0,1)|0;m=F;Ty(_,b,oa,0)|0;sa=ZGb(ia,m,b,oa)|0;Zy(_,sa);Ty(_,ia,m,0)|0;}else{JI(c[g>>2]|0,d,2335976,2331080);JI(c[g>>2]|0,d,2325984,2323920);JI(c[g>>2]|0,d,2321760,2320160);JI(c[g>>2]|0,d,2318560,2316448);JI(c[g>>2]|0,d,2314600,2313128);JI(c[g>>2]|0,d,2311168,2306664);JI(c[g>>2]|0,d,2302392,2300848);JI(c[g>>2]|0,d,2299456,2297936)}}while(0);u=d+1132|0;if((c[u>>2]|0)!=0){m=c[g>>2]|0;ia=Ty(m,0,0,1)|0;sa=F;ra=c[u>>2]|0;u=ra>>>0>255>>>0?255:ra;Zy(m,0);Yy(m,1819306083);Zy(m,16777216);Zy(m,0);Py(m,u);if((u|0)>0){ra=d+1136|0;d=f|0;na=f+4|0;pa=0;do{ka=c[(c[ra>>2]|0)+(pa<<2)>>2]|0;ha=ka+16|0;j=c[ha>>2]|0;Z=c[ha+4>>2]|0;c[d>>2]=1;c[na>>2]=1e7;ha=KDb(j,Z,ka+4|0,f)|0;ez(m,ha,F);ha=BBb(c[ka+32>>2]|0,2323920,0,0)|0;if((ha|0)==0){Py(m,0)}else{ka=ha+4|0;ha=SGb(c[ka>>2]|0)|0;Z=ha>>>0>255>>>0?255:ha;Py(m,Z);Ry(m,c[ka>>2]|0,Z)}pa=pa+1|0;}while((pa|0)<(u|0))}u=Ty(m,0,0,1)|0;pa=F;Ty(m,ia,sa,0)|0;f=ZGb(u,pa,ia,sa)|0;Zy(m,f);Ty(m,u,pa,0)|0;}pa=Oz(c[g>>2]|0,h)|0;if((pa|0)>0){Zy(a,pa+8|0);Yy(a,1635017845);Ry(a,c[h>>2]|0,pa)}ZDb(c[h>>2]|0);ta=0;ua=0;va=Ty(a,ta,ua,1)|0;wa=F;xa=Ty(a,k,l,0)|0;ya=F;za=ZGb(va,wa,k,l)|0;Aa=F;Ba=za;Ca=Ba;Zy(a,Ca);Da=Ty(a,va,wa,0)|0;Ea=F;i=e;return}function EI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=a+12|0;j=c[h>>2]|0;k=j;l=j+52|0;m=c[l>>2]|0;if((m&2|0)==0){i=b;return}do{if((m&4|0)==0){n=j+72|0;if((c[n>>2]|0)!=0){break}o=a+16|0;p=Ty(c[o>>2]|0,0,0,1)|0;q=F;r=j+48|0;s=j+16|0;t=c[s>>2]|0;u=0;while(1){if((u|0)>=(t|0)){break}if((c[(c[r>>2]|0)+(u<<8)+4>>2]|0)==0){v=55;break}else{u=u+1|0}}if((v|0)==55){i=b;return}u=c[h>>2]|0;t=Pz(e)|0;if((t|0)<0){w=t}else{DI(c[e>>2]|0,u,a);w=Rz(c[e>>2]|0)|0}u=c[s>>2]|0;if((u|0)>0){t=YGb(p,q,8,0)|0;x=YGb(t,F,w,(w|0)<0|0?-1:0)|0;t=F;y=c[r>>2]|0;z=0;do{A=y+(z<<8)+184|0;c[A>>2]=x;c[A+4>>2]=t;z=z+1|0;}while((z|0)<(u|0))}DI(c[o>>2]|0,k,a);u=j+92|0;z=Oz(c[u>>2]|0,f)|0;c[u>>2]=0;Zy(c[o>>2]|0,z+8|0);Yy(c[o>>2]|0,1952539757);Ry(c[o>>2]|0,c[f>>2]|0,z);ZDb(c[f>>2]|0);c[n>>2]=(c[n>>2]|0)+1;z=j+40|0;c[z>>2]=0;c[z+4>>2]=0;if((c[s>>2]|0)>0){z=c[r>>2]|0;u=0;do{t=z+(u<<8)+4|0;if((c[t>>2]|0)!=0){x=z+(u<<8)+112|0;y=z+(u<<8)+24|0;q=YGb(c[y>>2]|0,c[y+4>>2]|0,c[x>>2]|0,c[x+4>>2]|0)|0;x=(c[z+(u<<8)+88>>2]|0)+8|0;y=ZGb(q,F,c[x>>2]|0,c[x+4>>2]|0)|0;x=z+(u<<8)+192|0;q=YGb(y,F,c[x>>2]|0,c[x+4>>2]|0)|0;c[x>>2]=q;c[x+4>>2]=F}c[t>>2]=0;u=u+1|0;}while((u|0)<(c[s>>2]|0))}Sy(c[o>>2]|0);i=b;return}}while(0);f=j+16|0;if((c[f>>2]|0)<=0){i=b;return}w=j+48|0;e=0;h=0;s=-1;u=0;z=m;while(1){m=c[w>>2]|0;r=(z&16|0)==0;n=m+(u<<8)+184|0;c[n>>2]=r?h:0;c[n+4>>2]=r?e:0;r=c[m+(u<<8)+180>>2]|0;if((r|0)==0){B=s;C=e;D=h}else{m=Ty(r,0,0,1)|0;r=YGb(m,F,h,e)|0;B=(s|0)<0?u:s;C=F;D=r}r=u+1|0;E=c[f>>2]|0;if((r|0)>=(E|0)){break}e=C;h=D;s=B;u=r;z=c[l>>2]|0}if((D|0)==0&(C|0)==0){i=b;return}a:do{if((E|0)>0){z=j+48|0;u=a+16|0;s=j+88|0;h=j+72|0;e=C;w=D;r=0;while(1){m=c[z>>2]|0;n=m+(r<<8)+4|0;t=c[n>>2]|0;if((t|0)==0){G=0;H=0}else{x=m+(r<<8)+112|0;q=m+(r<<8)+24|0;y=YGb(c[q>>2]|0,c[q+4>>2]|0,c[x>>2]|0,c[x+4>>2]|0)|0;x=(c[m+(r<<8)+88>>2]|0)+8|0;q=ZGb(y,F,c[x>>2]|0,c[x+4>>2]|0)|0;G=F;H=q}do{if((c[l>>2]&16|0)==0){if((r|0)==(B|0)){I=e;J=w;K=-1;v=34}else{L=e;M=w;N=t;v=49}}else{q=c[m+(r<<8)+180>>2]|0;if((q|0)==0){O=e;P=w;break}x=Ty(q,0,0,1)|0;I=F;J=x;K=r;v=34}}while(0);if((v|0)==34){v=0;Sy(c[u>>2]|0);t=m+(r<<8)+208|0;x=c[t>>2]|0;q=x+1|0;c[t>>2]=q;y=m+(r<<8)+216|0;if(q>>>0<(c[y>>2]|0)>>>0){Q=q;R=m+(r<<8)+212|0}else{q=x+65|0;x=m+(r<<8)+212|0;if((bEb(x,q,32)|0)!=0){break}c[y>>2]=q;Q=c[t>>2]|0;R=x}x=Q-1|0;q=c[R>>2]|0;y=Ty(c[u>>2]|0,0,0,1)|0;p=q+(x<<5)|0;c[p>>2]=y;c[p+4>>2]=F;p=(c[z>>2]|0)+(r<<8)+192|0;y=c[p+4>>2]|0;A=q+(x<<5)+8|0;c[A>>2]=c[p>>2];c[A+4>>2]=y;y=q+(x<<5)+16|0;c[y>>2]=H;c[y+4>>2]=G;y=c[u>>2]|0;A=Ty(y,0,0,1)|0;p=F;S=c[s>>2]|0;if((S|0)>0){T=0;U=S;while(1){S=c[t>>2]|0;V=-2-T+S|0;W=S+~V|0;do{if((V|0)<0){X=U}else{S=(c[R>>2]|0)+(V<<5)+24|0;Ty(y,c[S>>2]|0,c[S+4>>2]|0,0)|0;Zy(y,(W<<4)+29|0);Yy(y,1684632949);Ry(y,671752,16);Py(y,1);hz(y,0);Py(y,W);if((W|0)>0){S=V+1|0;Y=0;do{Z=S+Y|0;_=(c[R>>2]|0)+(Z<<5)+8|0;ez(y,c[_>>2]|0,c[_+4>>2]|0);_=(c[R>>2]|0)+(Z<<5)+16|0;ez(y,c[_>>2]|0,c[_+4>>2]|0);Y=Y+1|0;}while((Y|0)<(W|0))}Y=c[s>>2]|0;if((W|0)>=(Y|0)){X=Y;break}S=Y-W<<4;Zy(y,S);Yy(y,1701147238);Qy(y,0,S-8|0);X=c[s>>2]|0}}while(0);W=T+1|0;if((W|0)<(X|0)){T=W;U=X}else{break}}}Ty(y,A,p,0)|0;U=c[u>>2]|0;if((Pz(d)|0)>=0){HI(c[d>>2]|0,k,K,0)|0;HI(U,k,K,Rz(c[d>>2]|0)|0)|0}U=m+(r<<8)+200|0;T=c[U+4>>2]|0;t=q+(x<<5)+24|0;c[t>>2]=c[U>>2];c[t+4>>2]=T;c[h>>2]=(c[h>>2]|0)+1;T=c[u>>2]|0;t=YGb(J,I,8,0)|0;Zy(T,t);Yy(c[u>>2]|0,1952539757);L=I;M=J;N=c[n>>2]|0;v=49}do{if((v|0)==49){v=0;if((N|0)!=0){t=m+(r<<8)+192|0;T=YGb(c[t>>2]|0,c[t+4>>2]|0,H,G)|0;c[t>>2]=T;c[t+4>>2]=F}c[n>>2]=0;t=m+(r<<8)+180|0;T=c[t>>2]|0;if((T|0)==0){O=L;P=M;break}U=Oz(T,g)|0;c[t>>2]=0;Ry(c[u>>2]|0,c[g>>2]|0,U);ZDb(c[g>>2]|0);O=L;P=M}}while(0);m=r+1|0;if((m|0)<(c[f>>2]|0)){e=O;w=P;r=m}else{$=u;break a}}i=b;return}else{$=a+16|0}}while(0);a=j+40|0;c[a>>2]=0;c[a+4>>2]=0;Sy(c[$>>2]|0);i=b;return}function FI(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;g=b+84|0;h=c[b+80>>2]|0;j=(c[g>>2]|0)+h|0;k=c[b+240>>2]|0;l=c[b+244>>2]|0;m=c[b+248>>2]|0;n=b+112|0;o=c[n>>2]|0;p=c[n+4>>2]|0;n=cEb(h+16|0)|0;if((n|0)==0){q=-12;i=f;return q|0}h=c[g>>2]|0;g=j;a:do{if((g-h|0)>=4){r=-1;s=h;while(1){if(!(s>>>0<j>>>0)){break a}t=r<<8;if((t|0)==256){break}else{r=d[s]|t;s=s+1|0}}r=s-3|0;if(r>>>0<j>>>0){u=0;v=0;w=0;y=r}else{break}b:while(1){r=y;while(1){t=r+4|0;c:do{if((g-t|0)<4){z=j}else{A=-1;B=t;while(1){if(!(B>>>0<j>>>0)){z=j;break c}C=A<<8;if((C|0)==256){break}else{A=d[B]|C;B=B+1|0}}z=B-3|0}}while(0);A=z-r|0;C=A-4|0;if((C|0)>=1){if((C|0)<4){D=t;E=n;F=0;while(1){a[E]=a[D]|0;G=F+1|0;if((G|0)<(C|0)){D=D+1|0;E=E+1|0;F=G}else{H=C;break}}}else{F=A-5|0;E=t;D=0;G=0;while(1){I=a[E]|0;do{if(I<<24>>24==3&(G|0)>1){if((a[E-1|0]|0)!=0){J=20;break}if(!((a[E-2|0]|0)==0&(G|0)<(F|0))){J=20;break}K=E+1|0;L=a[K]|0;if(!((L&255)>>>0<4>>>0)){J=20;break}a[n+D|0]=L;M=G+1|0;N=K}else{J=20}}while(0);if((J|0)==20){J=0;a[n+D|0]=I;M=G;N=E}B=D+1|0;K=M+1|0;if((K|0)<(C|0)){E=N+1|0;D=B;G=K}else{H=B;break}}}O=H<<3;P=O>>>0>2147483639>>>0;G=r;if((d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)==251723776){break}}if(z>>>0<j>>>0){r=z}else{J=29;break b}}r=P?0:n;G=P?8:O+8|0;D=r;E=G>>>0>2>>>0?2:G;if(((d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24)&192|0)!=192){J=25;break}D=r+(E>>>3)|0;C=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&2)>>>29;D=E+3|0;E=G>>>0>D>>>0?D:G;D=-E|0;F=G-E|0;if((D|0)>35){Q=D}else{Q=(F|0)<35?F:35}F=E+1+Q|0;E=G>>>0>F>>>0?F:G;G=d[r+(E>>>3)|0]<<(E&7)>>>7&1;if(z>>>0<j>>>0){u=1;v=C;w=G;y=z}else{R=G;S=C;break}}if((J|0)==25){ZDb(n);q=-38;i=f;return q|0}else if((J|0)==29){if((u|0)==0){break}else{R=w;S=v}}s=(o|0)!=0|(p|0)!=(-2147483648|0);C=c[(c[b+76>>2]|0)+108>>2]|0;G=e;x=fe((((((R|((S<<4|S)<<8|393216))<<1|(k|0)==0&s&1)<<1|(l|0)==0&s&1)<<1|(m|0)==0)<<10|C>>>24)^8192|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;G=C<<8;s=C>>>16&255;C=8;E=e+4|0;while(1){a[E]=s;r=G;G=r<<8;F=C+8|0;if((F|0)<32){s=r>>>16&255;C=F;E=E+1|0}else{break}}G=0;ZDb(n);q=0;i=f;return q|0}}while(0);ZDb(n);q=-38;i=f;return q|0}function GI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+24|0;d=c[b>>2]|0;e=a+48|0;if((d|0)!=0){f=e;g=c[f>>2]|0;h=c[g+(d<<8)+76>>2]|0;if((h|0)==0){i=d;j=g}else{$Db(h+96|0);i=c[b>>2]|0;j=c[f>>2]|0}$Db(j+(i<<8)+76|0)}i=a+16|0;if((c[i>>2]|0)<=0){$Db(e);return}j=e;f=a+20|0;a=0;do{b=c[j>>2]|0;h=c[b+(a<<8)+68>>2]|0;do{if((h|0)==544240754){ZI(b+(a<<8)|0)}else if((h|0)==1684237684){if((c[f>>2]|0)==0){break}$Db(b+(a<<8)+76|0)}}while(0);$Db((c[j>>2]|0)+(a<<8)+88|0);$Db((c[j>>2]|0)+(a<<8)+212|0);b=c[j>>2]|0;if((c[b+(a<<8)+80>>2]|0)!=0){$Db(b+(a<<8)+84|0)}a=a+1|0;}while((a|0)<(c[i>>2]|0));$Db(e);return}function HI(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=Ty(a,0,0,1)|0;g=F;Zy(a,0);Yy(a,1718579053);Zy(a,16);Yy(a,1684563565);Zy(a,0);Zy(a,c[b+72>>2]|0);h=b+16|0;i=c[h>>2]|0;if((i|0)<=0){j=0;k=0;l=Ty(a,j,k,1)|0;m=F;n=Ty(a,f,g,0)|0;o=F;p=ZGb(l,m,f,g)|0;q=F;r=p;s=r;Zy(a,s);t=Ty(a,l,m,0)|0;u=F;return s|0}v=b+48|0;w=(d|0)<0;x=b+52|0;y=e+8|0;e=0;z=b+4|0;A=b+88|0;b=0;B=i;while(1){i=c[v>>2]|0;C=i+(b<<8)|0;do{if(w|(b|0)==(d|0)){D=i+(b<<8)+4|0;if((c[D>>2]|0)==0){E=B;break}G=Ty(a,0,0,1)|0;H=F;Zy(a,0);Yy(a,1717662324);I=Ty(a,0,0,1)|0;J=F;K=(c[D>>2]|0)==0?65561:57;L=(c[x>>2]&256|0)==0?K:K&65592;K=(c[C>>2]|0)==64?L&65568:L;Zy(a,0);Yy(a,1684563572);Py(a,0);hz(a,K);L=i+(b<<8)+64|0;Zy(a,c[L>>2]|0);if((K&1|0)!=0){ez(a,f,g)}if((K&8|0)!=0){M=II(C,0)|0;N=i+(b<<8)+152|0;c[N>>2]=M;c[N+4>>2]=(M|0)<0|0?-1:0;Zy(a,M)}if((K&16|0)==0){c[i+(b<<8)+164>>2]=-1}else{if((c[D>>2]|0)==0){O=1}else{O=c[(c[i+(b<<8)+88>>2]|0)+16>>2]|0}c[i+(b<<8)+164>>2]=O;Zy(a,O)}if((K&32|0)!=0){K=(c[(c[i+(b<<8)+76>>2]|0)+8>>2]|0)==0?16842752:33554432;c[i+(b<<8)+160>>2]=K;Zy(a,K)}K=Ty(a,0,0,1)|0;M=F;Ty(a,I,J,0)|0;N=ZGb(K,M,I,J)|0;Zy(a,N);Ty(a,K,M,0)|0;M=Ty(a,0,0,1)|0;K=F;if((c[D>>2]|0)>0){N=i+(b<<8)+152|0;J=i+(b<<8)+88|0;I=i+(b<<8)+164|0;P=i+(b<<8)+160|0;Q=1;R=0;while(1){S=II(C,R)|0;T=(S|0)==(c[N>>2]|0)&(((S|0)<0|0?-1:0)|0)==(c[N+4>>2]|0)?Q:Q|256;S=c[J>>2]|0;U=(c[S+(R*40|0)+16>>2]|0)==(c[I>>2]|0)?T:T|512;if((R|0)>0){V=(((c[S+(R*40|0)+36>>2]&1|0)!=0?33554432:16842752)|0)==(c[P>>2]|0)?U:U|1024}else{V=U}U=R+1|0;if((U|0)<(c[D>>2]|0)){Q=V;R=U}else{W=V;break}}}else{W=1}R=(W&1024|0)==0?W|4:W;Q=(c[i+(b<<8)+52>>2]&1|0)==0?R:R|2048;Zy(a,0);Yy(a,1853190772);Py(a,0);hz(a,Q);Zy(a,c[D>>2]|0);do{if((c[x>>2]&272|0)==256){if((c[L>>2]|0)==1){X=24;break}Zy(a,0)}else{X=24}}while(0);if((X|0)==24){X=0;L=i+(b<<8)+184|0;R=YGb(c[L>>2]|0,c[L+4>>2]|0,y,e)|0;L=c[i+(b<<8)+88>>2]|0;P=YGb(R,F,c[L>>2]|0,c[L+4>>2]|0)|0;Zy(a,P)}if((Q&4|0)!=0){Zy(a,(c[(c[i+(b<<8)+88>>2]|0)+36>>2]&1|0)!=0?33554432:16842752)}if((c[D>>2]|0)>0){P=(Q&256|0)==0;L=(Q&512|0)==0;R=(Q&1024|0)==0;I=(Q&2048|0)==0;J=i+(b<<8)+88|0;N=0;do{if(!P){Zy(a,II(C,N)|0)}if(!L){Zy(a,c[(c[J>>2]|0)+(N*40|0)+16>>2]|0)}if(!R){Zy(a,(c[(c[J>>2]|0)+(N*40|0)+36>>2]&1|0)!=0?33554432:16842752)}if(!I){Zy(a,c[(c[J>>2]|0)+(N*40|0)+32>>2]|0)}N=N+1|0;}while((N|0)<(c[D>>2]|0))}D=Ty(a,0,0,1)|0;N=F;Ty(a,M,K,0)|0;J=ZGb(D,N,M,K)|0;Zy(a,J);Ty(a,D,N,0)|0;do{if((c[z>>2]|0)==64){N=Ty(a,0,0,1)|0;D=F;Zy(a,0);Yy(a,1684632949);Ry(a,671736,16);Py(a,1);hz(a,0);J=i+(b<<8)+192|0;ez(a,c[J>>2]|0,c[J+4>>2]|0);J=i+(b<<8)+112|0;I=i+(b<<8)+24|0;R=YGb(c[I>>2]|0,c[I+4>>2]|0,c[J>>2]|0,c[J+4>>2]|0)|0;J=(c[i+(b<<8)+88>>2]|0)+8|0;I=ZGb(R,F,c[J>>2]|0,c[J+4>>2]|0)|0;ez(a,I,F);I=Ty(a,0,0,1)|0;J=F;Ty(a,N,D,0)|0;R=ZGb(I,J,N,D)|0;Zy(a,R);Ty(a,I,J,0)|0;J=c[A>>2]|0;if((J|0)==0){break}I=J<<4;J=I+21|0;R=Ty(a,0,0,1)|0;D=i+(b<<8)+200|0;c[D>>2]=R;c[D+4>>2]=F;Zy(a,I+29|0);Yy(a,1701147238);if((J|0)>0){Y=0}else{break}do{Py(a,0);Y=Y+1|0;}while((Y|0)<(J|0))}}while(0);K=Ty(a,0,0,1)|0;M=F;Ty(a,G,H,0)|0;J=ZGb(K,M,G,H)|0;Zy(a,J);Ty(a,K,M,0)|0;E=c[h>>2]|0}else{E=B}}while(0);i=b+1|0;if((i|0)<(E|0)){b=i;B=E}else{break}}j=0;k=0;l=Ty(a,j,k,1)|0;m=F;n=Ty(a,f,g,0)|0;o=F;p=ZGb(l,m,f,g)|0;q=F;r=p;s=r;Zy(a,s);t=Ty(a,l,m,0)|0;u=F;return s|0}function II(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a+4>>2]|0;if((e|0)<=(b|0)){f=0;i=d;return f|0}g=b+1|0;if((g|0)==(e|0)){e=a+24|0;h=a+112|0;j=YGb(c[h>>2]|0,c[h+4>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0;k=F;l=j;m=c[a+88>>2]|0}else{j=c[a+88>>2]|0;a=j+(g*40|0)+8|0;k=c[a+4>>2]|0;l=c[a>>2]|0;m=j}j=m+(b*40|0)+8|0;b=ZGb(l,k,c[j>>2]|0,c[j+4>>2]|0)|0;j=F;k=-1;if(!((j|0)>(k|0)|(j|0)==(k|0)&b>>>0>-1>>>0)){yDb(0,0,2345536,(n=i,i=i+24|0,c[n>>2]=2343992,c[n+8>>2]=2342720,c[n+16>>2]=621,n)|0);i=n;Cd();return 0}k=0;if(!((j|0)<(k|0)|(j|0)==(k|0)&b>>>0<-2147483648>>>0)){yDb(0,0,2345536,(n=i,i=i+24|0,c[n>>2]=2341344,c[n+8>>2]=2342720,c[n+16>>2]=622,n)|0);i=n;Cd();return 0}f=b;i=d;return f|0}function JI(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=Ty(b,0,0,1)|0;i=F;j=e+1140|0;e=BBb(c[j>>2]|0,g,0,0)|0;if((e|0)==0){return}g=e+4|0;e=c[g>>2]|0;k=a[e]|0;if(k<<24>>24==0){return}else{l=e;m=0;n=k}a:while(1){k=n&255;e=k>>>1&64;if((k&192|0)==128|(n&255)>>>0>253>>>0){break}o=l+1|0;if((e&k|0)==0){p=o}else{q=k;k=e;e=o;while(1){o=(d[e]|0)-128|0;if(o>>>0>63>>>0){break a}r=o+(q<<6)|0;o=k<<5;s=e+1|0;if((r&o|0)==0){p=s;break}else{q=r;k=o;e=s}}}t=m+1|0;e=a[p]|0;if(e<<24>>24==0){u=8;break}else{l=p;m=t;n=e}}do{if((u|0)==8){if((t|0)!=0){break}return}}while(0);Zy(b,0);Yy(b,(d[f+1|0]|0)<<8|(d[f]|0)|(d[f+2|0]|0)<<16|(d[f+3|0]|0)<<24);Zy(b,0);do{if((QGb(f,2299456)|0)==0){fz(b,gd(c[g>>2]|0)|0)}else{fz(b,5575);t=c[g>>2]|0;Ry(b,t,(SGb(t|0)|0)+1|0);if((QGb(f,2311168)|0)!=0){break}t=BBb(c[j>>2]|0,2224168,0,0)|0;if((t|0)==0){break}Py(b,gd(c[t+4>>2]|0)|0)}}while(0);j=Ty(b,0,0,1)|0;f=F;Ty(b,h,i,0)|0;g=ZGb(j,f,h,i)|0;Zy(b,g);Ty(b,j,f,0)|0;return}function KI(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+16|0;h=a+1140|0;a=BBb(c[h>>2]|0,e,0,0)|0;if((a|0)==0){j=0;i=g;return j|0}k=SGb(c[a>>2]|0)|0;l=g|0;Lb(l|0,16,2216144,(m=i,i=i+8|0,c[m>>2]=e,m)|0)|0;i=m;m=BBb(c[h>>2]|0,l,0,2)|0;a:do{if((m|0)==0){n=0;o=a+4|0}else{e=k+4|0;p=a+4|0;q=m;while(1){r=c[q>>2]|0;do{if((SGb(r|0)|0)==(e|0)){if((QGb(c[p>>2]|0,c[q+4>>2]|0)|0)!=0){break}s=qF(r+(k+1)|0,1)|0;if((s|0)>-1){n=s;o=p;break a}}}while(0);r=BBb(c[h>>2]|0,l,q,2)|0;if((r|0)==0){n=0;o=p;break}else{q=r}}}}while(0);j=LI(b,d,c[o>>2]|0,n,f)|0;i=g;return j|0}function LI(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)==0){h=0;return h|0}if((a[e]|0)==0){h=0;return h|0}i=Ty(b,0,0,1)|0;j=F;Zy(b,0);Yy(b,d[c+1|0]<<8|d[c]|d[c+2|0]<<16|d[c+3|0]<<24);if((g|0)==0){if((f|0)==0){k=qF(2221296,1)|0}else{k=f}fz(b,SGb(e|0)|0);fz(b,k);Ry(b,e,SGb(e|0)|0)}else{Zy(b,(SGb(e|0)|0)+16|0);Yy(b,1635017060);Zy(b,1);Zy(b,0);Ry(b,e,SGb(e|0)|0)}e=Ty(b,0,0,1)|0;k=F;Ty(b,i,j,0)|0;f=ZGb(e,k,i,j)|0;j=f;Zy(b,j);Ty(b,e,k,0)|0;h=j;return h|0}function MI(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0;if(!((g|0)==4|(g|0)==1)){return}h=BBb(c[a+1140>>2]|0,f,0,0)|0;if((h|0)==0){return}f=gd(c[h+4>>2]|0)|0;Zy(b,g+24|0);Yy(b,(d[e+1|0]|0)<<8|(d[e]|0)|(d[e+2|0]|0)<<16|(d[e+3|0]|0)<<24);Zy(b,g+16|0);Yy(b,1635017060);Zy(b,21);Zy(b,0);e=f&255;if((g|0)==4){Zy(b,e);return}else{Py(b,e);return}}function NI(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=(e|0)!=0;e=BBb(b,f?2225168:2224168,0,0)|0;if((e|0)==0){return}b=c[e+4>>2]|0;e=gd(b|0)|0;if((e|0)==0){return}g=Vb(b|0,47)|0;if((g|0)==0){h=0}else{h=gd(g+1|0)|0}Zy(a,32);g=f?2223120:2222144;Yy(a,(d[g+1|0]|0)<<8|(d[g]|0)|(d[g+2|0]|0)<<16|(d[g+3|0]|0)<<24);Zy(a,24);Yy(a,1635017060);Zy(a,0);Zy(a,0);fz(a,0);fz(a,e);fz(a,h);fz(a,0);return}function OI(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=a[c]|0;do{if(g<<24>>24==0){h=0}else{i=c;j=0;k=g;a:while(1){l=k&255;m=l>>>1&64;if((l&192|0)==128|(k&255)>>>0>253>>>0){n=15;break}o=i+1|0;if((m&l|0)==0){p=o}else{q=l;l=m;m=o;while(1){o=(d[m]|0)-128|0;if(o>>>0>63>>>0){n=15;break a}r=o+(q<<6)|0;o=l<<5;s=m+1|0;if((r&o|0)==0){p=s;break}else{q=r;l=o;m=s}}}t=j+1|0;m=a[p]|0;if(m<<24>>24==0){n=7;break}else{i=p;j=t;k=m}}if((n|0)==7){if((t|0)>=0){h=t;break}return}else if((n|0)==15){return}}}while(0);fz(b,(h<<1)+12|0);Zy(b,f);fz(b,((d[e+1|0]|0)<<5&992|(d[e]|0)<<10&31744|a[e+2|0]&31)&65535);fz(b,1);e=a[c]|0;b:do{if(!(e<<24>>24==0)){f=c;h=e;c:while(1){t=h&255;p=t>>>1&64;if((t&192|0)==128|(h&255)>>>0>253>>>0){n=15;break}g=f+1|0;if((p&t|0)==0){u=t;v=p;w=g}else{k=t;t=p;p=g;while(1){g=(d[p]|0)-128|0;if(g>>>0>63>>>0){n=15;break c}j=g+(k<<6)|0;g=t<<5;i=p+1|0;if((j&g|0)==0){u=j;v=g;w=i;break}else{k=j;t=g;p=i}}}fz(b,(v<<1)-1&u);p=a[w]|0;if(p<<24>>24==0){break b}else{f=w;h=p}}if((n|0)==15){return}}}while(0);fz(b,0);return}function PI(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+32|0;f=e|0;g=Ty(a,0,0,1)|0;h=F;j=(b|0)!=0;do{if(j){k=(c[b>>2]|0)==2?2146280:9203360;l=b+76|0;m=c[l>>2]|0;n=c[m+8>>2]|0;if((n|0)==3){o=c[b+68>>2]|0;if((o|0)==1731426420){p=2140688}else if((o|0)==942683747){q=k;r=2141536;s=2141240;break}else{p=2149560}q=k;r=p;s=2140464;break}else if((n|0)==0){q=k;r=2144280;s=2142776;break}else if((n|0)==1){q=k;r=2142312;s=2141936;break}else{n=c[m+52>>2]|0;if((n|0)==1684237684){q=k;r=2191704;s=2138664;break}else if((n|0)==544240754){q=k;r=2140240;s=2139984;break}else{m=f|0;I0a(m,32,n)|0;n=c[l>>2]|0;l=c[n+52>>2]|0;yDb(n,24,2137256,(n=i,i=i+16|0,c[n>>2]=m,c[n+8>>2]=l,n)|0);i=n;q=k;r=2154200;s=2146536;break}}}else{q=2147e3;r=2154200;s=2146536}}while(0);Zy(a,0);Yy(a,1919706216);Zy(a,0);Ry(a,q,4);Yy(a,(d[r+1|0]|0)<<8|(d[r]|0)|(d[r+2|0]|0)<<16|(d[r+3|0]|0)<<24);Zy(a,0);Zy(a,0);Zy(a,0);if(j){if((c[b>>2]|0)==2){t=12}}else{t=12}if((t|0)==12){Py(a,SGb(s|0)|0)}Ry(a,s,SGb(s|0)|0);do{if(j){if((c[b>>2]|0)==2){break}Py(a,0)}}while(0);b=Ty(a,0,0,1)|0;j=F;Ty(a,g,h,0)|0;s=ZGb(b,j,g,h)|0;Zy(a,s);Ty(a,b,j,0)|0;i=e;return}function QI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=Ty(a,0,0,1)|0;e=F;Zy(a,0);Yy(a,1684565351);Zy(a,24);Yy(a,1852403047);Zy(a,0);fz(a,64);fz(a,32768);fz(a,32768);fz(a,32768);fz(a,0);fz(a,0);if((c[b+68>>2]|0)!=942683747){Zy(a,44);Yy(a,1954047348);fz(a,1);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,1);Zy(a,0);Zy(a,0);Zy(a,0);Zy(a,16384);fz(a,0)}if((c[(c[b+76>>2]|0)+52>>2]|0)!=1684237684){f=0;g=0;h=Ty(a,f,g,1)|0;i=F;j=Ty(a,d,e,0)|0;k=F;l=ZGb(h,i,d,e)|0;m=F;n=l;o=n;Zy(a,o);p=Ty(a,h,i,0)|0;q=F;return}b=Ty(a,0,0,1)|0;r=F;Zy(a,0);Yy(a,1684237684);s=Ty(a,0,0,1)|0;t=F;Zy(a,0);Yy(a,1768776564);Zy(a,0);fz(a,0);fz(a,0);fz(a,12);fz(a,0);fz(a,0);fz(a,0);fz(a,0);fz(a,65535);fz(a,65535);fz(a,65535);Py(a,13);Ry(a,2148952,13);u=Ty(a,0,0,1)|0;v=F;Ty(a,s,t,0)|0;w=ZGb(u,v,s,t)|0;Zy(a,w);Ty(a,u,v,0)|0;v=Ty(a,0,0,1)|0;u=F;Ty(a,b,r,0)|0;w=ZGb(v,u,b,r)|0;Zy(a,w);Ty(a,v,u,0)|0;f=0;g=0;h=Ty(a,f,g,1)|0;i=F;j=Ty(a,d,e,0)|0;k=F;l=ZGb(h,i,d,e)|0;m=F;n=l;o=n;Zy(a,o);p=Ty(a,h,i,0)|0;q=F;return}function RI(b,f){b=b|0;f=f|0;var g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0;g=i;i=i+64|0;j=g|0;l=g+8|0;m=g+16|0;n=g+24|0;o=g+32|0;p=Ty(b,0,0,1)|0;q=F;Zy(b,0);Yy(b,1818391667);r=Ty(b,0,0,1)|0;s=F;Zy(b,0);Yy(b,1685288051);Zy(b,0);Zy(b,1);t=f+76|0;u=c[t>>2]|0;v=c[u+8>>2]|0;do{if((v|0)==3){w=Ty(b,0,0,1)|0;x=F;Zy(b,0);Yy(b,c[f+68>>2]|0);Zy(b,0);fz(b,0);fz(b,1);y=c[t>>2]|0;z=c[y+100>>2]|0;if((z|0)!=0){Ry(b,c[y+96>>2]|0,z)}z=Ty(b,0,0,1)|0;y=F;Ty(b,w,x,0)|0;A=ZGb(z,y,w,x)|0;Zy(b,A);Ty(b,z,y,0)|0;}else if((v|0)==1){y=Ty(b,0,0,1)|0;z=F;A=f+68|0;x=c[A>>2]|0;w=f|0;a:do{if((c[w>>2]|0)==2){if((c[f+8>>2]|0)>>>0>65535>>>0){switch(c[(c[t>>2]|0)+48>>2]|0){case 65556:case 65558:case 65557:case 65559:case 65541:case 65537:case 65549:case 65545:case 65540:case 65536:case 65548:case 65544:{B=1835233388;C=2;break a;break};default:{}}B=x;C=2;break}if((c[f+96>>2]|0)==0){D=c[(c[t>>2]|0)+48>>2]|0;if(!((D|0)==65557|(D|0)==65548|(D|0)==65544|(D|0)==65559|(D|0)==65556|(D|0)==65549|(D|0)==65545|(D|0)==65558|(D|0)==69638|(D|0)==69633|(D|0)==86035)){B=x;C=0;break}}B=x;C=1}else{B=x;C=0}}while(0);Zy(b,0);Yy(b,B);Zy(b,0);fz(b,0);fz(b,1);fz(b,C);fz(b,0);Zy(b,0);if((C|0)==2){fz(b,3);fz(b,16);fz(b,65534);fz(b,0);Zy(b,65536);Zy(b,72);h[k>>3]=+(c[(c[t>>2]|0)+412>>2]|0);ez(b,c[k>>2]|0,c[k+4>>2]|0);Zy(b,c[(c[t>>2]|0)+416>>2]|0);Zy(b,2130706432);Zy(b,u0a(c[(c[t>>2]|0)+48>>2]|0)|0);switch(c[(c[t>>2]|0)+48>>2]|0){case 65557:case 65559:{E=9;break};case 65541:{E=10;break};case 65537:case 65549:case 65545:{E=14;break};case 65540:case 65536:case 65548:case 65544:{E=12;break};case 65556:case 65558:{E=11;break};default:{E=0}}Zy(b,E);Zy(b,c[f+40>>2]|0);b:do{if((c[f+96>>2]|0)==0){G=1}else{x=f+4|0;if((c[x>>2]|0)==0){G=0;break}D=II(f,0)|0;H=1;while(1){if((H|0)>=(c[x>>2]|0)){G=D;break b}if((II(f,H)|0)==(D|0)){H=H+1|0}else{G=0;break}}}}while(0);Zy(b,G)}else{if((c[w>>2]|0)==2){fz(b,c[(c[t>>2]|0)+416>>2]|0);if(((c[(c[t>>2]|0)+48>>2]|0)-65540|0)>>>0<2>>>0){fz(b,8)}else{fz(b,16)}fz(b,(c[f+96>>2]|0)!=0?-2:0)}else{fz(b,2);fz(b,16);fz(b,0)}fz(b,0);H=c[(c[t>>2]|0)+412>>2]|0;fz(b,(H|0)<65536?H:0);fz(b,0)}H=(C|0)==1;if(H){D=c[t>>2]|0;switch(c[D+48>>2]|0){case 65557:case 65548:case 65544:case 65559:case 65556:case 65549:case 65545:case 65558:{Zy(b,1);break};default:{Zy(b,c[D+424>>2]|0)}}D=f+40|0;Zy(b,(c[D>>2]|0)/(c[(c[t>>2]|0)+416>>2]|0)|0);Zy(b,c[D>>2]|0);Zy(b,2)}do{if((c[w>>2]|0)==2){D=c[(c[t>>2]|0)+48>>2]|0;if((D|0)==65557|(D|0)==65548|(D|0)==65544|(D|0)==65559){if(!H){I=102;break}}else if((D|0)==65556|(D|0)==65549|(D|0)==65545|(D|0)==65558){if(!H){I=102;break}}else if(!((D|0)==86018|(D|0)==86019|(D|0)==73728|(D|0)==86032|(D|0)==69638|(D|0)==69633|(D|0)==86035)){I=102;break}D=Ty(b,0,0,1)|0;x=F;Zy(b,0);Yy(b,1702257015);J=c[t>>2]|0;do{if((c[J+48>>2]|0)==86035){K=J;I=99}else{Zy(b,12);Yy(b,1634562662);Yy(b,c[A>>2]|0);L=c[t>>2]|0;M=c[L+48>>2]|0;if((M|0)==65557|(M|0)==65548|(M|0)==65544|(M|0)==65559){Zy(b,10);Yy(b,1633971813);fz(b,1);break}else if((M|0)==65556|(M|0)==65549|(M|0)==65545|(M|0)==65558){Zy(b,10);Yy(b,1633971813);fz(b,0);break}else if((M|0)==86018){Zy(b,12);Yy(b,1630826605);Zy(b,0);TI(b,f);break}else if((M|0)==69638|(M|0)==69633){N=Ty(b,0,0,1)|0;O=F;Zy(b,0);Yy(b,c[A>>2]|0);P=(de((c[A>>2]|0)>>>16&65535|0)|0)&65535;Q=c[t>>2]|0;c[Q+52>>2]=P;GO(b,Q)|0;Q=Ty(b,0,0,1)|0;P=F;Ty(b,N,O,0)|0;R=ZGb(Q,P,N,O)|0;Zy(b,R);Ty(b,Q,P,0)|0;break}else if((M|0)==73728){UI(b,f);break}else if((M|0)==86019){VI(b,f);break}else if((M|0)==86032|(M|0)==86035){K=L;I=99;break}else{break}}}while(0);if((I|0)==99){Ry(b,c[K+96>>2]|0,c[K+100>>2]|0)}Zy(b,8);Zy(b,0);J=Ty(b,0,0,1)|0;L=F;Ty(b,D,x,0)|0;M=ZGb(J,L,D,x)|0;Zy(b,M);Ty(b,J,L,0)|0;}else{I=102}}while(0);do{if((I|0)==102){if((c[A>>2]|0)==1630826605){TI(b,f);break}H=c[t>>2]|0;L=c[H+48>>2]|0;if((L|0)==73728){UI(b,f);break}else if((L|0)==86019){VI(b,f);break}else if((L|0)==86032){Ry(b,c[H+96>>2]|0,c[H+100>>2]|0);break}else if((L|0)==86054){L=Ty(b,0,0,1)|0;H=F;Zy(b,0);Yy(b,2019911287);GO(b,c[t>>2]|0)|0;J=Ty(b,0,0,1)|0;M=F;Ty(b,L,H,0)|0;P=ZGb(J,M,L,H)|0;Zy(b,P);Ty(b,J,M,0)|0;break}else{M=f+80|0;J=c[M>>2]|0;if((J|0)<=0){break}Zy(b,J+8|0);Yy(b,1818389607);Ry(b,c[f+84>>2]|0,c[M>>2]|0);break}}}while(0);do{if((c[w>>2]|0)==2){if((c[(c[t>>2]|0)+8>>2]|0)!=1){break}A=Ty(b,0,0,1)|0;M=F;J=c[t>>2]|0;P=J+448|0;H=wI(c[J+48>>2]|0,c[P>>2]|0,c[P+4>>2]|0,j)|0;if((H|0)==0){yDb(c[t>>2]|0,24,2184936,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;break}else{Zy(b,0);Yy(b,1851877475);Py(b,0);hz(b,0);Zy(b,H);Zy(b,c[j>>2]|0);Zy(b,0);H=Ty(b,0,0,1)|0;P=F;Ty(b,A,M,0)|0;J=ZGb(H,P,A,M)|0;Zy(b,J);Ty(b,H,P,0)|0;break}}}while(0);w=Ty(b,0,0,1)|0;P=F;Ty(b,y,z,0)|0;H=ZGb(w,P,y,z)|0;Zy(b,H);Ty(b,w,P,0)|0;}else if((v|0)==0){P=o|0;w=Ty(b,0,0,1)|0;H=F;TGb(P|0,0,32)|0;Zy(b,0);J=f+68|0;Yy(b,c[J>>2]|0);Zy(b,0);fz(b,0);fz(b,1);fz(b,0);fz(b,0);M=f|0;do{if((c[M>>2]|0)==2){Yy(b,1347241542);if((c[(c[t>>2]|0)+48>>2]|0)==14){Zy(b,0);Zy(b,1024);break}else{Zy(b,512);Zy(b,512);break}}else{Zy(b,0);Zy(b,0);Zy(b,0)}}while(0);fz(b,c[(c[t>>2]|0)+120>>2]|0);fz(b,c[f+100>>2]|0);Zy(b,4718592);Zy(b,4718592);Zy(b,0);fz(b,1);z=c[t>>2]|0;y=c[z+120>>2]|0;if((y|0)==1920){T=(c[z+124>>2]|0)!=1080}else if((y|0)==1440){if((c[z+124>>2]|0)==1080){T=0}else{I=10}}else if((y|0)==1280){if((c[z+124>>2]|0)==720){T=0}else{I=10}}else{T=1}if((I|0)==10){T=1}do{if((c[M>>2]|0)==2){y=c[z+12>>2]|0;if((y|0)==0){I=16;break}A=c[y>>2]|0;if((A|0)==0){I=16;break}sAb(P,A,32)|0}else{I=16}}while(0);do{if((I|0)==16){if((c[z+48>>2]|0)!=2|T){break}A=(c[z+408>>2]|0)>>>0>1>>>0;y=c[f+72>>2]|0;L=n;Q=n;R=c[y+8>>2]|0;c[Q>>2]=c[R+108>>2];O=L+4|0;c[O>>2]=c[R+104>>2];if((bGb(L)|0)<0){L=c[O>>2]|0;O=y+92|0;R=c[O>>2]|0;N=c[y+96>>2]|0;yDb(0,48,2155464,(S=i,i=i+32|0,c[S>>2]=c[Q>>2],c[S+8>>2]=L,c[S+16>>2]=R,c[S+24>>2]=N,S)|0);i=S;N=O;O=c[N>>2]|0;R=c[N+4>>2]|0;c[n>>2]=O;c[n+4>>2]=R;U=O;V=R}else{U=c[n>>2]|0;V=c[n+4>>2]|0}R=~~(+(U|0)/+(V|0));uAb(P,32,2160600,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S;O=c[t>>2]|0;do{if((c[O+140>>2]|0)==4){uAb(P,32,2160144,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S}else{if((c[O+120>>2]|0)==1440){uAb(P,32,2159832,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S;break}else{uAb(P,32,2158208,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S;break}}}while(0);uAb(P,32,2156432,(S=i,i=i+16|0,c[S>>2]=c[(c[t>>2]|0)+124>>2],c[S+8>>2]=A?105:112,S)|0)|0;i=S;O=ba(R,A?2:1)|0;uAb(P,32,2155920,(S=i,i=i+8|0,c[S>>2]=O,S)|0)|0;i=S}}while(0);Py(b,SGb(P|0)|0);Ry(b,P,31);do{if((c[M>>2]|0)==2){z=c[(c[t>>2]|0)+792>>2]|0;if((z|0)==0){I=29;break}fz(b,z)}else{I=29}}while(0);if((I|0)==29){fz(b,24)}fz(b,65535);do{if((c[J>>2]|0)==1983148141){TI(b,f)}else{P=c[t>>2]|0;z=c[P+48>>2]|0;if((z|0)==1211250229){O=Ty(b,0,0,1)|0;x=F;Zy(b,0);Yy(b,1130591848);iX(b,c[f+84>>2]|0,c[f+80>>2]|0,0)|0;D=Ty(b,0,0,1)|0;N=F;Ty(b,O,x,0)|0;L=ZGb(D,N,O,x)|0;Zy(b,L);Ty(b,D,N,0)|0;break}else if((z|0)==93|(z|0)==107){break}else if((z|0)==28){N=Ty(b,0,0,1)|0;D=F;Zy(b,0);Yy(b,1130591841);cX(b,c[f+84>>2]|0,c[f+80>>2]|0)|0;L=Ty(b,0,0,1)|0;x=F;Ty(b,N,D,0)|0;O=ZGb(L,x,N,D)|0;Zy(b,O);Ty(b,L,x,0)|0;if((c[M>>2]|0)!=32){break}Zy(b,28);Yy(b,1684632949);Zy(b,1801994482);Zy(b,1596215237);Zy(b,-1170627301);Zy(b,-821877773);Zy(b,0);break}else if((z|0)==100){Zy(b,24);Yy(b,1380729665);Yy(b,1380729665);Yy(b,825241648);Zy(b,2);Zy(b,0);Zy(b,24);Yy(b,1196576833);Yy(b,1196576833);Yy(b,825241648);Zy(b,1);Zy(b,0);Zy(b,120);Yy(b,1397051969);Yy(b,1397051969);Yy(b,825241648);x=f+84|0;L=(c[x>>2]|0)+40|0;Zy(b,fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0);Zy(b,c[(c[t>>2]|0)+120>>2]|0);L=c[(c[t>>2]|0)+124>>2]|0;do{if((a[(c[x>>2]|0)+5|0]&2)==0){Zy(b,L);Zy(b,1);Zy(b,0);if((c[(c[t>>2]|0)+124>>2]|0)==1080){Zy(b,5);break}else{Zy(b,6);break}}else{Zy(b,(L|0)/2|0);Zy(b,2);Zy(b,0);Zy(b,4)}}while(0);ez(b,0,0);ez(b,0,0);ez(b,0,0);ez(b,0,0);ez(b,0,0);ez(b,0,0);ez(b,0,0);ez(b,0,0);ez(b,0,0);ez(b,0,0);Zy(b,0);break}else if((z|0)==71){L=f+80|0;if((c[L>>2]|0)<=0){break}x=m|0;TGb(x|0,0,7)|0;if((FI(f,x)|0)<0){break}Zy(b,(c[L>>2]|0)+15|0);Yy(b,828601956);A=Ty(b,0,0,1)|0;R=f+224|0;c[R>>2]=A;c[R+4>>2]=F;Ry(b,x,7);Ry(b,c[f+84>>2]|0,c[L>>2]|0);break}else if((z|0)==5){Zy(b,15);Yy(b,859189860);Yy(b,1347241542);Py(b,0);Py(b,10);Py(b,0);break}else if((z|0)==1096176969|(z|0)==24){Ry(b,c[P+96>>2]|0,c[P+100>>2]|0);Zy(b,0);break}else{L=f+80|0;x=c[L>>2]|0;if((x|0)<=0){break}Zy(b,x+8|0);Yy(b,1818389607);Ry(b,c[f+84>>2]|0,c[L>>2]|0);break}}}while(0);M=c[t>>2]|0;J=c[M+48>>2]|0;do{if((J|0)==28|(J|0)==13|(J|0)==100){W=M}else{L=c[M+408>>2]|0;if(!((L|0)!=0&L>>>0<6>>>0)){W=M;break}x=e[1071736+(L<<1)>>1]|0;Zy(b,10);Yy(b,1818585446);fz(b,x);W=c[t>>2]|0}}while(0);M=c[W+228>>2]|0;do{if((M|0)!=0){J=c[W+224>>2]|0;if((J|0)==0|(M|0)==(J|0)){break}x=l|0;L=l+4|0;iFb(x,L,J,(J|0)<0|0?-1:0,M,(M|0)<0|0?-1:0,2147483647,0)|0;Zy(b,16);Yy(b,1886609776);Zy(b,c[x>>2]|0);Zy(b,c[L>>2]|0)}}while(0);M=Ty(b,0,0,1)|0;L=F;Ty(b,w,H,0)|0;x=ZGb(M,L,w,H)|0;Zy(b,x);Ty(b,M,L,0)|0;}else{L=c[u+52>>2]|0;if((L|0)==544240754){M=Ty(b,0,0,1)|0;x=F;Zy(b,0);Yy(b,544240754);Zy(b,0);fz(b,0);fz(b,1);fz(b,1);fz(b,1);Zy(b,c[f+144>>2]|0);Zy(b,12);Yy(b,1936550260);Zy(b,c[f+8>>2]|0);J=Ty(b,0,0,1)|0;R=F;Ty(b,M,x,0)|0;A=ZGb(J,R,M,x)|0;Zy(b,A);Ty(b,J,R,0)|0;break}else if((L|0)!=1684237684){break}L=Ty(b,0,0,1)|0;R=F;J=f+8|0;A=c[t>>2]|0;x=c[A+104>>2]|0;M=c[A+108>>2]|0;A=~~(1.0/(+(x|0)/+(M|0))+.5);if((A|0)>255){yDb(0,16,2194528,(S=i,i=i+8|0,c[S>>2]=A,S)|0);i=S;break}else{O=IDb(c[J>>2]|0,0,x,(x|0)<0|0?-1:0,M,(M|0)<0|0?-1:0)|0;Zy(b,0);Yy(b,1684237684);Zy(b,0);Zy(b,1);Zy(b,0);Zy(b,c[f+56>>2]|0);Zy(b,c[J>>2]|0);Zy(b,O);Py(b,A);hz(b,0);A=Ty(b,0,0,1)|0;O=F;Ty(b,L,R,0)|0;J=ZGb(A,O,L,R)|0;Zy(b,J);Ty(b,A,O,0)|0;break}}}while(0);S=Ty(b,0,0,1)|0;u=F;Ty(b,r,s,0)|0;l=ZGb(S,u,r,s)|0;Zy(b,l);Ty(b,S,u,0)|0;do{if((c[(c[t>>2]|0)+8>>2]|0)==1){if((c[f+96>>2]|0)!=0){I=128;break}u=WDb(8)|0;c[u>>2]=c[f+36>>2];c[u+4>>2]=1;X=u;Y=1}else{I=128}}while(0);if((I|0)==128){u=f+4|0;S=c[u>>2]|0;do{if((S|0)==0){Z=-1;_=0}else{l=WDb(S<<3)|0;if((c[u>>2]|0)>0){$=-1;aa=0}else{Z=-1;_=l;break}while(1){s=II(f,aa)|0;do{if((aa|0)==0){I=133}else{if((s|0)!=(c[l+($<<3)+4>>2]|0)){I=133;break}r=l+($<<3)|0;c[r>>2]=(c[r>>2]|0)+1;ca=$}}while(0);if((I|0)==133){I=0;P=$+1|0;c[l+(P<<3)+4>>2]=s;c[l+(P<<3)>>2]=1;ca=P}P=aa+1|0;if((P|0)<(c[u>>2]|0)){$=ca;aa=P}else{Z=ca;_=l;break}}}}while(0);X=_;Y=Z+1|0}Zy(b,(Y<<3)+16|0);Yy(b,1937011827);Zy(b,0);Zy(b,Y);if((Y|0)!=0){Z=0;do{Zy(b,c[X+(Z<<3)>>2]|0);Zy(b,c[X+(Z<<3)+4>>2]|0);Z=Z+1|0;}while(Z>>>0<Y>>>0)}ZDb(X);X=c[t>>2]|0;if((c[X+8>>2]|0)==0){I=140}else{if((c[X+52>>2]|0)==544240754){I=140}}do{if((I|0)==140){X=c[f+48>>2]|0;if((X|0)==0){break}if((X|0)>=(c[f+4>>2]|0)){break}SI(b,f,1)}}while(0);do{if((c[f>>2]|0)==2){if((c[f+52>>2]&2|0)==0){break}SI(b,f,2)}}while(0);do{if((c[(c[t>>2]|0)+8>>2]|0)==0){if((c[f+52>>2]&1|0)==0){break}X=f+4|0;Y=WDb((c[X>>2]<<3)+8|0)|0;Z=Y;c[Y>>2]=1;_=c[f+88>>2]|0;c[Y+4>>2]=c[_+32>>2];ca=c[X>>2]|0;if((ca|0)>1){X=0;aa=1;while(1){$=c[_+(aa*40|0)+32>>2]|0;if(($|0)==(c[Z+(X<<3)+4>>2]|0)){u=Z+(X<<3)|0;c[u>>2]=(c[u>>2]|0)+1;da=X}else{u=X+1|0;c[Z+(u<<3)+4>>2]=$;c[Z+(u<<3)>>2]=1;da=u}u=aa+1|0;if((u|0)<(ca|0)){X=da;aa=u}else{ea=da;break}}}else{ea=0}aa=ea+1|0;Zy(b,(aa<<3)+16|0);Yy(b,1937011811);Zy(b,0);Zy(b,aa);if((aa|0)!=0){X=0;do{Zy(b,c[Z+(X<<3)>>2]|0);Zy(b,c[Z+(X<<3)+4>>2]|0);X=X+1|0;}while(X>>>0<aa>>>0)}ZDb(Y)}}while(0);ea=Ty(b,0,0,1)|0;da=F;Zy(b,0);Yy(b,1668510835);Zy(b,0);t=Ty(b,0,0,1)|0;aa=F;X=f+44|0;Zy(b,c[X>>2]|0);Z=f+4|0;ca=c[Z>>2]|0;if((ca|0)>0){_=f+88|0;u=0;$=-1;S=0;l=c[_>>2]|0;H=ca;while(1){do{if(($|0)==(c[l+(u*40|0)+20>>2]|0)){fa=S;ga=$;ha=l;ia=H}else{ca=c[l+(u*40|0)+24>>2]|0;if((ca|0)==0){fa=S;ga=$;ha=l;ia=H;break}Zy(b,ca);Zy(b,c[(c[_>>2]|0)+(u*40|0)+20>>2]|0);Zy(b,1);ca=c[_>>2]|0;fa=S+1|0;ga=c[ca+(u*40|0)+20>>2]|0;ha=ca;ia=c[Z>>2]|0}}while(0);Y=u+1|0;if((Y|0)<(ia|0)){u=Y;$=ga;S=fa;l=ha;H=ia}else{ja=fa;break}}}else{ja=0}fa=Ty(b,0,0,1)|0;ia=F;Ty(b,t,aa,0)|0;Zy(b,ja);Ty(b,fa,ia,0)|0;ia=Ty(b,0,0,1)|0;fa=F;Ty(b,ea,da,0)|0;ja=ZGb(ia,fa,ea,da)|0;Zy(b,ja);Ty(b,ia,fa,0)|0;fa=Ty(b,0,0,1)|0;ia=F;Zy(b,0);Yy(b,2054386803);Zy(b,0);ja=c[Z>>2]|0;if((ja|0)>0){da=c[f+88>>2]|0;ea=0;aa=-1;t=0;H=1;while(1){ha=c[da+(t*40|0)+28>>2]|0;l=((c[da+(t*40|0)+16>>2]|0)>>>0)/(ha>>>0)|0;ka=(aa|0)==-1|(l|0)==(aa|0)?H:0;la=ha+ea|0;ha=t+1|0;if((ha|0)<(ja|0)){ea=la;aa=l;t=ha;H=ka}else{break}}ma=la;na=(ka|0)!=0}else{ma=0;na=1}do{if(na&(ja|0)!=0){ka=c[f+88>>2]|0;la=((c[ka+16>>2]|0)>>>0)/((c[ka+28>>2]|0)>>>0)|0;Zy(b,(la|0)<1?1:la);Zy(b,ma)}else{Zy(b,0);Zy(b,ma);la=c[Z>>2]|0;if((la|0)<=0){break}ka=f+88|0;H=0;t=c[ka>>2]|0;aa=la;while(1){la=c[t+(H*40|0)+28>>2]|0;if((la|0)==0){oa=t;pa=aa}else{ea=0;da=t;ha=la;do{Zy(b,((c[da+(H*40|0)+16>>2]|0)>>>0)/(ha>>>0)|0);ea=ea+1|0;da=c[ka>>2]|0;ha=c[da+(H*40|0)+28>>2]|0;}while(ea>>>0<ha>>>0);oa=da;pa=c[Z>>2]|0}ha=H+1|0;if((ha|0)<(pa|0)){H=ha;t=oa;aa=pa}else{break}}}}while(0);pa=Ty(b,0,0,1)|0;oa=F;Ty(b,fa,ia,0)|0;ma=ZGb(pa,oa,fa,ia)|0;Zy(b,ma);Ty(b,pa,oa,0)|0;oa=c[Z>>2]|0;if((oa|0)>0){pa=(c[f+88>>2]|0)+((oa-1|0)*40|0)|0;oa=f+184|0;ma=YGb(c[oa>>2]|0,c[oa+4>>2]|0,c[pa>>2]|0,c[pa+4>>2]|0)|0;pa=F;oa=0;if(pa>>>0>oa>>>0|pa>>>0==oa>>>0&ma>>>0>-1>>>0){qa=1}else{I=176}}else{I=176}if((I|0)==176){qa=0}I=Ty(b,0,0,1)|0;ma=F;Zy(b,0);if((qa|0)==0){Yy(b,1868788851)}else{Yy(b,875982691)}Zy(b,0);Zy(b,c[X>>2]|0);X=c[Z>>2]|0;if((X|0)<=0){ra=0;sa=0;ta=Ty(b,ra,sa,1)|0;ua=F;va=Ty(b,I,ma,0)|0;wa=F;xa=ZGb(ta,ua,I,ma)|0;ya=F;za=xa;Aa=za;Zy(b,Aa);Ba=Ty(b,ta,ua,0)|0;Ca=F;Da=0;Ea=0;Fa=Ty(b,Da,Ea,1)|0;Ga=F;Ha=Ty(b,p,q,0)|0;Ia=F;Ja=ZGb(Fa,Ga,p,q)|0;Ka=F;La=Ja;Ma=La;Zy(b,Ma);Na=Ty(b,Fa,Ga,0)|0;Oa=F;i=g;return}oa=f+88|0;pa=f+184|0;if((qa|0)==1){qa=0;f=X;while(1){ia=c[oa>>2]|0;if((c[ia+(qa*40|0)+24>>2]|0)==0){Pa=f}else{fa=ia+(qa*40|0)|0;ia=YGb(c[fa>>2]|0,c[fa+4>>2]|0,c[pa>>2]|0,c[pa+4>>2]|0)|0;ez(b,ia,F);Pa=c[Z>>2]|0}ia=qa+1|0;if((ia|0)<(Pa|0)){qa=ia;f=Pa}else{break}}ra=0;sa=0;ta=Ty(b,ra,sa,1)|0;ua=F;va=Ty(b,I,ma,0)|0;wa=F;xa=ZGb(ta,ua,I,ma)|0;ya=F;za=xa;Aa=za;Zy(b,Aa);Ba=Ty(b,ta,ua,0)|0;Ca=F;Da=0;Ea=0;Fa=Ty(b,Da,Ea,1)|0;Ga=F;Ha=Ty(b,p,q,0)|0;Ia=F;Ja=ZGb(Fa,Ga,p,q)|0;Ka=F;La=Ja;Ma=La;Zy(b,Ma);Na=Ty(b,Fa,Ga,0)|0;Oa=F;i=g;return}else{Pa=0;f=X;while(1){X=c[oa>>2]|0;if((c[X+(Pa*40|0)+24>>2]|0)==0){Qa=f}else{qa=X+(Pa*40|0)|0;X=YGb(c[qa>>2]|0,c[qa+4>>2]|0,c[pa>>2]|0,c[pa+4>>2]|0)|0;Zy(b,X);Qa=c[Z>>2]|0}X=Pa+1|0;if((X|0)<(Qa|0)){Pa=X;f=Qa}else{break}}ra=0;sa=0;ta=Ty(b,ra,sa,1)|0;ua=F;va=Ty(b,I,ma,0)|0;wa=F;xa=ZGb(ta,ua,I,ma)|0;ya=F;za=xa;Aa=za;Zy(b,Aa);Ba=Ty(b,ta,ua,0)|0;Ca=F;Da=0;Ea=0;Fa=Ty(b,Da,Ea,1)|0;Ga=F;Ha=Ty(b,p,q,0)|0;Ia=F;Ja=ZGb(Fa,Ga,p,q)|0;Ka=F;La=Ja;Ma=La;Zy(b,Ma);Na=Ty(b,Fa,Ga,0)|0;Oa=F;i=g;return}}function SI(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=Ty(a,0,0,1)|0;g=F;Zy(a,0);h=(e|0)==1?2196656:2196072;Yy(a,(d[h+1|0]|0)<<8|(d[h]|0)|(d[h+2|0]|0)<<16|(d[h+3|0]|0)<<24);Zy(a,0);h=Ty(a,0,0,1)|0;i=F;j=b+4|0;Zy(a,c[j>>2]|0);k=c[j>>2]|0;if((k|0)>0){l=b+88|0;b=0;m=0;n=k;while(1){k=m+1|0;if((c[(c[l>>2]|0)+(m*40|0)+36>>2]&e|0)==0){o=b;p=n}else{Zy(a,k);o=b+1|0;p=c[j>>2]|0}if((k|0)<(p|0)){b=o;m=k;n=p}else{q=o;break}}}else{q=0}o=Ty(a,0,0,1)|0;p=F;Ty(a,h,i,0)|0;Zy(a,q);Ty(a,o,p,0)|0;p=Ty(a,0,0,1)|0;o=F;Ty(a,f,g,0)|0;q=ZGb(p,o,f,g)|0;Zy(a,q);Ty(a,p,o,0)|0;return}function TI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=Ty(a,0,0,1)|0;e=F;f=b+80|0;g=c[f>>2]|0;h=(g|0)==0?0:g+5|0;Zy(a,0);Yy(a,1935962981);Zy(a,0);g=h+27|0;Py(a,3);Py(a,g>>>21|128);Py(a,g>>>14|128);Py(a,g>>>7|128);Py(a,g&127);fz(a,c[b+64>>2]|0);Py(a,0);g=h+13|0;Py(a,4);Py(a,g>>>21|128);Py(a,g>>>14|128);Py(a,g>>>7|128);Py(a,g&127);g=b+76|0;h=c[g>>2]|0;i=c[h+48>>2]|0;do{if((i-86016|0)>>>0<2>>>0){if((c[h+412>>2]|0)<=24e3){j=4;break}Py(a,107)}else{j=4}}while(0);if((j|0)==4){Py(a,uT(1181928,i)|0)}if((c[(c[g>>2]|0)+8>>2]|0)==1){Py(a,21)}else{Py(a,17)}hz(a,c[(c[g>>2]|0)+524>>2]>>3);i=b+24|0;j=c[i>>2]|0;h=c[i+4>>2]|0;if((j|0)==0&(h|0)==0){k=0}else{i=c[b+4>>2]|0;if((i|0)>0){l=c[b+88>>2]|0;m=0;n=0;o=0;do{n=YGb(c[l+(o*40|0)+16>>2]|0,0,n,m)|0;m=F;o=o+1|0;}while((o|0)<(i|0));p=m<<3|n>>>29;q=n<<3|0>>>29}else{p=0;q=0}n=gHb(c[b+8>>2]|0,0,q,p)|0;p=hHb(n,F,j,h)|0;k=p}p=c[g>>2]|0;g=c[p+72>>2]|0;h=c[p+540>>2]|0;p=(g|0)>(h|0)?g:h;Zy(a,p>>>0>k>>>0?p:k);Zy(a,k);k=c[f>>2]|0;if((k|0)==0){Py(a,6);Py(a,128);Py(a,128);Py(a,128);Py(a,1);Py(a,2);r=0;s=0;t=Ty(a,r,s,1)|0;u=F;v=Ty(a,d,e,0)|0;w=F;x=ZGb(t,u,d,e)|0;y=F;z=x;A=z;Zy(a,A);B=Ty(a,t,u,0)|0;C=F;return}Py(a,5);Py(a,k>>>21|128);Py(a,k>>>14|128);Py(a,k>>>7|128);Py(a,k&127);Ry(a,c[b+84>>2]|0,c[f>>2]|0);Py(a,6);Py(a,128);Py(a,128);Py(a,128);Py(a,1);Py(a,2);r=0;s=0;t=Ty(a,r,s,1)|0;u=F;v=Ty(a,d,e,0)|0;w=F;x=ZGb(t,u,d,e)|0;y=F;z=x;A=z;Zy(a,A);B=Ty(a,t,u,0)|0;C=F;return}function UI(a,b){a=a|0;b=b|0;Zy(a,17);if((c[b>>2]|0)==2){Yy(a,1919770995)}else{Yy(a,1919770980)}Yy(a,1347241542);Py(a,0);fz(a,33279);Py(a,0);Py(a,1);return}function VI(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+8|0;g=f|0;h=e+80|0;if((c[h>>2]|0)<7){i=f;return}Zy(b,11);Yy(b,862151012);j=(c[e+84>>2]|0)+4|0;e=c[h>>2]<<3;h=(e-32|0)>>>0>2147483639>>>0|(j|0)==0;k=h?0:j;j=h?8:e-24|0;e=k;h=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>6;e=j>>>0>2>>>0?2:j;l=k+(e>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(e&2)>>>27;l=e+6|0;e=j>>>0>l>>>0?l:j;l=k+(e>>>3)|0;n=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(e&7)>>>27;l=e+5|0;e=j>>>0>l>>>0?l:j;l=k+(e>>>3)|0;o=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(e&7)>>>29;l=e+3|0;e=j>>>0>l>>>0?l:j;l=k+(e>>>3)|0;p=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(e&7)>>>29;l=e+3|0;e=j>>>0>l>>>0?l:j;do{if((p|0)==2){l=e+2|0;q=j>>>0>l>>>0?l:j}else{if((p&1|0)!=0&(p|0)!=1){l=e+2|0;r=j>>>0>l>>>0?l:j}else{r=e}if((p&4|0)==0){q=r;break}l=r+2|0;q=j>>>0>l>>>0?l:j}}while(0);j=g|0;g=o|(n|h<<5&96)<<3;h=(((d[k+(q>>>3)|0]|0)<<(q&7)>>>7&1|(p|g<<3)<<1)<<5|m)<<13;m=g>>>2&255;g=8;p=j;while(1){a[p]=m;q=h;h=q<<8;k=g+8|0;if((k|0)<32){m=q>>>16&255;g=k;p=p+1|0}else{break}}h=0;Ry(b,j,3);i=f;return}function WI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=c[b+32>>2]|0;h=c[f+48>>2]|0;j=c[h+(g<<8)+76>>2]|0;k=c[b+28>>2]|0;if((k|0)==0){l=0;i=d;return l|0}m=h+(g<<8)+4|0;do{if((c[m>>2]|0)==0){n=0;o=0}else{if(!(g>>>0<(c[a+24>>2]|0)>>>0)){n=0;o=0;break}p=b+16|0;q=(c[h+(g<<8)+88>>2]|0)+8|0;r=ZGb(c[p>>2]|0,c[p+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;q=(c[(c[a+28>>2]|0)+(g<<2)>>2]|0)+40|0;c[e>>2]=1;c[e+4>>2]=1e6;p=KDb(r,F,q,e)|0;n=F;o=p}}while(0);e=c[f+76>>2]|0;g=(e|0)<0|0?-1:0;do{if((e|0)==0|((n|0)<(g|0)|(n|0)==(g|0)&o>>>0<e>>>0)){h=c[f+84>>2]|0;if((h|0)!=0){p=f+40|0;q=YGb(c[p>>2]|0,c[p+4>>2]|0,k,(k|0)<0|0?-1:0)|0;p=F;r=(h|0)<0|0?-1:0;if(!(p>>>0<r>>>0|p>>>0==r>>>0&q>>>0<h>>>0)){s=12;break}}if((c[f+52>>2]&8|0)==0){break}if((c[j+8>>2]|0)!=0){break}if((c[m>>2]|0)==0){break}if((c[b+36>>2]&1|0)!=0){s=12}}else{s=12}}while(0);do{if((s|0)==12){m=c[f+80>>2]|0;j=(m|0)<0|0?-1:0;if((n|0)<(j|0)|(n|0)==(j|0)&o>>>0<m>>>0){break}EI(a)}}while(0);l=yI(a,b)|0;i=d;return l|0}function XI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[(c[a+12>>2]|0)+48>>2]|0;g=c[(c[a+28>>2]|0)+(d<<2)>>2]|0;h=f+(b<<8)+68|0;c[h>>2]=544240754;c[f+(b<<8)+124>>2]=d;j=ARa(0)|0;k=f+(b<<8)+76|0;c[k>>2]=j;do{if((j|0)==0){l=-12}else{c[j+8>>2]=2;c[j+52>>2]=c[h>>2];m=f+(b<<8)+128|0;n=zP(m,a,g,0,1450,d)|0;if((n|0)<0){l=n;break}c[f+(b<<8)+8>>2]=c[(c[c[(c[m>>2]|0)+28>>2]>>2]|0)+44>>2];c[f+(d<<8)+120>>2]=b;o=0;i=e;return o|0}}while(0);yDb(a,24,1945936,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;$Db(k);c[f+(b<<8)+8>>2]=9e4;o=l;i=e;return o|0}function YI(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;k=i;i=i+96|0;l=k|0;m=k+8|0;n=k+16|0;o=c[(c[b+12>>2]|0)+48>>2]|0;p=c[o+(f<<8)+128>>2]|0;c[l>>2]=0;c[m>>2]=0;if((p|0)==0){q=-2;i=k;return q|0}r=p+16|0;if((c[r>>2]|0)==0){q=-12;i=k;return q|0}s=o+(f<<8)+168|0;do{if((h|0)==0){t=c[e+24>>2]|0;u=c[e+28>>2]|0;if((u|0)<15){break}v=o+(f<<8)+176|0;w=c[v>>2]|0;if((w|0)==0){x=c[s>>2]|0;y=15}else{z=c[o+(f<<8)+172>>2]|0;A=c[s>>2]|0;if((z|0)<(A|0)){B=w;C=z}else{x=A;y=15}}if((y|0)==15){A=s|0;z=aEb(w,x+10|0,20)|0;if((z|0)==0){break}w=z;c[A>>2]=(c[A>>2]|0)+10;c[v>>2]=w;B=w;C=c[o+(f<<8)+172>>2]|0}w=o+(f<<8)+172|0;c[B+(C*20|0)>>2]=t;t=c[v>>2]|0;c[t+(C*20|0)+4>>2]=u;c[t+((c[w>>2]|0)*20|0)+8>>2]=g;c[t+((c[w>>2]|0)*20|0)+12>>2]=0;c[t+((c[w>>2]|0)*20|0)+16>>2]=0;c[w>>2]=(c[w>>2]|0)+1}else{if((j|0)<15){break}w=o+(f<<8)+176|0;t=c[w>>2]|0;if((t|0)==0){D=c[s>>2]|0;y=8}else{u=c[o+(f<<8)+172>>2]|0;v=c[s>>2]|0;if((u|0)<(v|0)){E=t;G=u}else{D=v;y=8}}if((y|0)==8){v=s|0;u=aEb(t,D+10|0,20)|0;if((u|0)==0){break}t=u;c[v>>2]=(c[v>>2]|0)+10;c[w>>2]=t;E=t;G=c[o+(f<<8)+172>>2]|0}t=o+(f<<8)+172|0;c[E+(G*20|0)>>2]=h;v=c[w>>2]|0;c[v+(G*20|0)+4>>2]=j;c[v+((c[t>>2]|0)*20|0)+8>>2]=g;c[v+((c[t>>2]|0)*20|0)+12>>2]=0;c[v+((c[t>>2]|0)*20|0)+16>>2]=0;c[t>>2]=(c[t>>2]|0)+1}}while(0);OK(p,0,e,b)|0;p=Oz(c[r>>2]|0,l)|0;g=Nz(r,1450)|0;do{if((g|0)<0|(p|0)<1){H=g}else{r=Mz(m)|0;if((r|0)<0){H=r;break}vZ(n);j=c[m>>2]|0;G=c[l>>2]|0;h=n+16|0;E=Ty(j,0,0,1)|0;D=F;fz(j,0);fz(j,0);a:do{if((p|0)>4){s=o+(f<<8)+144|0;C=o+(f<<8)+132|0;B=o+(f<<8)+136|0;x=o+(f<<8)+172|0;t=o+(f<<8)+176|0;v=0;w=p;u=G;while(1){A=w;z=u;while(1){I=z;J=fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0;I=A-4|0;if(J>>>0>I>>>0|J>>>0<13>>>0){K=v;break a}L=z+4|0;M=a[z+5|0]|0;if(!((M+64&255)>>>0<4>>>0|(M+56&255)>>>0<11>>>0)){break}M=I-J|0;if((M|0)>4){A=M;z=z+(J+4)|0}else{K=v;break a}}if(J>>>0>(c[s>>2]|0)>>>0){c[s>>2]=J}M=z+6|0;I=de((d[M]|d[M+1|0]<<8)<<16>>16|0)|0;M=z+8|0;N=fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0;M=c[C>>2]|0;if((M|0)==0){c[C>>2]=N;O=N}else{O=M}M=N-O|0;if((M|0)>0){P=YGb(c[B>>2]|0,c[B+4>>2]|0,M,(M|0)<0|0?-1:0)|0;c[B>>2]=P;c[B+4>>2]=F;c[C>>2]=N;Q=0}else{Q=M}if((c[h>>2]|0)==0&(c[h+4>>2]|0)==(-2147483648|0)){M=c[B+4>>2]|0;c[h>>2]=c[B>>2];c[h+4>>2]=M}M=v+1|0;Zy(j,0);Ry(j,L,2);fz(j,I&65535);I=(Q|0)!=0;fz(j,I?4:0);N=Ty(j,0,0,1)|0;P=F;fz(j,0);if(I){Zy(j,16);Zy(j,12);Ry(j,2233664,4);Zy(j,Q)}I=A-16|0;R=J-12|0;b:do{if((R|0)>0){S=R;T=z+16|0;U=0;c:while(1){if((c[x>>2]|0)<=0){V=S;W=T;X=U;break}d:while(1){Y=c[t>>2]|0;Z=Y+12|0;_=c[Z>>2]|0;$=c[Y+4>>2]|0;do{if((_|0)==0){if(($|0)<=5){aa=0;break}c[Z>>2]=5;aa=5}else{aa=_}}while(0);ba=c[Y>>2]|0;_=0;do{ca=0;while(1){da=ca+_|0;if((da|0)>=(S|0)){break}ea=ca+aa|0;if((ea|0)>=($|0)){break}if((a[ba+ea|0]|0)==(a[T+da|0]|0)){ca=ca+1|0}else{break}}if((ca|0)>=9){fa=aa;ga=_;ha=ca;while(1){da=(ga|0)>0;if(!((fa|0)>0&da)){ia=da;break}da=fa-1|0;ea=ga-1|0;if((a[ba+da|0]|0)==(a[T+ea|0]|0)){fa=da;ga=ea;ha=ha+1|0}else{ia=1;break}}if((ha|0)>=15){break d}}_=_+1|0;}while((_|0)<(S|0));if((aa|0)<10&($|0)>20){c[Z>>2]=($|0)/2|0}else{_=c[x>>2]|0;if((_|0)<1){V=S;W=T;X=U;break c}if((c[Y+16>>2]|0)==0){ja=_;ka=Y}else{ZDb(ba);ja=c[x>>2]|0;ka=c[t>>2]|0}_=ja-1|0;c[x>>2]=_;VGb(ka|0,ka+20|0,_*20|0|0)|0}if((c[x>>2]|0)<=0){V=S;W=T;X=U;break c}}_=c[Y+8>>2]|0;ca=fa+ha|0;c[Z>>2]=ca+5;do{if((ca+15|0)>=($|0)){ea=c[x>>2]|0;if((ea|0)<1){break}if((c[Y+16>>2]|0)==0){la=ea;ma=Y}else{ZDb(ba);la=c[x>>2]|0;ma=c[t>>2]|0}ea=la-1|0;c[x>>2]=ea;VGb(ma|0,ma+20|0,ea*20|0|0)|0}}while(0);if(ia){ca=ga;ea=T;da=U;while(1){na=(ca|0)>14?14:ca;Py(j,1);Py(j,na);Ry(j,ea,na);oa=ea+na|0;pa=ca-na|0;if((na|0)<14){qa=na;do{Py(j,0);qa=qa+1|0;}while((qa|0)<14)}qa=da+1|0;if((pa|0)>0){ca=pa;ea=oa;da=qa}else{ra=qa;break}}}else{ra=U}Py(j,2);Py(j,0);fz(j,ha);Zy(j,_);Zy(j,fa);fz(j,1);fz(j,1);da=ra+1|0;ea=S-ha-ga|0;if((ea|0)>0){S=ea;T=T+(ga+ha)|0;U=da}else{sa=da;break b}}while(1){U=(V|0)>14?14:V;Py(j,1);Py(j,U);Ry(j,W,U);T=W+U|0;S=V-U|0;if((U|0)<14){da=U;do{Py(j,0);da=da+1|0;}while((da|0)<14)}da=X+1|0;if((S|0)>0){V=S;W=T;X=da}else{sa=da;break}}}else{sa=0}}while(0);R=I+(12-J)|0;A=Ty(j,0,0,1)|0;da=F;Ty(j,N,P,0)|0;fz(j,sa);Ty(j,A,da,0)|0;if((R|0)>4){v=M;w=R;u=z+(J+4)|0}else{K=M;break}}}else{K=0}}while(0);G=Ty(j,0,0,1)|0;u=F;Ty(j,E,D,0)|0;fz(j,K);Ty(j,G,u,0)|0;$Db(l);c[n+28>>2]=Oz(c[m>>2]|0,l)|0;c[n+24>>2]=c[l>>2];u=c[h+4>>2]|0;G=n+8|0;c[G>>2]=c[h>>2];c[G+4>>2]=u;c[n+32>>2]=f;if((c[e+36>>2]&1|0)!=0){u=n+36|0;c[u>>2]=c[u>>2]|1}if((K|0)<=0){H=r;break}yI(b,n)|0;H=r}}while(0);ZDb(c[l>>2]|0);l=o+(f<<8)+172|0;n=c[l>>2]|0;if((n|0)<=0){q=H;i=k;return q|0}b=o+(f<<8)+176|0;f=0;o=n;e:while(1){n=f+1|0;K=o;while(1){ta=c[b>>2]|0;ua=ta+(f*20|0)+16|0;if((c[ua>>2]|0)!=0){va=K;break}wa=ta+(f*20|0)+4|0;xa=WDb(c[wa>>2]|0)|0;if((xa|0)!=0){y=83;break}e=c[b>>2]|0;VGb(e+(f*20|0)|0,e+(n*20|0)|0,(((c[l>>2]|0)-f|0)*20|0)-20|0)|0;e=(c[l>>2]|0)-1|0;c[l>>2]=e;if((f|0)<(e|0)){K=e}else{q=H;y=85;break e}}if((y|0)==83){y=0;K=ta+(f*20|0)|0;UGb(xa|0,c[K>>2]|0,c[wa>>2]|0)|0;c[K>>2]=xa;c[ua>>2]=1;va=c[l>>2]|0}if((n|0)<(va|0)){f=n;o=va}else{q=H;y=85;break}}if((y|0)==85){i=k;return q|0}return 0}function ZI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=c[a+128>>2]|0;$Db(a+76|0);f=a+172|0;g=c[f>>2]|0;h=a+176|0;if((g|0)>0){j=0;k=g;while(1){g=c[h>>2]|0;if((c[g+(j*20|0)+16>>2]|0)==0){l=k}else{ZDb(c[g+(j*20|0)>>2]|0);l=c[f>>2]|0}g=j+1|0;if((g|0)<(l|0)){j=g;k=l}else{break}}}$Db(h);c[f>>2]=0;c[a+168>>2]=0;if((e|0)==0){i=b;return}a=e+16|0;if((c[a>>2]|0)!=0){NK(e)|0;Oz(c[a>>2]|0,d)|0;ZDb(c[d>>2]|0)}bT(e);i=b;return}function _I(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+968|0;f=e|0;g=e+8|0;h=c[b+4>>2]|0;j=b+8|0;b=h+((c[j>>2]|0)-4)|0;k=h;while(1){if(!(k>>>0<b>>>0)){l=0;break}if((a[k]|0)==0){k=k+1|0}else{m=0;n=0;o=k;p=4;break}}do{if((p|0)==4){while(1){p=0;h=o;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=fe(q|0)|0;if((h&-2097152|0)!=-2097152|(h&393216|0)==0|(h&61440|0)==61440|(h&3072|0)==3072){r=o;s=n;t=m}else{a:do{if(o>>>0<b>>>0){h=0;u=o;v=q;while(1){w=aOa(g,fe(v|0)|0,f,f,f,f)|0;if((w|0)<0){x=h;y=u;break a}z=u+w|0;w=h+1|0;if(!(z>>>0<b>>>0)){x=w;y=z;break a}A=z;h=w;u=z;v=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0}}else{x=0;y=o}}while(0);r=y;s=(n|0)>(x|0)?n:x;t=(o|0)==(k|0)?x:m}q=r+1|0;if(q>>>0<b>>>0){m=t;n=s;o=q;p=4}else{break}}if((t|0)>3){B=51;i=e;return B|0}if((s|0)>200){B=50;i=e;return B|0}if((s|0)>3){B=25}else{l=s;break}i=e;return B|0}}while(0);do{if((vE(k,1925128)|0)!=0){s=(wE(k)|0)<<1;t=c[j>>2]|0;if((s|0)<(t|0)){break}B=(t|0)<1048576?12:48;i=e;return B|0}}while(0);B=(l|0)>0|0;i=e;return B|0}function $I(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+64|0;d=b|0;e=b+40|0;f=b+48|0;g=b+56|0;h=a+12|0;j=c[h>>2]|0;k=LT(a,0)|0;if((k|0)==0){l=-12;i=b;return l|0}m=k+8|0;n=c[m>>2]|0;c[n+8>>2]=1;c[n+48>>2]=86017;c[k+236>>2]=1463898624;n=k+48|0;c[n>>2]=0;c[n+4>>2]=0;MT(k,64,1,14112e3);o=a+16|0;p=c[o>>2]|0;q=p+96|0;c[q>>2]=-1;c[q+4>>2]=-1;q=Ty(p,0,0,1)|0;p=F;if((BBb(c[a+1140>>2]|0,9203248,0,2)|0)==0){mX(a)}r=c[o>>2]|0;if((c[r+88>>2]|0)==0){s=r}else{t=Wy(r)|0;r=j+8|0;c[r>>2]=t;c[r+4>>2]=F;s=c[o>>2]|0}r=c[h>>2]|0;t=vz(s)|0;do{if(!((t&-2097152|0)!=-2097152|(t&393216|0)==0|(t&61440|0)==61440|(t&3072|0)==3072)){if((_Na(d,t)|0)==0){s=c[d>>2]|0;u=(s|0)<0|0?-1:0;v=s}else{u=0;v=0}if((c[d+8>>2]|0)!=3){break}s=c[d+36>>2]|0;j=(s|0)!=0?576:1152;w=671016+(((s|0)==1)<<4)+(((c[d+24>>2]|0)==1)<<3)|0;Vy(c[o>>2]|0,c[w>>2]|0,c[w+4>>2]|0)|0;w=vz(c[o>>2]|0)|0;s=(w|0)==1231971951;x=s&1;do{if((w|0)==1483304551|(w|0)==1231971951){y=vz(c[o>>2]|0)|0;if((y&1|0)==0){z=0}else{z=vz(c[o>>2]|0)|0}if((y&2|0)==0){A=0}else{A=vz(c[o>>2]|0)|0}a:do{if((y&4|0)!=0){B=A;C=0;c[e>>2]=j;c[e+4>>2]=c[d+12>>2];D=KDb(z,0,e,k+40|0)|0;E=F;G=c[h>>2]|0;if((c[G+36>>2]|0)==0){H=0}else{I=0;H=((E|0)>(I|0)|(E|0)==(I|0)&D>>>0>0>>>0)&1}do{if((A|0)==0){I=Wy(c[o>>2]|0)|0;J=F;if(!((I|0)==0&(J|0)==0)){K=J;L=I;M=21;break}yDb(a,24,1951096,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;O=0}else{K=C;L=B;M=21}}while(0);do{if((M|0)==21){B=a+28|0;if((H|0)==0){O=0;break}else{P=0}do{C=lz(c[o>>2]|0)|0;I=c[c[B>>2]>>2]|0;J=IDb(C&255,0,L,K,256,0)|0;C=F;Q=IDb(P,(P|0)<0|0?-1:0,D,E,100,0)|0;jT(I,J,C,Q,F,0,0,1)|0;P=P+1|0;}while((P|0)<100);c[G+24>>2]=1;break a}}while(0);do{lz(c[o>>2]|0)|0;O=O+1|0;}while((O|0)<100)}}while(0);if((y&8|0)!=0){Vy(c[o>>2]|0,4,0)|0;}G=vz(c[o>>2]|0)|0;if(!((G|0)==1281455718|(G|0)==1279348037)){R=A;S=z;break}Vy(c[o>>2]|0,17,0)|0;G=uz(c[o>>2]|0)|0;E=G>>>12;D=r+28|0;c[D>>2]=E;B=r+32|0;c[B>>2]=G&4095;G=E+529|0;c[k+448>>2]=G;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){c[f>>2]=1;c[f+4>>2]=c[d+12>>2];E=KDb(G,0,f,k+40|0)|0;c[n>>2]=E;c[n+4>>2]=F}E=c[B>>2]|0;yDb(a,48,1981992,(N=i,i=i+16|0,c[N>>2]=c[D>>2],c[N+8>>2]=E,N)|0);i=N;R=A;S=z}else{R=0;S=0}}while(0);w=c[o>>2]|0;E=YGb(q,p,36,0)|0;Ty(w,E,F,0)|0;do{if((vz(c[o>>2]|0)|0)==1447187017){if((tz(c[o>>2]|0)|0)!=1){T=R;U=S;break}Vy(c[o>>2]|0,4,0)|0;E=vz(c[o>>2]|0)|0;T=E;U=vz(c[o>>2]|0)|0}else{T=R;U=S}}while(0);E=(U|0)!=0;w=E^1;D=(T|0)==0;if(D&w){break}B=c[o>>2]|0;G=YGb(v,u,q,p)|0;Ty(B,G,F,0)|0;if(E){c[g>>2]=j;c[g+4>>2]=c[d+12>>2];E=KDb(U,0,g,k+40|0)|0;G=k+56|0;c[G>>2]=E;c[G+4>>2]=F}G=T;E=0;if(!(D|w|s)){w=c[d+12>>2]<<3;D=gHb(U,0,j,0)|0;B=IDb(G,E,w,(w|0)<0|0?-1:0,D,F)|0;c[(c[m>>2]|0)+72>>2]=B}c[r+40>>2]=x;B=r+16|0;c[B>>2]=G;c[B+4>>2]=E;l=0;i=b;return l|0}}while(0);Ty(c[o>>2]|0,q,p,0)|0;l=0;i=b;return l|0}function aJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+12>>2]|0;e=a+16|0;a=Ty(c[e>>2]|0,0,0,1)|0;f=F;g=d+8|0;d=c[g>>2]|0;h=c[g+4>>2]|0;g=0;if(((h|0)>(g|0)|(h|0)==(g|0)&d>>>0>128>>>0)&((f|0)<(h|0)|(f|0)==(h|0)&a>>>0<d>>>0)){g=ZGb(d,h,a,f)|0;f=F;a=0;i=(f|0)<(a|0)|(f|0)==(a|0)&g>>>0<1024>>>0?g:1024}else{i=1024}g=TS(c[e>>2]|0,b,i)|0;if((g|0)<1){j=(g|0)<0?g:-541478725;return j|0}i=b+36|0;c[i>>2]=c[i>>2]&-3;c[b+32>>2]=0;if((g|0)>127){i=g-128|0;e=(PGb((c[b+24>>2]|0)+i|0,2074296,3)|0)==0;k=e?i:g}else{k=g}c[b+28>>2]=k;j=k;return j|0}function bJ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;b=i;i=i+64|0;g=b|0;h=b+40|0;j=c[a+12>>2]|0;k=c[c[a+28>>2]>>2]|0;l=oT(k,d,e,f)|0;m=f&1;f=(m|0)==0;n=(m<<1^2)-1|0;do{if((c[j+40>>2]|0)==0){o=7}else{m=k+56|0;p=c[m+4>>2]|0;q=0;if(!((p|0)>(q|0)|(p|0)==(q|0)&(c[m>>2]|0)>>>0>0>>>0)){o=7;break}q=j+16|0;p=c[q+4>>2]|0;r=a+1248|0;s=c[r+4>>2]|0;if(!((p|0)>(s|0)|(p|0)==(s|0)&(c[q>>2]|0)>>>0>(c[r>>2]|0)>>>0)){o=7;break}s=Wy(c[a+16>>2]|0)|0;p=F;t=c[r>>2]|0;u=c[r+4>>2]|0;r=(p|0)>(u|0)|(p|0)==(u|0)&s>>>0>t>>>0;v=c[q>>2]|0;w=c[q+4>>2]|0;q=ZGb(r?s:v,r?p:w,t,u)|0;p=F;r=c[m>>2]|0;s=c[m+4>>2]|0;m=ZGb(v,w,t,u)|0;w=IDb(r,s,q,p,m,F)|0;m=F;s=0;if((e|0)<(s|0)|(e|0)==(s|0)&d>>>0<0>>>0){x=0;y=0}else{s=(m|0)<(e|0)|(m|0)==(e|0)&w>>>0<d>>>0;x=s?m:e;y=s?w:d}s=h+8|0;c[s>>2]=y;c[s+4>>2]=x;s=IDb(y,x,q,p,w,m)|0;m=YGb(t,u,s,F)|0;s=h|0;c[s>>2]=m;c[s+4>>2]=F;z=h}}while(0);do{if((o|0)==7){if((c[j+24>>2]|0)!=0){if((l|0)<0){A=l;i=b;return A|0}else{z=(c[k+400>>2]|0)+(l*24|0)|0;break}}h=0;if((e|0)<(h|0)|(e|0)==(h|0)&d>>>0<1>>>0){B=(c[j+28>>2]|0)+529|0}else{B=0}c[k+448>>2]=B;A=-1;i=b;return A|0}}while(0);B=a+16|0;if(f){C=z|0}else{f=c[B>>2]|0;d=z|0;e=YGb(c[d>>2]|0,c[d+4>>2]|0,-4096,-1)|0;l=F;h=0;x=(l|0)>(h|0)|(l|0)==(h|0)&e>>>0>0>>>0;Ty(f,x?e:0,x?l:0,0)|0;C=d}d=Ty(c[B>>2]|0,c[C>>2]|0,c[C+4>>2]|0,0)|0;l=F;x=0;if((l|0)<(x|0)|(l|0)==(x|0)&d>>>0<0>>>0){A=d;i=b;return A|0}d=g|0;x=0;l=0;a:while(1){if((l|0)>=4096){D=x;break}e=ba(l,n)|0;f=YGb(c[C>>2]|0,c[C+4>>2]|0,e,(e|0)<0|0?-1:0)|0;e=F;h=Ty(c[B>>2]|0,f,e,0)|0;y=F;s=0;do{if((y|0)<(s|0)|(y|0)==(s|0)&h>>>0<0>>>0){E=h;o=25}else{m=vz(c[B>>2]|0)|0;if((m&-2097152|0)!=-2097152|(m&393216|0)==0|(m&61440|0)==61440|(m&3072|0)==3072){G=0;break}if((_Na(g,m)|0)==1){G=0;break}E=c[d>>2]|0;o=25}}while(0);do{if((o|0)==25){o=0;if((E|0)<0){G=0;break}h=YGb(E,(E|0)<0|0?-1:0,f,e)|0;s=F;y=Ty(c[B>>2]|0,h,s,0)|0;m=F;u=0;if((m|0)<(u|0)|(m|0)==(u|0)&y>>>0<0>>>0){H=y}else{y=vz(c[B>>2]|0)|0;if((y&-2097152|0)!=-2097152|(y&393216|0)==0|(y&61440|0)==61440|(y&3072|0)==3072){G=1;break}if((_Na(g,y)|0)==1){G=1;break}H=c[d>>2]|0}if((H|0)<0){G=1;break}y=YGb(H,(H|0)<0|0?-1:0,h,s)|0;s=Ty(c[B>>2]|0,y,F,0)|0;y=F;h=0;if((y|0)<(h|0)|(y|0)==(h|0)&s>>>0<0>>>0){I=s}else{s=vz(c[B>>2]|0)|0;if((s&-2097152|0)!=-2097152|(s&393216|0)==0|(s&61440|0)==61440|(s&3072|0)==3072){G=2;break}if((_Na(g,s)|0)==1){G=2;break}I=c[d>>2]|0}if((I|0)<0){G=2}else{D=3;break a}}}while(0);x=G;l=l+1|0}G=c[B>>2]|0;B=ba((D|0)==3?l:0,n)|0;n=YGb(B,(B|0)<0|0?-1:0,c[C>>2]|0,c[C+4>>2]|0)|0;C=Ty(G,n,F,0)|0;n=F;G=0;if((n|0)<(G|0)|(n|0)==(G|0)&C>>>0<0>>>0){A=C;i=b;return A|0}C=z+8|0;lT(a,k,c[C>>2]|0,c[C+4>>2]|0);a=c[C+4>>2]|0;z=0;if((a|0)<(z|0)|(a|0)==(z|0)&(c[C>>2]|0)>>>0<1>>>0){J=(c[j+28>>2]|0)+529|0}else{J=0}c[k+448>>2]=J;A=0;i=b;return A|0}function cJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;d=c[a+12>>2]|0;e=d+32|0;f=c[e>>2]|0;if(!((f|0)==0|(f|0)==3|(f|0)==4)){yDb(a,16,2147440,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-22;i=b;return h|0}j=d+3288|0;c[j>>2]=-1;k=a+24|0;l=c[k>>2]|0;do{if((l|0)!=0){m=c[a+28>>2]|0;n=0;o=-1;p=l;while(1){q=c[(c[m+(n<<2)>>2]|0)+8>>2]|0;r=c[q+8>>2]|0;if((r|0)==1){if((o|0)>-1){s=8;break}if((c[q+48>>2]|0)!=86017){s=8;break}c[j>>2]=n;t=n;u=c[k>>2]|0}else if((r|0)==0){t=o;u=p}else{s=10;break}r=n+1|0;if(r>>>0<u>>>0){n=r;o=t;p=u}else{s=12;break}}if((s|0)==8){yDb(a,16,2140976,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}else if((s|0)==10){yDb(a,16,2135152,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}else if((s|0)==12){if((t|0)<0){break}p=u-1|0;o=d+3292|0;c[o>>2]=p;n=(f|0)==0;do{if((p|0)==0){if(!n){s=18}}else{if(!n){s=18;break}yDb(a,16,2122600,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}}while(0);do{if((s|0)==18){n=d+8|0;nX(n,c[a+16>>2]|0,f,2117568);p=oX(a,n)|0;if((p|0)<0){h=p;i=b;return h|0}if((c[o>>2]|0)==0){break}else{h=0}i=b;return h|0}}while(0);if((c[e>>2]|0)!=0){rX(d+8|0,c[a+16>>2]|0,c[a+1316>>2]|0)}hJ(a);h=0;i=b;return h|0}}}while(0);yDb(a,16,2128768,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}function dJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=b+32|0;h=c[g>>2]|0;do{if((h|0)==(c[f+3288>>2]|0)){if((c[f+3292>>2]|0)==0){j=iJ(a,b)|0;i=d;return j|0}k=cEb(88)|0;l=k;c[e>>2]=l;if((k|0)==0){j=-12;i=d;return j|0}m=EZ(k,b)|0;if((m|0)<0){$Db(e);j=m;i=d;return j|0}m=f+3300|0;k=c[m>>2]|0;if((k|0)==0){c[f+3296>>2]=l}else{c[k+80>>2]=l}c[m>>2]=c[e>>2]}else{m=a+28|0;l=(c[(c[m>>2]|0)+(h<<2)>>2]|0)+64|0;if((c[l>>2]|0)==1&(c[l+4>>2]|0)==0){yDb(a,24,2154520,(l=i,i=i+8|0,c[l>>2]=h,l)|0);i=l}l=f+3292|0;if((c[l>>2]|0)==0){j=0;i=d;return j|0}k=(c[(c[m>>2]|0)+(c[g>>2]<<2)>>2]|0)+64|0;m=c[k+4>>2]|0;n=0;if((m|0)>(n|0)|(m|0)==(n|0)&(c[k>>2]|0)>>>0>0>>>0){j=0;i=d;return j|0}k=qX(a,f+8|0,b)|0;if((k|0)<0){j=k;i=d;return j|0}k=(c[l>>2]|0)-1|0;c[l>>2]=k;if((k|0)!=0){break}k=gJ(a)|0;if((k|0)<0){j=k}else{break}i=d;return j|0}}while(0);j=0;i=d;return j|0}function eJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+128|0;e=d|0;f=b+12|0;g=c[f>>2]|0;if((c[g+3292>>2]|0)!=0){yDb(b,24,1951032,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;gJ(b)|0}do{if((c[g+36>>2]|0)!=0){h=e|0;TGb(h|0,0,128)|0;a[h]=84;a[e+1|0]=65;a[e+2|0]=71;j=b+1140|0;k=BBb(c[j>>2]|0,1903008,0,0)|0;l=(k|0)!=0;if(l){sAb(e+3|0,c[k+4>>2]|0,31)|0}k=BBb(c[j>>2]|0,1883048,0,0)|0;m=(k|0)!=0;if(m){sAb(e+33|0,c[k+4>>2]|0,31)|0}k=BBb(c[j>>2]|0,2341136,0,0)|0;n=(k|0)!=0;if(n){sAb(e+63|0,c[k+4>>2]|0,31)|0}k=BBb(c[j>>2]|0,2318080,0,0)|0;o=(k|0)!=0;if(o){sAb(e+93|0,c[k+4>>2]|0,5)|0}k=BBb(c[j>>2]|0,2296184,0,0)|0;p=(k|0)!=0;if(p){sAb(e+97|0,c[k+4>>2]|0,31)|0}k=(m&1)+(l&1)+(n&1)+(o&1)+(p&1)|0;p=BBb(c[j>>2]|0,2279328,0,0)|0;if((p|0)==0){q=k}else{a[e+125|0]=0;a[e+126|0]=gd(c[p+4>>2]|0)|0;q=k+1|0}k=e+127|0;a[k]=-1;p=BBb(c[j>>2]|0,2264040,0,0)|0;a:do{if((p|0)==0){r=q}else{j=p+4|0;o=0;while(1){if((o|0)>=148){r=q;break a}if((yAb(c[j>>2]|0,c[1205192+(o<<2)>>2]|0)|0)==0){break}else{o=o+1|0}}a[k]=o;r=q+1|0}}while(0);if((r|0)<=0){break}Ry(c[b+16>>2]|0,h,128)}}while(0);r=g+48|0;if((c[r>>2]|0)==0&(c[r+4>>2]|0)==0){i=d;return 0}r=c[f>>2]|0;f=b+16|0;if((c[r+3284>>2]|0)==0){b=r+48|0;Ty(c[f>>2]|0,c[b>>2]|0,c[b+4>>2]|0,0)|0;Yy(c[f>>2]|0,1868983881);s=b}else{s=r+48|0}b=c[f>>2]|0;g=YGb(c[s>>2]|0,c[s+4>>2]|0,8,0)|0;Ty(b,g,F,0)|0;Zy(c[f>>2]|0,c[r+56>>2]|0);g=r+60|0;Zy(c[f>>2]|0,c[g>>2]|0);Py(c[f>>2]|0,0);b=r+72|0;s=r+80|0;r=1;do{q=s+((((ba(c[b>>2]|0,r)|0)>>>0)/100|0)<<3)|0;e=c[q>>2]|0;k=c[g>>2]|0;p=hHb(e<<8|0>>>24,c[q+4>>2]<<8|e>>>24,k,(k|0)<0|0?-1:0)|0;k=p;Py(c[f>>2]|0,(k|0)>255?255:k);r=r+1|0;}while((r|0)<100);Ty(c[f>>2]|0,0,0,2)|0;i=d;return 0}function fJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;b=1204600;while(1){d=c[b+32>>2]|0;if((d|0)==0){e=-1;f=4;break}if((d|0)==(a|0)){e=1128878145;f=4;break}else{b=b+36|0}}if((f|0)==4){return e|0}return 0}function gJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+8|0;d=b|0;e=c[a+12>>2]|0;rX(e+8|0,c[a+16>>2]|0,c[a+1316>>2]|0);hJ(a);f=e+3296|0;g=c[f>>2]|0;c[d>>2]=g;if((g|0)==0){h=0;j=e+3300|0;k=j;c[k>>2]=0;i=b;return h|0}l=d;m=0;n=1;o=g;while(1){if((n|0)==0){p=0;q=m;r=o}else{g=iJ(a,o|0)|0;p=(g|0)<0?0:n;q=g;r=c[d>>2]|0}BZ(r|0);c[f>>2]=c[r+80>>2];$Db(l);g=c[f>>2]|0;c[d>>2]=g;if((g|0)==0){h=q;break}else{m=q;n=p;o=g}}j=e+3300|0;k=j;c[k>>2]=0;i=b;return h|0}function hJ(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+40|0;g=f|0;h=c[b+12>>2]|0;j=c[(c[(c[b+28>>2]|0)+(c[h+3288>>2]<<2)>>2]|0)+8>>2]|0;k=(c[j+88>>2]&8388608|0)!=0?2235832:2222864;l=b+16|0;if((c[(c[l>>2]|0)+88>>2]|0)==0){i=f;return}if((c[h+40>>2]|0)==0){i=f;return}m=j+412|0;n=0;while(1){if(!(n>>>0<3>>>0)){o=0;break}p=c[m>>2]|0;q=e[1743632+(n<<1)>>1]|0;if((p|0)==(q|0)){o=1572864;break}if((p|0)==(q>>>1|0)){o=1048576;break}if((p|0)==(q>>>2|0)){o=0;break}else{n=n+1|0}}if((n|0)==3){yDb(b,24,2213304,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;i=f;return}m=c[j+416>>2]|0;if((m|0)==1){s=192}else if((m|0)==2){s=0}else{yDb(b,24,2203960,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;i=f;return}b=n<<10|o|s|-1900544;s=g+20|0;o=j+72|0;n=2147483647;m=-1;q=1;while(1){_Na(g,q<<12|b)|0;p=(c[s>>2]|0)-(c[o>>2]|0)|0;t=(p|0)>-1?p:-p|0;p=(t|0)<(n|0);u=p?q:m;v=q+1|0;if((v|0)<15){n=p?t:n;m=u;q=v}else{break}}if(!((u|0)>-1)){yDb(0,0,2196496,(r=i,i=i+24|0,c[r>>2]=2183800,c[r+8>>2]=2168752,c[r+16>>2]=171,r)|0);i=r;Cd()}if((u|0)==15){i=f;return}r=g+24|0;q=g+36|0;m=g|0;n=b;b=u;while(1){u=b<<12;w=u|n;_Na(g,w)|0;x=d[((c[r>>2]|0)==1)+(1840+(((c[q>>2]|0)==1)<<1))|0]|0;y=x+144|0;if((y|0)<=(c[m>>2]|0)){break}o=b+1|0;if((o|0)==15){z=30;break}else{n=w^u;b=o}}if((z|0)==30){i=f;return}Zy(c[l>>2]|0,w);Qy(c[l>>2]|0,0,x);x=Ty(c[l>>2]|0,0,0,1)|0;w=h+48|0;c[w>>2]=x;c[w+4>>2]=F;Yy(c[l>>2]|0,1735289176);Zy(c[l>>2]|0,7);c[h+60>>2]=c[m>>2];c[h+64>>2]=1;c[h+68>>2]=0;c[h+72>>2]=0;Zy(c[l>>2]|0,0);Zy(c[l>>2]|0,0);h=0;do{Py(c[l>>2]|0,((h*255|0|0)/100|0)&255);h=h+1|0;}while((h|0)<100);h=a[k]|0;if(h<<24>>24==0){A=0;B=c[l>>2]|0;z=28}else{w=1;x=h;while(1){Py(c[l>>2]|0,x<<24>>24);if(!(w>>>0<(SGb(k|0)|0)>>>0)){break}h=a[k+w|0]|0;w=w+1|0;x=h}x=c[l>>2]|0;if((w|0)<21){A=w;B=x;z=28}else{C=x}}if((z|0)==28){while(1){z=0;Py(B,0);x=A+1|0;w=c[l>>2]|0;if((x|0)<21){A=x;B=w;z=28}else{C=w;break}}}z=(c[j+116>>2]|0)-529|0;hz(C,(z|0)>0?z<<12:0);Qy(c[l>>2]|0,0,(c[m>>2]|0)-y|0);i=f;return}function iJ(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+40|0;f=e|0;g=c[a+12>>2]|0;h=g;j=c[b+24>>2]|0;do{if((j|0)!=0){k=b+28|0;l=c[k>>2]|0;if((l|0)<=3){break}m=j;n=fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;if((n&-2097152|0)!=-2097152|(n&393216|0)==0|(n&61440|0)==61440|(n&3072|0)==3072){yDb(a,24,2249040,(m=i,i=i+16|0,c[m>>2]=l,c[m+8>>2]=n,m)|0);i=m;o=lO(a,b)|0;i=e;return o|0}_Na(f,n)|0;n=g+3280|0;m=c[n>>2]|0;l=f+20|0;if((m|0)==0){p=c[l>>2]|0;c[n>>2]=p;q=p}else{q=m}m=c[l>>2]|0;if(!((m|0)!=0&(q|0)==(m|0))){c[g+3284>>2]=1}m=g+48|0;if((c[m>>2]|0)==0&(c[m+4>>2]|0)==0){break}m=g+56|0;c[m>>2]=(c[m>>2]|0)+1;m=g+68|0;l=(c[m>>2]|0)+1|0;c[m>>2]=l;p=g+60|0;n=(c[p>>2]|0)+(c[k>>2]|0)|0;c[p>>2]=n;p=g+64|0;if((c[p>>2]|0)!=(l|0)){break}l=g+72|0;k=h+80+(c[l>>2]<<3)|0;c[k>>2]=n;c[k+4>>2]=(n|0)<0|0?-1:0;n=(c[l>>2]|0)+1|0;c[l>>2]=n;if((n|0)==400){n=1;do{k=h+80+(n<<3)|0;r=c[k+4>>2]|0;s=h+80+(n>>1<<3)|0;c[s>>2]=c[k>>2];c[s+4>>2]=r;n=n+2|0;}while((n|0)<400);c[p>>2]=c[p>>2]<<1;c[l>>2]=200}c[m>>2]=0}}while(0);o=lO(a,b)|0;i=e;return o|0}function jJ(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==77){if((a[d+1|0]|0)!=80){break}if((a[d+2|0]|0)!=43){break}b=a[d+3|0]|0;if((b<<24>>24|0)==23|(b<<24>>24|0)==7){e=100}else{break}return e|0}}while(0);e=0;return e|0}function kJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[b+12>>2]|0;f=b+16|0;if((qz(c[f>>2]|0)|0)!=2838605){yDb(b,16,2140056,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=d;return h|0}j=lz(c[f>>2]|0)|0;c[e>>2]=j;if(!((j|0)==7|(j|0)==23)){yDb(b,16,2073952,(g=i,i=i+8|0,c[g>>2]=j,g)|0);i=g;h=-1094995529;i=d;return h|0}j=rz(c[f>>2]|0)|0;k=e+12|0;c[k>>2]=j;l=j;m=0<<4|l>>>28;n=0;if(m>>>0>n>>>0|m>>>0==n>>>0&(l<<4|0>>>28)>>>0>-2>>>0){yDb(b,16,2025496,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=d;return h|0}do{if((j|0)==0){yDb(b,24,1950912,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}else{l=WDb(j<<4)|0;c[e+16>>2]=l;if((l|0)!=0){break}yDb(b,16,1981768,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-12;i=d;return h|0}}while(0);c[e+4>>2]=0;c[e+8>>2]=-1;c[e+20>>2]=8;c[e+24>>2]=0;e=LT(b,0)|0;if((e|0)==0){h=-12;i=d;return h|0}g=e+8|0;j=c[g>>2]|0;c[j+8>>2]=1;c[j+48>>2]=86044;c[j+416>>2]=2;l=j+448|0;c[l>>2]=3;c[l+4>>2]=0;c[j+792>>2]=16;if((CT(j,c[f>>2]|0,16)|0)<0){h=-12;i=d;return h|0}j=c[g>>2]|0;g=c[648648+((a[(c[j+96>>2]|0)+2|0]&3)<<2)>>2]|0;c[j+412>>2]=g;MT(e,32,1152,g);g=e+48|0;c[g>>2]=0;c[g+4>>2]=0;g=e+56|0;c[g>>2]=c[k>>2];c[g+4>>2]=0;g=c[f>>2]|0;if((c[g+88>>2]|0)==0){h=0;i=d;return h|0}k=Ty(g,0,0,1)|0;g=F;tx(b)|0;if((BBb(c[b+1140>>2]|0,9203088,0,2)|0)==0){mX(b)}Ty(c[f>>2]|0,k,g,0)|0;h=0;i=d;return h|0}function lJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[b+12>>2]|0;f=e+4|0;g=c[f>>2]|0;h=e+12|0;i=c[h>>2]|0;if(!(g>>>0<i>>>0|(i|0)==0)){j=-541478725;return j|0}i=e+8|0;if((g|0)==((c[i>>2]|0)+1|0)){k=g;l=c[e+20>>2]|0;m=b+16|0}else{n=b+16|0;o=e+16|0;p=(c[o>>2]|0)+(g<<4)|0;Ty(c[n>>2]|0,c[p>>2]|0,c[p+4>>2]|0,0)|0;p=c[f>>2]|0;q=c[(c[o>>2]|0)+(p<<4)+12>>2]|0;c[e+20>>2]=q;k=p;l=q;m=n}c[i>>2]=k;c[f>>2]=k+1;k=e+20|0;i=Ty(c[m>>2]|0,0,0,1)|0;n=F;q=rz(c[m>>2]|0)|0;if((l|0)<13){r=q>>>((12-l|0)>>>0)}else{r=(rz(c[m>>2]|0)|0)>>>((44-l|0)>>>0)|q<<l-12}q=l+20|0;Ty(c[m>>2]|0,i,n,0)|0;p=l+51+(r&1048575)>>3&-4;o=e+24|0;do{if((g|0)==(c[o>>2]|0)){if((c[h>>2]|0)==0){break}s=c[e+16>>2]|0;t=s+(g<<4)|0;c[t>>2]=i;c[t+4>>2]=n;c[s+(g<<4)+8>>2]=p;c[s+(g<<4)+12>>2]=l;s=g;t=(g|0)<0|0?-1:0;jT(c[c[b+28>>2]>>2]|0,s,t,s,t,p,0,1)|0;c[o>>2]=(c[o>>2]|0)+1}}while(0);c[k>>2]=r+q&31;r=wZ(d,p)|0;if((r|0)<0){j=r;return j|0}r=d+24|0;a[c[r>>2]|0]=q;q=c[h>>2]|0;if((c[f>>2]|0)>>>0>q>>>0){u=(q|0)!=0|0}else{u=0}a[(c[r>>2]|0)+1|0]=u;a[(c[r>>2]|0)+2|0]=0;a[(c[r>>2]|0)+3|0]=0;c[d+32>>2]=0;u=d+8|0;c[u>>2]=g;c[u+4>>2]=(g|0)<0|0?-1:0;g=mz(c[m>>2]|0,(c[r>>2]|0)+4|0,p)|0;if((c[k>>2]|0)!=0){Ty(c[m>>2]|0,-4,-1,1)|0;}if((g|0)<(p|0)){BZ(d);j=(g|0)<0?g:-5;return j|0}else{c[d+28>>2]=g+4;j=0;return j|0}return 0}function mJ(a){a=a|0;$Db((c[a+12>>2]|0)+16|0);return 0}function nJ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+80|0;h=g|0;j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[a+12>>2]|0;k=YGb(d,e,-32,-1)|0;l=F;m=0;n=(l|0)>(m|0)|(l|0)==(m|0)&k>>>0>0>>>0;m=oT(j,n?k:0,n?l:0,f)|0;do{if((m|0)>-1){f=c[j+400>>2]|0;n=f+(((c[j+404>>2]|0)-1|0)*24|0)+8|0;o=c[n+4>>2]|0;if((o|0)<(l|0)|(o|0)==(l|0)&(c[n>>2]|0)>>>0<k>>>0){break}c[b+4>>2]=c[f+(m*24|0)>>2];p=0;i=g;return p|0}}while(0);m=0;if((e|0)<(m|0)|(e|0)==(m|0)&d>>>0<0>>>0){p=-1;i=g;return p|0}m=0;if(!((m|0)>(e|0)|(m|0)==(e|0)&(c[b+12>>2]|0)>>>0>d>>>0)){p=-1;i=g;return p|0}d=b+4|0;e=c[d>>2]|0;m=c[b+24>>2]|0;if((m|0)==0){q=e}else{b=m-1|0;c[d>>2]=b;q=b}b=0;if(!((b|0)<(l|0)|(b|0)==(l|0)&q>>>0<k>>>0)){p=0;i=g;return p|0}while(1){r=gT(a,h)|0;if((r|0)<0){break}BZ(h);q=0;if(!((q|0)<(l|0)|(q|0)==(l|0)&(c[d>>2]|0)>>>0<k>>>0)){p=0;s=12;break}}if((s|0)==12){i=g;return p|0}c[d>>2]=e;p=r;i=g;return p|0}function oJ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=c[b+4>>2]|0;f=c[b+8>>2]|0;b=e+(f+4)|0;if((f|0)<16){g=0;return g|0}h=e;if((d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)!=1262702669){g=0;return g|0}h=f+7|0;f=e+h|0;if((h|0)>4){i=e+4|0}else{g=0;return g|0}a:while(1){e=a[i]|0;if(e<<24>>24==83){j=(a[i+1|0]|0)==72}else{if((e-65&255)>>>0>25>>>0){g=0;k=17;break}else{j=0}}if(((a[i+1|0]|0)-65&255)>>>0>25>>>0){g=0;k=17;break}e=0;h=0;l=0;m=i+2|0;while(1){n=d[m]|0;o=m+1|0;p=n&127|(l<<7|0>>>25);q=h<<7|l>>>25|0;r=e+1|0;if((r|0)>10){g=0;k=17;break a}if((n&128|0)==0){break}else{e=r;h=q;l=p;m=o}}s=ZGb(p,q,r,(r|0)<0|0?-1:0)|0;t=F;l=0;if((t|0)<(l|0)|(t|0)==(l|0)&s>>>0<2>>>0){g=0;k=17;break}if(!((m+(s-1)|0)>>>0<b>>>0)){g=49;k=17;break}if(j){k=14;break}l=YGb(s,t,-2,0)|0;h=m+(l+1)|0;if(h>>>0<f>>>0){i=h}else{g=0;k=17;break}}if((k|0)==14){i=YGb(s,t,-11,-1)|0;t=F;s=0;if(t>>>0>s>>>0|t>>>0==s>>>0&i>>>0>17>>>0){g=0;return g|0}i=o;g=(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)==0?0:100;return g|0}else if((k|0)==17){return g|0}return 0}function pJ(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;e=c[a+12>>2]|0;f=a+16|0;g=c[f>>2]|0;h=Ty(g,0,0,1)|0;j=e+8|0;c[j>>2]=h;c[j+4>>2]=F;if((rz(g)|0)!=1262702669){yDb(a,16,1925056,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=b;return l|0}a:do{if((Xy(g)|0)==0){while(1){j=Ty(g,0,0,1)|0;h=F;m=Ty(g,0,0,1)|0;n=F;o=pz(g)|0;p=Bz(g)|0;q=F;r=Ty(g,0,0,1)|0;s=ZGb(m,n,r,F)|0;t=YGb(s,F,p,q)|0;u=F;if((o|0)==18515){break}sJ(a,o,j,h,t,u);if((Xy(g)|0)!=0){break a}}h=Ty(g,0,0,1)|0;j=F;Vy(g,4,0)|0;o=lz(g)|0;c[e>>2]=o;if((o|0)!=8){yDb(a,16,1882984,(k=i,i=i+8|0,c[k>>2]=o,k)|0);i=k;l=-1163346256;i=b;return l|0}o=Bz(g)|0;q=e+16|0;c[q>>2]=o;c[q+4>>2]=F;Bz(g)|0;o=LT(a,0)|0;if((o|0)==0){l=-12;i=b;return l|0}p=o+8|0;s=c[p>>2]|0;c[s+8>>2]=1;c[s+48>>2]=86051;c[s+792>>2]=16;if((CT(s,g,2)|0)<0){l=-12;i=b;return l|0}s=c[p>>2]|0;r=c[s+96>>2]|0;n=r+1|0;c[s+416>>2]=((d[n]|0)>>>4)+1;m=c[649936+((d[r]|0)>>>5<<2)>>2]|0;c[s+412>>2]=m;MT(o,32,1152<<((d[n]|0)<<1&6),m);m=o+48|0;c[m>>2]=0;c[m+4>>2]=0;m=1152<<((d[(c[(c[p>>2]|0)+96>>2]|0)+1|0]|0)<<1&6);p=eHb(c[q>>2]|0,c[q+4>>2]|0,m,(m|0)<0|0?-1:0)|0;m=o+56|0;c[m>>2]=p;c[m+4>>2]=F;m=Ty(g,0,0,1)|0;p=ZGb(h,j,m,F)|0;m=YGb(p,F,t,u)|0;p=F;j=0;if((p|0)>(j|0)|(p|0)==(j|0)&m>>>0>0>>>0){Vy(g,m,p)|0;}if((c[g+88>>2]|0)==0){l=0;i=b;return l|0}p=Ty(c[f>>2]|0,0,0,1)|0;m=F;j=tx(a)|0;h=e+24|0;c[h>>2]=j;c[h+4>>2]=F;Ty(c[f>>2]|0,p,m,0)|0;l=0;i=b;return l|0}}while(0);yDb(a,16,1902944,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=b;return l|0}function qJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[a+12>>2]|0;e=a+16|0;if((Xy(c[e>>2]|0)|0)!=0){f=-541478725;return f|0}g=d+24|0;while(1){d=Ty(c[e>>2]|0,0,0,1)|0;h=F;i=c[g>>2]|0;j=c[g+4>>2]|0;if(!((i|0)==0&(j|0)==0|((h|0)<(j|0)|(h|0)==(j|0)&d>>>0<i>>>0))){f=-541478725;k=9;break}i=c[e>>2]|0;j=Ty(i,0,0,1)|0;l=F;m=pz(i)|0;n=Bz(i)|0;o=F;p=Ty(i,0,0,1)|0;i=ZGb(j,l,p,F)|0;q=YGb(i,F,n,o)|0;o=F;n=0;if((o|0)<(n|0)|(o|0)==(n|0)&q>>>0<0>>>0){f=-1;k=9;break}if((m|0)==17747){f=-5;k=9;break}else if((m|0)==20545){k=6;break}sJ(a,m,d,h,q,o);if((Xy(c[e>>2]|0)|0)!=0){f=-541478725;k=9;break}}if((k|0)==6){if((TS(c[e>>2]|0,b,q)|0)<0){f=-12;return f|0}c[b+32>>2]=0;c[b+48>>2]=1;f=0;return f|0}else if((k|0)==9){return f|0}return 0}function rJ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=oT(g,d,e,f)|0;if((b|0)<0){h=-1;return h|0}f=g+400|0;e=(c[f>>2]|0)+(b*24|0)|0;d=Ty(c[a+16>>2]|0,c[e>>2]|0,c[e+4>>2]|0,0)|0;e=F;i=0;if((e|0)<(i|0)|(e|0)==(i|0)&d>>>0<0>>>0){h=-1;return h|0}d=(c[f>>2]|0)+(b*24|0)+8|0;lT(a,g,c[d>>2]|0,c[d+4>>2]|0);h=0;return h|0}function sJ(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;k=i;l=b+16|0;m=c[l>>2]|0;if((e|0)!=20307){Vy(m,h,j)|0;i=k;return}e=Ty(m,0,0,1)|0;n=YGb(e,F,h,j)|0;j=F;h=Bz(m)|0;e=F;o=c[b+12>>2]|0;a:do{if((c[b+24>>2]|0)==0){yDb(b,16,2140008,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}else{q=YGb(h,e,f,g)|0;Ty(c[l>>2]|0,q,F,0)|0;q=c[l>>2]|0;r=Ty(q,0,0,1)|0;s=F;t=pz(q)|0;u=Bz(q)|0;v=F;w=Ty(q,0,0,1)|0;q=ZGb(r,s,w,F)|0;w=YGb(q,F,u,v)|0;v=F;if((t|0)!=21587){yDb(b,16,2073912,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}t=YGb(w,v,-1,-1)|0;u=F;q=0;if(u>>>0>q>>>0|u>>>0==q>>>0&t>>>0>214748363>>>0){yDb(b,16,2025472,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}t=YGb(w,v,16,0)|0;q=WDb(t)|0;if((q|0)==0){break}t=w;u=mz(c[l>>2]|0,q,t)|0;if(!((u|0)==(w|0)&(((u|0)<0|0?-1:0)|0)==(v|0))){yDb(b,16,1981744,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;ZDb(q);break}TGb(q+t|0,0,16)|0;t=w<<3|0>>>29;w=t>>>0>2147483639>>>0;v=w?0:q;u=w?8:t+8|0;t=(u|0)>0|0;b:do{if((a[v]|0)>-1){x=0;y=0;z=t;A=14}else{w=0;s=0;r=0;B=t;while(1){C=v+(B>>>3)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7)>>>25;C=B+7|0;E=u>>>0>C>>>0?C:u;C=D|s;D=w|0;if((r|0)>=57){G=D;H=C;I=E;break b}J=C<<7|0>>>25;K=D<<7|C>>>25;C=((E|0)<(u|0))+E|0;if((d[v+(E>>>3)|0]&128>>>((E&7)>>>0)|0)==0){x=K;y=J;z=C;A=14;break}else{w=K;s=J;r=r+7|0;B=C}}}}while(0);if((A|0)==14){t=v+(z>>>3)|0;B=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(z&7)>>>25;t=z+7|0;G=x|0;H=B|y;I=u>>>0>t>>>0?t:u}t=0;do{if(!((G|0)>(t|0)|(G|0)==(t|0)&H>>>0>1073741823>>>0)){B=o+16|0;r=eHb(c[B>>2]|0,c[B+4>>2]|0,1152,0)|0;B=F;if((G|0)>(B|0)|(G|0)==(B|0)&H>>>0>r>>>0){break}r=v+(I>>>3)|0;B=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(I&7);r=I+4|0;s=u>>>0>r>>>0?r:u;r=o+8|0;w=b+28|0;C=((s|0)<(u|0))+s|0;c:do{if((d[v+(s>>>3)|0]&128>>>((s&7)>>>0)|0)==0){L=0;M=0;N=C;A=21}else{J=0;K=0;E=0;D=C;while(1){O=v+(D>>>3)|0;P=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(D&7)>>>25;O=D+7|0;Q=u>>>0>O>>>0?O:u;O=P|K;P=J|0;if((E|0)>=57){R=P;S=O;T=Q;break c}U=O<<7|0>>>25;V=P<<7|O>>>25;O=((Q|0)<(u|0))+Q|0;if((d[v+(Q>>>3)|0]&128>>>((Q&7)>>>0)|0)==0){L=V;M=U;N=O;A=21;break}else{J=V;K=U;E=E+7|0;D=O}}}}while(0);if((A|0)==21){C=v+(N>>>3)|0;s=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(N&7)>>>25;C=N+7|0;R=L|0;S=s|M;T=u>>>0>C>>>0?C:u}C=YGb(c[r>>2]|0,c[r+4>>2]|0,S,R)|0;s=F;jT(c[c[w>>2]>>2]|0,C,s,0,0,0,0,1)|0;D=((T|0)<(u|0))+T|0;d:do{if((d[v+(T>>>3)|0]&128>>>((T&7)>>>0)|0)==0){W=0;X=0;Y=D;A=32}else{E=0;K=0;J=0;O=D;while(1){U=v+(O>>>3)|0;V=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(O&7)>>>25;U=O+7|0;Q=u>>>0>U>>>0?U:u;U=V|K;V=E|0;if((J|0)>=57){Z=V;_=U;$=Q;break d}P=U<<7|0>>>25;aa=V<<7|U>>>25;U=((Q|0)<(u|0))+Q|0;if((d[v+(Q>>>3)|0]&128>>>((Q&7)>>>0)|0)==0){W=aa;X=P;Y=U;A=32;break}else{E=aa;K=P;J=J+7|0;O=U}}}}while(0);if((A|0)==32){D=v+(Y>>>3)|0;O=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(Y&7)>>>25;D=Y+7|0;Z=W|0;_=O|X;$=u>>>0>D>>>0?D:u}D=YGb(c[r>>2]|0,c[r+4>>2]|0,_,Z)|0;O=F;jT(c[c[w>>2]>>2]|0,D,O,1,0,0,0,1)|0;J=B>>>28;K=0;if((G|0)>(K|0)|(G|0)==(K|0)&H>>>0>2>>>0){K=$;E=2;U=O;O=D;D=s;P=C;while(1){aa=0;Q=K;while(1){if((aa|0)>=33){ba=Q;break}V=((Q|0)<(u|0))+Q|0;if((d[v+(Q>>>3)|0]&128>>>((Q&7)>>>0)|0)==0){aa=aa+1|0;Q=V}else{ba=V;break}}Q=v+(ba>>>3)|0;V=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(ba&7)>>>20;Q=ba+12|0;ca=V|aa<<12;if((V&1|0)==0){da=ca}else{da=-(ca&-2)|0}ca=da>>1;V=ZGb(O<<1|0>>>31,U<<1|O>>>31,P,D)|0;ea=YGb(V,F,ca,(ca|0)<0|0?-1:0)|0;ca=F;V=E<<J;jT(c[c[w>>2]>>2]|0,ea,ca,V,(V|0)<0|0?-1:0,0,0,1)|0;V=E+1|0;fa=(V|0)<0|0?-1:0;if((fa|0)<(G|0)|(fa|0)==(G|0)&V>>>0<H>>>0){K=u>>>0>Q>>>0?Q:u;E=V;D=U;U=ca;P=O;O=ea}else{break}}}ZDb(q);break a}}while(0);yDb(b,16,1950888,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);Ty(m,n,j,0)|0;i=k;return}function tJ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=c[b+8>>2]|0;if((e|0)<=0){f=0;return f|0}g=c[b+4>>2]|0;b=0;h=0;i=0;j=0;k=0;l=0;m=0;n=-256;while(1){o=d[g+l|0]|0;p=o|n;a:do{if((n|0)==256){q=d[g+(l+1)|0]|0;r=q<<8|(d[g+(l+2)|0]|0);s=g+e|0;t=g+(l+3)|0;u=a[t]|0;do{if((u&-64)<<24>>24==-128){v=a[g+(l+4)|0]&192;if((v|0)==64){w=0;break}if((v|0)==0){w=1;break}w=(v>>>2|0)==(a[g+(l+6)|0]&240|0)}else{w=0}}while(0);v=t;x=u;while(1){if(!(v>>>0<s>>>0)){break}y=v+1|0;if(!(x<<24>>24==-1)){break}v=y;x=a[y]|0}s=(x&-64)<<24>>24==64?v+2|0:v;u=a[s]|0;t=u&240;if((t|0)==48){z=a[s+2|0]&u&a[s+4|0]&a[s+5|0]&a[s+7|0]&a[s+9|0]&1}else if((t|0)==32){z=a[s+2|0]&u&a[s+4|0]&1}else{z=u<<24>>24==15|0}u=w|(z|0)!=0;if((q&192|0)==64){A=1}else{A=(q&240|0)==32|0}if((p|0)==443){B=m+1|0;C=l;D=k;E=j;F=i;G=h;H=b;break}else if((p|0)==442){I=20}do{if((I|0)==20){I=0;if((A|0)==0){break}B=m;C=l;D=k;E=j;F=i;G=h;H=b+1|0;break a}}while(0);q=(o&240|0)==224;v=u^1;if(!(q^1|v)){B=m;C=l;D=k;E=j;F=i+1|0;G=h;H=b;break}x=(o&224|0)==192;if(!(x^1|v)){B=m;C=r+l|0;D=k;E=j+1|0;F=i;G=h;H=b;break}s=(p|0)==445;if(!(s^1|v)){B=m;C=r+l|0;D=k;E=j;F=i;G=h+1|0;H=b;break}if(!((p|0)!=509|v)){B=m;C=l;D=k;E=j;F=i+1|0;G=h;H=b;break}if(q&v){B=m;C=l;D=k+1|0;E=j;F=i;G=h;H=b;break}if(x&v){B=m;C=l;D=k+1|0;E=j;F=i;G=h;H=b;break}else{B=m;C=l;D=(s&v&1)+k|0;E=j;F=i;G=h;H=b;break}}else{B=m;C=l;D=k;E=j;F=i;G=h;H=b}}while(0);o=C+1|0;if((o|0)<(e|0)){b=H;h=G;i=F;j=E;k=D;l=o;m=B;n=p<<8}else{break}}n=E+F|0;m=(n|0)>(D+1|0)?25:0;do{if((B|0)>(D|0)){if((B*9|0|0)>(H*10|0|0)){break}if((E|0)>12|(F|0)>3){f=52;return f|0}f=(H|0)>2?52:25;return f|0}}while(0);do{if((H|0)>(D|0)){if(((F+G+E|0)*10|0|0)<(H*9|0|0)){break}f=(H|0)>2?52:25;return f|0}}while(0);if(!((F|0)!=0^(E|0)!=0)){f=m;return f|0}if(!(((E|0)>4|(F|0)>1)&(B|0)==0&(H|0)==0)){f=m;return f|0}if(!((e|0)>2048&(n|0)>(D|0))){f=m;return f|0}if((E|0)>12){f=52;return f|0}f=(F|0)>((D<<1)+3|0)?52:25;return f|0}function uJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;d=c[a+12>>2]|0;e=a+16|0;f=Ty(c[e>>2]|0,0,0,1)|0;g=F;c[d>>2]=255;h=a+20|0;c[h>>2]=c[h>>2]|1;h=b|0;xz(c[e>>2]|0,6,h,7)|0;if((PGb(2070480,h,4)|0)==0){c[d+268>>2]=1;i=b;return 0}if((PGb(2066e3,h,6)|0)==0){c[d+260>>2]=1;i=b;return 0}else{Ty(c[e>>2]|0,f,g,0)|0;i=b;return 0}return 0}function vJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=i;i=i+40|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=c[b+12>>2]|0;m=CJ(b,j,f,g,h)|0;if((m|0)<0){n=m;i=e;return n|0}o=b+16|0;p=b+24|0;q=b+28|0;r=l+268|0;s=k|0;t=k+6|0;u=k+7|0;k=l+260|0;v=-1;w=0;x=0;y=m;a:while(1){m=c[f>>2]|0;z=m-128|0;do{if(z>>>0<80>>>0){if((y|0)<4){A=x;B=w;C=v;D=y;break}lz(c[o>>2]|0)|0;E=tz(c[o>>2]|0)|0;if(!((m-176|0)>>>0<16>>>0)){F=E;G=y-3|0;H=7;break}lz(c[o>>2]|0)|0;F=E;G=y-4|0;H=7}else{F=v;G=y;H=7}}while(0);b:do{if((H|0)==7){H=0;E=c[p>>2]|0;I=0;while(1){if(!(I>>>0<E>>>0)){H=10;break}J=c[(c[q>>2]|0)+(I<<2)>>2]|0;if((c[J+4>>2]|0)==(m|0)){K=x;L=w;M=J;break}else{I=I+1|0}}if((H|0)==10){H=0;I=a[l+((m&255)+4)|0]|0;do{if((I-1&255)>>>0<2>>>0){N=0;O=2;P=w}else{if((I-3&255)>>>0<2>>>0){N=1;O=86017;P=w;break}if((I<<24>>24|0)==16){N=0;O=13;P=w;break}else if((I<<24>>24|0)==(-127|0)){N=1;O=86019;P=w;break}else if((I<<24>>24|0)==15){N=1;O=86018;P=w;break}else if((I<<24>>24|0)==27){N=0;O=28;P=w;break}else{if((c[r>>2]|0)!=0&I<<24>>24==-111){N=1;O=65542;P=w;break}if((m-480|0)>>>0<16>>>0){mz(c[o>>2]|0,s,8)|0;Ty(c[o>>2]|0,-8,-1,1)|0;if((PGb(s,644976,4)|0)==0){if((a[t]|0)!=0){N=0;O=88;P=w;break}if((a[u]|0)!=1){N=0;O=88;P=w;break}}N=0;O=x;P=1;break}if((m|0)==447){N=2;O=1145979222;P=w;break}if((m-448|0)>>>0<32>>>0){E=(c[k>>2]|0)>0;N=1;O=E?69641:86016;P=E?50:w;break}if(z>>>0<8>>>0){N=1;O=86019;P=w;break}if((m-136|0)>>>0<8>>>0|(m-152|0)>>>0<8>>>0){N=1;O=86020;P=w;break}if((m-160|0)>>>0<16>>>0){N=1;O=(F|0)==6?86045:65555;P=w;break}if((m-176|0)>>>0<16>>>0){N=1;O=86061;P=w;break}if((m-192|0)>>>0<16>>>0){N=1;O=86019;P=w;break}if((m-32|0)>>>0<32>>>0){N=3;O=94208;P=w;break}if((m-64853|0)>>>0<11>>>0){N=0;O=71;P=w;break}else{A=x;B=w;C=F;D=G;break b}}}}while(0);I=LT(b,0)|0;if((I|0)==0){A=O;B=P;C=F;D=G;break}c[I+4>>2]=m;E=c[I+8>>2]|0;c[E+8>>2]=N;c[E+48>>2]=O;if((O|0)==65542){c[E+416>>2]=1;J=E+448|0;c[J>>2]=4;c[J+4>>2]=0;c[E+412>>2]=8e3}c[I+440>>2]=P;c[I+236>>2]=1;K=O;L=P;M=I}if((c[M+76>>2]|0)>47){A=K;B=L;C=F;D=G;break}if(!((m-160|0)>>>0<16>>>0&(F|0)==6)){Q=G;break a}if((c[(c[M+8>>2]|0)+48>>2]|0)!=86045){Q=G;break a}if((G|0)<6){A=K;B=L;C=6;D=G}else{H=42;break a}}}while(0);Vy(c[o>>2]|0,D,(D|0)<0|0?-1:0)|0;m=CJ(b,j,f,g,h)|0;if((m|0)<0){n=m;H=44;break}else{v=C;w=B;x=A;y=m}}if((H|0)==42){Vy(c[o>>2]|0,6,0)|0;Q=G-6|0}else if((H|0)==44){i=e;return n|0}H=TS(c[o>>2]|0,d,Q)|0;Q=c[g+4>>2]|0;o=d+8|0;c[o>>2]=c[g>>2];c[o+4>>2]=Q;Q=c[h+4>>2]|0;o=d+16|0;c[o>>2]=c[h>>2];c[o+4>>2]=Q;Q=c[j+4>>2]|0;o=d+64|0;c[o>>2]=c[j>>2];c[o+4>>2]=Q;c[d+32>>2]=c[M>>2];n=(H|0)<0?H:0;i=e;return n|0}function wJ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+32|0;e=f|0;g=f+8|0;h=f+16|0;j=f+24|0;k=c[d>>2]|0;l=c[d+4>>2]|0;c[g>>2]=k;c[g+4>>2]=l;m=a+16|0;n=Ty(c[m>>2]|0,k,l,0)|0;l=F;k=0;if((l|0)<(k|0)|(l|0)==(k|0)&n>>>0<0>>>0){o=-2147483648;p=0;i=f;return(F=o,p)|0}n=CJ(a,g,e,h,j)|0;if((n|0)<0){o=-2147483648;p=0;i=f;return(F=o,p)|0}k=a+28|0;l=n;while(1){if((c[e>>2]|0)==(c[(c[(c[k>>2]|0)+(b<<2)>>2]|0)+4>>2]|0)){q=c[j>>2]|0;r=c[j+4>>2]|0;if(!((q|0)==0&(r|0)==(-2147483648|0))){break}}Vy(c[m>>2]|0,l,(l|0)<0|0?-1:0)|0;n=CJ(a,g,e,h,j)|0;if((n|0)<0){o=-2147483648;p=0;s=8;break}else{l=n}}if((s|0)==8){i=f;return(F=o,p)|0}s=c[g+4>>2]|0;c[d>>2]=c[g>>2];c[d+4>>2]=s;o=r;p=q;i=f;return(F=o,p)|0}function xJ(a){a=a|0;var b=0;b=(RGb(c[a+4>>2]|0,2075096,20)|0)==0;return(b?100:0)|0}function yJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;d=i;i=i+3160|0;e=d|0;f=d+8|0;g=d+16|0;h=d+1040|0;j=d+3088|0;k=d+3096|0;l=k|0;m=i;i=i+4|0;i=i+7&-8;n=i;i=i+4|0;i=i+7&-8;o=i;i=i+4|0;i=i+7&-8;p=i;i=i+4|0;i=i+7&-8;q=i;i=i+8|0;r=i;i=i+8|0;s=i;i=i+4|0;i=i+7&-8;t=i;i=i+4|0;i=i+7&-8;u=i;i=i+4|0;i=i+7&-8;v=i;i=i+4|0;i=i+7&-8;c[e>>2]=0;w=c[b+12>>2]|0;x=b+32|0;y=eEb(x)|0;z=SGb(y|0)|0;A=y+(z-3)|0;do{if(!(z>>>0<4>>>0)){if((a[y+(z-4)|0]|0)!=46){break}B=(RGb(A,1882976,3)|0)==0;C=B?2341072:2318072;a[A]=a[C]|0;a[A+1|0]=a[C+1|0]|0;a[A+2|0]=a[C+2|0]|0;C=b;yDb(C,40,2296120,(D=i,i=i+16|0,c[D>>2]=x,c[D+8>>2]=y,D)|0);i=D;B=aT(w+272|0,y,1175704,0)|0;if((B|0)<0){yDb(C,16,2279288,(D=i,i=i+8|0,c[D>>2]=y,D)|0);i=D;E=B;ZDb(y);i=d;return E|0}IAb(g,0,-1);G=b+16|0;a:do{if((Xy(c[G>>2]|0)|0)==0){H=h|0;I=k;J=h+6|0;K=h+8|0;L=b+24|0;M=h+10|0;N=r|0;O=r+4|0;P=w+276|0;Q=h+4|0;R=0;S=0;T=0;U=0;b:while(1){if((wz(c[G>>2]|0,H,2048)|0)==0){V=L;break a}a[h+(hc(H|0,2263984)|0)|0]=0;c:do{if((RGb(H,2249e3,3)|0)==0){c[j>>2]=0;TGb(I|0,0,64)|0;W=xd(H|0,2235808,(D=i,i=i+16|0,c[D>>2]=k,c[D+8>>2]=j,D)|0)|0;i=D;if((W|0)==2){if((c[j>>2]|0)>>>0>31>>>0){X=14;break b}}else{yDb(C,24,2222768,(D=i,i=i+8|0,c[D>>2]=H,D)|0);i=D;c[l>>2]=6581877;c[j>>2]=0}W=LT(b,0)|0;if((W|0)==0){E=-12;X=52;break b}c[W+4>>2]=c[j>>2];Y=c[W+8>>2]|0;c[Y+8>>2]=3;c[Y+48>>2]=94208;MT(W,64,1,1e3);CBb(W+88|0,2196480,I,0)|0;yDb(C,48,2183744,(D=i,i=i+16|0,c[D>>2]=c[j>>2],c[D+8>>2]=k,D)|0);i=D;Z=1;_=S;$=T;aa=W}else{do{if((R|0)!=0){if((RGb(H,2168720,10)|0)!=0){if((RGb(H,2135144,4)|0)==0){ba=Q}else{break}while(1){if((a[ba]|0)==32){ba=ba+1|0}else{break}}CBb(R+88|0,2128760,ba,0)|0;yDb(C,48,2122576,(D=i,i=i+16|0,c[D>>2]=c[R+4>>2],c[D+8>>2]=ba,D)|0);i=D;Z=1;_=S;$=T;aa=R;break c}if((c[L>>2]|0)==0){X=20;break b}W=xd(M|0,2154456,(D=i,i=i+40|0,c[D>>2]=m,c[D+8>>2]=n,c[D+16>>2]=o,c[D+24>>2]=p,c[D+32>>2]=q,D)|0)|0;i=D;if((W|0)!=5){X=22;break b}W=c[m>>2]|0;Y=gHb(W,(W|0)<0|0?-1:0,3600,0)|0;W=F;ca=c[n>>2]|0;da=gHb(ca,(ca|0)<0|0?-1:0,60,0)|0;ca=YGb(da,F,Y,W)|0;W=c[o>>2]|0;Y=YGb(ca,F,W,(W|0)<0|0?-1:0)|0;W=gHb(Y,F,1e3,0)|0;Y=F;ca=c[p>>2]|0;da=YGb(ca,(ca|0)<0|0?-1:0,T,S)|0;ca=YGb(da,F,W,Y)|0;c[N>>2]=1;c[O>>2]=1e3;Y=KDb(ca,F,r,R+40|0)|0;ca=F;W=uR(P+(((c[L>>2]|0)-1|0)*20|0)|0,9203336,0,0)|0;if((W|0)==0){E=-12;X=52;break b}da=c[q+4>>2]|0;ea=W+64|0;c[ea>>2]=c[q>>2];c[ea+4>>2]=da;da=W+8|0;c[da>>2]=Y;c[da+4>>2]=ca;c[W+32>>2]=(c[L>>2]|0)-1;Z=U;_=S;$=T;aa=R;break c}}while(0);if((RGb(H,2117560,6)|0)==0){c[s>>2]=0;c[t>>2]=0;c[u>>2]=0;c[v>>2]=0;W=J;while(1){fa=a[W]|0;if((fa<<24>>24|0)==45|(fa<<24>>24|0)==43){X=33;break}else if((fa<<24>>24|0)!=32){ga=W;ha=0;ia=1;break}W=W+1|0}if((X|0)==33){X=0;ca=fa<<24>>24==45;ga=W+1|0;ha=ca?-1:0;ia=ca?-1:1}xd(ga|0,2106736,(D=i,i=i+32|0,c[D>>2]=s,c[D+8>>2]=t,c[D+16>>2]=u,c[D+24>>2]=v,D)|0)|0;i=D;ca=c[s>>2]|0;da=gHb(ca,(ca|0)<0|0?-1:0,3600,0)|0;ca=F;Y=c[t>>2]|0;ea=gHb(Y,(Y|0)<0|0?-1:0,60,0)|0;Y=YGb(ea,F,da,ca)|0;ca=c[u>>2]|0;da=YGb(Y,F,ca,(ca|0)<0|0?-1:0)|0;ca=gHb(da,F,1e3,0)|0;da=c[v>>2]|0;Y=YGb(ca,F,da,(da|0)<0|0?-1:0)|0;da=gHb(Y,F,ia,ha)|0;Z=U;_=F;$=da;aa=R;break}if((RGb(H,2095824,8)|0)==0){da=xd(K|0,2090336,(D=i,i=i+8|0,c[D>>2]=e,D)|0)|0;i=D;if((da|0)==1){Z=U;_=S;$=T;aa=R;break}yDb(C,16,2085368,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;Z=U;_=S;$=T;aa=R;break}if((U|0)!=0){Z=U;_=S;$=T;aa=R;break}da=a[H]|0;if((da<<24>>24|0)==0|(da<<24>>24|0)==35){Z=0;_=S;$=T;aa=R;break}KAb(g,2080192,(D=i,i=i+8|0,c[D>>2]=H,D)|0);i=D;Z=0;_=S;$=T;aa=R}}while(0);if((Xy(c[G>>2]|0)|0)==0){R=aa;S=_;T=$;U=Z}else{V=L;break a}}if((X|0)==14){yDb(C,16,2203912,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=-22;ZDb(y);i=d;return E|0}else if((X|0)==20){yDb(C,16,2161200,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=-1094995529;ZDb(y);i=d;return E|0}else if((X|0)==22){yDb(C,16,2147384,(D=i,i=i+8|0,c[D>>2]=H,D)|0);i=D;V=L;break}else if((X|0)==52){ZDb(y);i=d;return E|0}}else{V=b+24|0}}while(0);C=c[e>>2]|0;G=c[V>>2]|0;if(C>>>0<G>>>0){U=(c[(c[b+28>>2]|0)+(C<<2)>>2]|0)+72|0;c[U>>2]=c[U>>2]|1;ja=c[V>>2]|0}else{ja=G}if((ja|0)!=0){G=w+276|0;U=0;do{c[G+(U*20|0)+16>>2]=1;vR(G+(U*20|0)|0);U=U+1|0;}while(U>>>0<(c[V>>2]|0)>>>0)}U=g+4|0;if(!((c[U>>2]|0)>>>0<(c[g+8>>2]|0)>>>0)){QAb(g,0)|0;E=-12;ZDb(y);i=d;return E|0}QAb(g,f)|0;if((c[V>>2]|0)!=0){G=b+28|0;C=0;do{T=c[(c[G>>2]|0)+(C<<2)>>2]|0;S=eEb(c[f>>2]|0)|0;R=T+8|0;c[(c[R>>2]|0)+96>>2]=S;c[(c[R>>2]|0)+100>>2]=c[U>>2];C=C+1|0;}while(C>>>0<(c[V>>2]|0)>>>0)}ZDb(c[f>>2]|0);E=B;ZDb(y);i=d;return E|0}}while(0);yDb(b,16,1902864,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=-1094995529;ZDb(y);i=d;return E|0}function zJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+104|0;e=d|0;f=d+80|0;g=d+88|0;h=d+96|0;j=c[a+12>>2]|0;k=j+272|0;l=c[(c[k>>2]|0)+16>>2]|0;m=c[a+24>>2]|0;a=j+276|0;if((m|0)==0){n=0}else{j=0;o=2147483647;p=-1;q=0;while(1){r=(c[a+(q*20|0)>>2]|0)+((c[a+(q*20|0)+12>>2]|0)*80|0)+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;r=(t|0)<(o|0)|(t|0)==(o|0)&s>>>0<p>>>0;u=r?q:j;v=q+1|0;if(v>>>0<m>>>0){j=u;o=r?t:o;p=r?s:p;q=v}else{n=u;break}}}q=a+(n*20|0)|0;p=yR(q,e)|0;if((p|0)<0){w=p;i=d;return w|0}p=c[a+(n*20|0)+12>>2]|0;do{if((p|0)<(c[a+(n*20|0)+4>>2]|0)){o=(c[q>>2]|0)+(p*80|0)+64|0;j=e+64|0;m=c[j>>2]|0;u=c[j+4>>2]|0;j=ZGb(c[o>>2]|0,c[o+4>>2]|0,m,u)|0;x=j;y=u;z=m}else{m=Wy(l)|0;u=F;j=0;o=e+64|0;v=c[o>>2]|0;s=c[o+4>>2]|0;if((u|0)<(j|0)|(u|0)==(j|0)&m>>>0<0>>>0){x=65535;y=s;z=v;break}j=ZGb(m,u,v,s)|0;x=j;y=s;z=v}}while(0);p=e+64|0;Ty(l,z,y,0)|0;vZ(b);y=b+28|0;c[y>>2]=0;z=b+24|0;c[z>>2]=0;q=e+32|0;n=0;while(1){a=Ty(l,0,0,1)|0;v=F;A=CJ(c[k>>2]|0,0,f,g,h)|0;if((A|0)<0){B=10;break}s=A&65535;j=Ty(l,0,0,1)|0;u=F;m=ZGb(A,0,a,v)|0;v=YGb(m,F,j,u)|0;u=v+n|0;if((u|0)>(x|0)){B=17;break}if((c[f>>2]&31|0)!=(c[q>>2]|0)){B=17;break}v=zZ(b,s)|0;if((v|0)<0){C=v;B=18;break}v=mz(l,(c[z>>2]|0)+((c[y>>2]|0)-s)|0,s)|0;if((v|0)<(s|0)){c[y>>2]=v-s+(c[y>>2]|0)}if((u|0)<(x|0)){n=u}else{B=17;break}}if((B|0)==10){if((c[y>>2]|0)==0){C=A;B=18}else{B=17}}if((B|0)==17){A=e+8|0;y=c[A>>2]|0;n=c[A+4>>2]|0;A=b+16|0;c[A>>2]=y;c[A+4>>2]=n;A=b+8|0;c[A>>2]=y;c[A+4>>2]=n;n=c[p+4>>2]|0;A=b+64|0;c[A>>2]=c[p>>2];c[A+4>>2]=n;c[b+32>>2]=c[q>>2];BZ(e);w=0;i=d;return w|0}else if((B|0)==18){BZ(b);BZ(e);w=C;i=d;return w|0}return 0}function AJ(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;d=a+24|0;if((c[d>>2]|0)!=0){a=b+276|0;e=0;do{AR(a+(e*20|0)|0);e=e+1|0;}while(e>>>0<(c[d>>2]|0)>>>0)}d=b+272|0;if((c[d>>2]|0)==0){return 0}KT(d);return 0}function BJ(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;l=i;i=i+8|0;m=l|0;n=m;o=i;i=i+8|0;p=c[a+12>>2]|0;q=(b|0)==-1;do{if(q){r=a+24|0;if((c[r>>2]|0)==1){break}s=(c[c[a+28>>2]>>2]|0)+40|0;t=c[s+4>>2]|0;c[m>>2]=c[s>>2];c[m+4>>2]=t;c[o>>2]=1;c[o+4>>2]=1e6;t=KDb(f,g,o,n)|0;s=F;u=c[n+4>>2]|0;v=u;w=(u|0)<0|0?-1:0;u=c[m>>2]|0;x=gHb(u,(u|0)<0|0?-1:0,1e6,0)|0;u=F;y=HDb(d,e,v,w,x,u,8195)|0;z=F;A=HDb(h,j,v,w,x,u,8194)|0;u=F;if((c[r>>2]|0)==0){B=0;i=l;return B|0}x=p+276|0;w=0;v=0;while(1){C=zR(x+(w*20|0)|0,a,-1,y,z,t,s,A,u,k)|0;D=(C|0)<0?C:v;C=w+1|0;if(C>>>0<(c[r>>2]|0)>>>0){w=C;v=D}else{B=D;break}}i=l;return B|0}}while(0);m=q?0:b;B=zR(p+276+(m*20|0)|0,a,m,d,e,f,g,h,j,k)|0;i=l;return B|0}function CJ(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;j=i;i=i+8|0;k=j|0;l=c[b+12>>2]|0;m=l;n=b+16|0;o=Ty(c[n>>2]|0,0,0,1)|0;p=l;q=(e|0)!=0;r=l+260|0;s=l+264|0;l=k|0;t=k+1|0;u=t;v=k+3|0;k=b;w=F;x=o;a:while(1){Ty(c[n>>2]|0,x,w,0)|0;b:while(1){c[p>>2]=255;o=c[n>>2]|0;y=1e5;z=255;while(1){if((y|0)<=0){A=-1;B=z;break}if((Xy(o)|0)!=0){A=-1;B=z;break}C=(lz(o)|0|z<<8)&16777215;if((z|0)==1){A=C;B=C;break}else{y=y-1|0;z=C}}c[p>>2]=B;D=Ty(c[n>>2]|0,0,0,1)|0;E=F;if((A|0)<0){G=8;break a}if((A-442|0)>>>0<2>>>0){continue}do{if((A|0)==447){if((c[r>>2]|0)!=0){if((c[s>>2]|0)!=0){break}z=tz(c[n>>2]|0)|0;Vy(c[n>>2]|0,z,(z|0)<0|0?-1:0)|0;continue b}z=tz(c[n>>2]|0)|0;y=WDb(z)|0;o=c[n>>2]|0;if((y|0)==0){Vy(o,z,(z|0)<0|0?-1:0)|0;continue b}C=mz(o,y,z)|0;do{if((C|0)==(z|0)){do{if((z|0)>5){o=Ib(y|0,83,z-5|0)|0;if((o|0)==0){break}c[r>>2]=(PGb(o+1|0,1981736,5)|0)==0}}while(0);o=c[r>>2]|0;H=o-((o|0)==0)|0;c[r>>2]=H;if((H|0)>=0){break}if((z|0)==1018){if((a[y]|0)!=1){break}H=d[y+29|0]|0;o=H&15;I=d[y+30|0]|0;J=I&15;K=d[y+31|0]|0;L=K&15;M=((K>>>4)*10|0)+L|0;do{if((((H>>>4)*10|0)+o&248)>>>0<24>>>0){if(!((((I>>>4)*10|0)+J&252)>>>0<60>>>0)){N=0;break}if(!((M&252)>>>0<60>>>0&o>>>0<10>>>0&J>>>0<10>>>0)){N=0;break}N=L>>>0<10>>>0|0}else{N=0}}while(0);c[s>>2]=N;break}else if((z|0)==980){if((a[y]|0)!=0){break}L=y+13|0;J=fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0;L=y+17|0;o=fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0;L=d[y+25|0]|0;M=L&15;I=d[y+26|0]|0;H=I&15;K=d[y+27|0]|0;O=K&15;P=((K>>>4)*10|0)+O|0;do{if((((L>>>4)*10|0)+M&248)>>>0<24>>>0){if(!((((I>>>4)*10|0)+H&252)>>>0<60>>>0)){Q=0;break}if(!((P&252)>>>0<60>>>0&M>>>0<10>>>0&H>>>0<10>>>0&O>>>0<10>>>0)){Q=0;break}Q=o>>>0>=J>>>0|0}else{Q=0}}while(0);c[s>>2]=Q;break}else{break}}else{J=z-C|0;Vy(c[n>>2]|0,J,(J|0)<0|0?-1:0)|0;}}while(0);ZDb(y);if((c[s>>2]|0)==0){continue b}C=-2-z|0;J=Vy(c[n>>2]|0,C,(C|0)<0|0?-1:0)|0;C=F;o=0;if((C|0)<(o|0)|(C|0)==(o|0)&J>>>0<0>>>0){continue b}}else if((A|0)==444){J=c[n>>2]|0;o=tz(J)|0;lz(J)|0;lz(J)|0;C=tz(J)|0;Vy(J,C,(C|0)<0|0?-1:0)|0;tz(J)|0;O=o-10-C|0;if((O|0)>3){C=O;do{O=(lz(J)|0)&255;o=lz(J)|0;H=tz(J)|0;a[(o&255)+(m+4)|0]=O;O=H&65535;Vy(J,O,0)|0;C=C-4-O|0;}while((C|0)>3)}vz(J)|0;continue b}else if((A|0)==446){C=c[n>>2]|0;Vy(C,tz(C)|0,0)|0;continue b}}while(0);if(!((A-448|0)>>>0<32>>>0|(A-480|0)>>>0<16>>>0)){if(!((A|0)==509|(A|0)==447|(A|0)==445)){continue}}if(q){C=Ty(c[n>>2]|0,0,0,1)|0;z=YGb(C,F,-4,-1)|0;c[e>>2]=z;c[e+4>>2]=F}z=tz(c[n>>2]|0)|0;if((A|0)==447){R=z;S=447;T=-2147483648;U=0;V=-2147483648;W=0;break}else{X=z}while(1){if((X|0)<1){w=E;x=D;continue a}Y=lz(c[n>>2]|0)|0;Z=X-1|0;if((Y|0)==255){X=Z}else{break}}if((Y&192|0)==64){lz(c[n>>2]|0)|0;_=X-3|0;$=lz(c[n>>2]|0)|0}else{_=Z;$=Y}if(($&224|0)==32){G=51;break}if(($&192|0)==128){G=56;break}if(($|0)==15){aa=_;ba=A;ca=-2147483648;da=0;ea=-2147483648;fa=0;G=73;break}}do{if((G|0)==51){G=0;z=c[n>>2]|0;if(($|0)<0){ga=(lz(z)|0)&255}else{ga=$&255}a[l]=ga;mz(z,t,4)|0;z=a[l]&14;C=((de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(z<<29|0>>>3);y=C|((de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;C=0<<29|z>>>3|0;if(($&16|0)==0){aa=_-4|0;ba=A;ca=C;da=y;ea=C;fa=y;G=73;break}z=c[n>>2]|0;a[l]=lz(z)|0;mz(z,t,4)|0;z=a[l]&14;O=((de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(z<<29|0>>>3);aa=_-9|0;ba=A;ca=C;da=y;ea=0<<29|z>>>3|0;fa=O|((de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;G=73}else if((G|0)==56){G=0;O=lz(c[n>>2]|0)|0;z=lz(c[n>>2]|0)|0;y=_-2|0;if((z|0)>(y|0)){w=E;x=D;continue a}C=y-z|0;do{if((O&128|0)==0){ha=z;ia=-2147483648;ja=0;ka=-2147483648;la=0}else{y=c[n>>2]|0;a[l]=lz(y)|0;mz(y,t,4)|0;y=a[l]&14;H=((de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(y<<29|0>>>3);o=H|((de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;H=0<<29|y>>>3|0;if((O&64|0)==0){ha=z-5|0;ia=H;ja=o;ka=H;la=o;break}y=c[n>>2]|0;a[l]=lz(y)|0;mz(y,t,4)|0;y=a[l]&14;M=((de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(y<<29|0>>>3);ha=z-10|0;ia=H;ja=o;ka=0<<29|y>>>3|0;la=M|((de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)>>>1}}while(0);if((O&63|0)!=0&(ha|0)==0){yDb(k,24,1950848,(ma=i,i=i+1|0,i=i+7&-8,c[ma>>2]=0,ma)|0);i=ma;na=O&192}else{na=O}do{if((na&1|0)==0){oa=A;pa=ha}else{z=lz(c[n>>2]|0)|0;M=ha-1|0;y=z>>>4;o=(y&11)+(y&9)|0;if((z&64|0)!=0|(o|0)>(M|0)){yDb(k,24,1925032,(ma=i,i=i+8|0,c[ma>>2]=z,ma)|0);i=ma;qa=0;ra=0}else{qa=z;ra=o}Vy(c[n>>2]|0,ra,(ra|0)<0|0?-1:0)|0;o=M-ra|0;if((qa&1|0)==0){oa=A;pa=o;break}if(((lz(c[n>>2]|0)|0)&127|0)==0){oa=A;pa=o-1|0;break}M=lz(c[n>>2]|0)|0;if((M&128|0)==0){sa=M|A<<8&65280}else{sa=A}oa=sa;pa=o-2|0}}while(0);if((pa|0)<0){w=E;x=D;continue a}Vy(c[n>>2]|0,pa,(pa|0)<0|0?-1:0)|0;aa=C;ba=oa;ca=ia;da=ja;ea=ka;fa=la;G=73}}while(0);do{if((G|0)==73){G=0;if((ba|0)!=445){R=aa;S=ba;T=ea;U=fa;V=ca;W=da;break}R=aa-1|0;S=lz(c[n>>2]|0)|0;T=ea;U=fa;V=ca;W=da}}while(0);if((R|0)<0){w=E;x=D}else{break}}if((G|0)==8){G=(Xy(c[n>>2]|0)|0)==0;ta=G?-11:-541478725;i=j;return ta|0}do{if(!((U|0)==0&(T|0)==(-2147483648|0)|q^1)){G=b+24|0;D=c[G>>2]|0;if((D|0)==0){break}x=b+28|0;E=0;w=D;while(1){do{if((S|0)==(c[(c[(c[x>>2]|0)+(E<<2)>>2]|0)+4>>2]|0)){if((c[(c[n>>2]|0)+88>>2]|0)==0){ua=w;break}iT(b,E);jT(c[(c[x>>2]|0)+(E<<2)>>2]|0,c[e>>2]|0,c[e+4>>2]|0,U,T,0,0,1)|0;ua=c[G>>2]|0}else{ua=w}}while(0);C=E+1|0;if(C>>>0<ua>>>0){E=C;w=ua}else{break}}}}while(0);c[f>>2]=S;c[g>>2]=W;c[g+4>>2]=V;c[h>>2]=U;c[h+4>>2]=T;ta=R;i=j;return ta|0}function DJ(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;e=i;f=b+12|0;g=c[f>>2]|0;c[g+8>>2]=0;j=c[b+8>>2]|0;k=g+44|0;c[k>>2]=(j|0)==1178864;l=(j|0)==1177744|0;c[g+48>>2]=l;m=(j|0)==1177832;n=g+40|0;c[n>>2]=(j|0)==1177360|m?1:l;c[g+52>>2]=m&1;m=c[b+1076>>2]|0;do{if((m|0)==0){c[g+4>>2]=2048;o=8}else{if((m-20|0)>>>0>8388598>>>0){yDb(b,16,2106552,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;q=b+24|0;break}else{c[g+4>>2]=m;o=8;break}}}while(0);a:do{if((o|0)==8){m=b+1080|0;if((c[m>>2]|0)<0){c[m>>2]=7e5}m=g+64|0;l=m;j=g+32|0;c[j>>2]=0;r=g+36|0;c[r>>2]=0;s=b+24|0;t=b+28|0;u=b;TGb(m|0,0,16)|0;m=160;v=136;w=128;x=32;y=224;z=192;A=0;while(1){B=c[s>>2]|0;if(!(A>>>0<B>>>0)){o=12;break}C=c[(c[t>>2]|0)+(A<<2)>>2]|0;D=cEb(56)|0;if((D|0)==0){q=s;break a}c[C+12>>2]=D;MT(C,64,1,9e4);E=C+8|0;C=c[E>>2]|0;F=c[C+8>>2]|0;if((F|0)==1){do{if((c[n>>2]|0)==0){G=c[C+48>>2]|0;if(!((G|0)==86019|(G|0)==86020|(G|0)==65537)){H=C;break}I=H0a(G)|0;yDb(u,24,2095688,(p=i,i=i+8|0,c[p>>2]=I,p)|0);i=p;H=c[E>>2]|0}else{H=C}}while(0);C=c[H+48>>2]|0;if((C|0)==86019){a[D+4|0]=w;J=m;K=v;L=w+1|0;M=z}else if((C|0)==86020){a[D+4|0]=v;J=m;K=v+1|0;L=w;M=z}else if((C|0)==65537){C=m+1|0;a[D+4|0]=m;I=0;while(1){if((I|0)>=4){break}if((c[765528+(I<<2)>>2]|0)==(c[(c[E>>2]|0)+412>>2]|0)){break}else{I=I+1|0}}if((I|0)==4){q=s;break a}if((c[(c[E>>2]|0)+416>>2]|0)>8){N=-1;o=72;break}a[D+32|0]=12;a[D+33|0]=(c[(c[E>>2]|0)+416>>2]|0)+255|I<<4;a[D+34|0]=-128;c[D+36>>2]=c[(c[E>>2]|0)+416>>2]<<1;J=C;K=v;L=w;M=z}else{a[D+4|0]=z;J=m;K=v;L=w;M=z+1|0}c[D+8>>2]=4096;c[j>>2]=(c[j>>2]|0)+1;O=J;P=K;Q=L;R=x;S=y;T=M}else if((F|0)==0){G=y+1|0;a[D+4|0]=y;U=c[(c[E>>2]|0)+524>>2]|0;do{if((U|0)==0){yDb(u,24,2090280,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;c[D+8>>2]=235520}else{V=((U|0)/8|0)+6144|0;c[D+8>>2]=V;if((V|0)<=8387584){break}yDb(u,24,2085328,(p=i,i=i+8|0,c[p>>2]=V,p)|0);i=p;c[D+8>>2]=8387584}}while(0);c[r>>2]=(c[r>>2]|0)+1;O=m;P=v;Q=w;R=x;S=G;T=z}else if((F|0)==3){a[D+4|0]=x;c[D+8>>2]=16384;O=m;P=v;Q=w;R=x+1|0;S=y;T=z}else{N=-1;o=72;break}U=UBb(16)|0;c[D>>2]=U;if((U|0)==0){q=s;break a}else{m=O;v=P;w=Q;x=R;y=S;z=T;A=A+1|0}}if((o|0)==12){if((B|0)==0){W=0;X=0;Y=0}else{A=c[t>>2]|0;z=0;y=0;x=0;w=0;while(1){v=c[A+(y<<2)>>2]|0;m=c[v+12>>2]|0;r=c[v+8>>2]|0;v=r+540|0;if((c[v>>2]|0)==0){Z=(a[m+4|0]|0)==-32?v:r+72|0}else{Z=v}v=c[Z>>2]|0;if((v|0)==0){_=838860800/(B>>>0)|0}else{_=v}v=_+z|0;r=a[m+4|0]|0;if((r&-32)<<24>>24==-64){$=w;aa=_+x|0}else{$=(r<<24>>24==-32?_:0)+w|0;aa=x}r=y+1|0;if(r>>>0<B>>>0){z=v;y=r;x=aa;w=$}else{W=v;X=aa;Y=$;break}}}w=c[g+24>>2]|0;do{if((w|0)==0){x=((W|0)/20|0)+W|0;y=x+1e4|0;z=x+10399|0;x=(z|0)/400|0;A=g+28|0;c[A>>2]=x;if((z|0)<=1677721599){ba=y;break}yDb(u,24,2080128,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;c[A>>2]=4194303;ba=y}else{c[g+28>>2]=(w+399|0)/400|0;ba=W}}while(0);w=c[k>>2]|0;do{if((w|0)==0){if((c[n>>2]|0)!=0){ca=0;o=52;break}u=(ba<<1|0)/(c[g+4>>2]|0)|0;y=(u|0)/8|0;c[g+12>>2]=y;if(!((u+7|0)>>>0<15>>>0)){da=y;ea=0;break}c[g+12>>2]=1;da=1;ea=0}else{h[l>>3]=1394400.0-(+(ba|0)+(+(X|0)*.125/2279.0*45.0+ +(Y|0)*.125/2294.0*30.0)*8.0);ca=w;o=52}}while(0);if((o|0)==52){c[g+12>>2]=1;da=1;ea=ca}do{if((c[n>>2]|0)==0){if((ea|0)==0){c[g+16>>2]=da*5|0;break}else{c[g+16>>2]=2147483647;break}}else{c[g+16>>2]=da*40|0}}while(0);if((c[s>>2]|0)==0){fa=0}else{w=c[t>>2]|0;l=0;while(1){c[(c[(c[w+(l<<2)>>2]|0)+12>>2]|0)+28>>2]=0;y=l+1|0;u=c[s>>2]|0;if(y>>>0<u>>>0){l=y}else{fa=u;break}}}do{if((c[(c[f>>2]|0)+52>>2]|0)==0){if((fa|0)==0){ga=12;break}l=c[t>>2]|0;s=0;w=0;u=12;while(1){if((d[(c[(c[l+(s<<2)>>2]|0)+12>>2]|0)+4|0]|0)>>>0<192>>>0){if((w|0)==0){ha=1;o=68}else{ia=u;ja=w}}else{ha=w;o=68}if((o|0)==68){o=0;ia=u+3|0;ja=ha}y=s+1|0;if(y>>>0<fa>>>0){s=y;w=ja;u=ia}else{ga=ia;break}}}else{ga=18}}while(0);c[g+20>>2]=ga;t=g+56|0;c[t>>2]=0;c[t+4>>2]=-2147483648;N=0;i=e;return N|0}else if((o|0)==72){i=e;return N|0}}}while(0);if((c[q>>2]|0)==0){N=-12;i=e;return N|0}o=b+28|0;b=0;while(1){ZDb(c[(c[(c[o>>2]|0)+(b<<2)>>2]|0)+12>>2]|0);g=b+1|0;if(g>>>0<(c[q>>2]|0)>>>0){b=g}else{N=-12;break}}i=e;return N|0}function EJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;d=i;e=c[a+12>>2]|0;f=c[b+28>>2]|0;g=c[b+24>>2]|0;h=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;j=c[h+12>>2]|0;if((c[(c[h+8>>2]|0)+8>>2]|0)==0){k=(c[b+36>>2]&1|0)==0}else{k=1}h=e+80|0;l=c[h>>2]|0;m=IDb(l,(l|0)<0|0?-1:0,9e4,0,1e6,0)|0;n=m;m=b+8|0;o=c[m>>2]|0;p=c[m+4>>2]|0;m=b+16|0;b=c[m>>2]|0;q=c[m+4>>2]|0;m=e+56|0;if((c[m>>2]|0)==0&(c[m+4>>2]|0)==(-2147483648|0)){a:do{if((b|0)==0&(q|0)==(-2147483648|0)){r=l;s=9}else{t=n;u=(n|0)<0|0?-1:0;if((q|0)<(u|0)|(q|0)==(u|0)&b>>>0<t>>>0){if((c[a+1204>>2]|0)==0){s=7}}else{s=7}do{if((s|0)==7){if((c[e+52>>2]|0)!=0){break}v=ZGb(b,q,t,u)|0;w=F;c[m>>2]=v;c[m+4>>2]=w;c[h>>2]=0;x=0;y=w;z=v;break a}}while(0);u=ZGb(0,0,b,q)|0;t=IDb(u,F,1e6,0,9e4,0)|0;u=YGb(l,0,t,F)|0;t=u;c[h>>2]=t;r=t;s=9}}while(0);if((s|0)==9){c[m>>2]=0;c[m+4>>2]=0;x=r;y=0;z=0}r=IDb(x,(x|0)<0|0?-1:0,9e4,0,1e6,0)|0;x=r;r=YGb(x,(x|0)<0|0?-1:0,b,q)|0;m=F;yDb(a,48,2117512,(s=i,i=i+32|0,c[s>>2]=z,c[s+8>>2]=y,c[s+16>>2]=r,c[s+24>>2]=m,s)|0);i=s;A=x}else{A=n}if((b|0)==0&(q|0)==(-2147483648|0)){B=-2147483648;C=0}else{n=YGb(A,(A|0)<0|0?-1:0,b,q)|0;B=F;C=n}if((o|0)==0&(p|0)==(-2147483648|0)){D=-2147483648;E=0}else{n=YGb(A,(A|0)<0|0?-1:0,o,p)|0;D=F;E=n}n=j+20|0;p=j+24|0;if((c[n>>2]|0)==0){c[p>>2]=n}n=cEb(32)|0;o=n;c[c[p>>2]>>2]=o;A=n;c[A>>2]=E;c[A+4>>2]=D;A=n+8|0;c[A>>2]=C;c[A+4>>2]=B;c[n+16>>2]=f;c[n+20>>2]=f;B=j+16|0;if((c[B>>2]|0)==0){c[B>>2]=o}c[p>>2]=n+28;n=j;p=c[n>>2]|0;if((YBb(p,(WBb(p)|0)+f|0)|0)<0){G=-1;i=d;return G|0}do{if(!((c[e+52>>2]|0)==0|k)){p=j+48|0;if((c[e+8>>2]|0)!=0){o=ZGb(E,D,c[p>>2]|0,c[p+4>>2]|0)|0;B=F;A=0;if(!((B|0)>(A|0)|(B|0)==(A|0)&o>>>0>35999>>>0)){break}}c[j+40>>2]=WBb(c[n>>2]|0)|0;c[j+44>>2]=1;c[p>>2]=E;c[p+4>>2]=D}}while(0);_Bb(c[n>>2]|0,g,f,0)|0;while(1){f=GJ(a,0)|0;if((f|0)<1){G=f;break}}i=d;return G|0}function FJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;do{b=GJ(a,1)|0;if((b|0)<0){d=b;e=9;break}}while((b|0)!=0);if((e|0)==9){return d|0}b=a+24|0;if((c[b>>2]|0)==0){d=0;return d|0}f=a+28|0;a=0;while(1){g=c[(c[(c[f>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;if((WBb(c[g>>2]|0)|0)!=0){e=7;break}VBb(c[g>>2]|0);g=a+1|0;if(g>>>0<(c[b>>2]|0)>>>0){a=g}else{d=0;e=9;break}}if((e|0)==7){yd(2203832,2196408,1159,2359896);return 0}else if((e|0)==9){return d|0}return 0}function GJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0.0,oa=0,pa=0.0,qa=0,ra=0,sa=0;d=i;e=a+12|0;f=c[e>>2]|0;g=f+56|0;j=c[g>>2]|0;k=c[g+4>>2]|0;l=c[a+1080>>2]|0;m=IDb(l,(l|0)<0|0?-1:0,9e4,0,1e6,0)|0;l=F;n=a+24|0;o=a+28|0;p=f+4|0;q=(b|0)==0;b=a;r=0;s=-1;t=-2147483648;u=0;v=k;k=j;a:while(1){b:do{if((c[n>>2]|0)==0){w=t;x=s;y=r;z=0}else{j=(u|0)==0;if(q){A=t;B=s;C=r;D=0}else{G=t;H=s;I=r;J=0;while(1){K=c[(c[(c[o>>2]|0)+(J<<2)>>2]|0)+12>>2]|0;L=WBb(c[K>>2]|0)|0;M=c[K+8>>2]|0;N=c[K+12>>2]|0;O=M-N|0;R=O;S=eHb(R<<10|0>>>22,((O|0)<0|0?-1:0)<<10|R>>>22,M,(M|0)<0|0?-1:0)|0;M=S;S=c[K+20>>2]|0;do{if((L|0)==0){T=I;U=H;V=G}else{if((L|0)<=0){W=17;break a}if((O|0)<(c[p>>2]|0)&j){T=I;U=H;V=G;break}if((S|0)!=0){R=S+8|0;X=ZGb(c[R>>2]|0,c[R+4>>2]|0,k,v)|0;R=F;if((R|0)>(l|0)|(R|0)==(l|0)&X>>>0>m>>>0){T=I;U=H;V=G;break}}X=c[K+16>>2]|0;if((X|0)==0){Y=M}else{Y=(c[X+16>>2]|0)>(N|0)?M+268435456|0:M}X=(Y|0)>(G|0);T=X?O:I;U=X?J:H;V=X?Y:G}}while(0);O=J+1|0;M=c[n>>2]|0;if(O>>>0<M>>>0){G=V;H=U;I=T;J=O}else{w=V;x=U;y=T;z=M;break b}}}while(1){J=c[(c[o>>2]|0)+(D<<2)>>2]|0;I=c[J+12>>2]|0;H=WBb(c[I>>2]|0)|0;G=c[I+8>>2]|0;M=c[I+12>>2]|0;O=G-M|0;N=O;K=eHb(N<<10|0>>>22,((O|0)<0|0?-1:0)<<10|N>>>22,G,(G|0)<0|0?-1:0)|0;G=K;K=c[I+20>>2]|0;N=c[p>>2]|0;if((N|0)>(H|0)){if((c[(c[J+8>>2]|0)+8>>2]|0)!=3){Z=0;W=61;break a}}do{if((H|0)==0){_=C;$=B;ba=A}else{if((H|0)<=0){W=17;break a}if((O|0)<(N|0)&j){_=C;$=B;ba=A;break}if((K|0)!=0){J=K+8|0;S=ZGb(c[J>>2]|0,c[J+4>>2]|0,k,v)|0;J=F;if((J|0)>(l|0)|(J|0)==(l|0)&S>>>0>m>>>0){_=C;$=B;ba=A;break}}S=c[I+16>>2]|0;if((S|0)==0){ca=G}else{ca=(c[S+16>>2]|0)>(M|0)?G+268435456|0:G}S=(ca|0)>(A|0);_=S?O:C;$=S?D:B;ba=S?ca:A}}while(0);O=D+1|0;G=c[n>>2]|0;if(O>>>0<G>>>0){A=ba;B=$;C=_;D=O}else{w=ba;x=$;y=_;z=G;break}}}}while(0);if((x|0)>=0){W=35;break}if((z|0)==0){Z=0;W=61;break}j=c[o>>2]|0;G=2147483647;O=-1;M=0;while(1){I=c[(c[(c[j+(M<<2)>>2]|0)+12>>2]|0)+16>>2]|0;if((I|0)==0){da=G;ea=O}else{K=I+8|0;I=c[K>>2]|0;N=c[K+4>>2]|0;K=(N|0)<(G|0)|(N|0)==(G|0)&I>>>0<O>>>0;da=K?N:G;ea=K?I:O}I=M+1|0;if(I>>>0<z>>>0){G=da;O=ea;M=I}else{break}}if((ea|0)==(-1|0)&(da|0)==2147483647){Z=0;W=61;break}M=YGb(ea,da,1,0)|0;O=F;if((v|0)>=(O|0)&((v|0)>(O|0)|k>>>0>=M>>>0)&(u|0)==0){yDb(b,16,2161136,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;ha=1}else{ha=u}G=(O|0)>(v|0)|(O|0)==(v|0)&M>>>0>k>>>0;j=G?M:k;M=G?O:v;HJ(a,j,M);r=y;s=x;t=w;u=ha;v=M;k=j}if((W|0)==17){yDb(0,0,2183496,(fa=i,i=i+24|0,c[fa>>2]=2168672,c[fa+8>>2]=2196408,c[fa+16>>2]=969,fa)|0);i=fa;Cd();return 0}else if((W|0)==35){fa=c[(c[(c[o>>2]|0)+(x<<2)>>2]|0)+12>>2]|0;o=fa;if((WBb(c[o>>2]|0)|0)<=0){yd(2147328,2196408,1017,2359880);return 0}if((y|0)<(c[p>>2]|0)&(u|0)==0){yd(2140904,2196408,1019,2359880);return 0}u=fa+20|0;y=c[u>>2]|0;ha=c[y+20>>2]|0;if((ha|0)==(c[y+16>>2]|0)){ia=0;ja=y}else{ia=ha;ja=c[y+28>>2]|0}do{if((ja|0)==0){if((WBb(c[o>>2]|0)|0)==(ia|0)){ka=IJ(a,x,0,-2147483648,0,-2147483648,k,v,ia)|0;break}else{yd(2135080,2196408,1036,2359880);return 0}}else{y=ja|0;ha=ja+8|0;ka=IJ(a,x,c[y>>2]|0,c[y+4>>2]|0,c[ha>>2]|0,c[ha+4>>2]|0,k,v,ia)|0}}while(0);c:do{if((c[f+44>>2]|0)==0){la=c[u>>2]|0;ma=f+28|0}else{ia=a+16|0;v=f+28|0;while(1){k=c[u>>2]|0;x=k|0;ja=c[x>>2]|0;o=c[x+4>>2]|0;x=c[e>>2]|0;na=+h[x+64>>3];if(na<=0.0|(ja|0)==0&(o|0)==(-2147483648|0)){oa=0}else{pa=na*((+(ja>>>0)+ +(o|0)*4294967296.0)/9.0e4)*.125;o=(E=+pa,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);ja=x+72|0;ha=ZGb(~~+pa>>>0,o,c[ja>>2]|0,c[ja+4>>2]|0)|0;ja=ha;oa=(ja|0)<0?0:ja}if((oa|0)<(c[p>>2]|0)){la=k;ma=v;break c}k=x+4|0;ja=c[k>>2]|0;if((ja|0)>0){ha=0;while(1){Py(c[ia>>2]|0,0);o=ha+1|0;y=c[k>>2]|0;if((o|0)<(y|0)){ha=o}else{qa=y;break}}}else{qa=ja}ha=x+72|0;k=YGb(c[ha>>2]|0,c[ha+4>>2]|0,qa,(qa|0)<0|0?-1:0)|0;c[ha>>2]=k;c[ha+4>>2]=F;Sy(c[ia>>2]|0);ha=x+8|0;c[ha>>2]=(c[ha>>2]|0)+1;ha=c[p>>2]|0;k=gHb(ha,(ha|0)<0|0?-1:0,9e4,0)|0;ha=F;y=c[v>>2]|0;o=gHb(y,(y|0)<0|0?-1:0,50,0)|0;y=eHb(k,ha,o,F)|0;o=YGb(c[g>>2]|0,c[g+4>>2]|0,y,F)|0;c[g>>2]=o;c[g+4>>2]=F}}}while(0);qa=fa+12|0;c[qa>>2]=(c[qa>>2]|0)+ka;qa=c[p>>2]|0;p=gHb(qa,(qa|0)<0|0?-1:0,9e4,0)|0;qa=F;fa=c[ma>>2]|0;ma=gHb(fa,(fa|0)<0|0?-1:0,50,0)|0;fa=eHb(p,qa,ma,F)|0;ma=YGb(c[g>>2]|0,c[g+4>>2]|0,fa,F)|0;fa=F;c[g>>2]=ma;c[g+4>>2]=fa;d:do{if((la|0)==0){ra=ka;sa=0}else{g=la;qa=ka;while(1){p=c[g+20>>2]|0;if((p|0)>(qa|0)){ra=qa;sa=g;break d}oa=qa-p|0;p=c[g+28>>2]|0;c[u>>2]=p;if((p|0)==0){ra=oa;sa=0;break}else{g=p;qa=oa}}}}while(0);if((ra|0)!=0){u=sa+20|0;c[u>>2]=(c[u>>2]|0)-ra}HJ(a,ma,fa);Z=1;i=d;return Z|0}else if((W|0)==61){i=d;return Z|0}return 0}function HJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+8|0;f=e|0;g=a+24|0;if((c[g>>2]|0)==0){i=e;return}h=a+28|0;j=f;k=a;a=0;do{l=c[(c[(c[h>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;m=l+16|0;n=c[m>>2]|0;c[f>>2]=n;a:do{if((n|0)!=0){o=l+12|0;p=l+20|0;q=n;while(1){r=q+8|0;s=c[r+4>>2]|0;if(!((s|0)<(d|0)|(s|0)==(d|0)&(c[r>>2]|0)>>>0<b>>>0)){break a}t=c[o>>2]|0;u=c[q+16>>2]|0;if((t|0)<(u|0)){break}if((c[m>>2]|0)==(c[p>>2]|0)){break}c[o>>2]=t-u;c[m>>2]=c[q+28>>2];$Db(j);q=c[m>>2]|0;c[f>>2]=q;if((q|0)==0){break a}}yDb(k,16,2122528,(q=i,i=i+24|0,c[q>>2]=a,c[q+8>>2]=t,c[q+16>>2]=u,q)|0);i=q}}while(0);a=a+1|0;}while(a>>>0<(c[g>>2]|0)>>>0);i=e;return}function IJ(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;n=i;i=i+128|0;o=n|0;p=b+12|0;q=c[p>>2]|0;r=c[(c[(c[b+28>>2]|0)+(e<<2)>>2]|0)+12>>2]|0;e=a[r+4|0]|0;s=e&255;t=o|0;u=q+8|0;v=q+56|0;do{if(((c[u>>2]|0)%(c[q+12>>2]|0)|0|0)==0){w=4}else{if(!((c[v>>2]|0)==(k|0)&(c[v+4>>2]|0)==(l|0))){w=4;break}x=0;y=t;z=q+44|0}}while(0);a:do{if((w|0)==4){A=JJ(q,t,k,l)|0;B=o+A|0;c[v>>2]=k;c[v+4>>2]=l;C=q+44|0;if((c[C>>2]|0)!=0){if((c[r+28>>2]|0)!=0){x=0;y=B;z=C;break}x=0;y=o+((KJ(b,B,s)|0)+A)|0;z=C;break}if((c[q+52>>2]|0)==0){if(((c[u>>2]|0)%(c[q+16>>2]|0)|0|0)!=0){x=0;y=B;z=C;break}x=0;y=o+((KJ(b,B,0)|0)+A)|0;z=C;break}D=r+44|0;if((c[D>>2]|0)==0){if((c[u>>2]|0)!=0){x=0;y=B;z=C;break}}E=q+4|0;G=(c[E>>2]|0)-A|0;do{if((f|0)==0&(g|0)==(-2147483648|0)){H=G-10|0}else{if((h|0)==(f|0)&(j|0)==(g|0)){H=G-15|0;break}else{H=G-20|0;break}}}while(0);G=c[r+40>>2]|0;do{if((G|0)!=0){if((c[u>>2]|0)==0){break}x=(G|0)<(H|0)?H-G|0:0;y=B;z=C;break a}}while(0);G=(KJ(b,B,0)|0)+A|0;I=b+16|0;Ry(c[I>>2]|0,t,G);Zy(c[I>>2]|0,447);fz(c[I>>2]|0,980);Py(c[I>>2]|0,0);G=0;J=c[I>>2]|0;do{Py(J,0);G=G+1|0;J=c[I>>2]|0}while((G|0)<979);Zy(J,447);fz(c[I>>2]|0,1018);Py(c[I>>2]|0,1);G=0;do{Py(c[I>>2]|0,0);G=G+1|0;}while((G|0)<1017);TGb(t|0,0,128)|0;c[u>>2]=(c[u>>2]|0)+1;c[D>>2]=0;G=c[E>>2]|0;I=gHb(G,(G|0)<0|0?-1:0,9e4,0)|0;G=F;J=c[q+28>>2]|0;A=gHb(J,(J|0)<0|0?-1:0,50,0)|0;J=eHb(I,G,A,F)|0;A=YGb(J,F,k,l)|0;J=F;G=JJ(c[p>>2]|0,t,A,J)|0;c[v>>2]=A;c[v+4>>2]=J;x=0;y=o+G|0;z=C}}while(0);v=y-o|0;o=b+16|0;Ry(c[o>>2]|0,t,v);t=(c[q+4>>2]|0)-v|0;do{if((c[z>>2]|0)==0){K=0;w=27}else{v=(s&224|0)==192?20:0;if((c[r+28>>2]|0)!=0){K=v;w=27;break}L=v;M=c[q+48>>2]|0;w=29}}while(0);do{if((w|0)==27){z=c[q+48>>2]|0;if((z|0)==0){N=0;O=x;P=K;break}if((c[u>>2]|0)==0){L=K;M=z;w=29}else{N=0;O=x;P=K}}}while(0);if((w|0)==29){N=(M|0)!=0|0;O=t-L|0;P=L}L=t-P-O|0;do{if((L|0)>0){t=L-6|0;M=q+40|0;K=(c[M>>2]|0)==0;if(K){Q=0}else{Q=(c[r+28>>2]|0)==0?7:4}x=(f|0)!=0|(g|0)!=(-2147483648|0);do{if(x){if((h|0)==(f|0)&(j|0)==(g|0)){R=Q+5|0;break}else{R=Q+10|0;break}}else{R=(K&1)+Q|0}}while(0);K=t-R|0;do{if((e&255)>>>0<192>>>0){if(!((e&255)>>>0>63>>>0)){S=445;T=K-1|0;break}S=445;T=K+((e&255)>>>0>159>>>0?-7:-4)|0}else{S=s|256;T=K}}while(0);K=r;C=T-(WBb(c[K>>2]|0)|0)|0;do{if((T|0)>(m|0)){U=g;V=f;W=O;X=t;Y=R;Z=C;_=j;$=h;aa=T}else{if(!x){U=-2147483648;V=0;W=O;X=t;Y=R;Z=C;_=j;$=h;aa=T;break}E=((c[M>>2]|0)!=0?5:4)+((h|0)==(f|0)&(j|0)==(g|0)?0:5)|0;D=R-E|0;do{if((c[q+52>>2]|0)==0){w=47}else{if((c[r+44>>2]|0)==0){w=47;break}ba=E+O|0;ca=t-E|0;da=T}}while(0);if((w|0)==47){ba=O;ca=t;da=E+T|0}z=E+C|0;if((da|0)<=(m|0)){U=-2147483648;V=0;W=ba;X=ca;Y=D;Z=z;_=-2147483648;$=0;aa=da;break}U=-2147483648;V=0;W=ba;X=ca;Y=D;Z=z-m+da|0;_=-2147483648;$=0;aa=da}}while(0);if((W-1|0)>>>0<7>>>0){ea=0;fa=W+X|0;ga=W+((Z|0)<0?0:Z)|0;ha=W+aa|0}else{ea=W;fa=X;ga=Z;ha=aa}C=(ga|0)<0?0:ga;t=(S|0)==445;x=(e&255)>>>0>159>>>0;do{if(t&x){if((ha|0)>=(WBb(c[K>>2]|0)|0)){ia=C;break}ia=((ha|0)%(c[r+36>>2]|0)|0)+C|0}else{ia=C}}while(0);if((ia|0)>16){ja=ia+ea|0;ka=fa-ia|0;la=0;ma=ha-ia|0}else{ja=ea;ka=fa;la=ia;ma=ha}C=ma-la|0;if((C|0)>0){z=C;v=0;b=r+20|0;while(1){y=c[b>>2]|0;l=c[y+20>>2]|0;k=((c[y+16>>2]|0)==(l|0))+v|0;H=z-l|0;if((H|0)>0){z=H;v=k;b=y+28|0}else{na=k;break}}}else{na=0}Zy(c[o>>2]|0,S);fz(c[o>>2]|0,ka);do{if((c[M>>2]|0)==0){if((la|0)>0){b=0;do{Py(c[o>>2]|0,255);b=b+1|0;}while((b|0)<(la|0));if((c[M>>2]|0)!=0){w=64;break}}if((V|0)==0&(U|0)==(-2147483648|0)){Py(c[o>>2]|0,15);break}b=c[o>>2]|0;D=((V>>>30|U<<2)<<1|0>>>31)&14;if(($|0)==(V|0)&(_|0)==(U|0)){Py(b,D|33);fz(b,(($>>>15|_<<17)<<1|0>>>31|1)&65535);fz(b,($<<1|0>>>31|1)&65535);break}else{Py(b,D|49);fz(b,((V>>>15|U<<17)<<1|0>>>31|1)&65535);fz(b,(V<<1|0>>>31|1)&65535);b=c[o>>2]|0;Py(b,(($>>>30|_<<2)<<1|0>>>31)&14|17);fz(b,(($>>>15|_<<17)<<1|0>>>31|1)&65535);fz(b,($<<1|0>>>31|1)&65535);break}}else{w=64}}while(0);do{if((w|0)==64){Py(c[o>>2]|0,128);if((V|0)==0&(U|0)==(-2147483648|0)){oa=0}else{oa=($|0)==(V|0)&(_|0)==(U|0)?128:192}b=(c[r+28>>2]|0)==0;Py(c[o>>2]|0,b&1|oa);Py(c[o>>2]|0,Y-3+la|0);if((oa&128|0)!=0){D=c[o>>2]|0;Py(D,((V>>>30|U<<2)<<1|0>>>31)&14|(oa>>>2|32)|1);fz(D,((V>>>15|U<<17)<<1|0>>>31|1)&65535);fz(D,(V<<1|0>>>31|1)&65535)}if((oa&64|0)!=0){D=c[o>>2]|0;Py(D,(($>>>30|_<<2)<<1|0>>>31)&14|17);fz(D,(($>>>15|_<<17)<<1|0>>>31|1)&65535);fz(D,($<<1|0>>>31|1)&65535)}if(!b){break}Py(c[o>>2]|0,16);b=c[o>>2]|0;D=c[r+8>>2]|0;if((s&224|0)==192){fz(b,(D|0)/128|0|16384);break}else{fz(b,(D|0)/1024|0|24576);break}}}while(0);do{if((c[M>>2]|0)!=0){Py(c[o>>2]|0,255);if((la|0)>0){pa=0}else{break}do{Py(c[o>>2]|0,255);pa=pa+1|0;}while((pa|0)<(la|0))}}while(0);do{if(t){Py(c[o>>2]|0,s);if(x){Py(c[o>>2]|0,7);fz(c[o>>2]|0,4);Py(c[o>>2]|0,d[r+32|0]|0);Py(c[o>>2]|0,d[r+33|0]|0);Py(c[o>>2]|0,d[r+34|0]|0);break}if(!((e&255)>>>0>63>>>0)){break}Py(c[o>>2]|0,na);fz(c[o>>2]|0,m+1|0)}}while(0);if((C|0)>(WBb(c[K>>2]|0)|0)){yd(2128680,2196408,861,2359944);return 0}else{ZBb(c[K>>2]|0,c[o>>2]|0,C,1902)|0;x=r+40|0;c[x>>2]=(c[x>>2]|0)-C;qa=ja;ra=la;sa=ma;break}}else{qa=O;ra=0;sa=0}}while(0);do{if((qa|0)>0){O=c[o>>2]|0;ma=c[p>>2]|0;Zy(O,446);la=qa-6|0;fz(O,la);if((c[ma+40>>2]|0)==0){Py(O,15);ta=qa-7|0}else{ta=la}if((ta|0)>0){ua=0}else{break}do{Py(O,255);ua=ua+1|0;}while((ua|0)<(ta|0))}}while(0);ta=c[o>>2]|0;if((P|0)>0){ua=0;qa=ta;while(1){Py(qa,0);p=ua+1|0;O=c[o>>2]|0;if((p|0)<(P|0)){ua=p;qa=O}else{va=O;break}}}else{va=ta}Sy(va);c[u>>2]=(c[u>>2]|0)+1;if((N|0)!=0){wa=sa-ra|0;i=n;return wa|0}N=r+28|0;c[N>>2]=(c[N>>2]|0)+1;wa=sa-ra|0;i=n;return wa|0}function JJ(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;g=i;h=d;x=-1174339584;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=b+40|0;j=(c[h>>2]|0)==0;k=((j?56592:14152)|(e>>>30|f<<2)&7)<<1|1;l=k;m=(e>>>15|f<<17)&32767;if(1){n=j?9:11;o=k<<15|m;p=d+4|0}else{n=0;o=m;p=0}l=o;if((n|0)>1){q=n-1|0;r=o<<1|1;s=p}else{m=p;x=fe(1>>>((1-n|0)>>>0)|o<<n|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;q=n+31|0;r=1;s=p+4|0}l=r;p=e&32767;if((q|0)>15){t=q-15|0;u=r<<15|p;v=s}else{e=s;x=fe(p>>>((15-q|0)>>>0)|r<<q|0)|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;t=q+17|0;u=p;v=s+4|0}l=u;if((t|0)>1){w=t-1|0;y=u<<1|1;z=v}else{s=v;x=fe(1>>>((1-t|0)>>>0)|u<<t|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;w=t+31|0;y=1;z=v+4|0}l=y;if((c[h>>2]|0)==0){A=w;B=z;C=y}else{if((w|0)>9){D=w-9|0;E=y<<9;F=z}else{v=z;x=fe(y<<w|0)|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;D=w+23|0;E=0;F=z+4|0}l=E;A=D;B=F;C=E}if((A|0)>1){G=A-1|0;H=C<<1|1;I=B}else{E=B;x=fe(1>>>((1-A|0)>>>0)|C<<A|0)|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;G=A+31|0;H=1;I=B+4|0}l=H;B=c[b+28>>2]|0;if((G|0)>22){J=G-22|0;K=B|H<<22;L=I}else{b=I;x=fe(B>>>((22-G|0)>>>0)|H<<G|0)|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;J=G+10|0;K=B;L=I+4|0}l=K;if((J|0)>1){M=J-1|0;N=K<<1|1;O=L}else{I=L;x=fe(1>>>((1-J|0)>>>0)|K<<J|0)|0;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;M=J+31|0;N=1;O=L+4|0}l=N;if((c[h>>2]|0)==0){P=M;Q=O;R=N}else{if((M|0)>1){S=M-1|0;T=N<<1|1;U=O}else{h=O;x=fe(1>>>((1-M|0)>>>0)|N<<M|0)|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;S=M+31|0;T=1;U=O+4|0}l=T;if((S|0)>5){V=S-5|0;W=T<<5|31;X=U}else{O=U;x=fe(31>>>((5-S|0)>>>0)|T<<S|0)|0;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;V=S+27|0;W=31;X=U+4|0}l=W;if((V|0)>3){Y=V-3|0;Z=W<<3;_=X}else{U=X;x=fe(W<<V|0)|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;Y=V+29|0;Z=0;_=X+4|0}l=Z;P=Y;Q=_;R=Z}if((P|0)>=32){$=Q;aa=$;ba=d;ca=aa-ba|0;i=g;return ca|0}Z=R<<P;l=Z;R=((31-P|0)>>>3)+1|0;_=Z>>>24&255;Z=P;P=Q;while(1){a[P]=_;Y=l;l=Y<<8;X=Z+8|0;if((X|0)<32){_=Y>>>16&255;Z=X;P=P+1|0}else{break}}$=Q+R|0;aa=$;ba=d;ca=aa-ba|0;i=g;return ca|0}function KJ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;f=i;g=c[b+12>>2]|0;h=d;x=-1157562368;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=d+4|0;j=58064897;k=c[g+28>>2]|0;l=h;x=fe(k>>>7|32768|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=d+8|0;m=k<<1|1;j=m;k=g+44|0;if((c[k>>2]|0)!=0&(e|0)==224){n=m<<6}else{n=c[g+32>>2]|m<<6}j=n;m=n<<2|(c[k>>2]|0)!=0;j=m;do{if((c[k>>2]|0)==0){if((c[g+52>>2]|0)!=0){o=6;break}j=m<<1;p=m<<3}else{o=6}}while(0);if((o|0)==6){n=m<<1|1;j=n;p=n<<2|2}n=p|1;j=n;do{if((c[k>>2]|0)==0){o=11}else{if((e&224|0)!=192){o=11;break}q=n<<5}}while(0);if((o|0)==11){q=n<<5|c[g+36>>2]}j=q;n=g+52|0;if((c[n>>2]|0)==0){g=l;x=fe(q<<8|255|0)|0;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;r=255}else{j=q<<1;g=l;x=fe(q<<8|127|0)|0;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;r=127}g=d+12|0;j=r;q=b+24|0;l=c[q>>2]|0;p=(l|0)==0;if((c[n>>2]|0)!=0){if(p){s=0;t=0;u=0}else{n=c[b+28>>2]|0;m=0;v=0;w=0;y=0;while(1){z=c[(c[n+(y<<2)>>2]|0)+12>>2]|0;A=a[z+4|0]|0;do{if(A<<24>>24==-67){B=c[z+8>>2]|0;C=(B|0)>(w|0)?B:w;D=v;E=m}else{if((A+64&255)>>>0<8>>>0){B=c[z+8>>2]|0;if((B|0)>(v|0)){C=w;D=B;E=m;break}}if(!(A<<24>>24==-32)){C=w;D=v;E=m;break}B=c[z+8>>2]|0;C=w;D=v;E=(B|0)>(m|0)?B:m}}while(0);z=y+1|0;if(z>>>0<l>>>0){m=E;v=D;w=C;y=z}else{s=E;t=D;u=C;break}}}C=g;x=fe(((s|0)/1024|0)<<8|-1176502088|0)|0;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=(u|0)/128|0;u=d+16|0;x=fe(C>>>8|((t|0)==0?-1071596096:((t|0)/128|0)<<16|-1073693248)|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;u=d+20|0;x=fe(C<<24|12574722|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;j=2;F=d+24|0;G=F;H=d;I=G-H|0;J=I+65530|0;K=J&65535;L=de(K|0)|0;M=h;x=L;a[M]=x;x=x>>8;a[M+1|0]=x;i=f;return I|0}if(p){F=g;G=F;H=d;I=G-H|0;J=I+65530|0;K=J&65535;L=de(K|0)|0;M=h;x=L;a[M]=x;x=x>>8;a[M+1|0]=x;i=f;return I|0}p=b+28|0;b=(e|0)==0;u=g;g=32;C=0;t=0;s=r;while(1){r=c[(c[(c[p>>2]|0)+(t<<2)>>2]|0)+12>>2]|0;D=a[r+4|0]|0;if((c[k>>2]|0)==0){o=30}else{if((D&255|0)==(e|0)|b){o=30}else{N=C;O=g;P=u;Q=s}}do{if((o|0)==30){o=0;E=D&255;if((D&255)>>>0<192>>>0){if((C|0)==0){R=1;S=189}else{N=C;O=g;P=u;Q=s;break}}else{R=C;S=E}if((g|0)>8){T=g-8|0;U=s<<8|S;V=u}else{E=u;x=fe(s<<g|S>>>((8-g|0)>>>0)|0)|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;T=g+24|0;U=S;V=u+4|0}j=U;if((T|0)>2){W=T-2|0;X=U<<2|3;Y=V}else{E=V;x=fe(3>>>((2-T|0)>>>0)|U<<T|0)|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;W=T+30|0;X=3;Y=V+4|0}j=X;E=(W|0)>1;if(S>>>0<224>>>0){if(E){Z=W-1|0;_=X<<1;$=Y}else{y=Y;x=fe(X<<W|0)|0;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;Z=W+31|0;_=0;$=Y+4|0}j=_;y=(c[r+8>>2]|0)/128|0;if((Z|0)>13){aa=Z-13|0;ba=y|_<<13;ca=$}else{w=$;x=fe(y>>>((13-Z|0)>>>0)|_<<Z|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;aa=Z+19|0;ba=y;ca=$+4|0}j=ba;N=R;O=aa;P=ca;Q=ba;break}else{if(E){da=W-1|0;ea=X<<1|1;fa=Y}else{E=Y;x=fe(1>>>((1-W|0)>>>0)|X<<W|0)|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;da=W+31|0;ea=1;fa=Y+4|0}j=ea;E=(c[r+8>>2]|0)/1024|0;if((da|0)>13){ga=da-13|0;ha=E|ea<<13;ia=fa}else{y=fa;x=fe(E>>>((13-da|0)>>>0)|ea<<da|0)|0;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;ga=da+19|0;ha=E;ia=fa+4|0}j=ha;N=R;O=ga;P=ia;Q=ha;break}}}while(0);r=t+1|0;if(r>>>0<(c[q>>2]|0)>>>0){u=P;g=O;C=N;t=r;s=Q}else{break}}if((O|0)>=32){F=P;G=F;H=d;I=G-H|0;J=I+65530|0;K=J&65535;L=de(K|0)|0;M=h;x=L;a[M]=x;x=x>>8;a[M+1|0]=x;i=f;return I|0}s=Q<<O;j=s;Q=((31-O|0)>>>3)+1|0;t=s>>>24&255;s=O;O=P;while(1){a[O]=t;N=j;j=N<<8;C=s+8|0;if((C|0)<32){t=N>>>16&255;s=C;O=O+1|0}else{break}}F=P+Q|0;G=F;H=d;I=G-H|0;J=I+65530|0;K=J&65535;L=de(K|0)|0;M=h;x=L;a[M]=x;x=x>>8;a[M+1|0]=x;i=f;return I|0}function LJ(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;n=i;i=i+512|0;o=n|0;p=n+256|0;q=n+384|0;r=c[g>>2]|0;if(!(r>>>0<h>>>0)){s=-1;i=n;return s|0}t=r+1|0;u=d[r]|0;c[g>>2]=t;if(!(t>>>0<h>>>0)){s=-1;i=n;return s|0}v=a[t]|0;t=v&255;c[g>>2]=r+2;w=r+(t+2)|0;if(w>>>0>h>>>0){s=-1;i=n;return s|0}h=e+8|0;r=c[h>>2]|0;a:do{if((c[r+48>>2]|0)==0&(f|0)==6){if((o0a(r)|0)==0){y=2365672}else{yDb(0,48,2154376,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break}while(1){A=c[y>>2]|0;if((A|0)==0){break a}if((A|0)==(u|0)){break}else{y=y+12|0}}A=c[h>>2]|0;c[A+8>>2]=c[y+4>>2];c[A+48>>2]=c[y+8>>2];c[e+440>>2]=0}}while(0);b:do{switch(u|0){case 82:{y=c[g>>2]|0;if(y>>>0<w>>>0){r=d[y]|0;c[g>>2]=y+1;B=r+1|0}else{B=0}c[e+420>>2]=B;break};case 38:{r=c[g>>2]|0;do{if((r+1|0)>>>0<w>>>0){y=r;f=(d[y]|d[y+1|0]<<8)<<16>>16;y=r+2|0;c[g>>2]=y;if(!(f<<16>>16==-1)){C=y;break}y=r+6|0;c[g>>2]=y;C=y}else{C=r}}while(0);if(!(C>>>0<w>>>0)){break b}r=C+1|0;y=a[C]|0;c[g>>2]=r;if(!(y<<24>>24==-1)){break b}c[g>>2]=C+5;y=r;r=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=c[h>>2]|0;c[y+52>>2]=r;if((c[y+48>>2]|0)!=0){break b}if((o0a(y)|0)==0){D=2363448}else{yDb(0,48,2154376,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break b}while(1){y=c[D>>2]|0;if((y|0)==0){break b}if((y|0)==(r|0)){break}else{D=D+12|0}}r=c[h>>2]|0;c[r+8>>2]=c[D+4>>2];c[r+48>>2]=c[D+8>>2];c[e+440>>2]=0;break};case 5:{r=c[g>>2]|0;c[g>>2]=r+4;y=r;r=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=c[h>>2]|0;c[y+52>>2]=r;if((c[y+48>>2]|0)!=0){break b}if((o0a(y)|0)==0){E=2362448}else{yDb(0,48,2154376,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break b}while(1){y=c[E>>2]|0;if((y|0)==0){break b}if((y|0)==(r|0)){break}else{E=E+12|0}}r=c[h>>2]|0;c[r+8>>2]=c[E+4>>2];c[r+48>>2]=c[E+8>>2];c[e+440>>2]=0;break};case 30:{r=c[g>>2]|0;if((r+1|0)>>>0<w>>>0){y=r;f=(de((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535;c[g>>2]=r+2;F=f}else{F=-1}do{if((m|0)!=0){f=c[m+8288+(l<<2)>>2]|0;if((f|0)==0){break}c[f+4>>2]=F}}while(0);if((k|0)<=0){break b}f=e+236|0;r=m;y=m+8288+(l<<2)|0;if(l>>>0>8191>>>0){A=0;while(1){G=c[j+(A*68|0)+4>>2]|0;do{if((G|0)!=0){if((c[j+(A*68|0)>>2]|0)!=(F|0)){break}Ny(p,c[j+(A*68|0)+8>>2]|0,G,0,0,0,0,0)|0;vF(b,e,p)|0;H=c[h>>2]|0;if((c[H+48>>2]|0)!=86018){break}if((c[H+100>>2]|0)<=0){break}c[f>>2]=0}}while(0);A=A+1|0;if((A|0)>=(k|0)){break b}}}else{I=0}do{A=c[j+(I*68|0)+4>>2]|0;do{if((A|0)!=0){if((c[j+(I*68|0)>>2]|0)!=(F|0)){break}Ny(p,c[j+(I*68|0)+8>>2]|0,A,0,0,0,0,0)|0;vF(b,e,p)|0;G=c[h>>2]|0;H=c[G+48>>2]|0;if((H|0)==86018){if((c[G+100>>2]|0)<=0){break}c[f>>2]=0;if((H|0)!=131073){break}}else if((H|0)!=131073){break}if((c[y>>2]|0)!=0){break}H=cEb(40)|0;if((H|0)==0){break}c[y>>2]=H;c[H+12>>2]=1;c[H>>2]=l;c[H+4>>2]=-1;c[H+8>>2]=-1;c[H+32>>2]=1176;c[H+36>>2]=r;G=WDb(4096)|0;c[H+24>>2]=G;J=H+28|0;c[J>>2]=c[J>>2]|1;if((G|0)!=0){break}ZDb(H)}}while(0);I=I+1|0;}while((I|0)<(k|0));break};case 86:{r=((v&255)/5|0)&255;if(!(v<<24>>24==0|((v&255)%5|0)<<24>>24==0)){s=-1094995529;i=n;return s|0}if(!((v&255)>>>0>4>>>0)){break b}y=c[h>>2]|0;f=r<<1;do{if((c[y+96>>2]|0)==0){if((BT(y,f)|0)==0){K=c[h>>2]|0;break}else{s=-12;i=n;return s|0}}else{K=y}}while(0);if((c[K+100>>2]|0)<(f|0)){s=-1094995529;i=n;return s|0}y=(v&255)>>>0>9>>>0;A=0;H=c[K+96>>2]|0;G=c[g>>2]|0;while(1){if(G>>>0<w>>>0){J=G+1|0;L=a[G]|0;c[g>>2]=J;M=L;N=J}else{M=-1;N=G}J=A<<2;a[o+J|0]=M;if(N>>>0<w>>>0){L=N+1|0;O=a[N]|0;c[g>>2]=L;P=O;Q=L}else{P=-1;Q=N}a[o+(J|1)|0]=P;if(Q>>>0<w>>>0){L=Q+1|0;O=a[Q]|0;c[g>>2]=L;R=O;S=L}else{R=-1;S=Q}a[o+(J|2)|0]=R;a[o+(J|3)|0]=44;J=S;L=H;x=(d[J]|d[J+1|0]<<8)<<16>>16;a[L]=x;x=x>>8;a[L+1|0]=x;L=(c[g>>2]|0)+2|0;c[g>>2]=L;J=A+1|0;if((J|0)<(r|0)){A=J;H=H+2|0;G=L}else{break}}a[o+(y?(r<<2)-1|0:3)|0]=0;CBb(e+88|0,194e4,o|0,0)|0;break};case 10:{if((v&255)>>>0<4>>>0){break b}G=e+72|0;H=(t+1|0)>>>0>8>>>0;A=0;f=4;L=c[g>>2]|0;while(1){if(L>>>0<w>>>0){J=L+1|0;O=a[L]|0;c[g>>2]=J;T=O;U=J}else{T=-1;U=L}a[o+A|0]=T;if(U>>>0<w>>>0){J=U+1|0;O=a[U]|0;c[g>>2]=J;V=O;W=J}else{V=-1;W=U}a[o+(A|1)|0]=V;if(W>>>0<w>>>0){J=W+1|0;O=a[W]|0;c[g>>2]=J;X=O;Y=J}else{X=-1;Y=W}a[o+(A|2)|0]=X;a[o+(A|3)|0]=44;do{if(Y>>>0<w>>>0){J=Y+1|0;O=d[Y]|0;c[g>>2]=J;if((O|0)==1){c[G>>2]=c[G>>2]|512;Z=J;break}else if((O|0)==2){c[G>>2]=c[G>>2]|128;Z=J;break}else if((O|0)==3){c[G>>2]=c[G>>2]|256;Z=J;break}else{Z=J;break}}else{Z=Y}}while(0);J=f+4|0;if((J|0)>(t|0)){break}else{A=f;f=J;L=Z}}L=H?t&252:4;if((L|0)==0){break b}a[o+(L-1)|0]=0;CBb(e+88|0,194e4,o|0,0)|0;break};case 89:{L=t>>>3;if(!(v<<24>>24==0|(t&7|0)==0)){s=-1094995529;i=n;return s|0}if((v&255)>>>0>15>>>0){DDb(b,2230872,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}if(!((v&255)>>>0>7>>>0)){break b}f=c[h>>2]|0;A=L*5|0;do{if((c[f+96>>2]|0)==0){if((BT(f,A)|0)==0){_=c[h>>2]|0;break}else{s=-12;i=n;return s|0}}else{_=f}}while(0);if((c[_+100>>2]|0)<(A|0)){s=-1094995529;i=n;return s|0}if((L|0)==0){$=-1}else{f=e+72|0;H=(v&255)>>>0>15>>>0;G=0;r=c[_+96>>2]|0;y=c[g>>2]|0;while(1){if(y>>>0<w>>>0){J=y+1|0;O=a[y]|0;c[g>>2]=J;aa=O;ba=J}else{aa=-1;ba=y}J=G<<2;a[o+J|0]=aa;if(ba>>>0<w>>>0){O=ba+1|0;ca=a[ba]|0;c[g>>2]=O;da=ca;ea=O}else{da=-1;ea=ba}a[o+(J|1)|0]=da;if(ea>>>0<w>>>0){O=ea+1|0;ca=a[ea]|0;c[g>>2]=O;fa=ca;ga=O}else{fa=-1;ga=ea}a[o+(J|2)|0]=fa;a[o+(J|3)|0]=44;if(((d[ga]|0)-32|0)>>>0<6>>>0){c[f>>2]=c[f>>2]|128}if(ga>>>0<w>>>0){J=a[ga]|0;c[g>>2]=ga+1;ha=J}else{ha=-1}a[r+4|0]=ha;J=c[g>>2]|0;O=r;x=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;O=(c[g>>2]|0)+4|0;c[g>>2]=O;J=G+1|0;if((J|0)<(L|0)){G=J;r=r+5|0;y=O}else{break}}$=H?(L<<2)-1|0:3}a[o+$|0]=0;CBb(e+88|0,194e4,o|0,0)|0;break};case 31:{y=c[g>>2]|0;if((y+1|0)>>>0<w>>>0){c[g>>2]=y+2}if((k|0)<=0){break b}if((c[(c[h>>2]|0)+48>>2]|0)!=86066){if((c[e+440>>2]|0)<=0){break b}}y=c[j+4>>2]|0;if((y|0)==0){break b}if((c[j>>2]|0)!=(l|0)){break b}Ny(q,c[j+8>>2]|0,y,0,0,0,0,0)|0;vF(b,e,q)|0;y=c[h>>2]|0;if((c[y+48>>2]|0)!=86018){break b}if((c[y+100>>2]|0)<=0){break b}c[e+236>>2]=0;c[e+440>>2]=0;c[y+8>>2]=1;break};default:{}}}while(0);c[g>>2]=w;s=0;i=n;return s|0}function MJ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+1376|0;g=f|0;h=f+160|0;j=f+288|0;k=c[b+36>>2]|0;TGb(j|0,0,1088)|0;b=c[k+4>>2]|0;if((e-4|0)<=7){i=f;return}if((a[d]|0)!=5){i=f;return}l=e-12|0;e=j|0;do{if(l>>>0>1073741824>>>0){m=0}else{n=g+8|0;if((Ny(n,d+8|0,l,0,0,0,0,0)|0)<0){m=0;break}c[g>>2]=b;c[g+152>>2]=0;o=g+144|0;c[o>>2]=0;c[g+136>>2]=e;c[g+140>>2]=0;c[g+148>>2]=16;p=Ty(n,0,0,1)|0;a:do{if((l|0)>0){q=F;r=p;s=l;while(1){if((cK(g,r,q,s,0)|0)<0){break a}t=Ty(n,0,0,1)|0;u=F;v=YGb(s,0,r,q)|0;w=ZGb(v,F,t,u)|0;v=w;if((v|0)>0){q=u;r=t;s=v}else{break}}}}while(0);m=c[o>>2]|0}}while(0);g=k+8288|0;k=(m|0)>0;l=b;e=0;do{d=g+(e<<2)|0;n=c[d>>2]|0;b:do{if(!((n|0)==0|k^1)){p=0;s=n;while(1){c:do{if((c[s+4>>2]|0)==(c[j+(p*68|0)>>2]|0)){do{if((s|0)!=0){if((c[s+12>>2]|0)!=0){break}r=c[s+20>>2]|0;q=c[r+20>>2]|0;if((q|0)==0){break c}UGb(r+348|0,j+(p*68|0)+12|0,56)|0;Ny(h,c[j+(p*68|0)+8>>2]|0,c[j+(p*68|0)+4>>2]|0,0,0,0,0,0)|0;vF(b,q,h)|0;r=c[q+8>>2]|0;v=c[r+48>>2]|0;do{if((v|0)==0){break c}else if((v|0)==28){x=20}else if((v|0)==86018){if((c[r+100>>2]|0)<=0){x=25;break}c[q+236>>2]=0;if((v|0)==0){break c}else if((v|0)==28){x=20}else{x=22}}else{x=22}}while(0);do{if((x|0)==20){x=0;if((c[r+100>>2]|0)<=0){x=23;break}c[q+236>>2]=0;if((v|0)==0){break c}else{x=22}}}while(0);do{if((x|0)==22){x=0;if(v>>>0<65536>>>0){x=23;break}if(v>>>0<94208>>>0){x=25;break}if(!(v>>>0<98304>>>0)){break c}c[r+8>>2]=3;break c}}while(0);if((x|0)==23){x=0;c[r+8>>2]=0;break c}else if((x|0)==25){x=0;c[r+8>>2]=1;break c}}}while(0);yDb(l,16,2080064,(v=i,i=i+8|0,c[v>>2]=e,v)|0);i=v}}while(0);v=p+1|0;if((v|0)>=(m|0)){break b}p=v;s=c[d>>2]|0}}}while(0);e=e+1|0;}while((e|0)<8192);if(k){y=0}else{i=f;return}do{ZDb(c[j+(y*68|0)+8>>2]|0);y=y+1|0;}while((y|0)<(m|0));i=f;return}function NJ(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=f-4|0;f=e+g|0;if((g|0)<=0){return}if(!((g|0)>7&(a[e]|0)==66&(g|0)>9&(g|0)>10&(g|0)>12)){return}g=(c[b+36>>2]|0)+4|0;b=e+11|0;while(1){e=b;h=(de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535;if(!((b+2|0)>>>0<f>>>0&(b+4|0)>>>0<f>>>0)){i=22;break}e=b+3|0;j=(de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&4095;e=j+5|0;k=b+e|0;if(k>>>0>f>>>0){i=22;break}a:do{if(e>>>0>5>>>0){l=b+5|0;while(1){m=l+1|0;if(m>>>0<k>>>0){n=d[m]|0;o=l+2|0}else{n=-1;o=m}m=o+n|0;if(m>>>0>k>>>0){break a}do{if((a[l]|0)==72&o>>>0<f>>>0){p=o+1|0;if(!(p>>>0<f>>>0)){break}q=d[p]|0;p=q+2|0;r=o+p|0;if(r>>>0>f>>>0){break}s=WDb(q+1|0)|0;if((s|0)==0){break}UGb(s|0,o+2|0,q)|0;a[s+q|0]=0;do{if(r>>>0<f>>>0){t=d[r]|0;u=t+1|0;if((o+(u+p)|0)>>>0>f>>>0){v=0;break}w=WDb(u)|0;if((w|0)==0){v=0;break}UGb(w|0,o+(q+3)|0,t)|0;a[w+t|0]=0;t=NT(c[g>>2]|0,h)|0;if((t|0)==0){v=w;break}u=t+20|0;CBb(u,2090248,w,0)|0;CBb(u,2085296,s,0)|0;v=w}else{v=0}}while(0);ZDb(v);ZDb(s)}}while(0);if(m>>>0<k>>>0){l=m}else{break}}}}while(0);if((b+(j+6)|0)>>>0<f>>>0){b=k}else{i=22;break}}if((i|0)==22){return}}function OJ(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=c[b+36>>2]|0;b=g;h=f-4|0;f=e+h|0;if((h|0)<=4){return}if(!((h|0)>7&(a[e]|0)==0)){return}i=e+3|0;j=(de((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535;i=g+4|0;c[(c[i>>2]|0)+1184>>2]=j;j=g+92|0;k=j;$Db(j);l=g+88|0;c[l>>2]=0;a:do{if((h|0)>9){m=g+41056|0;n=g+8288|0;o=e+8|0;while(1){p=o;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=(de(q|0)|0)&65535;if(!((o+3|0)>>>0<f>>>0)){r=47;break}s=o+4|0;t=o+2|0;u=(de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&8191;if((u|0)==(c[m>>2]|0)){r=47;break}b:do{if(!(q<<16>>16==0)){t=n+(u<<2)|0;v=c[t>>2]|0;w=NT(c[i>>2]|0,p)|0;c[w+24>>2]=p;c[w+28>>2]=u;c:do{if((v|0)!=0){do{if((c[v+12>>2]|0)==1){if((c[v>>2]|0)!=(u|0)){break}if((c[v+32>>2]|0)==1034){break c}}}while(0);w=c[t>>2]|0;x=c[w>>2]|0;y=c[w+12>>2]|0;do{if((y|0)==0){z=w+20|0;A=z;XAb((c[A>>2]|0)+344|0);if((c[(c[A>>2]|0)+20>>2]|0)!=0){break}$Db(z)}else if((y|0)==1){$Db(w+24|0)}}while(0);ZDb(w);c[b+8288+(x<<2)>>2]=0}}while(0);do{if((c[t>>2]|0)==0){v=cEb(40)|0;if((v|0)==0){break}c[b+8288+(u<<2)>>2]=v;c[v+12>>2]=1;c[v>>2]=u;c[v+4>>2]=-1;c[v+8>>2]=-1;c[v+32>>2]=1034;c[v+36>>2]=g;y=WDb(4096)|0;c[v+24>>2]=y;z=v+28|0;c[z>>2]=c[z>>2]|1;if((y|0)!=0){break}ZDb(v)}}while(0);if((bEb(j,(c[l>>2]|0)+1|0,268)|0)<0){B=0}else{t=c[l>>2]|0;v=c[k>>2]|0;c[v+(t*268|0)>>2]=p;c[v+(t*268|0)+4>>2]=0;c[v+(t*268|0)+264>>2]=0;B=(c[l>>2]|0)+1|0}c[l>>2]=B;t=0;while(1){if(!(t>>>0<B>>>0)){C=B;break}D=c[k>>2]|0;E=D+(t*268|0)|0;if((c[E>>2]|0)==(p|0)){r=28;break}else{t=t+1|0}}do{if((r|0)==28){r=0;if((E|0)==0){C=B;break}v=D+(t*268|0)+4|0;y=c[v>>2]|0;if(y>>>0>63>>>0){C=B;break}c[v>>2]=y+1;c[D+(t*268|0)+8+(y<<2)>>2]=0;C=c[l>>2]|0}}while(0);t=0;while(1){if(!(t>>>0<C>>>0)){break b}F=c[k>>2]|0;G=F+(t*268|0)|0;if((c[G>>2]|0)==(p|0)){break}else{t=t+1|0}}if((G|0)==0){break}y=F+(t*268|0)+4|0;v=c[y>>2]|0;if(v>>>0>63>>>0){break}c[y>>2]=v+1;c[F+(t*268|0)+8+(v<<2)>>2]=u}}while(0);if((o+5|0)>>>0<f>>>0){o=s}else{break a}}if((r|0)==47){return}}}while(0);r=c[i>>2]|0;i=r+1104|0;f=c[i>>2]|0;if((f|0)==0){return}else{H=0;I=f}while(1){f=c[l>>2]|0;F=0;while(1){if(!(F>>>0<f>>>0)){break}if((c[(c[k>>2]|0)+(F*268|0)>>2]|0)==(c[c[(c[r+1108>>2]|0)+(H<<2)>>2]>>2]|0)){break}else{F=F+1|0}}d:do{if((F|0)==(f|0)){G=c[r+1108>>2]|0;C=c[c[G+(H<<2)>>2]>>2]|0;D=0;while(1){if(!(D>>>0<I>>>0)){J=I;break d}K=c[G+(D<<2)>>2]|0;if((c[K>>2]|0)==(C|0)){break}else{D=D+1|0}}if((K|0)==0){J=I;break}c[K+16>>2]=0;J=c[i>>2]|0}else{J=I}}while(0);f=H+1|0;if(f>>>0<J>>>0){H=f;I=J}else{break}}return}function PJ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=i;g=b+4|0;h=c[g>>2]|0;j=e+1|0;k=(d[j]|d[j+1|0]<<8)<<16>>16;j=(de(k|0)|0)&8191;do{if((j|0)!=0){l=c[h+1104>>2]|0;m=h+1108|0;n=0;while(1){if(!(n>>>0<l>>>0)){break}if((c[(c[(c[m>>2]|0)+(n<<2)>>2]|0)+8>>2]|0)==48){break}else{n=n+1|0}}if((n|0)==(l|0)){break}o=c[b+88>>2]|0;if((o|0)==0){break}p=c[b+92>>2]|0;q=(l|0)==0;r=0;s=0;t=0;while(1){u=c[p+(r*268|0)+4>>2]|0;do{if((u|0)==0){v=s;w=t}else{x=p+(r*268|0)|0;if(q){v=s;w=t;break}else{y=0;z=s;A=t}while(1){if((c[p+(r*268|0)+8+(y<<2)>>2]|0)==(j|0)){B=c[x>>2]|0;C=c[m>>2]|0;D=0;E=z;G=A;while(1){H=c[C+(D<<2)>>2]|0;do{if((c[H>>2]|0)==(B|0)){if((c[H+8>>2]|0)==48){I=G+1|0;J=E;break}else{I=G;J=E+1|0;break}}else{I=G;J=E}}while(0);H=D+1|0;if(H>>>0<l>>>0){D=H;E=J;G=I}else{K=I;L=J;break}}}else{K=A;L=z}G=y+1|0;if(G>>>0<u>>>0){y=G;z=L;A=K}else{v=L;w=K;break}}}}while(0);u=r+1|0;if(u>>>0<o>>>0){r=u;s=v;t=w}else{break}}if((v|0)!=0|(w|0)==0){break}else{M=0}i=f;return M|0}}while(0);w=k&64;k=b+8288+(j<<2)|0;v=c[k>>2]|0;K=(w|0)==0;if((v|0)!=0|(c[b+40>>2]|0)==0|K){N=v}else{v=cEb(416)|0;a:do{if((v|0)!=0){c[v+12>>2]=b;c[v+16>>2]=c[g>>2];c[v>>2]=j;c[v+4>>2]=-1;c[v+28>>2]=4;L=v+56|0;c[L>>2]=0;c[L+4>>2]=-2147483648;L=v+64|0;c[L>>2]=0;c[L+4>>2]=-2147483648;L=v+408|0;c[L>>2]=-1;c[L+4>>2]=-1;do{if((c[k>>2]|0)==0){L=cEb(40)|0;if((L|0)==0){break}c[k>>2]=L;c[L+12>>2]=0;c[L>>2]=j;c[L+4>>2]=-1;c[L+8>>2]=-1;c[L+16>>2]=2;c[L+20>>2]=v;break a}}while(0);ZDb(v)}}while(0);N=c[k>>2]|0}if((N|0)==0){M=0;i=f;return M|0}c[b+41056>>2]=j;v=e+3|0;L=d[v]|0;A=L>>>4;if((A&3|0)==0){M=0;i=f;return M|0}z=A&1;y=(A&2|0)!=0;do{if(y){if((a[e+4|0]|0)==0){O=0;break}O=(a[e+5|0]|0)<0}else{O=0}}while(0);A=L&15;L=(z|0)!=0;z=N+8|0;J=c[z>>2]|0;if(L){P=J+1&15}else{P=J}do{if((j|0)==8191|O){c[z>>2]=A;Q=1}else{c[z>>2]=A;if((J|0)<0|(P|0)==(A|0)){Q=1;break}yDb(c[g>>2]|0,48,2203776,(R=i,i=i+24|0,c[R>>2]=j,c[R+8>>2]=P,c[R+16>>2]=A,R)|0);i=R;if((c[N+12>>2]|0)!=0){Q=0;break}I=(c[N+20>>2]|0)+36|0;c[I>>2]=c[I>>2]|2;Q=0}}while(0);if(!L){M=0;i=f;return M|0}L=e+4|0;do{if(y){A=(d[L]|0)+5|0;if(A>>>0<188>>>0){S=e+A|0;break}else{M=0;i=f;return M|0}}else{S=L}}while(0);y=e+188|0;A=Ty(c[(c[g>>2]|0)+16>>2]|0,0,0,1)|0;P=F;j=-1;do{if((P|0)>(j|0)|(P|0)==(j|0)&A>>>0>-1>>>0){J=0;if((P|0)>(J|0)|(P|0)==(J|0)&A>>>0>187>>>0){J=YGb(A,P,-188,-1)|0;z=b+32|0;c[z>>2]=J;c[z+4>>2]=F;break}else{yDb(0,0,2196352,(R=i,i=i+24|0,c[R>>2]=2183448,c[R+8>>2]=2168640,c[R+16>>2]=1987,R)|0);i=R;Cd();return 0}}}while(0);do{if((c[N+12>>2]|0)==1){do{if(K){if(!Q){break}ZJ(c[h+12>>2]|0,N,S,y-S|0,0)}else{j=a[S]|0;z=j&255;J=S+(z+1)|0;if(J>>>0>y>>>0){M=0;i=f;return M|0}do{if(!(j<<24>>24==0|Q^1)){ZJ(c[h+12>>2]|0,N,S+1|0,z,0);if((c[k>>2]|0)==0){M=0}else{break}i=f;return M|0}}while(0);if(!(J>>>0<y>>>0)){break}ZJ(c[h+12>>2]|0,N,J,y-J|0,1)}}while(0);z=c[g>>2]|0;if((c[z+20>>2]&1|0)==0){break}j=b+92|0;O=c[b+88>>2]|0;I=0;while(1){if(!(I>>>0<O>>>0)){break}if((c[(c[j>>2]|0)+(I*268|0)+264>>2]|0)==0){break}else{I=I+1|0}}if((I|0)!=(O|0)|(O|0)==0){break}j=0;if(!((c[z+24>>2]|0)>>>0>1>>>0|((P|0)>(j|0)|(P|0)==(j|0)&A>>>0>1e5>>>0))){break}yDb(z,48,2161088,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;j=(c[g>>2]|0)+20|0;c[j>>2]=c[j>>2]&-2}else{do{if((a[v]&32)>>>0<32>>>0){T=-1;U=-1}else{j=a[L]|0;if(j<<24>>24==0){T=-1;U=-1;break}if((a[e+5|0]&16)==0){T=-1;U=-1;break}if(((j&255)-1|0)<6){T=-1;U=-1;break}j=e+6|0;t=fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;j=d[e+10|0]|0;s=j<<8&256|d[e+11|0];r=gHb(j>>>7|(t<<1|0>>>31),0<<1|t>>>31|0,300,0)|0;t=YGb(r,F,s,0)|0;T=F;U=t}}while(0);z=c[N+16>>2]|0;O=c[b+8>>2]|0;I=ZGb(A,P,O,(O|0)<0|0?-1:0)|0;O=Ze[z&15](N,S,y-S|0,w,I,F,U,T)|0;if((O|0)<0){M=O}else{break}i=f;return M|0}}while(0);M=0;i=f;return M|0}function QJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+816|0;e=d|0;f=c[b+8>>2]|0;g=(f|0)/204|0;if((f|0)<2040){h=-1;i=d;return h|0}f=c[b+4>>2]|0;b=e;j=0;k=0;l=0;do{m=g-j|0;n=(m|0)>100?100:m;m=j*188|0;TGb(b|0,0,752)|0;o=(n*188|0)-3|0;if((o|0)>0){p=m|3;q=0;r=0;while(1){s=r+1|0;do{if((a[f+(r+m)|0]|0)==71){if((a[f+(s+m)|0]|0)<0){t=q;break}if((a[f+(p+r)|0]|0)==71){t=q;break}u=e+(((r|0)%188|0)<<2)|0;v=(c[u>>2]|0)+1|0;c[u>>2]=v;t=(v|0)>(q|0)?v:q}else{t=q}}while(0);if((s|0)<(o|0)){q=t;r=s}else{w=t;break}}}else{w=0}r=j*192|0;TGb(b|0,0,768)|0;q=(n*192|0)-3|0;if((q|0)>0){o=r|3;p=0;m=0;while(1){v=m+1|0;do{if((a[f+(m+r)|0]|0)==71){if((a[f+(v+r)|0]|0)<0){x=p;break}if((a[f+(o+m)|0]|0)==71){x=p;break}u=e+(((m|0)%192|0)<<2)|0;y=(c[u>>2]|0)+1|0;c[u>>2]=y;x=(y|0)>(p|0)?y:p}else{x=p}}while(0);if((v|0)<(q|0)){p=x;m=v}else{z=x;break}}}else{z=0}m=j*204|0;TGb(b|0,0,816)|0;p=(n*204|0)-3|0;if((p|0)>0){q=m|3;o=0;r=0;while(1){s=r+1|0;do{if((a[f+(r+m)|0]|0)==71){if((a[f+(s+m)|0]|0)<0){A=o;break}if((a[f+(q+r)|0]|0)==71){A=o;break}y=e+(((r|0)%204|0)<<2)|0;u=(c[y>>2]|0)+1|0;c[y>>2]=u;A=(u|0)>(o|0)?u:o}else{A=o}}while(0);if((s|0)<(p|0)){o=A;r=s}else{B=A;break}}}else{B=0}r=(w|0)>(z|0)?w:z;o=(r|0)>(B|0)?r:B;k=o+k|0;l=(l|0)>(o|0)?l:o;j=j+100|0;}while((j|0)<(g|0));j=(k*10|0|0)/(g|0)|0;if((j|0)<=6){i=d;return((l*10|0|0)>699?j+40|0:-1)|0}h=j+90|0;i=d;return h|0}function RJ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;i=i+9232|0;f=e|0;g=e+816|0;h=e+9008|0;j=e+9024|0;k=e+9032|0;l=e+9224|0;m=c[b+12>>2]|0;n=m;o=b+16|0;p=c[o>>2]|0;q=g|0;TGb(q|0,0,8192)|0;r=b+1088|0;Dz(p,c[r>>2]|0)|0;s=Ty(p,0,0,1)|0;t=F;u=mz(p,q,8192)|0;a:do{if((u|0)<1021){q=m+8|0;c[q>>2]=-1;v=q;w=26}else{q=f;TGb(q|0,0,752)|0;x=u-3|0;if((x|0)>0){y=0;z=0}else{TGb(q|0,0,768)|0;TGb(q|0,0,816)|0;A=m+8|0;c[A>>2]=-1;v=A;w=26;break}while(1){A=z+1|0;do{if((a[g+z|0]|0)==71){if((a[g+A|0]|0)<0){B=y;break}if((a[g+(z+3)|0]|0)==71){B=y;break}C=f+(((z|0)%188|0)<<2)|0;D=(c[C>>2]|0)+1|0;c[C>>2]=D;B=(D|0)>(y|0)?D:y}else{B=y}}while(0);if((A|0)<(x|0)){y=B;z=A}else{break}}TGb(q|0,0,768)|0;D=0;C=0;while(1){E=C+1|0;do{if((a[g+C|0]|0)==71){if((a[g+E|0]|0)<0){G=D;break}if((a[g+(C+3)|0]|0)==71){G=D;break}H=f+(((C|0)%192|0)<<2)|0;I=(c[H>>2]|0)+1|0;c[H>>2]=I;G=(I|0)>(D|0)?I:D}else{G=D}}while(0);if((E|0)<(x|0)){D=G;C=E}else{break}}TGb(q|0,0,816)|0;C=0;D=0;while(1){A=D+1|0;do{if((a[g+D|0]|0)==71){if((a[g+A|0]|0)<0){J=C;break}if((a[g+(D+3)|0]|0)==71){J=C;break}I=f+(((D|0)%204|0)<<2)|0;H=(c[I>>2]|0)+1|0;c[I>>2]=H;J=(H|0)>(C|0)?H:C}else{J=C}}while(0);if((A|0)<(x|0)){C=J;D=A}else{break}}do{if((B|0)>(J|0)&(B|0)>(G|0)){K=188}else{if((G|0)>(B|0)&(G|0)>(J|0)){K=192;break}D=(B|0)<(J|0)&(G|0)<(J|0);C=m+8|0;c[C>>2]=D?204:-1;if(D){L=C;break a}else{v=C;w=26;break a}}}while(0);C=m+8|0;c[C>>2]=K;L=C}}while(0);if((w|0)==26){yDb(b,24,2263792,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;c[v>>2]=188;L=v}c[m+4>>2]=b;v=m+40|0;c[v>>2]=0;do{if((c[b+4>>2]|0)==1175624){K=Ty(p,s,t,0)|0;J=F;G=0;if((J|0)<(G|0)|(J|0)==(G|0)&K>>>0<0>>>0){yDb(b,(c[p+88>>2]|0)!=0?16:32,2248816,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M}K=m+8356|0;do{if((c[K>>2]|0)==0){G=cEb(40)|0;if((G|0)==0){break}c[K>>2]=G;c[G+12>>2]=1;c[G>>2]=17;c[G+4>>2]=-1;c[G+8>>2]=-1;c[G+32>>2]=1604;c[G+36>>2]=m;J=WDb(4096)|0;c[G+24>>2]=J;B=G+28|0;c[B>>2]=c[B>>2]|1;if((J|0)!=0){break}ZDb(G)}}while(0);K=m+8288|0;do{if((c[K>>2]|0)==0){G=cEb(40)|0;if((G|0)==0){break}c[K>>2]=G;c[G+12>>2]=1;c[G>>2]=0;c[G+4>>2]=-1;c[G+8>>2]=-1;c[G+32>>2]=112;c[G+36>>2]=m;J=WDb(4096)|0;c[G+24>>2]=J;B=G+28|0;c[B>>2]=c[B>>2]|1;if((J|0)!=0){break}ZDb(G)}}while(0);XJ(n,((c[r>>2]|0)>>>0)/((c[L>>2]|0)>>>0)|0)|0;c[v>>2]=1;K=b+20|0;c[K>>2]=c[K>>2]|1}else{K=LT(b,0)|0;if((K|0)==0){N=-1;i=e;return N|0}MT(K,60,1,27e6);G=K+8|0;J=c[G>>2]|0;c[J+8>>2]=2;c[J+48>>2]=131072;J=k|0;if((WJ(b,J,c[L>>2]|0,l)|0)<0){N=-1;i=e;return N|0}else{O=-1;P=0;Q=0}b:while(1){B=c[l>>2]|0;f=B+1|0;g=(de((d[f]|d[f+1|0]<<8)<<16>>16|0)|0)&8191;do{if((O|0)==-1|(O|0)==(g|0)){if((a[B+3|0]&32)>>>0<32>>>0){w=50;break}f=a[B+4|0]|0;if(f<<24>>24==0){w=50;break}if((a[B+5|0]&16)==0){w=50;break}if(((f&255)-1|0)<6){w=50;break}f=B+6|0;z=fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;f=d[B+10|0]|0;y=f<<8&256|d[B+11|0];u=(c[L>>2]|0)-188|0;if((u|0)>0){Vy(c[o>>2]|0,u,(u|0)<0|0?-1:0)|0;}c[j+(Q<<2)>>2]=P;u=gHb(f>>>7|(z<<1|0>>>31),0<<1|z>>>31|0,300,0)|0;z=YGb(u,F,y,0)|0;y=h+(Q<<3)|0;c[y>>2]=z;c[y+4>>2]=F;if((Q|0)>0){w=53;break b}R=Q+1|0;S=g}else{w=50}}while(0);do{if((w|0)==50){w=0;g=(c[L>>2]|0)-188|0;if((g|0)<=0){R=Q;S=O;break}Vy(c[o>>2]|0,g,(g|0)<0|0?-1:0)|0;R=Q;S=O}}while(0);if((WJ(b,J,c[L>>2]|0,l)|0)<0){N=-1;w=56;break}else{O=S;P=P+1|0;Q=R}}if((w|0)==53){J=h+8|0;g=h|0;B=c[g>>2]|0;A=c[g+4>>2]|0;g=ZGb(c[J>>2]|0,c[J+4>>2]|0,B,A)|0;J=c[j>>2]|0;y=(c[j+4>>2]|0)-J|0;z=eHb(g,F,y,(y|0)<0|0?-1:0)|0;y=z;c[m+64>>2]=y;z=ba(J,y)|0;J=ZGb(B,A,z,(z|0)<0|0?-1:0)|0;z=F;A=m+56|0;c[A>>2]=J;c[A+4>>2]=z;A=~~(40608.0e6/+(y|0));c[b+1072>>2]=A;c[(c[G>>2]|0)+72>>2]=A;A=K+48|0;c[A>>2]=J;c[A+4>>2]=z;break}else if((w|0)==56){i=e;return N|0}}}while(0);w=Ty(p,s,t,0)|0;t=F;s=0;if(!((t|0)<(s|0)|(t|0)==(s|0)&w>>>0<0>>>0)){N=0;i=e;return N|0}yDb(b,(c[p+88>>2]|0)!=0?16:32,2248816,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=0;i=e;return N|0}function SJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[a+12>>2]|0;a=b+28|0;c[a>>2]=-1;e=d+72|0;c[e>>2]=b;f=XJ(d,0)|0;a:do{if((f|0)<0){BZ(c[e>>2]|0);g=d+8288|0;h=0;b:while(1){i=c[g+(h<<2)>>2]|0;do{if((i|0)!=0){if((c[i+12>>2]|0)!=0){break}j=c[i+20>>2]|0;k=j+28|0;if((c[k>>2]|0)!=3){break}if((c[j+32>>2]|0)>0){break b}}}while(0);h=h+1|0;if((h|0)>=8192){break a}}YJ(j,b);c[k>>2]=4;l=c[a>>2]|0;m=l>>31;n=m&-4;return n|0}}while(0);if((f|0)==0){l=c[a>>2]|0;m=l>>31;n=m&-4;return n|0}else{return f|0}return 0}function TJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+12>>2]|0;a=b;$Db(b+92|0);c[b+88>>2]=0;b=0;do{d=c[a+8288+(b<<2)>>2]|0;if((d|0)!=0){e=c[d>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==0){g=d+20|0;h=g;XAb((c[h>>2]|0)+344|0);if((c[(c[h>>2]|0)+20>>2]|0)!=0){break}$Db(g)}else if((f|0)==1){$Db(d+24|0)}}while(0);ZDb(d);c[a+8288+(e<<2)>>2]=0}b=b+1|0;}while((b|0)<8192);return 0}function UJ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+80|0;h=g|0;j=c[a+12>>2]|0;k=j+32|0;l=c[j+8>>2]|0;j=l;m=(l|0)<0|0?-1:0;l=fHb(c[k>>2]|0,c[k+4>>2]|0,j,m)|0;k=c[d>>2]|0;n=c[d+4>>2]|0;o=l;l=o;p=(o|0)<0|0?-1:0;o=YGb(j,m,-1,-1)|0;q=YGb(o,F,k,n)|0;n=ZGb(q,F,l,p)|0;q=F;k=fHb(n,q,j,m)|0;m=ZGb(n,q,k,F)|0;k=YGb(m,F,l,p)|0;p=F;kT(a);l=Ty(c[a+16>>2]|0,k,p,0)|0;m=F;q=-1;if(!(((m|0)>(q|0)|(m|0)==(q|0)&l>>>0>-1>>>0)&((p|0)<(f|0)|(p|0)==(f|0)&k>>>0<e>>>0))){r=-2147483648;s=0;i=g;return(F=r,s)|0}k=h+16|0;p=h+64|0;l=h+32|0;q=a+28|0;a:while(1){vZ(h);if((gT(a,h)|0)<0){r=-2147483648;s=0;t=10;break}BZ(h);do{if(!((c[k>>2]|0)==0&(c[k+4>>2]|0)==(-2147483648|0))){m=c[p+4>>2]|0;n=-1;if(!((m|0)>(n|0)|(m|0)==(n|0)&(c[p>>2]|0)>>>0>-1>>>0)){break}iT(a,c[l>>2]|0);jT(c[(c[q>>2]|0)+(c[l>>2]<<2)>>2]|0,c[p>>2]|0,c[p+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0,0,0,1)|0;if((c[l>>2]|0)!=(b|0)){break}u=c[p>>2]|0;v=c[p+4>>2]|0;n=c[d+4>>2]|0;if(!((v|0)<(n|0)|(v|0)==(n|0)&u>>>0<(c[d>>2]|0)>>>0)){t=8;break a}}}while(0);n=c[p+4>>2]|0;if(!((n|0)<(f|0)|(n|0)==(f|0)&(c[p>>2]|0)>>>0<e>>>0)){r=-2147483648;s=0;t=10;break}}if((t|0)==8){c[d>>2]=u;c[d+4>>2]=v;r=c[k+4>>2]|0;s=c[k>>2]|0;i=g;return(F=r,s)|0}else if((t|0)==10){i=g;return(F=r,s)|0}return 0}function VJ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+24|0;g=f|0;h=f+16|0;j=c[b+12>>2]|0;if((wZ(e,188)|0)<0){k=-12;i=f;return k|0}l=b+16|0;m=Ty(c[l>>2]|0,0,0,1)|0;n=e+64|0;c[n>>2]=m;c[n+4>>2]=F;n=e+24|0;m=j+8|0;o=WJ(b,c[n>>2]|0,c[m>>2]|0,h)|0;if((o|0)<0){BZ(e);k=o;i=f;return k|0}o=c[h>>2]|0;h=c[n>>2]|0;if((o|0)!=(h|0)){UGb(h|0,o|0,c[m>>2]|0)|0}o=(c[m>>2]|0)-188|0;if((o|0)>0){Vy(c[l>>2]|0,o,(o|0)<0|0?-1:0)|0;}if((c[j+44>>2]|0)!=0){o=c[n>>2]|0;do{if(!((a[o+3|0]&32)>>>0<32>>>0)){n=a[o+4|0]|0;if(n<<24>>24==0){break}if((a[o+5|0]&16)==0){break}if(((n&255)-1|0)<6){break}n=o+6|0;h=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=d[o+10|0]|0;b=n>>>7|(h<<1|0>>>31);p=0<<1|h>>>31|0;h=n<<8&256|(d[o+11|0]|0);n=Ty(c[l>>2]|0,0,0,1)|0;q=F;r=g|0;s=g+3|0;t=g+4|0;u=g+5|0;v=g+6|0;w=0;a:while(1){x=c[l>>2]|0;y=ba(c[m>>2]|0,w)|0;z=YGb(y,(y|0)<0|0?-1:0,n,q)|0;Ty(x,z,F,0)|0;mz(c[l>>2]|0,r,12)|0;do{if(!((a[s]&32)>>>0<32>>>0)){z=a[t]|0;if(z<<24>>24==0){break}if((a[u]&16)==0){break}if(((z&255)-1|0)>=6){A=18;break a}}}while(0);z=w+1|0;if((z|0)<697){w=z}else{break}}if((A|0)==18){u=v;t=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=d[g+10|0]|0;s=u<<8&256|(d[g+11|0]|0);r=ZGb(u>>>7|(t<<1|0>>>31),0<<1|t>>>31|0,b,p)|0;t=gHb(r,F,300,0)|0;r=s-h|0;s=YGb(t,F,r,(r|0)<0|0?-1:0)|0;r=w+1|0;t=eHb(s,F,r,(r|0)<0|0?-1:0)|0;c[j+64>>2]=t}Ty(c[l>>2]|0,n,q,0)|0;t=gHb(b,p,300,0)|0;r=YGb(t,F,h,0)|0;t=j+56|0;c[t>>2]=r;c[t+4>>2]=F}}while(0);l=j+56|0;g=c[l+4>>2]|0;A=e+8|0;c[A>>2]=c[l>>2];c[A+4>>2]=g;g=j+64|0;c[e+48>>2]=c[g>>2];j=c[g>>2]|0;g=YGb(c[l>>2]|0,c[l+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[l>>2]=g;c[l+4>>2]=F}c[e+32>>2]=0;k=0;i=f;return k|0}function WJ(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;g=i;h=b+16|0;j=c[h>>2]|0;k=nz(j,d,188,f)|0;a:do{if((k|0)==188){l=e;m=(e|0)<0|0?-1:0;n=b+12|0;b:while(1){if((a[c[f>>2]|0]|0)==71){o=0;p=23;break}q=Ty(j,0,0,1)|0;r=F;s=m>>>0>r>>>0|m>>>0==r>>>0&l>>>0>q>>>0;t=ZGb(0,0,s?q:l,s?r:m)|0;Ty(j,t,F,1)|0;t=c[h>>2]|0;r=0;while(1){if((r|0)>=65536){p=22;break b}s=lz(t)|0;if((Xy(t)|0)!=0){o=-11;p=23;break b}if((s|0)==71){break}else{r=r+1|0}}Ty(t,-1,-1,1)|0;r=c[n>>2]|0;s=r+4|0;q=Ty(c[(c[s>>2]|0)+16>>2]|0,0,0,1)|0;u=F;v=0;do{if(!((u|0)<(v|0)|(u|0)==(v|0)&q>>>0<0>>>0)){w=r+32|0;x=ZGb(q,u,c[w>>2]|0,c[w+4>>2]|0)|0;w=F;y=204;z=0;A=188;B=0;if((x|0)==192&(w|0)==0){C=r+16|0;c[C>>2]=(c[C>>2]|0)+1}else if((x|0)==(y|0)&(w|0)==(z|0)){z=r+20|0;c[z>>2]=(c[z>>2]|0)+1}else if((x|0)==(A|0)&(w|0)==(B|0)){B=r+12|0;c[B>>2]=(c[B>>2]|0)+1}B=r+24|0;w=(c[B>>2]|0)+1|0;c[B>>2]=w;if((w|0)<=10){break}w=r+12|0;do{if((c[w>>2]|0)>10){D=188;p=19}else{if((c[r+16>>2]|0)>10){D=192;p=19;break}B=(c[r+20>>2]|0)>10;if(B){D=B?204:0;p=19}}}while(0);do{if((p|0)==19){p=0;B=r+8|0;if((D|0)==(c[B>>2]|0)){break}yDb(c[s>>2]|0,24,1924880,(E=i,i=i+8|0,c[E>>2]=D,E)|0);i=E;c[B>>2]=D}}while(0);TGb(w|0,0,16)|0}}while(0);s=nz(j,d,188,f)|0;if((s|0)!=188){G=s;break a}}if((p|0)==22){yDb(b,16,1950616,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;o=-11;i=g;return o|0}else if((p|0)==23){i=g;return o|0}}else{G=k}}while(0);o=(G|0)<0?G:-541478725;i=g;return o|0}function XJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+216|0;e=d|0;f=d+208|0;g=c[a+4>>2]|0;h=g+16|0;j=Ty(c[h>>2]|0,0,0,1)|0;k=a+80|0;if(!((j|0)==(c[k>>2]|0)&(F|0)==(c[k+4>>2]|0))){j=0;do{l=a+8288+(j<<2)|0;m=c[l>>2]|0;if((m|0)!=0){if((c[m+12>>2]|0)==0){n=c[m+20>>2]|0;XAb(n+344|0);c[n+32>>2]=0;c[n+28>>2]=4;o=n+408|0;c[o>>2]=-1;c[o+4>>2]=-1;p=c[l>>2]|0}else{p=m}c[p+8>>2]=-1}j=j+1|0;}while((j|0)<8192)}j=a+68|0;c[j>>2]=0;p=e|0;TGb(e+188|0,0,16)|0;e=a+8|0;m=(b|0)==0;l=0;while(1){o=l+1|0;if(!(m|(o|0)<(b|0))){q=-11;break}n=c[j>>2]|0;if((n|0)>1){q=-11;break}if((n|0)>0){q=0;break}n=WJ(g,p,c[e>>2]|0,f)|0;if((n|0)!=0){q=n;break}n=PJ(a,c[f>>2]|0)|0;r=(c[e>>2]|0)-188|0;if((r|0)>0){Vy(c[h>>2]|0,r,(r|0)<0|0?-1:0)|0;}if((n|0)==0){l=o}else{q=n;break}}l=Ty(c[h>>2]|0,0,0,1)|0;c[k>>2]=l;c[k+4>>2]=F;i=d;return q|0}function YJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;vZ(b);e=a+344|0;c[b>>2]=c[e>>2];f=c[(c[e>>2]|0)+4>>2]|0;g=b+24|0;c[g>>2]=f;h=a+32|0;j=c[h>>2]|0;k=b+28|0;c[k>>2]=j;l=c[a+40>>2]|0;do{if((l|0)==204800){m=f;n=j}else{if(((c[h>>2]|0)+(c[a+44>>2]|0)|0)==(l+6|0)){m=f;n=j;break}yDb(c[a+16>>2]|0,24,2279144,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;o=a+36|0;c[o>>2]=c[o>>2]|2;m=c[g>>2]|0;n=c[k>>2]|0}}while(0);TGb(m+n|0,0,16)|0;n=c[a+24>>2]|0;do{if((n|0)==0){p=8}else{if((c[a+8>>2]|0)!=131){p=8;break}if((c[a+48>>2]|0)!=118){p=8;break}c[b+32>>2]=c[n>>2]}}while(0);if((p|0)==8){c[b+32>>2]=c[c[a+20>>2]>>2]}p=a+56|0;n=c[p+4>>2]|0;m=b+8|0;c[m>>2]=c[p>>2];c[m+4>>2]=n;n=a+64|0;m=c[n+4>>2]|0;k=b+16|0;c[k>>2]=c[n>>2];c[k+4>>2]=m;m=a+72|0;k=c[m+4>>2]|0;g=b+64|0;c[g>>2]=c[m>>2];c[g+4>>2]=k;k=a+36|0;c[b+36>>2]=c[k>>2];c[p>>2]=0;c[p+4>>2]=-2147483648;c[n>>2]=0;c[n+4>>2]=-2147483648;c[e>>2]=0;c[h>>2]=0;c[k>>2]=0;i=d;return}function ZJ(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=e+16|0;do{if((h|0)==0){if((c[e+28>>2]&2|0)==0){j=i|0;k=c[j>>2]|0;l=4096-k|0;m=(l|0)>(g|0)?g:l;UGb((c[e+24>>2]|0)+k|0,f|0,m)|0;k=(c[j>>2]|0)+m|0;c[j>>2]=k;j=c[e+20>>2]|0;m=e+20|0;if((j|0)==-1){n=k;o=m;p=5;break}else{q=j;r=k;s=m;break}}else{return}}else{UGb(c[e+24>>2]|0,f|0,g)|0;c[i>>2]=g;c[e+20>>2]=-1;m=e+28|0;c[m>>2]=c[m>>2]&-3;n=g;o=e+20|0;p=5}}while(0);do{if((p|0)==5){do{if((n|0)>2){g=(c[e+24>>2]|0)+1|0;i=((de((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&4095)+3|0;if(i>>>0>4096>>>0){return}else{c[o>>2]=i;t=i;break}}else{t=c[o>>2]|0}}while(0);if(!((t|0)==-1)){q=t;r=n;s=o;break}return}}while(0);if((r|0)<(q|0)){return}q=e+28|0;r=c[q>>2]|0;c[q>>2]=r|2;do{if((r&1|0)==0){u=e+24|0}else{q=tBb(3)|0;o=e+24|0;n=(uBb(q,-1,c[o>>2]|0,c[s>>2]|0)|0)==0;q=b+((c[e>>2]|0)+96)|0;if(n){a[q]=100;u=o;break}n=a[q]|0;if(!(n<<24>>24>-10)){u=o;break}a[q]=n-1;return}}while(0);Xe[c[e+32>>2]&4095](e,c[u>>2]|0,c[s>>2]|0);return}function _J(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0;m=i;i=i+24|0;n=m|0;o=c[b+20>>2]|0;b=o;p=o+12|0;q=c[p>>2]|0;r=q+72|0;s=c[r>>2]|0;if((s|0)==0){t=0;i=m;return t|0}if(!((k|0)==(-1|0)&(l|0)==(-1|0))){u=o+408|0;c[u>>2]=k;c[u+4>>2]=l}if((g|0)==0){v=o+32|0}else{g=o+28|0;l=o+32|0;do{if((c[g>>2]|0)==3){if((c[l>>2]|0)<=0){break}YJ(b,s);c[q+68>>2]=1}}while(0);c[g>>2]=0;c[l>>2]=0;g=o+72|0;c[g>>2]=h;c[g+4>>2]=j;v=l}l=o+44|0;j=q+4|0;if((f|0)<=0){t=0;i=m;return t|0}g=o+28|0;h=o+80|0;s=o+81|0;u=o+82|0;k=o+83|0;w=o+20|0;x=o;y=o+84|0;z=o+40|0;A=o+344|0;B=o+24|0;C=o+88|0;D=o+87|0;E=o+89|0;G=o+56|0;H=o+64|0;I=o+48|0;J=o+8|0;K=n|0;L=n+12|0;M=n+16|0;N=n+4|0;O=n+8|0;P=o+348|0;Q=o+352|0;R=o+380|0;S=o+368|0;T=o+360|0;U=o+400|0;V=o+392|0;W=o+388|0;X=o+376|0;Y=o+384|0;Z=o+356|0;_=o+396|0;$=o+364|0;aa=o+372|0;ba=o+16|0;ca=o+90|0;da=o+92|0;ea=o+94|0;fa=o+95|0;ga=o+97|0;ha=o+99|0;ia=q+68|0;q=e;e=f;a:while(1){b:do{switch(c[g>>2]|0){case 0:{f=c[v>>2]|0;ja=6-f|0;ka=(ja|0)>(e|0)?e:ja;UGb(o+(f+80)|0,q|0,ka)|0;f=ka+(c[v>>2]|0)|0;c[v>>2]=f;ja=q+ka|0;la=e-ka|0;if((f|0)!=6){ma=la;na=ja;break b}c:do{if((a[h]|0)==0){if((a[s]|0)!=0){break}if((a[u]|0)!=1){break}f=d[k]|256;ka=c[w>>2]|0;oa=(ka|0)==0;do{if(oa){pa=21}else{if((c[ka+76>>2]|0)!=48){pa=21;break}qa=c[B>>2]|0;if((qa|0)==0){break c}if((c[qa+76>>2]|0)==48|(f|0)==446){break c}}}while(0);if((pa|0)==21){pa=0;if((f|0)==446){break}}if(oa){ka=LT(c[j>>2]|0,0)|0;c[w>>2]=ka;if((ka|0)==0){t=-12;pa=135;break a}c[ka+4>>2]=c[x>>2];$J(ka,b,0,0)}ka=(d[y]|d[y+1|0]<<8)<<16>>16;qa=(de(ka|0)|0)&65535;ra=ka<<16>>16==0?204800:qa;c[z>>2]=ra;qa=UAb(ra+16|0)|0;c[A>>2]=qa;if((qa|0)==0){t=-12;pa=135;break a}switch(f|0){case 511:case 504:case 498:case 497:case 496:case 447:case 444:{c[g>>2]=3;c[v>>2]=0;ma=la;na=ja;break b;break};default:{}}c[g>>2]=1;qa=c[w>>2]|0;if((c[(c[qa+8>>2]|0)+48>>2]|0)!=0){ma=la;na=ja;break b}ra=qa+440|0;if((c[ra>>2]|0)!=0){ma=la;na=ja;break b}c[ra>>2]=1;ma=la;na=ja;break b}}while(0);c[g>>2]=4;ma=la;na=ja;break};case 1:{ra=c[v>>2]|0;qa=9-ra|0;if((qa|0)<0){t=-1;pa=135;break a}ka=(qa|0)>(e|0)?e:qa;UGb(o+(ra+80)|0,q|0,ka)|0;ra=(c[v>>2]|0)+ka|0;c[v>>2]=ra;qa=q+ka|0;sa=e-ka|0;if((ra|0)!=9){ma=sa;na=qa;break b}c[l>>2]=(d[C]|0)+9;c[g>>2]=2;ma=sa;na=qa;break};case 4:{t=0;pa=135;break a;break};case 3:{pa=123;break a;break};case 2:{qa=c[v>>2]|0;sa=(c[l>>2]|0)-qa|0;if((sa|0)<0){t=-1;pa=135;break a}ra=(sa|0)>(e|0)?e:sa;UGb(o+(qa+80)|0,q|0,ra)|0;qa=(c[v>>2]|0)+ra|0;c[v>>2]=qa;sa=q+ra|0;ka=e-ra|0;if((qa|0)!=(c[l>>2]|0)){ma=ka;na=sa;break b}ta=d[D]|0;c[G>>2]=0;c[G+4>>2]=-2147483648;c[H>>2]=0;c[H+4>>2]=-2147483648;ua=ta&192;if((ua|0)==128){va=a[E]&14;wa=((de((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(va<<29|0>>>3);xa=wa|((de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;wa=0<<29|va>>>3|0;c[G>>2]=xa;c[G+4>>2]=wa;c[H>>2]=xa;c[H+4>>2]=wa;ya=ea}else if((ua|0)==192){ua=a[E]&14;wa=((de((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(ua<<29|0>>>3);c[G>>2]=wa|((de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;c[G+4>>2]=0<<29|ua>>>3;ua=a[ea]&14;wa=((de((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(ua<<29|0>>>3);c[H>>2]=wa|((de((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;c[H+4>>2]=0<<29|ua>>>3;ya=ha}else{ya=E}c[I>>2]=-1;do{if((ta&1|0)!=0){ua=d[ya]|0;wa=ua>>>4;xa=(wa&11)+(wa&9)|0;if((ua&65|0)!=1){break}if((ya+(xa+3)|0)>>>0>(o+(qa+80)|0)>>>0){break}if((a[ya+(xa+1)|0]&127)==0){break}ua=d[ya+(xa+2)|0]|0;if((ua&128|0)!=0){break}c[I>>2]=ua}}while(0);c[g>>2]=3;c[v>>2]=0;ta=c[J>>2]|0;if((ta|0)==18&(ka|0)>0){ja=ka<<3;la=ja>>>0>2147483639>>>0|(sa|0)==0;ua=la?0:sa;xa=la?0:ja;c[K>>2]=ua;c[L>>2]=xa;ja=xa+8|0;c[M>>2]=ja;c[N>>2]=ua+(xa>>3);c[O>>2]=0;xa=(c[P>>2]|0)==0;if(xa){za=0;Aa=0}else{la=(d[ua]|0)>>>7;wa=(ja|0)>0|0;c[O>>2]=wa;za=la;Aa=wa}wa=(c[Q>>2]|0)==0;if(wa){Ba=Aa}else{la=((Aa|0)<(ja|0))+Aa|0;c[O>>2]=la;Ba=la}if(xa){Ca=wa?1:za}else{Ca=za}wa=c[R>>2]|0;if((wa|0)>0){xa=d[ua+(Ba>>>3)|0]<<(Ba&7)>>>7;la=((Ba|0)<(ja|0))+Ba|0;c[O>>2]=la;Da=xa&1;Ea=la}else{Da=0;Ea=Ba}if((c[S>>2]|0)==0){Fa=0;Ga=Ea}else{la=d[ua+(Ea>>>3)|0]<<(Ea&7)>>>7;xa=((Ea|0)<(ja|0))+Ea|0;c[O>>2]=xa;Fa=la&1;Ga=xa}do{if((c[T>>2]|0)==0){Ha=0;Ia=0;Ja=Ga}else{xa=d[ua+(Ga>>>3)|0]|0;la=((Ga|0)<(ja|0))+Ga|0;c[O>>2]=la;if((xa&128>>>((Ga&7)>>>0)|0)==0){Ha=0;Ia=0;Ja=la;break}xa=ua+(la>>>3)|0;va=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(la&7)>>>29;xa=la+3|0;la=ja>>>0>xa>>>0?xa:ja;c[O>>2]=la;Ha=va;Ia=1;Ja=la}}while(0);do{if((Fa|0)==0){if(Ia&(Ha|0)==0){break}la=c[U>>2]|0;if((la|0)==0){Ka=Ja}else{va=-Ja|0;xa=ja-Ja|0;if((la|0)<(va|0)){La=va}else{La=(xa|0)<(la|0)?xa:la}la=La+Ja|0;c[O>>2]=la;Ka=la}la=c[V>>2]|0;do{if((la|0)==0){Ma=Ka}else{xa=d[ua+(Ka>>>3)|0]|0;va=((Ka|0)<(ja|0))+Ka|0;c[O>>2]=va;if((xa&128>>>((Ka&7)>>>0)|0)==0){Ma=va;break}xa=va+la|0;va=ja>>>0>xa>>>0?xa:ja;c[O>>2]=va;Ma=va}}while(0);if((Da|0)==0){Na=Ma}else{la=-Ma|0;f=ja-Ma|0;if((wa|0)<(la|0)){Oa=la}else{Oa=(f|0)<(wa|0)?f:wa}f=Oa+Ma|0;c[O>>2]=f;Na=f}do{if((Ca|0)==0){Pa=-1;Qa=-1;Ra=Na}else{if((c[Z>>2]|0)==0){Sa=Na}else{f=((Na|0)<(ja|0))+Na|0;c[O>>2]=f;Sa=f}f=c[_>>2]|0;if((f|0)>0){la=-Sa|0;oa=ja-Sa|0;if((f|0)<(la|0)){Ta=la}else{Ta=(oa|0)<(f|0)?oa:f}f=Ta+Sa|0;c[O>>2]=f;Ua=f}else{Ua=Sa}if((c[$>>2]|0)==0){Pa=-1;Qa=-1;Ra=Ua;break}f=((Ua|0)<(ja|0))+Ua|0;oa=d[ua+(Ua>>>3)|0]<<(Ua&7)>>>7&1;la=d[ua+(f>>>3)|0]<<(f&7)>>>7;va=((f|0)<(ja|0))+f|0;c[O>>2]=va;Pa=la&1;Qa=oa;Ra=va}}while(0);if((c[W>>2]|0)==0){Va=0}else{va=d[ua+(Ra>>>3)|0]<<(Ra&7)>>>7;c[O>>2]=((Ra|0)<(ja|0))+Ra;Va=va&1}if((Qa|0)==1){va=aK(n,c[X>>2]|0)|0;Wa=F;Xa=va}else{Wa=-2147483648;Xa=0}if((Pa|0)==1){va=aK(n,c[X>>2]|0)|0;Ya=F;Za=va}else{Ya=-2147483648;Za=0}va=c[Y>>2]|0;if((va|0)>0){oa=c[O>>2]|0;la=-oa|0;f=(c[M>>2]|0)-oa|0;if((va|0)<(la|0)){_a=la}else{_a=(f|0)<(va|0)?f:va}c[O>>2]=_a+oa}if((Va|0)!=0){oa=c[W>>2]|0;va=c[O>>2]|0;f=-va|0;la=(c[M>>2]|0)-va|0;if((oa|0)<(f|0)){$a=f}else{$a=(la|0)<(oa|0)?la:oa}c[O>>2]=$a+va}if(!((Xa|0)==0&(Wa|0)==(-2147483648|0))){c[H>>2]=Xa;c[H+4>>2]=Wa}if((Za|0)==0&(Ya|0)==(-2147483648|0)){break}c[G>>2]=Za;c[G+4>>2]=Ya}}while(0);ja=c[X>>2]|0;do{if((ja|0)!=0){ua=c[aa>>2]|0;if((ua|0)==0){break}MT(c[w>>2]|0,ja,1,ua)}}while(0);ja=(c[O>>2]|0)+7>>3;ua=(c[l>>2]|0)+ja|0;c[l>>2]=ua;ab=ka-ja|0;bb=q+(ja+ra)|0;cb=c[J>>2]|0;db=ua}else{ab=ka;bb=sa;cb=ta;db=qa}if((cb|0)==21&(ab|0)>4){c[l>>2]=db+5;eb=ab-5|0;fb=bb+5|0}else{eb=ab;fb=bb}if((c[(c[p>>2]|0)+48>>2]|0)==0){ma=eb;na=fb;break b}ua=c[w>>2]|0;if((c[(c[ua+8>>2]|0)+48>>2]|0)!=94215){ma=eb;na=fb;break b}ja=HT(c[ba>>2]|0,0,c[ua>>2]|0)|0;if((ja|0)==0){ma=eb;na=fb;break b}else{gb=ja}d:while(1){ja=c[gb+32>>2]|0;do{if(!((ja|0)==-1)){if((c[gb+8>>2]|0)==48){break}ua=c[(c[p>>2]|0)+8288+(ja<<2)>>2]|0;if((ua|0)==0){break}if((c[ua+12>>2]|0)!=0){break}wa=c[ua+20>>2]|0;if((wa|0)==0){break}ua=wa+408|0;hb=c[ua>>2]|0;ib=c[ua+4>>2]|0;if((hb|0)==(-1|0)&(ib|0)==(-1|0)){break}jb=c[wa+20>>2]|0;if((jb|0)==0){break}if((c[jb+76>>2]|0)!=48){break d}}}while(0);ja=HT(c[ba>>2]|0,gb,c[c[w>>2]>>2]|0)|0;if((ja|0)==0){ma=eb;na=fb;break b}else{gb=ja}}qa=eHb(hb,ib,300,0)|0;ta=F;sa=jb+464|0;ka=c[sa+4>>2]|0;ra=c[w>>2]|0;ja=ra+464|0;c[ja>>2]=c[sa>>2];c[ja+4>>2]=ka;c[ra+472>>2]=c[jb+472>>2];ra=c[H>>2]|0;ka=c[H+4>>2]|0;if((ra|0)==0&(ka|0)==(-2147483648|0)|((ka|0)<(ta|0)|(ka|0)==(ta|0)&ra>>>0<qa>>>0)){c[H>>2]=qa;c[H+4>>2]=ta;c[G>>2]=qa;c[G+4>>2]=ta;ma=eb;na=fb;break b}ja=YGb(qa,ta,12654,0)|0;ta=F;if(!((ka|0)>(ta|0)|(ka|0)==(ta|0)&ra>>>0>ja>>>0)){ma=eb;na=fb;break b}c[H>>2]=ja;c[H+4>>2]=ta;c[G>>2]=ja;c[G+4>>2]=ta;ma=eb;na=fb;break};default:{ma=e;na=q}}}while(0);if((ma|0)>0){q=na;e=ma}else{t=0;pa=135;break}}if((pa|0)==123){ma=c[A>>2]|0;if((ma|0)!=0){na=c[v>>2]|0;do{if((na|0)>0){if((na+e|0)<=(c[z>>2]|0)){kb=e;lb=ma;mb=na;break}YJ(b,c[r>>2]|0);c[z>>2]=204800;fb=UAb(204816)|0;c[A>>2]=fb;if((fb|0)==0){t=-12;i=m;return t|0}else{c[ia>>2]=1;kb=e;lb=fb;mb=c[v>>2]|0;break}}else{if((na|0)!=0){kb=e;lb=ma;mb=na;break}fb=c[z>>2]|0;kb=(e|0)>(fb|0)?fb:e;lb=ma;mb=0}}while(0);UGb((c[lb+4>>2]|0)+mb|0,q|0,kb)|0;c[v>>2]=(c[v>>2]|0)+kb}if((c[ia>>2]|0)!=0){t=0;i=m;return t|0}kb=c[z>>2]|0;if((kb|0)>=204800){t=0;i=m;return t|0}if(((c[v>>2]|0)+(c[l>>2]|0)|0)!=(kb+6|0)){t=0;i=m;return t|0}c[ia>>2]=1;YJ(b,c[r>>2]|0);t=0;i=m;return t|0}else if((pa|0)==135){i=m;return t|0}return 0}function $J(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;e=a+8|0;h=c[e>>2]|0;j=c[h+8>>2]|0;k=c[h+48>>2]|0;if((o0a(h)|0)!=0){yDb(c[b+16>>2]|0,48,2154376,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;i=f;return}MT(a,33,1,9e4);h=b;c[a+12>>2]=h;m=c[e>>2]|0;c[m+8>>2]=2;c[m+48>>2]=0;c[a+236>>2]=1;c[b+20>>2]=a;m=b+8|0;c[m>>2]=d;n=b+16|0;o=b|0;p=c[o>>2]|0;yDb(c[n>>2]|0,48,2147232,(l=i,i=i+32|0,c[l>>2]=c[a>>2],c[l+8>>2]=d,c[l+16>>2]=p,c[l+24>>2]=g,l)|0);i=l;p=c[e>>2]|0;c[p+52>>2]=c[m>>2];d=c[m>>2]|0;a:do{if((o0a(p)|0)==0){q=2365048;while(1){r=c[q>>2]|0;if((r|0)==0){break a}if((r|0)==(d|0)){break}else{q=q+12|0}}r=c[e>>2]|0;c[r+8>>2]=c[q+4>>2];c[r+48>>2]=c[q+8>>2];c[a+440>>2]=0}else{yDb(0,48,2154376,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}}while(0);d=c[g>>2]|0;do{if((d|0)==1447904328|(d|0)==1380992072){g=c[e>>2]|0;if((c[g+48>>2]|0)!=0){break}p=c[m>>2]|0;b:do{if((o0a(g)|0)==0){r=2365256;while(1){s=c[r>>2]|0;if((s|0)==0){break b}if((s|0)==(p|0)){break}else{r=r+12|0}}s=c[e>>2]|0;c[s+8>>2]=c[r+4>>2];c[s+48>>2]=c[r+8>>2];c[a+440>>2]=0}else{yDb(0,48,2154376,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}}while(0);if((c[m>>2]|0)!=131){break}p=WDb(416)|0;if((p|0)==0){i=f;return}UGb(p|0,h|0,416)|0;g=LT(c[n>>2]|0,0)|0;if((g|0)!=0){c[g+4>>2]=c[o>>2];MT(g,33,1,9e4);c[g+12>>2]=p;q=c[g+8>>2]|0;c[q+8>>2]=1;c[q+48>>2]=86019;c[g+236>>2]=1;c[b+24>>2]=g;c[p+24>>2]=g;break}ZDb(p);i=f;return}}while(0);b=c[e>>2]|0;c:do{if((c[b+48>>2]|0)==0){o=c[m>>2]|0;if((o0a(b)|0)==0){t=2363408}else{yDb(0,48,2154376,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}while(1){n=c[t>>2]|0;if((n|0)==0){break c}if((n|0)==(o|0)){break}else{t=t+12|0}}o=c[e>>2]|0;c[o+8>>2]=c[t+4>>2];c[o+48>>2]=c[t+8>>2];c[a+440>>2]=0}}while(0);a=c[e>>2]|0;e=a+48|0;if((c[e>>2]|0)!=0){i=f;return}c[e>>2]=k;c[a+8>>2]=j;i=f;return}function aK(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=a+8|0;f=c[e>>2]|0;if(((c[a+12>>2]|0)-f|0)<(b|0)){g=-2147483648;h=0;return(F=g,h)|0}if((b|0)<33){do{if((b|0)==0){i=0}else{j=c[a+16>>2]|0;k=c[a>>2]|0;l=k+(f>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(f&7);if((b|0)<26){l=f+b|0;c[e>>2]=j>>>0>l>>>0?l:j;i=m>>>((32-b|0)>>>0);break}else{l=f+16|0;n=j>>>0>l>>>0?l:j;c[e>>2]=n;l=b-16|0;o=k+(n>>>3)|0;k=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(n&7)>>>((48-b|0)>>>0);o=n+l|0;c[e>>2]=j>>>0>o>>>0?o:j;i=k|m>>>16<<l;break}}}while(0);g=0;h=i;return(F=g,h)|0}i=b-32|0;do{if((i|0)==0){p=0;q=f;r=c[a+16>>2]|0;s=c[a>>2]|0}else{l=c[a+16>>2]|0;m=c[a>>2]|0;k=m+(f>>>3)|0;j=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(f&7);if((i|0)<26){k=f+i|0;o=l>>>0>k>>>0?k:l;c[e>>2]=o;p=j>>>((64-b|0)>>>0);q=o;r=l;s=m;break}else{o=f+16|0;k=l>>>0>o>>>0?o:l;c[e>>2]=k;o=b-48|0;n=m+(k>>>3)|0;t=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7)>>>((80-b|0)>>>0);n=k+o|0;k=l>>>0>n>>>0?n:l;c[e>>2]=k;p=t|j>>>16<<o;q=k;r=l;s=m;break}}}while(0);b=s+(q>>>3)|0;f=(fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(q&7)&-65536;b=q+16|0;q=r>>>0>b>>>0?b:r;c[e>>2]=q;b=s+(q>>>3)|0;s=(fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(q&7)>>>16;b=q+16|0;c[e>>2]=r>>>0>b>>>0?b:r;g=p|0;h=s|f|0;return(F=g,h)|0}function bK(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;g=i;i=i+1256|0;h=g|0;j=g+160|0;k=g+168|0;l=c[b+36>>2]|0;b=l;TGb(k|0,0,1088)|0;m=f-4|0;f=e+m|0;c[j>>2]=e;if((m|0)<=0){i=g;return}n=a[e]|0;o=e+3|0;c[j>>2]=o;if((m|0)<=4){i=g;return}p=o;o=(d[p]|d[p+1|0]<<8)<<16>>16;c[j>>2]=e+5;p=de(o|0)|0;if((m|0)<=5){i=g;return}c[j>>2]=e+6;if((m|0)<=6){i=g;return}c[j>>2]=e+7;if((m|0)<=7){i=g;return}o=e+8|0;c[j>>2]=o;if(!(n<<24>>24==2)){i=g;return}n=p&65535;p=l+4|0;q=c[p>>2]|0;r=c[q+1104>>2]|0;s=q+1108|0;q=0;while(1){if(!(q>>>0<r>>>0)){break}t=c[(c[s>>2]|0)+(q<<2)>>2]|0;if((c[t>>2]|0)==(n|0)){u=10;break}else{q=q+1|0}}do{if((u|0)==10){if((t|0)==0){break}c[t+16>>2]=0}}while(0);t=l+88|0;q=c[t>>2]|0;if((q|0)==0){v=0}else{s=c[l+92>>2]|0;r=0;w=q;while(1){if((c[s+(r*268|0)>>2]|0)==(n|0)){c[s+(r*268|0)+4>>2]=0;c[s+(r*268|0)+264>>2]=0;x=c[t>>2]|0}else{x=w}q=r+1|0;if(q>>>0<x>>>0){r=q;w=x}else{v=x;break}}}if((m|0)<=9){i=g;return}x=o;o=(d[x]|d[x+1|0]<<8)<<16>>16;x=e+10|0;c[j>>2]=x;w=(de(o|0)|0)&8191;o=l+92|0;r=0;while(1){if(!(r>>>0<v>>>0)){break}y=c[o>>2]|0;z=y+(r*268|0)|0;if((c[z>>2]|0)==(n|0)){u=21;break}else{r=r+1|0}}do{if((u|0)==21){if((z|0)==0){break}v=y+(r*268|0)+4|0;s=c[v>>2]|0;if(s>>>0>63>>>0){break}c[v>>2]=s+1;c[y+(r*268|0)+8+(s<<2)>>2]=w}}while(0);r=c[p>>2]|0;y=c[r+1104>>2]|0;z=r+1108|0;r=0;while(1){if(!(r>>>0<y>>>0)){break}A=c[(c[z>>2]|0)+(r<<2)>>2]|0;if((c[A>>2]|0)==(n|0)){u=27;break}else{r=r+1|0}}if((u|0)==27){c[A+32>>2]=w}if((m|0)<=11){i=g;return}m=x;x=(d[m]|d[m+1|0]<<8)<<16>>16;m=e+12|0;c[j>>2]=m;e=(de(x|0)|0)&4095;a:do{if(e>>>0>1>>>0){x=h+8|0;A=h|0;r=h+152|0;z=h+144|0;y=h+136|0;s=h+140|0;v=h+148|0;q=0;B=e;C=0;D=m;while(1){if(D>>>0<f>>>0){E=D+1|0;G=d[D]|0;c[j>>2]=E;H=G;I=E}else{H=255;I=D}if(I>>>0<f>>>0){E=I+1|0;G=d[I]|0;c[j>>2]=E;J=G;K=E}else{J=-1;K=I}E=J&255;G=J&255;L=B-2|0;if((G|0)>(L|0)){M=q;N=B;O=C;P=K;break a}Q=L-G|0;do{if((H|0)==5){if(!(G>>>0>3>>>0)){R=E;S=C;T=q;break}c[j>>2]=K+4;L=K;R=J+252&255;S=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;T=q}else if((H|0)==29){if(K>>>0<f>>>0){L=K+1|0;c[j>>2]=L;U=L}else{U=K}if(U>>>0<f>>>0){L=U+1|0;c[j>>2]=L;V=L}else{V=U}L=J+254|0;W=L&255;X=c[p>>2]|0;Y=L&255;if((Ny(x,V,Y,0,0,0,0,0)|0)<0){R=W;S=C;T=q;break}c[A>>2]=X;c[r>>2]=0;c[z>>2]=0;c[y>>2]=k+(q*68|0);c[s>>2]=0;c[v>>2]=16;X=Ty(x,0,0,1)|0;cK(h,X,F,Y,2)|0;R=W;S=C;T=c[z>>2]|0}else{R=E;S=C;T=q}}while(0);E=(c[j>>2]|0)+(R&255)|0;c[j>>2]=E;if((Q|0)>1){q=T;B=Q;C=S;D=E}else{M=T;N=Q;O=S;P=E;break}}}else{M=0;N=e;O=0;P=m}}while(0);m=P+N|0;c[j>>2]=m;b:do{if(m>>>0<f>>>0){if((c[(c[p>>2]|0)+24>>2]|0)==0){c[l+68>>2]=2}N=c[t>>2]|0;P=0;while(1){if(!(P>>>0<N>>>0)){break}Z=c[o>>2]|0;_=Z+(P*268|0)|0;if((c[_>>2]|0)==(n|0)){u=52;break}else{P=P+1|0}}do{if((u|0)==52){if((_|0)==0){break}c[Z+(P*268|0)+264>>2]=1}}while(0);P=l+41056|0;N=l+8288|0;e=k|0;S=(O|0)==1447904328;T=m;c:while(1){R=T+1|0;h=a[T]|0;V=h&255;c[j>>2]=R;if(!((T+2|0)>>>0<f>>>0)){break b}J=R;R=(d[J]|d[J+1|0]<<8)<<16>>16;c[j>>2]=T+3;J=(de(R|0)|0)&8191;if((J|0)==(c[P>>2]|0)){break b}R=c[N+(J<<2)>>2]|0;U=(R|0)==0;do{if(U){u=62}else{if((c[R+12>>2]|0)!=0){u=62;break}K=c[R+20>>2]|0;H=K;I=K+20|0;if((c[I>>2]|0)!=0){$=H;aa=I;u=79;break}D=LT(c[K+16>>2]|0,0)|0;c[I>>2]=D;if((D|0)==0){break b}c[D+4>>2]=c[K>>2];$=H;aa=I;u=79}}while(0);do{if((u|0)==62){u=0;if(h<<24>>24==19){Q=aU(c[p>>2]|0,J)|0;I=c[p>>2]|0;if((Q|0)>-1){$=0;aa=(c[I+28>>2]|0)+(Q<<2)|0;u=79;break}Q=LT(I,0)|0;if((Q|0)==0){break b}c[Q+4>>2]=J;c[(c[Q+8>>2]|0)+8>>2]=2;ba=0;ca=Q;da=0;break}if(!U){Q=c[R>>2]|0;I=c[R+12>>2]|0;do{if((I|0)==0){H=R+20|0;K=H;XAb((c[K>>2]|0)+344|0);if((c[(c[K>>2]|0)+20>>2]|0)!=0){break}$Db(H)}else if((I|0)==1){$Db(R+24|0)}}while(0);ZDb(R);c[b+8288+(Q<<2)>>2]=0}ea=cEb(416)|0;if((ea|0)==0){break b}c[ea+12>>2]=b;I=ea+16|0;c[I>>2]=c[p>>2];H=ea;c[H>>2]=J;c[ea+4>>2]=w;c[ea+28>>2]=4;K=ea+56|0;c[K>>2]=0;c[K+4>>2]=-2147483648;K=ea+64|0;c[K>>2]=0;c[K+4>>2]=-2147483648;K=ea+408|0;c[K>>2]=-1;c[K+4>>2]=-1;K=b+8288+(J<<2)|0;if((c[K>>2]|0)!=0){break c}D=cEb(40)|0;if((D|0)==0){break c}c[K>>2]=D;c[D+12>>2]=0;c[D>>2]=J;c[D+4>>2]=-1;c[D+8>>2]=-1;c[D+16>>2]=2;c[D+20>>2]=ea;D=LT(c[I>>2]|0,0)|0;if((D|0)==0){break b}c[D+4>>2]=c[H>>2];fa=D;ga=ea;u=80}}while(0);if((u|0)==79){u=0;R=c[aa>>2]|0;if((R|0)==0){break b}else{fa=R;ga=$;u=80}}do{if((u|0)==80){u=0;if((ga|0)==0){ba=0;ca=fa;da=0;break}if((c[ga+8>>2]|0)!=0){ba=ga;ca=fa;da=1;break}$J(fa,ga,V,O);ba=ga;ca=fa;da=1}}while(0);R=c[t>>2]|0;U=0;while(1){if(!(U>>>0<R>>>0)){break}ha=c[o>>2]|0;ia=ha+(U*268|0)|0;if((c[ia>>2]|0)==(n|0)){u=86;break}else{U=U+1|0}}do{if((u|0)==86){u=0;if((ia|0)==0){break}R=ha+(U*268|0)+4|0;D=c[R>>2]|0;if(D>>>0>63>>>0){break}c[R>>2]=D+1;c[ha+(U*268|0)+8+(D<<2)>>2]=J}}while(0);PT(c[p>>2]|0,n,c[ca>>2]|0);U=c[j>>2]|0;if(!((U+1|0)>>>0<f>>>0)){break b}D=U;R=(d[D]|d[D+1|0]<<8)<<16>>16;c[j>>2]=U+2;T=U+(((de(R|0)|0)&4095)+2)|0;if(T>>>0>f>>>0){break b}if((LJ(c[p>>2]|0,ca,V,j,T,e,M,J,b)|0)>=0){R=da&S&h<<24>>24==-125;U=ba+24|0;D=ca+8|0;do{do{if(R){H=c[U>>2]|0;if((H|0)==0){break}PT(c[p>>2]|0,n,c[H>>2]|0);c[(c[(c[U>>2]|0)+8>>2]|0)+52>>2]=c[(c[D>>2]|0)+52>>2]}}while(0);}while((LJ(c[p>>2]|0,ca,V,j,T,e,M,J,b)|0)>=0)}c[j>>2]=T;if(!(T>>>0<f>>>0)){break b}}ZDb(ea)}}while(0);if((M|0)>0){ja=0}else{i=g;return}do{ZDb(c[k+(ja*68|0)+8>>2]|0);ja=ja+1|0;}while((ja|0)<(M|0));i=g;return}function cK(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=a|0;l=a+8|0;m=tF(c[k>>2]|0,l,j)|0;n=Ty(l,0,0,1)|0;o=F;p=YGb(e,0,b,d)|0;d=ZGb(p,F,n,o)|0;p=d;do{if((p|0)>=0){if((m|0)>(p|0)|(m|0)<1){break}d=a+152|0;b=c[d>>2]|0;c[d>>2]=b+1;a:do{if((b|0)>3){yDb(c[k>>2]|0,16,2122480,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}else{e=c[j>>2]|0;if(!((f|0)==0|(e|0)==(f|0))){yDb(c[k>>2]|0,16,2117472,(q=i,i=i+16|0,c[q>>2]=e,c[q+8>>2]=f,q)|0);i=q;break}switch(e|0){case 4:{e=a+140|0;r=c[e>>2]|0;if((r|0)==0){break a}s=WDb(m)|0;c[(c[e>>2]|0)+8>>2]=s;s=c[r+8>>2]|0;if((s|0)==0){break a}c[r+4>>2]=m;mz(l,s,m)|0;break a;break};case 1:{if((m|0)<2){break a}if(((tz(l)|0)&32|0)!=0){break a}s=Ty(l,0,0,1)|0;r=F;e=ZGb(YGb(m,0,n,o)|0,F,s,r)|0;if((e|0)>0){t=r;u=s;v=e}else{break a}while(1){if((cK(a,u,t,v,0)|0)<0){break a}e=Ty(l,0,0,1)|0;s=F;r=YGb(v,0,u,t)|0;w=ZGb(r,F,e,s)|0;r=w;if((r|0)>0){t=s;u=e;v=r}else{break}}break};case 6:{r=c[a+140>>2]|0;if((r|0)==0){break a}if((lz(l)|0)!=0){EDb(c[k>>2]|0,2095624,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break a}e=lz(l)|0;c[r+12>>2]=e>>>7&1;c[r+16>>2]=e>>>6&1;c[r+20>>2]=e>>>5&1;c[r+24>>2]=e>>>3&1;c[r+28>>2]=e>>>2&1;c[r+32>>2]=e>>>1&1;c[r+36>>2]=vz(l)|0;vz(l)|0;e=lz(l)|0;s=r+40|0;c[s>>2]=e;if((e|0)>64){DDb(0,2106432,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[s>>2]=64;break a}else{c[r+44>>2]=lz(l)|0;c[r+48>>2]=lz(l)|0;c[r+52>>2]=lz(l)|0;s=tz(l)|0;c[r+56>>2]=s>>12;c[r+60>>2]=s>>>7&31;c[r+64>>2]=s>>>2&31;break a}break};case 3:{c[h>>2]=0;s=a+144|0;if((c[s>>2]|0)>=(c[a+148>>2]|0)){break a}uF(l,h);r=c[a+136>>2]|0;e=c[s>>2]|0;c[s>>2]=e+1;s=r+(e*68|0)|0;e=a+140|0;c[e>>2]=s;c[s>>2]=c[h>>2];s=Ty(l,0,0,1)|0;r=F;w=ZGb(n,o,s,r)|0;x=YGb(w,F,m,0)|0;w=F;cK(a,s,r,x,4)|0;y=Ty(l,0,0,1)|0;z=F;A=ZGb(s,r,y,z)|0;r=YGb(A,F,x,w)|0;w=r;if((w|0)>0){cK(a,y,z,w,6)|0}c[e>>2]=0;break a;break};case 2:{tz(l)|0;lz(l)|0;lz(l)|0;lz(l)|0;lz(l)|0;lz(l)|0;e=Ty(l,0,0,1)|0;w=F;z=YGb(m,0,n,o)|0;y=ZGb(z,F,e,w)|0;z=y;if((z|0)>0){B=w;C=e;D=z}else{break a}while(1){if((cK(a,C,B,D,0)|0)<0){break a}z=Ty(l,0,0,1)|0;e=F;w=YGb(D,0,C,B)|0;y=ZGb(w,F,z,e)|0;w=y;if((w|0)>0){B=e;C=z;D=w}else{break}}break};default:{break a}}}}while(0);c[d>>2]=(c[d>>2]|0)-1;b=YGb(n,o,m,(m|0)<0|0?-1:0)|0;Ty(l,b,F,0)|0;E=0;i=g;return E|0}}while(0);yDb(c[k>>2]|0,16,2128600,(q=i,i=i+24|0,c[q>>2]=c[j>>2],c[q+8>>2]=m,c[q+16>>2]=p,q)|0);i=q;E=-1;i=g;return E|0}function dK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;b=i;d=c[a+12>>2]|0;e=a+1080|0;if((c[e>>2]|0)<0){c[e>>2]=0}f=d+84|0;g=(c[f>>2]|0)+197|0;c[f>>2]=-14-((g|0)%184|0)+g;c[d+64>>2]=c[d+88>>2];c[d+60>>2]=c[d+92>>2];g=a+1140|0;h=BBb(c[g>>2]|0,2222560,0,0)|0;if((h|0)==0){j=BBb(c[g>>2]|0,2213048,0,0)|0;if((j|0)==0){k=2203712}else{l=j;m=5}}else{l=h;m=5}if((m|0)==5){k=c[l+4>>2]|0}l=BBb(c[g>>2]|0,2196304,0,0)|0;if((l|0)==0){n=2183408}else{n=c[l+4>>2]|0}l=c[d+96>>2]|0;g=cEb(40)|0;if((g|0)==0){o=0}else{h=d+56|0;c[g>>2]=(c[h>>2]|0)+(c[d+100>>2]|0);c[g+16>>2]=l;c[g+24>>2]=eEb(n)|0;c[g+20>>2]=eEb(k)|0;c[g+28>>2]=8191;gEb(d+36|0,h,g);o=g}c[o+8>>2]=70;g=a;c[o+12>>2]=g;c[o+4>>2]=15;c[d+4>>2]=0;c[d+8>>2]=15;c[d+12>>2]=70;c[d+16>>2]=g;c[d+20>>2]=17;c[d+24>>2]=15;c[d+28>>2]=70;c[d+32>>2]=g;h=a+24|0;k=WDb(c[h>>2]<<2)|0;n=k;if((k|0)==0){p=-12;i=b;return p|0}a:do{if((c[h>>2]|0)==0){q=0;r=o+28|0}else{l=a+28|0;j=d+104|0;s=o|0;t=o+28|0;u=d+116|0;v=0;w=0;b:while(1){x=c[(c[l>>2]|0)+(v<<2)>>2]|0;MT(x,33,1,9e4);y=cEb(56)|0;if((y|0)==0){z=-12;break}c[x+12>>2]=y;A=cEb(c[f>>2]|0)|0;c[y+44>>2]=A;if((A|0)==0){z=-12;break}c[y>>2]=o;B=c[x+4>>2]|0;if((B|0)<16){A=(c[j>>2]|0)+v|0;c[y+4>>2]=A;C=A}else{if((B|0)>=8191){m=20;break}c[y+4>>2]=B;C=B}if((C|0)==(c[s>>2]|0)){m=22;break}else{D=0}while(1){if((D|0)>=(v|0)){break}if((c[n+(D<<2)>>2]|0)==(C|0)){m=25;break b}else{D=D+1|0}}c[n+(v<<2)>>2]=C;A=y+24|0;c[A>>2]=0;c[A+4>>2]=-2147483648;A=y+32|0;c[A>>2]=0;c[A+4>>2]=-2147483648;c[y+16>>2]=1;c[y+8>>2]=15;A=x+8|0;E=c[A>>2]|0;do{if((c[E+8>>2]|0)==0){if((c[t>>2]|0)!=8191){G=w;break}c[t>>2]=C;G=x}else{G=w}}while(0);do{if((c[E+48>>2]|0)==86018){if((c[E+100>>2]|0)<=0){break}x=tN()|0;H=y+48|0;c[H>>2]=x;if((x|0)==0){z=-12;break b}x=UC((c[u>>2]&2|0)!=0?2154352:2147208,0,0)|0;c[(c[H>>2]|0)+8>>2]=x;x=c[H>>2]|0;if((c[x+8>>2]|0)==0){z=-22;break b}I=c[(LT(x,0)|0)+8>>2]|0;x=BRa(I,c[A>>2]|0)|0;if((x|0)!=0){z=x;break b}x=FK(c[H>>2]|0,0)|0;if((x|0)<0){z=x;break b}}}while(0);A=v+1|0;if(A>>>0<(c[h>>2]|0)>>>0){v=A;w=G}else{q=G;r=t;break a}}if((m|0)==20){yDb(g,16,2168568,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J;z=-22}else if((m|0)==22){yDb(g,16,2161048,(J=i,i=i+8|0,c[J>>2]=C,J)|0);i=J;z=-22}else if((m|0)==25){yDb(g,16,2161048,(J=i,i=i+8|0,c[J>>2]=C,J)|0);i=J;z=-22}ZDb(k);if((c[h>>2]|0)==0){p=z;i=b;return p|0}else{K=0}while(1){t=(c[(c[l>>2]|0)+(K<<2)>>2]|0)+12|0;w=c[t>>2]|0;do{if((w|0)!=0){$Db(w+44|0);v=w+48|0;u=c[v>>2]|0;if((u|0)==0){break}bT(u);c[v>>2]=0}}while(0);$Db(t);w=K+1|0;if(w>>>0<(c[h>>2]|0)>>>0){K=w}else{p=z;break}}i=b;return p|0}}while(0);ZDb(k);do{if((c[r>>2]|0)==8191){if((c[h>>2]|0)==0){L=q;break}k=c[c[a+28>>2]>>2]|0;c[r>>2]=c[(c[k+12>>2]|0)+4>>2];L=k}else{L=q}}while(0);q=d+80|0;r=c[q>>2]|0;do{if((r|0)>1){c[o+36>>2]=(r*20|0|0)/1504e3|0;h=c[q>>2]|0;c[d+44>>2]=(h*500|0|0)/1504e3|0;c[d+52>>2]=(h*100|0|0)/1504e3|0;if((c[d+120>>2]|0)>=1){break}h=c[e>>2]|0;k=IDb(h,(h|0)<0|0?-1:0,27e6,0,1e6,0)|0;h=d+72|0;c[h>>2]=k;c[h+4>>2]=F}else{c[d+44>>2]=200;c[d+52>>2]=40;h=L+8|0;k=c[h>>2]|0;do{if((c[k+8>>2]|0)==1){z=c[k+424>>2]|0;if((z|0)==0){yDb(g,24,2140840,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=(c[(c[h>>2]|0)+412>>2]|0)/5120|0;c[o+36>>2]=K;M=K;break}else{K=(c[k+412>>2]|0)/(z*10|0|0)|0;c[o+36>>2]=K;M=K;break}}else{K=(c[k+108>>2]|0)/((c[k+104>>2]|0)*10|0|0)|0;c[o+36>>2]=K;M=K}}while(0);if((M|0)!=0){break}c[o+36>>2]=1}}while(0);M=o+36|0;c[o+32>>2]=c[M>>2];o=d+52|0;c[d+48>>2]=(c[o>>2]|0)-1;L=d+44|0;c[d+40>>2]=(c[L>>2]|0)-1;e=c[q>>2]|0;if((e|0)==1){yDb(g,40,2135016,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J}else{yDb(g,40,2128568,(J=i,i=i+8|0,c[J>>2]=e,J)|0);i=J}e=c[L>>2]|0;L=c[o>>2]|0;yDb(g,40,2122408,(J=i,i=i+24|0,c[J>>2]=c[M>>2],c[J+8>>2]=e,c[J+16>>2]=L,J)|0);i=J;J=d+108|0;do{if((c[J>>2]|0)==-1){if((TC(a+32|0,2117432)|0)==0){c[J>>2]=0;break}else{c[J>>2]=1;break}}}while(0);Sy(c[a+16>>2]|0);p=0;i=b;return p|0}function eK(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;f=i;i=i+96|0;g=f|0;h=f+8|0;j=f+16|0;if((e|0)==0){k=b+24|0;l=c[k>>2]|0;if((l|0)!=0){m=b+28|0;n=0;o=l;while(1){l=c[(c[m>>2]|0)+(n<<2)>>2]|0;p=c[l+12>>2]|0;q=p+12|0;r=c[q>>2]|0;if((r|0)>0){s=p+24|0;t=p+32|0;gK(b,l,c[p+44>>2]|0,r,c[s>>2]|0,c[s+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0,c[p+40>>2]&1);c[q>>2]=0;u=c[k>>2]|0}else{u=o}q=n+1|0;if(q>>>0<u>>>0){n=q;o=u}else{break}}}Sy(c[b+16>>2]|0);v=1;i=f;return v|0}u=b+28|0;o=c[(c[u>>2]|0)+(c[e+32>>2]<<2)>>2]|0;n=e+28|0;k=c[n>>2]|0;m=e+24|0;q=c[m>>2]|0;c[g>>2]=0;p=c[b+12>>2]|0;t=c[o+12>>2]|0;s=c[b+1080>>2]|0;r=IDb(s,(s|0)<0|0?-1:0,9e4,0,1e6,0)|0;s=F;l=r<<1|0>>>31;w=s<<1|r>>>31;y=e+16|0;z=c[y>>2]|0;A=c[y+4>>2]|0;B=e+8|0;C=c[B>>2]|0;D=c[B+4>>2]|0;B=p+112|0;if((c[B>>2]|0)==0){E=c[p+116>>2]|0}else{yDb(b,24,2340608,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;c[B>>2]=0;B=p+116|0;H=c[B>>2]|1;c[B>>2]=H;E=H}if((E&1|0)!=0){c[p+48>>2]=(c[p+52>>2]|0)-1;c[p+40>>2]=(c[p+44>>2]|0)-1;c[p+116>>2]=E&-2}if((c[p+120>>2]|0)<1){E=(C|0)==0&(D|0)==(-2147483648|0);H=YGb(C,D,l,w)|0;B=E?-2147483648:F;I=(z|0)==0&(A|0)==(-2147483648|0);J=YGb(z,A,l,w)|0;K=B;L=E?0:H;M=I?-2147483648:F;N=I?0:J}else{K=D;L=C;M=A;N=z}z=t+16|0;if((c[z>>2]|0)!=0&((L|0)==0&(K|0)==(-2147483648|0))){yDb(b,16,2317544,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;v=-1094995529;i=f;return v|0}c[z>>2]=0;z=o+8|0;A=c[(c[z>>2]|0)+48>>2]|0;do{if((A|0)==86018){if((c[n>>2]|0)<2){yDb(b,16,2263744,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;v=-1094995529;i=f;return v|0}C=c[m>>2]|0;if(((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&-16)<<16>>16==-16){O=k;P=q;break}C=t+48|0;if((c[C>>2]|0)==0){yDb(b,16,2248720,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;v=-1094995529;i=f;return v|0}vZ(j);c[j+24>>2]=c[m>>2];c[j+28>>2]=c[n>>2];if((Mz((c[C>>2]|0)+16|0)|0)<0){v=-12;i=f;return v|0}D=GK(c[C>>2]|0,j)|0;J=Oz(c[(c[C>>2]|0)+16>>2]|0,g)|0;c[(c[C>>2]|0)+16>>2]=0;C=c[g>>2]|0;if((D|0)>=0){O=J;P=C;break}ZDb(C);v=D;i=f;return v|0}else if((A|0)==28){D=q+k|0;c[h>>2]=-1;if((c[n>>2]|0)<5){Q=20}else{C=c[m>>2]|0;if((d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)==16777216){R=q}else{Q=20}}do{if((Q|0)==20){C=o+64|0;J=b;if(!((c[C>>2]|0)==0&(c[C+4>>2]|0)==0)){yDb(J,24,2279064,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;R=q;break}yDb(J,16,2295736,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;v=-22;i=f;return v|0}}while(0);do{R=f1a(R,D,h)|0;S=c[h>>2]&31;if(!(R>>>0<D>>>0)){break}}while(!((S|0)==9|(S|0)==5|(S|0)==1));if((S|0)==9){O=k;P=q;break}D=WDb((c[n>>2]|0)+6|0)|0;c[g>>2]=D;if((D|0)==0){v=-12;i=f;return v|0}else{J=c[n>>2]|0;UGb(D+6|0,c[m>>2]|0,J)|0;C=D;x=16777216;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;a[D+4|0]=9;a[D+5|0]=-16;O=J+6|0;P=D;break}}else{O=k;P=q}}while(0);do{if(!((c[y>>2]|0)==0&(c[y+4>>2]|0)==(-2147483648|0))){q=b+24|0;k=c[q>>2]|0;if((k|0)==0){break}else{T=0;U=k}while(1){k=c[(c[u>>2]|0)+(T<<2)>>2]|0;m=c[k+12>>2]|0;n=m+12|0;S=c[n>>2]|0;do{if((S|0)==0){V=U}else{R=m+32|0;h=c[R>>2]|0;Q=c[R+4>>2]|0;if(!((h|0)==0&(Q|0)==(-2147483648|0))){R=ZGb(N,M,h,Q)|0;A=F;if(!((A|0)>(s|0)|(A|0)==(s|0)&R>>>0>r>>>0)){V=U;break}}R=m+24|0;gK(b,k,c[m+44>>2]|0,S,c[R>>2]|0,c[R+4>>2]|0,h,Q,c[m+40>>2]&1);c[n>>2]=0;V=c[q>>2]|0}}while(0);n=T+1|0;if(n>>>0<V>>>0){T=n;U=V}else{break}}}}while(0);V=t+12|0;U=c[V>>2]|0;do{if((U|0)==0){W=0}else{if((U+O|0)<=(c[p+84>>2]|0)){W=U;break}T=t+24|0;r=t+32|0;gK(b,o,c[t+44>>2]|0,U,c[T>>2]|0,c[T+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0,c[t+40>>2]&1);c[V>>2]=0;W=0}}while(0);do{if((c[(c[z>>2]|0)+8>>2]|0)==1){if((O|0)>(c[p+84>>2]|0)){break}if((W|0)==0){U=t+24|0;c[U>>2]=L;c[U+4>>2]=K;U=t+32|0;c[U>>2]=N;c[U+4>>2]=M;c[t+40>>2]=c[e+36>>2]}UGb((c[t+44>>2]|0)+W|0,P|0,O)|0;c[V>>2]=(c[V>>2]|0)+O;ZDb(c[g>>2]|0);v=0;i=f;return v|0}}while(0);if((W|0)!=0){yDb(0,0,1980776,(G=i,i=i+24|0,c[G>>2]=2235648,c[G+8>>2]=1924704,c[G+16>>2]=1286,G)|0);i=G;Cd();return 0}gK(b,o,P,O,L,K,N,M,c[e+36>>2]&1);ZDb(c[g>>2]|0);v=0;i=f;return v|0}function fK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+12>>2]|0;d=a+24|0;e=c[d>>2]|0;if((e|0)!=0){f=a+28|0;g=0;h=e;while(1){e=c[(c[f>>2]|0)+(g<<2)>>2]|0;i=c[e+12>>2]|0;j=i+12|0;k=c[j>>2]|0;if((k|0)>0){l=i+24|0;m=i+32|0;gK(a,e,c[i+44>>2]|0,k,c[l>>2]|0,c[l+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0,c[i+40>>2]&1);c[j>>2]=0;n=c[d>>2]|0}else{n=h}j=g+1|0;if(j>>>0<n>>>0){g=j;h=n}else{break}}}Sy(c[a+16>>2]|0);if((c[d>>2]|0)!=0){n=a+28|0;a=0;do{h=c[(c[(c[n>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;$Db(h+44|0);g=h+48|0;h=c[g>>2]|0;if((h|0)!=0){bT(h);c[g>>2]=0}a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0)}d=b+56|0;a=b+36|0;b=c[a>>2]|0;if((c[d>>2]|0)>0){o=0;p=b}else{q=b;r=q;ZDb(r);return 0}while(1){b=c[p+(o<<2)>>2]|0;$Db(b+24|0);$Db(b+20|0);ZDb(b);b=o+1|0;n=c[a>>2]|0;if((b|0)<(c[d>>2]|0)){o=b;p=n}else{q=n;break}}r=q;ZDb(r);return 0}function gK(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0;n=i;i=i+1424|0;o=n|0;p=n+8|0;q=n+16|0;r=n+24|0;s=n+216|0;t=n+1232|0;u=e+12|0;v=c[u>>2]|0;w=b+12|0;y=c[w>>2]|0;z=c[b+1080>>2]|0;A=IDb(z,(z|0)<0|0?-1:0,9e4,0,1e6,0)|0;z=F;B=e+8|0;e=(m|0)==0;if((c[(c[B>>2]|0)+8>>2]|0)!=0|e){C=0}else{C=(c[v+20>>2]|0)==0|0}if((g|0)<=0){D=b+16|0;E=c[D>>2]|0;Sy(E);G=v+20|0;H=G;c[H>>2]=m;i=n;return}I=s|0;J=s+1|0;K=s+2|0;L=s+3|0;M=s;N=v+4|0;O=v;P=y+80|0;Q=(k|0)==0&(l|0)==(-2147483648|0);R=b+16|0;S=y+72|0;T=r|0;U=r+1|0;V=r+2|0;W=r+3|0;X=r+4|0;Y=p;Z=r+5|0;_=r+6|0;$=r+7|0;aa=r+8|0;ba=r+9|0;ca=r+10|0;da=r+11|0;ea=r+12|0;r=q;fa=s+4|0;s=b+24|0;ga=b+28|0;ha=M+1012|0;ia=t|0;ja=t+1|0;ka=t+2|0;la=t+3|0;ma=v+8|0;na=t+4|0;oa=(h|0)==0&(j|0)==(-2147483648|0);pa=y+108|0;y=(h|0)!=0|(j|0)!=(-2147483648|0);qa=y?5:0;ra=y?128:0;sa=Q|y^1|(k|0)==(h|0)&(l|0)==(j|0);ta=((h>>>30|j<<2)<<1|0>>>31)&14;ua=(h>>>22|j<<10)&255;va=((h>>>15|j<<17)<<1|0>>>31|1)&255;wa=(h>>>7|j<<25)&255;j=(h<<1|0>>>31|1)&255;h=(((k>>>30|l<<2)<<1|0>>>31)&14|17)&255;xa=(k>>>22|l<<10)&255;ya=((k>>>15|l<<17)<<1|0>>>31|1)&255;za=(k>>>7|l<<25)&255;Aa=(k<<1|0>>>31|1)&255;Ba=qa+5|0;Ca=ra|64;Da=t;Ea=t+5|0;Fa=t+6|0;Ga=t+187|0;Ha=o;Ia=b;b=ZGb(k,l,A,z)|0;Ja=gHb(b,F,300,0)|0;b=F;Ka=1;La=0;Ma=g;g=f;f=C;while(1){C=(Ka|0)==0;Na=f;while(1){Oa=c[w>>2]|0;Pa=Oa+40|0;Qa=(c[Pa>>2]|0)+1|0;c[Pa>>2]=Qa;if((Qa|0)==(c[Oa+44>>2]|0)){c[Pa>>2]=0;Pa=c[Oa+60>>2]|0;a[I]=Pa>>>8;a[J]=Pa;a[K]=-1;Pa=Oa+56|0;if((c[Pa>>2]|0)>0){Qa=Oa+36|0;Ra=L;Sa=0;while(1){Ta=c[(c[Qa>>2]|0)+(Sa<<2)>>2]|0;Ua=c[Ta+16>>2]|0;a[Ra]=Ua>>>8;a[Ra+1|0]=Ua;Ua=Ra+3|0;a[Ra+2|0]=-4;Va=Ra+6|0;a[Ra+5|0]=72;a[Ra+7|0]=1;Wa=c[Ta+24>>2]|0;if((Wa|0)==0){Xa=0}else{Xa=SGb(Wa|0)|0}a[Ra+8|0]=Xa;UGb(Ra+9|0,Wa|0,Xa)|0;Wa=c[Ta+20>>2]|0;if((Wa|0)==0){Ya=0}else{Ya=SGb(Wa|0)|0}Ta=Xa+10|0;a[Ra+(Xa+9)|0]=Ya;UGb(Ra+Ta|0,Wa|0,Ya)|0;Wa=Ra+(Ya+Ta)|0;Ta=Wa;a[Va]=255-Va+Ta;Va=Ta-Ua-2|0;a[Ua]=Va>>>8|128;a[Ra+4|0]=Va;Va=Sa+1|0;if((Va|0)<(c[Pa>>2]|0)){Ra=Wa;Sa=Va}else{Za=Wa;break}}}else{Za=L}hK(Oa+20|0,66,c[Oa+64>>2]|0,c[Oa+124>>2]|0,I,Za-M|0)}Sa=Oa+48|0;Ra=(c[Sa>>2]|0)+1|0;c[Sa>>2]=Ra;do{if(!((Ra|0)!=(c[Oa+52>>2]|0)&(Na|0)==0)){c[Sa>>2]=0;Pa=c[w>>2]|0;Qa=Pa+56|0;if((c[Qa>>2]|0)>0){Wa=Pa+36|0;Va=I;Ua=0;while(1){Ta=c[(c[Wa>>2]|0)+(Ua<<2)>>2]|0;_a=c[Ta+16>>2]|0;a[Va]=_a>>>8;a[Va+1|0]=_a;_a=c[Ta>>2]|0;a[Va+2|0]=_a>>>8|224;Ta=Va+4|0;a[Va+3|0]=_a;_a=Ua+1|0;if((_a|0)<(c[Qa>>2]|0)){Va=Ta;Ua=_a}else{$a=Ta;break}}}else{$a=I}hK(Pa+4|0,0,c[Pa+64>>2]|0,c[Pa+124>>2]|0,I,$a-M|0);Ua=Oa+56|0;if((c[Ua>>2]|0)<=0){break}Va=Oa+36|0;Qa=0;do{Wa=c[(c[Va>>2]|0)+(Qa<<2)>>2]|0;Ta=c[w>>2]|0;_a=c[Wa+28>>2]|0;a[I]=_a>>>8|224;a[J]=_a;a[K]=-16;a[L]=0;a:do{if((c[s>>2]|0)==0){ab=fa;bb=86}else{_a=Ta+116|0;cb=fa;db=0;while(1){eb=c[(c[ga>>2]|0)+(db<<2)>>2]|0;fb=c[eb+12>>2]|0;gb=BBb(c[eb+88>>2]|0,1882704,0,0)|0;hb=eb+8|0;ib=c[(c[hb>>2]|0)+48>>2]|0;if((ib|0)==117){jb=209}else if((ib|0)==86016|(ib|0)==86017){jb=3}else if((ib|0)==1|(ib|0)==2){jb=2}else if((ib|0)==13){jb=16}else if((ib|0)==28){jb=27}else if((ib|0)==88){jb=66}else if((ib|0)==86018){jb=(c[_a>>2]&2)+15|0}else if((ib|0)==86066){jb=17}else if((ib|0)==86019){jb=129}else{jb=6}if((cb-M|0)>>>0>980>>>0){break a}a[cb]=jb;ib=c[fb+4>>2]|0;a[cb+1|0]=ib>>>8|224;fb=cb+3|0;a[cb+2|0]=ib;ib=cb+5|0;kb=c[hb>>2]|0;lb=c[kb+8>>2]|0;b:do{if((lb|0)==2){if((c[kb+48>>2]|0)!=1263294017){mb=ib;break}a[ib]=5;a[cb+6|0]=4;a[cb+7|0]=75;a[cb+8|0]=76;a[cb+9|0]=86;a[cb+10|0]=65;mb=cb+11|0}else if((lb|0)==3){if((gb|0)==0){nb=644728}else{ob=c[gb+4>>2]|0;pb=(SGb(ob|0)|0)>>>0>2>>>0;nb=pb?ob:644728}ob=c[kb+48>>2]|0;if((ob|0)==94215){pb=cb+6|0;a[ib]=86;qb=cb+7|0;c:do{if((SGb(nb|0)|0)>>>0>2>>>0){rb=qb;sb=nb;tb=0;while(1){ub=rb;vb=sb;while(1){if(!((ub-M|0)>>>0<1006>>>0)){wb=ub;break c}a[ub]=a[vb]|0;a[ub+1|0]=a[vb+1|0]|0;xb=vb+3|0;yb=ub+3|0;a[ub+2|0]=a[vb+2|0]|0;zb=(a[xb]|0)==0?xb:vb+4|0;Ab=c[hb>>2]|0;if(((c[Ab+100>>2]|0)-1|0)>(tb|0)){break}a[yb]=8;xb=ub+5|0;a[ub+4|0]=0;if((SGb(zb|0)|0)>>>0>2>>>0){ub=xb;vb=zb}else{wb=xb;break c}}vb=(c[Ab+96>>2]|0)+tb|0;xb=yb;x=(d[vb]|d[vb+1|0]<<8)<<16>>16;a[xb]=x;x=x>>8;a[xb+1|0]=x;xb=ub+5|0;if((SGb(zb|0)|0)>>>0>2>>>0){rb=xb;sb=zb;tb=tb+2|0}else{wb=xb;break}}}else{wb=qb}}while(0);a[pb]=255-pb+wb;mb=wb;break}else if((ob|0)!=94209){mb=ib;break}qb=cb+6|0;a[ib]=89;tb=cb+7|0;d:do{if((SGb(nb|0)|0)>>>0>2>>>0){sb=eb+72|0;rb=tb;xb=nb;vb=0;while(1){e:do{if((vb|0)==0){Bb=rb;Cb=xb;while(1){if(!((ha-Bb|0)>>>0>7>>>0)){Db=Bb;break d}a[Bb]=a[Cb]|0;a[Bb+1|0]=a[Cb+1|0]|0;Eb=Cb+3|0;Fb=Bb+3|0;a[Bb+2|0]=a[Cb+2|0]|0;Gb=(a[Eb]|0)==0?Eb:Cb+4|0;Eb=c[hb>>2]|0;if((c[Eb+100>>2]|0)>4){Hb=Bb;Ib=Fb;Jb=Gb;Kb=Eb;bb=69;break e}Lb=Bb+4|0;a[Fb]=((c[sb>>2]|0)>>>3&16)+16;Mb=c[hb>>2]|0;if((c[Mb+100>>2]|0)==4){break}a[Lb]=0;a[Bb+5|0]=1;a[Bb+6|0]=0;Fb=Bb+8|0;a[Bb+7|0]=1;if((SGb(Gb|0)|0)>>>0>2>>>0){Bb=Fb;Cb=Gb}else{Db=Fb;break d}}Cb=Lb;Fb=c[Mb+96>>2]|0;x=d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0;a[Cb]=x;x=x>>8;a[Cb+1|0]=x;x=x>>8;a[Cb+2|0]=x;x=x>>8;a[Cb+3|0]=x;Nb=4;Ob=Gb;Pb=Bb}else{Cb=rb;Fb=xb;while(1){if(!((ha-Cb|0)>>>0>7>>>0)){Db=Cb;break d}a[Cb]=a[Fb]|0;a[Cb+1|0]=a[Fb+1|0]|0;Eb=Fb+3|0;Qb=Cb+3|0;a[Cb+2|0]=a[Fb+2|0]|0;Rb=(a[Eb]|0)==0?Eb:Fb+4|0;Eb=c[hb>>2]|0;if(((c[Eb+100>>2]|0)-vb|0)>4){Hb=Cb;Ib=Qb;Jb=Rb;Kb=Eb;bb=69;break e}a[Qb]=((c[sb>>2]|0)>>>3&16)+16;a[Cb+4|0]=0;a[Cb+5|0]=1;a[Cb+6|0]=0;Qb=Cb+8|0;a[Cb+7|0]=1;if((SGb(Rb|0)|0)>>>0>2>>>0){Cb=Qb;Fb=Rb}else{Db=Qb;break d}}}}while(0);if((bb|0)==69){bb=0;a[Ib]=a[(c[Kb+96>>2]|0)+(vb+4)|0]|0;ub=(c[(c[hb>>2]|0)+96>>2]|0)+vb|0;Fb=Hb+4|0;x=d[ub]|d[ub+1|0]<<8|d[ub+2|0]<<16|d[ub+3|0]<<24|0;a[Fb]=x;x=x>>8;a[Fb+1|0]=x;x=x>>8;a[Fb+2|0]=x;x=x>>8;a[Fb+3|0]=x;Nb=vb+5|0;Ob=Jb;Pb=Hb}Fb=Pb+8|0;if((SGb(Ob|0)|0)>>>0>2>>>0){rb=Fb;xb=Ob;vb=Nb}else{Db=Fb;break}}}else{Db=tb}}while(0);a[qb]=255-qb+Db;mb=Db}else if((lb|0)==1){tb=c[kb+48>>2]|0;if((tb|0)==86057){a[ib]=122;a[cb+6|0]=1;a[cb+7|0]=0;Sb=cb+8|0;Tb=c[(c[hb>>2]|0)+48>>2]|0}else{Sb=ib;Tb=tb}if((Tb|0)==65562){a[Sb]=5;a[Sb+1|0]=4;a[Sb+2|0]=66;a[Sb+3|0]=83;a[Sb+4|0]=83;a[Sb+5|0]=68;Ub=Sb+6|0}else{Ub=Sb}if((gb|0)==0){mb=Ub;break}tb=gb+4|0;ob=c[tb>>2]|0;pb=Ub+1|0;a[Ub]=10;vb=Ub+2|0;a[pb]=0;f:do{if((ob|0)==0){Wb=vb;Xb=0}else{xb=eb+72|0;rb=vb;sb=c[tb>>2]|0;Fb=0;while(1){if(!((Fb&255)>>>0<252>>>0)){mb=rb;break b}if(!((rb-M|0)>>>0<1008>>>0)){Wb=rb;Xb=Fb;break f}ub=Vb(sb|0,44)|0;if((SGb(sb|0)|0)==3){bb=47}else{if((ub|0)!=0&(ub|0)==(sb+3|0)){bb=47}else{Yb=rb;Zb=Fb}}if((bb|0)==47){bb=0;a[rb]=a[sb]|0;a[rb+1|0]=a[sb+1|0]|0;Cb=rb+3|0;a[rb+2|0]=a[sb+2|0]|0;Bb=c[xb>>2]|0;do{if((Bb&512|0)==0){if((Bb&128|0)!=0){a[Cb]=2;_b=rb+4|0;break}Qb=rb+4|0;if((Bb&256|0)==0){a[Cb]=0;_b=Qb;break}else{a[Cb]=3;_b=Qb;break}}else{a[Cb]=1;_b=rb+4|0}}while(0);Cb=(a[pb]|0)+4&255;a[pb]=Cb;Yb=_b;Zb=Cb}if((ub|0)==0){Wb=Yb;Xb=Zb;break}else{rb=Yb;sb=ub+1|0;Fb=Zb}}}}while(0);mb=Xb<<24>>24==0?Wb-2|0:Wb}else if((lb|0)==0){if((jb|0)!=209){mb=ib;break}a[ib]=5;a[cb+6|0]=4;a[cb+7|0]=100;a[cb+8|0]=114;a[cb+9|0]=97;a[cb+10|0]=99;mb=cb+11|0}else{mb=ib}}while(0);ib=mb-fb-2|0;a[fb]=ib>>>8|240;a[cb+4|0]=ib;ib=db+1|0;if(ib>>>0<(c[s>>2]|0)>>>0){cb=mb;db=ib}else{ab=mb;bb=86;break}}}}while(0);if((bb|0)==86){bb=0;hK(Wa|0,2,c[Wa+16>>2]|0,c[Ta+124>>2]|0,I,ab-M|0)}Qa=Qa+1|0;}while((Qa|0)<(c[Ua>>2]|0))}}while(0);Oa=c[O>>2]|0;do{if((c[N>>2]|0)==(c[Oa+28>>2]|0)){Sa=Oa+32|0;Ra=c[Sa>>2]|0;if((c[P>>2]|0)<2&C){$b=Ra}else{Ua=Ra+1|0;c[Sa>>2]=Ua;$b=Ua}if(($b|0)<(c[Oa+36>>2]|0)){ac=0;break}c[Oa+32>>2]=0;ac=1}else{ac=0}}while(0);if((c[P>>2]|0)<2|Q){break}Oa=Ty(c[R>>2]|0,0,0,1)|0;Ua=YGb(Oa,F,11,0)|0;Oa=c[P>>2]|0;Sa=IDb(Ua,F,216e6,0,Oa,(Oa|0)<0|0?-1:0)|0;Oa=YGb(c[S>>2]|0,c[S+4>>2]|0,Sa,F)|0;Sa=eHb(Oa,F,300,0)|0;Oa=ZGb(k,l,Sa,F)|0;Sa=F;if(!((Sa|0)>(z|0)|(Sa|0)==(z|0)&Oa>>>0>A>>>0)){break}if((ac|0)==0){a[T]=71;a[U]=31;a[V]=-1;a[W]=16;TGb(X|0,-1|0,184)|0;Oa=c[w>>2]|0;if((c[Oa+108>>2]|0)!=0){Sa=Ty(c[R>>2]|0,0,0,1)|0;Ua=YGb(Sa,F,11,0)|0;Sa=c[Oa+80>>2]|0;Ra=IDb(Ua,F,216e6,0,Sa,(Sa|0)<0|0?-1:0)|0;Sa=Oa+72|0;Oa=YGb(c[Sa>>2]|0,c[Sa+4>>2]|0,Ra,F)|0;Ra=fHb(Oa,F,1073741823,0)|0;c[p>>2]=fe(Ra|0)|0;Ry(c[R>>2]|0,Y,4)}Ry(c[R>>2]|0,T,188);Na=0;continue}else{Ra=c[u>>2]|0;Oa=c[w>>2]|0;a[T]=71;Sa=c[Ra+4>>2]|0;a[U]=Sa>>>8;a[V]=Sa;a[W]=c[Ra+8>>2]|32;a[X]=-73;a[Z]=16;Ra=Ty(c[R>>2]|0,0,0,1)|0;Sa=YGb(Ra,F,11,0)|0;Ra=c[Oa+80>>2]|0;Ua=IDb(Sa,F,216e6,0,Ra,(Ra|0)<0|0?-1:0)|0;Ra=Oa+72|0;Oa=YGb(c[Ra>>2]|0,c[Ra+4>>2]|0,Ua,F)|0;Ua=F;Ra=fHb(Oa,Ua,300,0)|0;Sa=F;Qa=eHb(Oa,Ua,300,0)|0;Ua=F;a[_]=Qa>>>25|Ua<<7;a[$]=Qa>>>17|Ua<<15;a[aa]=Qa>>>9|Ua<<23;a[ba]=Qa>>>1|Ua<<31;a[ca]=Ra>>>8|Sa<<24|(Qa<<7|0>>>25)|126;a[da]=Ra;TGb(ea|0,-1|0,176)|0;Ra=c[w>>2]|0;if((c[Ra+108>>2]|0)!=0){Qa=Ty(c[R>>2]|0,0,0,1)|0;Sa=YGb(Qa,F,11,0)|0;Qa=c[Ra+80>>2]|0;Ua=IDb(Sa,F,216e6,0,Qa,(Qa|0)<0|0?-1:0)|0;Qa=Ra+72|0;Ra=YGb(c[Qa>>2]|0,c[Qa+4>>2]|0,Ua,F)|0;Ua=fHb(Ra,F,1073741823,0)|0;c[q>>2]=fe(Ua|0)|0;Ry(c[R>>2]|0,r,4)}Ry(c[R>>2]|0,T,188);Na=0;continue}}a[ia]=71;Na=c[N>>2]>>8;C=(Ka|0)!=0;if(C){bc=(Na|64)&255}else{bc=Na&255}a[ja]=bc;a[ka]=c[N>>2];Na=(c[ma>>2]|0)+1&15;c[ma>>2]=Na;Ua=(Na|16)&255;a[la]=Ua;do{if(e|C^1|oa){cc=na;dc=ac;ec=Ua}else{Na=(c[N>>2]|0)==(c[(c[O>>2]|0)+28>>2]|0)?1:ac;Ra=Ua|32;a[la]=Ra;a[na]=1;a[Ea]=64;if(0){cc=na;dc=Na;ec=Ra;break}cc=t+((d[na]|0)+5)|0;dc=Na;ec=Ra}}while(0);if((dc|0)==0){fc=cc}else{if((ec&32)==0){Ua=ec|32;a[la]=Ua;a[na]=1;a[Ea]=0;gc=16;hc=Ua}else{gc=a[Ea]|16;hc=ec}a[Ea]=gc;if((hc&32)==0){ic=na}else{ic=t+((d[na]|0)+5)|0}if((c[P>>2]|0)>1){Ua=Ty(c[R>>2]|0,0,0,1)|0;Ra=YGb(Ua,F,11,0)|0;Ua=c[P>>2]|0;Na=IDb(Ra,F,216e6,0,Ua,(Ua|0)<0|0?-1:0)|0;Ua=YGb(c[S>>2]|0,c[S+4>>2]|0,Na,F)|0;jc=F;kc=Ua}else{jc=b;kc=Ja}Ua=eHb(kc,jc,300,0)|0;Na=F;if(((Na|0)>(l|0)|(Na|0)==(l|0)&Ua>>>0>k>>>0)&(Q^1)){yDb(Ia,24,2024504,(lc=i,i=i+1|0,i=i+7&-8,c[lc>>2]=0,lc)|0);i=lc}Ra=fHb(kc,jc,300,0)|0;a[ic]=Ua>>>25|Na<<7;a[ic+1|0]=Ua>>>17|Na<<15;a[ic+2|0]=Ua>>>9|Na<<23;a[ic+3|0]=Ua>>>1|Na<<31;a[ic+4|0]=Ra>>>8|F<<24|(Ua<<7|0>>>25)|126;a[ic+5|0]=Ra;if((a[la]&32)==0){bb=118;break}Ra=(a[na]|0)+6&255;a[na]=Ra;fc=t+((Ra&255)+5)|0}do{if(C){a[fc]=0;a[fc+1|0]=0;Ra=fc+3|0;a[fc+2|0]=1;Ua=c[B>>2]|0;Na=c[Ua+8>>2]|0;do{if((Na|0)==0){Qa=fc+4|0;if((c[Ua+48>>2]|0)==117){a[Ra]=-3;mc=Qa;nc=0;oc=0;break}else{a[Ra]=-32;mc=Qa;nc=0;oc=0;break}}else if((Na|0)==1){if(((c[Ua+48>>2]|0)-86016|0)>>>0<3>>>0){a[Ra]=-64;mc=fc+4|0;nc=0;oc=0;break}if((c[Ua+48>>2]|0)!=86019){bb=130;break}if((c[pa>>2]|0)==0){bb=130;break}a[Ra]=-3;mc=fc+4|0;nc=0;oc=0}else{bb=130}}while(0);do{if((bb|0)==130){bb=0;Ua=fc+4|0;a[Ra]=-67;Na=c[B>>2]|0;if((c[Na+8>>2]|0)!=3){mc=Ua;nc=0;oc=0;break}Qa=c[Na+48>>2]|0;if((Qa|0)==94209){mc=Ua;nc=0;oc=1;break}mc=Ua;nc=(Qa|0)==94215|0;oc=0}}while(0);Ra=sa?qa:Ba;Qa=sa?ra:Ca;Ua=c[B>>2]|0;Na=c[Ua+8>>2]|0;do{if((Na|0)==0){if((c[Ua+48>>2]|0)!=117){pc=0;qc=Qa;rc=Ra;break}pc=1;qc=Qa|1;rc=Ra+3|0}else{pc=0;qc=Qa;rc=Ra}}while(0);do{if((c[pa>>2]|0)!=0&(Na|0)==1){if((c[Ua+48>>2]|0)!=86019){sc=pc;tc=qc;uc=rc;break}sc=1;tc=qc|1;uc=rc+3|0}else{sc=pc;tc=qc;uc=rc}}while(0);Ua=(nc|0)!=0;Na=Ua?36:uc;Ra=Ua?36-uc|0:0;Qa=Na+Ma|0;Sa=(oc|0)!=0;if(Sa){vc=Ma+1|0;wc=Qa+6|0}else{vc=Ma;wc=Qa+3|0}Qa=(wc|0)>65535;a[mc]=Qa?0:wc>>>8&255;a[mc+1|0]=Qa?0:wc&255;a[mc+2|0]=((c[(c[B>>2]|0)+8>>2]|0)-2|0)>>>0<2>>>0?-124:-128;a[mc+3|0]=tc;Qa=mc+5|0;a[mc+4|0]=Na;if(y){a[Qa]=ta|tc>>6<<4|1;a[mc+6|0]=ua;a[mc+7|0]=va;a[mc+8|0]=wa;a[mc+9|0]=j;xc=mc+10|0}else{xc=Qa}if(sa){yc=xc}else{a[xc]=h;a[xc+1|0]=xa;a[xc+2|0]=ya;a[xc+3|0]=za;a[xc+4|0]=Aa;yc=xc+5|0}do{if((sc|0)==0){zc=yc}else{if((c[(c[B>>2]|0)+48>>2]|0)==117){a[yc]=1;a[yc+1|0]=-127;a[yc+2|0]=96;Ac=yc+3|0}else{Ac=yc}if((c[pa>>2]|0)==0){zc=Ac;break}if((c[(c[B>>2]|0)+48>>2]|0)!=86019){zc=Ac;break}a[Ac]=1;a[Ac+1|0]=-127;a[Ac+2|0]=113;zc=Ac+3|0}}while(0);if(Sa){a[zc]=32;a[zc+1|0]=0;Bc=zc+2|0}else{Bc=zc}if(!Ua){Cc=vc;Dc=Bc;Ec=oc;break}TGb(Bc|0,-1|0,Ra|0)|0;Cc=vc;Dc=Bc+Ra|0;Ec=oc}else{Cc=Ma;Dc=fc;Ec=La}}while(0);C=Dc-Da|0;Qa=188-C|0;Na=(Qa|0)>(Cc|0)?Cc:Qa;Oa=Qa-Na|0;do{if((Oa|0)>0){if(!((a[la]&32)==0)){Qa=d[na]|0;Va=Qa+5|0;Pa=t+Va|0;VGb(t+(Va+Oa)|0,Pa|0,C-5-Qa|0)|0;a[na]=(d[na]|0)+Oa;TGb(Pa|0,-1|0,Oa|0)|0;break}VGb(t+(Oa+4)|0,na|0,C-4|0)|0;a[la]=a[la]|32;a[na]=Oa+255;if((Oa|0)<=1){break}a[Ea]=0;TGb(Fa|0,-1|0,Oa-2|0)|0}}while(0);Oa=t+(188-Na)|0;if((Ec|0)!=0&(Cc|0)==(Na|0)){UGb(Oa|0,g|0,Cc-1|0)|0;a[Ga]=-1}else{UGb(Oa|0,g|0,Na)|0}Oa=Cc-Na|0;C=c[w>>2]|0;if((c[C+108>>2]|0)!=0){Pa=Ty(c[R>>2]|0,0,0,1)|0;Qa=YGb(Pa,F,11,0)|0;Pa=c[C+80>>2]|0;Va=IDb(Qa,F,216e6,0,Pa,(Pa|0)<0|0?-1:0)|0;Pa=C+72|0;C=YGb(c[Pa>>2]|0,c[Pa+4>>2]|0,Va,F)|0;Va=fHb(C,F,1073741823,0)|0;c[o>>2]=fe(Va|0)|0;Ry(c[R>>2]|0,Ha,4)}Ry(c[R>>2]|0,ia,188);if((Oa|0)>0){Ka=0;La=Ec;Ma=Oa;g=g+Na|0;f=0}else{D=R;bb=166;break}}if((bb|0)==118){yDb(0,0,1980776,(lc=i,i=i+24|0,c[lc>>2]=1950432,c[lc+8>>2]=1924704,c[lc+16>>2]=899,lc)|0);i=lc;Cd()}else if((bb|0)==166){E=c[D>>2]|0;Sy(E);G=v+20|0;H=G;c[H>>2]=m;i=n;return}}function hK(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+1216|0;k=j|0;l=j+192|0;m=h+12|0;if(m>>>0>1024>>>0){i=j;return}n=l|0;a[n]=d;o=h+9|0;a[l+1|0]=(o|((d|0)==66?61440:45056))>>>8;a[l+2|0]=o;a[l+3|0]=e>>>8;a[l+4|0]=e;a[l+5|0]=f<<1|193;a[l+6|0]=0;a[l+7|0]=0;UGb(l+8|0,g|0,h)|0;g=k|0;f=h+8|0;e=fe(uBb(tBb(3)|0,-1,n,f)|0)|0;a[l+f|0]=e>>>24;a[l+o|0]=e>>>16;a[l+(h+10)|0]=e>>>8;a[l+(h+11)|0]=e;if((m|0)<=0){i=j;return}e=k+1|0;h=b|0;l=k+2|0;o=k+3|0;f=b+4|0;d=k+4|0;p=k+5|0;q=k;k=b+8|0;r=n;s=m;while(1){a[g]=71;m=c[h>>2]|0;t=m>>8;if((r|0)==(n|0)){u=(t|64)&255;v=1}else{u=t&255;v=0}a[e]=u;a[l]=m;m=(c[f>>2]|0)+1&15;c[f>>2]=m;a[o]=m|16;if(v){a[d]=0;w=p}else{w=d}m=q-w+188|0;t=(m|0)>(s|0)?s:m;UGb(w|0,r|0,t)|0;m=w+t|0;x=q-m+188|0;if((x|0)>0){TGb(m|0,-1|0,x|0)|0}ne[c[k>>2]&1023](b,g);x=s-t|0;if((x|0)>0){r=r+t|0;s=x}else{break}}i=j;return}function iK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;a=c[f+12>>2]|0;g=f+16|0;if((c[a+108>>2]|0)==0){h=c[g>>2]|0;Ry(h,b,188);i=d;return}f=Ty(c[g>>2]|0,0,0,1)|0;j=YGb(f,F,11,0)|0;f=c[a+80>>2]|0;k=IDb(j,F,216e6,0,f,(f|0)<0|0?-1:0)|0;f=a+72|0;a=YGb(c[f>>2]|0,c[f+4>>2]|0,k,F)|0;k=fHb(a,F,1073741823,0)|0;c[e>>2]=fe(k|0)|0;Ry(c[g>>2]|0,e,4);h=c[g>>2]|0;Ry(h,b,188);i=d;return}function jK(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=c[b+8>>2]|0;if((e|0)<=0){f=0;return f|0}g=c[b+4>>2]|0;b=-256;h=0;i=0;j=0;k=0;l=0;m=0;n=0;o=0;p=0;q=0;while(1){r=d[g+p|0]|0|b;a:do{if((b|0)==256){b:do{if((r|0)==442){s=n;t=k+1|0;u=i;v=h;w=j;x=o}else if((r|0)==435){if((a[g+(p+7)|0]&32)==0){s=n;t=k;u=i;v=h;w=j;x=o;break}y=(a[g+(p+8)|0]&2)==0?p:p+64|0;if((y|0)>=(e|0)){s=n;t=k;u=i;v=h;w=j;x=o;break}z=(a[g+(y+8)|0]&1)==0?y:y+64|0;if((z|0)>=(e|0)){s=n;t=k;u=i;v=h;w=j;x=o;break}s=n;t=k;u=(((d[g+(z+10)|0]|0)<<8|(d[g+(z+9)|0]|0)<<16|a[g+(z+11)|0]&254|0)==0)+i|0;v=h;w=j;x=o}else if((r|0)==256){s=n;t=k;u=i;v=h+1|0;w=j;x=o}else if((r|0)==438){s=n+1|0;t=k;u=i;v=h;w=j;x=o}else{do{if((r-257|0)>>>0<175>>>0){if((q-257|0)>>>0<175>>>0){if(r>>>0<q>>>0){A=o+1|0;B=j;break}else{A=o;B=j+1|0;break}}else{if((r|0)==257){s=n;t=k;u=i;v=h;w=j+1|0;x=o;break b}else{A=o+1|0;B=j;break}}}else{A=o;B=j}}while(0);if((r&496|0)!=480){s=n;t=k;u=i;v=h;w=B;x=A;break}C=r;D=A;E=n;F=m;G=l+1|0;H=k;I=B;J=i;K=h;break a}}while(0);C=r;D=x;E=s;F=((r&480|0)==448)+m|0;G=l;H=t;I=w;J=u;K=v}else{C=q;D=o;E=n;F=m;G=l;H=k;I=j;J=i;K=h}}while(0);z=p+1|0;if((z|0)<(e|0)){b=r<<8;h=K;i=J;j=I;k=H;l=G;m=F;n=E;o=D;p=z;q=C}else{break}}if((J|0)==0){f=0;return f|0}if((J*9|0|0)>(K*10|0|0)){f=0;return f|0}if(!((K*9|0|0)<=(I*10|0|0)&(H|0)==0&(F|0)==0&(E|0)==0&(I|0)>(D|0))){f=0;return f|0}if((G|0)!=0){f=12;return f|0}f=(K|0)>1?51:25;return f|0}function kK(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+256|0;d=b|0;Lb(d|0,256,1902464,(e=i,i=i+8|0,c[e>>2]=1924552,e)|0)|0;i=e;e=a+16|0;a=c[e>>2]|0;Ry(a,d,SGb(d|0)|0);Sy(c[e>>2]|0);i=b;return 0}function lK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+256|0;e=d|0;Lb(e|0,256,2023976,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;g=a+16|0;a=c[g>>2]|0;Ry(a,e,SGb(e|0)|0);a=b+28|0;Lb(e|0,256,1980312,(f=i,i=i+8|0,c[f>>2]=c[a>>2],f)|0)|0;i=f;h=c[g>>2]|0;Ry(h,e,SGb(e|0)|0);Ry(c[g>>2]|0,c[b+24>>2]|0,c[a>>2]|0);Lb(e|0,256,1950176,(f=i,i=i+8|0,c[f>>2]=1924552,f)|0)|0;i=f;f=c[g>>2]|0;Ry(f,e,SGb(e|0)|0);i=d;return 0}function mK(a){a=a|0;return 0}function nK(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[b+4>>2]|0;j=h+(c[b+8>>2]|0)|0;b=h;h=0;while(1){if((h|0)>=2){k=100;l=8;break}m=xd(b|0,1950160,(n=i,i=i+24|0,c[n>>2]=f,c[n+8>>2]=g,c[n+16>>2]=e,n)|0)|0;i=n;if((m|0)!=3){m=xd(b|0,1924536,(n=i,i=i+16|0,c[n>>2]=f,c[n+8>>2]=e,n)|0)|0;i=n;if((m|0)!=2){k=0;l=8;break}}m=hc(b|0,2071888)|0;n=a[b+m|0]|0;if(n<<24>>24==13){o=m+1|0;p=o;q=a[b+o|0]|0}else{p=m;q=n}n=b+((q<<24>>24==10)+p)|0;if(n>>>0<j>>>0){b=n;h=h+1|0}else{k=0;l=8;break}}if((l|0)==8){i=d;return k|0}return 0}function oK(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+4128|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+4120|0;k=c[b+12>>2]|0;l=LT(b,0)|0;if((l|0)==0){m=-12;i=d;return m|0}MT(l,64,1,10);n=c[l+8>>2]|0;c[n+8>>2]=3;c[n+48>>2]=1297108018;n=b+16|0;a:do{if((Xy(c[n>>2]|0)|0)==0){b=h|0;l=k;while(1){o=Ty(c[n>>2]|0,0,0,1)|0;p=F;if((wz(c[n>>2]|0,b,4096)|0)==0){q=l;break a}a[h+(hc(b|0,2071888)|0)|0]=0;r=xd(b|0,2023960,(s=i,i=i+24|0,c[s>>2]=j,c[s+8>>2]=e,c[s+16>>2]=f,s)|0)|0;i=s;do{if((r|0)>1){t=-1;u=10}else{v=xd(b|0,1980288,(s=i,i=i+32|0,c[s>>2]=j,c[s+8>>2]=g,c[s+16>>2]=e,c[s+24>>2]=f,s)|0)|0;i=s;if((v|0)<=2){break}v=ZGb(c[g>>2]|0,c[g+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;t=v;u=10}}while(0);if((u|0)==10){u=0;s=h+((c[f>>2]|0)-1)|0;r=uR(l,s,SGb(s|0)|0,0)|0;if((r|0)==0){m=-12;break}s=r+64|0;c[s>>2]=o;c[s+4>>2]=p;s=c[j+4>>2]|0;v=r+8|0;c[v>>2]=c[j>>2];c[v+4>>2]=s;c[r+48>>2]=t}if((Xy(c[n>>2]|0)|0)!=0){q=l;break a}}i=d;return m|0}else{q=k}}while(0);vR(q);m=0;i=d;return m|0}function pK(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function qK(a){a=a|0;AR(c[a+12>>2]|0);return 0}function rK(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function sK(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[b+4>>2]|0;e=c[b+8>>2]|0;b=d+e|0;if((e|0)>0){f=d}else{g=0;return g|0}while(1){if((PGb(f,1950144,11)|0)==0){g=50;h=8;break}if((PGb(f,1924528,7)|0)==0){g=16;h=8;break}d=hc(f|0,2071880)|0;e=a[f+d|0]|0;if(e<<24>>24==13){i=d+1|0;j=i;k=a[f+i|0]|0}else{j=d;k=e}e=(k<<24>>24==10)+j|0;if((e|0)==0){g=0;h=8;break}d=f+e|0;if(d>>>0<b>>>0){f=d}else{g=0;h=8;break}}if((h|0)==8){return g|0}return 0}function tK(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0.0,I=0.0,J=0,K=0;d=i;i=i+2072|0;e=d|0;f=d+1024|0;h=d+2048|0;j=d+2056|0;k=d+2064|0;l=c[b+12>>2]|0;IAb(e,0,-1);m=b+16|0;a:do{if((Xy(c[m>>2]|0)|0)==0){n=f|0;o=e+4|0;p=l;q=e|0;r=0.0;s=100.0;t=100;while(1){u=s;v=t;b:while(1){while(1){if((wz(c[m>>2]|0,n,1024)|0)==0){w=v;x=13;break a}a[f+(hc(n|0,2071880)|0)|0]=0;y=xd(n|0,2023944,(z=i,i=i+8|0,c[z>>2]=k,z)|0)|0;i=z;A=c[k>>2]|0;if((y|0)==1&(A|0)>3&(A|0)<100){break}y=xd(n|0,1980280,(z=i,i=i+16|0,c[z>>2]=h,c[z+8>>2]=j,z)|0)|0;i=z;if((y|0)==2){B=Ty(c[m>>2]|0,0,0,1)|0;C=F;DR(c[m>>2]|0,e);D=c[o>>2]|0;if((D|0)!=0){break b}}if((Xy(c[m>>2]|0)|0)!=0){w=v;x=13;break a}}if((Xy(c[m>>2]|0)|0)==0){u=1.0;v=A}else{w=A;x=13;break a}}y=uR(p,c[q>>2]|0,D,0)|0;if((y|0)==0){G=-12;break a}H=+g[h>>2];I=r+u*H;z=(E=+I,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);J=y+8|0;c[J>>2]=~~+I>>>0;c[J+4>>2]=z;I=+g[j>>2];c[y+48>>2]=~~(u*I);z=y+64|0;c[z>>2]=B;c[z+4>>2]=C;if((Xy(c[m>>2]|0)|0)==0){r=r+u*(H+I);s=u;t=v}else{w=v;x=13;break}}}else{w=100;x=13}}while(0);do{if((x|0)==13){m=LT(b,0)|0;if((m|0)==0){K=-12;i=d;return K|0}else{MT(m,64,1,w);C=c[m+8>>2]|0;c[C+8>>2]=3;c[C+48>>2]=94210;vR(l);G=0;break}}}while(0);QAb(e,0)|0;K=G;i=d;return K|0}function uK(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function vK(a){a=a|0;AR(c[a+12>>2]|0);return 0}function wK(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function xK(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+8>>2]|0;if((b|0)<24){e=-1;return e|0}f=c[a+4>>2]|0;a=0;a:while(1){g=f+a|0;do{if((d[g]|d[g+1|0]<<8)<<16>>16<<16>>16==24){h=f+(a+2)|0;i=(d[h]|d[h+1|0]<<8)<<16>>16&65535;h=f+(a+4)|0;j=(d[h]|d[h+1|0]<<8)<<16>>16;if((i|0)==160){if(!(j<<16>>16==120)){break}}else if((i|0)==320){if(!(j<<16>>16==240)){break}}else{break}j=f+(a+12)|0;if((d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)==808602701){break a}}}while(0);if((a+25|0)>(b|0)){e=-1;k=11;break}else{a=a+1|0}}if((k|0)==11){return e|0}if((a|0)==0){e=100;return e|0}e=(a|0)<14?50:33;return e|0}function yK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+16>>2]|0;e=LT(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=c[e+8>>2]|0;c[g+8>>2]=0;c[g+48>>2]=114;c[g+52>>2]=808602701;MT(e,32,1,1e3);do{if((lz(d)|0)==24){break}}while((Xy(d)|0)==0);if((Xy(d)|0)==0){f=0;i=b;return f|0}yDb(a,16,2137200,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-1;i=b;return f|0}function zK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+16>>2]|0;Vy(d,1,0)|0;Vy(d,2,0)|0;Vy(d,2,0)|0;a=pz(d)|0;e=rz(d)|0;Vy(d,4,0)|0;Vy(d,4,0)|0;f=rz(d)|0;if((e|0)==0){g=-1;return g|0}if((TS(d,b,e)|0)!=(e|0)){g=-1;return g|0}Vy(d,1,0)|0;d=f;f=0;h=b+8|0;c[h>>2]=d;c[h+4>>2]=f;h=b+16|0;c[h>>2]=d;c[h+4>>2]=f;c[b+32>>2]=0;if((a&1|0)!=0){a=b+36|0;c[a>>2]=c[a>>2]|1}g=e+24|0;return g|0}function AK(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[b+8>>2]|0;if((e|0)<57){f=0;return f|0}g=c[b+4>>2]|0;if((a[g]|0)!=65){f=0;return f|0}if((a[g+1|0]|0)!=77){f=0;return f|0}if((a[g+2|0]|0)!=86){f=0;return f|0}if((a[g+43|0]|0)!=77){f=0;return f|0}if((a[g+44|0]|0)!=80){f=0;return f|0}if((a[g+45|0]|0)!=51){f=0;return f|0}b=a[g+51|0]|0;if(b<<24>>24==0){f=0;return f|0}h=g+52|0;i=(d[h]|d[h+1|0]<<8)<<16>>16;h=g+54|0;j=(d[h]|d[h+1|0]<<8)<<16>>16;if((j|i)<<16>>16==0){f=0;return f|0}if(i<<16>>16==0|j<<16>>16==0){j=g+56|0;f=(d[j]|d[j+1|0]<<8)<<16>>16<<16>>16==0?0:50;return f|0}if(!(b<<24>>24==16)){f=25;return f|0}f=(e|0)<512?50:100;return f|0}function BK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;Vy(e,3,0)|0;c[d>>2]=rz(e)|0;c[d+4>>2]=rz(e)|0;Vy(e,32,0)|0;c[d+8>>2]=qz(e)|0;f=d+12|0;c[f>>2]=pz(e)|0;c[d+16>>2]=qz(e)|0;g=d+20|0;c[g>>2]=(lz(e)|0)>>3;h=d+24|0;c[h>>2]=pz(e)|0;j=d+28|0;c[j>>2]=pz(e)|0;k=d+32|0;c[k>>2]=pz(e)|0;l=c[g>>2]|0;if((l|0)!=16){yDb(a,24,2137152,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;c[g>>2]=16}g=c[h>>2]|0;l=c[j>>2]|0;n=(l|0)==0;do{if((g|0)==0){if(n){break}o=((c[k>>2]|0)>>>4>>>0)/(l>>>0)|0;c[h>>2]=o;if((o|0)!=0){p=8}}else{if(!n){p=8;break}o=((c[k>>2]|0)>>>4>>>0)/(g>>>0)|0;c[j>>2]=o;if((o|0)!=0){p=8}}}while(0);do{if((p|0)==8){if((c[k>>2]|0)==0){break}Vy(e,4,0)|0;g=pz(e)|0;if((g|0)==0){DDb(a,2023912,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;q=-1163346256;i=b;return q|0}c[d+40>>2]=(c[k>>2]|0)+(g<<9);n=d+36|0;c[n>>2]=((c[f>>2]|0)>>>2>>>0)/(g>>>0)|0;g=LT(a,0)|0;if((g|0)==0){q=-12;i=b;return q|0}MT(g,64,1,c[n>>2]|0);l=g+8|0;g=c[l>>2]|0;c[g+8>>2]=0;c[g+48>>2]=14;c[g+140>>2]=43;c[g+120>>2]=c[h>>2];c[g+124>>2]=c[j>>2];c[g+412>>2]=c[n>>2];n=eEb(1980264)|0;c[(c[l>>2]|0)+96>>2]=n;c[(c[l>>2]|0)+100>>2]=9;l=LT(a,0)|0;if((l|0)==0){q=-12;i=b;return q|0}MT(l,64,1,44100);n=c[l+8>>2]|0;c[n+8>>2]=1;c[n+48>>2]=86017;c[n+72>>2]=c[f>>2];c[l+236>>2]=1;l=Ty(e,512,0,0)|0;q=(l|0)==512&(F|0)==0?0:-5;i=b;return q|0}}while(0);yDb(a,16,2071744,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;q=-22;i=b;return q|0}function CK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=Ty(e,0,0,1)|0;g=a+1248|0;a=ZGb(f,F,c[g>>2]|0,c[g+4>>2]|0)|0;g=c[d+32>>2]|0;f=YGb(a,F,g,0)|0;a=fHb(f,F,c[d+40>>2]|0,0)|0;if((a|0)==0&(F|0)==0){a=TS(e,b,g)|0;if((a|0)<0){h=a;return h|0}c[b+32>>2]=0;h=a;return h|0}else{Vy(e,12,0)|0;a=TS(e,b,500)|0;if((a|0)<0){h=a;return h|0}e=b+64|0;g=YGb(c[e>>2]|0,c[e+4>>2]|0,-12,-1)|0;c[e>>2]=g;c[e+4>>2]=F;c[b+32>>2]=1;h=a;return h|0}return 0}function DK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[d+8>>2]|0;if((c[b+8>>2]|0)==1){f=b+412|0;g=1}else{f=b+108|0;g=c[b+104>>2]|0}b=c[f>>2]|0;a:do{if(((b|0)/(g|0)|0|0)<(e|0)){f=g;while(1){if((f&1|0)!=0){h=f;break a}d=(f|0)/2|0;if(((b|0)/(d|0)|0|0)<(e|0)){f=d}else{h=d;break}}}else{h=g}}while(0);b:do{if(((b|0)/(h|0)|0|0)<(e|0)){g=h;while(1){if(((g|0)%3|0|0)!=0){i=g;break b}f=(g|0)/3|0;if(((b|0)/(f|0)|0|0)<(e|0)){g=f}else{i=f;break}}}else{i=h}}while(0);c:do{if(((b|0)/(i|0)|0|0)<(e|0)){h=i;while(1){if(((h|0)%5|0|0)!=0){j=h;break c}g=(h|0)/5|0;if(((b|0)/(g|0)|0|0)<(e|0)){h=g}else{j=g;break}}}else{j=i}}while(0);d:do{if(((b|0)/(j|0)|0|0)<(e|0)){i=j;while(1){if(((i|0)%7|0|0)!=0){k=i;break d}h=(i|0)/7|0;if(((b|0)/(h|0)|0|0)<(e|0)){i=h}else{k=h;break}}}else{k=j}}while(0);e:do{if(((b|0)/(k|0)|0|0)<(e|0)){j=k;while(1){if(((j|0)%9|0|0)!=0){l=j;break e}i=(j|0)/9|0;if(((b|0)/(i|0)|0|0)<(e|0)){j=i}else{l=i;break}}}else{l=k}}while(0);f:do{if(((b|0)/(l|0)|0|0)<(e|0)){k=l;while(1){if(((k|0)%11|0|0)!=0){m=k;break f}j=(k|0)/11|0;if(((b|0)/(j|0)|0|0)<(e|0)){k=j}else{m=j;break}}}else{m=l}}while(0);g:do{if(((b|0)/(m|0)|0|0)<(e|0)){l=m;while(1){if(((l|0)%13|0|0)!=0){n=l;break g}k=(l|0)/13|0;if(((b|0)/(k|0)|0|0)<(e|0)){l=k}else{n=k;break}}}else{n=m}}while(0);m=b;while(1){if(((m|0)/(n|0)|0|0)<(e|0)&(m|0)<16777216){m=m<<1}else{break}}c[a>>2]=n;c[a+4>>2]=m;return}function EK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;g=tN()|0;c[a>>2]=0;a:do{if((g|0)==0){h=16}else{do{if((b|0)==0){if((d|0)==0){j=UC(0,e,0)|0;if((j|0)!=0){k=j;break}yDb(g,16,2227184,(l=i,i=i+8|0,c[l>>2]=e,l)|0);i=l;m=-22;break a}else{j=UC(d,0,0)|0;if((j|0)!=0){k=j;break}yDb(g,16,1932112,(l=i,i=i+8|0,c[l>>2]=d,l)|0);i=l;m=-22;break a}}else{k=b}}while(0);j=g+8|0;c[j>>2]=k;n=c[k+44>>2]|0;do{if((n|0)>0){o=cEb(n)|0;p=g+12|0;c[p>>2]=o;if((o|0)==0){h=16;break a}q=c[(c[j>>2]|0)+36>>2]|0;if((q|0)==0){break}c[o>>2]=q;DEb(c[p>>2]|0)}else{c[g+12>>2]=0}}while(0);if((e|0)!=0){sAb(g+32|0,e,1024)|0}c[a>>2]=g;r=0;i=f;return r|0}}while(0);if((h|0)==16){yDb(g,16,2137136,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-12}bT(g);r=m;i=f;return r|0}function FK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=i;i=i+72|0;e=d|0;f=d+8|0;g=d+40|0;c[e>>2]=0;h=a+8|0;j=c[h>>2]|0;k=(b|0)!=0;if(k){EBb(e,c[b>>2]|0,0)}l=a;m=IEb(l,e)|0;a:do{if((m|0)<0){n=m;o=60}else{p=a+12|0;q=c[p>>2]|0;do{if((q|0)!=0){r=c[(c[h>>2]|0)+36>>2]|0;if((r|0)==0){break}if((c[q>>2]|0)!=(r|0)){break}r=IEb(q,e)|0;if((r|0)<0){n=r;o=60;break a}}}while(0);q=a+24|0;b:do{if((c[q>>2]|0)==0){if((c[j+28>>2]&4096|0)!=0){break}yDb(l,16,2235544,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-22;o=60;break a}else{r=a+28|0;t=j+32|0;u=j+28|0;v=a+1296|0;w=0;c:while(1){x=c[(c[r>>2]|0)+(w<<2)>>2]|0;y=c[x+8>>2]|0;z=y+8|0;A=c[z>>2]|0;d:do{if((A|0)==0){if((c[y+104>>2]|0)<1){o=19;break c}if((c[y+108>>2]|0)<1){o=19;break c}if((c[y+120>>2]|0)<1){o=22}else{if((c[y+124>>2]|0)<1){o=22}}if((o|0)==22){o=0;if((c[u>>2]&2048|0)==0){o=23;break c}}B=c[x+80>>2]|0;C=c[x+84>>2]|0;D=c[y+224>>2]|0;E=c[y+228>>2]|0;G=gHb(E,(E|0)<0|0?-1:0,B,(B|0)<0|0?-1:0)|0;H=F;I=gHb(D,(D|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;do{if((G|0)==(I|0)&(H|0)==(F|0)){if(!((E|0)==0|(C|0)==0)){break d}if((B|0)==0|(D|0)==0){break}if((B>>31|0)==(D>>31|0)){break d}}}while(0);J=+(B|0)/+(C|0);K=J- +(D|0)/+(E|0);if(K<0.0){L=-0.0-K}else{L=K}if(!(L<=J*.004|(B|0)==0|(C|0)==0|(E|0)==0)){o=31;break c}}else if((A|0)==1){if((c[y+412>>2]|0)<1){o=14;break c}H=y+432|0;if((c[H>>2]|0)!=0){break}I=c[y+416>>2]|0;c[H>>2]=(ba(u0a(c[y+48>>2]|0)|0,I)|0)>>3}}while(0);A=c[t>>2]|0;e:do{if((A|0)!=0){M=y+52|0;N=y+48|0;f:do{if((c[M>>2]|0)!=0){do{if((c[N>>2]|0)==14){if((xT(A,14)|0)!=0){if((xT(c[t>>2]|0,c[N>>2]|0)|0)!=544694642){break}}if((PK(a,x)|0)!=0){break}c[M>>2]=0;break f}}while(0);if((c[M>>2]|0)==0){break}if((PK(a,x)|0)==0){o=41;break c}else{break e}}}while(0);c[M>>2]=xT(c[t>>2]|0,c[N>>2]|0)|0}}while(0);do{if((c[u>>2]&64|0)!=0){if((c[y+88>>2]&4194304|0)!=0){break}yDb(l,24,2168472,(s=i,i=i+8|0,c[s>>2]=w,s)|0);i=s}}while(0);if((c[z>>2]|0)!=4){y=c[v>>2]|0;c[y>>2]=(c[y>>2]|0)+1}w=w+1|0;if(!(w>>>0<(c[q>>2]|0)>>>0)){break b}}if((o|0)==14){yDb(l,16,2222464,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-22;o=60;break a}else if((o|0)==19){yDb(l,16,2213016,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-22;o=60;break a}else if((o|0)==23){yDb(l,16,2203672,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-22;o=60;break a}else if((o|0)==31){yDb(l,16,2196232,(s=i,i=i+32|0,c[s>>2]=B,c[s+8>>2]=C,c[s+16>>2]=D,c[s+24>>2]=E,s)|0);i=s;n=-22;o=60;break a}else if((o|0)==41){I0a(f,32,c[M>>2]|0)|0;I0a(g,32,xT(c[(c[h>>2]|0)+32>>2]|0,c[N>>2]|0)|0)|0;w=c[M>>2]|0;v=c[N>>2]|0;yDb(l,16,2183256,(s=i,i=i+32|0,c[s>>2]=f,c[s+8>>2]=w,c[s+16>>2]=v,c[s+24>>2]=g,s)|0);i=s;n=-1094995529;o=60;break a}}}while(0);do{if((c[p>>2]|0)==0){v=c[j+44>>2]|0;if((v|0)<=0){break}w=cEb(v)|0;c[p>>2]=w;if((w|0)==0){n=-12;o=60;break a}v=c[j+36>>2]|0;if((v|0)==0){break}c[w>>2]=v;DEb(w);w=IEb(c[p>>2]|0,e)|0;if((w|0)<0){n=w;o=60;break a}}}while(0);do{if((c[q>>2]|0)==0){o=57}else{if((c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)!=0){o=57;break}CBb(a+1140|0,2161032,2154336,0)|0}}while(0);if((o|0)==57){CBb(a+1140|0,2161032,0,0)|0}if(!k){O=0;break}DBb(b);c[b>>2]=c[e>>2];O=0}}while(0);if((o|0)==60){DBb(e);O=n}if((O|0)!=0){P=O;i=d;return P|0}O=c[(c[h>>2]|0)+48>>2]|0;do{if((O|0)!=0){n=re[O&4095](a)|0;if(!((n|0)>-1)){P=n;i=d;return P|0}e=c[a+16>>2]|0;if((e|0)==0){break}b=c[e+76>>2]|0;e=(b|0)<0?b:n;if((e|0)<0){P=e}else{break}i=d;return P|0}}while(0);O=c[a+24>>2]|0;g:do{if((O|0)!=0){e=c[a+28>>2]|0;n=0;h:while(1){b=c[e+(n<<2)>>2]|0;k=c[b+8>>2]|0;j=c[k+8>>2]|0;if((j|0)==1){s=c[b+40>>2]|0;g=c[k+412>>2]|0;f=gHb(g,(g|0)<0|0?-1:0,s,(s|0)<0|0?-1:0)|0;Q=F;R=f;o=71}else if((j|0)==0){j=c[b+40>>2]|0;f=c[k+108>>2]|0;k=gHb(f,(f|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;Q=F;R=k;o=71}do{if((o|0)==71){o=0;if((R|0)==0&(Q|0)==(-2147483648|0)){break}k=0;if((Q|0)<(k|0)|(Q|0)==(k|0)&R>>>0<1>>>0){P=-1094995529;break h}k=R>>>1|Q<<31;j=Q>>1|((Q|0)<0|0?-1:0)<<31;if((j|0)<(Q|0)|(j|0)==(Q|0)&k>>>0<R>>>0){S=0;T=0;U=j;V=k}else{f=eHb(k,j,R,Q)|0;s=F;g=fHb(k,j,R,Q)|0;S=s;T=f;U=F;V=g}g=b+16|0;c[g>>2]=T;c[g+4>>2]=S;g=b+24|0;c[g>>2]=V;c[g+4>>2]=U;g=b+32|0;c[g>>2]=R;c[g+4>>2]=Q}}while(0);n=n+1|0;if(!(n>>>0<O>>>0)){break g}}i=d;return P|0}}while(0);O=a+1204|0;if((c[O>>2]|0)>=0){P=0;i=d;return P|0}if((c[(c[h>>2]|0)+28>>2]&262272|0)==0){c[O>>2]=1;P=0;i=d;return P|0}else{c[O>>2]=0;P=0;i=d;return P|0}return 0}function GK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;if((b|0)==0){e=c[a+8>>2]|0;if((c[e+28>>2]&65536|0)==0){f=1;i=d;return f|0}g=Oe[c[e+52>>2]&1023](a,0)|0;do{if((c[a+1228>>2]|0)!=0){e=c[a+16>>2]|0;if((e|0)==0){break}if(!((c[e+76>>2]|0)>-1)){break}Sy(e)}}while(0);if(!((g|0)>-1)){f=g;i=d;return f|0}e=c[a+16>>2]|0;if((e|0)==0){f=g;i=d;return f|0}else{h=c[e+76>>2]|0;i=d;return((h|0)<0?h:g)|0}}g=b+32|0;h=c[g>>2]|0;do{if((h|0)>=0){if(!(h>>>0<(c[a+24>>2]|0)>>>0)){break}e=a+28|0;j=c[(c[e>>2]|0)+(h<<2)>>2]|0;if((c[(c[j+8>>2]|0)+8>>2]|0)==4){yDb(a,16,2248560,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;f=-22;i=d;return f|0}l=HK(a,j,b)|0;do{if((l|0)<0){if((c[(c[a+8>>2]|0)+28>>2]&128|0)==0){f=l}else{break}i=d;return f|0}}while(0);l=IK(a,b)|0;if(!((l|0)>-1)){f=l;i=d;return f|0}j=c[a+16>>2]|0;do{if((j|0)==0){m=l}else{n=c[j+76>>2]|0;o=(n|0)<0?n:l;if((o|0)>-1){m=o;break}else{f=o}i=d;return f|0}}while(0);l=(c[(c[e>>2]|0)+(c[g>>2]<<2)>>2]|0)+64|0;j=YGb(c[l>>2]|0,c[l+4>>2]|0,1,0)|0;c[l>>2]=j;c[l+4>>2]=F;f=m;i=d;return f|0}}while(0);yDb(a,16,2263616,(k=i,i=i+8|0,c[k>>2]=h,k)|0);i=k;f=-22;i=d;return f|0}function HK(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;f=i;i=i+144|0;g=f|0;h=f+8|0;j=f+16|0;k=f+48|0;l=f+80|0;m=f+112|0;n=d+8|0;o=c[n>>2]|0;p=c[o+176>>2]|0;q=(c[o+156>>2]|0)>0|0;o=(p|0)>(q|0)?p:q;q=e+48|0;do{if((c[q>>2]|0)==0){fT(g,h,d,0,e);p=c[h>>2]|0;if((p|0)==0){break}r=c[g>>2]|0;if((r|0)==0){break}s=c[d+44>>2]|0;t=gHb(s,(s|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;r=c[(c[n>>2]|0)+112>>2]|0;s=gHb(t,F,r,(r|0)<0|0?-1:0)|0;r=F;t=c[d+40>>2]|0;u=gHb(t,(t|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;p=IDb(1,0,s,r,u,F)|0;c[q>>2]=p}}while(0);g=e+8|0;h=c[g>>2]|0;p=c[g+4>>2]|0;do{if((h|0)==0&(p|0)==(-2147483648|0)){u=e+16|0;r=c[u>>2]|0;s=c[u+4>>2]|0;if(!(((r|0)!=0|(s|0)!=(-2147483648|0))&(o|0)==0)){v=-2147483648;w=0;x=9;break}c[g>>2]=r;c[g+4>>2]=s;y=s;z=r;x=8}else{y=p;z=h;x=8}}while(0);if((x|0)==8){if((z|0)==0&(y|0)==0|(z|0)==0&(y|0)==(-2147483648|0)){v=y;w=z;x=9}else{A=y;B=z;x=14}}if((x|0)==9){z=e+16|0;if((c[z>>2]|0)==0&(c[z+4>>2]|0)==(-2147483648|0)&(o|0)==0){if(!(a[1420840]|0)){yDb(b,24,1882520,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;a[1420840]=1}y=d+16|0;h=c[y>>2]|0;p=c[y+4>>2]|0;c[g>>2]=h;c[g+4>>2]=p;c[z>>2]=h;c[z+4>>2]=p;D=p;E=h}else{D=v;E=w}if(!((E|0)==0&(D|0)==(-2147483648|0))){A=D;B=E;x=14}}do{if((x|0)==14){E=e+16|0;if(!((c[E>>2]|0)==0&(c[E+4>>2]|0)==(-2147483648|0)&(o|0)<17)){break}D=d+264|0;c[D>>2]=B;c[D+4>>2]=A;w=o+1|0;v=(o|0)>0;a:do{if(v){h=~o;p=1;do{z=d+264+(p<<3)|0;if(!((c[z>>2]|0)==0&(c[z+4>>2]|0)==(-2147483648|0))){break}y=ba(c[q>>2]|0,p+h|0)|0;r=YGb(y,(y|0)<0|0?-1:0,c[g>>2]|0,c[g+4>>2]|0)|0;c[z>>2]=r;c[z+4>>2]=F;p=p+1|0;}while((p|0)<(w|0));if(!v){break}p=c[D>>2]|0;h=c[D+4>>2]|0;z=0;while(1){r=z+1|0;y=d+264+(r<<3)|0;s=c[y>>2]|0;u=c[y+4>>2]|0;if(!((h|0)>(u|0)|(h|0)==(u|0)&p>>>0>s>>>0)){break a}t=d+264+(z<<3)|0;c[y>>2]=p;c[y+4>>2]=h;c[t>>2]=s;c[t+4>>2]=u;if((r|0)<(o|0)){z=r}else{break}}}}while(0);v=c[D+4>>2]|0;c[E>>2]=c[D>>2];c[E+4>>2]=v}}while(0);o=d+208|0;q=c[o>>2]|0;A=c[o+4>>2]|0;do{if(!((q|0)==0&(A|0)==0|(q|0)==0&(A|0)==(-2147483648|0))){B=e+16|0;x=c[B>>2]|0;v=c[B+4>>2]|0;if(!((A|0)>=(v|0)&((A|0)>(v|0)|q>>>0>=x>>>0)&(c[(c[b+8>>2]|0)+28>>2]&131072|0)==0|((A|0)>(v|0)|(A|0)==(v|0)&q>>>0>x>>>0))){break}x=c[d>>2]|0;v=j|0;TGb(v|0,0,32)|0;a[v]=0;if((q|0)==0&(A|0)==(-2147483648|0)){Lb(v|0,32,2295656,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0)|0;i=C}else{Lb(v|0,32,2278928,(C=i,i=i+16|0,c[C>>2]=q,c[C+8>>2]=A,C)|0)|0;i=C}B=k|0;TGb(B|0,0,32)|0;a[B]=0;w=e+16|0;z=c[w>>2]|0;h=c[w+4>>2]|0;if((z|0)==0&(h|0)==(-2147483648|0)){Lb(B|0,32,2295656,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0)|0;i=C}else{Lb(B|0,32,2278928,(C=i,i=i+16|0,c[C>>2]=z,c[C+8>>2]=h,C)|0)|0;i=C}yDb(b,16,2340384,(C=i,i=i+24|0,c[C>>2]=x,c[C+8>>2]=v,c[C+16>>2]=B,C)|0);i=C;G=-22;i=f;return G|0}}while(0);k=e+16|0;A=c[k>>2]|0;q=c[k+4>>2]|0;do{if(!((A|0)==0&(q|0)==(-2147483648|0))){j=c[g>>2]|0;B=c[g+4>>2]|0;if(!(((j|0)!=0|(B|0)!=(-2147483648|0))&((B|0)<(q|0)|(B|0)==(q|0)&j>>>0<A>>>0))){break}v=l|0;TGb(v|0,0,32)|0;a[v]=0;Lb(v|0,32,2278928,(C=i,i=i+16|0,c[C>>2]=j,c[C+8>>2]=B,C)|0)|0;i=C;B=m|0;TGb(B|0,0,32)|0;a[B]=0;j=c[k>>2]|0;x=c[k+4>>2]|0;if((j|0)==0&(x|0)==(-2147483648|0)){Lb(B|0,32,2295656,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0)|0;i=C}else{Lb(B|0,32,2278928,(C=i,i=i+16|0,c[C>>2]=j,c[C+8>>2]=x,C)|0)|0;i=C}x=c[d>>2]|0;yDb(b,16,2317312,(C=i,i=i+24|0,c[C>>2]=v,c[C+8>>2]=B,c[C+16>>2]=x,C)|0);i=C;G=-22;i=f;return G|0}}while(0);c[o>>2]=A;c[o+4>>2]=q;q=c[k>>2]|0;o=c[k+4>>2]|0;k=d+16|0;c[k>>2]=q;c[k+4>>2]=o;A=c[n>>2]|0;n=c[A+8>>2]|0;if((n|0)==1){if((c[e+36>>2]&8192|0)==0){H=eT(A,c[e+28>>2]|0,1)|0}else{H=c[(c[e+24>>2]|0)+76>>2]|0}if(!((H|0)>-1)){G=0;i=f;return G|0}C=d+24|0;b=c[C>>2]|0;m=c[C+4>>2]|0;C=d+32|0;l=c[C>>2]|0;g=c[C+4>>2]|0;do{if((c[e+28>>2]|0)==0){if(!((b|0)==(l>>>1|g<<31|0)&(m|0)==(g>>1|((g|0)<0|0?-1:0)<<31|0))){break}if((c[k>>2]|0)==0&(c[k+4>>2]|0)==0){G=0}else{break}i=f;return G|0}}while(0);e=c[d+44>>2]|0;C=gHb(e,(e|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;H=d+24|0;e=YGb(C,F,b,m)|0;m=F;b=0;do{if((m|0)<(b|0)|(m|0)==(b|0)&e>>>0<0>>>0){C=eHb(e,m,l,g)|0;x=YGb(c[k>>2]|0,c[k+4>>2]|0,C,F)|0;C=F;c[k>>2]=x;c[k+4>>2]=C;B=fHb(e,m,l,g)|0;v=F;j=0;if(!((v|0)<(j|0)|(v|0)==(j|0)&B>>>0<0>>>0)){I=v;J=B;break}j=YGb(B,v,l,g)|0;v=F;B=YGb(x,C,-1,-1)|0;c[k>>2]=B;c[k+4>>2]=F;I=v;J=j}else{if((m|0)<(g|0)|(m|0)==(g|0)&e>>>0<l>>>0){I=m;J=e;break}j=eHb(e,m,l,g)|0;v=YGb(c[k>>2]|0,c[k+4>>2]|0,j,F)|0;c[k>>2]=v;c[k+4>>2]=F;v=fHb(e,m,l,g)|0;I=F;J=v}}while(0);c[H>>2]=J;c[H+4>>2]=I;G=0;i=f;return G|0}else if((n|0)==0){n=c[d+44>>2]|0;I=c[A+104>>2]|0;A=gHb(I,(I|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=d+24|0;I=YGb(A,F,c[n>>2]|0,c[n+4>>2]|0)|0;A=F;H=d+32|0;d=c[H>>2]|0;J=c[H+4>>2]|0;H=0;do{if((A|0)<(H|0)|(A|0)==(H|0)&I>>>0<0>>>0){g=eHb(I,A,d,J)|0;l=YGb(g,F,q,o)|0;g=F;c[k>>2]=l;c[k+4>>2]=g;m=fHb(I,A,d,J)|0;e=F;b=0;if(!((e|0)<(b|0)|(e|0)==(b|0)&m>>>0<0>>>0)){K=e;L=m;break}b=YGb(m,e,d,J)|0;e=F;m=YGb(l,g,-1,-1)|0;c[k>>2]=m;c[k+4>>2]=F;K=e;L=b}else{if((A|0)<(J|0)|(A|0)==(J|0)&I>>>0<d>>>0){K=A;L=I;break}b=eHb(I,A,d,J)|0;e=YGb(b,F,q,o)|0;c[k>>2]=e;c[k+4>>2]=F;e=fHb(I,A,d,J)|0;K=F;L=e}}while(0);c[n>>2]=L;c[n+4>>2]=K;G=0;i=f;return G|0}else{G=0;i=f;return G|0}return 0}function IK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a+1328|0;h=c[g>>2]|0;j=c[g+4>>2]|0;do{if(!((h|0)==0&(j|0)==0)){g=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;c[e>>2]=1;c[e+4>>2]=1e6;k=KDb(h,j,e,g+40|0)|0;g=F;l=b+16|0;m=c[l>>2]|0;n=c[l+4>>2]|0;if(!((m|0)==0&(n|0)==(-2147483648|0))){o=YGb(m,n,k,g)|0;c[l>>2]=o;c[l+4>>2]=F}l=b+8|0;o=c[l>>2]|0;n=c[l+4>>2]|0;if((o|0)==0&(n|0)==(-2147483648|0)){break}m=YGb(o,n,k,g)|0;c[l>>2]=m;c[l+4>>2]=F}}while(0);e=c[a+1204>>2]|0;do{if((e|0)>0){j=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;h=j+456|0;l=c[h>>2]|0;m=c[h+4>>2]|0;g=b+16|0;k=c[g>>2]|0;n=c[g+4>>2]|0;o=-1;p=a+1280|0;q=c[p>>2]|0;r=c[p+4>>2]|0;if((q|0)==0&(r|0)==0&(((e|0)!=2&((n|0)>(o|0)|(n|0)==(o|0)&k>>>0>-1>>>0)|(k|0)==0&(n|0)==(-2147483648|0))^1)){o=ZGb(0,0,k,n)|0;n=F;c[p>>2]=o;c[p+4>>2]=n;p=j+40|0;k=a+1288|0;s=c[p+4>>2]|0;c[k>>2]=c[p>>2];c[k+4>>2]=s;t=n;u=o}else{t=r;u=q}if(((u|0)!=0|(t|0)!=0)&((l|0)==0&(m|0)==0)){q=JDb(u,t,a+1288|0,j+40|0,3)|0;j=F;c[h>>2]=q;c[h+4>>2]=j;v=j;w=q}else{v=m;w=l}l=c[g>>2]|0;m=c[g+4>>2]|0;if(!((l|0)==0&(m|0)==(-2147483648|0))){q=YGb(l,m,w,v)|0;c[g>>2]=q;c[g+4>>2]=F}g=b+8|0;q=c[g>>2]|0;m=c[g+4>>2]|0;if((q|0)==0&(m|0)==(-2147483648|0)){break}l=YGb(q,m,w,v)|0;c[g>>2]=l;c[g+4>>2]=F}}while(0);v=JZ(b)|0;do{if((c[b+36>>2]&8192|0)==0){x=Oe[c[(c[a+8>>2]|0)+52>>2]&1023](a,b)|0}else{c[f>>2]=c[b+24>>2];if((c[b+28>>2]|0)==-1431655292){w=_e[c[(c[a+8>>2]|0)+76>>2]&1023](a,c[b+32>>2]|0,f,0)|0;JCb(f);x=w;break}else{yDb(0,0,2071712,(w=i,i=i+24|0,c[w>>2]=2023848,c[w+8>>2]=1980240,c[w+16>>2]=565,w)|0);i=w;Cd();return 0}}}while(0);do{if((c[a+1228>>2]|0)!=0){f=c[a+16>>2]|0;if(!((f|0)!=0&(x|0)>-1)){break}if((c[a+1084>>2]&512|0)==0){break}Sy(f)}}while(0);if((v|0)==0){i=d;return x|0}IZ(b)|0;i=d;return x|0}function JK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;e=i;i=i+8|0;f=e|0;g=b+32|0;h=a+28|0;j=c[(c[h>>2]|0)+(c[g>>2]<<2)>>2]|0;k=a+1196|0;if((c[k>>2]|0)==0){l=(c[a+1192>>2]|0)!=0}else{l=1}m=cEb(88)|0;n=m;if((m|0)==0){o=-12;i=e;return o|0}p=m;UGb(m|0,b|0,80)|0;c[b+52>>2]=0;c[b>>2]=0;do{if((c[b+36>>2]&8192|0)==0){q=CZ(p)|0;if((q|0)>=0){AZ(p,p)|0;break}ZDb(m);o=q;i=e;return o|0}else{if(!((c[b+28>>2]|0)==-1431655292)){yDb(0,0,2071712,(r=i,i=i+24|0,c[r>>2]=2023848,c[r+8>>2]=1980240,c[r+16>>2]=655,r)|0);i=r;Cd();return 0}if(((c[b+24>>2]|0)+360|0)!=0){break}yDb(0,0,2071712,(r=i,i=i+24|0,c[r>>2]=1950112,c[r+8>>2]=1980240,c[r+16>>2]=656,r)|0);i=r;Cd();return 0}}while(0);if((c[(c[(c[h>>2]|0)+(c[g>>2]<<2)>>2]|0)+244>>2]|0)==0){s=a+1236|0}else{s=(c[j+244>>2]|0)+80|0}do{if(l){r=c[a+1192>>2]|0;c[f>>2]=1;c[f+4>>2]=1e6;p=JDb(r,(r|0)<0|0?-1:0,f,j+40|0,3)|0;r=F;q=c[b+28>>2]|0;t=j+424|0;u=YGb(c[t>>2]|0,c[t+4>>2]|0,q,(q|0)<0|0?-1:0)|0;q=F;c[t>>2]=u;c[t+4>>2]=q;v=c[b+48>>2]|0;w=j+432|0;x=YGb(c[w>>2]|0,c[w+4>>2]|0,v,(v|0)<0|0?-1:0)|0;v=F;c[w>>2]=x;c[w+4>>2]=v;y=c[k>>2]|0;z=(y|0)<0|0?-1:0;if(!((y|0)!=0&((q|0)>(z|0)|(q|0)==(z|0)&u>>>0>y>>>0))){if(!(((p|0)!=0|(r|0)!=0)&(v>>>0>r>>>0|v>>>0==r>>>0&x>>>0>p>>>0))){break}}c[t>>2]=0;c[t+4>>2]=0;t=m+36|0;c[t>>2]=c[t>>2]|4096;if(((p|0)!=0|(r|0)!=0)&(v>>>0>r>>>0|v>>>0==r>>>0&x>>>0>p>>>0)){t=ZGb(0,0,(c[(c[j+8>>2]|0)+8>>2]|0)==0|0,0)|0;y=r&F;u=(p&t)>>>1|y<<31;t=y>>>1|0<<31;y=b+16|0;z=c[y>>2]|0;q=c[y+4>>2]|0;y=YGb(u,t,z,q)|0;A=IDb(y,F,1,0,p,r)|0;y=gHb(A,F,p,r)|0;A=ZGb(z,q,y,F)|0;y=YGb(A,F,u,t)|0;t=eHb(y,F,8,0)|0;y=F;u=ZGb(x,v,p,r)|0;r=YGb(u,F,t,y)|0;c[w>>2]=r;c[w+4>>2]=F;break}else{c[w>>2]=0;c[w+4>>2]=0;break}}}while(0);j=c[s>>2]|0;a:do{if((j|0)==0){B=s;C=a+1240|0;D=35}else{if(l){if((c[m+36>>2]&4096|0)==0){E=s;G=j;break}}k=a+1240|0;if((ze[d&511](a,c[k>>2]|0,b)|0)==0){B=(c[k>>2]|0)+80|0;C=k;D=35;break}f=c[s>>2]|0;if((f|0)==0){B=s;C=k;D=35;break}b:do{if(l){w=s;r=f;while(1){if((c[r+36>>2]&4096|0)==0){H=r}else{y=(ze[d&511](a,r|0,b)|0)==0;t=c[w>>2]|0;if(y){H=t}else{I=w;J=t;break b}}t=H+80|0;y=c[t>>2]|0;if((y|0)==0){B=t;C=k;D=35;break a}else{w=t;r=y}}}else{r=s;w=f;while(1){y=(ze[d&511](a,w|0,b)|0)==0;t=c[r>>2]|0;if(!y){I=r;J=t;break b}y=t+80|0;t=c[y>>2]|0;if((t|0)==0){B=y;C=k;D=35;break a}else{r=y;w=t}}}}while(0);if((J|0)==0){B=I;C=k;D=35}else{E=I;G=J}}}while(0);if((D|0)==35){c[C>>2]=n;E=B;G=c[B>>2]|0}c[m+80>>2]=G;c[E>>2]=n;c[(c[(c[h>>2]|0)+(c[g>>2]<<2)>>2]|0)+244>>2]=n;o=0;i=e;return o|0}function KK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;do{if((d|0)!=0){k=JK(a,d,70)|0;if((k|0)<0){l=k}else{break}i=f;return l|0}}while(0);d=a+24|0;k=c[d>>2]|0;if((k|0)==0){m=0}else{n=c[a+28>>2]|0;o=0;p=0;while(1){q=p+((c[(c[n+(o<<2)>>2]|0)+244>>2]|0)!=0)|0;r=o+1|0;if(r>>>0<k>>>0){o=r;p=q}else{m=q;break}}}p=(c[c[a+1296>>2]>>2]|0)==(m|0)?1:e;e=a+1176|0;o=c[e+4>>2]|0;k=0;do{if((o|0)>(k|0)|(o|0)==(k|0)&(c[e>>2]|0)>>>0>0>>>0){n=c[a+1236>>2]|0;if(!((n|0)!=0&(p|0)==0)){s=p;t=15;break}q=n+16|0;r=c[q>>2]|0;u=c[q+4>>2]|0;q=a+28|0;v=(c[(c[q>>2]|0)+(c[n+32>>2]<<2)>>2]|0)+40|0;c[h>>2]=1;c[h+4>>2]=1e6;n=KDb(r,u,v,h)|0;v=F;u=c[d>>2]|0;if((u|0)==0){break}r=j|0;w=j+4|0;x=0;y=-2147483648;z=0;A=u;while(1){u=c[(c[q>>2]|0)+(x<<2)>>2]|0;B=c[u+244>>2]|0;if((B|0)==0){C=y;D=z;E=A}else{G=B+16|0;B=c[G>>2]|0;H=c[G+4>>2]|0;c[r>>2]=1;c[w>>2]=1e6;G=KDb(B,H,u+40|0,j)|0;u=ZGb(G,F,n,v)|0;G=F;H=(y|0)>(G|0)|(y|0)==(G|0)&z>>>0>u>>>0;C=H?y:G;D=H?z:u;E=c[d>>2]|0}u=x+1|0;if(u>>>0<E>>>0){x=u;y=C;z=D;A=E}else{break}}A=c[e>>2]|0;z=c[e+4>>2]|0;if(!((C|0)>(z|0)|(C|0)==(z|0)&D>>>0>A>>>0)){break}yDb(a,48,1924424,(y=i,i=i+32|0,c[y>>2]=D,c[y+8>>2]=C,c[y+16>>2]=A,c[y+24>>2]=z,y)|0);i=y;s=1;t=15}else{s=p;t=15}}while(0);do{if((t|0)==15){if((m|0)==0|(s|0)==0){break}p=a+1236|0;C=c[p>>2]|0;c[g>>2]=C;UGb(b|0,C|0,80)|0;D=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;e=c[C+80>>2]|0;c[p>>2]=e;if((e|0)==0){c[a+1240>>2]=0}e=D+244|0;if((c[e>>2]|0)==(C|0)){c[e>>2]=0}$Db(g);l=1;i=f;return l|0}}while(0);vZ(b);l=0;i=f;return l|0}function LK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=d+32|0;j=c[a+28>>2]|0;k=c[j+(c[h>>2]<<2)>>2]|0;l=b+32|0;m=c[j+(c[l>>2]<<2)>>2]|0;j=b+16|0;b=m+40|0;n=d+16|0;d=k+40|0;o=LDb(c[j>>2]|0,c[j+4>>2]|0,b,c[n>>2]|0,c[n+4>>2]|0,d)|0;p=a+1188|0;do{if((c[p>>2]|0)==0){q=o}else{a=k+8|0;r=m+8|0;if(!((c[(c[a>>2]|0)+8>>2]|0)==1^(c[(c[r>>2]|0)+8>>2]|0)==1)){q=o;break}s=c[n>>2]|0;t=c[n+4>>2]|0;c[f>>2]=1;c[f+4>>2]=1e6;u=KDb(s,t,d,f)|0;t=c[p>>2]&-((c[(c[a>>2]|0)+8>>2]|0)==1|0);s=ZGb(u,F,t,(t|0)<0|0?-1:0)|0;t=F;u=c[j>>2]|0;v=c[j+4>>2]|0;c[g>>2]=1;c[g+4>>2]=1e6;w=KDb(u,v,b,g)|0;v=c[p>>2]|0;u=(c[(c[r>>2]|0)+8>>2]|0)==1;r=v&-(u&1);x=ZGb(w,F,r,(r|0)<0|0?-1:0)|0;r=F;if((s|0)==(x|0)&(t|0)==(r|0)){w=c[d>>2]|0;y=gHb(c[n>>2]|0,c[n+4>>2]|0,1e6,0)|0;z=gHb(y,F,w,(w|0)<0|0?-1:0)|0;w=F;y=v;A=(v|0)<0|0?-1:0;v=ZGb(0,0,(c[(c[a>>2]|0)+8>>2]|0)==1|0,0)|0;a=c[k+44>>2]|0;B=a;C=(a|0)<0|0?-1:0;a=gHb(y&v,A&F,B,C)|0;v=ZGb(z,w,a,F)|0;a=c[m+44>>2]|0;w=a;z=(a|0)<0|0?-1:0;a=gHb(v,F,w,z)|0;v=F;D=c[b>>2]|0;E=gHb(c[j>>2]|0,c[j+4>>2]|0,1e6,0)|0;G=gHb(E,F,D,(D|0)<0|0?-1:0)|0;D=F;E=ZGb(0,0,u&1,0)|0;u=gHb(w,z,y&E,A&F)|0;A=ZGb(G,D,u,F)|0;u=gHb(A,F,B,C)|0;C=ZGb(a,v,u,F)|0;H=0;I=0;J=F;K=C}else{H=r;I=x;J=t;K=s}q=(((J|0)>(H|0)|(J|0)==(H|0)&K>>>0>I>>>0)&1)-(((J|0)<(H|0)|(J|0)==(H|0)&K>>>0<I>>>0)&1)|0}}while(0);if((q|0)==0){L=(c[h>>2]|0)<(c[l>>2]|0);M=L&1;i=e;return M|0}else{L=(q|0)>0;M=L&1;i=e;return M|0}return 0}function MK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+80|0;e=d|0;a:do{if((b|0)==0){f=1;g=0;h=a+28|0}else{j=c[b+32>>2]|0;do{if((j|0)<0){k=5}else{if(!(j>>>0<(c[a+24>>2]|0)>>>0)){k=5;break}l=a+28|0;m=c[(c[l>>2]|0)+(j<<2)>>2]|0;n=c[(c[m+8>>2]|0)+8>>2]|0;if((n|0)==4){yDb(a,16,2248560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;break}else if((n|0)==1){if((c[b+28>>2]|0)==0){p=0;break}}n=HK(a,m,b)|0;if((n|0)<0){if((c[(c[a+8>>2]|0)+28>>2]&128|0)==0){p=n;break}}n=b+16|0;if(!((c[n>>2]|0)==0&(c[n+4>>2]|0)==(-2147483648|0))){f=0;g=b;h=l;break a}if((c[(c[a+8>>2]|0)+28>>2]&128|0)==0){p=-22}else{f=0;g=b;h=l;break a}}}while(0);if((k|0)==5){yDb(a,16,2263616,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;p=-22}NZ(b);q=p;i=d;return q|0}}while(0);p=a+8|0;b=e+32|0;o=a+16|0;l=g;while(1){g=c[(c[p>>2]|0)+60>>2]|0;do{if((g|0)==0){n=KK(a,e,l,f)|0;if((l|0)==0){r=n}else{s=n;k=18}}else{n=_e[g&1023](a,e,l,f)|0;if((l|0)==0){r=n;break}BZ(l);s=n;k=18}}while(0);if((k|0)==18){k=0;TGb(l|0,0,80)|0;vZ(l);r=s}if((r|0)<1){q=r;k=25;break}t=IK(a,e)|0;if(!((t|0)>-1)){k=21;break}g=(c[(c[h>>2]|0)+(c[b>>2]<<2)>>2]|0)+64|0;j=YGb(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=j;c[g+4>>2]=F;BZ(e);g=c[o>>2]|0;if((g|0)==0){l=0;continue}j=c[g+76>>2]|0;if((j|0)==0){l=0}else{q=j;k=25;break}}if((k|0)==21){BZ(e);q=t;i=d;return q|0}else if((k|0)==25){i=d;return q|0}return 0}function NK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+80|0;d=b|0;e=a+8|0;f=d+32|0;g=a+28|0;h=a+16|0;while(1){j=c[(c[e>>2]|0)+60>>2]|0;if((j|0)==0){k=KK(a,d,0,1)|0}else{k=_e[j&1023](a,d,0,1)|0}if((k|0)<0){l=k;break}if((k|0)==0){m=11;break}n=IK(a,d)|0;if(!((n|0)>-1)){m=8;break}j=(c[(c[g>>2]|0)+(c[f>>2]<<2)>>2]|0)+64|0;o=YGb(c[j>>2]|0,c[j+4>>2]|0,1,0)|0;c[j>>2]=o;c[j+4>>2]=F;BZ(d);j=c[h>>2]|0;if((j|0)==0){continue}if((c[j+76>>2]|0)!=0){l=n;break}}do{if((m|0)==8){BZ(d);l=n}else if((m|0)==11){f=c[(c[e>>2]|0)+56>>2]|0;if((f|0)==0){l=0;break}l=re[f&4095](a)|0}}while(0);m=c[h>>2]|0;if((m|0)!=0){Sy(m)}do{if((l|0)==0){m=c[h>>2]|0;if((m|0)==0){p=0;break}p=c[m+76>>2]|0}else{p=l}}while(0);l=a+24|0;if((c[l>>2]|0)!=0){h=0;do{$Db((c[(c[g>>2]|0)+(h<<2)>>2]|0)+12|0);$Db((c[(c[g>>2]|0)+(h<<2)>>2]|0)+400|0);h=h+1|0;}while(h>>>0<(c[l>>2]|0)>>>0)}l=a+12|0;if((c[(c[e>>2]|0)+36>>2]|0)==0){q=l;$Db(q);i=b;return p|0}HEb(c[l>>2]|0);q=l;$Db(q);i=b;return p|0}function OK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+80|0;g=f|0;UGb(g|0,d|0,80)|0;c[g+32>>2]=b;h=d+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;if(!((j|0)==0&(k|0)==(-2147483648|0))){h=KDb(j,k,(c[(c[e+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+40|0,(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+40|0)|0;k=g+8|0;c[k>>2]=h;c[k+4>>2]=F}k=d+16|0;h=c[k>>2]|0;j=c[k+4>>2]|0;if(!((h|0)==0&(j|0)==(-2147483648|0))){k=KDb(h,j,(c[(c[e+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+40|0,(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+40|0)|0;j=g+16|0;c[j>>2]=k;c[j+4>>2]=F}j=c[d+48>>2]|0;if((j|0)==0){l=GK(a,g)|0;i=f;return l|0}k=KDb(j,(j|0)<0|0?-1:0,(c[(c[e+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+40|0,(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+40|0)|0;c[g+48>>2]=k;l=GK(a,g)|0;i=f;return l|0}function PK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a+8|0;a=c[d>>2]|0;e=c[c[a+32>>2]>>2]|0;do{if((e|0)!=0){f=b+8|0;g=0;h=0;i=-1;j=-1;k=e;l=a;a:while(1){m=k|0;if((c[m>>2]|0)==0){n=h;o=i;p=j;q=l}else{r=h;s=i;t=j;u=m;while(1){m=u+4|0;v=S0a(c[m>>2]|0)|0;w=(v|0)==(S0a(c[(c[f>>2]|0)+52>>2]|0)|0);v=c[u>>2]|0;x=c[(c[f>>2]|0)+48>>2]|0;if(w){if((v|0)==(x|0)){y=1;z=15;break a}else{A=v}}else{A=r}if((v|0)==(x|0)){B=0;C=c[m>>2]|0}else{B=s;C=t}m=u+8|0;if((c[m>>2]|0)==0){break}else{r=A;s=B;t=C;u=m}}n=A;o=B;p=C;q=c[d>>2]|0}u=g+1|0;t=c[(c[q+32>>2]|0)+(u<<2)>>2]|0;if((t|0)==0){break}else{g=u;h=n;i=o;j=p;k=t;l=q}}if((z|0)==15){return y|0}if((n|0)!=0){y=0;return y|0}l=-1;if(!((o|0)>(l|0)|(o|0)==(l|0)&p>>>0>-1>>>0)){break}if((c[(c[b+8>>2]|0)+680>>2]|0)>-1){y=0}else{break}return y|0}}while(0);y=1;return y|0}function QK(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1230393165){e=b+4|0;if(((de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535)>>>0<3>>>0){f=100}else{break}return f|0}}while(0);f=0;return f|0}function RK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;b=i;d=c[a+12>>2]|0;e=a+16|0;f=c[e>>2]|0;Vy(f,4,0)|0;g=tz(f)|0;if((g|0)==2){Vy(f,22,0)|0;h=LT(a,0)|0;if((h|0)==0){j=-12;i=b;return j|0}k=LT(a,0)|0;if((k|0)==0){j=-12;i=b;return j|0}l=k+8|0;c[(c[l>>2]|0)+8>>2]=0;MT(k,64,1,15);m=k+64|0;c[m>>2]=vz(f)|0;c[m+4>>2]=0;n=vz(f)|0;if((n|0)==2){o=c[l>>2]|0;c[o+140>>2]=27;c[o+48>>2]=14;p=o}else if((n|0)==1){o=c[l>>2]|0;c[o+48>>2]=1297498929;p=o}else{DDb(a,2136864,(q=i,i=i+8|0,c[q>>2]=n,q)|0);i=q;p=c[l>>2]|0}c[p+52>>2]=0;p=vz(f)|0;c[(c[l>>2]|0)+120>>2]=p;p=vz(f)|0;c[(c[l>>2]|0)+124>>2]=p;Vy(f,12,0)|0;p=h+8|0;c[(c[p>>2]|0)+8>>2]=1;l=c[m+4>>2]|0;n=h+64|0;c[n>>2]=c[m>>2];c[n+4>>2]=l;l=vz(f)|0;c[(c[p>>2]|0)+412>>2]=l;MT(h,33,1,l);l=vz(f)|0;if((l|0)<1){yDb(a,16,2037576,(q=i,i=i+8|0,c[q>>2]=l,q)|0);i=q;j=-1094995529;i=b;return j|0}n=c[p>>2]|0;c[n+416>>2]=l;o=(l|0)==1;l=n+448|0;c[l>>2]=o?4:3;c[l+4>>2]=o?0:0;o=vz(f)|0;if((o|0)==401){c[(c[p>>2]|0)+48>>2]=65537}else{DDb(a,2071512,(q=i,i=i+8|0,c[q>>2]=o,q)|0);i=q}Vy(f,12,0)|0;o=c[e>>2]|0;l=WDb(129)|0;if((l|0)!=0){n=xz(o,128,l,129)|0;if((n|0)<128){r=128-n|0;Vy(o,r,(r|0)<0|0?-1:0)|0;}CBb(a+1140|0,2023696,l,8)|0}l=c[e>>2]|0;e=WDb(257)|0;if((e|0)!=0){r=xz(l,256,e,257)|0;if((r|0)<256){o=256-r|0;Vy(l,o,(o|0)<0|0?-1:0)|0;}CBb(a+1140|0,1980112,e,8)|0}Vy(f,128,0)|0;e=c[m+4>>2]|0;o=0;if((e|0)>(o|0)|(e|0)==(o|0)&(c[m>>2]|0)>>>0>0>>>0){s=0;t=0;u=0;v=0;w=0}else{j=0;i=b;return j|0}while(1){o=vz(f)|0;e=vz(f)|0;l=vz(f)|0;Vy(f,8,0)|0;jT(h,o,0,u,t,e,0,1)|0;jT(k,e+o|0,0,w,v,l,0,1)|0;l=YGb((e>>>0)/(c[(c[p>>2]|0)+416>>2]<<1>>>0)|0,0,u,t)|0;e=s+1|0;o=e;r=(e|0)<0|0?-1:0;n=c[m+4>>2]|0;if((r|0)<(n|0)|(r|0)==(n|0)&o>>>0<(c[m>>2]|0)>>>0){s=e;t=F;u=l;v=r;w=o}else{j=0;break}}i=b;return j|0}else if((g|0)==0){x=23}do{if((x|0)==23){if((tz(f)|0)!=3){break}Vy(f,4,0)|0;UK(a,0,472);w=d+4|0;v=c[w>>2]|0;if((v|0)>1){DDb(a,1950032,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=-1163346256;i=b;return j|0}do{if((v|0)==0){y=0}else{u=LT(a,0)|0;if((u|0)==0){j=-12;i=b;return j|0}t=u+8|0;c[(c[t>>2]|0)+8>>2]=1;UK(a,u,100);s=c[t>>2]|0;m=c[s+52>>2]|0;p=s+48|0;k=c[p>>2]|0;do{if((m|0)==100&(k|0)==401){if((c[s+792>>2]|0)!=16){z=401;x=31;break}c[p>>2]=65537;A=s}else{z=k;x=31}}while(0);if((x|0)==31){k=c[s+792>>2]|0;DDb(a,1924344,(q=i,i=i+24|0,c[q>>2]=m,c[q+8>>2]=z,c[q+16>>2]=k,q)|0);i=q;k=c[t>>2]|0;c[k+48>>2]=0;A=k}c[A+52>>2]=0;if((c[A+416>>2]|0)>=1){y=u;break}yDb(a,16,1902408,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=-1094995529;i=b;return j|0}}while(0);v=d;k=c[v>>2]|0;if((k|0)>1){DDb(a,1882464,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=-1163346256;i=b;return j|0}do{if((k|0)==0){B=0}else{p=LT(a,0)|0;if((p|0)==0){j=-12;i=b;return j|0}else{c[(c[p+8>>2]|0)+8>>2]=0;UK(a,p,502);B=p;break}}}while(0);do{if((c[w>>2]|0)!=0){k=y+64|0;p=c[k+4>>2]|0;h=0;if(!((p|0)>(h|0)|(p|0)==(h|0)&(c[k>>2]|0)>>>0>0>>>0)){break}h=y+8|0;p=0;o=0;r=0;while(1){l=vz(f)|0;e=vz(f)|0;Vy(f,8,0)|0;jT(y,l,0,r,o,e,0,1)|0;l=c[h>>2]|0;if((c[l+8>>2]|0)==1){C=0;D=(e>>>0)/(c[l+416>>2]<<1>>>0)|0}else{C=0;D=1}l=YGb(D,C,r,o)|0;e=p+1|0;n=(e|0)<0|0?-1:0;E=c[k+4>>2]|0;if((n|0)<(E|0)|(n|0)==(E|0)&e>>>0<(c[k>>2]|0)>>>0){p=e;o=F;r=l}else{break}}}}while(0);if((c[v>>2]|0)==0){j=0;i=b;return j|0}w=B+64|0;r=c[w+4>>2]|0;o=0;if(!((r|0)>(o|0)|(r|0)==(o|0)&(c[w>>2]|0)>>>0>0>>>0)){j=0;i=b;return j|0}o=B+8|0;r=0;p=0;k=0;while(1){h=vz(f)|0;u=vz(f)|0;Vy(f,8,0)|0;jT(B,h,0,k,p,u,0,1)|0;h=c[o>>2]|0;if((c[h+8>>2]|0)==1){G=0;H=(u>>>0)/(c[h+416>>2]<<1>>>0)|0}else{G=0;H=1}h=YGb(H,G,k,p)|0;u=r+1|0;t=(u|0)<0|0?-1:0;m=c[w+4>>2]|0;if((t|0)<(m|0)|(t|0)==(m|0)&u>>>0<(c[w>>2]|0)>>>0){r=u;p=F;k=h}else{j=0;break}}i=b;return j|0}}while(0);DDb(a,2340344,(q=i,i=i+8|0,c[q>>2]=g,q)|0);i=q;j=-1163346256;i=b;return j|0}function SK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=d+12|0;g=c[f>>2]|0;h=c[(c[a+28>>2]|0)+(g<<2)>>2]|0;i=d+16|0;j=c[i+(g<<2)>>2]|0;do{if((j|0)<(c[h+404>>2]|0)){k=c[h+400>>2]|0;l=Ty(e,0,0,1)|0;m=F;n=k+(j*24|0)|0;o=c[n>>2]|0;p=c[n+4>>2]|0;do{if(p>>>0>m>>>0|p>>>0==m>>>0&o>>>0>l>>>0){n=ZGb(o,p,l,m)|0;Vy(e,n,F)|0;}else{if(!(p>>>0<m>>>0|p>>>0==m>>>0&o>>>0<l>>>0)){break}if((c[e+88>>2]|0)==0){q=-5;return q|0}n=Ty(e,o,p,0)|0;r=n;if((r|0)<0){q=r}else{break}return q|0}}while(0);p=TS(e,b,c[k+(j*24|0)+16>>2]>>2)|0;if((p|0)<0){q=p;return q|0}else{c[b+32>>2]=c[f>>2];p=k+(j*24|0)+8|0;o=c[p+4>>2]|0;l=b+8|0;c[l>>2]=c[p>>2];c[l+4>>2]=o;o=b+36|0;c[o>>2]=c[o>>2]|1;o=i+(c[f>>2]<<2)|0;c[o>>2]=(c[o>>2]|0)+1;c[d+8>>2]=0;s=c[f>>2]|0;t=a+24|0;break}}else{o=d+8|0;l=(c[o>>2]|0)+1|0;c[o>>2]=l;o=a+24|0;if(l>>>0<(c[o>>2]|0)>>>0){s=g;t=o;break}else{q=-541478725}return q|0}}while(0);g=s+1|0;c[f>>2]=g;if(g>>>0<(c[t>>2]|0)>>>0){q=0;return q|0}c[f>>2]=0;q=0;return q|0}function TK(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[a+12>>2]|0;if((f&10|0)!=0){h=-38;return h|0}if((c[(c[a+16>>2]|0)+88>>2]|0)==0){h=-5;return h|0}i=oT(c[(c[a+28>>2]|0)+(b<<2)>>2]|0,d,e,f)|0;if((i|0)<0){h=-1;return h|0}f=a+24|0;if((c[f>>2]|0)==0){h=0;return h|0}a=g+16|0;g=0;while(1){c[a+(g<<2)>>2]=i;e=g+1|0;if(e>>>0<(c[f>>2]|0)>>>0){g=e}else{h=0;break}}return h|0}function UK(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+24|0;g=f|0;h=c[b+16>>2]|0;Vy(h,4,0)|0;j=vz(h)|0;Vy(h,4,0)|0;if((j|0)<=0){i=f;return}k=g|0;l=g+16|0;g=b;m=0;do{mz(h,k,16)|0;a[l]=0;n=vz(h)|0;if((_e[e&1023](b,d,k,n)|0)<0){DDb(g,2041024,(o=i,i=i+8|0,c[o>>2]=k,o)|0);i=o;Vy(h,n,(n|0)<0|0?-1:0)|0;}m=m+1|0;}while((m|0)<(j|0));i=f;return}function VK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+16|0;f=b|0;g=b+8|0;h=c[a+12>>2]|0;j=c[a+16>>2]|0;if((QGb(d,2079920)|0)==0){k=e+1|0;l=WDb(k)|0;if((l|0)==0){m=0;n=6}else{o=xz(j,e,l,k)|0;if((o|0)<(e|0)){k=e-o|0;Vy(j,k,(k|0)<0|0?-1:0)|0;}k=xd(l|0,2122400,(p=i,i=i+8|0,c[p>>2]=g,p)|0)|0;i=p;if((k|0)==1){q=l}else{m=l;n=6}}if((n|0)==6){c[g>>2]=0;q=m}ZDb(q);c[h>>2]=c[g>>2];r=0;i=b;return r|0}if((QGb(d,2074976)|0)==0){g=e+1|0;q=WDb(g)|0;if((q|0)==0){s=0;n=13}else{m=xz(j,e,q,g)|0;if((m|0)<(e|0)){g=e-m|0;Vy(j,g,(g|0)<0|0?-1:0)|0;}g=xd(q|0,2122400,(p=i,i=i+8|0,c[p>>2]=f,p)|0)|0;i=p;if((g|0)==1){t=q}else{s=q;n=13}}if((n|0)==13){c[f>>2]=0;t=s}ZDb(t);c[h+4>>2]=c[f>>2];r=0;i=b;return r|0}do{if((QGb(d,2070384)|0)!=0){if((QGb(d,2065872)|0)==0){break}do{if((QGb(d,2061624)|0)!=0){if((QGb(d,2058272)|0)==0){break}if((QGb(d,2048920)|0)==0){break}else{r=-1}i=b;return r|0}}while(0);Vy(j,e,(e|0)<0|0?-1:0)|0;r=0;i=b;return r|0}}while(0);f=e+1|0;h=WDb(f)|0;if((h|0)==0){r=0;i=b;return r|0}t=xz(j,e,h,f)|0;if((t|0)<(e|0)){f=e-t|0;Vy(j,f,(f|0)<0|0?-1:0)|0;}CBb(a+1140|0,d,h,8)|0;r=0;i=b;return r|0}function WK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=c[a+16>>2]|0;if((QGb(d,2317200)|0)==0){o=e+1|0;p=WDb(o)|0;if((p|0)==0){q=0;r=6}else{s=xz(n,e,p,o)|0;if((s|0)<(e|0)){o=e-s|0;Vy(n,o,(o|0)<0|0?-1:0)|0;}o=xd(p|0,2122400,(t=i,i=i+8|0,c[t>>2]=m,t)|0)|0;i=t;if((o|0)==1){u=p}else{q=p;r=6}}if((r|0)==6){c[m>>2]=0;u=q}ZDb(u);u=c[m>>2]|0;m=b+64|0;c[m>>2]=u;c[m+4>>2]=(u|0)<0|0?-1:0;v=0;i=f;return v|0}if((QGb(d,2117416)|0)==0){u=e+1|0;m=WDb(u)|0;if((m|0)==0){w=0;r=13}else{q=xz(n,e,m,u)|0;if((q|0)<(e|0)){u=e-q|0;Vy(n,u,(u|0)<0|0?-1:0)|0;}u=xd(m|0,2122400,(t=i,i=i+8|0,c[t>>2]=l,t)|0)|0;i=t;if((u|0)==1){x=m}else{w=m;r=13}}if((r|0)==13){c[l>>2]=0;x=w}ZDb(x);c[(c[b+8>>2]|0)+48>>2]=c[l>>2];v=0;i=f;return v|0}if((QGb(d,2295480)|0)==0){l=e+1|0;x=WDb(l)|0;if((x|0)==0){y=0;r=20}else{w=xz(n,e,x,l)|0;if((w|0)<(e|0)){l=e-w|0;Vy(n,l,(l|0)<0|0?-1:0)|0;}l=xd(x|0,2122400,(t=i,i=i+8|0,c[t>>2]=k,t)|0)|0;i=t;if((l|0)==1){z=x}else{y=x;r=20}}if((r|0)==20){c[k>>2]=0;z=y}ZDb(z);c[(c[b+8>>2]|0)+52>>2]=c[k>>2];v=0;i=f;return v|0}if((QGb(d,2106064)|0)==0){k=e+1|0;z=WDb(k)|0;if((z|0)==0){v=0;i=f;return v|0}y=xz(n,e,z,k)|0;if((y|0)<(e|0)){k=e-y|0;Vy(n,k,(k|0)<0|0?-1:0)|0;}CBb(a+1140|0,d,z,8)|0;v=0;i=f;return v|0}if((QGb(d,2095544)|0)==0){z=e+1|0;k=WDb(z)|0;if((k|0)==0){A=0;r=32}else{y=xz(n,e,k,z)|0;if((y|0)<(e|0)){z=e-y|0;Vy(n,z,(z|0)<0|0?-1:0)|0;}z=xd(k|0,2122400,(t=i,i=i+8|0,c[t>>2]=j,t)|0)|0;i=t;if((z|0)==1){B=k}else{A=k;r=32}}if((r|0)==32){c[j>>2]=0;B=A}ZDb(B);B=c[j>>2]|0;if((B|0)<1){yDb(a,16,2037576,(t=i,i=i+8|0,c[t>>2]=B,t)|0);i=t;v=-1094995529;i=f;return v|0}else{a=c[b+8>>2]|0;c[a+416>>2]=B;j=(B|0)==1;B=a+448|0;c[B>>2]=j?4:3;c[B+4>>2]=j?0:0;v=0;i=f;return v|0}}if((QGb(d,2090144)|0)==0){j=e+1|0;B=WDb(j)|0;if((B|0)==0){C=0;r=41}else{a=xz(n,e,B,j)|0;if((a|0)<(e|0)){j=e-a|0;Vy(n,j,(j|0)<0|0?-1:0)|0;}j=xd(B|0,2122400,(t=i,i=i+8|0,c[t>>2]=h,t)|0)|0;i=t;if((j|0)==1){D=B}else{C=B;r=41}}if((r|0)==41){c[h>>2]=0;D=C}ZDb(D);D=c[h>>2]|0;c[(c[b+8>>2]|0)+412>>2]=D;MT(b,33,1,D);v=0;i=f;return v|0}if((QGb(d,2085224)|0)!=0){v=-1;i=f;return v|0}d=e+1|0;D=WDb(d)|0;if((D|0)==0){E=0;r=48}else{h=xz(n,e,D,d)|0;if((h|0)<(e|0)){d=e-h|0;Vy(n,d,(d|0)<0|0?-1:0)|0;}d=xd(D|0,2122400,(t=i,i=i+8|0,c[t>>2]=g,t)|0)|0;i=t;if((d|0)==1){F=D}else{E=D;r=48}}if((r|0)==48){c[g>>2]=0;F=E}ZDb(F);c[(c[b+8>>2]|0)+792>>2]=c[g>>2]<<3;v=0;i=f;return v|0}function XK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=c[a+16>>2]|0;if((QGb(d,2317200)|0)==0){o=e+1|0;p=WDb(o)|0;if((p|0)==0){q=0;r=6}else{s=xz(n,e,p,o)|0;if((s|0)<(e|0)){o=e-s|0;Vy(n,o,(o|0)<0|0?-1:0)|0;}o=xd(p|0,2122400,(t=i,i=i+8|0,c[t>>2]=m,t)|0)|0;i=t;if((o|0)==1){u=p}else{q=p;r=6}}if((r|0)==6){c[m>>2]=0;u=q}ZDb(u);u=c[m>>2]|0;m=u;q=(u|0)<0|0?-1:0;u=b+56|0;c[u>>2]=m;c[u+4>>2]=q;u=b+64|0;c[u>>2]=m;c[u+4>>2]=q;v=0;i=f;return v|0}if((QGb(d,2295480)|0)==0){q=e+1|0;u=WDb(q)|0;if((u|0)==0){v=-1094995529;i=f;return v|0}m=xz(n,e,u,q)|0;if((m|0)<(e|0)){q=e-m|0;Vy(n,q,(q|0)<0|0?-1:0)|0;}do{if((QGb(u,2278920)|0)==0){c[(c[b+8>>2]|0)+48>>2]=1297498929}else{if((QGb(u,2263608)|0)==0){q=c[b+8>>2]|0;c[q+140>>2]=29;c[q+48>>2]=14;break}if((QGb(u,2248552)|0)==0){c[(c[b+8>>2]|0)+48>>2]=1397180754;break}if((QGb(u,2235536)|0)==0){c[(c[b+8>>2]|0)+48>>2]=8;break}if((QGb(u,2222448)|0)==0){c[(c[b+8>>2]|0)+48>>2]=1297498930;break}else{DDb(a,2212992,(t=i,i=i+8|0,c[t>>2]=u,t)|0);i=t;break}}}while(0);ZDb(u);v=0;i=f;return v|0}if((QGb(d,2203664)|0)==0){u=e+1|0;q=WDb(u)|0;if((q|0)==0){w=0;x=0}else{m=xz(n,e,q,u)|0;if((m|0)<(e|0)){u=e-m|0;Vy(n,u,(u|0)<0|0?-1:0)|0;}lFb(l,+HBb(q,0),2147483647);u=c[l>>2]|0;m=c[l+4>>2]|0;ZDb(q);w=u;x=m}MT(b,64,x,w);v=0;i=f;return v|0}if((QGb(d,2196192)|0)==0){w=e+1|0;x=WDb(w)|0;if((x|0)==0){y=0;r=35}else{m=xz(n,e,x,w)|0;if((m|0)<(e|0)){w=e-m|0;Vy(n,w,(w|0)<0|0?-1:0)|0;}w=xd(x|0,2122400,(t=i,i=i+8|0,c[t>>2]=k,t)|0)|0;i=t;if((w|0)==1){z=x}else{y=x;r=35}}if((r|0)==35){c[k>>2]=0;z=y}ZDb(z);c[(c[b+8>>2]|0)+124>>2]=c[k>>2];v=0;i=f;return v|0}if((QGb(d,2183160)|0)==0){k=b+80|0;z=e+1|0;y=WDb(z)|0;if((y|0)==0){A=0;B=0;C=0;D=0}else{x=xz(n,e,y,z)|0;if((x|0)<(e|0)){z=e-x|0;Vy(n,z,(z|0)<0|0?-1:0)|0;}lFb(j,+HBb(y,0),2147483647);z=c[j>>2]|0;x=c[j+4>>2]|0;ZDb(y);A=x&0;B=z|0;C=x|0;D=z&0}z=k;c[z>>2]=B|D;c[z+4>>2]=A|C;A=B;iFb(k|0,b+84|0,A,(A|0)<0|0?-1:0,C,(C|0)<0|0?-1:0,2147483647,0)|0;v=0;i=f;return v|0}if((QGb(d,2168464)|0)==0){C=e+1|0;A=WDb(C)|0;if((A|0)==0){E=0;r=48}else{k=xz(n,e,A,C)|0;if((k|0)<(e|0)){C=e-k|0;Vy(n,C,(C|0)<0|0?-1:0)|0;}C=xd(A|0,2122400,(t=i,i=i+8|0,c[t>>2]=h,t)|0)|0;i=t;if((C|0)==1){F=A}else{E=A;r=48}}if((r|0)==48){c[h>>2]=0;F=E}ZDb(F);c[(c[b+8>>2]|0)+120>>2]=c[h>>2];v=0;i=f;return v|0}if((QGb(d,2161e3)|0)==0){h=e+1|0;F=WDb(h)|0;if((F|0)==0){G=0;r=55}else{E=xz(n,e,F,h)|0;if((E|0)<(e|0)){h=e-E|0;Vy(n,h,(h|0)<0|0?-1:0)|0;}h=xd(F|0,2122400,(t=i,i=i+8|0,c[t>>2]=g,t)|0)|0;i=t;if((h|0)==1){H=F}else{G=F;r=55}}if((r|0)==55){c[g>>2]=0;H=G}ZDb(H);if((c[g>>2]|0)!=1101){v=0;i=f;return v|0}g=eEb(2154320)|0;H=b+8|0;c[(c[H>>2]|0)+96>>2]=g;c[(c[H>>2]|0)+100>>2]=9;v=0;i=f;return v|0}do{if((QGb(d,2147176)|0)!=0){if((QGb(d,2140824)|0)==0){break}do{if((QGb(d,2135e3)|0)!=0){if((QGb(d,2128560)|0)==0){break}else{v=-1}i=f;return v|0}}while(0);Vy(n,e,(e|0)<0|0?-1:0)|0;v=0;i=f;return v|0}}while(0);H=e+1|0;g=WDb(H)|0;if((g|0)==0){v=0;i=f;return v|0}b=xz(n,e,g,H)|0;if((b|0)<(e|0)){H=e-b|0;Vy(n,H,(H|0)<0|0?-1:0)|0;}CBb(a+1140|0,d,g,8)|0;v=0;i=f;return v|0}function YK(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=LT(b,0)|0;if((g|0)==0){h=-12;i=d;return h|0}j=LT(b,0)|0;if((j|0)==0){h=-12;i=d;return h|0}k=j+8|0;if((BT(c[k>>2]|0,2)|0)!=0){h=-12;i=d;return h|0}l=lz(f)|0;m=(lz(f)|0)&255;a[c[(c[k>>2]|0)+96>>2]|0]=m;m=(lz(f)|0)&255;a[(c[(c[k>>2]|0)+96>>2]|0)+1|0]=m;m=rz(f)|0;n=rz(f)|0;o=pz(f)|0;c[(c[k>>2]|0)+120>>2]=o;o=pz(f)|0;c[(c[k>>2]|0)+124>>2]=o;lz(f)|0;o=pz(f)|0;p=g+8|0;c[(c[p>>2]|0)+412>>2]=o;o=e+4|0;c[o>>2]=rz(f)|0;lz(f)|0;q=rz(f)|0;pz(f)|0;lz(f)|0;if((m|0)==0){h=-1094995529;i=d;return h|0}if((c[o>>2]|0)==0){h=-1094995529;i=d;return h|0}if((l|0)!=7|q>>>0>213>>>0){yDb(b,16,2136608,(r=i,i=i+16|0,c[r>>2]=l,c[r+8>>2]=q,r)|0);i=r;h=-1094995529;i=d;return h|0}MT(g,64,1,c[(c[p>>2]|0)+412>>2]|0);g=c[p>>2]|0;c[g+8>>2]=1;c[g+48>>2]=65541;c[g+416>>2]=1;q=g+448|0;c[q>>2]=4;c[q+4>>2]=0;c[g+792>>2]=8;c[g+72>>2]=c[g+412>>2]<<3;MT(j,64,n,1e6);n=j+92|0;g=c[j+40>>2]|0;c[n>>2]=c[j+44>>2];c[n+4>>2]=g;g=c[k>>2]|0;c[g+8>>2]=0;c[g+48>>2]=120;k=(ba(c[g+124>>2]|0,c[g+120>>2]|0)|0)<65536;c[e>>2]=k?1064:2646;k=c[o>>2]|0;o=k;g=hHb(o<<10|0>>>22,0<<10|o>>>22,m,0)|0;o=F;n=e+16|0;c[n>>2]=g;c[n+4>>2]=o;n=0;if(o>>>0<n>>>0|o>>>0==n>>>0&g>>>0<513>>>0){yDb(b,16,2071400,(r=i,i=i+16|0,c[r>>2]=k,c[r+8>>2]=m,r)|0);i=r;h=-1094995529;i=d;return h|0}else{r=(c[(c[p>>2]|0)+412>>2]|0)*830|0;p=hHb(r,(r|0)<0|0?-1:0,g,o)|0;r=YGb(p,F,-1,-1)|0;p=gHb(r,F,g,o)|0;o=e+8|0;c[o>>2]=p;c[o+4>>2]=F;c[e+24>>2]=k;h=0;i=d;return h|0}return 0}function ZK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;a=d+28|0;f=c[a>>2]|0;if((f|0)!=0){g=TS(e,b,f)|0;if((g|0)<0){h=g;return h|0}c[b+32>>2]=1;c[a>>2]=0;h=0;return h|0}c[a>>2]=re[c[d>>2]&4095](e)|0;a=d+24|0;g=c[a>>2]|0;if((g|0)==0){h=-5;return h|0}f=d+8|0;i=d+16|0;d=c[i>>2]|0;j=c[i+4>>2]|0;k=YGb(c[f>>2]|0,c[f+4>>2]|0,512,0)|0;l=YGb(k,F,d,j)|0;j=l>>>10|F<<22;l=(j|0)>(g|0)?g:j;j=TS(e,b,l)|0;if((j|0)<0){h=j;return h|0}c[b+32>>2]=0;c[a>>2]=(c[a>>2]|0)-l;a=l<<10;l=ZGb(c[i>>2]|0,c[i+4>>2]|0,a,(a|0)<0|0?-1:0)|0;a=YGb(l,F,c[f>>2]|0,c[f+4>>2]|0)|0;c[f>>2]=a;c[f+4>>2]=F;h=0;return h|0}function _K(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=c[a+4>>2]|0;e=c[a+8>>2]|0;if(e>>>0<14>>>0){f=0;return f|0}a=e-14|0;e=b+a|0;if((a|0)>0){g=b}else{f=0;return f|0}a:while(1){if(((d[g+13|0]|0)+255&242|0)==0){b=g;do{if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==875236870){a=g+4|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=16844034){break}a=g+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=16908557){break}a=g+12|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==513){f=100;h=11;break a}}}while(0);i=g+1|0}else{i=g+10|0}if(i>>>0<e>>>0){g=i}else{f=0;h=11;break}}if((h|0)==11){return f|0}return 0}function $K(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0;e=i;i=i+120|0;f=e|0;g=e+8|0;h=e+32|0;j=e+40|0;k=e+56|0;l=e+88|0;m=b+12|0;n=c[m>>2]|0;o=n+112|0;c[o>>2]=-1;c[o+4>>2]=2147483647;c[n+136>>2]=1;p=b+16|0;q=c[p>>2]|0;a:do{if((Xy(q)|0)==0){r=0;while(1){s=lz(q)|0;if((s|0)==6){t=1}else{u=(s|0)==(d[640952+r|0]|0)?r+1|0:0;if(u>>>0<14>>>0){t=u}else{break}}if((Xy(q)|0)==0){r=t}else{break a}}if((u|0)!=14){break}Ty(c[p>>2]|0,-14,-1,1)|0;r=n+28|0;c[r>>2]=b;s=Ty(c[p>>2]|0,0,0,1)|0;v=n+100|0;c[v>>2]=s;s=k|0;w=c[m>>2]|0;x=c[p>>2]|0;if((c[x+88>>2]|0)==0){y=x}else{z=Wy(x)|0;x=F;A=c[p>>2]|0;B=YGb(z,x,-4,-1)|0;Ty(A,B,F,0)|0;B=vz(c[p>>2]|0)|0;b:do{if(!(B>>>0<33>>>0)){A=B;C=0;D=0;E=(x|0)>(D|0)|(x|0)==(D|0)&z>>>0>2147483647>>>0;D=E?0:x;if(!((C|0)<(D|0)|(C|0)==(D|0)&A>>>0<(E?2147483647:z)>>>0)){break}E=c[p>>2]|0;D=ZGb(z,x,A,C)|0;Ty(E,D,F,0)|0;D=c[p>>2]|0;if((Xy(D)|0)==0){G=0}else{break}while(1){E=lz(D)|0;if((E|0)==6){H=1}else{I=(E|0)==(d[640824+G|0]|0)?G+1|0:0;if(I>>>0<4>>>0){H=I}else{break}}if((Xy(D)|0)==0){G=H}else{break b}}if((I|0)!=4){break}E=Ty(D,0,0,1)|0;C=YGb(E,F,-4,-1)|0;E=k+16|0;c[E>>2]=C;c[E+4>>2]=F;c[k>>2]=875236870;mz(D,k+4|0,12)|0;E=lz(D)|0;C=E;A=(E|0)<0|0?-1:0;c:do{if((C&128|0)==0&(A&0|0)==0){J=A;K=C;L=20}else{M=E&127;do{if(M>>>0>8>>>0){N=-1;O=-1094995529}else{if((M|0)==0){N=0;O=0;break}else{P=0;Q=0;R=M}while(1){S=R-1|0;T=lz(D)|0;U=T|(Q<<8|0>>>24);V=((T|0)<0|0?-1:0)|(P<<8|Q>>>24);if((S|0)==0){J=V;K=U;L=20;break c}else{P=V;Q=U;R=S}}}}while(0);M=k+24|0;c[M>>2]=O;c[M+4>>2]=N;W=N;X=O}}while(0);if((L|0)==20){D=k+24|0;c[D>>2]=K;c[D+4>>2]=J;if((K|0)==(-1|0)&(J|0)==(-1|0)){break}else{W=J;X=K}}if((PGb(s,638312,16)|0)!=0){break}if(!((X|0)==(B-20|0)&(W|0)==0)){break}D=c[p>>2]|0;E=YGb(X,W,-12,-1)|0;Vy(D,E,F)|0;E=Az(c[p>>2]|0)|0;D=w+48|0;c[D>>2]=E;c[D+4>>2]=F}}while(0);B=c[w+100>>2]|0;Ty(c[p>>2]|0,B,(B|0)<0|0?-1:0,0)|0;y=c[p>>2]|0}do{if((Xy(y)|0)==0){B=l+16|0;s=l;x=l+4|0;z=l+24|0;D=l|0;E=n+104|0;C=n+8|0;A=n+108|0;M=n+56|0;S=n+48|0;U=l+13|0;V=l+5|0;T=j|0;Y=n+40|0;Z=n+36|0;_=n+20|0;$=n+24|0;aa=-1;ba=-1;ca=0;da=1;ea=0;fa=0;d:while(1){ga=Ty(c[p>>2]|0,0,0,1)|0;if((ga|0)==(ba|0)&(F|0)==(aa|0)){L=28;break}ga=YGb(da,ca,1,0)|0;ha=F;ia=iHb(0,536870912,da,ca)|0;if((ia|0)==0&(F|0)==0){ia=Ty(c[p>>2]|0,0,0,1)|0;ja=F;ka=ia}else{ja=aa;ka=ba}ia=c[p>>2]|0;e:do{if((Xy(ia)|0)==0){la=0;while(1){ma=lz(ia)|0;if((ma|0)==6){na=1}else{oa=(ma|0)==(d[640824+la|0]|0)?la+1|0:0;if(oa>>>0<4>>>0){na=oa}else{break}}if((Xy(ia)|0)==0){la=na}else{L=42;break e}}if((oa|0)!=4){L=42;break}la=Ty(ia,0,0,1)|0;ma=YGb(la,F,-4,-1)|0;c[B>>2]=ma;c[B+4>>2]=F;c[s>>2]=875236870;mz(ia,x,12)|0;ma=lz(ia)|0;la=ma;pa=(ma|0)<0|0?-1:0;f:do{if((la&128|0)==0&(pa&0|0)==0){qa=pa;ra=la;L=41}else{sa=ma&127;do{if(sa>>>0>8>>>0){ta=-1;ua=-1094995529}else{if((sa|0)==0){ta=0;ua=0;break}else{va=0;wa=0;xa=sa}while(1){ya=xa-1|0;za=lz(ia)|0;Aa=za|(wa<<8|0>>>24);Ba=((za|0)<0|0?-1:0)|(va<<8|wa>>>24);if((ya|0)==0){qa=Ba;ra=Aa;L=41;break f}else{va=Ba;wa=Aa;xa=ya}}}}while(0);c[z>>2]=ua;c[z+4>>2]=ta}}while(0);if((L|0)==41){L=0;c[z>>2]=ra;c[z+4>>2]=qa;if((ra|0)==(-1|0)&(qa|0)==(-1|0)){L=42;break}}do{if((PGb(D,642872,16)|0)!=0){if((PGb(D,641032,12)|0)==0){break}if((PGb(D,642952,12)|0)==0){break}if((PGb(D,637968,13)|0)==0){break}do{if((PGb(D,640952,13)|0)==0){if(!(((a[U]|0)-2&255)>>>0<3>>>0)){Ca=638600;break}ma=c[E>>2]|0;if((ma|0)==0){Ca=638600;break}if((c[A>>2]|0)==0){Ca=638600;break}la=c[v>>2]|0;pa=ma+16|0;ma=YGb(la,(la|0)<0|0?-1:0,c[pa>>2]|0,c[pa+4>>2]|0)|0;pa=F;la=c[o+4>>2]|0;if(!(pa>>>0>la>>>0|pa>>>0==la>>>0&ma>>>0>(c[o>>2]|0)>>>0)){Da=ea;Ea=fa;break d}Ty(c[(c[r>>2]|0)+16>>2]|0,ma,pa,0)|0;c[E>>2]=0;if((c[A>>2]|0)==0){Ca=638600}else{Fa=ea;Ga=fa;break e}}else{Ca=638600}}while(0);while(1){Ha=Ca+16|0;Ia=c[Ha>>2]|0;if((Ia|0)==0){break}if((PGb(D,Ca|0,16)|0)==0){L=76;break}else{Ca=Ca+28|0}}if((L|0)==76){L=0;do{if((a[V]|0)==83){pa=c[Ca+20>>2]|0;ma=c[Ca+24>>2]|0;la=c[(c[r>>2]|0)+16>>2]|0;Ja=(pa|0)!=0;if(Ja){Ka=cEb(pa)|0}else{Ka=n}pa=Ty(la,0,0,1)|0;sa=YGb(c[z>>2]|0,c[z+4>>2]|0,pa,F)|0;pa=F;if((Ka|0)==0){La=-12;L=121;break d}ya=Ty(la,0,0,1)|0;Aa=YGb(ya,F,4,0)|0;ya=F;g:do{if(ya>>>0<pa>>>0|ya>>>0==pa>>>0&Aa>>>0<sa>>>0){if(!Ja){while(1){if((Xy(la)|0)!=0){break g}Ba=tz(la)|0;za=tz(la)|0;Ma=Ty(la,0,0,1)|0;Na=YGb(Ma,F,za,(za|0)<0|0?-1:0)|0;Ma=F;TGb(T|0,0,16)|0;do{if((za|0)==0){yDb(c[r>>2]|0,16,1985760,(Oa=i,i=i+8|0,c[Oa>>2]=Ba,Oa)|0);i=Oa}else{do{if((Ba|0)>32767){Pa=c[Y>>2]|0;if((Pa|0)<=0){break}Qa=c[Z>>2]|0;Ra=0;do{Sa=Ra*18|0;Ta=Qa+Sa|0;if(((de((d[Ta]|d[Ta+1|0]<<8)<<16>>16|0)|0)&65535|0)==(Ba|0)){UGb(T|0,Qa+(Sa+2)|0,16)|0}Ra=Ra+1|0;}while((Ra|0)<(Pa|0))}}while(0);Pa=je[Ia&127](Ka,la,Ba,za,T,-1,-1)|0;if((Pa|0)<0){La=Pa;L=121;break d}Pa=Ty(la,0,0,1)|0;Ra=F;if(Ra>>>0>pa>>>0|Ra>>>0==pa>>>0&Pa>>>0>sa>>>0){Ua=Ba;L=110;break d}Pa=Ty(la,0,0,1)|0;Ra=F;if(Ra>>>0>Ma>>>0|Ra>>>0==Ma>>>0&Pa>>>0>Na>>>0){break}Ty(la,Na,Ma,0)|0;}}while(0);Ma=Ty(la,0,0,1)|0;Na=YGb(Ma,F,4,0)|0;Ma=F;if(!(Ma>>>0<pa>>>0|Ma>>>0==pa>>>0&Na>>>0<sa>>>0)){break g}}}do{if((Xy(la)|0)!=0){break g}Na=tz(la)|0;Ma=tz(la)|0;Ba=Ty(la,0,0,1)|0;za=YGb(Ba,F,Ma,(Ma|0)<0|0?-1:0)|0;Ba=F;TGb(T|0,0,16)|0;do{if((Ma|0)==0){yDb(c[r>>2]|0,16,1985760,(Oa=i,i=i+8|0,c[Oa>>2]=Na,Oa)|0);i=Oa}else{do{if((Na|0)>32767){Pa=c[Y>>2]|0;if((Pa|0)<=0){break}Ra=c[Z>>2]|0;Qa=0;do{Sa=Qa*18|0;Ta=Ra+Sa|0;if(((de((d[Ta]|d[Ta+1|0]<<8)<<16>>16|0)|0)&65535|0)==(Na|0)){UGb(T|0,Ra+(Sa+2)|0,16)|0}Qa=Qa+1|0;}while((Qa|0)<(Pa|0))}}while(0);if((Na|0)==15370){mz(la,Ka,16)|0}else{Pa=je[Ia&127](Ka,la,Na,Ma,T,-1,-1)|0;if((Pa|0)<0){La=Pa;L=121;break d}}Pa=Ty(la,0,0,1)|0;Qa=F;if(Qa>>>0>pa>>>0|Qa>>>0==pa>>>0&Pa>>>0>sa>>>0){Ua=Na;L=110;break d}Pa=Ty(la,0,0,1)|0;Qa=F;if(Qa>>>0>Ba>>>0|Qa>>>0==Ba>>>0&Pa>>>0>za>>>0){break}Ty(la,za,Ba,0)|0;}}while(0);Ba=Ty(la,0,0,1)|0;za=YGb(Ba,F,4,0)|0;Ba=F;}while(Ba>>>0<pa>>>0|Ba>>>0==pa>>>0&za>>>0<sa>>>0)}}while(0);if(!Ja){break}c[Ka+16>>2]=ma;sa=aEb(c[_>>2]|0,(c[$>>2]|0)+1|0,4)|0;pa=sa;if((sa|0)==0){La=-12;L=121;break d}c[_>>2]=pa;sa=c[$>>2]|0;c[pa+(sa<<2)>>2]=Ka;c[$>>2]=sa+1}else{sa=Ty(c[p>>2]|0,0,0,1)|0;pa=c[z>>2]|0;la=YGb(pa,c[z+4>>2]|0,sa,F)|0;sa=F;Aa=je[c[Ha>>2]&127](n,c[p>>2]|0,0,pa,D,c[B>>2]|0,c[B+4>>2]|0)|0;pa=Ty(c[p>>2]|0,0,0,1)|0;ya=F;if(ya>>>0>sa>>>0|ya>>>0==sa>>>0&pa>>>0>la>>>0){L=119;break d}Ty(c[p>>2]|0,la,sa,0)|0;if((Aa|0)<0){La=Aa;L=121;break d}}}while(0);if((c[Ha>>2]|0)!=0){Fa=ea;Ga=fa;break e}}Vy(c[p>>2]|0,c[z>>2]|0,c[z+4>>2]|0)|0;Fa=ea;Ga=fa;break e}}while(0);Aa=c[E>>2]|0;if((Aa|0)==0){L=51;break d}sa=Aa+40|0;do{if((c[sa>>2]|0)==0&(c[sa+4>>2]|0)==0){la=Aa+32|0;pa=c[Aa+80>>2]|0;ya=YGb(pa,(pa|0)<0|0?-1:0,c[la>>2]|0,c[la+4>>2]|0)|0;la=F;pa=c[Aa+56>>2]|0;za=pa;Ba=(pa|0)<0|0?-1:0;pa=fHb(ya,la,za,Ba)|0;Na=F;Ma=Aa+64|0;Pa=c[Ma>>2]|0;Qa=c[Ma+4>>2]|0;Ma=fHb(Pa,Qa,za,Ba)|0;Ra=F;Sa=Aa+72|0;Ta=c[Sa>>2]|0;Va=c[Sa+4>>2]|0;Sa=fHb(Ta,Va,za,Ba)|0;Wa=F;if((c[C>>2]|0)==10){Xa=Ty(c[p>>2]|0,0,0,1)|0;Ya=c[E>>2]|0;Za=Ya+40|0;c[Za>>2]=Xa;c[Za+4>>2]=F;Za=c[z+4>>2]|0;Xa=Ya+48|0;c[Xa>>2]=c[z>>2];c[Xa+4>>2]=Za;_a=Ya;break}else{Ya=(Sa|0)==0&(Wa|0)==0;Za=(Ma|0)==0&(Ra|0)==0;Xa=(pa|0)==0&(Na|0)==0;$a=ZGb(ya,la,pa,Na)|0;Na=YGb($a,F,Pa,Qa)|0;Qa=YGb(Na,F,Xa?0:za,Xa?0:Ba)|0;Xa=ZGb(Qa,F,Ma,Ra)|0;Ra=YGb(Xa,F,Ta,Va)|0;Va=YGb(Ra,F,Za?0:za,Za?0:Ba)|0;Za=ZGb(Va,F,Sa,Wa)|0;Wa=YGb(Za,F,Ya?0:za,Ya?0:Ba)|0;c[sa>>2]=Wa;c[sa+4>>2]=F;_a=Aa;break}}else{_a=Aa}}while(0);Aa=(fa|0)==0&(ea|0)==0;ab=Aa?c[B>>2]|0:fa;bb=Aa?c[B+4>>2]|0:ea;Aa=c[(c[r>>2]|0)+16>>2]|0;if((c[A>>2]|0)!=0){if((_a|0)==0){Da=bb;Ea=ab;break d}sa=c[v>>2]|0;Wa=_a+16|0;Ba=YGb(sa,(sa|0)<0|0?-1:0,c[Wa>>2]|0,c[Wa+4>>2]|0)|0;Wa=F;sa=c[o+4>>2]|0;if(!(Wa>>>0>sa>>>0|Wa>>>0==sa>>>0&Ba>>>0>(c[o>>2]|0)>>>0)){Da=bb;Ea=ab;break d}Ty(Aa,Ba,Wa,0)|0;c[E>>2]=0;Fa=bb;Ga=ab;break}Wa=c[M>>2]|0;Ba=c[M+4>>2]|0;if((Wa|0)==0&(Ba|0)==0){sa=c[S>>2]|0;Ya=c[S+4>>2]|0;if((sa|0)==0&(Ya|0)==0){Da=bb;Ea=ab;break d}else{cb=Ya;db=sa}}else{cb=Ba;db=Wa}Wa=Ty(Aa,0,0,1)|0;c[o>>2]=Wa;c[o+4>>2]=F;if((c[Aa+88>>2]|0)==0){L=63;break d}Wa=c[v>>2]|0;Ba=YGb(Wa,(Wa|0)<0|0?-1:0,db,cb)|0;Wa=Ty(Aa,Ba,F,0)|0;Ba=F;Aa=0;if((Ba|0)<(Aa|0)|(Ba|0)==(Aa|0)&Wa>>>0<0>>>0){Aa=c[r>>2]|0;sa=c[v>>2]|0;Ya=YGb(sa,(sa|0)<0|0?-1:0,db,cb)|0;sa=F;yDb(Aa,16,1913760,(Oa=i,i=i+32|0,c[Oa>>2]=Ya,c[Oa+8>>2]=sa,c[Oa+16>>2]=Wa,c[Oa+24>>2]=Ba,Oa)|0);i=Oa;if((Wa|0)<1){Da=bb;Ea=ab;break d}else{Fa=bb;Ga=ab;break}}else{c[E>>2]=0;c[A>>2]=1;Fa=bb;Ga=ab;break}}else{L=42}}while(0);do{if((L|0)==42){L=0;if((c[A>>2]|0)==0){Fa=ea;Ga=fa;break}ia=c[(c[r>>2]|0)+16>>2]|0;Wa=c[E>>2]|0;if((Wa|0)==0){Da=ea;Ea=fa;break d}Ba=c[v>>2]|0;sa=Wa+16|0;Wa=YGb(Ba,(Ba|0)<0|0?-1:0,c[sa>>2]|0,c[sa+4>>2]|0)|0;sa=F;Ba=c[o+4>>2]|0;if(!(sa>>>0>Ba>>>0|sa>>>0==Ba>>>0&Wa>>>0>(c[o>>2]|0)>>>0)){Da=ea;Ea=fa;break d}Ty(ia,Wa,sa,0)|0;c[E>>2]=0;Fa=ea;Ga=fa}}while(0);if((Xy(c[p>>2]|0)|0)==0){aa=ja;ba=ka;ca=ha;da=ga;ea=Fa;fa=Ga}else{Da=Fa;Ea=Ga;break}}if((L|0)==28){yDb(c[r>>2]|0,16,2235504,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}else if((L|0)==51){yDb(c[r>>2]|0,16,2222344,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}else if((L|0)==63){yDb(c[r>>2]|0,32,1919024,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Da=bb;Ea=ab}else if((L|0)==110){if(Ja){ZDb(Ka)}fa=c[B>>2]|0;ea=c[B+4>>2]|0;yDb(c[r>>2]|0,16,1982304,(Oa=i,i=i+24|0,c[Oa>>2]=Ua,c[Oa+8>>2]=fa,c[Oa+16>>2]=ea,Oa)|0);i=Oa;La=-1094995529;L=121}else if((L|0)==119){ea=c[B+4>>2]|0;yDb(b,16,2212960,(Oa=i,i=i+16|0,c[Oa>>2]=c[B>>2],c[Oa+8>>2]=ea,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}if((L|0)==121){yDb(b,16,2203624,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=La;i=e;return eb|0}if((Ea|0)==0&(Da|0)==0){break}Ty(c[p>>2]|0,Ea,Da,0)|0;ea=n+8|0;h:do{if((c[ea>>2]|0)!=10){fa=n+4|0;da=c[fa>>2]|0;if((da|0)==0){break}ca=n;ba=0;aa=da;while(1){da=c[ca>>2]|0;do{if((c[da+(ba*88|0)+28>>2]|0)==0){fb=aa;gb=ba+1|0}else{if(!(ba>>>0<(aa-1|0)>>>0)){break h}E=ba+1|0;A=da+(E*88|0)+32|0;S=c[A>>2]|0;M=c[A+4>>2]|0;A=da+(ba*88|0)+40|0;z=ZGb(S,M,c[A>>2]|0,c[A+4>>2]|0)|0;A=F;C=da+(ba*88|0)+48|0;c[C>>2]=z;c[C+4>>2]=A;D=0;if(!((A|0)<(D|0)|(A|0)==(D|0)&z>>>0<0>>>0)){fb=aa;gb=E;break}c[C>>2]=0;c[C+4>>2]=0;yDb(c[r>>2]|0,16,1989472,(Oa=i,i=i+24|0,c[Oa>>2]=E,c[Oa+8>>2]=S,c[Oa+16>>2]=M,Oa)|0);i=Oa;fb=c[fa>>2]|0;gb=E}}while(0);if(gb>>>0<fb>>>0){ba=gb;aa=fb}else{break}}}}while(0);B=n+16|0;aa=c[B>>2]|0;i:do{if((aa|0)>0){ba=n+12|0;fa=c[ba>>2]|0;ca=n+24|0;ga=n+20|0;ha=0;j:while(1){da=fa+(ha<<4)|0;k:do{if((da|0)==0){hb=0}else{E=c[ca>>2]|0;if((E|0)<=0){hb=0;break}M=da|0;S=c[ga>>2]|0;C=0;while(1){ib=c[S+(C<<2)>>2]|0;if((PGb(M,ib|0,16)|0)==0){if((c[ib+16>>2]|0)==1){break}}z=C+1|0;if((z|0)<(E|0)){C=z}else{hb=0;break k}}C=ib;if((ib|0)==0){hb=C}else{jb=C;break j}}}while(0);da=ha+1|0;if((da|0)<(aa|0)){ha=da}else{jb=hb;break}}if((jb|0)==0){L=148;break}ha=jb+40|0;l:do{if((c[ha>>2]|0)>0){fa=jb+36|0;da=j|0;C=(a[1171496]|0)==0;E=(a[1171656]|0)==0;M=h|0;S=h+4|0;z=(a[1171256]|0)==0;D=0;m:while(1){A=(c[fa>>2]|0)+(D<<4)|0;n:do{if((A|0)==0){L=156}else{$=c[ca>>2]|0;if(($|0)<=0){L=156;break}_=A|0;T=c[ga>>2]|0;Z=0;while(1){kb=c[T+(Z<<2)>>2]|0;if((PGb(_,kb|0,16)|0)==0){if((c[kb+16>>2]|0)==8){break}}Y=Z+1|0;if((Y|0)<($|0)){Z=Y}else{L=156;break n}}if((kb|0)==0){L=156;break}Z=kb+24|0;o:do{if((Z|0)==0){L=169}else{_=0;do{lb=c[T+(_<<2)>>2]|0;if((PGb(Z,lb|0,16)|0)==0){if((c[lb+16>>2]|0)==4){L=161;break}}_=_+1|0;}while((_|0)<($|0));do{if((L|0)==161){L=0;if((lb|0)==0){break}if((cGb(g,lb+28|0,(c[lb+20>>2]|0)==1|0,c[lb+24>>2]|0,c[r>>2]|0)|0)!=0){break}_=(c[r>>2]|0)+1140|0;CBb(_,2085208,_Fb(g,da,0)|0,0)|0}}while(0);_=c[ca>>2]|0;if((_|0)<=0){L=169;break}ma=c[ga>>2]|0;Y=0;while(1){mb=c[ma+(Y<<2)>>2]|0;if((PGb(Z,mb|0,16)|0)==0){if((c[mb+16>>2]|0)==5){break}}V=Y+1|0;if((V|0)<(_|0)){Y=V}else{L=169;break o}}Y=mb;_=kb+20|0;c[_>>2]=Y;if((mb|0)==0){break}p:do{if((c[mb+40>>2]|0)>0){ma=0;V=Y;q:while(1){U=(c[V+36>>2]|0)+(ma<<4)|0;r:do{if((U|0)==0){nb=V}else{x=c[ca>>2]|0;if((x|0)<=0){nb=V;break}s=U|0;sa=c[ga>>2]|0;Wa=0;while(1){ob=c[sa+(Wa<<2)>>2]|0;if((PGb(s,ob|0,16)|0)==0){if((c[ob+16>>2]|0)==4){break}}ia=Wa+1|0;if((ia|0)<(x|0)){Wa=ia}else{nb=V;break r}}if((ob|0)==0){nb=V;break}if((cGb(g,ob+28|0,(c[ob+20>>2]|0)==1|0,c[ob+24>>2]|0,c[r>>2]|0)|0)==0){break q}nb=c[_>>2]|0}}while(0);U=ma+1|0;if((U|0)<(c[nb+40>>2]|0)){ma=U;V=nb}else{pb=nb;break p}}V=(c[r>>2]|0)+1140|0;CBb(V,2085208,_Fb(g,da,0)|0,0)|0;pb=c[_>>2]|0}else{pb=Y}}while(0);Y=c[pb+40>>2]|0;if((Y|0)<=0){break n}V=c[pb+36>>2]|0;ma=0;U=0;Wa=0;s:while(1){x=V+(Wa<<4)|0;t:do{if((x|0)==0){qb=U;rb=ma;sb=0}else{s=c[ca>>2]|0;if((s|0)<=0){qb=U;rb=ma;sb=0;break}sa=x|0;ia=c[ga>>2]|0;Ba=0;while(1){tb=c[ia+(Ba<<2)>>2]|0;if((PGb(sa,tb|0,16)|0)==0){if((c[tb+16>>2]|0)==3){break}}Ya=Ba+1|0;if((Ya|0)<(s|0)){Ba=Ya}else{qb=U;rb=ma;sb=0;break t}}Ba=tb;if((tb|0)==0){qb=U;rb=ma;sb=Ba;break}sa=c[B>>2]|0;u:do{if((sa|0)>0){Ya=c[ba>>2]|0;Aa=tb+20|0;za=0;v:while(1){Za=Ya+(za<<4)|0;w:do{if((Za|0)!=0){Sa=Za|0;Va=0;while(1){ub=c[ia+(Va<<2)>>2]|0;if((PGb(Sa,ub|0,16)|0)==0){if((c[ub+16>>2]|0)==2){break}}Va=Va+1|0;if((Va|0)>=(s|0)){break w}}if((ub|0)==0){break}if((PGb(ub+20|0,Aa,16)|0)==0){break v}}}while(0);Za=za+1|0;if((Za|0)<(sa|0)){za=Za}else{vb=ma;break u}}vb=ub}else{vb=ma}}while(0);if((vb|0)==0){wb=Ba;xb=0;yb=U;break s}sa=c[vb+40>>2]|0;za=vb+36|0;Aa=tb+72|0;Ya=0;while(1){if((Ya|0)>=(sa|0)){zb=U;break}Za=(c[za>>2]|0)+(Ya<<4)|0;if((Za|0)==0){L=213;break m}Va=Za|0;Za=0;while(1){Ab=c[ia+(Za<<2)>>2]|0;if((PGb(Va,Ab|0,16)|0)==0){if((c[Ab+16>>2]|0)==8){break}}Sa=Za+1|0;if((Sa|0)<(s|0)){Za=Sa}else{L=213;break m}}if((Ab|0)==0){L=213;break m}if((c[Ab+40>>2]|0)==(c[Aa>>2]|0)){zb=Ab;break}else{Ya=Ya+1|0}}if((zb|0)==0){L=216;break s}else{qb=zb;rb=vb;sb=Ba}}}while(0);x=Wa+1|0;if((x|0)<(Y|0)){ma=rb;U=qb;Wa=x}else{wb=sb;xb=rb;yb=qb;break}}if((L|0)==216){L=0;yDb(c[r>>2]|0,16,2070328,(Oa=i,i=i+8|0,c[Oa>>2]=c[kb+40>>2],Oa)|0);i=Oa;break n}if((yb|0)==0|(wb|0)==0){break n}Wa=yb+24|0;if((Wa|0)==0){L=225;break m}U=c[ca>>2]|0;if((U|0)<=0){L=225;break m}ma=Wa|0;Wa=c[ga>>2]|0;Y=0;while(1){Bb=c[Wa+(Y<<2)>>2]|0;if((PGb(ma,Bb|0,16)|0)==0){if((c[Bb+16>>2]|0)==5){break}}V=Y+1|0;if((V|0)<(U|0)){Y=V}else{L=225;break m}}Y=yb+20|0;c[Y>>2]=Bb;if((Bb|0)==0){break m}U=(PGb((c[_>>2]|0)+20|0,Bb+20|0,16)|0)==0;ma=c[r>>2]|0;if(!U){yDb(ma,16,2061576,(Oa=i,i=i+8|0,c[Oa>>2]=c[kb+40>>2],Oa)|0);i=Oa;break n}U=LT(ma,0)|0;if((U|0)==0){L=231;break m}ma=yb+40|0;c[U+4>>2]=c[ma>>2];c[U+12>>2]=yb;Wa=wb+56|0;V=c[Wa>>2]|0;x=c[Wa+4>>2]|0;Wa=U+56|0;c[Wa>>2]=V;c[Wa+4>>2]=x;Ya=yb+72|0;c[Ya>>2]=V;c[Ya+4>>2]=x;if((c[Wa>>2]|0)==(-1|0)&(c[Wa+4>>2]|0)==(-1|0)){c[Wa>>2]=0;c[Wa+4>>2]=-2147483648}x=wb+64|0;Ya=c[x+4>>2]|0;V=U+48|0;c[V>>2]=c[x>>2];c[V+4>>2]=Ya;Ya=kb+48|0;V=Ya;x=c[V>>2]|0;Aa=kb+52|0;s=c[Aa>>2]|0;if((x|0)<1|(s|0)<1){ia=c[U>>2]|0;yDb(c[r>>2]|0,24,2048776,(Oa=i,i=i+24|0,c[Oa>>2]=x,c[Oa+8>>2]=s,c[Oa+16>>2]=ia,Oa)|0);i=Oa;c[V>>2]=25;c[Aa>>2]=1;Cb=1;Db=25}else{Cb=s;Db=x}MT(U,64,Cb,Db);x=Ya;Ya=yb+48|0;s=c[x+4>>2]|0;c[Ya>>2]=c[x>>2];c[Ya+4>>2]=s;s=c[Y>>2]|0;x:do{if(C){Eb=1171496}else{Y=1171496;while(1){Ya=c[Y+16>>2]|0;if((Ya|0)>0){Fb=0}else{Eb=Y;break x}while(1){if((Fb|0)!=7){if((a[Y+Fb|0]|0)!=(a[s+20+Fb|0]|0)){break}}x=Fb+1|0;if((x|0)<(Ya|0)){Fb=x}else{Eb=Y;break x}}Ya=Y+24|0;if((a[Ya|0]|0)==0){Eb=Ya;break}else{Y=Ya}}}}while(0);s=U+8|0;c[(c[s>>2]|0)+8>>2]=c[Eb+20>>2];_=xb+48|0;y:do{if((_|0)==0){L=247}else{Y=c[ca>>2]|0;if((Y|0)<=0){L=247;break}Ya=_|0;Ba=c[ga>>2]|0;x=0;while(1){Gb=c[Ba+(x<<2)>>2]|0;if((PGb(Ya,Gb|0,16)|0)==0){break}ia=x+1|0;if((ia|0)<(Y|0)){x=ia}else{L=247;break y}}x=Gb;Y=xb+44|0;c[Y>>2]=x;if((Gb|0)==0){break}Ya=c[Gb+16>>2]|0;if((Ya|0)==6){if((c[Gb+108>>2]|0)>0){Hb=0;Ib=x}else{break}z:while(1){Ba=(c[Ib+104>>2]|0)+(Hb<<4)|0;A:do{if((Ba|0)==0){L=258}else{ia=c[ca>>2]|0;if((ia|0)<=0){L=258;break}za=Ba|0;sa=c[ga>>2]|0;Za=0;while(1){Jb=c[sa+(Za<<2)>>2]|0;if((PGb(za,Jb|0,16)|0)==0){if((c[Jb+16>>2]|0)==7){break}}Va=Za+1|0;if((Va|0)<(ia|0)){Za=Va}else{L=258;break A}}if((Jb|0)==0){L=258;break}if((c[Jb+112>>2]|0)==(c[ma>>2]|0)){break z}else{Kb=Ib}}}while(0);if((L|0)==258){L=0;yDb(c[r>>2]|0,16,2040976,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Kb=c[Y>>2]|0}Ba=Hb+1|0;if((Ba|0)<(c[Kb+108>>2]|0)){Hb=Ba;Ib=Kb}else{break y}}Lb=Jb}else if((Ya|0)==7){Lb=x}else{break}if((Lb|0)==0){break}Y=Lb+20|0;B:do{if((PGb(Y|0,642888,16)|0)==0){yDb(c[r>>2]|0,32,2034200,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Ba=c[ca>>2]|0;Za=0;while(1){if((Za|0)>=(Ba|0)){Mb=Y;break B}Nb=c[(c[ga>>2]|0)+(Za<<2)>>2]|0;if((c[Nb+16>>2]|0)==9){break}else{Za=Za+1|0}}Mb=Nb+20|0}else{Mb=Y}}while(0);C:do{if(E){Ob=1171656}else{Y=1171656;while(1){x=c[Y+16>>2]|0;if((x|0)>0){Pb=0}else{Ob=Y;break C}while(1){if((Pb|0)!=7){if((a[Y+Pb|0]|0)!=(a[Lb+36+Pb|0]|0)){break}}Ya=Pb+1|0;if((Ya|0)<(x|0)){Pb=Ya}else{Ob=Y;break C}}x=Y+24|0;if((a[x|0]|0)==0){Ob=x;break}else{Y=x}}}}while(0);Y=c[Ob+20>>2]|0;c[(c[s>>2]|0)+48>>2]=Y;x=c[r>>2]|0;Ya=H0a(Y)|0;yDb(x,40,2029984,(Oa=i,i=i+8|0,c[Oa>>2]=Ya,Oa)|0);i=Oa;Ya=0;x=c[r>>2]|0;while(1){yDb(x,40,2026112,(Oa=i,i=i+8|0,c[Oa>>2]=d[Lb+36+Ya|0]|0,Oa)|0);i=Oa;Y=Ya+1|0;if((Y&19|0)==0|(Ya|0)==5){yDb(c[r>>2]|0,40,2022712,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa}Qb=c[r>>2]|0;if((Y|0)<16){Ya=Y;x=Qb}else{break}}yDb(Qb,40,2019280,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;x=c[s>>2]|0;Ya=c[x+8>>2]|0;do{if((Ya|0)==1){Y=0;while(1){if((Y|0)==7){Y=8;continue}if((a[637984+Y|0]|0)!=(a[Mb+Y|0]|0)){Rb=0;L=352;break}Za=Y+1|0;if((Za|0)<14){Y=Za}else{Sb=637984;break}}D:do{if((L|0)==352){while(1){L=0;if((Rb|0)==7){Rb=8;L=352;continue}if((a[638008+Rb|0]|0)!=(a[Mb+Rb|0]|0)){Tb=0;break}Y=Rb+1|0;if((Y|0)<14){Rb=Y;L=352}else{Sb=638008;break D}}while(1){if((Tb|0)==7){Tb=8;continue}if((a[638032+Tb|0]|0)!=(a[Mb+Tb|0]|0)){Ub=0;break}Y=Tb+1|0;if((Y|0)<14){Tb=Y}else{Sb=638032;break D}}while(1){if((Ub|0)==7){Ub=8;continue}if((a[638056+Ub|0]|0)!=(a[Mb+Ub|0]|0)){Sb=638080;break D}Y=Ub+1|0;if((Y|0)<14){Ub=Y}else{Sb=638056;break}}}}while(0);Y=x+48|0;Za=c[Y>>2]|0;if((Za|0)==0){Vb=c[Sb+20>>2]|0;L=327}else if((Za|0)==65543){Za=c[Sb+20>>2]|0;if((Za|0)!=0){Vb=Za;L=327}}if((L|0)==327){L=0;c[Y>>2]=Vb}c[x+416>>2]=c[Lb+84>>2];Y=Lb+88|0;c[x+792>>2]=c[Y>>2];Za=Lb+52|0;Ba=Lb+56|0;ia=c[Ba>>2]|0;if((ia|0)>0){za=Za|0;c[x+412>>2]=(c[za>>2]|0)/(ia|0)|0;MT(U,64,c[Ba>>2]|0,c[za>>2]|0)}else{za=c[U>>2]|0;yDb(c[r>>2]|0,24,1992936,(Oa=i,i=i+24|0,c[Oa>>2]=c[Za>>2],c[Oa+8>>2]=ia,c[Oa+16>>2]=za,Oa)|0);i=Oa;MT(U,64,1,48e3)}za=c[Wa>>2]|0;ia=c[Wa+4>>2]|0;if(!((za|0)==0&(ia|0)==(-2147483648|0))){Za=c[V>>2]|0;c[M>>2]=c[Aa>>2];c[S>>2]=Za;Za=KDb(za,ia,h,U+40|0)|0;c[Wa>>2]=Za;c[Wa+4>>2]=F}Za=c[s>>2]|0;ia=Za+48|0;za=c[ia>>2]|0;if((za|0)==65536){Ba=c[Y>>2]|0;if((Ba-17|0)>>>0<8>>>0){c[ia>>2]=65548;Wb=Za;break}if((Ba|0)!=32){Wb=Za;break}c[ia>>2]=65544;Wb=Za;break}else if((za|0)==65537){Ba=c[Y>>2]|0;if((Ba-17|0)>>>0<8>>>0){c[ia>>2]=65549;Wb=Za;break}if((Ba|0)!=32){Wb=Za;break}c[ia>>2]=65545;Wb=Za;break}else if((za|0)==86016){c[U+236>>2]=1;Wb=Za;break}else{Wb=Za;break}}else if((Ya|0)==0){Za=0;while(1){if((Za|0)==7){Za=8;continue}if((a[640904+Za|0]|0)!=(a[Lb+20+Za|0]|0)){Xb=640928;break}za=Za+1|0;if((za|0)<14){Za=za}else{Xb=640904;break}}if((c[Xb+20>>2]|0)==0){Za=0;while(1){if((Za|0)==7){Za=8;continue}if((a[640832+Za|0]|0)!=(a[Lb+36+Za|0]|0)){Yb=0;L=288;break}za=Za+1|0;if((za|0)<14){Za=za}else{Zb=640832;break}}E:do{if((L|0)==288){while(1){L=0;if((Yb|0)==7){Yb=8;L=288;continue}if((a[640856+Yb|0]|0)!=(a[Lb+36+Yb|0]|0)){Zb=640880;break E}Za=Yb+1|0;if((Za|0)<14){Yb=Za;L=288}else{Zb=640856;break}}}}while(0);_b=(c[Zb+20>>2]|0)!=0|0}else{_b=1}c[yb+56>>2]=_b;Za=0;while(1){if((Za|0)==7){Za=8;continue}if((a[638328+Za|0]|0)!=(a[Mb+Za|0]|0)){$b=0;L=361;break}za=Za+1|0;if((za|0)<14){Za=za}else{ac=638328;break}}F:do{if((L|0)==361){while(1){L=0;if(($b|0)==7){$b=8;L=361;continue}if((a[638352+$b|0]|0)!=(a[Mb+$b|0]|0)){bc=0;break}Za=$b+1|0;if((Za|0)<14){$b=Za;L=361}else{ac=638352;break F}}while(1){if((bc|0)==7){bc=8;continue}if((a[638376+bc|0]|0)!=(a[Mb+bc|0]|0)){ac=638400;break F}Za=bc+1|0;if((Za|0)<14){bc=Za}else{ac=638376;break}}}}while(0);Za=x+48|0;if((c[Za>>2]|0)==0){c[Za>>2]=c[ac+20>>2]}c[x+120>>2]=c[Lb+68>>2];Za=c[Lb+72>>2]|0;c[x+124>>2]=Za;za=c[Lb+76>>2]|0;switch(za|0){case 4:{yDb(c[r>>2]|0,32,2015032,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;break};case 0:{c[x+408>>2]=1;break};case 2:{yDb(c[r>>2]|0,32,2011752,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;break};case 1:{ia=c[Lb+80>>2]|0;if((ia|0)==1){c[x+408>>2]=2;cc=x;dc=Za}else if((ia|0)==2){c[x+408>>2]=3;cc=x;dc=Za}else{DDb(c[r>>2]|0,2003264,(Oa=i,i=i+8|0,c[Oa>>2]=ia,Oa)|0);i=Oa;ia=c[s>>2]|0;cc=ia;dc=c[ia+124>>2]|0}c[cc+124>>2]=dc<<1;break};case 3:{break};default:{yDb(c[r>>2]|0,32,1996136,(Oa=i,i=i+8|0,c[Oa>>2]=za,Oa)|0);i=Oa}}za=c[s>>2]|0;do{if((c[za+48>>2]|0)==14){ia=c[Lb+124>>2]|0;Za=za+140|0;c[Za>>2]=ia;if(!((ia|0)==-1)){break}G:do{if(z){ec=1171256}else{ia=1171256;while(1){Ba=c[ia+16>>2]|0;if((Ba|0)>0){fc=0}else{ec=ia;break G}while(1){if((fc|0)!=7){if((a[ia+fc|0]|0)!=(a[Lb+36+fc|0]|0)){break}}Y=fc+1|0;if((Y|0)<(Ba|0)){fc=Y}else{ec=ia;break G}}Ba=ia+24|0;if((a[Ba|0]|0)==0){ec=Ba;break}else{ia=Ba}}}}while(0);ia=c[ec+20>>2]|0;c[Za>>2]=ia;if(!((ia|0)==-1)){break}if((c[Lb+96>>2]|0)!=2){break}if((c[Lb+100>>2]|0)!=1){break}if((c[Lb+92>>2]|0)!=8){break}c[Za>>2]=17}}while(0);c[U+236>>2]=2;Wb=za}else{Wb=x}}while(0);x=Lb+116|0;do{if((c[x>>2]|0)==0){if((c[Wb+48>>2]|0)!=28){break}Ya=iU(U)|0;if((Ya|0)<0){gc=Ya;break i}}else{Ya=Lb+120|0;if((BT(Wb,c[Ya>>2]|0)|0)!=0){break}UGb(c[(c[s>>2]|0)+96>>2]|0,c[x>>2]|0,c[Ya>>2]|0)|0}}while(0);if((c[(c[s>>2]|0)+8>>2]|0)==2){break n}if(!((d[Mb+15|0]|0)>>>0>1>>>0)){break n}c[U+236>>2]=3;break n}}while(0);if((L|0)==247){L=0;c[xb+44>>2]=0}s=c[U>>2]|0;yDb(c[r>>2]|0,32,2037520,(Oa=i,i=i+16|0,c[Oa>>2]=c[ma>>2],c[Oa+8>>2]=s,Oa)|0);i=Oa;break n}}while(0);if((L|0)==169){L=0;c[kb+20>>2]=0}yDb(c[r>>2]|0,16,2079864,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa}}while(0);if((L|0)==156){L=0;yDb(c[r>>2]|0,16,2090096,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa}D=D+1|0;if((D|0)>=(c[ha>>2]|0)){break l}}if((L|0)==213){yDb(c[r>>2]|0,16,2074928,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-1094995529;break i}else if((L|0)==225){c[yb+20>>2]=0}else if((L|0)==231){yDb(c[r>>2]|0,16,2058240,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-12;break i}yDb(c[r>>2]|0,16,2065816,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-1094995529;break i}}while(0);ha=f;c[f>>2]=0;ba=c[ca>>2]|0;H:do{if((ba|0)>0){D=c[ga>>2]|0;z=0;S=0;do{z=((c[(c[D+(S<<2)>>2]|0)+16>>2]|0)==14)+z|0;S=S+1|0;}while((S|0)<(ba|0));if((z|0)==0){L=396;break}S=dEb(z,4)|0;D=S;do{if((S|0)!=0){M=dEb(z,4)|0;c[f>>2]=M;if((M|0)==0){break}M=c[ca>>2]|0;if((M|0)>0){E=c[ga>>2]|0;C=0;da=0;while(1){fa=c[E+(da<<2)>>2]|0;if((c[fa+16>>2]|0)==14){c[D+(C<<2)>>2]=fa;hc=C+1|0}else{hc=C}fa=da+1|0;if((fa|0)<(M|0)){C=hc;da=fa}else{break}}}if((z|0)>0){ic=-1;jc=-1;kc=-1;lc=0}else{ZDb(S);L=396;break H}while(1){da=(lc|0)==0;C=kc;M=(kc|0)<0|0?-1:0;E=0;fa=-1;A=-1;Z=-1;$=-1;T=0;s=0;while(1){Wa=c[D+(E<<2)>>2]|0;Aa=c[Wa+28>>2]|0;V=c[Wa+24>>2]|0;if(da|(Aa|0)>(ic|0)|(V|0)>(jc|0)){L=384}else{_=Wa+40|0;x=c[_+4>>2]|0;if(x>>>0>M>>>0|x>>>0==M>>>0&(c[_>>2]|0)>>>0>C>>>0){L=384}else{mc=T;nc=s;oc=$;pc=Z;qc=A;rc=fa}}I:do{if((L|0)==384){L=0;_=Wa+40|0;x=c[_>>2]|0;Ya=c[_+4>>2]|0;do{if((fa|0)==-1|(Aa|0)<(A|0)|(V|0)<(Z|0)){sc=x}else{_=$;ia=($|0)<0|0?-1:0;if(Ya>>>0<ia>>>0|Ya>>>0==ia>>>0&x>>>0<_>>>0){sc=x;break}if(!((x|0)==(_|0)&(Ya|0)==(ia|0))){mc=T;nc=s;oc=$;pc=Z;qc=A;rc=fa;break I}ia=Wa+48|0;_=c[ia+4>>2]|0;if(_>>>0>T>>>0|_>>>0==T>>>0&(c[ia>>2]|0)>>>0>s>>>0){sc=x}else{mc=T;nc=s;oc=$;pc=Z;qc=A;rc=fa;break I}}}while(0);x=Wa+48|0;mc=c[x+4>>2]|0;nc=c[x>>2]|0;oc=sc;pc=V;qc=Aa;rc=E}}while(0);Aa=E+1|0;if((Aa|0)<(z|0)){E=Aa;fa=rc;A=qc;Z=pc;$=oc;T=mc;s=nc}else{break}}if((rc|0)==-1){tc=lc;break}s=lc+1|0;c[(c[f>>2]|0)+(lc<<2)>>2]=c[D+(rc<<2)>>2];if((s|0)<(z|0)){ic=qc;jc=pc;kc=oc;lc=s}else{tc=s;break}}ZDb(S);if((tc|0)<1){L=396;break H}s=n+128|0;T=c[f>>2]|0;$=0;J:while(1){do{if(($|0)==0){L=399}else{Z=c[T+($-1<<2)>>2]|0;A=c[T+($<<2)>>2]|0;if((c[Z+24>>2]|0)!=(c[A+24>>2]|0)){L=399;break}if((c[Z+28>>2]|0)!=(c[A+28>>2]|0)){L=401;break J}}}while(0);if((L|0)==399){L=0;c[s>>2]=(c[s>>2]|0)+1}A=$+1|0;if((A|0)<(tc|0)){$=A}else{L=403;break}}K:do{if((L|0)==401){yDb(c[r>>2]|0,16,2154288,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;uc=-1094995529}else if((L|0)==403){$=c[s>>2]|0;do{if($>>>0<53687091>>>0){T=cEb($*40|0)|0;A=T;Z=n+132|0;c[Z>>2]=A;if((T|0)==0){break}T=c[f>>2]|0;fa=0;E=0;while(1){if((fa|0)==0){vc=E}else{vc=((c[(c[T+(fa-1<<2)>>2]|0)+24>>2]|0)!=(c[(c[T+(fa<<2)>>2]|0)+24>>2]|0))+E|0}C=A+(vc*40|0)+28|0;c[C>>2]=(c[C>>2]|0)+1;C=fa+1|0;if((C|0)<(tc|0)){fa=C;E=vc}else{break}}if((c[s>>2]|0)>0){wc=0;xc=0;yc=A}else{uc=0;break K}L:while(1){E=yc+(xc*40|0)+28|0;fa=c[E>>2]|0;if(!(fa>>>0<536870911>>>0)){L=413;break}T=cEb(fa<<2)|0;fa=T;C=yc+(xc*40|0)+32|0;c[C>>2]=fa;if((T|0)==0){break}T=c[f>>2]|0;M=c[T+(wc<<2)>>2]|0;da=M+40|0;Aa=c[da>>2]|0;V=c[da+4>>2]|0;if((Aa|0)==0&(V|0)==0){zc=fa;Ac=T}else{yDb(c[r>>2]|0,24,2134928,(Oa=i,i=i+24|0,c[Oa>>2]=c[M+24>>2],c[Oa+8>>2]=Aa,c[Oa+16>>2]=V,Oa)|0);i=Oa;zc=c[C>>2]|0;Ac=c[f>>2]|0}UGb(zc|0,Ac+(wc<<2)|0,c[E>>2]<<2)|0;V=c[(c[f>>2]|0)+(wc<<2)>>2]|0;Aa=yc+(xc*40|0)|0;c[Aa>>2]=c[V+24>>2];c[yc+(xc*40|0)+4>>2]=c[V+28>>2];V=c[E>>2]|0;M:do{if((V|0)>0){M=c[C>>2]|0;T=yc+(xc*40|0)+8|0;fa=0;while(1){da=c[M+(fa<<2)>>2]|0;if((c[da+68>>2]|0)==0){break}Wa=da+48|0;da=YGb(c[T>>2]|0,0,c[Wa>>2]|0,c[Wa+4>>2]|0)|0;Wa=da;c[T>>2]=Wa;da=fa+1|0;if((da|0)<(V|0)){fa=da}else{Bc=Wa;L=424;break M}}c[T>>2]=0;Cc=V}else{Bc=c[yc+(xc*40|0)+8>>2]|0;L=424}}while(0);do{if((L|0)==424){L=0;fa=yc+(xc*40|0)+8|0;if((Bc|0)<1){Cc=V;break}M=dEb(Bc,8)|0;Dc=yc+(xc*40|0)+24|0;c[Dc>>2]=M;if((M|0)==0){L=443;break L}M=dEb(c[fa>>2]|0,24)|0;za=yc+(xc*40|0)+36|0;c[za>>2]=M;if((M|0)==0){L=443;break L}M=c[fa>>2]|0;if((M|0)>0){Wa=c[Dc>>2]|0;da=0;do{ma=Wa+(da<<3)|0;c[ma>>2]=0;c[ma+4>>2]=-2147483648;da=da+1|0;}while((da|0)<(M|0))}M=c[E>>2]|0;if((M|0)>0){da=-128;Wa=0;T=0;while(1){ma=c[(c[C>>2]|0)+(T<<2)>>2]|0;U=ma+68|0;x=c[U>>2]|0;Ya=ma+48|0;ia=c[Ya>>2]|0;_=(x|0)==(ia<<1|0>>>31|1|0)&(((x|0)<0|0?-1:0)|0)==(c[Ya+4>>2]<<1|ia>>>31|0);ia=_?2:1;Ba=(_<<31>>31)+x|0;N:do{if((Ba|0)>0){x=ma+56|0;_=ma+60|0;Y=da;sa=Wa;Va=0;while(1){Sa=(a[(c[x>>2]|0)+Va|0]|0)/(ia|0)|0;Ra=Sa+sa|0;if((sa|0)>=(c[fa>>2]|0)){break}Ta=sa;Xa=(sa|0)<0|0?-1:0;Ma=c[za>>2]|0;Qa=Ma+(sa*24|0)+8|0;c[Qa>>2]=Ta;c[Qa+4>>2]=Xa;Qa=Ma+(sa*24|0)+16|0;c[Qa>>2]=(c[(c[_>>2]|0)+(Va<<2)>>2]&48|0)==0|c[Qa>>2]&-4;do{if((Ra|0)<0){L=438}else{if((Ra|0)>=(c[fa>>2]|0)){L=438;break}Qa=(c[Dc>>2]|0)+(Ra<<3)|0;c[Qa>>2]=Ta;c[Qa+4>>2]=Xa;Ec=(Y<<24>>24|0)>(Sa|0)?Y:Sa&255}}while(0);if((L|0)==438){L=0;yDb(c[r>>2]|0,16,2105792,(Oa=i,i=i+24|0,c[Oa>>2]=sa,c[Oa+8>>2]=Sa,c[Oa+16>>2]=Ra,Oa)|0);i=Oa;Ec=Y}Xa=Va+ia|0;Ta=sa+1|0;if((Xa|0)<(Ba|0)){Y=Ec;sa=Ta;Va=Xa}else{Fc=Ec;Gc=Ta;break N}}Va=c[Ya>>2]|0;_=c[Ya+4>>2]|0;yDb(c[r>>2]|0,16,2117352,(Oa=i,i=i+24|0,c[Oa>>2]=c[U>>2],c[Oa+8>>2]=Va,c[Oa+16>>2]=_,Oa)|0);i=Oa;Fc=Y;Gc=sa}else{Fc=da;Gc=Wa}}while(0);U=T+1|0;Ya=c[E>>2]|0;if((U|0)<(Ya|0)){da=Fc;Wa=Gc;T=U}else{Hc=Fc;Ic=Ya;break}}}else{Hc=-128;Ic=M}T=-(Hc<<24>>24)|0;Wa=yc+(xc*40|0)+16|0;c[Wa>>2]=T;c[Wa+4>>2]=(T|0)<0|0?-1:0;Cc=Ic}}while(0);E=0;while(1){if((E|0)>=(Cc|0)){break}V=(c[(c[C>>2]|0)+(E<<2)>>2]|0)+48|0;if((c[V>>2]|0)==0&(c[V+4>>2]|0)==0){L=446;break}else{E=E+1|0}}do{if((L|0)==446){L=0;if((Cc|0)>1){yDb(c[r>>2]|0,24,2128472,(Oa=i,i=i+16|0,c[Oa>>2]=c[Aa>>2],c[Oa+8>>2]=E,Oa)|0);i=Oa}V=c[r>>2]|0;if((c[V+24>>2]|0)==0){yDb(V,24,2122384,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;break}else{T=(c[c[V+28>>2]>>2]|0)+56|0;V=c[T+4>>2]|0;Wa=(c[(c[C>>2]|0)+(E<<2)>>2]|0)+48|0;c[Wa>>2]=c[T>>2];c[Wa+4>>2]=V;break}}}while(0);E=xc+1|0;C=c[Z>>2]|0;if((E|0)<(c[s>>2]|0)){wc=(c[C+(xc*40|0)+28>>2]|0)+wc|0;xc=E;yc=C}else{uc=0;break K}}if((L|0)==413){c[yc+(xc*40|0)+32>>2]=0}else if((L|0)==443){$Db(Dc);uc=-12;break K}yDb(c[r>>2]|0,16,2140768,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;uc=-12;break K}else{c[n+132>>2]=0}}while(0);yDb(c[r>>2]|0,16,2147136,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;uc=-12}}while(0);ZDb(c[f>>2]|0);if((uc|0)<0){gc=uc;break i}else{Jc=s;break H}}}while(0);$Db(ha);ZDb(S);L=396}else{L=396}}while(0);if((L|0)==396){yDb(c[r>>2]|0,24,2160976,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Jc=n+128|0}ha=c[Jc>>2]|0;do{if((ha|0)>1){ga=c[c[n+132>>2]>>2]|0;yDb(c[r>>2]|0,32,2182952,(Oa=i,i=i+16|0,c[Oa>>2]=ha,c[Oa+8>>2]=ga,Oa)|0);i=Oa}else{if((ha|0)!=0){break}if((c[ea>>2]|0)!=10){break}yDb(c[r>>2]|0,16,2168416,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-1094995529;break i}}while(0);ha=c[m>>2]|0;if((c[ha+8>>2]|0)!=10){eb=0;i=e;return eb|0}if((c[b+24>>2]|0)!=1){eb=0;i=e;return eb|0}ga=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;if((c[ga+8>>2]|0)!=1){eb=0;i=e;return eb|0}if(!(((c[ga+48>>2]|0)-65536|0)>>>0<16>>>0)){eb=0;i=e;return eb|0}if((c[ha+128>>2]|0)!=1){eb=0;i=e;return eb|0}ga=c[ha+132>>2]|0;if((c[ga+28>>2]|0)!=1){eb=0;i=e;return eb|0}if((c[(c[c[ga+32>>2]>>2]|0)+20>>2]|0)>31){eb=0;i=e;return eb|0}c[ha+136>>2]=1920;eb=0;i=e;return eb|0}else{L=148}}while(0);if((L|0)==148){yDb(c[r>>2]|0,16,2095448,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-1094995529}bL(b)|0;eb=gc;i=e;return eb|0}}while(0);yDb(b,16,2196176,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}}while(0);yDb(b,16,2248504,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}function aL(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;f=i;i=i+88|0;g=f|0;h=f+8|0;j=f+24|0;k=f+40|0;l=f+72|0;m=f+80|0;n=b+12|0;o=c[n>>2]|0;p=o;if((c[o+8>>2]|0)==10){q=c[c[b+28>>2]>>2]|0;r=c[o+132>>2]|0;s=o+124|0;t=c[s>>2]|0;u=t;v=(t|0)<0|0?-1:0;t=q+56|0;w=c[t>>2]|0;y=c[t+4>>2]|0;if(!((v|0)<(y|0)|(v|0)==(y|0)&u>>>0<w>>>0)){z=-541478725;i=f;return z|0}t=c[o+136>>2]|0;A=(t|0)<0|0?-1:0;B=ZGb(w,y,u,v)|0;y=F;w=(A|0)>(y|0)|(A|0)==(y|0)&t>>>0>B>>>0?B:t;t=dL(p,r,u,v,0,l,1)|0;if((t|0)<0){z=t;i=f;return z|0}t=(c[s>>2]|0)+w|0;a:do{if((dL(p,r,t,(t|0)<0|0?-1:0,0,m,0)|0)<0){v=c[r+4>>2]|0;u=c[o+4>>2]|0;b:do{if((u|0)==0){C=113}else{B=c[o>>2]|0;y=0;A=0;D=0;while(1){if((c[B+(y*88|0)+28>>2]|0)==(v|0)){E=B+(y*88|0)+48|0;G=c[E>>2]|0;H=c[E+4>>2]|0;if((G|0)==0&(H|0)==0){C=113;break b}E=B+(y*88|0)+40|0;I=YGb(c[E>>2]|0,c[E+4>>2]|0,G,H)|0;J=F;K=I}else{J=A;K=D}I=y+1|0;if(I>>>0<u>>>0){y=I;A=J;D=K}else{break}}c[m>>2]=K;c[m+4>>2]=J;D=0;if(!((J|0)<(D|0)|(J|0)==(D|0)&K>>>0<1>>>0)){L=J;M=K;break a}}}while(0);if((C|0)==113){c[m>>2]=0;c[m+4>>2]=0}yDb(b,16,1924272,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;z=-1094995529;i=f;return z|0}else{L=c[m+4>>2]|0;M=c[m>>2]|0}}while(0);m=c[l>>2]|0;K=c[l+4>>2]|0;l=ZGb(M,L,m,K)|0;L=l;if((L|0)<1){yDb(b,16,1902392,(N=i,i=i+8|0,c[N>>2]=L,N)|0);i=N;z=-1094995529;i=f;return z|0}l=b+16|0;M=Ty(c[l>>2]|0,m,K,0)|0;K=F;m=0;if((K|0)<(m|0)|(K|0)==(m|0)&M>>>0<0>>>0){z=M;i=f;return z|0}M=TS(c[l>>2]|0,e,L)|0;if((M|0)<0){z=M;i=f;return z|0}c[e+32>>2]=0;M=c[q+8>>2]|0;q=c[M+8>>2]|0;do{if((q|0)==0){L=c[r+24>>2]|0;if((L|0)==0){break}l=c[s>>2]|0;if(!((l|0)>-1)){break}if((l|0)<(c[r+8>>2]|0)){m=r+16|0;K=YGb(c[m>>2]|0,c[m+4>>2]|0,l,(l|0)<0|0?-1:0)|0;m=e+16|0;c[m>>2]=K;c[m+4>>2]=F;m=L+(l<<3)|0;l=c[m+4>>2]|0;L=e+8|0;c[L>>2]=c[m>>2];c[L+4>>2]=l;break}else{if((q|0)==1){C=127;break}else{break}}}else if((q|0)==1){C=127}}while(0);do{if((C|0)==127){q=(c[(c[c[(c[o+28>>2]|0)+28>>2]>>2]|0)+12>>2]|0)+64|0;r=c[q+4>>2]|0;l=e+8|0;c[l>>2]=c[q>>2];c[l+4>>2]=r;r=M+416|0;if((c[r>>2]|0)<1){z=-22;i=f;return z|0}l=M+48|0;if((u0a(c[l>>2]|0)|0)<1){z=-22;i=f;return z|0}L=c[r>>2]|0;m=u0a(c[l>>2]|0)|0;K=gHb(m,(m|0)<0|0?-1:0,L,(L|0)<0|0?-1:0)|0;L=F;m=0;if((L|0)<(m|0)|(L|0)==(m|0)&K>>>0<8>>>0){z=-22;i=f;return z|0}else{K=c[e+28>>2]|0;m=c[r>>2]|0;r=u0a(c[l>>2]|0)|0;l=gHb(r,(r|0)<0|0?-1:0,m,(m|0)<0|0?-1:0)|0;m=eHb(l,F,8,0)|0;l=eHb(K,(K|0)<0|0?-1:0,m,F)|0;m=YGb(c[q>>2]|0,c[q+4>>2]|0,l,F)|0;c[q>>2]=m;c[q+4>>2]=F;break}}}while(0);c[s>>2]=(c[s>>2]|0)+w;z=0;i=f;return z|0}w=k|0;s=b+16|0;M=k+16|0;q=k;m=k+4|0;l=k+24|0;K=b+24|0;r=b+28|0;L=k+12|0;J=b;t=L;u=c[s>>2]|0;c:do{if((Xy(u)|0)==0){v=u;d:while(1){D=0;while(1){A=lz(v)|0;if((A|0)==6){O=1}else{P=(A|0)==(d[640824+D|0]|0)?D+1|0:0;if(P>>>0<4>>>0){O=P}else{break}}if((Xy(v)|0)==0){D=O}else{break c}}if((P|0)!=4){break c}D=Ty(v,0,0,1)|0;A=YGb(D,F,-4,-1)|0;c[M>>2]=A;c[M+4>>2]=F;c[q>>2]=875236870;mz(v,m,12)|0;A=lz(v)|0;D=A;y=(A|0)<0|0?-1:0;e:do{if((D&128|0)==0&(y&0|0)==0){Q=y;R=D;C=13}else{B=A&127;do{if(B>>>0>8>>>0){S=-1;T=-1094995529}else{if((B|0)==0){S=0;T=0;break}else{U=0;V=0;W=B}while(1){I=W-1|0;H=lz(v)|0;G=H|(V<<8|0>>>24);E=((H|0)<0|0?-1:0)|(U<<8|V>>>24);if((I|0)==0){Q=E;R=G;C=13;break e}else{U=E;V=G;W=I}}}}while(0);c[l>>2]=T;c[l+4>>2]=S;X=S;Y=T}}while(0);if((C|0)==13){C=0;c[l>>2]=R;c[l+4>>2]=Q;if((R|0)==(-1|0)&(Q|0)==(-1|0)){break c}else{X=Q;Y=R}}if((PGb(w,642872,16)|0)==0){C=15;break}if((PGb(w,641032,12)|0)==0){C=56}else{if((PGb(w,642952,12)|0)==0){C=56}else{Z=X;_=Y}}do{if((C|0)==56){C=0;A=c[K>>2]|0;D=0;while(1){if(!(D>>>0<A>>>0)){C=59;break}if((PGb(L,(c[(c[(c[r>>2]|0)+(D<<2)>>2]|0)+12>>2]|0)+44|0,4)|0)==0){$=D;break}else{D=D+1|0}}if((C|0)==59){C=0;$=((A|0)!=1)<<31>>31}if(($|0)<0){D=fe(c[t>>2]|0)|0;yDb(J,16,2340312,(N=i,i=i+8|0,c[N>>2]=D,N)|0);i=N;Z=c[l+4>>2]|0;_=c[l>>2]|0;break}else{D=c[(c[r>>2]|0)+($<<2)>>2]|0;aa=c[D+12>>2]|0;if((c[D+76>>2]|0)==48){Z=X;_=Y;break}else{break d}}}}while(0);Vy(c[s>>2]|0,_,Z)|0;v=c[s>>2]|0;if((Xy(v)|0)!=0){break c}}if((C|0)==15){v=h|0;D=j|0;y=c[n>>2]|0;B=c[s>>2]|0;I=Ty(B,0,0,1)|0;G=YGb(c[l>>2]|0,c[l+4>>2]|0,I,F)|0;I=F;E=y+32|0;do{if((c[E>>2]|0)==0){y=b+1096|0;if((c[y>>2]|0)==0){C=20;break}if((c[b+1100>>2]|0)!=16){C=20;break}H=fAb()|0;c[E>>2]=H;if((H|0)==0){break}hAb(H,c[y>>2]|0,128,1)|0;C=20}else{C=20}}while(0);do{if((C|0)==20){y=lz(B)|0;H=y;ba=(y|0)<0|0?-1:0;do{if((H&128|0)==0&(ba&0|0)==0){ca=ba;da=H}else{ea=y&127;if(ea>>>0>8>>>0){ca=-1;da=-1094995529;break}if((ea|0)==0){ca=0;da=0;break}else{fa=0;ga=0;ha=ea}while(1){ea=ha-1|0;ia=lz(B)|0;ja=ia|(ga<<8|0>>>24);ka=((ia|0)<0|0?-1:0)|(fa<<8|ga>>>24);if((ea|0)==0){ca=ka;da=ja;break}else{fa=ka;ga=ja;ha=ea}}}}while(0);Vy(B,da,ca)|0;y=lz(B)|0;do{if((y&128|0)!=0){H=y&127;if(H>>>0>8>>>0|(H|0)==0){break}else{la=H}do{la=la-1|0;lz(B)|0;}while((la|0)!=0)}}while(0);y=Az(B)|0;H=F;ba=lz(B)|0;do{if((ba&128|0)!=0){A=ba&127;if(A>>>0>8>>>0|(A|0)==0){break}else{ma=A}do{ma=ma-1|0;lz(B)|0;}while((ma|0)!=0)}}while(0);mz(B,w,16)|0;if((PGb(w,641032,12)|0)!=0){break}ba=c[K>>2]|0;A=0;while(1){if(!(A>>>0<ba>>>0)){C=34;break}if((PGb(L,(c[(c[(c[r>>2]|0)+(A<<2)>>2]|0)+12>>2]|0)+44|0,4)|0)==0){na=A;break}else{A=A+1|0}}if((C|0)==34){na=((ba|0)!=1)<<31>>31}if((na|0)<0){break}A=lz(B)|0;do{if((A&128|0)!=0){ea=A&127;if(ea>>>0>8>>>0|(ea|0)==0){break}else{oa=ea}do{oa=oa-1|0;lz(B)|0;}while((oa|0)!=0)}}while(0);A=Az(B)|0;ba=F;if(ba>>>0<H>>>0|ba>>>0==H>>>0&A>>>0<y>>>0){break}ea=lz(B)|0;ja=ea;ka=(ea|0)<0|0?-1:0;if((ja&128|0)==0&(ka&0|0)==0){pa=ka;qa=ja}else{ja=ea&127;if(ja>>>0>8>>>0|(ja|0)==0){break}else{ra=0;sa=0;ta=ja}while(1){ja=ta-1|0;ea=lz(B)|0;ka=ea|(sa<<8|0>>>24);ia=((ea|0)<0|0?-1:0)|(ra<<8|sa>>>24);if((ja|0)==0){pa=ia;qa=ka;break}else{ra=ia;sa=ka;ta=ja}}}ja=0;if((pa|0)<(ja|0)|(pa|0)==(ja|0)&qa>>>0<32>>>0){break}ja=YGb(qa,pa,-32,-1)|0;ka=F;if(ka>>>0<ba>>>0|ka>>>0==ba>>>0&ja>>>0<A>>>0){break}mz(B,v,16)|0;mz(B,D,16)|0;ka=c[E>>2]|0;if((ka|0)!=0){gAb(ka,D,D,1,v,1)}if((PGb(D,642904,16)|0)!=0){yDb(J,16,2263568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N}ka=TS(B,e,ja)|0;ja=ka;ia=(ka|0)<0|0?-1:0;if((ka|0)<0|(ia>>>0<H>>>0|ia>>>0==H>>>0&ja>>>0<y>>>0)){break}ka=c[E>>2]|0;if((ka|0)!=0){ea=ZGb(ja,ia,y,H)|0;ia=(c[e+24>>2]|0)+y|0;gAb(ka,ia,ia,ea>>>4|F<<28,v,1)}yZ(e,A);c[e+32>>2]=na;ea=Ty(B,0,0,1)|0;ia=ZGb(G,I,ea,F)|0;Vy(B,ia,F)|0;z=0;i=f;return z|0}}while(0);yDb(J,16,1882432,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;z=-1094995529;i=f;return z|0}B=Ty(c[s>>2]|0,0,0,1)|0;I=YGb(c[l>>2]|0,c[l+4>>2]|0,B,F)|0;B=F;G=c[M>>2]|0;v=c[M+4>>2]|0;c[g>>2]=-1;c[g+4>>2]=-1;E=o+132|0;D=c[E>>2]|0;ia=o+128|0;f:do{if((c[ia>>2]|0)<1){ua=0}else{ea=o+124|0;ka=c[ea>>2]|0;g:do{if((ka|0)>-1){ja=-1;va=-1;wa=ka;while(1){xa=wa+1|0;if((dL(p,D,xa,(xa|0)<0|0?-1:0,0,g,0)|0)<0){ua=0;break f}xa=c[g>>2]|0;ya=c[g+4>>2]|0;if(!((ya|0)>(ja|0)|(ya|0)==(ja|0)&xa>>>0>va>>>0)){break}za=c[ea>>2]|0;if((ya|0)>(v|0)|(ya|0)==(v|0)&xa>>>0>G>>>0){Aa=za;Ba=ya;Ca=xa;break g}Da=za+1|0;c[ea>>2]=Da;if((Da|0)>-1){ja=ya;va=xa;wa=Da}else{Aa=Da;Ba=ya;Ca=xa;break g}}yDb(c[o+28>>2]|0,16,2278864,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;ua=0;break f}else{Aa=ka;Ba=-1;Ca=-1}}while(0);ka=(Aa|0)<0;ea=ka?-1:Ca;A=ka?-1:Ba;ka=-1;y=(A|0)>(ka|0)|(A|0)==(ka|0)&ea>>>0>-1>>>0;if(!(y&((B|0)>(A|0)|(B|0)==(A|0)&I>>>0>ea>>>0))){ua=y;break}DDb(J,2317048,(N=i,i=i+8|0,c[N>>2]=Aa,N)|0);i=N;y=Ty(c[s>>2]|0,0,0,1)|0;ka=ZGb(ea,A,y,F)|0;c[l>>2]=ka;c[l+4>>2]=F;ua=1}}while(0);h:do{if((a[L]|0)==6){if((a[k+13|0]|0)!=1){C=88;break}if((a[k+14|0]|0)!=16){C=88;break}G=c[(c[r>>2]|0)+($<<2)>>2]|0;v=c[l>>2]|0;D=c[l+4>>2]|0;ka=0;do{if(!((D|0)>(ka|0)|(D|0)==(ka|0)&v>>>0>61444>>>0)){y=TS(c[s>>2]|0,e,v)|0;if((y|0)<0){break}A=e+24|0;ea=c[A>>2]|0;H=ea+y|0;ba=G+8|0;wa=c[ba>>2]|0;va=c[wa+416>>2]|0;if((y-4|0)<(va<<2|0)){Ea=ea;Fa=ea}else{y=ea;ja=ea+4|0;ea=wa;wa=va;while(1){if((wa|0)>0){va=ja;xa=y;ya=0;Da=ea;while(1){za=va+4|0;Ga=va;Ha=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0;if((c[Da+792>>2]|0)==24){a[xa]=Ha>>>4;a[xa+1|0]=Ha>>>12;a[xa+2|0]=Ha>>>20;Ia=xa+3|0}else{Ga=xa;x=Ha>>>12&65535;a[Ga]=x;x=x>>8;a[Ga+1|0]=x;Ia=xa+2|0}Ga=ya+1|0;Ha=c[ba>>2]|0;Ja=c[Ha+416>>2]|0;if((Ga|0)<(Ja|0)){va=za;xa=Ia;ya=Ga;Da=Ha}else{Ka=za;La=Ia;Ma=Ha;Na=Ja;break}}}else{Ka=ja;La=y;Ma=ea;Na=wa}Da=Na<<2;ya=Ka+(32-Da)|0;if((H-ya|0)<(Da|0)){break}else{y=La;ja=ya;ea=Ma;wa=Na}}Ea=La;Fa=c[A>>2]|0}yZ(e,Ea-Fa|0);break h}}while(0);yDb(J,16,2295448,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;z=-1094995529;i=f;return z|0}else{C=88}}while(0);do{if((C|0)==88){G=TS(c[s>>2]|0,e,c[l>>2]|0)|0;if((G|0)<0){z=G}else{break}i=f;return z|0}}while(0);c[e+32>>2]=$;G=c[M+4>>2]|0;v=e+64|0;c[v>>2]=c[M>>2];c[v+4>>2]=G;G=c[(c[(c[r>>2]|0)+($<<2)>>2]|0)+8>>2]|0;v=c[G+8>>2]|0;i:do{if((v|0)!=0|ua^1){if((v|0)!=1){break}ka=(c[(c[(c[(c[o+28>>2]|0)+28>>2]|0)+($<<2)>>2]|0)+12>>2]|0)+64|0;D=c[ka+4>>2]|0;wa=e+8|0;c[wa>>2]=c[ka>>2];c[wa+4>>2]=D;D=G+416|0;if((c[D>>2]|0)<1){z=-22;i=f;return z|0}wa=G+48|0;if((u0a(c[wa>>2]|0)|0)<1){z=-22;i=f;return z|0}ea=c[D>>2]|0;ja=u0a(c[wa>>2]|0)|0;y=gHb(ja,(ja|0)<0|0?-1:0,ea,(ea|0)<0|0?-1:0)|0;ea=F;ja=0;if((ea|0)<(ja|0)|(ea|0)==(ja|0)&y>>>0<8>>>0){z=-22;i=f;return z|0}else{y=c[e+28>>2]|0;ja=c[D>>2]|0;D=u0a(c[wa>>2]|0)|0;wa=gHb(D,(D|0)<0|0?-1:0,ja,(ja|0)<0|0?-1:0)|0;ja=eHb(wa,F,8,0)|0;wa=eHb(y,(y|0)<0|0?-1:0,ja,F)|0;ja=YGb(c[ka>>2]|0,c[ka+4>>2]|0,wa,F)|0;c[ka>>2]=ja;c[ka+4>>2]=F;break}}else{ka=c[E>>2]|0;do{if((c[ia>>2]|0)>0){ja=c[o+124>>2]|0;if((ja|0)>=(c[ka+8>>2]|0)){break}wa=ka+16|0;y=YGb(c[wa>>2]|0,c[wa+4>>2]|0,ja,(ja|0)<0|0?-1:0)|0;wa=e+16|0;c[wa>>2]=y;c[wa+4>>2]=F;wa=(c[ka+24>>2]|0)+(ja<<3)|0;ja=c[wa+4>>2]|0;y=e+8|0;c[y>>2]=c[wa>>2];c[y+4>>2]=ja;break i}}while(0);if((c[aa+56>>2]|0)==0){break}ka=c[o+124>>2]|0;ja=e+8|0;c[ja>>2]=ka;c[ja+4>>2]=(ka|0)<0|0?-1:0}}while(0);Ty(c[s>>2]|0,I,B,0)|0;z=0;i=f;return z|0}}while(0);e=(Xy(c[s>>2]|0)|0)!=0;z=e?-541478725:-1;i=f;return z|0}function bL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;$Db(b+12|0);d=c[a+24>>2]|0;if((d|0)!=0){e=a+28|0;a=0;do{c[(c[(c[e>>2]|0)+(a<<2)>>2]|0)+12>>2]=0;a=a+1|0;}while(a>>>0<d>>>0)}d=b+24|0;a=b+20|0;a:do{if((c[d>>2]|0)>0){e=a;f=0;while(1){g=c[(c[e>>2]|0)+(f<<2)>>2]|0;switch(c[g+16>>2]|0){case 14:{$Db(g+56|0);$Db(g+60|0);$Db(g+64|0);break};case 2:case 1:{$Db(g+36|0);break};case 7:{$Db(g+116|0);break};case 5:{$Db(g+36|0);break};case 6:{$Db(g+104|0);break};default:{}}$Db((c[e>>2]|0)+(f<<2)|0);f=f+1|0;if((f|0)>=(c[d>>2]|0)){break a}}}}while(0);$Db(b);$Db(a);$Db(b+32|0);$Db(b+36|0);a=b+132|0;d=a;f=c[d>>2]|0;if((f|0)==0){$Db(a);return 0}e=b+128|0;if((c[e>>2]|0)>0){h=0;i=f}else{$Db(a);return 0}while(1){$Db(i+(h*40|0)+32|0);$Db((c[d>>2]|0)+(h*40|0)+24|0);$Db((c[d>>2]|0)+(h*40|0)+36|0);f=h+1|0;if((f|0)>=(c[e>>2]|0)){break}h=f;i=c[d>>2]|0}$Db(a);return 0}function cL(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ca=0,da=0.0,ea=0;g=i;i=i+64|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=g+40|0;o=g+48|0;p=g+56|0;c[n>>2]=d;c[n+4>>2]=e;q=a+28|0;r=c[(c[q>>2]|0)+(b<<2)>>2]|0;b=c[a+12>>2]|0;s=b;t=c[r+12>>2]|0;if((c[(c[r+8>>2]|0)+8>>2]|0)==1){u=c[t+48>>2]|0;c[p>>2]=c[t+52>>2];c[p+4>>2]=u;u=KDb(d,e,r+40|0,p)|0;p=F;c[n>>2]=u;c[n+4>>2]=p;v=p;w=u}else{v=e;w=d}do{if((c[b+128>>2]|0)<1){d=c[a+1072>>2]|0;if((d|0)==0){x=-1094995529;i=g;return x|0}e=0;if((v|0)<(e|0)|(v|0)==(e|0)&w>>>0<0>>>0){c[n>>2]=0;c[n+4>>2]=0;y=0;z=0}else{y=v;z=w}e=c[r+40>>2]|0;u=c[r+44>>2]|0;p=IDb(z,y,e,(e|0)<0|0?-1:0,u,(u|0)<0|0?-1:0)|0;u=c[a+16>>2]|0;e=gHb(d,(d|0)<0|0?-1:0,p,F)|0;p=F;d=Ty(u,e>>>3|p<<29,p>>3|((p|0)<0|0?-1:0)<<29,0)|0;p=F;c[o>>2]=d;c[o+4>>2]=p;e=0;if(!((p|0)<(e|0)|(p|0)==(e|0)&d>>>0<0>>>0)){lT(a,r,c[n>>2]|0,c[n+4>>2]|0);c[b+124>>2]=c[n>>2];break}x=d;i=g;return x|0}else{d=c[b+132>>2]|0;e=0;p=(v|0)>(e|0)|(v|0)==(e|0)&w>>>0>0>>>0;e=p?w:0;u=p?v:0;c[n>>2]=e;c[n+4>>2]=u;p=c[d+36>>2]|0;do{if((p|0)==0){A=t+72|0;B=YGb(c[A>>2]|0,c[A+4>>2]|0,-1,-1)|0;A=F;C=(u|0)>(A|0)|(u|0)==(A|0)&e>>>0>B>>>0;D=C?B:e;B=C?A:u;c[n>>2]=D;c[n+4>>2]=B;G=B;H=D}else{D=nT(p,c[d+8>>2]|0,e,u,f)|0;B=D;A=(D|0)<0|0?-1:0;c[n>>2]=B;c[n+4>>2]=A;if((D|0)<0){x=D}else{G=A;H=B;break}i=g;return x|0}}while(0);u=dL(s,d,H,G,n,o,1)|0;if((u|0)<0){x=u;i=g;return x|0}else{lT(a,r,c[n>>2]|0,c[n+4>>2]|0);c[b+124>>2]=c[n>>2];Ty(c[a+16>>2]|0,c[o>>2]|0,c[o+4>>2]|0,0)|0;break}}}while(0);o=a+24|0;a=c[o>>2]|0;if((a|0)==0){x=0;i=g;return x|0}n=b+28|0;r=h|0;G=h+4|0;H=j|0;s=j+4|0;f=b+124|0;b=l|0;t=l+4|0;v=k|0;w=k+4|0;y=0;z=a;while(1){a=c[(c[q>>2]|0)+(y<<2)>>2]|0;u=c[a+12>>2]|0;if((c[(c[a+8>>2]|0)+8>>2]|0)==1){a=c[n>>2]|0;e=c[(c[a+28>>2]|0)+(y<<2)>>2]|0;p=c[e+12>>2]|0;B=c[p+48>>2]|0;A=c[p+52>>2]|0;c[r>>2]=A;c[G>>2]=B;p=c[e+40>>2]|0;D=c[e+44>>2]|0;c[H>>2]=D;c[s>>2]=p;do{if(((D|0)/(p|0)|0|0)==48e3){e=vX(a,h)|0;if((e|0)==0){I=c[H>>2]|0;J=c[r>>2]|0;K=c[G>>2]|0;L=c[s>>2]|0;M=22;break}C=c[e+8>>2]|0;if((C|0)==0){N=0;O=0;R=0}else{S=0;T=0;U=C;do{T=T+U|0;S=S+1|0;U=c[e+8+(S<<2)>>2]|0;}while((U|0)!=0);N=S;O=(T|0)<0|0?-1:0;R=T}U=c[f>>2]|0;V=(U|0)/(N|0)|0;W=gHb(V,(V|0)<0|0?-1:0,R,O)|0;V=F;X=(U|0)%(N|0)|0;if((X|0)<=0){Y=V;Z=W;break}U=YGb(W,V,C,(C|0)<0|0?-1:0)|0;V=F;if((X|0)>1){_=1;$=V;ca=U}else{Y=V;Z=U;break}while(1){U=c[e+8+(_<<2)>>2]|0;V=_+1|0;W=YGb(ca,$,U,(U|0)<0|0?-1:0)|0;U=F;if((V|0)<(X|0)){_=V;$=U;ca=W}else{Y=U;Z=W;break}}}else{I=D;J=A;K=B;L=p;M=22}}while(0);do{if((M|0)==22){M=0;p=(ba(I,J)|0)%(ba(K,L)|0)|0;c[b>>2]=c[f>>2];c[t>>2]=1;jFb(m,j,h);jFb(k,l,m);da=+(c[v>>2]|0)/+(c[w>>2]|0);B=~~+da>>>0;A=(E=+da,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);if((p|0)==0){Y=A;Z=B;break}p=c[r>>2]|0;D=c[G>>2]|0;a=c[H>>2]|0;d=c[s>>2]|0;yDb(c[n>>2]|0,24,2136480,(X=i,i=i+40|0,c[X>>2]=y,c[X+8>>2]=p,c[X+16>>2]=D,c[X+24>>2]=a,c[X+32>>2]=d,X)|0);i=X;Y=A;Z=B}}while(0);B=u+64|0;c[B>>2]=Z;c[B+4>>2]=Y;ea=c[o>>2]|0}else{ea=z}B=y+1|0;if(B>>>0<ea>>>0){y=B;z=ea}else{x=0;break}}i=g;return x|0}function dL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;j=i;k=c[b+28>>2]|0;a:do{if((k|0)>0){l=c[b+32>>2]|0;m=e;n=d;o=0;p=0;q=0;while(1){r=c[l+(o<<2)>>2]|0;s=r+40|0;t=c[s>>2]|0;u=c[s+4>>2]|0;s=m>>>0>u>>>0|m>>>0==u>>>0&n>>>0>t>>>0;v=s?n:t;w=s?m:u;s=r+48|0;x=c[s>>2]|0;y=c[s+4>>2]|0;s=YGb(x,y,t,u)|0;z=F;if(w>>>0<z>>>0|w>>>0==z>>>0&v>>>0<s>>>0){break}s=c[r+20>>2]|0;z=gHb(s,(s|0)<0|0?-1:0,x,y)|0;s=YGb(z,F,q,p)|0;z=o+1|0;if((z|0)<(k|0)){m=w;n=v;o=z;p=F;q=s}else{A=w;B=v;break a}}o=ZGb(v,w,t,u)|0;n=F;m=c[r+20>>2]|0;do{if((m|0)==0){l=c[r+68>>2]|0;if((l|0)==0){yDb(c[a+28>>2]|0,16,2023584,(C=i,i=i+24|0,c[C>>2]=c[b>>2],c[C+8>>2]=t,c[C+16>>2]=u,C)|0);i=C;D=-1094995529;i=j;return D|0}s=l;z=(l|0)<0|0?-1:0;l=_Gb(o|0,n|0,(s|0)==(x<<1|0>>>31|1|0)&(z|0)==(y<<1|x>>>31|0)&1|0)|0;E=F;G=-1;if(((E|0)>(G|0)|(E|0)==(G|0)&l>>>0>-1>>>0)&((E|0)<(z|0)|(E|0)==(z|0)&l>>>0<s>>>0)){s=(c[r+64>>2]|0)+(l<<3)|0;H=c[s+4>>2]|0;I=c[s>>2]|0;break}yDb(c[a+28>>2]|0,16,2071336,(C=i,i=i+24|0,c[C>>2]=c[b>>2],c[C+8>>2]=t,c[C+16>>2]=u,C)|0);i=C;D=-1094995529;i=j;return D|0}else{s=gHb(m,(m|0)<0|0?-1:0,o,n)|0;l=YGb(s,F,q,p)|0;H=F;I=l}}while(0);if((f|0)!=0){c[f>>2]=v;c[f+4>>2]=w}p=c[b+4>>2]|0;q=c[a+4>>2]|0;b:do{if((q|0)!=0){n=c[a>>2]|0;o=0;m=H;l=I;while(1){if((c[n+(o*88|0)+28>>2]|0)==(p|0)){s=n+(o*88|0)+48|0;z=c[s>>2]|0;E=c[s+4>>2]|0;if((m|0)<(E|0)|(m|0)==(E|0)&l>>>0<z>>>0|(z|0)==0&(E|0)==0){break}s=ZGb(l,m,z,E)|0;J=F;K=s}else{J=m;K=l}s=o+1|0;if(s>>>0<q>>>0){o=s;m=J;l=K}else{break b}}s=n+(o*88|0)+40|0;E=YGb(c[s>>2]|0,c[s+4>>2]|0,l,m)|0;c[g>>2]=E;c[g+4>>2]=F;D=0;i=j;return D|0}}while(0);yDb(c[a+28>>2]|0,16,1949960,(C=i,i=i+24|0,c[C>>2]=I,c[C+8>>2]=H,c[C+16>>2]=p,C)|0);i=C;D=-1094995529;i=j;return D|0}else{A=e;B=d}}while(0);if((h|0)==0){D=-1094995529;i=j;return D|0}h=c[b>>2]|0;yDb(c[a+28>>2]|0,16,1980048,(C=i,i=i+24|0,c[C>>2]=B,c[C+8>>2]=A,c[C+16>>2]=h,C)|0);i=C;D=-1094995529;i=j;return D|0}function eL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;h=i;g=vz(b)|0;f=vz(b)|0;if((f|0)!=18){DDb(b,1922296,(j=i,i=i+8|0,c[j>>2]=f,j)|0);i=j;k=-1163346256;i=h;return k|0}if((g|0)>65536){yDb(c[a+28>>2]|0,16,1920768,(j=i,i=i+8|0,c[j>>2]=g,j)|0);i=j;k=-1094995529;i=h;return k|0}j=dEb(g,18)|0;c[a+36>>2]=j;if((j|0)==0){k=-12;i=h;return k|0}c[a+40>>2]=g;mz(b,j,g*18|0)|0;k=0;i=h;return k|0}function fL(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+16|0;l=f|0;m=b;n=b+4|0;o=aEb(c[m>>2]|0,(c[n>>2]|0)+1|0,88)|0;p=o;if((o|0)==0){q=-12;i=f;return q|0}c[m>>2]=p;o=b+120|0;r=c[o>>2]|0;s=r+1|0;if((c[b+108>>2]|0)==0){c[o>>2]=s;t=p+((c[n>>2]|0)*88|0)|0;c[b+104>>2]=t;u=t}else{VGb(p+(s*88|0)|0,p+(r*88|0)|0,((c[n>>2]|0)-r|0)*88|0|0)|0;r=(c[m>>2]|0)+((c[o>>2]|0)*88|0)|0;c[b+104>>2]=r;u=r}TGb(u|0,0,88)|0;c[n>>2]=(c[n>>2]|0)+1;n=Ty(e,0,0,1)|0;r=F;o=ZGb(g,0,j,k)|0;g=YGb(o,F,n,r)|0;c[u+80>>2]=g;g=d[h+13|0]|0;if((g|0)==4){c[u+8>>2]=2;v=1;w=h+14|0}else if((g|0)==3){c[u+8>>2]=1;x=10}else if((g|0)==2){c[u+8>>2]=0;x=10}else{yDb(c[b+28>>2]|0,16,1947416,(y=i,i=i+8|0,c[y>>2]=g,y)|0);i=y;q=-1094995529;i=f;return q|0}if((x|0)==10){g=h+14|0;v=(a[g]&1^1)&255;w=g}c[u>>2]=v;c[u+4>>2]=(d[w]|0)>>>0>2>>>0;Vy(e,4,0)|0;w=u+56|0;c[w>>2]=vz(e)|0;v=Az(e)|0;g=u+32|0;c[g>>2]=v;c[g+4>>2]=F;g=Az(e)|0;v=u+16|0;c[v>>2]=g;c[v+4>>2]=F;g=Az(e)|0;h=F;r=Az(e)|0;n=u+64|0;c[n>>2]=r;c[n+4>>2]=F;n=Az(e)|0;r=u+72|0;c[r>>2]=n;c[r+4>>2]=F;c[u+24>>2]=vz(e)|0;Vy(e,8,0)|0;c[u+28>>2]=vz(e)|0;if((mz(e,l|0,16)|0)!=16){yDb(c[b+28>>2]|0,16,1945632,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;q=-1094995529;i=f;return q|0}u=vz(e)|0;do{if(!((g|0)==0&(h|0)==0)){e=b+56|0;r=c[e>>2]|0;n=c[e+4>>2]|0;if((r|0)==0&(n|0)==0|(r|0)==(g|0)&(n|0)==(h|0)){c[e>>2]=g;c[e+4>>2]=h;break}else{yDb(c[b+28>>2]|0,16,1943832,(y=i,i=i+32|0,c[y>>2]=r,c[y+8>>2]=n,c[y+16>>2]=g,c[y+24>>2]=h,y)|0);i=y;break}}}while(0);h=c[v>>2]|0;g=c[v+4>>2]|0;do{if(!((h|0)==0&(g|0)==0)){v=c[b+100>>2]|0;n=YGb(v,(v|0)<0|0?-1:0,h,g)|0;v=F;if(v>>>0<k>>>0|v>>>0==k>>>0&n>>>0<j>>>0){break}yDb(c[b+28>>2]|0,16,1937768,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;q=-1094995529;i=f;return q|0}}while(0);j=a[l+12|0]|0;a:do{switch(j<<24>>24){case 16:{x=40;break};case 2:{x=26;break};case 1:{k=a[l+13|0]|0;if((k<<24>>24|0)==2){c[b+8>>2]=2;break a}else if((k<<24>>24|0)==1){c[b+8>>2]=1;break a}else if((k<<24>>24|0)==3){c[b+8>>2]=3;break a}else{if((j<<24>>24|0)==16){x=40;break a}else if((j<<24>>24|0)==2){x=26;break a}else if((j<<24>>24|0)==3){x=32;break a}else if((j<<24>>24|0)==64){x=38;break a}else{x=45;break a}}break};case 3:{x=32;break};case 64:{x=38;break};default:{x=45}}}while(0);do{if((x|0)==26){if((a[l+13|0]|0)==1){c[b+8>>2]=4;break}k=a[l+13|0]|0;if((k<<24>>24|0)==3){c[b+8>>2]=6;break}else if((k<<24>>24|0)==2){c[b+8>>2]=5;break}else{if((j<<24>>24|0)==16){x=40;break}else if((j<<24>>24|0)==3){x=32;break}else if((j<<24>>24|0)==64){x=38;break}else{x=45;break}}}}while(0);do{if((x|0)==32){if((a[l+13|0]|0)==1){c[b+8>>2]=7;break}k=a[l+13|0]|0;if((k<<24>>24|0)==3){c[b+8>>2]=9;break}else if((k<<24>>24|0)==2){c[b+8>>2]=8;break}else{if((j<<24>>24|0)==16){x=40;break}else if((j<<24>>24|0)==64){x=38;break}else{x=45;break}}}}while(0);do{if((x|0)==38){if((a[l+13|0]|0)!=1){x=45;break}c[b+8>>2]=11}else if((x|0)==40){if((u|0)==1){c[b+8>>2]=10;break}k=(u|0)!=0;g=b+8|0;if((c[g>>2]|0)==0){yDb(c[b+28>>2]|0,24,1932368,(y=i,i=i+16|0,c[y>>2]=u,c[y+8>>2]=k?1930472:1928728,y)|0);i=y}c[g>>2]=k?1:10}}while(0);if((x|0)==45){x=d[l+13|0]|0;yDb(c[b+28>>2]|0,16,1927024,(y=i,i=i+16|0,c[y>>2]=j&255,c[y+8>>2]=x,y)|0);i=y;c[b+8>>2]=1}x=c[w>>2]|0;if(!((x-1|0)>>>0>1048575>>>0)){q=0;i=f;return q|0}j=b+28|0;yDb(c[j>>2]|0,24,1925288,(y=i,i=i+8|0,c[y>>2]=x,y)|0);i=y;x=(c[b+8>>2]|0)==11?512:1;c[w>>2]=x;yDb(c[j>>2]|0,24,1923976,(y=i,i=i+8|0,c[y>>2]=x,y)|0);i=y;q=0;i=f;return q|0}function gL(a,b,e,f,g,h,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;i=i+72|0;h=j|0;g=j+48|0;k=j+64|0;l=c[a+28>>2]|0;a=g|0;TGb(a|0,0,16)|0;c[k>>2]=0;switch(e|0){case 15365:{mz(b,a,16)|0;e=cEb(37)|0;c[k>>2]=e;if((e|0)==0){m=-12;i=j;return m|0}else{n=0;o=e}while(1){Lb(o|0,3,2026112,(p=i,i=i+8|0,c[p>>2]=d[g+n|0]|0,p)|0)|0;i=p;e=o+2|0;if((n|0)==9|(n|0)==7|(n|0)==5|(n|0)==3){Lb(e|0,2,1949504,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0)|0;i=p;q=o+3|0}else{q=e}e=n+1|0;if(e>>>0<16>>>0){n=e;o=q}else{break}}CBb(l+1140|0,1965744,c[k>>2]|0,8)|0;m=0;i=j;return m|0};case 15368:{if((f|0)<0){m=-22;i=j;return m|0}q=f+1+((f|0)/2|0)|0;o=WDb(q)|0;c[k>>2]=o;if((o|0)==0){m=-12;i=j;return m|0}n=zz(b,f,o,q)|0;if((n|0)<0){$Db(k);m=n;i=j;return m|0}else{CBb(l+1140|0,1958360,c[k>>2]|0,8)|0;m=0;i=j;return m|0}break};case 15364:{if((f|0)<0){m=-22;i=j;return m|0}n=f+1+((f|0)/2|0)|0;q=WDb(n)|0;c[k>>2]=q;if((q|0)==0){m=-12;i=j;return m|0}o=zz(b,f,q,n)|0;if((o|0)<0){$Db(k);m=o;i=j;return m|0}else{CBb(l+1140|0,1972736,c[k>>2]|0,8)|0;m=0;i=j;return m|0}break};case 15366:{o=Az(b)|0;n=F;TGb(h|0,0,44)|0;q=YGb(n>>>16|0<<16,0>>>16|0<<16,-1900,0)|0;c[h+20>>2]=q;q=YGb((n>>>8|0<<24)&255,(0>>>8|0<<24)&0,-1,0)|0;e=q;q=n&255;c[h+8>>2]=(o>>>24|n<<8)&255;c[h+4>>2]=(o>>>16|n<<16)&255;c[h>>2]=(o>>>8|n<<24)&255;c[h+16>>2]=(e|0)>0?e:0;c[h+12>>2]=q>>>0>1>>>0?q:1;q=cEb(32)|0;c[k>>2]=q;if((q|0)==0){m=-12;i=j;return m|0}Ac(q|0,32,1951504,h|0)|0;CBb(l+1140|0,1960232,c[k>>2]|0,8)|0;m=0;i=j;return m|0};case 15361:{if((f|0)<0){m=-22;i=j;return m|0}h=f+1+((f|0)/2|0)|0;q=WDb(h)|0;c[k>>2]=q;if((q|0)==0){m=-12;i=j;return m|0}e=zz(b,f,q,h)|0;if((e|0)<0){$Db(k);m=e;i=j;return m|0}else{CBb(l+1140|0,1976656,c[k>>2]|0,8)|0;m=0;i=j;return m|0}break};case 15362:{if((f|0)<0){m=-22;i=j;return m|0}e=f+1+((f|0)/2|0)|0;h=WDb(e)|0;c[k>>2]=h;if((h|0)==0){m=-12;i=j;return m|0}q=zz(b,f,h,e)|0;if((q|0)<0){$Db(k);m=q;i=j;return m|0}else{CBb(l+1140|0,1974336,c[k>>2]|0,8)|0;m=0;i=j;return m|0}break};case 15370:{mz(b,a,16)|0;q=cEb(37)|0;c[k>>2]=q;if((q|0)==0){m=-12;i=j;return m|0}else{r=0;s=q}while(1){Lb(s|0,3,2026112,(p=i,i=i+8|0,c[p>>2]=d[g+r|0]|0,p)|0)|0;i=p;q=s+2|0;if((r|0)==9|(r|0)==7|(r|0)==5|(r|0)==3){Lb(q|0,2,1949504,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0)|0;i=p;t=s+3|0}else{t=q}q=r+1|0;if(q>>>0<16>>>0){r=q;s=t}else{break}}CBb(l+1140|0,1953696,c[k>>2]|0,8)|0;m=0;i=j;return m|0};case 15369:{mz(b,a,16)|0;a=cEb(37)|0;c[k>>2]=a;if((a|0)==0){m=-12;i=j;return m|0}else{u=0;v=a}while(1){Lb(v|0,3,2026112,(p=i,i=i+8|0,c[p>>2]=d[g+u|0]|0,p)|0)|0;i=p;a=v+2|0;if((u|0)==9|(u|0)==7|(u|0)==5|(u|0)==3){Lb(a|0,2,1949504,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0)|0;i=p;w=v+3|0}else{w=a}a=u+1|0;if(a>>>0<16>>>0){u=a;v=w}else{break}}CBb(l+1140|0,1955968,c[k>>2]|0,8)|0;m=0;i=j;return m|0};default:{m=0;i=j;return m|0}}return 0}function hL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((d|0)!=6401){i=0;return i|0}d=vz(b)|0;h=a+16|0;c[h>>2]=d;g=dEb(d,16)|0;d=a+12|0;c[d>>2]=g;if((g|0)==0){i=-12;return i|0}Vy(b,4,0)|0;mz(b,c[d>>2]|0,c[h>>2]<<4)|0;i=0;return i|0}function iL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((d|0)==18177){mz(b,a+48|0,16)|0;i=0;return i|0}else if((d|0)==17409){Vy(b,16,0)|0;mz(b,a+20|0,16)|0;i=0;return i|0}else if((d|0)==17411){d=vz(b)|0;h=a+40|0;c[h>>2]=d;g=dEb(d,16)|0;d=a+36|0;c[d>>2]=g;if((g|0)==0){i=-12;return i|0}Vy(b,4,0)|0;mz(b,c[d>>2]|0,c[h>>2]<<4)|0;i=0;return i|0}else{i=0;return i|0}return 0}function jL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((d|0)!=17411){i=0;return i|0}d=vz(b)|0;h=a+40|0;c[h>>2]=d;g=dEb(d,16)|0;d=a+36|0;c[d>>2]=g;if((g|0)==0){i=-12;return i|0}Vy(b,4,0)|0;mz(b,c[d>>2]|0,c[h>>2]<<4)|0;i=0;return i|0}function kL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((d|0)==514){h=Az(b)|0;g=a+48|0;c[g>>2]=h;c[g+4>>2]=F;i=0;return i|0}else if((d|0)==513){mz(b,a+20|0,16)|0;i=0;return i|0}else if((d|0)==4097){d=vz(b)|0;g=a+40|0;c[g>>2]=d;h=dEb(d,16)|0;d=a+36|0;c[d>>2]=h;if((h|0)==0){i=-12;return i|0}Vy(b,4,0)|0;mz(b,c[d>>2]|0,c[g>>2]<<4)|0;i=0;return i|0}else{i=0;return i|0}return 0}function lL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;if((d|0)==4609){h=Az(b)|0;g=a+64|0;c[g>>2]=h;c[g+4>>2]=F;return 0}else if((d|0)==4354){c[a+72>>2]=vz(b)|0;return 0}else if((d|0)==4353){Vy(b,16,0)|0;mz(b,a+20|0,16)|0;return 0}else if((d|0)==514){d=Az(b)|0;b=a+56|0;c[b>>2]=d;c[b+4>>2]=F;return 0}else{return 0}return 0}function mL(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;i=i+16|0;h=j|0;k=b+124|0;c[k>>2]=-1;a:do{switch(e|0){case 12812:{c[b+76>>2]=lz(d)|0;l=0;break};case 12818:{c[b+80>>2]=lz(d)|0;l=0;break};case 15617:{c[b+88>>2]=vz(d)|0;l=0;break};case 12292:{mz(d,b+20|0,16)|0;l=0;break};case 12802:{c[b+72>>2]=vz(d)|0;l=0;break};case 13057:{c[b+92>>2]=vz(d)|0;l=0;break};case 15622:{mz(d,b+36|0,16)|0;l=0;break};case 13064:{c[b+100>>2]=vz(d)|0;l=0;break};case 15619:{c[b+52>>2]=vz(d)|0;c[b+56>>2]=vz(d)|0;l=0;break};case 12803:{c[b+68>>2]=vz(d)|0;l=0;break};case 15623:{c[b+84>>2]=vz(d)|0;l=0;break};case 12814:{c[b+60>>2]=vz(d)|0;c[b+64>>2]=vz(d)|0;l=0;break};case 12294:{c[b+112>>2]=vz(d)|0;l=0;break};case 12801:{mz(d,b+36|0,16)|0;l=0;break};case 16129:{m=vz(d)|0;n=b+108|0;c[n>>2]=m;o=dEb(m,16)|0;m=b+104|0;c[m>>2]=o;if((o|0)==0){l=-12;break a}Vy(d,4,0)|0;mz(d,c[m>>2]|0,c[n>>2]<<4)|0;l=0;break};case 13058:{c[b+96>>2]=vz(d)|0;l=0;break};case 13313:{n=h|0;TGb(n|0,0,16)|0;m=0;while(1){o=lz(d)|0;p=lz(d)|0;if((m|0)>=15){break}a[h+m|0]=o;a[h+(m|1)|0]=p;if((o|0)==0){break}else{m=m+2|0}}uX(n,k)|0;l=0;break};default:{if((PGb(g,638104,16)|0)!=0){l=0;break a}m=b+116|0;if((c[m>>2]|0)==0){q=0}else{yDb(0,24,1979344,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;q=c[m>>2]|0}ZDb(q);o=b+120|0;c[o>>2]=0;p=WDb(f)|0;c[m>>2]=p;if((p|0)==0){l=-12;break a}c[o>>2]=f;mz(d,p,f)|0;l=0}}}while(0);i=j;return l|0}function nL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;if((d|0)==19201){c[a+48>>2]=vz(b)|0;c[a+52>>2]=vz(b)|0;return 0}else if((d|0)==18433){c[a+40>>2]=vz(b)|0;return 0}else if((d|0)==18435){mz(b,a+24|0,16)|0;return 0}else if((d|0)==18436){mz(b,a+44|0,4)|0;return 0}else{return 0}return 0}function oL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;if((d|0)==5379){c[a+20>>2]=lz(b)|0;return 0}else if((d|0)==5378){c[a+28>>2]=tz(b)|0;c[a+32>>2]=1;return 0}else if((d|0)==5377){d=Az(b)|0;c[a+24>>2]=d;return 0}else{return 0}return 0}function pL(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;do{if((d|0)==16){if((PGb(e,642920,16)|0)!=0){h=0;break}mz(b,a+20|0,16)|0;h=0}else{h=-1094995529}}while(0);return h|0}function qL(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;switch(e|0){case 16135:{c[b+28>>2]=vz(d)|0;j=0;return j|0};case 16141:{e=b+48|0;c[e>>2]=Az(d)|0;c[e+4>>2]=F;j=0;return j|0};case 16139:{c[b+32>>2]=vz(d)|0;c[b+36>>2]=vz(d)|0;j=0;return j|0};case 16138:{e=b+68|0;c[e>>2]=vz(d)|0;i=vz(d)|0;h=dEb(c[e>>2]|0,1)|0;g=b+56|0;c[g>>2]=h;if((h|0)==0){j=-12;return j|0}h=dEb(c[e>>2]|0,4)|0;f=b+60|0;c[f>>2]=h;if((h|0)==0){j=-12;return j|0}h=dEb(c[e>>2]|0,8)|0;k=b+64|0;c[k>>2]=h;if((h|0)==0){j=-12;return j|0}if((c[e>>2]|0)<=0){j=0;return j|0}h=i-11|0;i=h;l=(h|0)<0|0?-1:0;h=0;while(1){m=(lz(d)|0)&255;a[(c[g>>2]|0)+h|0]=m;lz(d)|0;m=lz(d)|0;c[(c[f>>2]|0)+(h<<2)>>2]=m;m=Az(d)|0;n=(c[k>>2]|0)+(h<<3)|0;c[n>>2]=m;c[n+4>>2]=F;Vy(d,i,l)|0;n=h+1|0;if((n|0)<(c[e>>2]|0)){h=n}else{j=0;break}}return j|0};case 16140:{h=Az(d)|0;e=b+40|0;c[e>>2]=h;c[e+4>>2]=F;j=0;return j|0};case 16133:{c[b+20>>2]=vz(d)|0;j=0;return j|0};case 16134:{c[b+24>>2]=vz(d)|0;j=0;return j|0};default:{j=0;return j|0}}return 0}function rL(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;e=i;i=i+56|0;f=e|0;g=e+8|0;h=e+48|0;j=h;k=i;i=i+8|0;l=k;m=i;i=i+8|0;n=b+12|0;o=c[n>>2]|0;TGb(g|0,0,35)|0;p=b+1140|0;q=BBb(c[p>>2]|0,2196152,0,0)|0;r=b+24|0;if((c[r>>2]|0)==0){s=-1;i=e;return s|0}t=b+28|0;u=l+4|0;v=k;w=o+104|0;y=o+20|0;z=y;A=y;y=o+24|0;B=o+80|0;C=b;D=b+8|0;E=o+108|0;G=o+16|0;H=o+48|0;I=0;J=q;q=0;a:while(1){K=c[(c[t>>2]|0)+(q<<2)>>2]|0;L=cEb(104)|0;if((L|0)==0){s=-12;M=67;break}c[K+12>>2]=L;N=K+8|0;O=c[N>>2]|0;P=c[O+8>>2]|0;Q=(P|0)==0;if((q|0)==0^Q){M=5;break}do{if(Q){R=O+104|0;S=c[R>>2]|0;T=c[R+4>>2]|0;c[k>>2]=S;c[k+4>>2]=T;c[L+76>>2]=8;R=S;c[w>>2]=(((R|0)/2|0)+T|0)/(R|0)|0;R=vX(b,l)|0;if((R|0)==0){M=8;break a}T=R;S=c[T>>2]|0;U=c[T+4>>2]|0;c[z>>2]=S;c[z+4>>2]=U;c[h>>2]=U;c[h+4>>2]=S;MT(K,64,c[A>>2]|0,c[y>>2]|0);do{if((J|0)==0){S=BBb(c[K+88>>2]|0,2196152,0,0)|0;if((S|0)!=0){V=S;M=11;break}W=cGb(B,j,0,0,C)|0;X=0}else{V=J;M=11}}while(0);if((M|0)==11){M=0;W=dGb(B,j,c[V+4>>2]|0,C)|0;X=V}if((W|0)<0){s=W;M=67;break a}S=c[N>>2]|0;U=c[S+72>>2]|0;if((U|0)==0){Y=c[S+540>>2]|0}else{Y=U}U=L+96|0;c[U>>2]=Y;if((c[D>>2]|0)!=1171568){Z=X;_=R;break}do{if((Y|0)==4e7){S=L+56|0;if((c[y>>2]|0)==25){c[S>>2]=7;break}else{c[S>>2]=9;break}}else if((Y|0)==5e7){S=L+56|0;if((c[y>>2]|0)==25){c[S>>2]=3;break}else{c[S>>2]=5;break}}else if((Y|0)==3e7){S=L+56|0;if((c[y>>2]|0)==25){c[S>>2]=11;break}else{c[S>>2]=13;break}}else{M=27;break a}}while(0);c[E>>2]=512;S=c[U>>2]|0;T=c[A>>2]|0;$=gHb(T,(T|0)<0|0?-1:0,S,(S|0)<0|0?-1:0)|0;S=c[y>>2]<<3;T=hHb($,F,S,(S|0)<0|0?-1:0)|0;S=YGb(T,F,532,0)|0;T=ZGb(512,0,S&511,F&0)|0;$=T;T=($>>>0<20>>>0?$+512|0:$&511)+S|0;c[E>>2]=T;S=T+(c[R+8>>2]<<5|24)|0;T=512-(S&511)|0;c[E>>2]=(T>>>0<20>>>0?T+512|0:T&511)+S;Z=X;_=R}else{if((P|0)!=1){Z=J;_=I;break}if((c[O+412>>2]|0)!=48e3){M=31;break a}MT(K,64,1,48e3);if((c[D>>2]|0)!=1171568){a[H]=1;Z=J;_=I;break}if((c[K>>2]|0)!=1){M=34;break a}S=c[(c[N>>2]|0)+48>>2]|0;if(!((S|0)==65536|(S|0)==65548)){yDb(C,16,2140720,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}c[L+56>>2]=(c[(c[(c[c[t>>2]>>2]|0)+12>>2]|0)+56>>2]|0)+1;Z=J;_=I}}while(0);ba=L+56|0;K=c[ba>>2]|0;if((K|0)==0){O=c[(c[N>>2]|0)+48>>2]|0;P=0;while(1){if((P|0)==5){M=42;break a}if((c[640984+(P<<3)>>2]|0)==(O|0)){break}else{P=P+1|0}}O=c[640988+(P<<3)>>2]|0;c[ba>>2]=O;ca=O}else{ca=K}c[L+60>>2]=641080+(ca*52|0);UGb(L+40|0,641064+(ca*52|0)|0,15)|0;O=a[g+ca|0]|0;a[L+55|0]=O;if(O<<24>>24==0){c[G>>2]=(c[G>>2]|0)+1;N=c[ba>>2]|0;da=N;ea=a[g+N|0]|0}else{da=ca;ea=O}a[g+da|0]=ea+1;O=q+1|0;if(O>>>0<(c[r>>2]|0)>>>0){I=_;J=Z;q=O}else{M=48;break}}if((M|0)==5){yDb(C,16,2182696,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==8){Z=c[v>>2]|0;yDb(C,16,2168376,(aa=i,i=i+16|0,c[aa>>2]=c[u>>2],c[aa+8>>2]=Z,aa)|0);i=aa;s=-22;i=e;return s|0}else if((M|0)==27){yDb(C,16,2160928,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==31){yDb(C,16,2154256,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==34){yDb(C,16,2147096,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==42){c[ba>>2]=-1;yDb(C,16,2134832,(aa=i,i=i+8|0,c[aa>>2]=q,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==48){if((c[D>>2]|0)==1171568){c[o+16>>2]=1}D=b+28|0;if((c[(c[(c[c[D>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)==0){aa=c[n>>2]|0;n=hFb()|0;q=fe(n|0)|0;C=aa+124|0;ba=C|0;x=879858770;a[ba]=x;x=x>>8;a[ba+1|0]=x;x=x>>8;a[ba+2|0]=x;x=x>>8;a[ba+3|0]=x;ba=C+4|0;x=q;a[ba]=x;x=x>>8;a[ba+1|0]=x;x=x>>8;a[ba+2|0]=x;x=x>>8;a[ba+3|0]=x;ba=fe(n>>>8|872415232|0)|0;q=aa+132|0;C=q|0;x=1905545728;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=q+4|0;x=ba;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[aa+120>>2]=n&16777215}if((c[r>>2]|0)!=0){n=0;do{aa=c[(c[(c[D>>2]|0)+(n<<2)>>2]|0)+12>>2]|0;C=aa+53|0;a[C]=a[g+(c[aa+56>>2]|0)|0]|0;if((PGb(aa+40|0,641844,13)|0)==0){ba=C;c[aa+64>>2]=fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0|352321536}else{ba=aa+52|0;c[aa+64>>2]=fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0}n=n+1|0;}while(n>>>0<(c[r>>2]|0)>>>0)}r=BBb(c[p>>2]|0,2128456,0,0)|0;do{if((r|0)!=0){p=bU(c[r+4>>2]|0)|0;if((p|0)==0&(F|0)==0){break}c[f>>2]=p;p=mc(f|0)|0;if((p|0)==0){fa=0;ga=0}else{n=c[p+8>>2]<<24;g=c[p+4>>2]<<16;D=c[p>>2]<<8;fa=(c[p+16>>2]|0)+1<<8|0>>>24|((c[p+20>>2]|0)+1900<<16|0>>>16)|c[p+12>>2]|((n|0)<0|0?-1:0)|((g|0)<0|0?-1:0)|((D|0)<0|0?-1:0);ga=0<<8|0>>>24|(0<<16|0>>>16)|n|g|D}D=o+40|0;c[D>>2]=ga;c[D+4>>2]=fa}}while(0);fa=o+72|0;c[fa>>2]=-1;c[fa+4>>2]=-1;fa=cEb(656)|0;ga=o+100|0;c[ga>>2]=fa;if((fa|0)==0){s=-12;i=e;return s|0}fa=cEb(104)|0;c[(c[ga>>2]|0)+12>>2]=fa;fa=c[ga>>2]|0;if((c[fa+12>>2]|0)==0){s=-12;i=e;return s|0}c[fa>>2]=-1;if((_|0)==0){c[m>>2]=1;c[m+4>>2]=25;ha=vX(b,m)|0}else{ha=_}s=(ZW(b,ha+8|0,o+20|0)|0)>>31;i=e;return s|0}else if((M|0)==67){i=e;return s|0}return 0}function sL(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;g=i;h=e+12|0;j=c[h>>2]|0;k=e+16|0;l=c[k>>2]|0;m=e+28|0;n=c[(c[m>>2]|0)+(c[f+32>>2]<<2)>>2]|0;o=n+12|0;p=c[o>>2]|0;q=j+108|0;do{if((c[q>>2]|0)==0){r=j+36|0;s=c[r>>2]|0;if(((s>>>0)%250|0|0)!=0){break}t=bEb(j+32|0,s+250|0,24)|0;if((t|0)>=0){break}c[r>>2]=0;yDb(e,16,2278800,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=t;i=g;return v|0}}while(0);t=n+8|0;r=c[(c[t>>2]|0)+48>>2]|0;a:do{if((r|0)==2){s=c[o>>2]|0;w=f+28|0;x=c[w>>2]|0;b:do{if((x-4|0)>0){y=f+24|0;z=s+92|0;A=s+84|0;B=s+88|0;C=s+80|0;D=0;E=-256;G=x;H=0;I=0;c:while(1){J=c[y>>2]|0;K=d[J+D|0]|0|E;do{if((K|0)==256){L=d[J+(D+2)|0]|0;M=L>>>3&7;N=((d[J+(D+1)|0]|0)<<2|L>>>6)&65535;if((M|0)==0){O=24;break c}else if((M|0)==3){L=((c[z>>2]|0)==0?51:19)|H;c[C>>2]=-1;P=L;Q=N;break}else if((M|0)==2){c[z>>2]=0;P=H|34;Q=N;break}else{P=H;Q=N;break}}else if((K|0)==437){N=d[J+(D+1)|0]|0;M=N&240;if((M|0)==16){L=c[t>>2]|0;c[L+840>>2]=N&7;c[L+844>>2]=(d[J+(D+2)|0]|0)>>>4;P=H;Q=I;break}else{R=D+5|0;if((R|0)<(G|0)&(M|0)==128){break c}else{P=H;Q=I;break}}}else if((K|0)==435){M=H|64;L=(d[J+(D+4)|0]|0)>>>4;if((L|0)==3){c[A>>2]=16;c[B>>2]=9;P=M;Q=I;break}else if((L|0)==2){c[A>>2]=4;c[B>>2]=3;P=M;Q=I;break}else if((L|0)==4){c[A>>2]=221;c[B>>2]=100;P=M;Q=I;break}else{L=c[t>>2]|0;N=c[L+120>>2]|0;S=c[L+124>>2]|0;iFb(A,B,N,(N|0)<0|0?-1:0,S,(S|0)<0|0?-1:0,1048576,0)|0;P=M;Q=I;break}}else if((K|0)==440){if((a[J+(D+4)|0]&64)==0){P=H;Q=I;break}c[z>>2]=1;P=(H&64)==0?H:H|-128;Q=I}else{P=H;Q=I}}while(0);M=D+1|0;S=c[w>>2]|0;if((M|0)>=(S-4|0)){T=P;U=Q;O=27;break b}D=M;E=K<<8;G=S;H=P;I=Q}if((O|0)==24){G=e;yDb(G,16,2203552,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;V=G;break}G=a[J+R|0]|0;c[s+68>>2]=(G&255)>>>7&255^1;if(!(G<<24>>24>-1)){T=H;U=I;O=27;break}c[s+72>>2]=2-((d[J+(D+4)|0]|0)>>>7&255);T=H;U=I;O=27}else{T=0;U=0;O=27}}while(0);if((O|0)==27){if((c[e+8>>2]|0)==1171568){W=c[s+60>>2]|0}else{w=c[t>>2]|0;if((c[w+136>>2]|0)>1){X=1}else{X=(c[w+176>>2]|0)!=0|0}x=c[w+840>>2]|0;do{if((x|0)==0){G=c[w+844>>2]|0;if((G|0)==2){Y=638440+((X|6)<<4)|0;break}else if((G|0)==5){Y=638440+((X|2)<<4)|0;break}else{Y=0;break}}else if((x|0)==4){G=c[w+844>>2]|0;if((G|0)==6){Y=638440+((X|8)<<4)|0;break}else if((G|0)==8){Y=638440+(X<<4)|0;break}else if((G|0)==4){Y=638440+((X|4)<<4)|0;break}else{Y=0;break}}else{Y=0}}while(0);c[s+60>>2]=Y;W=Y}if((W|0)!=0){Z=T;_=U;break}V=e}yDb(V,16,2263504,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1;i=g;return v|0}else if((r|0)==100){w=c[o>>2]|0;x=c[h>>2]|0;if((c[x+28>>2]|0)!=0){Z=0;_=0;break}if((c[f+28>>2]|0)<43){Z=0;_=0;break}G=c[f+24>>2]|0;E=(d[G+41|0]|0)<<16|(d[G+40|0]|0)<<24|(d[G+42|0]|0)<<8|(d[G+43|0]|0);G=V1(E)|0;if((G|0)<0){Z=0;_=0;break}switch(E|0){case 1253:{c[w+56>>2]=33;$=33;break};case 1252:{c[w+56>>2]=32;$=32;break};case 1237:{c[w+56>>2]=25;$=25;break};case 1243:{c[w+56>>2]=29;$=29;break};case 1251:{c[w+56>>2]=31;$=31;break};case 1241:{c[w+56>>2]=27;c[w+76>>2]=10;$=27;break};case 1242:{c[w+56>>2]=28;$=28;break};case 1235:{c[w+56>>2]=24;c[w+76>>2]=10;$=24;break};case 1238:{c[w+56>>2]=26;$=26;break};case 1250:{c[w+56>>2]=30;c[w+76>>2]=10;$=30;break};default:{Z=0;_=0;break a}}c[w+60>>2]=641080+($*52|0);c[w+84>>2]=16;c[w+88>>2]=9;w=x+108|0;c[w>>2]=512;x=e+24|0;if((c[x>>2]|0)==0){Z=0;_=0;break}E=c[m>>2]|0;z=G+20|0;G=0;B=512;while(1){A=c[E+(G<<2)>>2]|0;C=c[(c[A+8>>2]|0)+8>>2]|0;if((C|0)==1){y=c[A+12>>2]|0;A=B+20+(ba(c[y+16>>2]|0,c[c[y+24>>2]>>2]|0)|0)|0;y=512-(A&511)|0;S=(y>>>0<20>>>0?y+512|0:y&511)+A|0;c[w>>2]=S;aa=S}else if((C|0)==0){C=z+B|0;S=512-(C&511)|0;A=(S>>>0<20>>>0?S+512|0:S&511)+C|0;c[w>>2]=A;aa=A}else{aa=B}A=G+1|0;if(A>>>0<(c[x>>2]|0)>>>0){G=A;B=aa}else{Z=0;_=0;break}}}else if((r|0)==25){B=c[o>>2]|0;G=c[h>>2]|0;if((c[G+28>>2]|0)!=0){Z=0;_=0;break}if((c[f+28>>2]|0)<12e4){Z=0;_=0;break}x=c[f+24>>2]|0;w=d[x+451|0]|0;z=w&31;E=w>>>5;w=E&1;s=B+84|0;if((a[x+450|0]&7)==2){c[s>>2]=16;c[B+88>>2]=9}else{c[s>>2]=4;c[B+88>>2]=3}s=(d[x+456|0]|0)>>>4&1;x=B+68|0;c[x>>2]=s;do{if((z|0)==20){ca=w|4;da=(w|0)!=0?576e3:48e4}else if((z|0)==4){ca=w|2;da=(w|0)!=0?288e3:24e4}else if((z|0)==24){A=E|6;C=(w|0)!=0?288e3:24e4;if((s|0)==0){ca=A;da=C;break}yDb(e,16,2212896,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;c[x>>2]=0;ca=A;da=C}else{ca=w;da=(w|0)!=0?144e3:12e4}}while(0);w=ca+16|0;c[B+56>>2]=w;c[B+60>>2]=641080+(w*52|0);w=G+108|0;c[w>>2]=512;x=e+24|0;if((c[x>>2]|0)==0){Z=0;_=0;break}s=c[m>>2]|0;E=da|20;z=0;C=512;while(1){A=c[s+(z<<2)>>2]|0;S=c[(c[A+8>>2]|0)+8>>2]|0;if((S|0)==0){y=C+E|0;M=512-(y&511)|0;N=(M>>>0<20>>>0?M+512|0:M&511)+y|0;c[w>>2]=N;ea=N}else if((S|0)==1){S=c[A+12>>2]|0;A=C+20+(ba(c[S+16>>2]|0,c[c[S+24>>2]>>2]|0)|0)|0;S=512-(A&511)|0;N=(S>>>0<20>>>0?S+512|0:S&511)+A|0;c[w>>2]=N;ea=N}else{ea=C}N=z+1|0;if(N>>>0<(c[x>>2]|0)>>>0){z=N;C=ea}else{Z=0;_=0;break}}}else{Z=0;_=0}}while(0);ea=j+28|0;if((c[ea>>2]|0)==0){do{if((c[q>>2]|0)==0){da=xL(e,0,0,981432,1)|0;if((da|0)<0){v=da}else{break}i=g;return v|0}else{da=xL(e,1,2,981432,1)|0;if((da|0)<0){v=da;i=g;return v|0}da=Ty(c[k>>2]|0,0,0,1)|0;ca=ZGb(512,0,da&511,F&0)|0;da=ca;ca=da>>>0<20>>>0?da+512|0:da&511;if((ca|0)!=0){Ry(c[k>>2]|0,879896,16);da=ca-20|0;ca=c[k>>2]|0;Py(ca,131);hz(ca,da);Qy(c[k>>2]|0,0,da)}yL(e)}}while(0);c[ea>>2]=1}ea=c[n>>2]|0;n=(c[q>>2]|0)!=0;do{if((ea|0)==0){do{if(!n){da=c[j+36>>2]|0;if(!((da|0)==0|da>>>0>250>>>0)){break}if(!((Z&51)==0)){break}da=Ty(c[k>>2]|0,0,0,1)|0;ca=ZGb(512,0,da&511,F&0)|0;da=ca;ca=da>>>0<20>>>0?da+512|0:da&511;if((ca|0)!=0){Ry(c[k>>2]|0,879896,16);da=ca-20|0;ca=c[k>>2]|0;Py(ca,131);hz(ca,da);Qy(c[k>>2]|0,0,da)}da=xL(e,1,2,1680096,0)|0;if((da|0)<0){v=da;i=g;return v|0}da=Ty(c[k>>2]|0,0,0,1)|0;ca=ZGb(512,0,da&511,F&0)|0;da=ca;ca=da>>>0<20>>>0?da+512|0:da&511;if((ca|0)!=0){Ry(c[k>>2]|0,879896,16);da=ca-20|0;ca=c[k>>2]|0;Py(ca,131);hz(ca,da);Qy(c[k>>2]|0,0,da)}yL(e)}}while(0);da=Ty(c[k>>2]|0,0,0,1)|0;ca=ZGb(512,0,da&511,F&0)|0;da=ca;ca=da>>>0<20>>>0?da+512|0:da&511;if((ca|0)!=0){Ry(c[k>>2]|0,879896,16);da=ca-20|0;ca=c[k>>2]|0;Py(ca,131);hz(ca,da);Qy(c[k>>2]|0,0,da)}da=c[h>>2]|0;ca=c[k>>2]|0;r=(c[da+36>>2]|0)+(c[da+52>>2]|0)|0;Ry(ca,399744,16);Py(ca,131);hz(ca,57);Py(ca,92);Py(ca,4);Py(ca,0);fz(ca,0);aa=da+80|0;fz(ca,(c[aa>>2]|0)+r&65535);if((c[da+16>>2]|0)>1){Ry(ca,643816,16)}else{Ry(ca,641048+((c[(c[(c[c[m>>2]>>2]|0)+12>>2]|0)+56>>2]|0)*52|0)|0,16)}Py(ca,0);ez(ca,0,0);ez(ca,0,0);Py(ca,129);Zy(ca,ZFb(aa,r)|0);Zy(ca,0);ez(ca,0,0);Ry(ca,399728,16);Py(ca,131);hz(ca,35);Py(ca,131);fz(ca,32);ca=c[h>>2]|0;Ry(c[k>>2]|0,163136,13);hz(c[k>>2]|0,c[ca+120>>2]|0);Ry(c[k>>2]|0,ca+124|0,15);Py(c[k>>2]|0,1);if((c[q>>2]|0)==0){ca=j+112|0;r=c[ca+4>>2]|0;aa=j+36|0;da=c[aa>>2]|0;$=j+32|0;V=c[$>>2]|0;U=V+(da*24|0)+8|0;c[U>>2]=c[ca>>2];c[U+4>>2]=r;a[V+(da*24|0)|0]=Z;da=c[aa>>2]|0;b[(c[$>>2]|0)+(da*24|0)+20>>1]=_;$=YGb(c[ca>>2]|0,c[ca+4>>2]|0,512,0)|0;c[ca>>2]=$;c[ca+4>>2]=F;fa=da}else{fa=c[j+36>>2]|0}c[j+36>>2]=fa+1}else{if(!((ea|0)==1&(n^1))){break}da=j+112|0;ca=(c[j+36>>2]|0)-1|0;$=c[j+32>>2]|0;aa=$+(ca*24|0)+8|0;V=ZGb(c[da>>2]|0,c[da+4>>2]|0,c[aa>>2]|0,c[aa+4>>2]|0)|0;c[$+(ca*24|0)+16>>2]=V}}while(0);n=Ty(c[k>>2]|0,0,0,1)|0;ea=ZGb(512,0,n&511,F&0)|0;n=ea;ea=n>>>0<20>>>0?n+512|0:n&511;if((ea|0)!=0){Ry(c[k>>2]|0,879896,16);n=ea-20|0;ea=c[k>>2]|0;Py(ea,131);hz(ea,n);Qy(c[k>>2]|0,0,n)}Ry(l,p+40|0,16);do{if((c[e+8>>2]|0)==1171568){p=c[t>>2]|0;if((c[p+8>>2]|0)==0){n=c[h>>2]|0;ea=c[k>>2]|0;fa=c[(c[o>>2]|0)+96>>2]|0;_=c[n+20>>2]|0;Z=gHb(_,(_|0)<0|0?-1:0,fa,(fa|0)<0|0?-1:0)|0;fa=c[n+24>>2]<<3;n=hHb(Z,F,fa,(fa|0)<0|0?-1:0)|0;fa=n+20|0;n=512-(fa&511)|0;Z=f+28|0;_=c[Z>>2]|0;Py(ea,131);hz(ea,_);Ry(ea,c[f+24>>2]|0,c[Z>>2]|0);ea=(n>>>0<20>>>0?n+512|0:n&511)+fa-(c[Z>>2]|0)|0;Z=ea-20|0;if((Z|0)>20){Ry(c[k>>2]|0,879896,16);fa=ea-40|0;ea=c[k>>2]|0;Py(ea,131);hz(ea,fa);Qy(c[k>>2]|0,0,fa);break}else{yDb(e,24,2222296,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;Qy(c[k>>2]|0,0,Z);break}}Z=c[h>>2]|0;fa=c[k>>2]|0;ea=c[f+24>>2]|0;n=c[f+28>>2]|0;_=(n|0)/(c[p+432>>2]|0)|0;p=ea+n|0;Py(fa,131);hz(fa,_<<5|4);if((_|0)==1920){ga=0}else{ga=((((c[Z+36>>2]|0)-1|0)>>>0)%5|0)+1|0}Py(fa,ga);az(fa,_);Py(fa,(1<<c[(c[t>>2]|0)+416>>2])-1|0);if((n|0)>0){ha=ea}else{break}while(1){ea=c[t>>2]|0;if((c[ea+416>>2]|0)>0){n=ha;_=0;Z=ea;while(1){if((c[Z+48>>2]|0)==65548){ia=((d[n+1|0]|0)<<8|(d[n+2|0]|0)<<16|(d[n]|0))<<4;ja=n+3|0}else{ea=n;ia=((d[ea]|d[ea+1|0]<<8)<<16>>16&65535)<<12;ja=n+2|0}Yy(fa,ia|_);ka=_+1|0;ea=c[t>>2]|0;if((ka|0)<(c[ea+416>>2]|0)){n=ja;_=ka;Z=ea}else{break}}if((ka|0)<8){la=ka;ma=ja;O=126}else{na=ja}}else{la=0;ma=ha;O=126}if((O|0)==126){O=0;Z=la;while(1){Yy(fa,Z);_=Z+1|0;if((_|0)<8){Z=_}else{na=ma;break}}}if(na>>>0<p>>>0){ha=na}else{break}}}else{p=f+28|0;fa=c[p>>2]|0;Py(l,131);hz(l,fa);Ry(l,c[f+24>>2]|0,c[p>>2]|0);fa=(c[p>>2]|0)+20|0;p=512-(fa&511)|0;Z=j+112|0;_=YGb((p>>>0<20>>>0?p+512|0:p&511)+fa|0,0,c[Z>>2]|0,c[Z+4>>2]|0)|0;c[Z>>2]=_;c[Z+4>>2]=F}}while(0);Sy(l);v=0;i=g;return v|0}function tL(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;h=e+72|0;c[h>>2]=(c[e+36>>2]|0)+(c[e+52>>2]|0);c[h+4>>2]=0;h=Ty(g,0,0,1)|0;i=ZGb(512,0,h&511,F&0)|0;h=i;i=h>>>0<20>>>0?h+512|0:h&511;if((i|0)!=0){Ry(c[f>>2]|0,879896,16);h=i-20|0;i=c[f>>2]|0;Py(i,131);hz(i,h);Qy(c[f>>2]|0,0,h)}h=Ty(g,0,0,1)|0;i=e+8|0;c[i>>2]=h;c[i+4>>2]=F;i=e+108|0;do{if((c[i>>2]|0)==0){h=xL(a,0,2,1048488,0)|0;if((h|0)<0){j=h;return j|0}h=Ty(c[f>>2]|0,0,0,1)|0;k=ZGb(512,0,h&511,F&0)|0;h=k;k=h>>>0<20>>>0?h+512|0:h&511;if((k|0)!=0){Ry(c[f>>2]|0,879896,16);h=k-20|0;k=c[f>>2]|0;Py(k,131);hz(k,h);Qy(c[f>>2]|0,0,h)}yL(a)}else{h=xL(a,0,0,1048488,0)|0;if((h|0)<0){j=h}else{break}return j|0}}while(0);h=Ty(c[f>>2]|0,0,0,1)|0;k=ZGb(512,0,h&511,F&0)|0;h=k;k=h>>>0<20>>>0?h+512|0:h&511;if((k|0)!=0){Ry(c[f>>2]|0,879896,16);h=k-20|0;k=c[f>>2]|0;Py(k,131);hz(k,h);Qy(c[f>>2]|0,0,h)}h=c[b>>2]|0;b=c[f>>2]|0;k=Ty(b,0,0,1)|0;l=F;Ry(b,549584,16);m=h+60|0;n=gHb(c[m>>2]|0,0,12,0)|0;o=YGb(n,F,28,0)|0;n=F;p=0;q=o;do{if(n>>>0<p>>>0|n>>>0==p>>>0&o>>>0<128>>>0){Py(b,q)}else{r=q>>>0>65535>>>0;s=r?q>>>16:q;t=r?16:0;if((s&65280|0)==0){u=t;v=s}else{u=t|8;v=s>>>8}s=(d[1191992+v|0]|0)+u>>3;t=s+1|0;Py(b,s+129|0);if((t|0)==0){break}else{w=t}do{w=w-1|0;t=$Gb(o|0,n|0,w<<3|0)|0;Py(b,t&255);}while((w|0)!=0)}}while(0);if((c[h+108>>2]|0)==0){Zy(b,0)}else{Zy(b,1)}ez(b,0,0);if((c[m>>2]|0)!=0){w=h+56|0;n=0;do{Zy(b,1);o=(c[w>>2]|0)+(n<<3)|0;ez(b,c[o>>2]|0,c[o+4>>2]|0);n=n+1|0;}while(n>>>0<(c[m>>2]|0)>>>0)}Zy(b,0);m=h+8|0;ez(b,c[m>>2]|0,c[m+4>>2]|0);m=Ty(b,0,0,1)|0;h=F;n=ZGb(4,0,k,l)|0;l=YGb(n,F,m,h)|0;Zy(b,l);do{if((c[(c[f>>2]|0)+88>>2]|0)!=0){Ty(g,0,0,0)|0;if((c[i>>2]|0)==0){l=xL(a,0,0,981464,1)|0;if((l|0)<0){j=l}else{break}return j|0}l=xL(a,1,2,981464,1)|0;if((l|0)<0){j=l;return j|0}l=Ty(c[f>>2]|0,0,0,1)|0;b=ZGb(512,0,l&511,F&0)|0;l=b;b=l>>>0<20>>>0?l+512|0:l&511;if((b|0)!=0){Ry(c[f>>2]|0,879896,16);l=b-20|0;b=c[f>>2]|0;Py(b,131);hz(b,l);Qy(c[f>>2]|0,0,l)}yL(a)}}while(0);YW(a);$Db(e+32|0);$Db(e+56|0);f=e+100|0;$Db((c[f>>2]|0)+12|0);$Db(f);f=a+24|0;if((c[f>>2]|0)==0){j=0;return j|0}e=a+28|0;a=0;while(1){$Db((c[(c[e>>2]|0)+(a<<2)>>2]|0)+12|0);i=a+1|0;if(i>>>0<(c[f>>2]|0)>>>0){a=i}else{j=0;break}}return j|0}function uL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _W(a,b,c,d,342,170)|0}function vL(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+8|0;f=d|0;g=c[a+24>>2]|0;a:do{if((g|0)!=0){h=c[a+28>>2]|0;j=0;k=0;do{k=((c[(c[h+(j<<2)>>2]|0)+244>>2]|0)!=0)+k|0;j=j+1|0;}while(j>>>0<g>>>0);if((k|0)==0){break}if((g|0)!=(k|0)&(e|0)==0){break}j=a+1236|0;h=c[j>>2]|0;c[f>>2]=h;b:do{if((g|0)==(k|0)){l=h}else{do{if((h|0)!=0){m=k;n=0;o=h;while(1){if((c[o+32>>2]|0)==0){p=n;q=o;break}r=c[o+80>>2]|0;c[f>>2]=r;s=m-1|0;if((r|0)==0|(s|0)==0){p=o;q=r;break}else{m=s;n=o;o=r}}if((q|0)!=0){o=a+28|0;n=f;m=q;while(1){r=c[m+80>>2]|0;s=(c[(c[o>>2]|0)+(c[m+32>>2]<<2)>>2]|0)+244|0;if((c[s>>2]|0)==(m|0)){c[s>>2]=0;t=c[f>>2]|0}else{t=m}BZ(t|0);$Db(n);c[f>>2]=r;if((r|0)==0){break}else{m=r}}}if((p|0)==0){break}c[p+80>>2]=0;m=c[j>>2]|0;c[f>>2]=m;l=m;break b}}while(0);c[j>>2]=0;c[a+1240>>2]=0;break a}}while(0);UGb(b|0,l|0,80)|0;h=c[l+80>>2]|0;c[j>>2]=h;k=(c[(c[a+28>>2]|0)+(c[l+32>>2]<<2)>>2]|0)+244|0;if((c[k>>2]|0)==(l|0)){c[k>>2]=0;u=c[j>>2]|0}else{u=h}if((u|0)==0){c[a+1240>>2]=0}$Db(f);v=1;i=d;return v|0}}while(0);vZ(b);v=0;i=d;return v|0}function wL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[a+28>>2]|0;a=b+16|0;f=c[a>>2]|0;g=c[a+4>>2]|0;a=d+16|0;h=c[a>>2]|0;i=c[a+4>>2]|0;if((g|0)>(i|0)|(g|0)==(i|0)&f>>>0>h>>>0){j=1;return j|0}if(!((f|0)==(h|0)&(g|0)==(i|0))){j=0;return j|0}j=(c[(c[(c[e+(c[d+32>>2]<<2)>>2]|0)+12>>2]|0)+64>>2]|0)<(c[(c[(c[e+(c[b+32>>2]<<2)>>2]|0)+12>>2]|0)+64>>2]|0)|0;return j|0}function xL(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;i=b+12|0;j=c[i>>2]|0;k=b+16|0;l=c[k>>2]|0;m=Ty(l,0,0,1)|0;n=F;o=(c[j+108>>2]|0)==0;do{if(o){p=c[j+36>>2]|0;if((p|0)==0){q=4;break}r=((c[b+24>>2]|0)*6|0)+115+(ba((d[j+48|0]<<2)+11|0,p)|0)|0}else{q=4}}while(0);if((q|0)==4){r=o|(f|0)==0?0:80}if((r|0)==0){s=0}else{if(r>>>0<128>>>0){t=17}else{o=r>>>0>65535>>>0;p=o?r>>>16:r;u=o?16:0;if((p&65280|0)==0){v=u;w=p}else{v=u|8;w=p>>>8}t=((d[1191992+w|0]|0)+v>>3)+18|0}v=t+r|0;r=512-(v&511)|0;s=(r>>>0<20>>>0?r+512|0:r&511)+v|0}do{if((PGb(g,1680096,16)|0)==0){v=j+56|0;r=j+60|0;t=bEb(v,(c[r>>2]|0)+1|0,8)|0;if((t|0)>=0){w=c[r>>2]|0;c[r>>2]=w+1;p=(c[v>>2]|0)+(w<<3)|0;c[p>>2]=m;c[p+4>>2]=n;break}c[r>>2]=0;x=t;return x|0}}while(0);Ry(l,g,16);t=c[j+16>>2]|0;r=((t|0)>1)+t|0;t=r;p=YGb(t<<4|0>>>28,((r|0)<0|0?-1:0)<<4|t>>>28,88,0)|0;t=F;r=0;w=p;do{if(t>>>0<r>>>0|t>>>0==r>>>0&p>>>0<128>>>0){Py(l,w)}else{v=w>>>0>65535>>>0;u=v?w>>>16:w;o=v?16:0;if((u&65280|0)==0){y=o;z=u}else{y=o|8;z=u>>>8}u=(d[1191992+z|0]|0)+y>>3;o=u+1|0;Py(l,u+129|0);if((o|0)==0){break}else{A=o}do{A=A-1|0;o=$Gb(p|0,t|0,A<<3|0)|0;Py(l,o&255);}while((A|0)!=0)}}while(0);fz(l,1);fz(l,2);Zy(l,512);ez(l,m,n);do{if((PGb(g,1680096,16)|0)==0){n=c[j+60>>2]|0;if(!(n>>>0>1>>>0)){q=24;break}m=(c[j+56>>2]|0)+(n-2<<3)|0;ez(l,c[m>>2]|0,c[m+4>>2]|0)}else{q=24}}while(0);a:do{if((q|0)==24){do{if((PGb(g,1048488,16)|0)==0){m=c[j+60>>2]|0;if((m|0)==0){break}n=(c[j+56>>2]|0)+(m-1<<3)|0;ez(l,c[n>>2]|0,c[n+4>>2]|0);break a}}while(0);ez(l,0,0)}}while(0);g=j+8|0;ez(l,c[g>>2]|0,c[g+4>>2]|0);g=Ty(l,0,0,1)|0;n=F;ez(l,0,0);ez(l,s,0);Zy(l,(s|0)!=0?f:0);do{if((e|0)==0){q=32}else{if((c[j+36>>2]|0)==0){q=32;break}if((c[j+60>>2]|0)==0){q=32;break}f=j+112|0;ez(l,c[f>>2]|0,c[f+4>>2]|0)}}while(0);if((q|0)==32){ez(l,0,0)}Zy(l,e);Ry(l,628352,16);zL(b);if((h|0)!=0){h=Ty(c[k>>2]|0,0,0,1)|0;e=ZGb(512,0,h&511,F&0)|0;h=e;e=h>>>0<20>>>0?h+512|0:h&511;if((e|0)!=0){Ry(c[k>>2]|0,879896,16);h=e-20|0;e=c[k>>2]|0;Py(e,131);hz(e,h);Qy(c[k>>2]|0,0,h)}h=Ty(c[k>>2]|0,0,0,1)|0;e=F;q=c[k>>2]|0;Ry(q,561976,16);j=((d[1191996]|0)+8|0)>>>3;Py(q,j+129|0);f=j+1|0;do{f=f-1|0;j=$Gb(1250,0,f<<3|0)|0;Py(q,j&255);}while((f|0)!=0);Zy(q,69);Zy(q,18);f=0;do{fz(q,c[639440+(f*20|0)>>2]|0);Ry(q,639444+(f*20|0)|0,16);f=f+1|0;}while((f|0)<69);f=c[i>>2]|0;q=c[k>>2]|0;Ry(q,981448,13);hz(q,77568);j=f+16|0;s=c[j>>2]|0;m=((s|0)>1)+s|0;s=m;A=YGb(s<<4|0>>>28,((m|0)<0|0?-1:0)<<4|s>>>28,130,0)|0;s=F;m=0;t=A;do{if(s>>>0<m>>>0|s>>>0==m>>>0&A>>>0<128>>>0){Py(q,t)}else{p=t>>>0>65535>>>0;y=p?t>>>16:t;z=p?16:0;if((y&65280|0)==0){B=z;C=y}else{B=z|8;C=y>>>8}y=(d[1191992+C|0]|0)+B>>3;z=y+1|0;Py(q,y+129|0);if((z|0)==0){break}else{D=z}do{D=D-1|0;z=$Gb(A|0,s|0,D<<3|0)|0;Py(q,z&255);}while((D|0)!=0)}}while(0);fz(q,15370);fz(q,16);Ry(q,160968,12);fz(q,10);fz(q,0);fz(q,15106);fz(q,8);D=f+40|0;ez(q,c[D>>2]|0,c[D+4>>2]|0);fz(q,15109);fz(q,2);fz(q,258);fz(q,15110);fz(q,24);Zy(q,1);Zy(q,16);Ry(q,160968,12);fz(q,11);fz(q,0);fz(q,15107);fz(q,16);Ry(q,160968,12);fz(q,12);fz(q,0);fz(q,15113);fz(q,16);Ry(q,628352,16);D=c[j>>2]|0;fz(q,15114);fz(q,((D|0)>1)+D<<4|8);zL(b);fz(q,15115);fz(q,8);ez(q,0,0);q=c[i>>2]|0;D=c[k>>2]|0;Ry(D,981448,13);hz(D,77824);j=(c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)!=0?2340272:2316832;f=((SGb(j|0)|0)<<1)+116|0;s=f;A=(f|0)<0|0?-1:0;do{if(f>>>0<128>>>0){Py(D,f)}else{B=f>>>0>65535>>>0;C=B?f>>>16:f;t=B?16:0;if((C&65280|0)==0){E=t;G=C}else{E=t|8;G=C>>>8}C=(d[1191992+G|0]|0)+E>>3;t=C+1|0;Py(D,C+129|0);if((t|0)==0){break}else{H=t}do{H=H-1|0;t=$Gb(s|0,A|0,H<<3|0)|0;Py(D,t&255);}while((H|0)!=0)}}while(0);fz(D,15370);fz(D,16);Ry(D,160968,12);fz(D,11);fz(D,0);fz(D,15369);fz(D,16);Ry(D,160968,12);fz(D,11);fz(D,1);fz(D,15361);fz(D,12);fz(D,70);fz(D,70);fz(D,109);fz(D,112);fz(D,101);fz(D,103);fz(D,15362);fz(D,20);fz(D,79);fz(D,80);fz(D,49);fz(D,97);fz(D,32);fz(D,77);fz(D,117);fz(D,120);fz(D,101);fz(D,114);H=SGb(j|0)|0;fz(D,15364);fz(D,H<<1);if((H|0)>0){A=0;do{fz(D,a[j+A|0]|0);A=A+1|0;}while((A|0)<(H|0))}fz(D,15365);fz(D,16);Ry(D,160968,12);fz(D,11);fz(D,2);fz(D,15366);fz(D,8);H=q+40|0;ez(D,c[H>>2]|0,c[H+4>>2]|0);H=c[k>>2]|0;Ry(H,981448,13);hz(H,71680);Py(H,92);fz(H,15370);fz(H,16);Ry(H,160968,12);fz(H,12);fz(H,0);fz(H,6401);fz(H,40);Zy(H,2);Zy(H,16);Ry(H,160968,12);fz(H,1);fz(H,0);Ry(H,160968,12);fz(H,2);fz(H,0);fz(H,6402);fz(H,24);Zy(H,1);Zy(H,16);Ry(H,160968,12);fz(H,15);fz(H,0);AL(b,1);AL(b,2);b=c[k>>2]|0;Ry(b,981448,13);hz(b,74496);Py(b,72);fz(b,15370);fz(b,16);Ry(b,160968,12);fz(b,15);fz(b,0);fz(b,9985);fz(b,32);H=c[i>>2]|0;Ry(c[k>>2]|0,163136,13);hz(c[k>>2]|0,c[H+120>>2]|0);Ry(c[k>>2]|0,H+124|0,15);Py(c[k>>2]|0,1);fz(b,16135);fz(b,4);Zy(b,1);fz(b,16134);fz(b,4);Zy(b,2);b=Ty(c[k>>2]|0,0,0,1)|0;k=F;H=ZGb(b,k,h,e)|0;e=F;h=ZGb(512,0,b&511,k&0)|0;i=h;h=YGb(H,e,i>>>0<20>>>0?i+512|0:i&511,0)|0;i=F;Ty(l,g,n,0)|0;ez(l,h|0,i&0);Ty(l,b,k,0)|0;}Sy(l);x=0;return x|0}function yL(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;g=c[b+12>>2]|0;h=c[b+16>>2]|0;j=g+64|0;k=c[j>>2]|0;l=b;m=g+36|0;yDb(l,48,1979840,(n=i,i=i+8|0,c[n>>2]=c[m>>2],n)|0);i=n;o=g+108|0;do{if((c[m>>2]|0)==0){if((c[o>>2]|0)!=0){break}i=f;return}}while(0);Ry(h,913376,16);do{if((c[o>>2]|0)==0){p=gHb(c[b+24>>2]|0,0,6,0)|0;q=YGb(p,F,115,0)|0;p=F;r=c[m>>2]|0;s=d[g+48|0]|0;t=YGb(s<<2|0>>>30,0<<2|s>>>30,11,0)|0;s=gHb(t,F,r,0)|0;r=YGb(q,p,s,F)|0;s=F;p=0;q=r;if(s>>>0<p>>>0|s>>>0==p>>>0&r>>>0<128>>>0){Py(h,q);break}p=q>>>0>65535>>>0;t=p?q>>>16:q;q=p?16:0;if((t&65280|0)==0){u=q;v=t}else{u=q|8;v=t>>>8}t=(d[1191992+v|0]|0)+u>>3;q=t+1|0;Py(h,t+129|0);if((q|0)==0){break}else{w=q}do{w=w-1|0;q=$Gb(r|0,s|0,w<<3|0)|0;Py(h,q&255);}while((w|0)!=0)}else{Py(h,80)}}while(0);fz(h,15370);fz(h,16);Ry(h,160968,12);fz(h,14);fz(h,0);fz(h,16139);fz(h,8);Zy(h,c[g+24>>2]|0);Zy(h,c[g+20>>2]|0);fz(h,16140);fz(h,8);w=g+52|0;u=c[w>>2]|0;ez(h,u,(u|0)<0|0?-1:0);fz(h,16141);fz(h,8);if((c[o>>2]|0)==0){ez(h,c[m>>2]|0,0)}else{ez(h,0,0)}fz(h,16133);fz(h,4);Zy(h,c[o>>2]|0);fz(h,16134);fz(h,4);Zy(h,2);fz(h,16135);fz(h,4);Zy(h,1);if((c[o>>2]|0)!=0){i=f;return}fz(h,16136);fz(h,1);o=g+48|0;Py(h,d[o]|0);u=b+24|0;v=((c[u>>2]|0)*6|0)+14|0;fz(h,16137);fz(h,v);Zy(h,(c[u>>2]|0)+1|0);Zy(h,6);Py(h,0);Py(h,0);Zy(h,0);if((c[u>>2]|0)==0){x=0}else{v=b+28|0;b=0;s=0;while(1){r=c[(c[(c[v>>2]|0)+(s<<2)>>2]|0)+12>>2]|0;q=r+80|0;Py(h,c[q>>2]|0);t=(c[q>>2]|0)==0?b:1;if((s|0)==0){Py(h,0);Zy(h,512)}else{q=ba(c[r+16>>2]|0,c[c[r+24>>2]>>2]|0)|0;r=512-(q&511)|0;Py(h,1);Zy(h,ba((r>>>0<20>>>0?r+512|0:r&511)+q|0,s-1|0)|0)}q=s+1|0;if(q>>>0<(c[u>>2]|0)>>>0){b=t;s=q}else{x=t;break}}}s=(ba(((d[o]|0)<<2)+11|0,c[m>>2]|0)|0)+8|0;fz(h,16138);fz(h,s);Zy(h,c[m>>2]|0);Zy(h,((d[o]|0)<<2)+11|0);o=c[m>>2]|0;if((o|0)==0){y=k;z=0}else{s=g+32|0;g=(x|0)==0;x=k;k=0;b=o;while(1){o=c[s>>2]|0;if((a[o+(k*24|0)|0]&51)==0){c[j>>2]=x;A=k}else{A=x}do{if(g){B=0}else{v=k-A|0;if((v|0)==(e[o+(k*24|0)+20>>1]|0|0)){B=0;break}else{C=A}while(1){if(!(C>>>0<b>>>0)){break}if((v|0)==(e[o+(C*24|0)+20>>1]|0|0)){break}else{C=C+1|0}}if((C|0)==(b|0)){yDb(l,24,1949896,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}B=C-k|0}}while(0);Py(h,B);do{if((a[(c[s>>2]|0)+(k*24|0)|0]&48)==48){Py(h,(c[j>>2]|0)-k|0);D=c[s>>2]|0}else{Py(h,A-k|0);o=c[s>>2]|0;if((a[o+(k*24|0)|0]&32)==0){D=o;break}c[j>>2]=A;D=o}}while(0);o=D+(k*24|0)|0;v=a[o]|0;if((v&115)==64&(B|0)==0){a[o]=v|-128;E=a[(c[s>>2]|0)+(k*24|0)|0]|0}else{E=v}Py(h,E&255);v=(c[s>>2]|0)+(k*24|0)+8|0;ez(h,c[v>>2]|0,c[v+4>>2]|0);if((c[u>>2]|0)>>>0>1>>>0){Zy(h,c[(c[s>>2]|0)+(k*24|0)+16>>2]|0)}v=k+1|0;o=c[m>>2]|0;if(v>>>0<o>>>0){x=A;k=v;b=o}else{y=A;z=o;break}}}c[j>>2]=y-z;c[w>>2]=(c[w>>2]|0)+z;c[m>>2]=0;i=f;return}function zL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+16>>2]|0;e=(c[a+12>>2]|0)+16|0;f=c[e>>2]|0;Zy(d,((f|0)>1)+f|0);Zy(d,16);yDb(a,48,2295376,(f=i,i=i+8|0,c[f>>2]=c[e>>2],f)|0);i=f;if((c[e>>2]|0)<=0){i=b;return}f=a+28|0;a=0;do{Ry(d,641048+((c[(c[(c[(c[f>>2]|0)+(a<<2)>>2]|0)+12>>2]|0)+56>>2]|0)*52|0)|0,16);a=a+1|0;g=c[e>>2]|0;}while((a|0)<(g|0));if((g|0)<=1){i=b;return}Ry(d,643816,16);i=b;return}function AL(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;f=a+12|0;g=c[f>>2]|0;h=a+16|0;j=c[h>>2]|0;k=a+24|0;l=(c[k>>2]|0)+1|0;m=(b|0)==1;Ry(j,981448,13);do{if(m){hz(j,79360);n=(l<<4)+92|0;o=n;p=(n|0)<0|0?-1:0;if(n>>>0<128>>>0){Py(j,n);break}q=n>>>0>65535>>>0;r=q?n>>>16:n;n=q?16:0;if((r&65280|0)==0){s=n;t=r}else{s=n|8;t=r>>>8}r=(d[1191992+t|0]|0)+s>>3;n=r+1|0;Py(j,r+129|0);if((n|0)==0){break}else{u=n}do{u=u-1|0;n=$Gb(o|0,p|0,u<<3|0)|0;Py(j,n&255);}while((u|0)!=0)}else{hz(j,79616);p=(l<<4)+112|0;o=p;n=(p|0)<0|0?-1:0;if(p>>>0<128>>>0){Py(j,p);break}r=p>>>0>65535>>>0;q=r?p>>>16:p;p=r?16:0;if((q&65280|0)==0){v=p;w=q}else{v=p|8;w=q>>>8}q=(d[1191992+w|0]|0)+v>>3;p=q+1|0;Py(j,q+129|0);if((p|0)==0){break}else{x=p}do{x=x-1|0;p=$Gb(o|0,n|0,x<<3|0)|0;Py(j,p&255);}while((x|0)!=0)}}while(0);fz(j,15370);fz(j,16);Ry(j,160968,12);fz(j,b);fz(j,0);yDb(a,48,1924216,(x=i,i=i+8|0,c[x>>2]=b,x)|0);i=x;fz(j,17409);fz(j,32);x=(b|0)==2;v=c[f>>2]|0;Ry(c[h>>2]|0,163136,13);hz(c[h>>2]|0,c[v+120>>2]|0);Ry(c[h>>2]|0,v+124|0,15);Py(c[h>>2]|0,x&1);fz(j,17413);fz(j,8);v=g+40|0;ez(j,c[v>>2]|0,c[v+4>>2]|0);fz(j,17412);fz(j,8);ez(j,c[v>>2]|0,c[v+4>>2]|0);fz(j,17411);fz(j,l<<4|8);Zy(j,l);Zy(j,16);l=m?8:24;Ry(j,160968,12);fz(j,l);fz(j,-1);if((c[k>>2]|0)!=0){v=0;do{Ry(j,160968,12);fz(j,l);fz(j,v);v=v+1|0;}while(v>>>0<(c[k>>2]|0)>>>0)}do{if(x){fz(j,18177);fz(j,16);v=(c[k>>2]|0)>>>0>1>>>0;Ry(j,160968,12);if(!v){fz(j,13);fz(j,0);break}fz(j,6);fz(j,0);v=c[f>>2]|0;l=c[h>>2]|0;Ry(l,981448,13);hz(l,82944);w=c[k>>2]|0;u=YGb(w<<4|0>>>28,0<<4|w>>>28,64,0)|0;w=F;s=0;t=u;do{if(w>>>0<s>>>0|w>>>0==s>>>0&u>>>0<128>>>0){Py(l,t)}else{n=t>>>0>65535>>>0;o=n?t>>>16:t;p=n?16:0;if((o&65280|0)==0){y=p;z=o}else{y=p|8;z=o>>>8}o=(d[1191992+z|0]|0)+y>>3;p=o+1|0;Py(l,o+129|0);if((p|0)==0){break}else{A=p}do{A=A-1|0;p=$Gb(u|0,w|0,A<<3|0)|0;Py(l,p&255);}while((A|0)!=0)}}while(0);fz(l,15370);fz(l,16);Ry(l,160968,12);fz(l,6);fz(l,0);fz(l,12289);fz(l,8);Zy(l,c[v+24>>2]|0);Zy(l,c[v+20>>2]|0);fz(l,12292);fz(l,16);if((c[v+16>>2]|0)>1){B=643816}else{B=641048+((c[(c[(c[c[a+28>>2]>>2]|0)+12>>2]|0)+56>>2]|0)*52|0)|0}Ry(l,B,16);w=c[k>>2]<<4|8;fz(l,16129);fz(l,w);Zy(l,c[k>>2]|0);Zy(l,16);if((c[k>>2]|0)==0){break}else{C=0}do{Ry(l,160968,12);fz(l,13);fz(l,C);C=C+1|0;}while(C>>>0<(c[k>>2]|0)>>>0)}}while(0);C=g+100|0;BL(c[f>>2]|0,c[h>>2]|0,c[C>>2]|0,b);g=c[C>>2]|0;B=c[f>>2]|0;A=c[h>>2]|0;Ry(A,981448,13);hz(A,69376);Py(A,80);fz(A,15370);fz(A,16);y=m?5:21;z=g|0;j=c[z>>2]|0;Ry(A,160968,12);fz(A,y);fz(A,j);KL(c[f>>2]|0,c[h>>2]|0,g);fz(A,4097);fz(A,24);Zy(A,1);Zy(A,16);j=(c[B+100>>2]|0)==(g|0)?4:3;g=c[z>>2]|0;Ry(A,160968,12);fz(A,x?j|16:j);fz(A,g);g=c[C>>2]|0;C=c[f>>2]|0;A=c[h>>2]|0;Ry(A,981448,13);hz(A,70656);Py(A,75);fz(A,15370);fz(A,16);j=c[g>>2]|0;Ry(A,160968,12);fz(A,m?4:20);fz(A,j);KL(c[f>>2]|0,c[h>>2]|0,g);fz(A,5377);fz(A,8);g=c[C+80>>2]|0;ez(A,g,(g|0)<0|0?-1:0);fz(A,5378);fz(A,2);fz(A,c[C+104>>2]|0);fz(A,5379);fz(A,1);Py(A,c[C+84>>2]&1);if((c[k>>2]|0)==0){i=e;return}C=a+28|0;A=m?3:19;if(x){x=0;do{m=c[(c[C>>2]|0)+(x<<2)>>2]|0;BL(c[f>>2]|0,c[h>>2]|0,m,2);g=c[f>>2]|0;j=c[h>>2]|0;Ry(j,981448,13);hz(j,69376);Py(j,80);fz(j,15370);fz(j,16);z=m|0;B=c[z>>2]|0;Ry(j,160968,12);fz(j,y);fz(j,B);KL(c[f>>2]|0,c[h>>2]|0,m);fz(j,4097);fz(j,24);Zy(j,1);Zy(j,16);B=(c[g+100>>2]|0)==(m|0)?20:19;g=c[z>>2]|0;Ry(j,160968,12);fz(j,B);fz(j,g);g=c[h>>2]|0;Ry(g,981448,13);hz(g,69888);Py(g,108);fz(g,15370);fz(g,16);j=c[z>>2]|0;Ry(g,160968,12);fz(g,A);fz(g,j);KL(c[f>>2]|0,c[h>>2]|0,m);fz(g,4609);fz(g,8);ez(g,0,0);fz(g,4353);fz(g,32);ez(g,0,0);ez(g,0,0);ez(g,0,0);ez(g,0,0);fz(g,4354);fz(g,4);Zy(g,0);ne[c[641096+((c[(c[m+12>>2]|0)+56>>2]|0)*52|0)>>2]&1023](a,m);x=x+1|0;}while(x>>>0<(c[k>>2]|0)>>>0);i=e;return}else{x=0;do{a=c[(c[C>>2]|0)+(x<<2)>>2]|0;BL(c[f>>2]|0,c[h>>2]|0,a,b);m=c[f>>2]|0;g=c[h>>2]|0;Ry(g,981448,13);hz(g,69376);Py(g,80);fz(g,15370);fz(g,16);j=a|0;z=c[j>>2]|0;Ry(g,160968,12);fz(g,y);fz(g,z);KL(c[f>>2]|0,c[h>>2]|0,a);fz(g,4097);fz(g,24);Zy(g,1);Zy(g,16);z=(c[m+100>>2]|0)==(a|0)?4:3;m=c[j>>2]|0;Ry(g,160968,12);fz(g,z);fz(g,m);m=c[h>>2]|0;Ry(m,981448,13);hz(m,69888);Py(m,108);fz(m,15370);fz(m,16);g=c[j>>2]|0;Ry(m,160968,12);fz(m,A);fz(m,g);KL(c[f>>2]|0,c[h>>2]|0,a);fz(m,4609);fz(m,8);ez(m,0,0);fz(m,4353);fz(m,32);a=c[f>>2]|0;Ry(c[h>>2]|0,163136,13);hz(c[h>>2]|0,c[a+120>>2]|0);Ry(c[h>>2]|0,a+124|0,15);Py(c[h>>2]|0,1);fz(m,4354);fz(m,4);Zy(m,(c[j>>2]|0)+2|0);x=x+1|0;}while(x>>>0<(c[k>>2]|0)>>>0);i=e;return}}function BL(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[d+12>>2]|0;Ry(b,981448,13);hz(b,80640);Py(b,80);fz(b,15370);fz(b,16);g=(e|0)==1;e=d|0;d=c[e>>2]|0;Ry(b,160968,12);fz(b,g?8:24);fz(b,d);fz(b,18433);fz(b,4);Zy(b,(c[e>>2]|0)+2|0);fz(b,18436);fz(b,4);if(g){Zy(b,0)}else{Ry(b,f+52|0,4)}fz(b,19201);fz(b,8);Zy(b,c[a+24>>2]|0);Zy(b,c[a+20>>2]|0);fz(b,19202);fz(b,8);ez(b,0,0);fz(b,18435);fz(b,16);a=c[e>>2]|0;Ry(b,160968,12);fz(b,g?5:21);fz(b,a);return}function CL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+16>>2]|0;e=c[b+12>>2]|0;f=b+8|0;g=c[f>>2]|0;h=c[g+840>>2]<<4|c[g+844>>2];JL(a,b,638424,13);fz(d,32768);fz(d,4);Zy(d,c[e+96>>2]|0);fz(d,32775);fz(d,1);Py(d,(c[(c[f>>2]|0)+840>>2]|0)==0?h|128:h);return}function DL(a,b){a=a|0;b=b|0;var d=0;d=c[a+16>>2]|0;HL(c[a+12>>2]|0,d,b,642968,14);fz(d,15626);fz(d,2);a=b+8|0;fz(d,c[(c[a>>2]|0)+432>>2]|0);fz(d,15625);fz(d,4);b=c[a>>2]|0;Zy(d,ba(c[b+412>>2]|0,c[b+432>>2]|0)|0);return}function EL(a,b){a=a|0;b=b|0;var d=0;d=c[a+16>>2]|0;HL(c[a+12>>2]|0,d,b,637952,14);fz(d,15626);fz(d,2);a=b+8|0;fz(d,c[(c[a>>2]|0)+432>>2]|0);fz(d,15625);fz(d,4);b=c[a>>2]|0;Zy(d,ba(c[b+412>>2]|0,c[b+432>>2]|0)|0);return}function FL(a,b){a=a|0;b=b|0;JL(a,b,642936,0);return}function GL(a,b){a=a|0;b=b|0;HL(c[a+12>>2]|0,c[a+16>>2]|0,b,640968,0);return}function HL(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;IL(a,b,d,e,f+33|0);fz(b,15618);fz(b,1);Py(b,1);fz(b,15619);fz(b,8);f=d+8|0;Zy(b,c[(c[f>>2]|0)+412>>2]|0);Zy(b,1);fz(b,15623);fz(b,4);Zy(b,c[(c[f>>2]|0)+416>>2]|0);fz(b,15617);fz(b,4);Zy(b,u0a(c[(c[f>>2]|0)+48>>2]|0)|0);return}function IL(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;g=c[d+12>>2]|0;Ry(b,e,16);Py(b,131);hz(b,f+60|0);fz(b,15370);fz(b,16);f=d|0;d=c[f>>2]|0;Ry(b,160968,12);fz(b,13);fz(b,d);fz(b,12294);fz(b,4);Zy(b,(c[f>>2]|0)+2|0);fz(b,12289);fz(b,8);Zy(b,c[a+24>>2]|0);Zy(b,c[a+20>>2]|0);fz(b,12292);fz(b,16);Ry(b,641048+((c[g+56>>2]|0)*52|0)|0,16);return}function JL(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[b+12>>2]|0;g=c[a+16>>2]|0;h=b+8|0;i=(((c[(c[h>>2]|0)+124>>2]|0)+15|0)/16|0)<<4;j=f+68|0;k=c[j>>2]|0;l=e+69+(k<<2)|0;e=l+32|0;if((k|0)==0){m=e}else{m=(c[f+72>>2]|0)==0?e:l+37|0}IL(c[a+12>>2]|0,g,b,d,m);fz(g,12803);fz(g,4);Zy(g,c[(c[h>>2]|0)+120>>2]|0);fz(g,12802);fz(g,4);Zy(g,i>>c[j>>2]);fz(g,12809);fz(g,4);Zy(g,c[(c[h>>2]|0)+120>>2]|0);i=c[(c[h>>2]|0)+124>>2]|0;if((i|0)==608){n=576}else if((i|0)==512){n=486}else{n=i}fz(g,12808);fz(g,4);Zy(g,n>>c[j>>2]);fz(g,13057);fz(g,4);Zy(g,c[f+76>>2]|0);fz(g,13058);fz(g,4);Zy(g,2);fz(g,12812);fz(g,1);Py(g,c[j>>2]|0);n=c[h>>2]|0;switch(c[n+124>>2]|0){case 720:{o=0;p=26;break};case 512:{o=270;p=7;break};case 480:{o=(c[n+48>>2]|0)==25?285:283;p=20;break};case 576:{o=(c[n+48>>2]|0)==25?335:336;p=23;break};case 608:{o=320;p=7;break};case 1080:{o=584;p=21;break};default:{o=0;p=0}}n=c[j>>2]|0;h=(n|0)==0;fz(g,12813);fz(g,(n<<2)+12|0);Zy(g,(c[j>>2]|0)!=0?2:1);Zy(g,4);Zy(g,p<<(h&1));if((c[j>>2]|0)!=0){Zy(g,h?0:o)}fz(g,12814);fz(g,8);Zy(g,c[f+84>>2]|0);Zy(g,c[f+88>>2]|0);fz(g,12801);fz(g,16);Ry(g,c[f+60>>2]|0,16);if((c[j>>2]|0)==0){return}j=f+72|0;if((c[j>>2]|0)==0){return}fz(g,12818);fz(g,1);Py(g,c[j>>2]|0);return}function KL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;fz(d,513);fz(d,16);if((c[b+100>>2]|0)==(e|0)){Ry(d,435712,16)}else{f=c[(c[e+8>>2]|0)+8>>2]|0;e=1171496;while(1){g=e|0;if((a[g]|0)==0){break}if((c[e+20>>2]|0)==(f|0)){break}else{e=e+24|0}}Ry(d,g,16)}fz(d,514);fz(d,8);g=b+72|0;ez(d,c[g>>2]|0,c[g+4>>2]|0);return}function LL(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=LT(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[d+8>>2]|0;c[f+8>>2]=0;c[f+48>>2]=147;MT(d,64,1,1e6);d=LT(a,0)|0;if((d|0)==0){e=-12;return e|0}a=c[d+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=65543;c[a+416>>2]=1;f=a+448|0;c[f>>2]=4;c[f+4>>2]=0;c[a+412>>2]=8e3;c[a+792>>2]=8;c[a+432>>2]=1;MT(d,64,1,1e6);d=b+16|0;TGb(b|0,0,16)|0;c[d>>2]=0;c[d+4>>2]=-2147483648;c[b+24>>2]=0;e=0;return e|0}function ML(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;f=i;g=b+12|0;h=c[g>>2]|0;j=b+16|0;if((Xy(c[j>>2]|0)|0)!=0){k=-541478725;i=f;return k|0}l=h+24|0;m=h+4|0;n=h+16|0;o=h+8|0;p=b;a:while(1){if((c[(c[j>>2]|0)+76>>2]|0)!=0){k=-541478725;q=63;break}b=c[l>>2]|0;do{if(b>>>0<4>>>0){r=c[g>>2]|0;s=r+4|0;t=r;u=c[t>>2]|0;v=u;w=(c[s>>2]|0)-v|0;x=lc(w|0,1027)|0;if(F){k=-12;q=63;break a}y=r+8|0;z=(c[y>>2]|0)-v|0;v=jEb(u,r+12|0,x+16|0)|0;if((v|0)==0){k=-12;q=63;break a}c[t>>2]=v;c[s>>2]=v+w;if((c[y>>2]|0)!=0){c[y>>2]=v+z}z=r+24|0;r=c[z>>2]|0;y=mz(c[j>>2]|0,v+(r+w)|0,1027-r|0)|0;if((y|0)<0){k=y;q=63;break a}c[z>>2]=(c[z>>2]|0)+y;y=c[l>>2]|0;z=c[m>>2]|0;r=z+y|0;if(y>>>0>3>>>0){A=y;B=z;C=r;q=12;break}w=y-3|0;v=z+w|0;b:do{if((w|0)>0){s=z;while(1){t=s;x=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;if((x&-2139062144&-16843010-x|0)!=0){if((x&255)<<24>>24==-1){D=s;break b}x=s+1|0;if((a[x]|0)==-1){D=x;break b}x=s+2|0;if((a[x]|0)==-1){D=x;break b}x=s+3|0;if((a[x]|0)==-1){D=x;break b}}x=s+4|0;if(x>>>0<v>>>0){s=x}else{E=x;q=28;break}}}else{E=z;q=28}}while(0);c:do{if((q|0)==28){while(1){q=0;if(!(E>>>0<r>>>0)){D=r;break c}if((a[E]|0)==-1){D=E;break}else{E=E+1|0;q=28}}}}while(0);if(!(D>>>0<(z+(y-1)|0)>>>0)){k=-541478725;q=63;break a}if((a[D+1|0]|0)==-39){G=r;H=D;I=r;q=32}else{k=-541478725;q=63;break a}}else{v=c[m>>2]|0;A=b;B=v;C=v+b|0;q=12}}while(0);d:do{if((q|0)==12){q=0;b=B+(A-3)|0;v=A-6|0;w=B+v|0;if((v|0)>0){v=B;while(1){s=v;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;if((x&-2139062144&-16843010-x|0)!=0){if((x&255)<<24>>24==-1){G=b;H=v;I=C;q=32;break d}x=v+1|0;if((a[x]|0)==-1){G=b;H=x;I=C;q=32;break d}x=v+2|0;if((a[x]|0)==-1){G=b;H=x;I=C;q=32;break d}x=v+3|0;if((a[x]|0)==-1){G=b;H=x;I=C;q=32;break d}}x=v+4|0;if(x>>>0<w>>>0){v=x}else{J=x;break}}}else{J=B}while(1){if(!(J>>>0<b>>>0)){K=b;q=62;break d}if((a[J]|0)==-1){G=b;H=J;I=C;q=32;break}else{J=J+1|0}}}}while(0);do{if((q|0)==32){q=0;if((H|0)==(G|0)){K=H;q=62;break}b=a[H+1|0]|0;v=H+2|0;c[m>>2]=v;w=I-v|0;c[l>>2]=w;if((b<<24>>24|0)==(-39|0)){if((c[o>>2]|0)!=0){q=38;break a}yDb(p,24,2135912,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}else if((b<<24>>24|0)==(-40|0)){c[o>>2]=H;break}else{if(!((b+64&255)>>>0<16>>>0)){if((b&255)>>>0<218>>>0|b<<24>>24==-1){break}}r=v;y=de((d[r]|d[r+1|0]<<8)<<16>>16|0)|0;L=y&65535;if((y&65535)>>>0<2>>>0){k=-22;q=63;break a}if(w>>>0<L>>>0){r=c[g>>2]|0;z=r+4|0;x=r;s=c[x>>2]|0;t=s;u=(c[z>>2]|0)-t|0;M=lc(u|0,L|0)|0;if(F){k=-12;q=63;break a}N=r+8|0;O=(c[N>>2]|0)-t|0;t=jEb(s,r+12|0,M+16|0)|0;if((t|0)==0){k=-12;q=63;break a}c[x>>2]=t;c[z>>2]=t+u;if((c[N>>2]|0)!=0){c[N>>2]=t+O}O=r+24|0;r=c[O>>2]|0;N=mz(c[j>>2]|0,t+(r+u)|0,L-r|0)|0;if((N|0)<0){k=N;q=63;break a}c[O>>2]=(c[O>>2]|0)+N;N=c[m>>2]|0;P=N-2|0;Q=0;R=N}else{P=H;Q=w-L|0;R=v}c[l>>2]=Q;c[m>>2]=R+L;if(b<<24>>24==-19&(y&65535)>>>0>15>>>0){q=55;break a}if(!(b<<24>>24==-2&(y&65535)>>>0>17>>>0)){break}if((RGb(P+4|0,2071088,3)|0)!=0){break}y=P+12|0;b=y|0;v=y+4|0;y=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[n>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[n+4>>2]=y;break}}}while(0);if((q|0)==62){q=0;c[m>>2]=K;c[l>>2]=3}if((Xy(c[j>>2]|0)|0)!=0){k=-541478725;q=63;break}}if((q|0)==38){j=c[n>>2]|0;K=c[n+4>>2]|0;n=e+16|0;c[n>>2]=j;c[n+4>>2]=K;n=e+8|0;c[n>>2]=j;c[n+4>>2]=K;c[e+32>>2]=0;c[e+52>>2]=0;c[e>>2]=0;K=c[o>>2]|0;n=(c[m>>2]|0)-K|0;j=e+28|0;c[j>>2]=n;c[e+24>>2]=K;K=h;R=c[K>>2]|0;Q=c[l>>2]|0;if(((c[o>>2]|0)-R|0)>>>0>Q>>>0){if((Q|0)==0){S=R;T=n}else{UGb(R|0,c[m>>2]|0,Q)|0;S=c[K>>2]|0;T=c[j>>2]|0}c[m>>2]=S;U=T}else{U=n}c[o>>2]=0;k=U;i=f;return k|0}else if((q|0)==55){U=P+8|0;o=U|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=U+4|0;U=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;c[o>>2]=n;c[o+4>>2]=U;o=e+8|0;c[o>>2]=n;c[o+4>>2]=U;c[e+32>>2]=1;c[e+52>>2]=0;c[e>>2]=0;U=L-14|0;L=e+28|0;c[L>>2]=U;c[e+24>>2]=P+16;e=h;h=c[e>>2]|0;o=c[l>>2]|0;if(!((P-h|0)>>>0>o>>>0)){k=U;i=f;return k|0}if((o|0)==0){V=h;W=U}else{UGb(h|0,c[m>>2]|0,o)|0;V=c[e>>2]|0;W=c[L>>2]|0}c[m>>2]=V;k=W;i=f;return k|0}else if((q|0)==63){i=f;return k|0}return 0}function NL(a){a=a|0;$Db(c[a+12>>2]|0);return 0}function OL(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;e=b;if(!((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==-1526661120)){f=0;return f|0}e=b+5|0;g=(d[e]|d[e+1|0]<<8)<<16>>16&65535;if((g+20|0)>(c[a+8>>2]|0)){f=25;return f|0}a=b+(g+16)|0;f=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==-1526661120?100:0;return f|0}function PL(a){a=a|0;var b=0,d=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=13;c[b+236>>2]=1;MT(b,64,1,100);d=0;return d|0}function QL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a+16|0;f=-1;g=c[e>>2]|0;do{if((Xy(g)|0)!=0){h=-5;j=10;break}f=(lz(c[e>>2]|0)|0)+(f<<8)|0;g=c[e>>2]|0}while((f|0)!=421);if((j|0)==10){i=d;return h|0}lz(g)|0;g=pz(c[e>>2]|0)|0;Vy(c[e>>2]|0,9,0)|0;if((g|0)==0){yDb(a,48,2071048,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;h=-11;i=d;return h|0}a=TS(c[e>>2]|0,b,g)|0;if((a|0)==(g|0)){c[b+32>>2]=0;h=g;i=d;return h|0}if((a|0)<=0){h=-5;i=d;return h|0}BZ(b);h=-5;i=d;return h|0}function RL(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b|0;e=b+4|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1414744398&(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==172044639?100:0)|0}function SL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+176|0;d=b+96|0;e=b+104|0;f=b+32|0;UGb(f|0,637424,32)|0;g=b+64|0;UGb(g|0,637392,32)|0;c[d>>2]=0;c[e>>2]=-1;h=LT(a,0)|0;if((h|0)==0){j=-12;i=b;return j|0}k=h+8|0;c[(c[k>>2]|0)+8>>2]=1;l=a+16|0;m=b|0;wz(c[l>>2]|0,m,32)|0;wz(c[l>>2]|0,m,32)|0;xd(m|0,2071040,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;if((c[e>>2]|0)<1){j=-1094995529;i=b;return j|0}if((Xy(c[l>>2]|0)|0)!=0){j=-541478725;i=b;return j|0}o=h+56|0;p=b+112|0;q=b+144|0;r=a+1140|0;s=a;a=0;a:while(1){wz(c[l>>2]|0,m,32)|0;t=Ty(c[l>>2]|0,0,0,1)|0;u=F;v=c[e>>2]|0;w=(v|0)<0|0?-1:0;if(!((u|0)<(w|0)|(u|0)==(w|0)&t>>>0<v>>>0)){j=-1094995529;x=40;break}if((PGb(m,2023232,8)|0)==0){x=7;break}do{if((PGb(m,2340224,13)|0)==0){xd(m|0,2316784,(n=i,i=i+8|0,c[n>>2]=(c[k>>2]|0)+416,n)|0)|0;i=n;y=a}else{if((PGb(m,2295320,18)|0)==0){xd(m|0,2278760,(n=i,i=i+8|0,c[n>>2]=g,n)|0)|0;i=n;if((yAb(g,2263456)|0)==0){y=0;break}if((yAb(g,2248400)|0)==0){y=1;break}if((yAb(g,2235448)|0)==0){y=a;break}else{x=26;break a}}if((PGb(m,2212880,13)|0)==0){xd(m|0,2278760,(n=i,i=i+8|0,c[n>>2]=f,n)|0)|0;i=n;y=a;break}if((PGb(m,2203528,12)|0)==0){xd(m|0,2196136,(n=i,i=i+8|0,c[n>>2]=o,n)|0)|0;i=n;y=a;break}if((PGb(m,2182680,14)|0)==0){xd(m|0,2316784,(n=i,i=i+8|0,c[n>>2]=d,n)|0)|0;i=n;y=a;break}if((PGb(m,2168360,11)|0)==0){xd(m|0,2316784,(n=i,i=i+8|0,c[n>>2]=(c[k>>2]|0)+412,n)|0)|0;i=n;y=a;break}if((PGb(m,2160912,15)|0)==0){xd(m|0,2316784,(n=i,i=i+8|0,c[n>>2]=(c[k>>2]|0)+792,n)|0)|0;i=n;y=a;break}v=xd(m|0,2154240,(n=i,i=i+16|0,c[n>>2]=p,c[n+8>>2]=q,n)|0)|0;i=n;if((v|0)==3){CBb(r,p,q,32)|0;y=a;break}else{yDb(s,16,2147056,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;y=a;break}}}while(0);if((Xy(c[l>>2]|0)|0)==0){a=y}else{j=-541478725;x=40;break}}if((x|0)==7){y=(c[k>>2]|0)+792|0;if((c[y>>2]|0)==0){c[y>>2]=c[d>>2]<<3}b:do{if((yAb(f,1979776)|0)==0){d=wT(c[(c[k>>2]|0)+792>>2]|0,0,a,65535)|0;y=c[k>>2]|0;c[y+48>>2]=d;z=y}else{if((yAb(f,1949872)|0)==0){y=c[k>>2]|0;c[y+48>>2]=65543;z=y;break}do{if((yAb(f,1924176)|0)!=0){if((yAb(f,1902336)|0)==0){break}DDb(s,1882352,(n=i,i=i+8|0,c[n>>2]=f,n)|0);i=n;z=c[k>>2]|0;break b}}while(0);y=c[k>>2]|0;c[y+48>>2]=65542;z=y}}while(0);MT(h,64,1,c[z+412>>2]|0);z=c[k>>2]|0;c[z+432>>2]=(ba(c[z+416>>2]|0,c[z+792>>2]|0)|0)/8|0;z=Ty(c[l>>2]|0,0,0,1)|0;k=F;h=c[e>>2]|0;e=h;f=(h|0)<0|0?-1:0;if((k|0)>(f|0)|(k|0)==(f|0)&z>>>0>e>>>0){j=-1094995529;i=b;return j|0}z=c[l>>2]|0;l=Ty(z,0,0,1)|0;k=ZGb(e,f,l,F)|0;Vy(z,k,F)|0;j=0;i=b;return j|0}else if((x|0)==26){DDb(s,2222240,(n=i,i=i+8|0,c[n>>2]=g,n)|0);i=n;j=-1163346256;i=b;return j|0}else if((x|0)==40){i=b;return j|0}return 0}function TL(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[b+4>>2]|0;do{if((a[e]|0)==78){if((a[e+1|0]|0)!=83){break}if((a[e+2|0]|0)!=86){break}f=a[e+3|0]|0;if((f<<24>>24|0)==102|(f<<24>>24|0)==115){g=100}else{break}return g|0}}while(0);f=c[b+8>>2]|0;h=f-3|0;a:do{if((h|0)>1){i=0;j=1;b:while(1){k=e+j|0;do{if((d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)==1935037262){l=e+(j+22)|0;m=j+24+((d[l]|d[l+1|0]<<8)<<16>>16&65535)+((d[e+(j+20)|0]<<8|d[e+(j+21)|0]<<16|d[e+(j+19)|0])>>>4)|0;if((m|0)>(f-2|0)){n=20;break}l=e+m|0;if((d[l]|d[l+1|0]<<8)<<16>>16<<16>>16==-16657){g=80;break b}else{n=20}}else{n=i}}while(0);k=j+1|0;if((k|0)<(h|0)){i=n;j=k}else{o=n;break a}}return g|0}else{o=0}}while(0);n=(TC(c[b>>2]|0,1927600)|0)==0;g=n?o:50;return g|0}function UL(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b+12|0;e=c[d>>2]|0;f=e+16|0;c[f>>2]=0;c[e+128>>2]=0;c[e+48>>2]=0;e=b+16|0;g=b+1140|0;h=0;a:while(1){if((h|0)>=300){break}i=c[d>>2]|0;j=c[e>>2]|0;k=0;l=0;while(1){if((Xy(j)|0)!=0){m=5;break a}n=lz(j)|0|k;if((n&65535|0)==61374){m=7;break}if((n|0)==1314084454){m=9;break}else if((n|0)==1314084467){m=10;break}o=l+1|0;if((o|0)<512e3){k=n<<8;l=o}else{p=-1;m=39;break a}}if((m|0)==7){m=0;c[i+16>>2]=5}else if((m|0)==9){m=0;c[i+16>>2]=1}else if((m|0)==10){m=0;c[i+16>>2]=3}l=c[f>>2]|0;if((l|0)==1){k=c[d>>2]|0;j=c[e>>2]|0;o=k+16|0;c[o>>2]=0;n=rz(j)|0;if(n>>>0<28>>>0){p=-1;m=39;break}c[k+4>>2]=n;rz(j)|0;q=k+184|0;c[q>>2]=rz(j)|0;c[q+4>>2]=0;q=rz(j)|0;r=rz(j)|0;s=rz(j)|0;if((Xy(j)|0)!=0){p=-1;m=39;break}if((q|0)>0){t=cEb(q+1|0)|0;if((t|0)==0){p=-12;m=39;break}u=t+q|0;mz(j,t,q)|0;v=t+(q-2)|0;q=t;while(1){if((a[q]|0)==32){q=q+1|0;continue}if(!(q>>>0<v>>>0)){break}w=Vb(q|0,61)|0;if(!((w|0)!=0&w>>>0<v>>>0)){break}a[w]=0;x=w+2|0;y=Vb(x|0,a[w+1|0]|0)|0;if(!((y|0)!=0&y>>>0<u>>>0)){break}w=y+1|0;a[y]=0;CBb(g,q,x,0)|0;if(w>>>0<u>>>0){q=w}else{break}}ZDb(t)}if((Xy(j)|0)!=0){p=-1;m=39;break}do{if((s|0)>0){c[k+12>>2]=s;if(s>>>0>1073741822>>>0){p=-1;m=39;break a}q=s<<2;u=WDb(q)|0;v=k+8|0;c[v>>2]=u;if((u|0)==0){p=-12;m=39;break a}else{z=0}do{u=(rz(j)|0)+n|0;c[(c[v>>2]|0)+(z<<2)>>2]=u;z=z+1|0;}while((z|0)<(s|0));if((r|0)<=(s|0)){break}if((rz(j)|0)!=843272020){break}v=WDb(q)|0;u=k+216|0;c[u>>2]=v;if((v|0)==0){p=-12;m=39;break a}else{A=0}do{v=rz(j)|0;c[(c[u>>2]|0)+(A<<2)>>2]=v;A=A+1|0;}while((A|0)<(s|0))}}while(0);Ty(j,(c[k>>2]|0)+n|0,0,0)|0;if((Xy(j)|0)!=0){p=-1;m=39;break}c[o>>2]=2;B=c[f>>2]|0}else{B=l}if((B|0)==3){m=36;break}else{h=h+1|0}}do{if((m|0)==5){c[i+16>>2]=0;p=-1;return p|0}else if((m|0)==36){h=ZL(b)|0;if((h|0)<0){p=h}else{break}return p|0}else if((m|0)==39){return p|0}}while(0);if((c[b+24>>2]|0)==0){p=-1;return p|0}p=YL(b,1)|0;return p|0}function VL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[a+12>>2]|0;e=d+24|0;do{if((c[d+48>>2]|0)==0){if((c[d+128>>2]|0)!=0){f=0;break}g=YL(a,0)|0;if((g|0)<0){h=g}else{f=0;break}return h|0}else{f=0}}while(0);while(1){if((f|0)>=2){h=-1;i=7;break}j=e+(f*80|0)+24|0;if((c[j>>2]|0)==0){f=f+1|0}else{break}}if((i|0)==7){return h|0}UGb(b|0,e+(f*80|0)|0,80)|0;c[j>>2]=0;h=c[b+28>>2]|0;return h|0}function WL(a){a=a|0;var b=0;b=c[a+12>>2]|0;$Db(b+8|0);$Db(b+216|0);if((c[b+48>>2]|0)!=0){BZ(b+24|0)}if((c[b+128>>2]|0)==0){return 0}BZ(b+104|0);return 0}function XL(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[a+12>>2]|0;h=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[h+12>>2]|0;i=oT(h,d,e,f)|0;if((i|0)<0){j=-1;return j|0}f=h+400|0;h=(c[f>>2]|0)+(i*24|0)|0;e=Ty(c[a+16>>2]|0,c[h>>2]|0,c[h+4>>2]|0,0)|0;h=F;a=0;if((h|0)<(a|0)|(h|0)==(a|0)&e>>>0<0>>>0){j=-1;return j|0}c[b>>2]=c[(c[f>>2]|0)+(i*24|0)+8>>2];c[g+16>>2]=0;j=0;return j|0}function YL(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;e=i;i=i+8|0;f=e|0;g=f;h=a+12|0;j=c[h>>2]|0;k=a+16|0;l=c[k>>2]|0;c[f>>2]=0;c[f+4>>2]=0;m=j+24|0;if((c[j+48>>2]|0)!=0){n=0;i=e;return n|0}o=j+104|0;if((c[j+128>>2]|0)!=0){n=0;i=e;return n|0}if((Xy(l)|0)!=0){n=-1;i=e;return n|0}p=j+16|0;q=0;r=0;while(1){if((c[p>>2]|0)>>>0<3>>>0&(r|0)==0){s=c[h>>2]|0;t=c[k>>2]|0;u=0;v=0;while(1){if((Xy(t)|0)!=0){w=8;break}x=lz(t)|0|u;if((x&65535|0)==61374){w=10;break}if((x|0)==1314084454){w=12;break}else if((x|0)==1314084467){w=13;break}y=v+1|0;if((y|0)<512e3){u=x<<8;v=y}else{z=-1;break}}if((w|0)==8){w=0;c[s+16>>2]=0;z=-1}else if((w|0)==10){w=0;c[s+16>>2]=5;z=0}else if((w|0)==12){w=0;c[s+16>>2]=1;z=0}else if((w|0)==13){w=0;c[s+16>>2]=3;z=0}v=q+1|0;if((v|0)<300){q=v;r=z;continue}else{A=z}}else{A=r}if((A|0)<0){n=A;w=48;break}if((c[p>>2]|0)==3){B=ZL(a)|0}else{B=A}if((B|0)<0){n=B;w=48;break}if(!(((c[p>>2]|0)-4|0)>>>0<2>>>0)){n=-1;w=48;break}v=lz(l)|0;u=pz(l)|0;C=pz(l)|0;D=C&65535;t=u<<4|v>>>4&15;u=v&15;if((u|0)==0){E=t}else{v=0;y=t;while(1){t=pz(l)|0;rz(l)|0;x=t&65535;Vy(l,x,0)|0;t=y-6-x|0;x=v+1|0;if((x|0)<(u|0)){v=x;y=t}else{E=t;break}}}if((Xy(l)|0)!=0){n=-1;w=48;break}G=(E|0)!=0;if(!(D<<16>>16==0&(G^1))){w=26;break}c[p>>2]=0;if((Xy(l)|0)==0){q=0;r=B}else{n=-1;w=48;break}}if((w|0)==26){B=c[a+24>>2]|0;do{if((B|0)!=0){r=c[a+28>>2]|0;q=c[r>>2]|0;c[g+(c[q+4>>2]<<2)>>2]=q;if(!(B>>>0>1>>>0)){break}q=c[r+4>>2]|0;c[g+(c[q+4>>2]<<2)>>2]=q}}while(0);B=c[f>>2]|0;f=(B|0)==0;do{if(G){if(f){H=0;I=1;break}q=c[B+12>>2]|0;TS(l,m,E)|0;c[j+56>>2]=c[B>>2];r=c[q>>2]|0;q=j+40|0;c[q>>2]=r;c[q+4>>2]=(r|0)<0|0?-1:0;r=j+60|0;c[r>>2]=(c[p>>2]|0)==4|c[r>>2];w=33}else{if(f){H=0;I=1}else{w=33}}}while(0);if((w|0)==33){f=c[B+12>>2]|0;c[f>>2]=(c[f>>2]|0)+1;H=B;I=0}do{if((C&65535|0)!=0){B=c[g+4>>2]|0;if((B|0)==0){break}f=c[B+12>>2]|0;E=B+8|0;do{if((c[(c[E>>2]|0)+52>>2]|0)==541934416){m=lz(l)|0;G=lz(l)|0;r=pz(l)|0;q=C+65532&65535;if((d|0)==0){J=q;break}c[B+236>>2]=0;if((G&255)<<24>>24==0){yDb(a,24,2135760,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;K=m&255}else{K=(((m&255)>>>0)/((G&255)>>>0)|0)&255}G=c[E>>2]|0;if(K<<24>>24==8){c[G+48>>2]=65541}c[G+416>>2]=1;c[G+412>>2]=r>>>2&16383;J=q}else{J=D}}while(0);TS(l,o,J&65535)|0;c[j+136>>2]=c[B>>2];E=(c[p>>2]|0)==4;q=j+140|0;c[q>>2]=E&1|c[q>>2];if(!(I|E^1)){E=(c[c[H+12>>2]>>2]|0)-1|0;q=j+120|0;r=c[j+212>>2]|0;G=gHb(r,(r|0)<0|0?-1:0,1e3,0)|0;r=gHb(G,F,E,(E|0)<0|0?-1:0)|0;E=F;G=b[j+204>>1]|0;m=c[j+208>>2]|0;A=gHb(m,(m|0)<0|0?-1:0,G<<16>>16,G<<16>>16<0|0?-1:0)|0;G=YGb(A,F,r,E)|0;c[q>>2]=G;c[q+4>>2]=F}q=f;c[q>>2]=(c[q>>2]|0)+1}}while(0);c[p>>2]=0;n=0;i=e;return n|0}else if((w|0)==48){i=e;return n|0}return 0}function ZL(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=rz(e)|0;g=rz(e)|0;h=pz(e)|0;i=h&65535;j=pz(e)|0;k=lz(e)|0;do{if((k&128|0)==0){l=1;m=k}else{n=k>>>2&31;o=n>>>0<16>>>0;p=o?1:n-15|0;q=o?n+1|0:1;if((k&1|0)==0){r=q;s=p}else{r=q*1001|0;s=p*1e3|0}p=k&3;if((p|0)==2){l=r;m=s*25|0;break}else if((p|0)==3){l=r;m=s*24|0;break}else{l=r;m=s*30|0;break}}}while(0);b[d+204>>1]=pz(e)|0;c[d+208>>2]=m;c[d+212>>2]=l;a:do{if((c[a+24>>2]|0)==0){c[d+192>>2]=f;c[d+196>>2]=g;b[d+200>>1]=i;b[d+202>>1]=i;do{if((f|0)==1162760014){t=18}else{e=LT(a,0)|0;if((e|0)==0){break}c[e+4>>2]=0;s=cEb(28)|0;if((s|0)==0){break}c[e+12>>2]=s;s=e+8|0;r=c[s>>2]|0;c[r+8>>2]=0;c[r+52>>2]=f;r=vT(630288,f)|0;k=c[s>>2]|0;c[k+48>>2]=r;c[k+120>>2]=h&65535;c[k+124>>2]=j&65535;c[k+792>>2]=24;MT(e,64,l,m);k=e+48|0;c[k>>2]=0;c[k+4>>2]=0;k=d+184|0;r=m;s=(m|0)<0|0?-1:0;p=l*1e3|0;q=p;n=(p|0)<0|0?-1:0;p=IDb(c[k>>2]|0,c[k+4>>2]|0,r,s,q,n)|0;o=e+56|0;c[o>>2]=p;c[o+4>>2]=F;o=d+12|0;p=c[o>>2]|0;if((p|0)<=0){t=18;break}u=d+216|0;v=d+8|0;w=0;x=p;while(1){p=c[u>>2]|0;if((p|0)==0){y=gHb(c[k>>2]|0,c[k+4>>2]|0,w,(w|0)<0|0?-1:0)|0;z=eHb(y,F,x,(x|0)<0|0?-1:0)|0;y=IDb(z,F,r,s,q,n)|0;jT(e,c[(c[v>>2]|0)+(w<<2)>>2]|0,0,y,F,0,0,1)|0}else{jT(e,c[(c[v>>2]|0)+(w<<2)>>2]|0,0,c[p+(w<<2)>>2]|0,0,0,0,1)|0}p=w+1|0;y=c[o>>2]|0;if((p|0)<(y|0)){w=p;x=y}else{t=18;break}}}}while(0);do{if((t|0)==18){if((g|0)==1162760014){break a}x=LT(a,0)|0;if((x|0)==0){break}c[x+4>>2]=1;w=cEb(28)|0;if((w|0)==0){break}c[x+12>>2]=w;w=x+8|0;o=c[w>>2]|0;c[o+8>>2]=1;c[o+52>>2]=g;o=vT(630392,g)|0;c[(c[w>>2]|0)+48>>2]=o;c[x+236>>2]=1;MT(x,64,1,m*1e3|0);o=x+48|0;c[o>>2]=0;c[o+4>>2]=0;o=d+184|0;w=gHb(c[o>>2]|0,c[o+4>>2]|0,m,(m|0)<0|0?-1:0)|0;o=x+56|0;c[o>>2]=w;c[o+4>>2]=F;break a}}while(0);c[d+16>>2]=0;A=-1;return A|0}}while(0);c[d+16>>2]=4;A=0;return A|0}function _L(a,b){a=a|0;b=b|0;return 0}function $L(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+8>>2]|0;if((b|0)<=0){e=0;return e|0}f=c[a+4>>2]|0;a=0;g=0;h=0;while(1){i=d[f+a|0]|0|h;j=g|0;if((i|0)==526320813&(j|0)==1313700438){e=100;k=5;break}l=a+1|0;if((l|0)<(b|0)){a=l;g=j<<8|i>>>24;h=i<<8|0>>>24}else{e=0;k=5;break}}if((k|0)==5){return e|0}return 0}function aM(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+32|0;l=c[e+12>>2]|0;m=l;n=c[e+16>>2]|0;o=l;c[o>>2]=e;p=l+3780|0;q=l+3784|0;r=l+3736|0;s=l+3740|0;t=l+3756|0;u=l+940|0;v=l+3752|0;w=l+3076|0;x=l+3728|0;y=0;z=0;a:while(1){A=-1;if((y|0)>(A|0)|(y|0)==(A|0)&z>>>0>-1>>>0){Ty(n,z,y,0)|0;}if((Xy(n)|0)==0){B=0;C=0}else{D=9;break}while(1){A=lz(n)|0;E=A|(C<<8|0>>>24);G=((A|0)<0|0?-1:0)|(B<<8|C>>>24);if((E&0|0)==0&(G&-16777216|0)==1308622848){A=790881870;H=1314446695;I=1542650331;J=1314066752;K=-288733847;L=1313596589;M=-1248413064;N=1313450856;if((E|0)==526320813&(G|0)==1313700438){break}else if((E|0)==(M|0)&(G|0)==(N|0)|(E|0)==(K|0)&(G|0)==(L|0)|(E|0)==(I|0)&(G|0)==(J|0)|(E|0)==(A|0)&(G|0)==(H|0)){y=-1;z=-1;continue a}}if((Xy(n)|0)==0){B=G;C=E}else{D=9;break a}}E=Ty(n,0,0,1)|0;G=F;H=YGb(E,G,-8,-1)|0;A=F;J=0;if((A|0)<(J|0)|(A|0)==(J|0)&H>>>0<0>>>0){D=9;break}H=YGb(E,G,-7,-1)|0;G=F;O=c[o>>2]|0;E=c[O+16>>2]|0;J=gM(E,1,526320813,1313700438)|0;A=Ty(E,0,0,1)|0;I=YGb(J,(J|0)<0|0?-1:0,A,F)|0;A=F;J=Bz(E)|0;L=J;c[p>>2]=L;if((L|0)>3){L=Bz(E)|0;c[q>>2]=L}L=Bz(E)|0;J=F;K=0;if(!(((L|0)!=0|(J|0)!=0)&(J>>>0<K>>>0|J>>>0==K>>>0&L>>>0<257>>>0))){yDb(O,16,1926992,(P=i,i=i+16|0,c[P>>2]=L,c[P+8>>2]=J,P)|0);i=P;y=G;z=H;continue}Q=L;L=Bz(E)|0;J=L;c[r>>2]=J;if(J>>>0>65536>>>0){yDb(O,48,1925256,(P=i,i=i+8|0,c[P>>2]=J,P)|0);i=P;c[r>>2]=65536}J=Bz(E)|0;L=F;K=0;if(!(((J|0)!=0|(L|0)!=0)&(L>>>0<K>>>0|L>>>0==K>>>0&J>>>0<268435455>>>0))){yDb(O,16,1923936,(P=i,i=i+16|0,c[P>>2]=J,c[P+8>>2]=L,P)|0);i=P;y=G;z=H;continue}L=J;c[s>>2]=L;J=WDb(L<<3)|0;c[t>>2]=J;if((J|0)==0){y=G;z=H;continue}else{R=0}while(1){if(!(R>>>0<(c[s>>2]|0)>>>0)){S=0;T=0;U=1;V=0;W=0;D=27;break}X=Bz(E)|0;Y=F;J=0;if(!(((X|0)!=0|(Y|0)!=0)&(Y>>>0<J>>>0|Y>>>0==J>>>0&X>>>0<-2147483648>>>0))){D=21;break}c[(c[t>>2]|0)+(R<<3)>>2]=X;Z=Bz(E)|0;_=F;J=0;if(!(((Z|0)!=0|(_|0)!=0)&(_>>>0<J>>>0|_>>>0==J>>>0&Z>>>0<-2147483648>>>0))){D=23;break}J=Z;L=c[t>>2]|0;c[L+(R<<3)+4>>2]=J;K=c[L+(R<<3)>>2]|0;L=GDb(K,(K|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;if((L|0)==1&(F|0)==0){R=R+1|0}else{D=25;break}}if((D|0)==21){D=0;yDb(O,16,1922256,(P=i,i=i+16|0,c[P>>2]=X,c[P+8>>2]=Y,P)|0);i=P;y=G;z=H;continue}else if((D|0)==23){D=0;yDb(O,16,1920712,(P=i,i=i+16|0,c[P>>2]=Z,c[P+8>>2]=_,P)|0);i=P;y=G;z=H;continue}else if((D|0)==25){D=0;yDb(O,16,1919e3,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;y=G;z=H;continue}else if((D|0)==27){while(1){D=0;L=Bz(E)|0;J=Bz(E)|0;K=J;do{if((K|0)>0){J=Bz(E)|0;N=YGb(J,F,1,0)|0;J=F;M=(N&1|0)==0&(J&0|0)==0;$=N>>>1|J<<31;N=J>>1|((J|0)<0|0?-1:0)<<31;J=ZGb(0,0,$,N)|0;aa=F;ba=M?$:J;M?N:aa;aa=ba&65535;if((K|0)<=1){ca=0;da=U;ea=aa;fa=T;ga=0;D=34;break}ba=Bz(E)|0;N=ba;if((K|0)<=2){ca=0;da=N;ea=aa;fa=T;ga=0;D=34;break}ba=Bz(E)|0;M=ba;if((K|0)<=3){ca=0;da=N;ea=aa;fa=M;ga=0;D=34;break}ba=Bz(E)|0;J=ba;if((K|0)<=4){ca=J;da=N;ea=aa;fa=M;ga=0;D=34;break}ba=Bz(E)|0;$=ba&255;if((K|0)<=5){ca=J;da=N;ea=aa;fa=M;ga=$;D=34;break}ba=Bz(E)|0;ha=ba;ia=J;ja=N;ka=aa;la=M;ma=$}else{ca=0;da=U;ea=V;fa=T;ga=0;D=34}}while(0);if((D|0)==34){D=0;ha=da-ca|0;ia=ca;ja=da;ka=ea;la=fa;ma=ga}do{if((K|0)>6){Bz(E)|0;if((K|0)<=7){na=W;break}$=Bz(E)|0;M=$&255;if((K|0)>8){oa=K}else{na=M;break}while(1){$=oa-1|0;Bz(E)|0;if(($|0)>8){oa=$}else{na=M;break}}}else{na=W}}while(0);if((ha|0)==0){pa=0;D=41;break}if((ha+S|0)>256){pa=ha;D=41;break}if(!(la>>>0<Q>>>0)){D=45;break}if((ha|0)>0){K=L&65535;M=la&255;$=ja&65535;aa=S;N=0;while(1){if((aa|0)==78){b[u>>1]=8192;qa=N-1|0}else{b[m+4+(aa*12|0)>>1]=K;b[m+4+(aa*12|0)+8>>1]=ka;a[m+4+(aa*12|0)+2|0]=M;b[m+4+(aa*12|0)+4>>1]=$;b[m+4+(aa*12|0)+6>>1]=N+ia;a[m+4+(aa*12|0)+10|0]=ma;a[m+4+(aa*12|0)+11|0]=na;qa=N}J=qa+1|0;ba=aa+1|0;if((J|0)<(ha|0)){aa=ba;N=J}else{ra=ba;break}}}else{ra=S}if((ra|0)<256){S=ra;T=la;U=ja;V=ka;W=na;D=27}else{D=50;break}}if((D|0)==41){D=0;yDb(O,16,1913672,(P=i,i=i+16|0,c[P>>2]=pa,c[P+8>>2]=S,P)|0);i=P;y=G;z=H;continue}else if((D|0)==45){D=0;yDb(O,16,1909632,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;y=G;z=H;continue}else if((D|0)==50){D=0;if((b[u>>1]|0)!=8192){D=51;break}N=Ty(E,0,0,1)|0;aa=YGb(N,F,4,0)|0;N=F;if(A>>>0>N>>>0|A>>>0==N>>>0&I>>>0>aa>>>0){aa=Bz(E)|0;N=F;$=0;if(!(N>>>0<$>>>0|N>>>0==$>>>0&aa>>>0<128>>>0)){yDb(O,16,1906688,(P=i,i=i+16|0,c[P>>2]=aa,c[P+8>>2]=N,P)|0);i=P;y=G;z=H;continue}N=aa;c[v>>2]=N+1;b:do{if((N|0)>0){aa=1;$=1024;while(1){sa=Bz(E)|0;ta=F;M=0;if(!(((sa|0)!=0|(ta|0)!=0)&(ta>>>0<M>>>0|ta>>>0==M>>>0&sa>>>0<256>>>0))){D=57;break}M=m+3076+aa|0;a[M]=sa;K=sa&255;$=$-K|0;if(($|0)<0){D=59;break}L=WDb(K)|0;if((L|0)==0){y=G;z=H;continue a}mz(E,L,d[M]|0)|0;c[m+3204+(aa<<2)>>2]=L;aa=aa+1|0;if((aa|0)>=(c[v>>2]|0)){break b}}if((D|0)==57){D=0;yDb(O,16,1905120,(P=i,i=i+16|0,c[P>>2]=sa,c[P+8>>2]=ta,P)|0);i=P;y=G;z=H;continue a}else if((D|0)==59){D=0;yDb(O,16,1903200,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;y=G;z=H;continue a}}}while(0);if((a[w]|0)!=0){D=63;break}}N=Ty(E,0,0,1)|0;aa=F;$=ZGb(I,A,N,aa)|0;L=F;M=0;do{if((L|0)<(M|0)|(L|0)==(M|0)&$>>>0<0>>>0){Ty(E,$,L,1)|0;}else{if(!((N|0)==(I|0)&(aa|0)==(A|0))){K=L;ba=$;do{ba=YGb(ba,K,-1,-1)|0;K=F;lz(E)|0;}while(!((ba|0)==0&(K|0)==0))}if((jz(E)|0)!=0){break}K=dEb(Q,40)|0;c[x>>2]=K;if((K|0)==0){y=G;z=H;continue a}else{D=71;break a}}}while(0);yDb(O,16,1900920,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;y=G;z=H;continue}}}if((D|0)==9){yDb(e,16,2015e3,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;ua=-1094995529;i=f;return ua|0}else if((D|0)==51){yDb(0,0,2070936,(P=i,i=i+24|0,c[P>>2]=1908352,c[P+8>>2]=1979720,c[P+16>>2]=320,P)|0);i=P;Cd();return 0}else if((D|0)==63){yDb(0,0,2070936,(P=i,i=i+24|0,c[P>>2]=1902040,c[P+8>>2]=1979720,c[P+16>>2]=340,P)|0);i=P;Cd();return 0}else if((D|0)==71){if((Q|0)!=0){z=0;do{LT(O,0)|0;z=z+1|0;}while(z>>>0<Q>>>0)}Q=e+24|0;c:do{if((c[Q>>2]|0)==0){va=0;wa=0}else{z=j|0;O=j+4|0;y=j+8|0;w=k|0;ta=k+4|0;sa=k+8|0;v=0;u=0;S=0;d:while(1){pa=u;na=S;e:while(1){W=-1;if((pa|0)>(W|0)|(pa|0)==(W|0)&na>>>0>-1>>>0){Ty(n,na,pa,0)|0;}if((Xy(n)|0)==0){xa=0;ya=0}else{break d}while(1){W=lz(n)|0;ka=W|(ya<<8|0>>>24);V=((W|0)<0|0?-1:0)|(xa<<8|ya>>>24);if((ka&0|0)==0&(V&-16777216|0)==1308622848){W=1542650331;ja=1314066752;if((ka|0)==(-1248413064|0)&(V|0)==1313450856|(ka|0)==(-288733847|0)&(V|0)==1313596589|(ka|0)==526320813&(V|0)==1313700438|(ka|0)==790881870&(V|0)==1314446695){pa=-1;na=-1;continue e}else if((ka|0)==(W|0)&(V|0)==(ja|0)){break e}}if((Xy(n)|0)==0){xa=V;ya=ka}else{break d}}}na=Ty(n,0,0,1)|0;pa=F;ka=YGb(na,pa,-8,-1)|0;V=F;ja=YGb(na,pa,-7,-1)|0;pa=F;na=0;if((V|0)<(na|0)|(V|0)==(na|0)&ka>>>0<0>>>0){break}ka=c[o>>2]|0;na=c[ka+16>>2]|0;V=gM(na,1,1542650331,1314066752)|0;W=Ty(na,0,0,1)|0;U=YGb(V,(V|0)<0|0?-1:0,W,F)|0;W=F;V=Bz(na)|0;la=F;T=0;f:do{if(la>>>0<T>>>0|la>>>0==T>>>0&V>>>0<(c[ka+24>>2]|0)>>>0){ra=V;ha=c[x>>2]|0;qa=ha+(ra*40|0)+20|0;if((c[qa>>2]|0)!=0){D=86;break}ma=ka+28|0;ia=c[(c[ma>>2]|0)+(ra<<2)>>2]|0;if((ia|0)==0){za=0;break}oa=Bz(na)|0;ga=oa;oa=Bz(na)|0;fa=oa;if((fa|0)==2){Aa=pz(na)|0}else if((fa|0)==4){Aa=rz(na)|0}else{yDb(0,16,1930440,(P=i,i=i+8|0,c[P>>2]=fa,P)|0);i=P;Aa=-1}fa=ia+8|0;oa=c[fa>>2]|0;c[oa+52>>2]=Aa;if((ga|0)==0){c[oa+8>>2]=0;c[z>>2]=1167880;c[O>>2]=1240808;c[y>>2]=0;ea=zT(z,Aa)|0;c[(c[fa>>2]|0)+48>>2]=ea;Ba=ea;D=98}else if((ga|0)==1){c[oa+8>>2]=1;c[w>>2]=1169352;c[ta>>2]=1238064;c[sa>>2]=0;ea=zT(w,Aa)|0;c[(c[fa>>2]|0)+48>>2]=ea;Ba=ea;D=98}else if((ga|0)==2){c[oa+8>>2]=3;ea=vT(1168888,Aa)|0;c[(c[fa>>2]|0)+48>>2]=ea;Ba=ea;D=98}else if((ga|0)==3){c[oa+8>>2]=2;oa=vT(1169304,Aa)|0;c[(c[fa>>2]|0)+48>>2]=oa}else{yDb(ka,16,1965656,(P=i,i=i+8|0,c[P>>2]=ga,P)|0);i=P;za=0;break}do{if((D|0)==98){D=0;if((Ba|0)!=0){break}yDb(ka,16,1960168,(P=i,i=i+16|0,c[P>>2]=Aa,c[P+8>>2]=ra,P)|0);i=P}}while(0);ga=Bz(na)|0;oa=F;ea=0;if(!(oa>>>0<ea>>>0|oa>>>0==ea>>>0&ga>>>0<(c[s>>2]|0)>>>0)){yDb(ka,16,1958320,(P=i,i=i+16|0,c[P>>2]=ga,c[P+8>>2]=oa,P)|0);i=P;za=0;break}oa=ha+(ra*40|0)+16|0;c[oa>>2]=ga;ga=Bz(na)|0;ea=F;da=0;if(!(ea>>>0<da>>>0|ea>>>0==da>>>0&ga>>>0<16>>>0)){yDb(ka,16,1955920,(P=i,i=i+16|0,c[P>>2]=ga,c[P+8>>2]=ea,P)|0);i=P;za=0;break}c[ha+(ra*40|0)+24>>2]=ga;ga=Bz(na)|0;c[ha+(ra*40|0)+28>>2]=ga;ga=Bz(na)|0;ea=F;da=0;if(!(ea>>>0<da>>>0|ea>>>0==da>>>0&ga>>>0<1e3>>>0)){yDb(ka,16,1953656,(P=i,i=i+16|0,c[P>>2]=ga,c[P+8>>2]=ea,P)|0);i=P;za=0;break}ea=ga;c[ha+(ra*40|0)+32>>2]=ea;c[(c[fa>>2]|0)+176>>2]=ea;Bz(na)|0;ea=Bz(na)|0;ga=F;da=0;if(!(ga>>>0<da>>>0|ga>>>0==da>>>0&ea>>>0<1073741824>>>0)){yDb(ka,16,1951456,(P=i,i=i+16|0,c[P>>2]=ea,c[P+8>>2]=ga,P)|0);i=P;za=0;break}ga=ea;ea=c[fa>>2]|0;c[ea+100>>2]=ga;if((ga|0)==0){Ca=ea}else{if((CT(ea,na,ga)|0)<0){za=0;break}Ca=c[fa>>2]|0}ga=c[Ca+8>>2]|0;do{if((ga|0)==1){ea=Bz(na)|0;if((ea|0)==0&(F|0)==0){yDb(ka,16,1943792,(P=i,i=i+16|0,c[P>>2]=0,c[P+8>>2]=0,P)|0);i=P;za=0;break f}c[(c[fa>>2]|0)+412>>2]=ea;Bz(na)|0;ea=Bz(na)|0;if((ea|0)==0&(F|0)==0){yDb(ka,16,1937608,(P=i,i=i+16|0,c[P>>2]=0,c[P+8>>2]=0,P)|0);i=P;za=0;break f}else{c[(c[fa>>2]|0)+416>>2]=ea;break}}else if((ga|0)==0){ea=Bz(na)|0;if((ea|0)==0&(F|0)==0){yDb(ka,16,1949464,(P=i,i=i+16|0,c[P>>2]=0,c[P+8>>2]=0,P)|0);i=P;za=0;break f}c[(c[fa>>2]|0)+120>>2]=ea;ea=Bz(na)|0;if((ea|0)==0&(F|0)==0){yDb(ka,16,1947368,(P=i,i=i+16|0,c[P>>2]=0,c[P+8>>2]=0,P)|0);i=P;za=0;break f}c[(c[fa>>2]|0)+124>>2]=ea;ea=Bz(na)|0;da=ia+80|0;c[da>>2]=ea;ea=Bz(na)|0;ca=ea;c[ia+84>>2]=ca;ea=c[da>>2]|0;if((ea|0)==0^(ca|0)==0){yDb(ka,16,1945504,(P=i,i=i+16|0,c[P>>2]=ea,c[P+8>>2]=ca,P)|0);i=P;za=0;break f}else{Bz(na)|0;break}}}while(0);ia=Ty(na,0,0,1)|0;fa=F;ga=ZGb(U,W,ia,fa)|0;ha=F;ca=0;do{if((ha|0)<(ca|0)|(ha|0)==(ca|0)&ga>>>0<0>>>0){Ty(na,ga,ha,1)|0;}else{if(!((ia|0)==(U|0)&(fa|0)==(W|0))){ea=ha;da=ga;do{da=YGb(da,ea,-1,-1)|0;ea=F;lz(na)|0;}while(!((da|0)==0&(ea|0)==0))}if((jz(na)|0)!=0){break}ea=c[oa>>2]|0;da=c[t>>2]|0;_=da+(ea<<3)|0;c[qa>>2]=_;MT(c[(c[ma>>2]|0)+(ra<<2)>>2]|0,63,c[_>>2]|0,c[da+(ea<<3)+4>>2]|0);za=1;break f}}while(0);yDb(ka,16,1932304,(P=i,i=i+8|0,c[P>>2]=ra,P)|0);i=P;za=0}else{D=86}}while(0);if((D|0)==86){D=0;yDb(ka,16,1972704,(P=i,i=i+16|0,c[P>>2]=V,c[P+8>>2]=la,P)|0);i=P;za=0}na=za+v|0;if(na>>>0<(c[Q>>2]|0)>>>0){v=na;u=pa;S=ja}else{va=0;wa=0;break c}}yDb(e,16,2011720,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;ua=-1094995529;i=f;return ua|0}}while(0);g:while(1){Q=-1;if((va|0)>(Q|0)|(va|0)==(Q|0)&wa>>>0>-1>>>0){Ty(n,wa,va,0)|0;}if((Xy(n)|0)==0){Da=0;Ea=0}else{D=138;break}while(1){Q=lz(n)|0;Fa=Q|(Ea<<8|0>>>24);Ga=((Q|0)<0|0?-1:0)|(Da<<8|Ea>>>24);if((Fa&0|0)==0&(Ga&-16777216|0)==1308622848){if((Fa|0)==526320813&(Ga|0)==1313700438|(Fa|0)==1542650331&(Ga|0)==1314066752|(Fa|0)==(-288733847|0)&(Ga|0)==1313596589|(Fa|0)==(-1248413064|0)&(Ga|0)==1313450856|(Fa|0)==790881870&(Ga|0)==1314446695){break}}if((Xy(n)|0)==0){Da=Ga;Ea=Fa}else{D=138;break g}}Ha=Ty(n,0,0,1)|0;Ia=F;Q=-1248413064;za=1313450856;if((Fa|0)==(-288733847|0)&(Ga|0)==1313596589){break}else if(!((Fa|0)==(Q|0)&(Ga|0)==(za|0))){va=Ia;wa=Ha;continue}hM(m)|0;va=Ia;wa=Ha}if((D|0)==138){Ty(n,0,0,1)|0;yDb(e,16,2003120,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;ua=-1094995529;i=f;return ua|0}wa=l+3720|0;c[wa>>2]=-288733847;c[wa+4>>2]=1313596589;l=YGb(Ha,Ia,-8,-1)|0;Ia=e+1248|0;c[Ia>>2]=l;c[Ia+4>>2]=F;if((c[n+88>>2]|0)!=0){Ia=Ty(n,0,0,1)|0;l=F;Ha=c[o>>2]|0;va=c[Ha+16>>2]|0;m=Wy(va)|0;Ga=F;Fa=0;do{if(!((Ga|0)<(Fa|0)|(Ga|0)==(Fa|0)&m>>>0<1>>>0)){Ea=YGb(m,Ga,-12,-1)|0;Ty(va,Ea,F,0)|0;Ea=Az(va)|0;Da=ZGb(m,Ga,Ea,F)|0;Ty(va,Da,F,0)|0;Da=Az(va)|0;if(!((Da|0)==790881870&(F|0)==1314446695)){yDb(Ha,16,1992912,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;Da=Ha+1064|0;Ea=c[Da+4>>2]|0;za=0;if(!((Ea|0)<(za|0)|(Ea|0)==(za|0)&(c[Da>>2]|0)>>>0<1>>>0)){break}za=c[o>>2]|0;c[g>>2]=0;c[g+4>>2]=0;rT(za,-1,g,0,74)|0;Ea=c[g>>2]|0;Q=c[g+4>>2]|0;Ca=0;if((Q|0)>(Ca|0)|(Q|0)==(Ca|0)&Ea>>>0>0>>>0){c[za+1212>>2]=0}c[Da>>2]=Ea;c[Da+4>>2]=Q;break}Q=gM(va,1,790881870,1314446695)|0;Da=Ty(va,0,0,1)|0;Ea=YGb(Q,(Q|0)<0|0?-1:0,Da,F)|0;Da=F;Q=Bz(va)|0;za=F;Ca=c[s>>2]|0;Aa=0;Ba=hHb(Q,za,Ca,Aa)|0;x=F;ya=iHb(Q,za,Ca,Aa)|0;Aa=(c[t>>2]|0)+(ya<<3)|0;c[h>>2]=1;c[h+4>>2]=1e6;ya=KDb(Ba,x,Aa,h)|0;Aa=Ha+1064|0;c[Aa>>2]=ya;c[Aa+4>>2]=F;c[Ha+1212>>2]=0;Aa=Bz(va)|0;ya=F;x=0;if(!((ya>>>0<x>>>0|ya>>>0==x>>>0&Aa>>>0<268435455>>>0)&((Aa|0)!=0|(ya|0)!=0))){yDb(Ha,16,1989432,(P=i,i=i+16|0,c[P>>2]=Aa,c[P+8>>2]=ya,P)|0);i=P;break}ya=Aa;if(ya>>>0<268435455>>>0){Ja=WDb(ya<<3)|0}else{Ja=0}Aa=Ja;x=ya+1|0;h:do{if(x>>>0<2147483647>>>0){Ba=WDb(x)|0;if((Ja|0)==0|(Ba|0)==0){Ka=Ba;break}Ca=(ya|0)>0;if(Ca){za=0;do{Q=Bz(va)|0;xa=F;k=Aa+(za<<3)|0;c[k>>2]=Q;c[k+4>>2]=xa;j=0;if((xa|0)<(j|0)|(xa|0)==(j|0)&Q>>>0<1>>>0){Ka=Ba;break h}if((za|0)!=0){j=Aa+(za-1<<3)|0;S=YGb(c[j>>2]|0,c[j+4>>2]|0,Q,xa)|0;c[k>>2]=S;c[k+4>>2]=F}za=za+1|0;}while((za|0)<(ya|0))}za=Ha+24|0;ja=c[za>>2]|0;i:do{if((ja|0)!=0){pa=Ha+28|0;la=x;V=(x|0)<0|0?-1:0;ka=0;k=ja;j:while(1){if(Ca){La=0;S=-1;xa=-1;while(1){Q=Bz(va)|0;j=F;u=Q>>>1|j<<31;v=j>>>1|0<<31;do{if((Q&1|0)==0&(j&0|0)==0){if((u|0)==1&(v|0)==0){Ma=La;break}else{Na=v;Oa=u;Pa=La}while(1){if((Pa|0)>=(x|0)){D=172;break j}w=Pa+1|0;a[Ba+Pa|0]=Oa&1;sa=Oa>>>1|Na<<31;ta=Na>>>1|0<<31;if((sa|0)==1&(ta|0)==0){Ma=w;break}else{Na=ta;Oa=sa;Pa=w}}}else{w=u&1;Qa=Q>>>2|j<<30;Ra=j>>>2|0<<30;sa=YGb(Qa,Ra,La,(La|0)<0|0?-1:0)|0;ta=F;if(!(ta>>>0<V>>>0|ta>>>0==V>>>0&sa>>>0<la>>>0)){D=169;break j}if((Qa|0)==0&(Ra|0)==0){Sa=La}else{sa=YGb(Qa,Ra,-1,0)|0;ta=sa;TGb(Ba+La|0,w&255|0,ta+1|0)|0;Sa=La+1+ta|0}a[Ba+Sa|0]=w^1;Ma=Sa+1|0}}while(0);if((a[Ba]|0)!=0){D=175;break j}if((Ma|0)>(x|0)){D=179;break j}if((La|0)<(Ma|0)&(La|0)<(ya|0)){j=La-Ma|0;Q=La-ya|0;u=j>>>0>Q>>>0;v=La;w=S;ta=xa;while(1){if((a[Ba+v|0]|0)==0){Ta=w;Ua=ta}else{sa=Bz(va)|0;z=F;if((sa|0)==0&(z|0)==0){y=Bz(va)|0;O=F;H=Bz(va)|0;Va=O;Wa=y;Xa=F;Ya=H}else{Va=z;Wa=sa;Xa=0;Ya=0}sa=c[(c[pa>>2]|0)+(ka<<2)>>2]|0;z=Aa+(v-1<<3)|0;H=c[z>>2]|0;y=c[z+4>>2]<<4|H>>>28;z=YGb(Wa,Va,ta,w)|0;jT(sa,H<<4|0>>>28,y,z,F,0,0,1)|0;z=YGb(Ya,Xa,ta,w)|0;y=YGb(z,F,Wa,Va)|0;Ta=F;Ua=y}y=v+1|0;if((y|0)<(Ma|0)&(y|0)<(ya|0)){v=y;w=Ta;ta=Ua}else{break}}Za=La-(u?j:Q)|0;_a=Ta;$a=Ua}else{Za=La;_a=S;$a=xa}if((Za|0)<(ya|0)){La=Za;S=_a;xa=$a}else{break}}ab=c[za>>2]|0}else{ab=k}xa=ka+1|0;if(xa>>>0<ab>>>0){ka=xa;k=ab}else{break i}}if((D|0)==169){yDb(Ha,16,1985720,(P=i,i=i+32|0,c[P>>2]=La,c[P+8>>2]=Qa,c[P+16>>2]=Ra,c[P+24>>2]=x,P)|0);i=P;Ka=Ba;break h}else if((D|0)==172){yDb(Ha,16,1982280,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;Ka=Ba;break h}else if((D|0)==175){yDb(Ha,16,1979296,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;Ka=Ba;break h}else if((D|0)==179){yDb(0,0,2070936,(P=i,i=i+24|0,c[P>>2]=1976624,c[P+8>>2]=1979720,c[P+16>>2]=687,P)|0);i=P;Cd();return 0}}}while(0);za=Ty(va,0,0,1)|0;Ca=F;ja=ZGb(Ea,Da,za,Ca)|0;k=F;ka=0;if((k|0)<(ka|0)|(k|0)==(ka|0)&ja>>>0<0>>>0){Ty(va,ja,k,1)|0;}else{if(!((za|0)==(Ea|0)&(Ca|0)==(Da|0))){Ca=k;k=ja;do{k=YGb(k,Ca,-1,-1)|0;Ca=F;lz(va)|0;}while(!((k|0)==0&(Ca|0)==0))}if((jz(va)|0)==0){Ka=Ba;break}}yDb(Ha,16,1974272,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;Ka=Ba}else{Ka=0}}while(0);ZDb(Ja);ZDb(Ka)}}while(0);Ty(n,Ia,l,0)|0;}if(!((c[wa>>2]|0)==(-288733847|0)&(c[wa+4>>2]|0)==1313596589)){yDb(0,0,2070936,(P=i,i=i+24|0,c[P>>2]=1995992,c[P+8>>2]=1979720,c[P+16>>2]=774,P)|0);i=P;Cd();return 0}RG(e,0,1169024);ua=0;i=f;return ua|0}return 0}function bM(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[e+12>>2]|0;l=k;m=c[e+16>>2]|0;n=k+3720|0;o=e;e=k+3744|0;p=k;q=k+3736|0;r=k+3728|0;s=k+3752|0;k=f+24|0;t=f+64|0;u=f+28|0;v=0;a:while(1){w=Ty(m,0,0,1)|0;x=F;y=c[n>>2]|0;z=c[n+4>>2]|0;c[n>>2]=0;c[n+4>>2]=0;do{if((y|0)==0&(z|0)==0){A=lz(m)|0;if((Xy(m)|0)!=0){B=-541478725;C=69;break a}if((A|0)!=78){D=A;E=x;G=w;C=12;break}A=lz(m)|0;H=A;I=YGb(H<<8|0>>>24,((A|0)<0|0?-1:0)<<8|H>>>24,5111808,0)|0;H=F;A=lz(m)|0;J=YGb(A,(A|0)<0|0?-1:0,I,H)|0;H=F<<8|J>>>24;I=lz(m)|0;A=YGb(I,(I|0)<0|0?-1:0,J<<8|0>>>24,H)|0;H=F<<8|A>>>24;J=lz(m)|0;I=YGb(J,(J|0)<0|0?-1:0,A<<8|0>>>24,H)|0;H=F<<8|I>>>24;A=lz(m)|0;J=YGb(A,(A|0)<0|0?-1:0,I<<8|0>>>24,H)|0;H=F<<8|J>>>24;I=lz(m)|0;A=YGb(I,(I|0)<0|0?-1:0,J<<8|0>>>24,H)|0;H=F<<8|A>>>24;J=lz(m)|0;I=YGb(J,(J|0)<0|0?-1:0,A<<8|0>>>24,H)|0;K=F;L=I;M=x;N=w;O=78;C=7}else{I=YGb(w,x,-8,-1)|0;K=z;L=y;M=F;N=I;O=v;C=7}}while(0);do{if((C|0)==7){C=0;y=-288733847;z=1313596589;x=-1248413064;w=1313450856;I=790881870;H=1314446695;A=1542650331;J=1314066752;P=526320813;Q=1313700438;if((L|0)==0&(K|0)==0){D=O;E=M;G=N;C=12;break}else if((L|0)==(x|0)&(K|0)==(w|0)){if((hM(l)|0)<0){R=O;S=M;T=N;break}else{v=O;continue a}}else if((L|0)==(y|0)&(K|0)==(z|0)){if((fM(l,h,j)|0)<0){R=O;S=M;T=N;break}D=lz(m)|0;E=M;G=N;C=12;break}else if((L|0)==(P|0)&(K|0)==(Q|0)|(L|0)==(A|0)&(K|0)==(J|0)|(L|0)==(I|0)&(K|0)==(H|0)){H=gM(m,0,L,K)|0;Vy(m,H,(H|0)<0|0?-1:0)|0;v=O;continue a}else{R=O;S=M;T=N;break}}}while(0);b:do{if((C|0)==12){C=0;H=c[p>>2]|0;I=c[H+16>>2]|0;J=Ty(I,0,0,1)|0;A=F;Q=YGb(c[q>>2]|0,0,c[e>>2]|0,c[e+4>>2]|0)|0;P=F;if((A|0)>(P|0)|(A|0)==(P|0)&J>>>0>Q>>>0){Q=Ty(I,0,0,1)|0;J=F;P=c[e>>2]|0;A=c[e+4>>2]|0;z=c[q>>2]|0;yDb(H,16,2117296,(U=i,i=i+40|0,c[U>>2]=Q,c[U+8>>2]=J,c[U+16>>2]=P,c[U+24>>2]=A,c[U+32>>2]=z,U)|0);i=U;R=D;S=E;T=G;break}z=b[l+4+(D*12|0)>>1]|0;A=z&65535;P=b[l+4+(D*12|0)+4>>1]|0;J=b[l+4+(D*12|0)+6>>1]|0;Q=J&65535;y=d[l+4+(D*12|0)+2|0]|0;w=b[l+4+(D*12|0)+8>>1]|0;x=d[l+4+(D*12|0)+10|0]|0;V=a[l+4+(D*12|0)+11|0]|0;if((A&8192|0)!=0){R=D;S=E;T=G;break}if((A&4096|0)==0){W=A}else{A=Bz(I)|0;W=A^z&65535}do{if((W&16|0)==0){X=y}else{z=Bz(I)|0;A=F;Y=0;if(A>>>0<Y>>>0|A>>>0==Y>>>0&z>>>0<(c[H+24>>2]|0)>>>0){X=z;break}else{yDb(H,16,2105616,(U=i,i=i+16|0,c[U>>2]=z,c[U+8>>2]=A,U)|0);i=U;R=D;S=E;T=G;break b}}}while(0);y=c[r>>2]|0;A=y+(X*40|0)|0;do{if((W&8|0)==0){z=y+(X*40|0)+8|0;Y=YGb(c[z>>2]|0,c[z+4>>2]|0,w<<16>>16,w<<16>>16<0|0?-1:0)|0;Z=F;_=Y}else{Y=Bz(I)|0;z=Y;Y=c[y+(X*40|0)+24>>2]|0;$=z;aa=(z|0)<0|0?-1:0;if((z|0)<(1<<Y|0)){z=xX(A,$,aa)|0;Z=F;_=z;break}else{z=_Gb(1,0,Y|0)|0;Y=ZGb($,aa,z,F)|0;Z=F;_=Y;break}}}while(0);if((W&32|0)==0){ba=Q}else{w=Bz(I)|0;Y=gHb(w,F,P&65535,0)|0;w=YGb(Y,F,J&65535,0)|0;ba=w}if((W&2048|0)!=0){Bz(I)|0;}if((W&1024|0)==0){ca=V}else{w=Bz(I)|0;ca=w&255}if((W&128|0)==0){da=x}else{w=Bz(I)|0;da=w}if((da|0)>0){w=0;do{Bz(I)|0;w=w+1|0;}while((w|0)<(da|0))}w=ca&255;if(!(w>>>0<(c[s>>2]|0)>>>0)){yDb(H,16,2095424,(U=i,i=i+1|0,i=i+7&-8,c[U>>2]=0,U)|0);i=U;R=D;S=E;T=G;break}x=(ba|0)>4096?0:w;ea=l+3076+x|0;w=ba-(d[ea]|0)|0;do{if((W&64|0)==0){if(!(w>>>0>c[q>>2]<<1>>>0)){V=y+(X*40|0)+8|0;J=ZGb(c[V>>2]|0,c[V+4>>2]|0,_,Z)|0;P=F;Q=-1;Y=(P|0)>(Q|0)|(P|0)==(Q|0)&J>>>0>-1>>>0;Q=ZGb(0,0,J,P)|0;z=Y?P:F;P=c[y+(X*40|0)+28>>2]|0;aa=(P|0)<0|0?-1:0;if(!((z|0)>(aa|0)|(z|0)==(aa|0)&(Y?J:Q)>>>0>P>>>0)){fa=V;break}}yDb(H,16,2090048,(U=i,i=i+1|0,i=i+7&-8,c[U>>2]=0,U)|0);i=U;R=D;S=E;T=G;break b}else{vz(I)|0;fa=y+(X*40|0)+8|0}}while(0);c[fa>>2]=_;c[fa+4>>2]=Z;c[A>>2]=W;c:do{if((w|0)<0){ga=w}else{y=c[r>>2]|0;ha=y+(X*40|0)|0;V=(c[ha>>2]&1|0)==0;if(!V){c[y+(X*40|0)+4>>2]=0}P=c[(c[H+28>>2]|0)+(X<<2)>>2]|0;Q=c[P+76>>2]|0;J=P+216|0;P=c[J>>2]|0;Y=c[J+4>>2]|0;do{if((Q|0)<32|V^1){if((Q|0)<16|(P|0)==0&(Y|0)==(-2147483648|0)){if((Q|0)>47){break}}else{if((Y|0)>(Z|0)|(Y|0)==(Z|0)&P>>>0>_>>>0|(Q|0)>47){break}}if((c[y+(X*40|0)+4>>2]|0)!=0){break}if((wZ(f,(d[ea]|0)+w|0)|0)<0){R=D;S=E;T=G;break b}UGb(c[k>>2]|0,c[l+3204+(x<<2)>>2]|0,d[ea]|0)|0;J=Ty(I,0,0,1)|0;aa=F;c[t>>2]=J;c[t+4>>2]=aa;if((c[ha>>2]&256|0)==0){ia=w}else{z=w;$=(w|0)<0|0?-1:0;ja=YGb(J,aa,z,$)|0;if((iM(H,I,f,ja,F)|0)<0){R=D;S=E;T=G;break b}ja=YGb(c[t>>2]|0,c[t+4>>2]|0,z,$)|0;if((iM(H,I,f,ja,F)|0)<0){R=D;S=E;T=G;break b}ja=Ty(I,0,0,1)|0;$=ZGb(ja,F,c[t>>2]|0,c[t+4>>2]|0)|0;ja=$;c[u>>2]=(c[u>>2]|0)-ja;ia=w-ja|0}ka=mz(I,(c[k>>2]|0)+(d[ea]|0)|0,ia)|0;if((ka|0)!=(ia|0)&(ka|0)<0){ga=ka;break c}else{C=58;break a}}}while(0);Vy(I,w,(w|0)<0|0?-1:0)|0;v=D;continue a}}while(0);if((ga|0)==1){v=D;continue a}else if((ga|0)==0){B=0;C=69;break a}else{R=D;S=E;T=G}}}while(0);yDb(o,48,2248376,(U=i,i=i+16|0,c[U>>2]=T,c[U+8>>2]=S,U)|0);i=U;w=YGb(c[e>>2]|0,c[e+4>>2]|0,1,0)|0;I=F;H=-1;if((I|0)>(H|0)|(I|0)==(H|0)&w>>>0>-1>>>0){Ty(m,w,I,0)|0;}if((Xy(m)|0)==0){la=0;ma=0}else{B=-1094995529;C=69;break}while(1){I=lz(m)|0;na=I|(ma<<8|0>>>24);oa=((I|0)<0|0?-1:0)|(la<<8|ma>>>24);if((na&0|0)==0&(oa&-16777216|0)==1308622848){if((na|0)==526320813&(oa|0)==1313700438|(na|0)==1542650331&(oa|0)==1314066752|(na|0)==(-288733847|0)&(oa|0)==1313596589|(na|0)==(-1248413064|0)&(oa|0)==1313450856|(na|0)==790881870&(oa|0)==1314446695){break}}if((Xy(m)|0)==0){la=oa;ma=na}else{B=-1094995529;C=69;break a}}yDb(o,48,2235440,(U=i,i=i+1|0,i=i+7&-8,c[U>>2]=0,U)|0);i=U;c[n>>2]=na;c[n+4>>2]=oa;v=R}if((C|0)==58){yZ(f,(d[ea]|0)+ka|0);c[f+32>>2]=X;if((c[ha>>2]&1|0)!=0){ha=f+36|0;c[ha>>2]=c[ha>>2]|1}ha=f+8|0;c[ha>>2]=_;c[ha+4>>2]=Z;B=0;i=g;return B|0}else if((C|0)==69){i=g;return B|0}return 0}function cM(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;$Db(b+3756|0);$Db(b+3728|0);BX(b);a=b+3752|0;if((c[a>>2]|0)<=1){return 0}d=b+3204|0;b=1;do{$Db(d+(b<<2)|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function dM(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0;g=i;i=i+64|0;h=g|0;j=g+24|0;k=g+48|0;l=g+56|0;m=c[a+12>>2]|0;n=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=h|0;o=h+16|0;TGb(h|0,0,16)|0;p=(+(d>>>0)+ +(e|0)*4294967296.0)*(+(c[n+40>>2]|0)/+(c[n+44>>2]|0))*1.0e6;q=(E=+p,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[o>>2]=~~+p>>>0;c[o+4>>2]=q;q=j;c[q>>2]=c[137312];c[q+4>>2]=c[137313];c[q+8>>2]=c[137314];c[q+12>>2]=c[137315];c[q+16>>2]=c[137316];c[q+20>>2]=c[137317];q=k|0;c[q>>2]=j;r=k+4|0;c[r>>2]=j;s=n+400|0;do{if((c[s>>2]|0)==0){t=m+3760|0;u=h;v=k;fGb(c[t>>2]|0,u,320,v)|0;w=c[q>>2]|0;x=w|0;y=c[x+4>>2]|0;z=c[r>>2]|0;A=z|0;B=c[A>>2]|0;C=c[A+4>>2]|0;A=w+16|0;w=c[A>>2]|0;D=c[A+4>>2]|0;A=z+16|0;z=c[A>>2]|0;G=c[A+4>>2]|0;yDb(a,48,2135736,(H=i,i=i+64|0,c[H>>2]=c[x>>2],c[H+8>>2]=y,c[H+16>>2]=B,c[H+24>>2]=C,c[H+32>>2]=w,c[H+40>>2]=D,c[H+48>>2]=z,c[H+56>>2]=G,H)|0);i=H;G=c[q>>2]|0;z=G|0;D=c[r>>2]|0;w=D|0;C=c[w>>2]|0;B=c[w+4>>2]|0;w=G+16|0;G=D+16|0;D=qT(a,-1,c[o>>2]|0,c[o+4>>2]|0,c[z>>2]|0,c[z+4>>2]|0,C,B,C,B,c[w>>2]|0,c[w+4>>2]|0,c[G>>2]|0,c[G+4>>2]|0,1,l,74)|0;G=F;if((f&1|0)==0){w=YGb(D,G,16,0)|0;c[b>>2]=w;c[b+4>>2]=F;c[r>>2]=j;fGb(c[t>>2]|0,u,618,v)|0;v=c[q>>2]|0;w=v|0;B=c[r>>2]|0;C=B|0;z=c[C>>2]|0;y=c[C+4>>2]|0;C=v+8|0;v=B+8|0;B=qT(a,-2,c[b>>2]|0,c[b+4>>2]|0,c[w>>2]|0,c[w+4>>2]|0,z,y,z,y,c[C>>2]|0,c[C+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0,f,l,74)|0;v=F;C=-1;y=(v|0)>(C|0)|(v|0)==(C|0)&B>>>0>-1>>>0;I=y?v:G;J=y?B:D}else{I=G;J=D}c[b>>2]=J;c[b+4>>2]=I;D=fGb(c[t>>2]|0,u,618,0)|0;if((D|0)==0){yDb(0,0,2070936,(H=i,i=i+24|0,c[H>>2]=2023192,c[H+8>>2]=1979720,c[H+16>>2]=1157,H)|0);i=H;Cd();return 0}else{u=D+8|0;D=YGb(c[u>>2]|0,c[u+4>>2]|0,-15,-1)|0;K=F;L=D;break}}else{D=oT(n,d,e,f)|0;do{if((D|0)<0){u=oT(n,d,e,f^1)|0;if((u|0)<0){M=-1}else{N=u;break}i=g;return M|0}else{N=D}}while(0);D=c[s>>2]|0;u=D+(N*24|0)|0;t=c[u>>2]|0;G=c[u+4>>2]|0;u=D+(N*24|0)+8|0;D=c[u+4>>2]|0;c[l>>2]=c[u>>2];c[l+4>>2]=D;K=G;L=t}}while(0);yDb(0,48,1949832,(H=i,i=i+16|0,c[H>>2]=L,c[H+8>>2]=K,H)|0);i=H;l=a+16|0;N=c[l>>2]|0;s=K;f=L;a:while(1){e=-1;if((s|0)>(e|0)|(s|0)==(e|0)&f>>>0>-1>>>0){Ty(N,f,s,0)|0;}if((Xy(N)|0)==0){O=0;R=0}else{S=-1;T=-1;break}while(1){e=lz(N)|0;d=e|(R<<8|0>>>24);n=((e|0)<0|0?-1:0)|(O<<8|R>>>24);if((d&0|0)==0&(n&-16777216|0)==1308622848){e=-288733847;I=1313596589;if((d|0)==(-1248413064|0)&(n|0)==1313450856|(d|0)==526320813&(n|0)==1313700438|(d|0)==1542650331&(n|0)==1314066752|(d|0)==790881870&(n|0)==1314446695){s=-1;f=-1;continue a}else if((d|0)==(e|0)&(n|0)==(I|0)){U=17;break a}}if((Xy(N)|0)==0){O=n;R=d}else{S=-1;T=-1;break a}}}if((U|0)==17){U=Ty(N,0,0,1)|0;N=YGb(U,F,-8,-1)|0;S=F;T=N}Ty(c[l>>2]|0,T,S,0)|0;yDb(0,48,1924160,(H=i,i=i+16|0,c[H>>2]=T,c[H+8>>2]=S,H)|0);i=H;l=YGb(L,K,15,0)|0;N=F;if((K|0)>(S|0)|(K|0)==(S|0)&L>>>0>T>>>0|((N|0)<(S|0)|(N|0)==(S|0)&l>>>0<T>>>0)){yDb(0,16,1902304,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}H=a+24|0;if((c[H>>2]|0)==0){M=0;i=g;return M|0}a=c[m+3728>>2]|0;m=0;while(1){c[a+(m*40|0)+4>>2]=1;T=m+1|0;if(T>>>0<(c[H>>2]|0)>>>0){m=T}else{M=0;break}}i=g;return M|0}function eM(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[a+12>>2]|0;l=k;m=c[a+16>>2]|0;n=a;a=c[d>>2]|0;o=c[d+4>>2]|0;yDb(n,48,1882320,(p=i,i=i+40|0,c[p>>2]=b,c[p+8>>2]=a,c[p+16>>2]=o,c[p+24>>2]=e,c[p+32>>2]=f,p)|0);i=p;f=c[d+4>>2]|0;e=c[d>>2]|0;a:while(1){o=-1;if((f|0)>(o|0)|(f|0)==(o|0)&e>>>0>-1>>>0){Ty(m,e,f,0)|0;}if((Xy(m)|0)==0){q=0;r=0}else{s=9;break}while(1){o=lz(m)|0;a=o|(r<<8|0>>>24);t=((o|0)<0|0?-1:0)|(q<<8|r>>>24);if((a&0|0)==0&(t&-16777216|0)==1308622848){o=790881870;u=1314446695;v=1542650331;w=1314066752;x=526320813;y=1313700438;z=-1248413064;A=1313450856;if((a|0)==(-288733847|0)&(t|0)==1313596589){break}else if((a|0)==(z|0)&(t|0)==(A|0)|(a|0)==(x|0)&(t|0)==(y|0)|(a|0)==(v|0)&(t|0)==(w|0)|(a|0)==(o|0)&(t|0)==(u|0)){f=-1;e=-1;continue a}}if((Xy(m)|0)==0){q=t;r=a}else{s=9;break a}}a=Ty(m,0,0,1)|0;t=F;B=YGb(a,t,-8,-1)|0;C=F;u=0;if((C|0)<(u|0)|(C|0)==(u|0)&B>>>0<0>>>0){s=9;break}e=YGb(a,t,-7,-1)|0;f=F;if((fM(l,h,j)|0)>=0){break}}if((s|0)==9){yDb(n,16,2340200,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;D=-2147483648;E=0;i=g;return(F=D,E)|0}c[d>>2]=B;c[d+4>>2]=C;d=k+3744|0;if(!((c[d>>2]|0)==(B|0)&(c[d+4>>2]|0)==(C|0))){yDb(0,0,2070936,(p=i,i=i+24|0,c[p>>2]=2316728,c[p+8>>2]=1979720,c[p+16>>2]=1100,p)|0);i=p;Cd();return 0}C=c[h>>2]|0;d=c[h+4>>2]|0;h=c[j>>2]|0;B=c[j+4>>2]|0;yDb(n,48,2295296,(p=i,i=i+32|0,c[p>>2]=C,c[p+8>>2]=d,c[p+16>>2]=h,c[p+24>>2]=B,p)|0);i=p;if((b|0)==(-2|0)){D=B;E=h;i=g;return(F=D,E)|0}else if((b|0)==(-1|0)){D=d;E=C;i=g;return(F=D,E)|0}else{yDb(0,0,2070936,(p=i,i=i+24|0,c[p>>2]=2278736,c[p+8>>2]=1979720,c[p+16>>2]=1105,p)|0);i=p;Cd();return 0}return 0}function fM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0;e=i;f=c[a>>2]|0;g=c[f+16>>2]|0;h=Ty(g,0,0,1)|0;j=YGb(h,F,-8,-1)|0;h=a+3744|0;c[h>>2]=j;c[h+4>>2]=F;j=gM(g,1,-288733847,1313596589)|0;k=Ty(g,0,0,1)|0;l=F;m=Bz(g)|0;n=F;o=c[h>>2]|0;p=c[h+4>>2]|0;q=Bz(g)|0;r=ZGb(o,p,q<<4|0>>>28,F<<4|q>>>28)|0;q=F;c[d>>2]=r;c[d+4>>2]=q;p=0;if((q|0)<(p|0)|(q|0)==(p|0)&r>>>0<0>>>0){s=-1094995529;i=e;return s|0}r=YGb(j,(j|0)<0|0?-1:0,k,l)|0;l=F;k=a+3740|0;j=c[k>>2]|0;p=0;q=iHb(m,n,j,p)|0;o=a+3756|0;t=(c[o>>2]|0)+(q<<3)|0;q=hHb(m,n,j,p)|0;wX(a,t,q,F);q=Ty(g,0,0,1)|0;t=F;p=ZGb(r,l,q,t)|0;j=F;u=0;do{if((j|0)<(u|0)|(j|0)==(u|0)&p>>>0<0>>>0){Ty(g,p,j,1)|0;}else{if(!((q|0)==(r|0)&(t|0)==(l|0))){v=j;w=p;do{w=YGb(w,v,-1,-1)|0;v=F;lz(g)|0;}while(!((w|0)==0&(v|0)==0))}if((jz(g)|0)!=0){break}v=c[k>>2]|0;w=0;x=hHb(m,n,v,w)|0;y=+(x>>>0)+ +(F>>>0)*4294967296.0;x=iHb(m,n,v,w)|0;w=x;x=c[o>>2]|0;z=y*(+(c[x+(w<<3)>>2]|0)/+(c[x+(w<<3)+4>>2]|0))*1.0e6;w=~~+z>>>0;x=(E=+z,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[b>>2]=w;c[b+4>>2]=x;v=AX(a,c[h>>2]|0,c[h+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0,w,x)|0;s=(v|0)<0?v:0;i=e;return s|0}}while(0);yDb(f,16,2263424,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;s=-1094995529;i=e;return s|0}function gM(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=fe(d|0)|0;c[g>>2]=fe(e|0)|0;c[g+4>>2]=h;h=iz(0,g,8)|0;c[g>>2]=h;c[g+4>>2]=0;kz(a,310,h);h=Bz(a)|0;g=F;e=0;d=(g|0)>(e|0)|(g|0)==(e|0)&h>>>0>4096>>>0;if(d){vz(a)|0}if(!((jz(a)|0)==0|d^1)){j=-1;i=f;return j|0}kz(a,(b|0)!=0?310:0,0);j=h;i=f;return j|0}function hM(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;d=i;i=i+1536|0;e=d|0;f=d+256|0;g=d+1280|0;h=c[b>>2]|0;j=c[h+16>>2]|0;k=gM(j,1,-1248413064,1313450856)|0;l=Ty(j,0,0,1)|0;m=YGb(k,(k|0)<0|0?-1:0,l,F)|0;l=F;k=Bz(j)|0;n=F;o=h+24|0;p=0;if(n>>>0>p>>>0|n>>>0==p>>>0&k>>>0>(c[o>>2]|0)>>>0){yDb(h,16,2085168,(q=i,i=i+16|0,c[q>>2]=k,c[q+8>>2]=n,q)|0);i=q;r=-1094995529;i=d;return r|0}n=k;k=Bz(j)|0;p=YGb(k,F,1,0)|0;k=F;s=(p&1|0)==0&(k&0|0)==0;t=p>>>1|k<<31;p=k>>1|((k|0)<0|0?-1:0)<<31;k=ZGb(0,0,t,p)|0;s?p:F;p=s?t:k;k=Bz(j)|0;t=F;s=Bz(j)|0;u=F;v=Bz(j)|0;w=v;v=(n|0)==0;do{if((p|0)!=0&v){x=c[b+3740>>2]|0;y=0;z=hHb(k,t,x,y)|0;A=F;B=iHb(k,t,x,y)|0;y=(c[b+3756>>2]|0)+(B<<3)|0;B=YGb(z,A,s,u)|0;C=(OT(h,p,y,z,A,B,F,0)|0)+32|0;D=0}else{if(v){C=h+1140|0;D=0;break}else{B=c[(c[h+28>>2]|0)+(n-1<<2)>>2]|0;C=B+88|0;D=B;break}}}while(0);if((w|0)!=0){u=e|0;s=h;b=(p|0)==0;p=f|0;t=n-1|0;k=c[292281]|0;B=(k|0)==0;A=h+28|0;z=(C|0)==0;y=D+412|0;x=D+416|0;D=g|0;E=0;do{G=Bz(j)|0;H=G;do{if((H|0)==0){I=0}else{G=H>>>0>256>>>0;mz(j,u,G?256:H)|0;if(G){J=H}else{I=H;break}while(1){lz(j)|0;G=J-1|0;if(G>>>0>256>>>0){J=G}else{I=256;break}}}}while(0);a[e+(I>>>0>255>>>0?255:I)|0]=0;H=Bz(j)|0;G=YGb(H,F,1,0)|0;H=F;K=(G&1|0)==0&(H&0|0)==0;L=G>>>1|H<<31;G=H>>1|((H|0)<0|0?-1:0)<<31;H=ZGb(0,0,L,G)|0;M=K?L:H;H=K?G:F;G=-3;K=-1;L=-2;N=-1;O=-1;P=-1;do{if((M|0)==(-4|0)&(H|0)==(-1|0)){Bz(j)|0;Q=2070280}else if((M|0)==(G|0)&(H|0)==(K|0)){Bz(j)|0;Q=2074920}else if((M|0)==(O|0)&(H|0)==(P|0)){R=Bz(j)|0;S=R;do{if((S|0)==0){T=0}else{R=S>>>0>1024>>>0;mz(j,p,R?1024:S)|0;if(R){U=S}else{T=S;break}while(1){lz(j)|0;R=U-1|0;if(R>>>0>1024>>>0){U=R}else{T=1024;break}}}}while(0);a[f+(T>>>0>1023>>>0?1023:T)|0]=0;Q=2079856}else if((M|0)==(L|0)&(H|0)==(N|0)){S=Bz(j)|0;R=S;do{if((R|0)==0){V=0}else{S=R>>>0>256>>>0;mz(j,D,S?256:R)|0;if(S){W=R}else{V=R;break}while(1){lz(j)|0;S=W-1|0;if(S>>>0>256>>>0){W=S}else{V=256;break}}}}while(0);a[g+(V>>>0>255>>>0?255:V)|0]=0;R=Bz(j)|0;S=R;do{if((S|0)==0){X=0}else{R=S>>>0>1024>>>0;mz(j,p,R?1024:S)|0;if(R){Y=S}else{X=S;break}while(1){lz(j)|0;R=Y-1|0;if(R>>>0>1024>>>0){Y=R}else{X=1024;break}}}}while(0);a[f+(X>>>0>1023>>>0?1023:X)|0]=0;Q=D}else{S=-1;if(!((H|0)<(S|0)|(H|0)==(S|0)&M>>>0<-4>>>0)){Q=2061552;break}Bz(j)|0;Q=2065808}}while(0);M=c[o>>2]|0;a:do{if(n>>>0>M>>>0){yDb(s,16,2058200,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}else{if((QGb(Q,2079856)|0)!=0){break}do{if(b){if((QGb(u,2048648)|0)!=0){break}if(B){Z=37}else{H=0;N=0;L=k;do{P=(QGb(1169112+(N<<4)|0,p)|0)==0;H=P?L:H;N=N+1|0;L=c[1169124+(N<<4)>>2]|0;}while((L|0)!=0);if((H|0)==0){Z=37}else{_=H;$=M}}if((Z|0)==37){Z=0;yDb(s,32,2019248,(q=i,i=i+8|0,c[q>>2]=p,q)|0);i=q;_=0;$=c[o>>2]|0}if(($|0)==0){break a}if(v){L=c[A>>2]|0;N=0;while(1){P=(c[L+(N<<2)>>2]|0)+72|0;c[P>>2]=c[P>>2]|_;N=N+1|0;if(!(N>>>0<(c[o>>2]|0)>>>0)){break a}}}else{aa=0;ba=$}while(1){if((aa|0)==(t|0)){N=(c[(c[A>>2]|0)+(t<<2)>>2]|0)+72|0;c[N>>2]=c[N>>2]|_;ca=c[o>>2]|0}else{ca=ba}N=aa+1|0;if(N>>>0<ca>>>0){aa=N;ba=ca}else{break a}}}}while(0);do{if(!v){if((QGb(u,2040952)|0)!=0){break}xd(p|0,2037512,(q=i,i=i+16|0,c[q>>2]=y,c[q+8>>2]=x,q)|0)|0;i=q;N=c[y>>2]|0;L=(N|0)<0|0?-1:0;H=c[x>>2]|0;P=gHb(H,(H|0)<0|0?-1:0,1e3,0)|0;H=F;if((L|0)<(H|0)|(L|0)==(H|0)&N>>>0<P>>>0){break a}c[x>>2]=0;c[y>>2]=0;break a}}while(0);if(z){break}if((yAb(u,2034192)|0)==0){break}if((yAb(u,2029976)|0)==0){break}if((yAb(u,2026096)|0)==0){break}CBb(C,u,p,0)|0}}while(0);E=E+1|0;}while(E>>>0<w>>>0)}w=Ty(j,0,0,1)|0;E=F;p=ZGb(m,l,w,E)|0;u=F;C=0;do{if((u|0)<(C|0)|(u|0)==(C|0)&p>>>0<0>>>0){Ty(j,p,u,1)|0;}else{if(!((w|0)==(m|0)&(E|0)==(l|0))){z=u;y=p;do{y=YGb(y,z,-1,-1)|0;z=F;lz(j)|0;}while(!((y|0)==0&(z|0)==0))}if((jz(j)|0)==0){r=0}else{break}i=d;return r|0}}while(0);yDb(h,16,2022680,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=d;return r|0}function iM(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;h=i;i=i+776|0;j=h|0;k=h+256|0;l=h+512|0;m=h+768|0;n=Bz(d)|0;o=n;a:do{if((o|0)>0){n=j|0;p=b;q=k|0;r=l|0;s=0;t=0;u=0;v=0;w=0;y=0;z=0;A=0;B=0;b:while(1){C=Ty(d,0,0,1)|0;D=F;if(!((D|0)<(g|0)|(D|0)==(g|0)&C>>>0<f>>>0)){E=-1094995529;G=53;break}C=Bz(d)|0;D=C;do{if((D|0)==0){H=0}else{C=D>>>0>256>>>0;mz(d,n,C?256:D)|0;if(C){I=D}else{H=D;break}while(1){lz(d)|0;C=I-1|0;if(C>>>0>256>>>0){I=C}else{H=256;break}}}}while(0);a[j+(H>>>0>255>>>0?255:H)|0]=0;D=Bz(d)|0;C=YGb(D,F,1,0)|0;D=F;J=(C&1|0)==0&(D&0|0)==0;K=C>>>1|D<<31;C=D>>1|((D|0)<0|0?-1:0)<<31;D=ZGb(0,0,K,C)|0;J?C:F;C=J?K:D;c:do{if((C|0)==(-4|0)){Bz(d)|0;L=B;M=z;N=y;O=w;P=u;Q=v;R=t;S=s}else if((C|0)==(-1|0)){D=Bz(d)|0;K=D;do{if((K|0)==0){T=0}else{D=K>>>0>256>>>0;mz(d,q,D?256:K)|0;if(D){U=K}else{T=K;break}while(1){lz(d)|0;D=U-1|0;if(D>>>0>256>>>0){U=D}else{T=256;break}}}}while(0);a[k+(T>>>0>255>>>0?255:T)|0]=0;yDb(p,24,2222216,(V=i,i=i+16|0,c[V>>2]=n,c[V+8>>2]=q,V)|0);i=V;L=B;M=z;N=y;O=w;P=u;Q=v;R=t;S=s}else if((C|0)==(-3|0)){Bz(d)|0;L=B;M=z;N=y;O=w;P=u;Q=v;R=t;S=s}else if((C|0)==(-2|0)){K=Bz(d)|0;D=K;do{if((D|0)==0){W=0}else{K=D>>>0>256>>>0;mz(d,r,K?256:D)|0;if(K){X=D}else{W=D;break}while(1){lz(d)|0;K=X-1|0;if(K>>>0>256>>>0){X=K}else{W=256;break}}}}while(0);a[l+(W>>>0>255>>>0?255:W)|0]=0;D=Bz(d)|0;K=F;J=Ty(d,0,0,1)|0;Y=YGb(J,F,D,K)|0;J=F;if(!((J|0)<(g|0)|(J|0)==(g|0)&Y>>>0<f>>>0)){E=-1094995529;G=53;break b}do{if((QGb(n,2212872)|0)==0){Z=GZ(e,0,D)|0}else{if((QGb(n,2203512)|0)==0){Z=GZ(e,1,D)|0;break}Y=xd(n|0,2196104,(V=i,i=i+8|0,c[V>>2]=m,V)|0)|0;i=V;if((Y|0)==1){Y=YGb(D,K,8,0)|0;J=GZ(e,74,Y)|0;if((J|0)==0){E=-12;G=53;break b}Y=c[m+4>>2]|0;_=fe(c[m>>2]|0)|0;$=J;aa=$|0;x=fe(Y|0)|0;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;aa=$+4|0;x=_|0;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;Z=J+8|0;break}if((QGb(n,2182632)|0)==0&((D|0)==8&(K|0)==0)){J=sz(d)|0;L=B;M=z;N=y;O=w;P=F;Q=J;R=t;S=s;break c}else{yDb(p,24,2168336,(V=i,i=i+16|0,c[V>>2]=n,c[V+8>>2]=r,V)|0);i=V;Vy(d,D,K)|0;L=B;M=z;N=y;O=w;P=u;Q=v;R=t;S=s;break c}}}while(0);if((Z|0)==0){E=-12;G=53;break b}mz(d,Z,D)|0;L=B;M=z;N=y;O=w;P=u;Q=v;R=t;S=s}else{if((C|0)<-4){Bz(d)|0;L=B;M=z;N=y;O=w;P=u;Q=v;R=t;S=s;break}if((QGb(n,2160896)|0)==0){L=C;M=z;N=y;O=w;P=u;Q=v;R=t;S=s;break}if((QGb(n,2154232)|0)==0){L=B;M=z;N=y;O=w;P=u;Q=v;R=t;S=C;break}if((QGb(n,2147040)|0)==0){L=B;M=z;N=y;O=w;P=u;Q=v;R=C;S=s;break}if((QGb(n,2140704)|0)==0){L=B;M=z;N=y;O=C;P=u;Q=v;R=t;S=s;break}if((QGb(n,2134816)|0)==0){L=B;M=z;N=C;O=w;P=u;Q=v;R=t;S=s;break}if((QGb(n,2128448)|0)==0){L=B;M=C;N=y;O=w;P=u;Q=v;R=t;S=s;break}yDb(p,24,2122352,(V=i,i=i+8|0,c[V>>2]=n,V)|0);i=V;L=B;M=z;N=y;O=w;P=u;Q=v;R=t;S=s}}while(0);C=A+1|0;if((C|0)<(o|0)){s=S;t=R;u=P;v=Q;w=O;y=N;z=M;A=C;B=L}else{ba=S;ca=R;da=P;ea=Q;fa=O;ga=N;ha=M;ia=L;break a}}if((G|0)==53){i=h;return E|0}}else{ba=0;ca=0;da=0;ea=0;fa=0;ga=0;ha=0;ia=0}}while(0);G=(ca|0)!=0;do{if(!((ea|0)==0&(da|0)==0&(G^1)&(fa|0)==0&(ga|0)==0&(ha|0)==0)){L=GZ(e,2,28)|0;if((L|0)==0){E=-12;i=h;return E|0}M=(ea|0)!=0|(da|0)!=0;N=(fa|0)!=0;O=ha|ga;Q=L;x=(M&1)<<1|G&1|(N&1)<<2|((O|0)!=0)<<3;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=L+4|0;if(G){P=Q;x=ca;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;ja=L+8|0}else{ja=Q}if(M){M=ja;Q=M|0;x=ea;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=M+4|0;x=da;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;ka=ja+8|0}else{ka=ja}if(N){N=ka;x=fa;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;la=ka+4|0}else{la=ka}if((O|0)==0){break}O=la;x=ga;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;O=la+4|0;x=ha;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x}}while(0);if((ia|ba|0)==0){E=0;i=h;return E|0}ha=GZ(e,70,10)|0;if((ha|0)==0){E=-12;i=h;return E|0}e=ha;x=ia;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=ha+4|0;x=ba;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;E=0;i=h;return E|0}function jM(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;e=i;i=i+64|0;f=e|0;g=e+40|0;h=e+48|0;j=e+56|0;k=j;l=i;i=i+8|0;m=l;n=d+12|0;o=c[n>>2]|0;p=c[d+16>>2]|0;c[o>>2]=d;q=d+24|0;r=o+3728|0;s=r;c[s>>2]=dEb(c[q>>2]|0,40)|0;t=d+1132|0;u=o+3732|0;v=u;c[v>>2]=dEb(c[t>>2]|0,4)|0;w=dEb((c[t>>2]|0)+(c[q>>2]|0)|0,8)|0;x=o+3756|0;y=x;c[y>>2]=w;do{if((c[s>>2]|0)!=0){if((c[v>>2]|0)==0|(w|0)==0){break}if((c[q>>2]|0)!=0){z=d+28|0;A=k+4|0;B=j;C=j;D=o+3740|0;E=0;do{G=c[(c[z>>2]|0)+(E<<2)>>2]|0;H=G+8|0;KO(c[H>>2]|0,A,h,B);I=c[H>>2]|0;do{if((c[I+8>>2]|0)==1){H=c[I+412>>2]|0;if((H|0)==0){J=11;break}c[B>>2]=1;c[A>>2]=H;K=1;L=H}else{J=11}}while(0);if((J|0)==11){J=0;DK(m,d,G,48e3);I=c[l>>2]|0;H=c[l+4>>2]|0;c[j>>2]=I;c[j+4>>2]=H;K=I;L=H}MT(G,64,K,L);H=c[D>>2]|0;I=0;while(1){M=c[y>>2]|0;if(!(I>>>0<H>>>0)){break}if((PGb(C,M+(I<<3)|0,8)|0)==0){break}else{I=I+1|0}}H=M+(I<<3)|0;G=c[j+4>>2]|0;c[H>>2]=c[j>>2];c[H+4>>2]=G;c[(c[s>>2]|0)+(E*40|0)+20>>2]=(c[y>>2]|0)+(I<<3);if((I|0)==(c[D>>2]|0)){c[D>>2]=I+1}G=c[B>>2]|0;H=gHb(G,(G|0)<0|0?-1:0,1e3,0)|0;G=F;N=c[A>>2]|0;O=(N|0)<0|0?-1:0;c[(c[s>>2]|0)+(E*40|0)+24>>2]=(G|0)<(O|0)|(G|0)==(O|0)&H>>>0<N>>>0?14:7;N=c[A>>2]|0;H=c[B>>2]|0;c[(c[s>>2]|0)+(E*40|0)+28>>2]=(((N|0)>(H|0)?N:H)|0)/(H|0)|0;E=E+1|0;}while(E>>>0<(c[q>>2]|0)>>>0)}if((c[t>>2]|0)!=0){E=d+1136|0;B=o+3740|0;A=0;D=c[B>>2]|0;while(1){C=(c[(c[E>>2]|0)+(A<<2)>>2]|0)+4|0;z=C;H=0;while(1){P=c[y>>2]|0;if(!(H>>>0<D>>>0)){break}if((PGb(z,P+(H<<3)|0,8)|0)==0){break}else{H=H+1|0}}z=C;I=P+(H<<3)|0;N=c[z+4>>2]|0;c[I>>2]=c[z>>2];c[I+4>>2]=N;c[(c[v>>2]|0)+(A<<2)>>2]=(c[y>>2]|0)+(H<<3);N=c[B>>2]|0;if((H|0)==(N|0)){I=H+1|0;c[B>>2]=I;Q=I}else{Q=N}N=A+1|0;if(N>>>0<(c[t>>2]|0)>>>0){A=N;D=Q}else{break}}}c[o+3736>>2]=32767;D=c[n>>2]|0;A=D+3752|0;c[A>>2]=7;B=D+3204|0;E=1;do{N=E-1|0;a[D+(E+3076)|0]=a[1678920+(N*5|0)|0]|0;c[B+(E<<2)>>2]=1678921+(N*5|0);E=E+1|0;}while((E|0)<(c[A>>2]|0));A=c[n>>2]|0;E=c[q>>2]|0;B=E>>>0>2>>>0;D=A+4|0;N=D;b[A+16>>1]=4096;b[A+20>>1]=1;b[A+24>>1]=1;if(B){b[A+28>>1]=56;b[A+32>>1]=1;R=3;J=29}else{if((E|0)!=0){R=2;J=29}}if((J|0)==29){I=254-R|0;z=d+28|0;O=f|0;G=f+4|0;S=f+8|0;T=f+12|0;U=f+16|0;V=A+3728|0;W=g+4|0;X=g|0;Y=0;Z=E;while(1){E=(((ba(Y,I)|0)>>>0)/(Z>>>0)|0)+R|0;_=Y+1|0;$=(((ba(_,I)|0)>>>0)/(Z>>>0)|0)+R|0;aa=c[(c[(c[z>>2]|0)+(Y<<2)>>2]|0)+8>>2]|0;ca=(c[aa+8>>2]|0)==1;da=ca&1;do{if(ca){ea=O0a(aa,0)|0;fa=(c[aa+48>>2]|0)==86021&(ea|0)==0?64:ea;J=36}else{kFb(g,aa+104|0,c[(c[V>>2]|0)+(Y*40|0)+20>>2]|0);if((c[W>>2]|0)==1){ea=c[X>>2]|0;fa=(ea|0)>0?ea:0;J=36;break}else{ga=Y&255;ha=1;J=53;break}}}while(0);do{if((J|0)==36){J=0;H=(fa|0)==0?1:fa;C=Y&255;if(ca&B){b[N+(E*12|0)>>1]=41;a[N+(E*12|0)+2|0]=C;b[N+(E*12|0)+4>>1]=1;a[N+(E*12|0)+11|0]=qM(c[n>>2]|0,aa,-1,1)|0;ia=E+1|0;ja=H;ka=C;J=38;break}if(!ca){ga=C;ha=H;J=53;break}b[N+(E*12|0)>>1]=40;a[N+(E*12|0)+2|0]=C;b[N+(E*12|0)+4>>1]=1;a[N+(E*12|0)+11|0]=qM(c[n>>2]|0,aa,-1,0)|0;ea=E+1|0;b[N+(ea*12|0)>>1]=41;a[N+(ea*12|0)+2|0]=C;b[N+(ea*12|0)+4>>1]=1;a[N+(ea*12|0)+11|0]=qM(c[n>>2]|0,aa,-1,1)|0;la=C;ma=H;na=E+2|0;J=39}}while(0);if((J|0)==53){J=0;b[N+(E*12|0)>>1]=40;a[N+(E*12|0)+2|0]=ga;b[N+(E*12|0)+4>>1]=1;H=E+1|0;b[N+(H*12|0)>>1]=41;a[N+(H*12|0)+2|0]=ga;b[N+(H*12|0)+4>>1]=1;ia=E+2|0;ja=ha;ka=ga;J=38}do{if((J|0)==38){J=0;if(ca){la=ka;ma=ja;na=ia;J=39;break}b[N+(ia*12|0)>>1]=33;a[N+(ia*12|0)+2|0]=ka;b[N+(ia*12|0)+4>>1]=1;b[N+(ia*12|0)+8>>1]=ja;oa=ia+1|0;pa=ka;qa=ja}}while(0);if((J|0)==39){J=0;E=c[aa+424>>2]|0;H=c[aa+72>>2]|0;C=gHb(H,(H|0)<0|0?-1:0,E,(E|0)<0|0?-1:0)|0;E=c[aa+412>>2]<<3;H=eHb(C,F,E,(E|0)<0|0?-1:0)|0;E=H;C=E+2&65535;b[N+(na*12|0)>>1]=1;a[N+(na*12|0)+2|0]=la;b[N+(na*12|0)+4>>1]=C;ea=H&65535;b[N+(na*12|0)+6>>1]=ea;b[N+(na*12|0)+8>>1]=0;a[N+(na*12|0)+11|0]=qM(c[n>>2]|0,aa,E,da)|0;H=na+1|0;b[N+(H*12|0)>>1]=1;a[N+(H*12|0)+2|0]=la;b[N+(H*12|0)+4>>1]=C;ra=E+1|0;sa=ra&65535;b[N+(H*12|0)+6>>1]=sa;b[N+(H*12|0)+8>>1]=0;a[N+(H*12|0)+11|0]=qM(c[n>>2]|0,aa,ra,da)|0;H=na+2|0;ta=ma&65535;b[N+(H*12|0)>>1]=1;a[N+(H*12|0)+2|0]=la;b[N+(H*12|0)+4>>1]=C;b[N+(H*12|0)+6>>1]=ea;b[N+(H*12|0)+8>>1]=ta;a[N+(H*12|0)+11|0]=qM(c[n>>2]|0,aa,E,da)|0;E=na+3|0;b[N+(E*12|0)>>1]=1;a[N+(E*12|0)+2|0]=la;b[N+(E*12|0)+4>>1]=C;b[N+(E*12|0)+6>>1]=sa;b[N+(E*12|0)+8>>1]=ta;a[N+(E*12|0)+11|0]=qM(c[n>>2]|0,aa,ra,da)|0;oa=na+4|0;pa=la;qa=ma}do{if((c[aa+176>>2]|0)==0){if((c[aa+48>>2]|0)==86021){c[O>>2]=2;c[G>>2]=9;c[S>>2]=16;ua=3;va=2;break}else{c[O>>2]=1;ua=1;va=1;break}}else{c[O>>2]=-2;c[G>>2]=-1;c[S>>2]=1;c[T>>2]=3;c[U>>2]=4;ua=5;va=-2}}while(0);ra=$-oa|0;E=ca&1|32;ta=0;sa=va;while(1){C=((ba(ta,ra)|0)/(ua|0)|0)+oa|0;H=ta+1|0;ea=((ba(H,ra)|0)/(ua|0)|0)+oa|0;wa=ba(sa,qa)|0;c[f+(ta<<2)>>2]=wa;if((C|0)<(ea|0)){xa=ea-C&65535;ya=wa&65535;if(ca){wa=C;do{b[N+(wa*12|0)>>1]=E;a[N+(wa*12|0)+2|0]=pa;b[N+(wa*12|0)+4>>1]=xa;b[N+(wa*12|0)+6>>1]=wa-C;b[N+(wa*12|0)+8>>1]=ya;a[N+(wa*12|0)+11|0]=qM(c[n>>2]|0,aa,-1,da)|0;wa=wa+1|0;}while((wa|0)<(ea|0))}else{wa=C;do{b[N+(wa*12|0)>>1]=E;a[N+(wa*12|0)+2|0]=pa;b[N+(wa*12|0)+4>>1]=xa;b[N+(wa*12|0)+6>>1]=wa-C;b[N+(wa*12|0)+8>>1]=ya;wa=wa+1|0;}while((wa|0)<(ea|0))}}if((H|0)>=(ua|0)){break}ta=H;sa=c[f+(H<<2)>>2]|0}sa=c[q>>2]|0;if(_>>>0<sa>>>0){Y=_;Z=sa}else{break}}}Z=A+940|0;VGb(A+952|0,Z|0,2124)|0;b[Z>>1]=8192;b[A+3064>>1]=8192;b[D>>1]=8192;if((b[o+940>>1]|0)!=8192){yDb(0,0,2022928,(Z=i,i=i+24|0,c[Z>>2]=2117248,c[Z+8>>2]=1949704,c[Z+16>>2]=753,Z)|0);i=Z;Cd();return 0}Ry(p,2105368,24);Py(p,0);Z=mM(d,p)|0;if((Z|0)<0){za=Z;i=e;return za|0}Z=d+1204|0;if((c[Z>>2]|0)<0){c[Z>>2]=1}Sy(p);za=0;i=e;return za|0}}while(0);$Db(r);$Db(u);$Db(x);za=-12;i=e;return za|0}function kM(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=c[a+12>>2]|0;m=l;n=b+32|0;o=c[n>>2]|0;p=l+3728|0;q=c[p>>2]|0;r=q+(o*40|0)|0;s=c[a+16>>2]|0;c[h>>2]=0;t=(c[b+36>>2]&1|0)==0;u=b+28|0;v=c[u>>2]|0;w=b+8|0;x=c[w>>2]|0;y=c[w+4>>2]|0;z=0;if((y|0)<(z|0)|(y|0)==(z|0)&x>>>0<0>>>0){yDb(a,16,2295216,(A=i,i=i+24|0,c[A>>2]=o,c[A+8>>2]=x,c[A+16>>2]=y,A)|0);i=A;B=-22;i=f;return B|0}do{if((c[b+44>>2]|0)==0){C=v;D=0}else{if((c[l+3780>>2]|0)<=3){C=v;D=0;break}y=Mz(h)|0;if((y|0)<0){B=y;i=f;return B|0}else{y=a+28|0;oM(c[y>>2]|0,c[h>>2]|0,b,0);oM(c[y>>2]|0,c[h>>2]|0,b,1);y=Oz(c[h>>2]|0,j)|0;C=y+v|0;D=y;break}}}while(0);v=l+3752|0;h=_Gb(1,0,((c[v>>2]|0)*3|0)+20|0)|0;y=F;x=Ty(s,0,0,1)|0;z=F;if(!((y|0)>(z|0)|(y|0)==(z|0)&h>>>0>x>>>0)){mM(a,s)|0}if(t){E=1}else{E=(c[r>>2]&1|0)!=0}t=C+30|0;x=Ty(s,0,0,1)|0;h=YGb(x,F,t,(t|0)<0|0?-1:0)|0;t=F;x=l+3744|0;z=YGb(c[l+3736>>2]|0,0,c[x>>2]|0,c[x+4>>2]|0)|0;y=F;a:do{if(!(((t|0)<(y|0)|(t|0)==(y|0)&h>>>0<z>>>0)&E)){G=k;c[G>>2]=c[157494];c[G+4>>2]=c[157495];c[G+8>>2]=c[157496];c[G+12>>2]=c[157497];c[G+16>>2]=c[157498];c[G+20>>2]=c[157499];H=q+(o*40|0)+20|0;I=b+16|0;wX(m,c[H>>2]|0,c[I>>2]|0,c[I+4>>2]|0);J=a+24|0;if((c[J>>2]|0)==0){K=k|0}else{L=a+28|0;M=k|0;N=0;while(1){O=c[(c[L>>2]|0)+(N<<2)>>2]|0;P=c[I>>2]|0;Q=c[I+4>>2]|0;R=c[H>>2]|0;S=c[R>>2]|0;T=c[(c[p>>2]|0)+(N*40|0)+20>>2]|0;U=c[T+4>>2]|0;V=gHb(U,(U|0)<0|0?-1:0,S,(S|0)<0|0?-1:0)|0;S=F;U=c[R+4>>2]|0;R=c[T>>2]|0;T=gHb(R,(R|0)<0|0?-1:0,U,(U|0)<0|0?-1:0)|0;U=HDb(P,Q,V,S,T,F,2)|0;T=oT(O,U,F,1)|0;if((T|0)>-1){U=c[M>>2]|0;S=c[M+4>>2]|0;V=(c[O+400>>2]|0)+(T*24|0)|0;T=c[V>>2]|0;O=c[V+4>>2]|0;V=S>>>0>O>>>0|S>>>0==O>>>0&U>>>0>T>>>0;c[M>>2]=V?T:U;c[M+4>>2]=V?O:S}S=N+1|0;if(S>>>0<(c[J>>2]|0)>>>0){N=S}else{K=M;break}}}if((c[K>>2]|0)==(-1|0)&(c[K+4>>2]|0)==2147483647){c[K>>2]=0;c[K+4>>2]=0}M=fGb(c[l+3760>>2]|0,G,618,0)|0;N=Ty(s,0,0,1)|0;c[x>>2]=N;c[x+4>>2]=F;N=Mz(g)|0;if((N|0)<0){B=N;i=f;return B|0}N=c[H>>2]|0;L=c[g>>2]|0;S=c[l+3756>>2]|0;O=gHb(c[l+3740>>2]|0,0,c[I>>2]|0,c[I+4>>2]|0)|0;V=N-S>>3;S=YGb(V,(V|0)<0|0?-1:0,O,F)|0;cz(L,S,F);S=c[g>>2]|0;if((M|0)==0){W=0;X=0}else{L=M;M=ZGb(c[x>>2]|0,c[x+4>>2]|0,c[L>>2]|0,c[L+4>>2]|0)|0;L=F;W=L>>>4|0<<28;X=M>>>4|L<<28}cz(S,X,W);nM(s,c[g>>2]|0,-288733847,1313596589);S=AX(m,c[x>>2]|0,c[x+4>>2]|0,0,0,c[I>>2]|0,c[I+4>>2]|0)|0;if((S|0)<0){B=S;i=f;return B|0}S=l+3764|0;L=c[S>>2]|0;M=fHb(0,268435456,L,(L|0)<0|0?-1:0)|0;if(!((M|0)==0&(F|0)==0)){break}if((c[J>>2]|0)==0){break}else{Y=0;Z=L}while(1){L=(c[p>>2]|0)+(Y*40|0)+36|0;bEb(L,Z<<1,8)|0;M=c[L>>2]|0;if((M|0)==0){B=-12;break}Z=c[S>>2]|0;L=(Z|0)==1?0:Z;O=Z<<1;if((L|0)<(O|0)){V=L;do{L=M+(V<<3)|0;c[L>>2]=0;c[L+4>>2]=-2147483648;V=V+1|0;}while((V|0)<(O|0))}Y=Y+1|0;if(!(Y>>>0<(c[J>>2]|0)>>>0)){break a}}i=f;return B|0}}while(0);Y=q+(o*40|0)+8|0;if((c[Y>>2]|0)==0&(c[Y+4>>2]|0)==(-2147483648|0)){yDb(0,0,2022928,(A=i,i=i+24|0,c[A>>2]=2278656,c[A+8>>2]=1949704,c[A+16>>2]=1020,A)|0);i=A;Cd();return 0}Z=q+(o*40|0)+24|0;p=(1<<c[Z>>2])-1|0;g=p&c[w>>2];W=((p|0)<0|0?-1:0)&c[w+4>>2];p=xX(r,g,W)|0;X=c[w>>2]|0;K=c[w+4>>2]|0;if((p|0)==(X|0)&(F|0)==(K|0)){_=W;$=g}else{g=1<<c[Z>>2];Z=YGb(g,(g|0)<0|0?-1:0,X,K)|0;_=F;$=Z}Z=c[u>>2]|0;do{if((Z|0)>4096){aa=0}else{K=c[v>>2]|0;if((K|0)<=1){aa=0;break}X=b+24|0;g=1;W=0;p=0;while(1){k=d[m+3076+g|0]|0;if((Z|0)>=(k|0)&(k|0)>(p|0)){E=(PGb(c[X>>2]|0,c[m+3204+(g<<2)>>2]|0,k)|0)==0;ba=E?k:p;ca=E?g:W}else{ba=p;ca=W}E=g+1|0;if((E|0)<(K|0)){g=E;W=ca;p=ba}else{aa=ca;break}}}}while(0);ca=l+4|0;ba=l+(aa+3076)|0;Z=0;v=-1;p=2147483647;while(1){W=ca+(Z*12|0)|0;g=e[W>>1]|0;do{if((g&8192|0)==0){K=pM(m,r,W,b)|0;X=g&4096;E=X>>>12;k=(X|0)==0?g:K;if((k&K|0)!=(K|0)){da=p;ea=v;break}if(((k^K)&1|0)!=0){da=p;ea=v;break}if((k&16|0)==0){fa=E}else{K=c[n>>2]|0;fa=(bz(K,(K|0)<0|0?-1:0)|0)+E|0}E=e[ca+(Z*12|0)+4>>1]|0;if(((C|0)%(E|0)|0|0)!=(e[ca+(Z*12|0)+6>>1]|0|0)){da=p;ea=v;break}if((k&32|0)==0){ga=fa}else{K=(C|0)/(E|0)|0;ga=(bz(K,(K|0)<0|0?-1:0)|0)+fa|0}K=(k&64|0)==0?ga:ga+4|0;if((k&8|0)==0){ha=K}else{ha=(bz($,_)|0)+K|0}if((k&4096|0)==0){ia=k}else{ia=(d[ba]|0)>>>0>((d[l+((d[ca+(Z*12|0)+11|0]|0)+3076)|0]|0)+1|0)>>>0?k|1024:k}if((ia&1024|0)==0){ja=ha-(d[l+((d[ca+(Z*12|0)+11|0]|0)+3076)|0]|0)|0}else{ja=ha+1-(d[ba]|0)|0}k=((ja<<2|ia>>>3&1)^1)+(ia>>>6&1^1)|0;K=(k|0)<(p|0);da=K?k:p;ea=K?Z:v}else{da=p;ea=v}}while(0);g=Z+1|0;if((g|0)<256){Z=g;v=ea;p=da}else{break}}if((ea|0)==-1){yDb(0,0,2022928,(A=i,i=i+24|0,c[A>>2]=2263376,c[A+8>>2]=1949704,c[A+16>>2]=1084,A)|0);i=A;Cd();return 0}A=ca+(ea*12|0)|0;da=e[A>>1]|0;p=pM(m,r,A,b)|0;A=d[ca+(ea*12|0)+11|0]|0;kz(s,310,0);Py(s,ea);if((da&4096|0)==0){ka=da}else{m=(da^p)&-4097;cz(s,m,(m|0)<0|0?-1:0);ka=p}if((ka&16|0)!=0){p=c[n>>2]|0;cz(s,p,(p|0)<0|0?-1:0)}if((ka&8|0)!=0){cz(s,$,_)}if((ka&32|0)!=0){_=(C|0)/(e[ca+(ea*12|0)+4>>1]|0|0)|0;cz(s,_,(_|0)<0|0?-1:0)}if((ka&1024|0)==0){la=A}else{cz(s,aa,(aa|0)<0|0?-1:0);la=aa}aa=jz(s)|0;if((ka&64|0)!=0){Yy(s,aa)}if((ka&256|0)!=0){Ry(s,c[j>>2]|0,D);$Db(j)}j=d[l+(la+3076)|0]|0;Ry(s,(c[b+24>>2]|0)+j|0,(c[u>>2]|0)-j|0);c[r>>2]=ka;r=c[w+4>>2]|0;c[Y>>2]=c[w>>2];c[Y+4>>2]=r;do{if((ka&1|0)!=0){jT(c[(c[a+28>>2]|0)+(c[n>>2]<<2)>>2]|0,c[x>>2]|0,c[x+4>>2]|0,c[w>>2]|0,c[w+4>>2]|0,0,0,1)|0;r=c[q+(o*40|0)+36>>2]|0;if((r|0)==0){break}Y=r+(c[l+3764>>2]<<3)|0;if(!((c[Y>>2]|0)==0&(c[Y+4>>2]|0)==(-2147483648|0))){break}r=c[w+4>>2]|0;c[Y>>2]=c[w>>2];c[Y+4>>2]=r}}while(0);x=l+3776|0;n=c[x>>2]|0;a=l+3768|0;do{if((n|0)==0){ma=q+(o*40|0)+20|0}else{l=q+(o*40|0)+20|0;if((LDb(c[a>>2]|0,c[a+4>>2]|0,n,c[w>>2]|0,c[w+4>>2]|0,c[l>>2]|0)|0)<0){ma=l;break}else{B=0}i=f;return B|0}}while(0);n=c[w+4>>2]|0;c[a>>2]=c[w>>2];c[a+4>>2]=n;c[x>>2]=c[ma>>2];B=0;i=f;return B|0}function lM(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;b=i;i=i+40|0;e=b|0;f=b+24|0;g=b+32|0;h=c[a+12>>2]|0;j=h;k=c[a+16>>2]|0;l=h+3752|0;if((c[l>>2]|0)<3){do{mM(a,k)|0;}while((c[l>>2]|0)<3)}do{if((Mz(g)|0)>-1){l=h+3764|0;if((c[l>>2]|0)==0){break}m=c[g>>2]|0;n=e;TGb(n|0,0,24)|0;c[f>>2]=0;c[f+4>>2]=0;o=Ty(m,0,0,1)|0;p=F;q=c[h+3776>>2]|0;r=h+3768|0;s=c[h+3756>>2]|0;t=gHb(c[h+3740>>2]|0,0,c[r>>2]|0,c[r+4>>2]|0)|0;r=q-s>>3;s=YGb(r,(r|0)<0|0?-1:0,t,F)|0;cz(m,s,F);s=c[l>>2]|0;cz(m,s,(s|0)<0|0?-1:0);s=c[l>>2]|0;if((s|0)>0){t=h+3760|0;r=f;q=f+4|0;u=e|0;v=0;while(1){fGb(c[t>>2]|0,n,618,r)|0;w=c[q>>2]|0;x=c[w+4>>2]|0;y=c[u+4>>2]|0;z=ZGb((c[w>>2]|0)>>>4|x<<28,x>>>4|0<<28,(c[u>>2]|0)>>>4|y<<28,y>>>4|0<<28)|0;cz(m,z,F);z=c[q>>2]|0;y=c[z+4>>2]|0;c[u>>2]=c[z>>2];c[u+4>>2]=y;y=v+1|0;z=c[l>>2]|0;if((y|0)<(z|0)){v=y}else{A=z;break}}}else{A=s}v=h;u=c[v>>2]|0;a:do{if((c[u+24>>2]|0)!=0){q=h+3728|0;r=0;n=A;t=u;b:while(1){if((n|0)>0){z=(c[q>>2]|0)+(r*40|0)+36|0;y=-1;x=-1;w=0;B=n;while(1){C=c[z>>2]|0;do{if((w|0)==0){D=B;E=C;G=c[C+4>>2]|0;H=c[C>>2]|0}else{I=C+(w<<3)|0;J=c[I>>2]|0;K=c[I+4>>2]|0;I=C+(w-1<<3)|0;if(!((J|0)==(c[I>>2]|0)&(K|0)==(c[I+4>>2]|0))){D=B;E=C;G=K;H=J;break}yDb(c[v>>2]|0,24,2070664,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;J=c[z>>2]|0;K=J+(w<<3)|0;c[K>>2]=0;c[K+4>>2]=-2147483648;D=c[l>>2]|0;E=J;G=-2147483648;H=0}}while(0);C=(w+1|0)==(D|0);J=((H|0)!=0|(G|0)!=(-2147483648|0))^C;K=J&1;c:do{if((w|0)>=(D|0)|C){M=w;N=0}else{I=0;O=w;while(1){P=I+1|0;Q=O+1|0;if((Q|0)>=(D|0)){M=Q;N=P;break c}R=E+(Q<<3)|0;if(((c[R>>2]|0)!=0|(c[R+4>>2]|0)!=(-2147483648|0))^J){M=Q;N=P;break}else{I=P;O=Q}}}}while(0);J=K<<1|N<<2|1;cz(m,J,(J|0)<0|0?-1:0);d:do{if((N|0)<0){S=y;T=x}else{J=y;C=x;O=M-N|0;while(1){if((O|0)>=(c[l>>2]|0)){S=J;T=C;break d}I=(c[z>>2]|0)+(O<<3)|0;Q=c[I>>2]|0;P=c[I+4>>2]|0;if((Q|0)==0&(P|0)==(-2147483648|0)){U=J;V=C}else{if(!((P|0)>(J|0)|(P|0)==(J|0)&Q>>>0>C>>>0)){break b}I=ZGb(Q,P,C,J)|0;cz(m,I,F);I=(c[z>>2]|0)+(O<<3)|0;U=c[I+4>>2]|0;V=c[I>>2]|0}I=O+1|0;if((I|0)>(M|0)){S=U;T=V;break}else{J=U;C=V;O=I}}}}while(0);K=M+1|0;W=c[l>>2]|0;if((K|0)<(W|0)){y=S;x=T;w=K;B=W}else{break}}X=W;Y=c[v>>2]|0}else{X=n;Y=t}B=r+1|0;if(B>>>0<(c[Y+24>>2]|0)>>>0){r=B;n=X;t=Y}else{break a}}yDb(0,0,2022928,(L=i,i=i+24|0,c[L>>2]=1979584,c[L+8>>2]=1949704,c[L+16>>2]=608,L)|0);i=L;Cd();return 0}}while(0);v=Ty(m,0,0,1)|0;l=ZGb(v,F,o,p)|0;v=F;u=YGb(l,v,12,0)|0;s=F;t=u;n=t>>>0>65535>>>0;r=n?t>>>16:t;t=n?16:0;if((r&65280|0)==0){Z=t;_=r}else{Z=t|8;_=r>>>8}r=((d[1191992+_|0]|0)+Z|0)/7|0;t=0;n=YGb(l,v,21,0)|0;v=YGb(n,F,(((s|0)>(t|0)|(s|0)==(t|0)&u>>>0>4096>>>0)&1)<<2,0)|0;u=YGb(v,F,r,(r|0)<0|0?-1:0)|0;ez(m,u,F);nM(k,c[g>>2]|0,790881870,1314446695)}}while(0);BX(j);j=a+24|0;a=h+3728|0;if((c[j>>2]|0)==0){$Db(a);$=h+3732|0;$Db($);aa=h+3756|0;$Db(aa);i=b;return 0}g=a;k=0;do{$Db((c[g>>2]|0)+(k*40|0)+36|0);k=k+1|0;}while(k>>>0<(c[j>>2]|0)>>>0);$Db(a);$=h+3732|0;$Db($);aa=h+3756|0;$Db(aa);i=b;return 0}function mM(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;h=i;i=i+328|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+288|0;p=h+296|0;q=h+304|0;r=h+312|0;s=h+320|0;t=f+12|0;u=c[t>>2]|0;v=u;RG(f,1169024,0);w=Mz(q)|0;if((w|0)<0){x=w;i=h;return x|0}w=c[q>>2]|0;y=u+3780|0;c[y>>2]=3;cz(w,3,0);if((c[y>>2]|0)>3){y=c[u+3784>>2]|0;cz(w,y,(y|0)<0|0?-1:0)}y=u;cz(w,c[(c[y>>2]|0)+24>>2]|0,0);cz(w,c[u+3736>>2]|0,0);z=u+3740|0;cz(w,c[z>>2]|0,0);if((c[z>>2]|0)==0){A=0;B=0;C=1;D=0;E=0}else{G=u+3756|0;H=0;while(1){I=c[(c[G>>2]|0)+(H<<3)>>2]|0;cz(w,I,(I|0)<0|0?-1:0);I=c[(c[G>>2]|0)+(H<<3)+4>>2]|0;cz(w,I,(I|0)<0|0?-1:0);I=H+1|0;if(I>>>0<(c[z>>2]|0)>>>0){H=I}else{A=0;B=0;C=1;D=0;E=0;break}}}while(1){H=b[v+4+(E*12|0)+8>>1]|0;G=H<<16>>16;I=b[v+4+(E*12|0)+4>>1]|0;J=I&65535;K=a[v+4+(E*12|0)+2|0]|0;L=K&255;M=b[v+4+(E*12|0)+6>>1]|0;N=a[v+4+(E*12|0)+11|0]|0;O=N&255;P=(D|0)==(O|0)?M<<16>>16==0?(B|0)==(L|0)?(C|0)==(J|0)?(A|0)!=(G|0)|0:2:3:4:8;Q=b[v+4+(E*12|0)>>1]|0;R=M&65535;a:do{if((E|0)<256){S=0;T=E;while(1){U=T;while(1){V=U+1|0;if((U|0)==78){U=V}else{break}}if(!((b[v+4+(U*12|0)+8>>1]|0)==H<<16>>16)){W=S;X=U;break a}if(!((b[v+4+(U*12|0)>>1]|0)==Q<<16>>16)){W=S;X=U;break a}if(!((a[v+4+(U*12|0)+2|0]|0)==K<<24>>24)){W=S;X=U;break a}if(!((b[v+4+(U*12|0)+4>>1]|0)==I<<16>>16)){W=S;X=U;break a}if((e[v+4+(U*12|0)+6>>1]|0)!=(S+R|0)){W=S;X=U;break a}if(!((a[v+4+(U*12|0)+11|0]|0)==N<<24>>24)){W=S;X=U;break a}Y=S+1|0;if((V|0)<256){S=Y;T=V}else{W=Y;X=V;break}}}else{W=0;X=E}}while(0);T=(W|0)==(J-R|0)?P:6;cz(w,Q&65535,0);cz(w,T,(T|0)<0|0?-1:0);do{if((T|0)!=0){S=H<<16>>16;Y=H<<16>>16<0|0?-1:0;Z=H<<16>>16>-1;_=ZGb(0,0,S,Y)|0;$=Z?S:_;_=ZGb($<<1|0>>>31,(Z?Y:F)<<1|$>>>31,H<<16>>16>0|0,0)|0;cz(w,_,F);if(!(T>>>0>1>>>0)){break}cz(w,I&65535,0);if(!(T>>>0>2>>>0)){break}cz(w,K&255,0);if(!(T>>>0>3>>>0)){break}cz(w,M&65535,0);if(!(T>>>0>4>>>0)){break}cz(w,0,0);if(!(T>>>0>5>>>0)){break}cz(w,W,(W|0)<0|0?-1:0);if(!(T>>>0>6>>>0)){break}cz(w,1,-1073741824);if(!(T>>>0>7>>>0)){break}cz(w,N&255,0)}}while(0);if((X|0)<256){A=G;B=L;C=J;D=O;E=X}else{break}}X=u+3752|0;E=(c[X>>2]|0)-1|0;cz(w,E,(E|0)<0|0?-1:0);if((c[X>>2]|0)>1){E=1;do{D=v+3076+E|0;cz(w,d[D]|0,0);Ry(w,c[v+3204+(E<<2)>>2]|0,d[D]|0);E=E+1|0;}while((E|0)<(c[X>>2]|0))}nM(g,c[q>>2]|0,526320813,1313700438);E=(c[(c[y>>2]|0)+24>>2]|0)==0;v=Mz(q)|0;w=(v|0)<0;b:do{if(E){aa=v;ba=w}else{D=0;C=v;B=w;while(1){if(B){x=C;ca=83;break}A=c[q>>2]|0;W=c[(c[(c[y>>2]|0)+28>>2]|0)+(D<<2)>>2]|0;V=c[t>>2]|0;N=c[W+8>>2]|0;cz(A,D,(D|0)<0|0?-1:0);T=N+8|0;M=c[T>>2]|0;if((M|0)==3){cz(A,2,0)}else if((M|0)==0){cz(A,0,0)}else if((M|0)==1){cz(A,1,0)}else{cz(A,3,0)}cz(A,4,0);M=c[N+52>>2]|0;if((M|0)==0){break}Yy(A,M);M=V+3728|0;K=(c[(c[M>>2]|0)+(D*40|0)+20>>2]|0)-(c[V+3756>>2]|0)>>3;cz(A,K,(K|0)<0|0?-1:0);K=c[(c[M>>2]|0)+(D*40|0)+24>>2]|0;cz(A,K,(K|0)<0|0?-1:0);K=c[(c[M>>2]|0)+(D*40|0)+28>>2]|0;cz(A,K,(K|0)<0|0?-1:0);K=c[N+176>>2]|0;cz(A,K,(K|0)<0|0?-1:0);Py(A,0);K=N+100|0;M=c[K>>2]|0;cz(A,M,(M|0)<0|0?-1:0);Ry(A,c[N+96>>2]|0,c[K>>2]|0);K=c[T>>2]|0;if((K|0)==0){T=c[N+120>>2]|0;cz(A,T,(T|0)<0|0?-1:0);T=c[N+124>>2]|0;cz(A,T,(T|0)<0|0?-1:0);T=c[W+80>>2]|0;do{if((T|0)<1){ca=41}else{M=W+84|0;if((c[M>>2]|0)<1){ca=41;break}cz(A,T,(T|0)<0|0?-1:0);V=c[M>>2]|0;cz(A,V,(V|0)<0|0?-1:0)}}while(0);if((ca|0)==41){ca=0;cz(A,0,0);cz(A,0,0)}cz(A,0,0)}else if((K|0)==1){T=c[N+412>>2]|0;cz(A,T,(T|0)<0|0?-1:0);cz(A,1,0);T=c[N+416>>2]|0;cz(A,T,(T|0)<0|0?-1:0)}nM(g,c[q>>2]|0,1542650331,1314066752);T=D+1|0;W=T>>>0<(c[(c[y>>2]|0)+24>>2]|0)>>>0;V=Mz(q)|0;M=(V|0)<0;if(W){D=T;C=V;B=M}else{aa=V;ba=M;break b}}if((ca|0)==83){i=h;return x|0}yDb(f,16,2316488,(da=i,i=i+8|0,c[da>>2]=D,da)|0);i=da;x=-22;i=h;return x|0}}while(0);if(ba){x=aa;i=h;return x|0}aa=c[q>>2]|0;ba=c[y>>2]|0;c[p>>2]=0;if((Mz(o)|0)>=0){f=ba+1140|0;ba=BBb(c[f>>2]|0,9203080,0,2)|0;if((ba|0)==0){ea=0;fa=0}else{t=0;w=ba;do{ba=c[o>>2]|0;v=c[w>>2]|0;E=c[w+4>>2]|0;B=SGb(v|0)|0;cz(ba,B,(B|0)<0|0?-1:0);Ry(ba,v,B);cz(ba,2,0);B=SGb(E|0)|0;cz(ba,B,(B|0)<0|0?-1:0);Ry(ba,E,B);t=t+1|0;w=BBb(c[f>>2]|0,9203080,w,2)|0;}while((w|0)!=0);ea=(t|0)<0|0?-1:0;fa=t}cz(aa,0,0);cz(aa,0,0);cz(aa,0,0);cz(aa,0,0);cz(aa,fa,ea);ea=Oz(c[o>>2]|0,p)|0;Ry(aa,c[p>>2]|0,ea);ZDb(c[p>>2]|0)}nM(g,c[q>>2]|0,-1248413064,1313450856);p=c[y>>2]|0;c:do{if((c[p+24>>2]|0)==0){ga=p}else{ea=n|0;aa=c[292281]|0;o=(aa|0)==0;fa=0;while(1){t=Mz(q)|0;if((t|0)<0){x=t;ca=83;break}t=c[q>>2]|0;w=c[(c[(c[y>>2]|0)+28>>2]|0)+(fa<<2)>>2]|0;c[m>>2]=0;f=Mz(l)|0;if((f|0)<0){ha=f}else{f=w+88|0;B=BBb(c[f>>2]|0,9203080,0,2)|0;if((B|0)==0){ia=0}else{E=0;ba=B;while(1){B=c[l>>2]|0;v=c[ba>>2]|0;C=c[ba+4>>2]|0;O=SGb(v|0)|0;cz(B,O,(O|0)<0|0?-1:0);Ry(B,v,O);cz(B,2,0);O=SGb(C|0)|0;cz(B,O,(O|0)<0|0?-1:0);Ry(B,C,O);O=E+1|0;C=BBb(c[f>>2]|0,9203080,ba,2)|0;if((C|0)==0){ia=O;break}else{E=O;ba=C}}}if(o){ja=ia}else{ba=w+72|0;E=ia;f=0;A=aa;while(1){if((c[ba>>2]&A|0)==0){ka=E}else{N=c[l>>2]|0;K=1169112+(f<<4)|0;cz(N,11,0);Ry(N,1902256,11);cz(N,2,0);C=SGb(K|0)|0;cz(N,C,(C|0)<0|0?-1:0);Ry(N,K,C);ka=E+1|0}C=f+1|0;K=c[1169124+(C<<4)>>2]|0;if((K|0)==0){ja=ka;break}else{E=ka;f=C;A=K}}}A=c[w+8>>2]|0;if((c[A+8>>2]|0)==0){f=c[A+104>>2]|0;Lb(ea|0,256,1882272,(da=i,i=i+16|0,c[da>>2]=c[A+108>>2],c[da+8>>2]=f,da)|0)|0;i=da;f=c[l>>2]|0;cz(f,12,0);Ry(f,2340128,12);cz(f,2,0);A=SGb(ea|0)|0;cz(f,A,(A|0)<0|0?-1:0);Ry(f,ea,A);la=ja+1|0}else{la=ja}A=Oz(c[l>>2]|0,m)|0;if((la|0)!=0){f=fa+1|0;cz(t,f,(f|0)<0|0?-1:0);cz(t,0,0);cz(t,0,0);cz(t,0,0);cz(t,la,(la|0)<0|0?-1:0);Ry(t,c[m>>2]|0,A)}ZDb(c[m>>2]|0);ha=la}if((ha|0)<0){x=ha;ca=83;break}A=c[q>>2]|0;if((ha|0)>0){nM(g,A,-1248413064,1313450856)}else{Oz(A,r)|0;ZDb(c[r>>2]|0)}A=fa+1|0;f=c[y>>2]|0;if(A>>>0<(c[f+24>>2]|0)>>>0){fa=A}else{ga=f;break c}}if((ca|0)==83){i=h;return x|0}}}while(0);d:do{if((c[ga+1132>>2]|0)!=0){r=k;ha=u+3732|0;la=u+3756|0;m=0;while(1){l=Mz(q)|0;if((l|0)<0){x=l;ca=83;break}l=c[q>>2]|0;c[k>>2]=0;ja=c[(c[(c[y>>2]|0)+1136>>2]|0)+(m<<2)>>2]|0;ma=Mz(j)|0;if((ma|0)<0){break}cz(l,0,0);da=m+1|0;ka=da;ia=ZGb(ka<<1|0>>>31,((da|0)<0|0?-1:0)<<1|ka>>>31,(da|0)>0|0,0)|0;cz(l,ia,F);ia=c[(c[ha>>2]|0)+(m<<2)>>2]|0;ka=ja+16|0;n=c[la>>2]|0;p=gHb(c[z>>2]|0,0,c[ka>>2]|0,c[ka+4>>2]|0)|0;fa=ia-n>>3;n=YGb(fa,(fa|0)<0|0?-1:0,p,F)|0;cz(l,n,F);n=ja+24|0;p=ZGb(c[n>>2]|0,c[n+4>>2]|0,c[ka>>2]|0,c[ka+4>>2]|0)|0;cz(l,p,F);p=ja+32|0;ja=BBb(c[p>>2]|0,9203080,0,2)|0;if((ja|0)==0){na=0;oa=0}else{ka=0;n=ja;do{ja=c[j>>2]|0;fa=c[n>>2]|0;ia=c[n+4>>2]|0;ea=SGb(fa|0)|0;cz(ja,ea,(ea|0)<0|0?-1:0);Ry(ja,fa,ea);cz(ja,2,0);ea=SGb(ia|0)|0;cz(ja,ea,(ea|0)<0|0?-1:0);Ry(ja,ia,ea);ka=ka+1|0;n=BBb(c[p>>2]|0,9203080,n,2)|0;}while((n|0)!=0);na=(ka|0)<0|0?-1:0;oa=ka}cz(l,oa,na);n=Oz(c[j>>2]|0,k)|0;Ry(l,c[k>>2]|0,n);$Db(r);nM(g,c[q>>2]|0,-1248413064,1313450856);if(da>>>0<(c[(c[y>>2]|0)+1132>>2]|0)>>>0){m=da}else{break d}}if((ca|0)==83){i=h;return x|0}Oz(c[q>>2]|0,s)|0;$Db(s);x=ma;i=h;return x|0}}while(0);ma=u+3744|0;c[ma>>2]=-2147483648;c[ma+4>>2]=-1;c[X>>2]=(c[X>>2]|0)+1;x=0;i=h;return x|0}function nM(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;c[g>>2]=0;h=Oz(b,g)|0;b=h+4|0;if((b|0)>4096){kz(a,310,0);ez(a,d,e);cz(a,b,(b|0)<0|0?-1:0);Yy(a,jz(a)|0)}else{ez(a,d,e);cz(a,b,(b|0)<0|0?-1:0)}kz(a,310,0);Ry(a,c[g>>2]|0,h);Yy(a,jz(a)|0);ZDb(c[g>>2]|0);i=f;return}function oM(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;i=i+272|0;j=h|0;k=h+264|0;l=c[b+(c[f+32>>2]<<2)>>2]|0;if((Mz(j)|0)<0){i=h;return}b=f+44|0;a:do{if((c[b>>2]|0)>0){m=f+40|0;n=(g|0)==0;o=h+8|0;p=l+8|0;q=0;r=0;b:while(1){s=c[m>>2]|0;t=c[s+(r*12|0)>>2]|0;u=c[s+(r*12|0)+4>>2]|0;v=t+u|0;w=c[s+(r*12|0)+8>>2]|0;c:do{if(n){switch(w|0){case 0:{s=c[j>>2]|0;cz(s,7,0);Ry(s,2248320,7);break};case 74:{s=t;x=s|0;y=s+4|0;s=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0;x=fe(s|0)|0;Lb(o|0,256,2222160,(z=i,i=i+16|0,c[z>>2]=x,c[z+8>>2]=y,z)|0)|0;i=z;y=c[j>>2]|0;x=SGb(o|0)|0;cz(y,x,(x|0)<0|0?-1:0);Ry(y,o,x);break};case 70:{x=t;if((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)==0){A=q}else{y=c[j>>2]|0;cz(y,9,0);Ry(y,2128432,9);y=c[j>>2]|0;s=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=s;B=ZGb(x<<1|0>>>31,0<<1|x>>>31,(s|0)!=0|0,0)|0;cz(y,B,F);A=q+1|0}B=t+4|0;if((d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)==0){C=A;break c}y=c[j>>2]|0;cz(y,7,0);Ry(y,2122344,7);y=c[j>>2]|0;s=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=s;cz(y,ZGb(B<<1|0>>>31,0<<1|B>>>31,(s|0)!=0|0,0)|0,F);C=A+1|0;break c;break};case 72:case 77:{C=q;break c;break};case 2:{s=t+4|0;B=t;y=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;if((y&1|0)==0){D=q;E=s}else{B=c[j>>2]|0;cz(B,8,0);Ry(B,2168320,8);B=c[j>>2]|0;x=s;s=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=s;G=ZGb(x<<1|0>>>31,0<<1|x>>>31,(s|0)!=0|0,0)|0;cz(B,G,F);D=q+1|0;E=t+8|0}if((y&2|0)==0){H=D;I=E}else{G=c[j>>2]|0;cz(G,13,0);Ry(G,2160880,13);cz(c[j>>2]|0,4,0);G=c[j>>2]|0;cz(G,3,0);Ry(G,2154224,3);cz(e,8,0);Ry(c[j>>2]|0,E,8);H=D+1|0;I=E+8|0}if((y&4|0)==0){J=H;K=I}else{G=c[j>>2]|0;cz(G,10,0);Ry(G,2147008,10);G=c[j>>2]|0;B=I;s=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=s;x=ZGb(B<<1|0>>>31,0<<1|B>>>31,(s|0)!=0|0,0)|0;cz(G,x,F);J=H+1|0;K=I+4|0}if((y&8|0)==0){C=J;break c}y=c[j>>2]|0;cz(y,5,0);Ry(y,2140696,5);y=c[j>>2]|0;x=K;G=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=G;cz(y,ZGb(x<<1|0>>>31,0<<1|x>>>31,(G|0)!=0|0,0)|0,F);G=c[j>>2]|0;cz(G,6,0);Ry(G,2134808,6);G=c[j>>2]|0;x=K+4|0;y=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=y;cz(G,ZGb(x<<1|0>>>31,0<<1|x>>>31,(y|0)!=0|0,0)|0,F);C=J+2|0;break c;break};case 1:{y=c[j>>2]|0;cz(y,9,0);Ry(y,2235400,9);break};default:{Lb(o|0,256,2212848,(z=i,i=i+16|0,c[z>>2]=(c[(c[p>>2]|0)+88>>2]&8388608|0)!=0?2203496:2196080,c[z+8>>2]=w,z)|0)|0;i=z;y=c[j>>2]|0;x=SGb(o|0)|0;cz(y,x,(x|0)<0|0?-1:0);Ry(y,o,x)}}cz(c[j>>2]|0,4,0);x=c[j>>2]|0;cz(x,3,0);Ry(x,2182344,3);x=c[(c[m>>2]|0)+(r*12|0)+4>>2]|0;cz(c[j>>2]|0,x,(x|0)<0|0?-1:0);Ry(c[j>>2]|0,t,c[(c[m>>2]|0)+(r*12|0)+4>>2]|0);C=q+1|0}else{if(!((w|0)==77|(w|0)==72)){C=q;break}if((u|0)==0){L=31;break b}if((a[t+(u-1)|0]|0)!=0){L=31;break b}if((u|0)>0){M=t;N=q}else{C=q;break}while(1){x=SGb(M|0)|0;y=M+(x+1)|0;if(!(y>>>0<v>>>0)){L=31;break b}G=c[j>>2]|0;cz(G,x,(x|0)<0|0?-1:0);Ry(G,M,x);cz(c[j>>2]|0,2,0);G=c[j>>2]|0;s=SGb(y|0)|0;cz(G,s,(s|0)<0|0?-1:0);Ry(G,y,s);s=M+(x+2+(SGb(y|0)|0))|0;y=N+1|0;if(s>>>0<v>>>0){M=s;N=y}else{C=y;break}}}}while(0);v=r+1|0;if((v|0)<(c[b>>2]|0)){q=C;r=v}else{O=C;break a}}if((L|0)==31){i=h;return}}else{O=0}}while(0);cz(e,O,(O|0)<0|0?-1:0);O=Oz(c[j>>2]|0,k)|0;Ry(e,c[k>>2]|0,O);$Db(k);i=h;return}function pM(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=c[i+36>>2]&1;k=(c[i+32>>2]|0)==(d[h+2|0]|0|0)?j:j|16;j=c[i+28>>2]|0;l=((j|0)/(e[h+4>>1]|0|0)|0|0)==0?k:k|32;k=i+8|0;m=g+8|0;n=ZGb(c[k>>2]|0,c[k+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;m=F;k=b[h+8>>1]|0;o=(n|0)==(k<<16>>16|0)&(m|0)==((k<<16>>16<0|0?-1:0)|0)?l:l|8;if((c[i+44>>2]|0)==0){p=o}else{p=(c[f+3780>>2]|0)>3?o|256:o}o=p|64;l=j>>>0>c[f+3736>>2]<<1>>>0?o:p;p=-1;k=(m|0)>(p|0)|(m|0)==(p|0)&n>>>0>-1>>>0;p=ZGb(0,0,n,m)|0;q=k?m:F;m=c[g+28>>2]|0;g=(m|0)<0|0?-1:0;r=(q|0)>(g|0)|(q|0)==(g|0)&(k?n:p)>>>0>m>>>0?o:l;l=a[h+11|0]|0;o=l&255;m=d[f+3076+o|0]|0;do{if((j|0)>=(m|0)){if(!((j|0)<4097|l<<24>>24==0)){break}if((PGb(c[i+24>>2]|0,c[f+3204+(o<<2)>>2]|0,m)|0)==0){s=r}else{break}t=h|0;u=b[t>>1]|0;v=u&65535;w=v&4096;x=w|s;return x|0}}while(0);s=r|1024;t=h|0;u=b[t>>1]|0;v=u&65535;w=v&4096;x=w|s;return x|0}function qM(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+64|0;k=j|0;l=k|0;m=k;n=k;k=c[f+412>>2]|0;do{if((g|0)>4096){o=0}else{a[m+2|0]=1;a[m+1|0]=0;a[n]=0;p=c[f+48>>2]|0;if((p|0)==13){if((h|0)!=0){o=3;break}a[n+3|0]=-74;o=4;break}else if((p|0)==1|(p|0)==2|(p|0)==28){o=3;break}else if((p|0)==86017|(p|0)==86016){q=(p|0)==86017?3:2;p=(k|0)<28e3|0;r=p+((k|0)<14e3)|0;s=k<<r;if((s|0)<38050){t=2}else{t=(s|0)>46049|0}s=q-1|0;u=(e[1743632+(t<<1)>>1]|0)>>>(r>>>0)<<p;r=2;while(1){if((r|0)>=30){break}if(((((e[1743640+(p*90|0)+(s*30|0)+(r>>1<<1)>>1]|0)*144e3|0|0)/(u|0)|0)+(r&1)|0)==(g|0)){break}else{r=r+1|0}}c[l>>2]=fe(4-q<<17|p<<19^-458752|0)|0;if((g|0)<1){o=2;break}o=(r|0)==30?-1:2;break}else{o=0;break}}}while(0);g=b+3204|0;l=c[b+3752>>2]|0;if((l|0)>1){v=1}else{w=0;i=j;return w|0}while(1){if((o|0)==(d[b+(v+3076)|0]|0|0)){if((PGb(n,c[g+(v<<2)>>2]|0,o)|0)==0){w=v;x=17;break}}t=v+1|0;if((t|0)<(l|0)){v=t}else{w=0;x=17;break}}if((x|0)==17){i=j;return w|0}return 0}function rM(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;if((PGb(b,2223104,12)|0)==0){d=100;return d|0}a=(PGb(b,2022848,12)|0)==0;d=a?100:0;return d|0}function sM(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;b=i;i=i+24|0;d=b+16|0;e=d;f=i;i=i+8|0;g=f;j=c[a+12>>2]|0;l=c[a+16>>2]|0;m=b|0;mz(l,m,12)|0;n=(PGb(m,2022848,12)|0)==0;Vy(l,5,0)|0;Vy(l,3,0)|0;m=rz(l)|0;o=rz(l)|0;rz(l)|0;rz(l)|0;lz(l)|0;Vy(l,3,0)|0;p=sz(l)|0;q=F;r=(c[k>>2]=p,c[k+4>>2]=q,+h[k>>3]);s=r>.9999&r<1.0001?1.3333333333333333:r;q=sz(l)|0;p=F;r=(c[k>>2]=q,c[k+4>>2]=p,+h[k>>3]);p=rz(l)|0;q=rz(l)|0;rz(l)|0;rz(l)|0;do{if((p|0)==0){c[j>>2]=-1;t=0}else{u=LT(a,0)|0;if((u|0)==0){v=-12;i=b;return v|0}else{c[j>>2]=c[u>>2];w=c[u+8>>2]|0;c[w+8>>2]=0;c[w+48>>2]=85;c[w+120>>2]=m;c[w+124>>2]=o;c[w+792>>2]=10;lFb(e,+(o|0)*s/+(m|0),1e4);w=u+80|0;x=c[d+4>>2]|0;c[w>>2]=c[d>>2];c[w+4>>2]=x;lFb(g,r,6e4);x=u+92|0;w=c[f>>2]|0;y=c[f+4>>2]|0;c[x>>2]=w;c[x+4>>2]=y;x=u+412|0;c[x>>2]=w;c[x+4>>2]=y;MT(u,32,1,1e3);t=u;break}}}while(0);do{if((q|0)==0){c[j+4>>2]=-1;z=0}else{f=LT(a,0)|0;if((f|0)==0){v=-12;i=b;return v|0}else{c[j+4>>2]=c[f>>2];g=c[f+8>>2]|0;c[g+8>>2]=1;c[g+48>>2]=65536;c[g+416>>2]=2;d=g+448|0;c[d>>2]=3;c[d+4>>2]=0;c[g+412>>2]=44100;c[g+72>>2]=1411200;c[g+432>>2]=4;c[g+792>>2]=16;MT(f,32,1,1e3);z=f;break}}}while(0);a=(t|0)!=0;q=n^1;a:do{if(!(q&(a^1))){if((Xy(l)|0)!=0){break}f=t+8|0;b:do{if(a){c:while(1){g=lz(l)|0;do{if((g|0)==68){d=lz(l)|0;Vy(l,6,0)|0;m=(rz(l)|0)&16777215;if((d|0)!=82){A=m;break}d=c[f>>2]|0;o=d+96|0;if((c[o>>2]|0)==0){B=d}else{$Db(o);o=c[f>>2]|0;c[o+100>>2]=0;B=o}C=CT(B,l,m)|0;if((C|0)<0|q){break c}else{A=0}}else if((g|0)==88){Vy(l,7,0)|0;m=(rz(l)|0)&16777215;if((m|0)==512){break b}else{A=m}}else if((g|0)==82){A=11}else{Vy(l,7,0)|0;A=(rz(l)|0)&16777215}}while(0);Vy(l,A,0)|0;if((Xy(l)|0)!=0){break a}}g=C>>31&-12;if((g|0)<0){v=g}else{break a}i=b;return v|0}else{if(n){while(1){g=lz(l)|0;if((g|0)==68){lz(l)|0;Vy(l,6,0)|0;D=(rz(l)|0)&16777215}else if((g|0)==82){D=11}else if((g|0)==88){Vy(l,7,0)|0;g=(rz(l)|0)&16777215;if((g|0)==512){break b}else{D=g}}else{Vy(l,7,0)|0;D=(rz(l)|0)&16777215}Vy(l,D,0)|0;if((Xy(l)|0)!=0){break a}}}else{while(1){g=lz(l)|0;if((g|0)==88){Vy(l,7,0)|0;m=(rz(l)|0)&16777215;if((m|0)==512){break b}else{E=m}}else if((g|0)==68){lz(l)|0;Vy(l,6,0)|0;E=(rz(l)|0)&16777215}else if((g|0)==82){E=11}else{Vy(l,7,0)|0;E=(rz(l)|0)&16777215}Vy(l,E,0)|0;if((Xy(l)|0)!=0){break a}}}}}while(0);rz(l)|0;do{if(a){g=rz(l)|0;c[(c[f>>2]|0)+52>>2]=g;m=vT(1240808,g)|0;g=c[f>>2]|0;o=g+48|0;c[o>>2]=m;if((c[g+52>>2]|0)!=1196444242){break}c[o>>2]=85}else{Vy(l,4,0)|0;}}while(0);if((z|0)==0){Vy(l,16,0)|0;}else{f=rz(l)|0;o=z+8|0;c[(c[o>>2]|0)+52>>2]=f;f=rz(l)|0;c[(c[o>>2]|0)+412>>2]=f;f=rz(l)|0;c[(c[o>>2]|0)+792>>2]=f;f=rz(l)|0;g=c[o>>2]|0;c[g+416>>2]=f;f=g+448|0;c[f>>2]=0;c[f+4>>2]=0;f=BO(c[g+52>>2]|0,c[g+792>>2]|0)|0;do{if((f|0)==0){g=vT(629952,c[(c[o>>2]|0)+52>>2]|0)|0;if((g|0)!=65536){G=g;break}G=wT(c[(c[o>>2]|0)+792>>2]|0,0,0,-2)|0}else{G=f}}while(0);c[(c[o>>2]|0)+48>>2]=G;c[z+236>>2]=1}Vy(l,488,0)|0;}}while(0);if((t|0)==0){H=0}else{H=(c[(c[t+8>>2]|0)+48>>2]|0)==85|0}c[j+8>>2]=H;v=0;i=b;return v|0}function tM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+16|0;g=f|0;h=c[b+12>>2]|0;j=c[b+16>>2]|0;if((Xy(j)|0)!=0){k=-5;i=f;return k|0}l=h+8|0;m=g|0;n=g+8|0;o=h;p=b;b=h+4|0;a:while(1){q=(c[l>>2]|0)!=0?12:0;r=Ty(j,0,0,1)|0;s=F;t=mz(j,m,12)|0;if((t|0)<12){u=4;break}h=d[m]|0;v=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24)&16777215;do{if((h|0)==86){u=8}else if((h|0)==65){if((c[b>>2]|0)>=0){u=17;break a}yDb(p,16,2070576,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;Vy(j,v,0)|0;}else if((h|0)==68){if((c[l>>2]|0)!=0){u=8;break}Vy(j,v,0)|0;}else if((h|0)!=82){Vy(j,v,0)|0;}}while(0);if((u|0)==8){u=0;if((c[o>>2]|0)>=0){u=10;break}yDb(p,16,2135304,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;Vy(j,v,0)|0;}if((Xy(j)|0)!=0){k=-5;u=20;break}}if((u|0)==4){k=(t|0)<0?t:-5;i=f;return k|0}else if((u|0)==10){t=wZ(e,v+q|0)|0;if((t|0)<0){k=t;i=f;return k|0}t=e+64|0;c[t>>2]=r;c[t+4>>2]=s;t=e+36|0;c[t>>2]=(a[g+2|0]|0)==0|c[t>>2];t=g+4|0;w=e+8|0;c[w>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[w+4>>2]=0;c[e+32>>2]=c[o>>2];o=e+24|0;UGb(c[o>>2]|0,m|0,q)|0;m=mz(j,(c[o>>2]|0)+q|0,v)|0;if((m|0)<0){BZ(e);k=m;i=f;return k|0}if((m|0)>=(v|0)){k=0;i=f;return k|0}yZ(e,m+q|0);k=0;i=f;return k|0}else if((u|0)==17){q=TS(j,e,v)|0;v=e+36|0;c[v>>2]=c[v>>2]|1;v=e+64|0;c[v>>2]=r;c[v+4>>2]=s;s=g+4|0;g=e+8|0;c[g>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[g+4>>2]=0;c[e+32>>2]=c[b>>2];k=(q|0)<0?q:0;i=f;return k|0}else if((u|0)==20){i=f;return k|0}return 0}function uM(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;i=i+16|0;k=j|0;l=c[b+12>>2]|0;m=b+16|0;n=c[m>>2]|0;o=Ty(n,c[f>>2]|0,c[f+4>>2]|0,0)|0;p=F;q=0;if((p|0)<(q|0)|(p|0)==(q|0)&o>>>0<0>>>0){r=-2147483648;s=0;i=j;return(F=r,s)|0}o=c[m>>2]|0;if((Xy(o)|0)==0){t=0}else{r=-2147483648;s=0;i=j;return(F=r,s)|0}a:while(1){q=Ty(o,0,0,1)|0;p=F;if(!((p|0)<(h|0)|(p|0)==(h|0)&q>>>0<g>>>0)){r=-2147483648;s=0;u=19;break}q=lz(o)|0|t<<8;do{if((q|0)==1381263978){p=vz(o)|0;if((p|0)!=1785358954){v=p;break}p=vz(o)|0;if((p|0)==1785358954){u=7;break a}else{v=p}}else{v=q}}while(0);if((Xy(o)|0)==0){t=v}else{r=-2147483648;s=0;u=19;break}}if((u|0)==7){if((Xy(n)|0)!=0){r=-2147483648;s=0;i=j;return(F=r,s)|0}v=k|0;t=k+8|0;o=k+2|0;q=l+4|0;while(1){p=Ty(n,0,0,1)|0;w=F;if(!((w|0)<(h|0)|(w|0)==(h|0)&p>>>0<g>>>0)){r=-2147483648;s=0;u=19;break}if((mz(n,v,12)|0)<12){r=-2147483648;s=0;u=19;break}p=a[v]|0;w=p&255;x=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24)&16777215;if((w|0)==65|(w|0)==86){if(p<<24>>24==86){y=(a[o]|0)==0|0;z=l}else{y=1;z=q}if((c[z>>2]|0)==(e|0)){u=16;break}else{u=17}}else if((w|0)!=82){u=17}if((u|0)==17){u=0;Vy(n,x,0)|0;}if((Xy(n)|0)!=0){r=-2147483648;s=0;u=19;break}}if((u|0)==16){n=Ty(c[m>>2]|0,0,0,1)|0;m=YGb(n,F,-12,-1)|0;n=F;z=k+4|0;k=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=0;jT(c[(c[b+28>>2]|0)+(e<<2)>>2]|0,m,n,k,z,x+12|0,0,y)|0;c[f>>2]=m;c[f+4>>2]=n;r=z;s=k;i=j;return(F=r,s)|0}else if((u|0)==19){i=j;return(F=r,s)|0}}else if((u|0)==19){i=j;return(F=r,s)|0}return 0}function vM(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;do{if((PGb(2212816,b,5)|0)==0){if((d[b+5|0]|0)>>>0<8>>>0){e=100}else{break}return e|0}}while(0);e=0;return e|0}function wM(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;b=i;i=i+8|0;d=b|0;e=a+12|0;f=c[e>>2]|0;c[f+12>>2]=-1;g=f+8|0;do{h=CM(a,0,0,0,0)|0;if((h|0)<0){j=3;break}}while((c[g>>2]|0)==0);if((j|0)==3){g=c[e>>2]|0;k=g+4|0;if((c[k>>2]|0)>0){l=g;m=0;do{$Db((c[l>>2]|0)+(m*400|0)|0);n=c[l>>2]|0;o=c[n+(m*400|0)+84>>2]|0;do{if((o|0)==0){p=n}else{q=c[o+32>>2]|0;if((q|0)==0){p=n;break}ne[q&1023](a,m);p=c[l>>2]|0}}while(0);$Db(p+(m*400|0)+392|0);$Db((c[l>>2]|0)+(m*400|0)+384|0);m=m+1|0;}while((m|0)<(c[k>>2]|0))}$Db(g);r=h;i=b;return r|0}h=f+4|0;a:do{if((c[h>>2]|0)>0){g=f;k=a;m=a+28|0;l=a+1156|0;p=0;b:while(1){n=c[g>>2]|0;do{if((c[n+(p*400|0)+88>>2]|0)<0){yDb(k,16,2235344,(s=i,i=i+8|0,c[s>>2]=p,s)|0);i=s;c[(c[g>>2]|0)+(p*400|0)+84>>2]=0}else{o=c[n+(p*400|0)+84>>2]|0;if((o|0)==0){break}q=c[n+(p*400|0)+376>>2]|0;t=c[o+28>>2]|0;if((q|0)>=(t|0)){break}yDb(k,24,2222080,(s=i,i=i+24|0,c[s>>2]=p,c[s+8>>2]=t,c[s+16>>2]=q,s)|0);i=s;if((c[l>>2]&8|0)!=0){r=-1094995529;break b}}}while(0);q=n+(p*400|0)+40|0;t=c[q>>2]|0;o=c[q+4>>2]|0;if(!((t|0)==(-1|0)&(o|0)==(-1|0))){q=c[(c[c[e>>2]>>2]|0)+(p*400|0)+84>>2]|0;do{if((q|0)==0){u=o;v=t}else{w=c[q+20>>2]|0;if((w|0)==0){u=o;v=t;break}x=Pe[w&255](a,p,t,o,0)|0;u=F;v=x}}while(0);o=(c[(c[m>>2]|0)+(p<<2)>>2]|0)+48|0;c[o>>2]=v;c[o+4>>2]=u;o=n+(p*400|0)+48|0;c[o>>2]=v;c[o+4>>2]=u}p=p+1|0;if((p|0)>=(c[h>>2]|0)){break a}}i=b;return r|0}}while(0);h=c[e>>2]|0;u=a+16|0;v=c[u>>2]|0;if((c[v+88>>2]|0)==0){r=0;i=b;return r|0}s=a+1064|0;if(!((c[s>>2]|0)==0&(c[s+4>>2]|0)==(-2147483648|0))){r=0;i=b;return r|0}s=Wy(v)|0;v=F;f=0;if((v|0)<(f|0)|(v|0)==(f|0)&s>>>0<0>>>0){r=0;i=b;return r|0}f=0;p=(v|0)>(f|0)|(v|0)==(f|0)&s>>>0>65307>>>0;f=YGb(s,v,-65307,-1)|0;v=p?F:0;GM(a);Ty(c[u>>2]|0,p?f:0,v,0)|0;v=h+16|0;c[v>>2]=-1;c[v+4>>2]=-1;c:do{if((EM(a,d)|0)==0){v=h;f=a+28|0;p=0;while(1){d:while(1){s=c[d>>2]|0;m=c[v>>2]|0;l=m+(s*400|0)+32|0;k=c[l>>2]|0;g=c[l+4>>2]|0;do{if(!((k|0)==(-1|0)&(g|0)==(-1|0)|(k|0)==0&(g|0)==0)){if((c[m+(s*400|0)+84>>2]|0)==0){break}l=c[(c[c[e>>2]>>2]|0)+(s*400|0)+84>>2]|0;do{if((l|0)==0){y=g;z=k;A=s}else{o=c[l+20>>2]|0;if((o|0)==0){y=g;z=k;A=s;break}t=Pe[o&255](a,s,k,g,0)|0;y=F;z=t;A=c[d>>2]|0}}while(0);l=c[(c[f>>2]|0)+(A<<2)>>2]|0;B=l+56|0;c[B>>2]=z;c[B+4>>2]=y;t=l+48|0;C=c[t>>2]|0;D=c[t+4>>2]|0;if(!((C|0)==0&(D|0)==(-2147483648|0))){j=37;break d}E=(c[v>>2]|0)+(A*400|0)+368|0;if((c[E>>2]|0)==0){j=40;break d}}}while(0);if((EM(a,d)|0)!=0){G=p;break c}}if((j|0)==37){j=0;n=ZGb(z,y,C,D)|0;c[B>>2]=n;c[B+4>>2]=F;n=(c[v>>2]|0)+(A*400|0)+368|0;g=p-((c[n>>2]|0)==-1)|0;c[n>>2]=1;H=g}else if((j|0)==40){j=0;c[E>>2]=-1;H=p+1|0}if((EM(a,d)|0)==0){p=H}else{G=H;break}}}else{G=0}}while(0);HM(c[e>>2]|0,c[u>>2]|0);GM(a);H=a+1248|0;Ty(c[u>>2]|0,c[H>>2]|0,c[H+4>>2]|0,0)|0;BM(a);e:do{if((G|0)>0){H=a+28|0;E=h;A=G;do{if((CM(a,d,0,0,0)|0)!=0){break e}f:while(1){B=c[d>>2]|0;g:do{if((B|0)>=0){D=c[c[e>>2]>>2]|0;C=D+(B*400|0)+48|0;y=c[C>>2]|0;z=c[C+4>>2]|0;if((y|0)==0&(z|0)==(-2147483648|0)){I=-2147483648;J=0}else{c[C>>2]=0;c[C+4>>2]=-2147483648;I=z;J=y}y=D+(B*400|0)+56|0;if(!((c[y>>2]|0)==0&(c[y+4>>2]|0)==(-2147483648|0))){c[y>>2]=0;c[y+4>>2]=-2147483648}do{if((c[D+(B*400|0)+360>>2]|0)==0){K=I;L=J;M=B}else{z=D+(B*400|0)+32|0;p=c[z>>2]|0;v=c[z+4>>2]|0;if((p|0)==(-1|0)&(v|0)==(-1|0)){K=I;L=J;M=B;break}f=c[D+(B*400|0)+84>>2]|0;do{if((f|0)==0){j=58}else{g=c[f+20>>2]|0;n=(g|0)==0;if((c[f+24>>2]|0)==0){if(n){j=58;break}k=Pe[g&255](a,B,p,v,y)|0;N=F;O=k;j=60;break}else{if(n){P=v;Q=p;break}n=Pe[g&255](a,B,p,v,0)|0;P=F;Q=n;break}}}while(0);do{if((j|0)==58){j=0;if((y|0)==0){N=v;O=p;j=60;break}c[y>>2]=p;c[y+4>>2]=v;N=v;O=p;j=60}}while(0);if((j|0)==60){j=0;c[C>>2]=O;c[C+4>>2]=N;P=I;Q=J}c[z>>2]=-1;c[z+4>>2]=-1;K=P;L=Q;M=c[d>>2]|0}}while(0);R=c[(c[H>>2]|0)+(M<<2)>>2]|0;C=R+48|0;y=(c[C>>2]|0)==0&(c[C+4>>2]|0)==(-2147483648|0);do{if((L|0)==0&(K|0)==(-2147483648|0)){if(y){break g}}else{if(!y){break}S=(c[E>>2]|0)+(M*400|0)+368|0;if((c[S>>2]|0)==0){j=67;break f}else{break g}}}while(0);T=(c[E>>2]|0)+(M*400|0)+368|0;if((c[T>>2]|0)==0){j=68;break f}}}while(0);if((CM(a,d,0,0,0)|0)!=0){break e}}if((j|0)==67){j=0;B=R+56|0;y=ZGb(c[B>>2]|0,c[B+4>>2]|0,L,K)|0;c[B>>2]=y;c[B+4>>2]=F;c[S>>2]=1}else if((j|0)==68){j=0;c[T>>2]=1}A=A-1|0;}while((A|0)>0)}}while(0);HM(c[e>>2]|0,c[u>>2]|0);r=0;i=b;return r|0}function xM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+40|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=b+1300|0;if((c[m>>2]|0)!=0){BM(b);c[m>>2]=0}m=CM(b,g,h,j,k)|0;if((m|0)<0){n=m;i=f;return n|0}m=b+28|0;o=b+12|0;p=b;a:while(1){q=c[g>>2]|0;do{if((q|0)>=0){if((c[(c[m>>2]|0)+(q<<2)>>2]|0)==0){break}r=c[c[o>>2]>>2]|0;s=DM(b,q,l)|0;t=F;u=c[g>>2]|0;v=c[h>>2]|0;w=c[c[o>>2]>>2]|0;y=w+(u*400|0)|0;do{if((c[j>>2]|0)!=0){z=c[(c[(c[(c[m>>2]|0)+(u<<2)>>2]|0)+8>>2]|0)+48>>2]|0;if((z|0)==141){A=c[w+(u*400|0)+20>>2]|0;B=(a[(c[y>>2]|0)+v|0]&1^1)&255^A&1;C=A}else if((z|0)==31){z=c[w+(u*400|0)+20>>2]|0;B=((d[(c[y>>2]|0)+v|0]|0)>>>6&1^1)&255^z&1;C=z}else{break}if((B|0)==0){break}z=C^1;c[w+(u*400|0)+20>>2]=z;yDb(p,24,2135240,(A=i,i=i+8|0,c[A>>2]=(z&1|0)!=0?9203296:2022800,A)|0);i=A}}while(0);D=r+(q*400|0)+364|0;if((c[D>>2]|0)==0){break a}if((c[r+(q*400|0)+20>>2]&1|0)!=0){break a}}}while(0);u=CM(b,g,h,j,k)|0;if((u|0)<0){n=u;E=24;break}}if((E|0)==24){i=f;return n|0}c[D>>2]=0;D=wZ(e,c[j>>2]|0)|0;if((D|0)<0){n=D;i=f;return n|0}c[e+32>>2]=c[g>>2];UGb(c[e+24>>2]|0,(c[r+(q*400|0)>>2]|0)+(c[h>>2]|0)|0,c[j>>2]|0)|0;h=e+8|0;c[h>>2]=s;c[h+4>>2]=t;t=c[l+4>>2]|0;h=e+16|0;c[h>>2]=c[l>>2];c[h+4>>2]=t;c[e+36>>2]=c[r+(q*400|0)+20>>2];c[e+48>>2]=c[r+(q*400|0)+24>>2];t=c[k+4>>2]|0;h=e+64|0;c[h>>2]=c[k>>2];c[h+4>>2]=t;t=r+(q*400|0)+380|0;do{if((c[t>>2]|0)!=0){h=GZ(e,70,10)|0;if((h|0)!=0){k=h+4|0;x=c[t>>2]|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[t>>2]=0;break}BZ(e);ZDb(e);n=-12;i=f;return n|0}}while(0);t=r+(q*400|0)+384|0;if((c[t>>2]|0)!=0){k=r+(q*400|0)+388|0;q=GZ(e,77,c[k>>2]|0)|0;UGb(q|0,c[t>>2]|0,c[k>>2]|0)|0;$Db(t);c[k>>2]=0}n=c[j>>2]|0;i=f;return n|0}function yM(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;d=b+4|0;if((c[d>>2]|0)<=0){$Db(b);return 0}e=b;f=0;do{$Db((c[e>>2]|0)+(f*400|0)|0);g=c[e>>2]|0;h=c[g+(f*400|0)+84>>2]|0;do{if((h|0)==0){i=g}else{j=c[h+32>>2]|0;if((j|0)==0){i=g;break}ne[j&1023](a,f);i=c[e>>2]|0}}while(0);$Db(i+(f*400|0)+392|0);$Db((c[e>>2]|0)+(f*400|0)+384|0);f=f+1|0;}while((f|0)<(c[d>>2]|0));$Db(b);return 0}function zM(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=c[a+12>>2]|0;j=h;k=c[j>>2]|0;if((c[h+4>>2]|0)<=(b|0)){yDb(0,0,2278624,(h=i,i=i+24|0,c[h>>2]=2263280,c[h+8>>2]=2248256,c[h+16>>2]=865,h)|0);i=h;Cd();return 0}BM(a);do{if((c[(c[(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==0){if((f&4|0)!=0){break}c[k+(b*400|0)+364>>2]=1}}while(0);k=pT(a,b,d,e,f)|0;if((k|0)>=0){i=g;return k|0}c[(c[j>>2]|0)+(b*400|0)+364>>2]=0;i=g;return k|0}function AM(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;n=b+12|0;o=c[n>>2]|0;p=c[b+16>>2]|0;Ty(p,c[f>>2]|0,c[f+4>>2]|0,0)|0;BM(b);q=o;o=b+28|0;r=b;s=-1;t=-1;a:while(1){u=Ty(p,0,0,1)|0;v=F;if((v|0)>(h|0)|(v|0)==(h|0)&u>>>0>g>>>0){w=-2147483648;x=0;y=37;break}u=-1;v=(s|0)>(u|0)|(s|0)==(u|0)&t>>>0>-1>>>0;while(1){if((CM(b,k,l,m,f)|0)!=0){w=-2147483648;x=0;y=37;break a}if((c[k>>2]|0)!=(e|0)){s=s;t=t;continue a}u=c[q>>2]|0;if((c[u+(e*400|0)+80>>2]&6|0)==4){if((c[u+(e*400|0)+84>>2]|0)!=1167352){y=9}}else{y=9}if((y|0)==9){y=0;z=c[c[n>>2]>>2]|0;A=z+(e*400|0)+48|0;B=c[A>>2]|0;C=c[A+4>>2]|0;if((B|0)==0&(C|0)==(-2147483648|0)){D=-2147483648;E=0}else{c[A>>2]=0;c[A+4>>2]=-2147483648;D=C;E=B}B=z+(e*400|0)+56|0;if(!((c[B>>2]|0)==0&(c[B+4>>2]|0)==(-2147483648|0))){c[B>>2]=0;c[B+4>>2]=-2147483648}do{if((c[z+(e*400|0)+360>>2]|0)==0){G=D;H=E;I=e;J=z}else{C=z+(e*400|0)+32|0;K=c[C>>2]|0;L=c[C+4>>2]|0;if((K|0)==(-1|0)&(L|0)==(-1|0)){G=D;H=E;I=e;J=z;break}M=c[z+(e*400|0)+84>>2]|0;do{if((M|0)==0){y=21}else{N=c[M+20>>2]|0;O=(N|0)==0;if((c[M+24>>2]|0)==0){if(O){y=21;break}P=Pe[N&255](b,e,K,L,B)|0;Q=F;R=P;y=23;break}else{if(O){S=L;T=K;break}O=Pe[N&255](b,e,K,L,0)|0;S=F;T=O;break}}}while(0);do{if((y|0)==21){y=0;if((B|0)==0){Q=L;R=K;y=23;break}c[B>>2]=K;c[B+4>>2]=L;Q=L;R=K;y=23}}while(0);if((y|0)==23){y=0;c[A>>2]=R;c[A+4>>2]=Q;S=D;T=E}c[C>>2]=-1;c[C+4>>2]=-1;G=S;H=T;I=c[k>>2]|0;J=c[c[n>>2]>>2]|0}}while(0);A=c[l>>2]|0;B=J+(I*400|0)|0;do{if((c[m>>2]|0)!=0){z=c[(c[(c[(c[o>>2]|0)+(I<<2)>>2]|0)+8>>2]|0)+48>>2]|0;if((z|0)==141){K=c[J+(I*400|0)+20>>2]|0;U=(a[(c[B>>2]|0)+A|0]&1^1)&255^K&1;V=K}else if((z|0)==31){z=c[J+(I*400|0)+20>>2]|0;U=((d[(c[B>>2]|0)+A|0]|0)>>>6&1^1)&255^z&1;V=z}else{break}if((U|0)==0){break}z=V^1;c[J+(I*400|0)+20>>2]=z;yDb(r,24,2135240,(K=i,i=i+8|0,c[K>>2]=(z&1|0)!=0?9203296:2022800,K)|0);i=K}}while(0);if((c[u+(e*400|0)+20>>2]&1|0)!=0){y=32;break}if((c[u+(e*400|0)+364>>2]|0)==0){W=s;X=t;break}if(v){y=35;break}}A=Ty(p,0,0,1)|0;B=F;if((B|0)>(h|0)|(B|0)==(h|0)&A>>>0>g>>>0){w=-2147483648;x=0;y=37;break a}}if((y|0)==32){y=0;W=c[f+4>>2]|0;X=c[f>>2]|0}else if((y|0)==35){y=0;c[f>>2]=t;c[f+4>>2]=s;W=s;X=t}if((H|0)==0&(G|0)==(-2147483648|0)){s=W;t=X}else{w=G;x=H;y=37;break}}if((y|0)==37){BM(b);i=j;return(F=w,x)|0}return 0}function BM(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[a+12>>2]|0;d=Ty(c[a+16>>2]|0,0,0,1)|0;e=F;f=b+4|0;if((c[f>>2]|0)<=0){g=b+16|0;h=g;i=-1;j=-1;k=h|0;c[k>>2]=i;l=h+4|0;c[l>>2]=j;m=b+12|0;n=m;c[n>>2]=-1;return}o=b;p=a+1248|0;a=0;do{q=c[o>>2]|0;c[q+(a*400|0)+8>>2]=0;c[q+(a*400|0)+12>>2]=0;c[q+(a*400|0)+16>>2]=0;r=q+(a*400|0)+32|0;c[r>>2]=-1;c[r+4>>2]=-1;r=q+(a*400|0)+48|0;c[r>>2]=0;c[r+4>>2]=-2147483648;s=q+(a*400|0)+56|0;c[s>>2]=0;c[s+4>>2]=-2147483648;s=q+(a*400|0)+64|0;c[s>>2]=-1;c[s+4>>2]=-1;s=q+(a*400|0)+72|0;c[s>>2]=0;c[s+4>>2]=0;c[q+(a*400|0)+92>>2]=0;c[q+(a*400|0)+96>>2]=0;c[q+(a*400|0)+356>>2]=0;c[q+(a*400|0)+372>>2]=0;s=c[p+4>>2]|0;if(!((e|0)>(s|0)|(e|0)==(s|0)&d>>>0>(c[p>>2]|0)>>>0)){c[r>>2]=0;c[r+4>>2]=0}c[q+(a*400|0)+380>>2]=0;$Db(q+(a*400|0)+384|0);c[q+(a*400|0)+388>>2]=0;a=a+1|0;}while((a|0)<(c[f>>2]|0));g=b+16|0;h=g;i=-1;j=-1;k=h|0;c[k>>2]=i;l=h+4|0;c[l>>2]=j;m=b+12|0;n=m;c[n>>2]=-1;return}function CM(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;j=i;i=i+8|0;k=j|0;l=c[b+12>>2]|0;m=(e|0)!=0;if(m){c[e>>2]=-1}n=l+12|0;o=l;a:while(1){p=c[n>>2]|0;c[k>>2]=p;if((p|0)<0){while(1){q=EM(b,k)|0;if((q|0)<0){r=q;s=53;break a}q=c[k>>2]|0;if((q|0)>=0){t=q;break}}}else{t=p}u=c[o>>2]|0;v=u+(t*400|0)+84|0;if((c[v>>2]|0)==0){w=u+(t*400|0)+88|0;if((c[w>>2]|0)>=0){r=0;s=53;break}q=c[u+(t*400|0)>>2]|0;x=c[u+(t*400|0)+8>>2]|0;y=0;z=1138072;while(1){A=d[z+4|0]|0;if((A|0)<=(x|0)){if((PGb(q,c[z>>2]|0,A)|0)==0){break}}A=y+1|0;if((A|0)==15){s=13;break a}else{y=A;z=c[628416+(A<<2)>>2]|0}}c[v>>2]=z;if((z|0)==0){break}}B=u+(t*400|0)+96|0;C=c[B>>2]|0;D=u+(t*400|0)+16|0;E=c[D>>2]|0;F=u+(t*400|0)+92|0;y=c[F>>2]|0;q=C;x=E;while(1){if((q|0)>=(y|0)){break}p=q+1|0;c[B>>2]=p;A=a[u+(t*400|0)+100+q|0]|0;G=x+(A&255)|0;c[D>>2]=G;if(A<<24>>24==-1){q=p;x=G}else{s=21;break a}}if((q|0)!=(y|0)){continue}c[n>>2]=-1;c[u+(t*400|0)+356>>2]=(c[D>>2]|0)!=0}if((s|0)==13){c[v>>2]=0}else if((s|0)==21){x=u+(t*400|0)+32|0;if((c[x>>2]|0)==(-1|0)&(c[x+4>>2]|0)==(-1|0)){x=u+(t*400|0)+72|0;z=c[x+4>>2]|0;yDb(b,24,1949600,(H=i,i=i+16|0,c[H>>2]=c[x>>2],c[H+8>>2]=z,H)|0);i=H}c[n>>2]=c[k>>2];c[u+(t*400|0)+356>>2]=0;z=u+(t*400|0)+88|0;do{if((c[z>>2]|0)==0){c[u+(t*400|0)+20>>2]=0;c[u+(t*400|0)+24>>2]=0;x=c[v>>2]|0;do{if((x|0)!=0){G=c[x+16>>2]|0;if((G|0)==0){break}Oe[G&1023](b,c[k>>2]|0)|0}}while(0);if(m){c[e>>2]=c[k>>2]}if((f|0)!=0){c[f>>2]=c[u+(t*400|0)+12>>2]}if((g|0)!=0){c[g>>2]=c[D>>2]}if((h|0)!=0){x=u+(t*400|0)+64|0;y=c[x+4>>2]|0;c[h>>2]=c[x>>2];c[h+4>>2]=y}y=u+(t*400|0)+12|0;x=(c[y>>2]|0)+(c[D>>2]|0)|0;c[y>>2]=x;c[D>>2]=0;q=u+(t*400|0)+8|0;if((x|0)==(c[q>>2]|0)){c[y>>2]=0;c[q>>2]=0}q=u+(t*400|0)+72|0;y=c[q+4>>2]|0;x=u+(t*400|0)+64|0;c[x>>2]=c[q>>2];c[x+4>>2]=y}else{y=Oe[c[(c[v>>2]|0)+12>>2]&1023](b,c[k>>2]|0)|0;c[z>>2]=y;if((y|0)!=0){y=u+(t*400|0)+376|0;c[y>>2]=(c[y>>2]|0)+1;y=u+(t*400|0)+12|0;c[y>>2]=(c[y>>2]|0)+(c[D>>2]|0);c[D>>2]=0;break}c[B>>2]=C;c[D>>2]=E;c[l+8>>2]=1;y=b+1248|0;x=c[y>>2]|0;q=c[y+4>>2]|0;if((x|0)==0&(q|0)==0){G=u+(t*400|0)+64|0;p=c[G>>2]|0;A=c[G+4>>2]|0;c[y>>2]=p;c[y+4>>2]=A;I=A;J=p}else{I=q;J=x}x=c[l+4>>2]|0;if((x|0)<=0){break}q=c[o>>2]|0;p=0;A=I;G=J;while(1){if((c[q+(p*400|0)+356>>2]|0)==0){K=A;L=G}else{M=q+(p*400|0)+64|0;N=c[M>>2]|0;O=c[M+4>>2]|0;M=(A|0)>(O|0)|(A|0)==(O|0)&G>>>0>N>>>0;P=M?N:G;N=M?O:A;c[y>>2]=P;c[y+4>>2]=N;K=N;L=P}P=p+1|0;if((P|0)<(x|0)){p=P;A=K;G=L}else{break}}}}while(0);L=u+(t*400|0)+360|0;c[L>>2]=1;K=c[B>>2]|0;B=c[F>>2]|0;F=K;while(1){if((F|0)>=(B|0)){break}if((a[u+(t*400|0)+100+F|0]|0)==-1){F=F+1|0}else{s=50;break}}if((s|0)==50){c[L>>2]=0}if((K|0)!=(B|0)){r=0;i=j;return r|0}c[n>>2]=-1;r=0;i=j;return r|0}else if((s|0)==53){i=j;return r|0}yDb(b,24,1979424,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[w>>2]=0;r=0;i=j;return r|0}function DM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=c[c[a+12>>2]>>2]|0;f=(d|0)!=0;if(f){c[d>>2]=0;c[d+4>>2]=-2147483648}g=e+(b*400|0)+48|0;h=c[g>>2]|0;i=c[g+4>>2]|0;if((h|0)==0&(i|0)==(-2147483648|0)){j=-2147483648;k=0}else{c[g>>2]=0;c[g+4>>2]=-2147483648;j=i;k=h}h=e+(b*400|0)+56|0;i=c[h>>2]|0;l=c[h+4>>2]|0;if(!((i|0)==0&(l|0)==(-2147483648|0))){if(f){c[d>>2]=i;c[d+4>>2]=l}c[h>>2]=0;c[h+4>>2]=-2147483648}if((c[e+(b*400|0)+360>>2]|0)==0){m=j;n=k;return(F=m,n)|0}l=e+(b*400|0)+32|0;i=c[l>>2]|0;f=c[l+4>>2]|0;if((i|0)==(-1|0)&(f|0)==(-1|0)){m=j;n=k;return(F=m,n)|0}o=c[e+(b*400|0)+84>>2]|0;do{if((o|0)==0){p=19}else{e=c[o+20>>2]|0;q=(e|0)==0;if((c[o+24>>2]|0)==0){if(q){p=19;break}r=Pe[e&255](a,b,i,f,h)|0;s=F;t=r;p=21;break}if(!q){q=Pe[e&255](a,b,i,f,d)|0;u=F;v=q;break}if((d|0)==0){u=f;v=i;break}c[d>>2]=i;c[d+4>>2]=f;u=f;v=i}}while(0);do{if((p|0)==19){if((h|0)==0){s=f;t=i;p=21;break}c[h>>2]=i;c[h+4>>2]=f;s=f;t=i;p=21}}while(0);if((p|0)==21){c[g>>2]=t;c[g+4>>2]=s;u=j;v=k}c[l>>2]=-1;c[l+4>>2]=-1;m=u;n=v;return(F=m,n)|0}function EM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=h;k=b+16|0;l=c[k>>2]|0;m=b+12|0;n=c[m>>2]|0;o=mz(l,h,4)|0;if((o|0)<4){p=(o|0)<0?o:-541478725;i=f;return p|0}o=l+88|0;q=n+16|0;r=0;a:while(1){s=j+(r&3)|0;do{if((a[s]|0)==79){if((a[j+(r+1&3)|0]|0)!=103){break}if((a[j+(r+2&3)|0]|0)!=103){break}if((a[j+(r+3&3)|0]|0)==83){t=r;break a}}}while(0);do{if((r|0)==0){if((c[o>>2]|0)==0){break}u=c[q>>2]|0;v=c[q+4>>2]|0;w=0;if(!((v|0)>(w|0)|(v|0)==(w|0)&u>>>0>0>>>0)){break}c[h>>2]=0;w=YGb(u,v,4,0)|0;Ty(l,w,F,0)|0;c[q>>2]=-1;c[q+4>>2]=-1}}while(0);w=lz(l)|0;if((Xy(l)|0)!=0){p=-541478725;x=69;break}v=r+1|0;a[s]=w;if((r|0)<65307){r=v}else{t=v;break}}if((x|0)==69){i=f;return p|0}if((t|0)>65306){yDb(b,32,1924024,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;p=-1094995529;i=f;return p|0}if((lz(l)|0)!=0){yDb(b,16,1902192,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;p=-1094995529;i=f;return p|0}t=lz(l)|0;r=sz(l)|0;h=F;o=rz(l)|0;Vy(l,8,0)|0;j=lz(l)|0;v=n;w=c[n+4>>2]|0;n=0;while(1){if((n|0)>=(w|0)){z=0;x=22;break}A=c[v>>2]|0;if((c[A+(n*400|0)+28>>2]|0)==(o|0)){x=21;break}else{n=n+1|0}}if((x|0)==21){if((n|0)<0){z=0;x=22}else{B=n;C=A}}b:do{if((x|0)==22){while(1){x=0;if((z|0)>=(w|0)){x=39;break}if((c[(c[v>>2]|0)+(z*400|0)+372>>2]|0)==0){z=z+1|0;x=22}else{x=24;break}}c:do{if((x|0)==24){s=g|0;A=c[m>>2]|0;n=c[k>>2]|0;d:do{if((c[n+88>>2]|0)==0){if((c[A+4>>2]|0)==1){D=0;E=c[A>>2]|0;break}else{EDb(b,2295160,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;G=-1163346256;break c}}else{u=Ty(n,0,0,1)|0;H=F;Vy(c[k>>2]|0,j,(j|0)<0|0?-1:0)|0;mz(c[k>>2]|0,s,8)|0;Ty(c[k>>2]|0,u,H,0)|0;H=0;u=1138072;while(1){I=a[u+4|0]|0;if(!((I&255)>>>0>8>>>0)){if((PGb(s,c[u>>2]|0,I&255)|0)==0){x=29;break}}I=H+1|0;if((I|0)==15){break}else{H=I;u=c[628416+(I<<2)>>2]|0}}do{if((x|0)==29){if((u|0)==0){break}H=A;I=c[A+4>>2]|0;J=0;while(1){if((J|0)>=(I|0)){break}K=c[H>>2]|0;if((c[K+(J*400|0)+84>>2]|0)==(u|0)){D=J;E=K;break d}else{J=J+1|0}}L=FM(b,o)|0;x=40;break c}}while(0);yDb(b,16,2316416,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;G=-1094995529;break c}}while(0);c[E+(D*400|0)+28>>2]=o;L=D;x=40}else if((x|0)==39){L=FM(b,o)|0;x=40}}while(0);do{if((x|0)==40){if((L|0)<0){G=L;break}B=L;C=c[v>>2]|0;break b}}while(0);yDb(b,16,1882208,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;p=G;i=f;return p|0}}while(0);G=C+(B*400|0)|0;y=Ty(l,0,0,1)|0;b=YGb(y,F,-27,-1)|0;y=F;L=C+(B*400|0)+72|0;c[L>>2]=b;c[L+4>>2]=y;c[q>>2]=b;c[q+4>>2]=y;y=C+(B*400|0)+16|0;if((c[y>>2]|0)!=0){q=c[v>>2]|0;v=WDb((c[q+(B*400|0)+4>>2]|0)+16|0)|0;b=q+(B*400|0)+8|0;o=q+(B*400|0)+12|0;D=c[o>>2]|0;E=(c[b>>2]|0)-D|0;k=q+(B*400|0)|0;q=c[k>>2]|0;if((q|0)!=0){UGb(v|0,q+D|0,E)|0;ZDb(q)}c[k>>2]=v;c[b>>2]=E;c[o>>2]=0}o=mz(l,C+(B*400|0)+100|0,j)|0;if((o|0)<(j|0)){p=(o|0)<0?o:-541478725;i=f;return p|0}c[C+(B*400|0)+92>>2]=j;o=C+(B*400|0)+96|0;c[o>>2]=0;if((j|0)>0){E=0;b=0;while(1){v=(d[C+(B*400|0)+100+b|0]|0)+E|0;k=b+1|0;if((k|0)<(j|0)){E=v;b=k}else{M=v;break}}}else{M=0}if((t&2|0)==0){c[C+(B*400|0)+372>>2]=1}do{if((t&1|0)==0){if((c[C+(B*400|0)+356>>2]|0)!=0){x=55;break}c[y>>2]=0;b=c[L+4>>2]|0;E=C+(B*400|0)+64|0;c[E>>2]=c[L>>2];c[E+4>>2]=b}else{x=55}}while(0);do{if((x|0)==55){if((c[y>>2]|0)!=0){break}b=C+(B*400|0)+12|0;E=0;while(1){if((E|0)>=(j|0)){break}v=E+1|0;c[o>>2]=v;k=a[C+(B*400|0)+100+E|0]|0;c[b>>2]=(c[b>>2]|0)+(k&255);if(k<<24>>24==-1){E=v}else{break}}E=c[L+4>>2]|0;b=C+(B*400|0)+64|0;c[b>>2]=c[L>>2];c[b+4>>2]=E}}while(0);L=C+(B*400|0)+4|0;o=c[L>>2]|0;j=C+(B*400|0)+8|0;y=c[j>>2]|0;do{if((o-y|0)>>>0<M>>>0){x=o<<1;c[L>>2]=x;E=WDb(x+16|0)|0;if((E|0)==0){p=-12;i=f;return p|0}else{x=G|0;UGb(E|0,c[x>>2]|0,c[j>>2]|0)|0;ZDb(c[x>>2]|0);c[x>>2]=E;N=c[j>>2]|0;O=E;break}}else{N=y;O=c[G>>2]|0}}while(0);y=mz(l,O+N|0,M)|0;if((y|0)<(M|0)){p=(y|0)<0?y:-541478725;i=f;return p|0}y=(c[j>>2]|0)+M|0;c[j>>2]=y;j=C+(B*400|0)+32|0;c[j>>2]=r;c[j+4>>2]=h;c[C+(B*400|0)+80>>2]=t;TGb((c[G>>2]|0)+y|0,0,16)|0;if((e|0)==0){p=0;i=f;return p|0}c[e>>2]=B;p=0;i=f;return p|0}function FM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[a+12>>2]|0;f=e+4|0;g=c[f>>2]|0;if((c[e+24>>2]|0)!=0){yDb(a,16,2340016,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-558323010;i=d;return j|0}h=g+1|0;k=h*400|0;do{if(h>>>0>65535>>>0){if(((k>>>0)/(h>>>0)|0|0)==400){break}else{j=-12}i=d;return j|0}}while(0);h=e;e=XDb(c[h>>2]|0,k)|0;k=e;if((e|0)==0){j=-12;i=d;return j|0}c[h>>2]=k;h=k+(g*400|0)|0;e=h;TGb(e|0,0,400)|0;c[k+(g*400|0)+28>>2]=b;c[k+(g*400|0)+4>>2]=65307;b=WDb(65323)|0;c[h>>2]=b;c[k+(g*400|0)+88>>2]=-1;h=k+(g*400|0)+40|0;c[h>>2]=-1;c[h+4>>2]=-1;if((b|0)==0){j=-12;i=d;return j|0}b=LT(a,0)|0;if((b|0)==0){$Db(e);j=-12;i=d;return j|0}else{c[b+4>>2]=g;MT(b,64,1,1e6);c[f>>2]=(c[f>>2]|0)+1;j=g;i=d;return j|0}return 0}function GM(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=b+4|0;e=WDb(((c[d>>2]|0)*400|0)+24|0)|0;f=e;g=Ty(c[a+16>>2]|0,0,0,1)|0;a=e;c[a>>2]=g;c[a+4>>2]=F;c[e+8>>2]=c[b+12>>2];a=b+24|0;c[e+12>>2]=c[a>>2];c[e+16>>2]=c[d>>2];g=e+24|0;e=g;h=b;UGb(g|0,c[h>>2]|0,(c[d>>2]|0)*400|0)|0;if((c[d>>2]|0)>0){i=0}else{c[a>>2]=f;return}do{g=c[h>>2]|0;b=cEb((c[g+(i*400|0)+4>>2]|0)+16|0)|0;c[g+(i*400|0)>>2]=b;UGb(b|0,c[e+(i*400|0)>>2]|0,c[g+(i*400|0)+8>>2]|0)|0;c[g+(i*400|0)+384>>2]=0;c[g+(i*400|0)+388>>2]=0;i=i+1|0;}while((i|0)<(c[d>>2]|0));c[a>>2]=f;return}function HM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+24|0;e=c[d>>2]|0;if((e|0)==0){return}c[d>>2]=c[e+12>>2];d=a+4|0;if((c[d>>2]|0)>0){f=a;g=0;do{$Db((c[f>>2]|0)+(g*400|0)|0);g=g+1|0;}while((g|0)<(c[d>>2]|0))}g=e|0;Ty(b,c[g>>2]|0,c[g+4>>2]|0,0)|0;g=a+16|0;c[g>>2]=-1;c[g+4>>2]=-1;c[a+12>>2]=c[e+8>>2];g=e+16|0;b=c[g>>2]|0;c[d>>2]=b;if((bEb(a,b,400)|0)<0){c[d>>2]=0;return}else{UGb(c[a>>2]|0,e+24|0,(c[g>>2]|0)*400|0)|0;ZDb(e);return}}function IM(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=i;i=i+80|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;if((c[(c[b+12>>2]|0)+8>>2]|0)!=0){yDb(b,24,2203448,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}r=b+24|0;s=b+28|0;t=b+1140|0;u=b;v=0;a:while(1){w=c[(c[s>>2]|0)+(v<<2)>>2]|0;y=w+8|0;z=c[y>>2]|0;A=c[z+8>>2]|0;do{if((A|0)==0){MT(w,64,c[z+104>>2]|0,c[z+108>>2]|0)}else if((A|0)==1){if((c[z+48>>2]|0)==1330664787){MT(w,64,1,48e3);break}else{MT(w,64,1,c[z+412>>2]|0);break}}}while(0);z=c[y>>2]|0;A=c[z+48>>2]|0;if(!((A|0)==86021|(A|0)==31|(A|0)==86052|(A|0)==86028|(A|0)==1330664787)){B=12;break}if((c[z+96>>2]|0)==0){B=15;break}if((c[z+100>>2]|0)==0){B=15;break}C=cEb(65376)|0;c[C+72>>2]=v;b:do{if((c[(c[y>>2]|0)+88>>2]&8388608|0)==0){c:while(1){z=hFb()|0;A=0;while(1){if((A|0)>=(v|0)){D=z;break b}if((z|0)==(c[(c[(c[(c[s>>2]|0)+(A<<2)>>2]|0)+12>>2]|0)+65360>>2]|0)){continue c}else{A=A+1|0}}}}else{D=v}}while(0);c[C+65360>>2]=D;A=w+88|0;EBb(A,c[t>>2]|0,16);E=w+12|0;c[E>>2]=C;z=c[y>>2]|0;F=c[z+48>>2]|0;do{if((F|0)==86052){G=c[z+88>>2]&8388608;if((c[z+100>>2]|0)<80){H=-1;B=30;break a}I=cEb(80)|0;if((I|0)==0){H=-12;B=30;break a}c[C+4>>2]=I;c[C+16>>2]=80;UGb(I|0,c[z+96>>2]|0,80)|0;J=I+68|0;x=0;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;J=(G|0)!=0?2122320:2117200;QG(A,1087448,0);G=FU(c[A>>2]|0,J,l)|0;I=cEb(G)|0;c[k>>2]=I;if((I|0)==0){H=-12;B=30;break a}c[k>>2]=I;GU(k,A,J,c[l>>2]|0)|0;c[C+20>>2]=G;c[C+8>>2]=I}else if((F|0)==86028){I=c[z+88>>2]&8388608;if((V9(z,o,p)|0)==0){K=-1;B=25;break a}c[C+16>>2]=51;G=cEb(51)|0;c[C+4>>2]=G;if((G|0)==0){K=-12;B=25;break a}a[G]=127;J=G+1|0;x=1128352838;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;a[G+5|0]=1;a[G+6|0]=0;J=G+7|0;x=256;a[J]=x;x=x>>8;a[J+1|0]=x;J=G+9|0;x=1130450022;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;a[G+13|0]=0;a[G+16|0]=34;a[G+15|0]=0;a[G+14|0]=0;UGb(G+17|0,c[p>>2]|0,34)|0;G=(I|0)!=0?2122320:2117200;QG(A,1087448,0);I=FU(c[A>>2]|0,G,n)|0;J=I+4|0;L=cEb(J)|0;c[m>>2]=L;if((L|0)==0){K=-12;B=25;break a}c[m>>2]=L+4;GU(m,A,G,c[n>>2]|0)|0;c[C+20>>2]=J;c[C+8>>2]=L;a[L]=-124;a[L+3|0]=I;a[L+2|0]=I>>>8;a[L+1|0]=I>>>16}else if((F|0)==1330664787){I=c[z+88>>2]&8388608;L=z+100|0;J=c[L>>2]|0;if((J|0)<19){M=-1;B=35;break a}G=cEb(J)|0;if((G|0)==0){M=-12;B=35;break a}c[C+4>>2]=G;c[C+16>>2]=c[L>>2];UGb(G|0,c[z+96>>2]|0,c[L>>2]|0)|0;L=(I|0)!=0?2122320:2117200;QG(A,1087448,0);I=(FU(c[A>>2]|0,L,j)|0)+8|0;G=cEb(I)|0;c[h>>2]=G;if((G|0)==0){M=-12;B=35;break a}c[h>>2]=G+8;GU(h,A,L,c[j>>2]|0)|0;c[C+20>>2]=I;c[C+8>>2]=G;I=G;G=I|0;x=1937076303;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;G=I+4|0;x=1936154964;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x}else{G=(F|0)==86021;I=G?2146960:2140680;L=C+4|0;if((Bdb(c[z+96>>2]|0,c[z+100>>2]|0,G?30:42,L,C+16|0)|0)<0){B=37;break a}J=C+20|0;N=(c[(c[y>>2]|0)+88>>2]&8388608|0)!=0?2122320:2117200;QG(A,1087448,0);O=FU(c[A>>2]|0,N,g)|0;P=O+(G?8:7)|0;O=cEb(P)|0;c[f>>2]=O;if((O|0)==0){Q=0}else{c[f>>2]=O+7;GU(f,A,N,c[g>>2]|0)|0;if(G){a[c[f>>2]|0]=1;c[f>>2]=(c[f>>2]|0)+1}c[J>>2]=P;Q=O}c[C+8>>2]=Q;if((Q|0)==0){R=-12;B=53;break a}a[Q]=G?3:-127;G=Q+1|0;a[G]=a[I]|0;a[G+1|0]=a[I+1|0]|0;a[G+2|0]=a[I+2|0]|0;a[G+3|0]=a[I+3|0]|0;a[G+4|0]=a[I+4|0]|0;a[G+5|0]=a[I+5|0]|0;if((c[(c[y>>2]|0)+48>>2]|0)!=31){break}I=c[L>>2]|0;L=(d[I+40|0]|0)<<3&24|(d[I+41|0]|0)>>>5;c[C+28>>2]=L;G=d[I+9|0]|0;c[C+40>>2]=G;yDb(u,48,2128352,(q=i,i=i+16|0,c[q>>2]=L,c[q+8>>2]=G,q)|0);i=q}}while(0);y=v+1|0;S=c[r>>2]|0;if(y>>>0<S>>>0){v=y}else{B=4;break}}if((B|0)==4){do{if((S|0)!=0){Q=b+28|0;f=0;do{g=c[(c[Q>>2]|0)+(f<<2)>>2]|0;j=c[g+12>>2]|0;NM(b,c[(c[g+8>>2]|0)+48>>2]|0,j,c[j+4>>2]|0,c[j+16>>2]|0,0,0,1);g=j+76|0;a[g]=a[g]|2;LM(b,j);f=f+1|0;T=c[r>>2]|0;}while(f>>>0<T>>>0);if((T|0)==0){break}f=b+28|0;Q=0;do{j=c[(c[f>>2]|0)+(Q<<2)>>2]|0;g=j+12|0;h=c[g>>2]|0;n=j+8|0;j=c[h+20>>2]|0;if((j|0)!=0){NM(b,c[(c[n>>2]|0)+48>>2]|0,h,c[h+8>>2]|0,j,0,0,1)}j=c[h+24>>2]|0;if((j|0)!=0){NM(b,c[(c[n>>2]|0)+48>>2]|0,c[g>>2]|0,c[h+12>>2]|0,j,0,0,1)}LM(b,h);Q=Q+1|0;}while(Q>>>0<(c[r>>2]|0)>>>0)}}while(0);r=C+56|0;c[r>>2]=0;c[r+4>>2]=-2147483648;R=0;i=e;return R|0}else if((B|0)==12){yDb(u,16,2196032,(q=i,i=i+8|0,c[q>>2]=v,q)|0);i=q;R=-1;i=e;return R|0}else if((B|0)==15){yDb(u,16,2182176,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;R=-1;i=e;return R|0}else if((B|0)==25){yDb(u,16,2168288,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;$Db(E);R=K;i=e;return R|0}else if((B|0)==30){yDb(u,16,2160848,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;$Db(E);R=H;i=e;return R|0}else if((B|0)==35){yDb(u,16,2154168,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;$Db(E);R=M;i=e;return R|0}else if((B|0)==37){yDb(u,16,2134728,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;$Db(E);R=-1;i=e;return R|0}else if((B|0)==53){i=e;return R|0}return 0}function JM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+8|0;e=d|0;f=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;g=f+12|0;h=c[g>>2]|0;j=f+8|0;k=c[j>>2]|0;l=c[k+48>>2]|0;do{if((l|0)==31){m=b+8|0;n=c[m>>2]|0;o=c[m+4>>2]|0;if((c[h+40>>2]|0)<1){p=o;q=n}else{m=c[b+48>>2]|0;r=YGb(m,(m|0)<0|0?-1:0,n,o)|0;p=F;q=r}r=h+32|0;if((c[b+36>>2]&1|0)==0){s=c[r+4>>2]|0;t=c[r>>2]|0}else{c[r>>2]=q;c[r+4>>2]=p;s=p;t=q}r=ZGb(q,p,t,s)|0;o=r;r=c[h+28>>2]|0;if((o|0)<(1<<r|0)){u=o;v=s;w=t}else{n=h+32|0;m=YGb(o,(o|0)<0|0?-1:0,t,s)|0;o=F;c[n>>2]=m;c[n+4>>2]=o;u=0;v=o;w=m}m=_Gb(w|0,v|0,r|0)|0;x=F|((u|0)<0|0?-1:0);y=m|u}else{m=b+8|0;r=c[b+48>>2]|0;o=YGb(r,(r|0)<0|0?-1:0,c[m>>2]|0,c[m+4>>2]|0)|0;m=F;if((l|0)!=1330664787){x=m;y=o;break}r=c[k+116>>2]|0;c[e>>2]=1;c[e+4>>2]=c[k+412>>2];n=KDb(r,(r|0)<0|0?-1:0,e,f+40|0)|0;r=YGb(n,F,o,m)|0;x=F;y=r}}while(0);f=h+56|0;if(!((c[f>>2]|0)==0&(c[f+4>>2]|0)==(-2147483648|0))){z=b+24|0;A=c[z>>2]|0;B=b+28|0;C=c[B>>2]|0;D=c[j>>2]|0;E=c[g>>2]|0;G=D+48|0;H=c[G>>2]|0;NM(a,H,E,A,C,y,x,0);MM(a,0);I=h+65368|0;J=I;K=J|0;c[K>>2]=y;L=J+4|0;c[L>>2]=x;i=d;return 0}e=b+8|0;k=c[e+4>>2]|0;c[f>>2]=c[e>>2];c[f+4>>2]=k;z=b+24|0;A=c[z>>2]|0;B=b+28|0;C=c[B>>2]|0;D=c[j>>2]|0;E=c[g>>2]|0;G=D+48|0;H=c[G>>2]|0;NM(a,H,E,A,C,y,x,0);MM(a,0);I=h+65368|0;J=I;K=J|0;c[K>>2]=y;L=J+4|0;c[L>>2]=x;i=d;return 0}function KM(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+24|0;e=c[d>>2]|0;if((e|0)!=0){f=a+28|0;g=0;h=e;while(1){e=c[(c[(c[f>>2]|0)+(g<<2)>>2]|0)+12>>2]|0;if((b[e+65358>>1]|0)==0){i=h}else{LM(a,e);i=c[d>>2]|0}e=g+1|0;if(e>>>0<i>>>0){g=e;h=i}else{break}}}MM(a,1);if((c[d>>2]|0)==0){return 0}i=a+28|0;a=0;do{h=c[(c[i>>2]|0)+(a<<2)>>2]|0;g=h+12|0;f=c[g>>2]|0;e=c[(c[h+8>>2]|0)+48>>2]|0;if((e|0)==86028|(e|0)==86052|(e|0)==1330664787){$Db(f+4|0)}$Db(f+8|0);$Db(g);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0);return 0}function LM(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=c[d+12>>2]|0;k=cEb(65312)|0;l=k;if((k|0)==0){i=f;return}m=j+4|0;j=e+56|0;UGb(k|0,j|0,65304)|0;n=e+64|0;o=c[n+4>>2]|0;p=j|0;c[p>>2]=c[n>>2];c[p+4>>2]=o;o=e+48|0;c[o>>2]=(c[o>>2]|0)+1;c[n>>2]=-1;c[n+4>>2]=-1;a[e+76|0]=0;a[e+77|0]=0;b[e+65358>>1]=0;e=c[m>>2]|0;a:do{if((e|0)==0){q=m;r=0}else{n=d+28|0;o=k+16|0;p=k+8|0;j=g|0;s=g+4|0;t=h|0;u=h+4|0;v=m;w=e;while(1){x=c[n>>2]|0;y=w+8|0;z=c[y>>2]|0;A=c[y+4>>2]|0;y=c[x+(c[w+16>>2]<<2)>>2]|0;B=c[x+(c[o>>2]<<2)>>2]|0;do{if((z|0)==(-1|0)&(A|0)==(-1|0)){C=w}else{if((c[p>>2]|0)==(-1|0)&(c[p+4>>2]|0)==(-1|0)){C=w;break}x=c[(c[y+12>>2]|0)+28>>2]|0;if((x|0)==0){D=A;E=z}else{G=aHb(z|0,A|0,x|0)|0;H=(1<<x)-1|0;x=YGb(H&z,((H|0)<0|0?-1:0)&A,G,F)|0;D=F;E=x}c[j>>2]=1;c[s>>2]=1e6;x=KDb(E,D,y+40|0,g)|0;G=F;H=c[p>>2]|0;I=c[p+4>>2]|0;J=c[(c[B+12>>2]|0)+28>>2]|0;if((J|0)==0){K=I;L=H}else{M=aHb(H|0,I|0,J|0)|0;N=(1<<J)-1|0;J=YGb(N&H,((N|0)<0|0?-1:0)&I,M,F)|0;K=F;L=J}c[t>>2]=1;c[u>>2]=1e6;J=KDb(L,K,B+40|0,h)|0;M=F;I=c[v>>2]|0;if((G|0)>(M|0)|(G|0)==(M|0)&x>>>0>J>>>0){q=v;r=I;break a}else{C=I}}}while(0);B=C+65304|0;y=c[B>>2]|0;if((y|0)==0){q=B;r=0;break}else{v=B;w=y}}}}while(0);c[k+65304>>2]=r;c[q>>2]=l;i=f;return}function MM(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=(c[a+12>>2]|0)+4|0;l=c[k>>2]|0;if((l|0)==0){i=f;return}c[j>>2]=l;m=a+28|0;n=j;o=a+16|0;a:do{if((b|0)==0){a=l;while(1){p=c[(c[(c[m>>2]|0)+(c[a+16>>2]<<2)>>2]|0)+12>>2]|0;q=p+48|0;if((c[q>>2]|0)>>>0<2>>>0){r=a;break a}do{if((Mz(g)|0)>=0){kz(c[g>>2]|0,310,0);Yy(c[g>>2]|0,1399285583);Py(c[g>>2]|0,0);Py(c[g>>2]|0,d[a+20|0]|0);s=a+8|0;dz(c[g>>2]|0,c[s>>2]|0,c[s+4>>2]|0);Yy(c[g>>2]|0,c[p+65360>>2]|0);s=c[g>>2]|0;t=p;u=c[t>>2]|0;c[t>>2]=u+1;Yy(s,u);u=Ty(c[g>>2]|0,0,0,1)|0;s=F;Yy(c[g>>2]|0,0);t=a+21|0;Py(c[g>>2]|0,d[t]|0);Ry(c[g>>2]|0,a+22|0,d[t]|0);Ry(c[g>>2]|0,a+277|0,e[a+65302>>1]|0);t=c[g>>2]|0;v=Ty(t,0,0,1)|0;w=F;x=jz(t)|0;Ty(t,u,s,0)|0;Zy(t,x);Ty(t,v,w,0)|0;Sy(c[g>>2]|0);w=Oz(c[g>>2]|0,h)|0;if((w|0)<0){break}Ry(c[o>>2]|0,c[h>>2]|0,w);Sy(c[o>>2]|0);ZDb(c[h>>2]|0);c[q>>2]=(c[q>>2]|0)-1}}while(0);q=c[(c[j>>2]|0)+65304>>2]|0;$Db(n);c[j>>2]=q;if((q|0)==0){r=0;break}else{a=q}}}else{a=l;while(1){q=c[(c[(c[m>>2]|0)+(c[a+16>>2]<<2)>>2]|0)+12>>2]|0;p=q+48|0;w=c[p>>2]|0;do{if((Mz(g)|0)>=0){kz(c[g>>2]|0,310,0);Yy(c[g>>2]|0,1399285583);Py(c[g>>2]|0,0);Py(c[g>>2]|0,d[a+20|0]|0|((w|0)==1?4:0));v=a+8|0;dz(c[g>>2]|0,c[v>>2]|0,c[v+4>>2]|0);Yy(c[g>>2]|0,c[q+65360>>2]|0);v=c[g>>2]|0;t=q;x=c[t>>2]|0;c[t>>2]=x+1;Yy(v,x);x=Ty(c[g>>2]|0,0,0,1)|0;v=F;Yy(c[g>>2]|0,0);t=a+21|0;Py(c[g>>2]|0,d[t]|0);Ry(c[g>>2]|0,a+22|0,d[t]|0);Ry(c[g>>2]|0,a+277|0,e[a+65302>>1]|0);t=c[g>>2]|0;s=Ty(t,0,0,1)|0;u=F;y=jz(t)|0;Ty(t,x,v,0)|0;Zy(t,y);Ty(t,s,u,0)|0;Sy(c[g>>2]|0);u=Oz(c[g>>2]|0,h)|0;if((u|0)<0){break}Ry(c[o>>2]|0,c[h>>2]|0,u);Sy(c[o>>2]|0);ZDb(c[h>>2]|0);c[p>>2]=(c[p>>2]|0)-1}}while(0);p=c[(c[j>>2]|0)+65304>>2]|0;$Db(n);c[j>>2]=p;if((p|0)==0){r=0;break}else{a=p}}}}while(0);c[k>>2]=r;i=f;return}function NM(f,g,h,j,k,l,m,n){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;o=i;i=i+16|0;p=o|0;q=o+8|0;r=h;s=c[f+12>>2]|0;t=((k>>>0)/255|0)+1|0;do{if((g|0)==31&(n|0)==0){u=c[h+28>>2]|0;if((u|0)==0){v=h+65368|0;w=c[v+4>>2]|0;x=c[v>>2]|0;y=m;z=l;A=0}else{v=u;B=aHb(l|0,m|0,v|0)|0;C=(1<<u)-1|0;D=C;E=(C|0)<0|0?-1:0;C=YGb(D&l,E&m,B,F)|0;B=F;G=h+65368|0;H=c[G>>2]|0;I=c[G+4>>2]|0;G=aHb(H|0,I|0,v|0)|0;v=YGb(D&H,E&I,G,F)|0;w=F;x=v;y=B;z=C;A=u}u=YGb(x,w,1,0)|0;C=F;if(!((y|0)>(C|0)|(y|0)==(C|0)&z>>>0>u>>>0)){if((A|0)==0){J=0;break}u=(1<<A)-1|0;if(!((u&l|0)==0&(((u|0)<0|0?-1:0)&m|0)==0)){J=0;break}}u=h+64|0;if((c[u>>2]|0)==(-1|0)&(c[u+4>>2]|0)==(-1|0)){J=1;break}LM(f,r);J=1}else{J=0}}while(0);A=(n|0)!=0;do{if(!A){n=b[h+65358>>1]|0;if(n<<16>>16==0){break}if(!((65025-(n&65535)|0)>>>0<k>>>0)){break}LM(f,r)}}while(0);n=h+77|0;z=h+76|0;y=h+65358|0;w=h+64|0;x=h+72|0;g=f+28|0;u=h+56|0;C=p|0;B=p+4|0;v=q|0;G=q+4|0;I=s+8|0;E=s+16|0;if(A){A=0;s=j;H=k;while(1){D=t-A|0;K=a[n]|0;L=K&255;M=L^255;N=(D|0)>(M|0)?M:D;if((A|0)!=0&K<<24>>24==0){a[z]=a[z]|1}K=N-1|0;TGb(h+(L+78)|0,-1|0,K|0)|0;L=(d[n]|0)+K|0;D=N*255|0;M=H>>>0>D>>>0?D:H;a[n]=(L&255)+1;a[h+((L&255)+78)|0]=M+(K*-255|0);UGb(h+((e[y>>1]|0)+333)|0,s|0,M)|0;K=N+A|0;b[y>>1]=(e[y>>1]|0)+M;if((K|0)==(t|0)){c[w>>2]=l;c[w+4>>2]=m}if((K|0)<(t|0)){A=K;s=s+M|0;H=H-M|0}else{break}}}else{H=0;s=j;j=k;do{k=t-H|0;A=a[n]|0;M=A&255;K=M^255;N=(k|0)>(K|0)?K:k;if((H|0)!=0&A<<24>>24==0){a[z]=a[z]|1}A=N-1|0;TGb(h+(M+78)|0,-1|0,A|0)|0;M=(d[n]|0)+A|0;k=N*255|0;K=j>>>0>k>>>0?k:j;a[n]=(M&255)+1;a[h+((M&255)+78)|0]=K+(A*-255|0);UGb(h+((e[y>>1]|0)+333)|0,s|0,K)|0;s=s+K|0;j=j-K|0;H=N+H|0;b[y>>1]=(e[y>>1]|0)+K;if((H|0)==(t|0)){c[w>>2]=l;c[w+4>>2]=m}K=c[u>>2]|0;N=c[u+4>>2]|0;A=(c[(c[g>>2]|0)+(c[x>>2]<<2)>>2]|0)+40|0;c[C>>2]=1;c[B>>2]=1e6;M=KDb(K,N,A,p)|0;N=F;K=c[w>>2]|0;k=c[w+4>>2]|0;c[v>>2]=1;c[G>>2]=1e6;L=KDb(K,k,A,q)|0;A=F;do{if((a[n]|0)==-1){O=30}else{k=c[I>>2]|0;if((k|0)>0){if((e[y>>1]|0)>=(k|0)){O=30;break}}k=c[E>>2]|0;K=c[E+4>>2]|0;D=0;if(!((K|0)>(D|0)|(K|0)==(D|0)&k>>>0>0>>>0)){break}D=ZGb(L,A,M,N)|0;P=F;if(!((P|0)<(K|0)|(P|0)==(K|0)&D>>>0<k>>>0)){O=30}}}while(0);if((O|0)==30){O=0;LM(f,r)}}while((H|0)<(t|0))}if((J|0)==0){i=o;return}J=h+64|0;if((c[J>>2]|0)==(-1|0)&(c[J+4>>2]|0)==(-1|0)){i=o;return}LM(f,r);i=o;return}function OM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[c[b+12>>2]>>2]|0;g=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;h=f+(e*400|0)+392|0;i=c[h>>2]|0;j=c[f+(e*400|0)>>2]|0;k=c[f+(e*400|0)+12>>2]|0;l=j+k|0;m=c[f+(e*400|0)+16>>2]|0;do{if((m|0)==60){if((PGb(l,1924328,8)|0)!=0){break}e=WDb(4)|0;if((e|0)==0){n=-12;return n|0}f=g+8|0;if((BT(c[f>>2]|0,8)|0)<0){n=-12;return n|0}o=j+(k+28)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+36)|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+40)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+44)|0;s=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+48)|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+56)|0;u=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=c[f>>2]|0;c[o+8>>2]=1;c[o+48>>2]=86068;c[o+412>>2]=q;c[o+416>>2]=r;c[o+424>>2]=s;if((q|0)!=0){MT(g,64,1,q)}c[e>>2]=u+1;ZDb(c[h>>2]|0);c[h>>2]=e;e=c[(c[f>>2]|0)+96>>2]|0;x=t;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=(c[(c[f>>2]|0)+96>>2]|0)+4|0;x=p;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;n=1;return n|0}}while(0);if((i|0)==0){n=0;return n|0}h=i;if((c[h>>2]|0)==0){n=0;return n|0}eN(b,g+88|0,l,m)|0;c[h>>2]=(c[h>>2]|0)-1;n=1;return n|0}function PM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+48|0;e=d+24|0;f=c[c[a+12>>2]>>2]|0;g=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;a=g+8|0;if((c[(c[a>>2]|0)+48>>2]|0)==117){h=0;i=d;return h|0}j=(c[f+(b*400|0)>>2]|0)+((c[f+(b*400|0)+12>>2]|0)+13)|0;k=(c[f+(b*400|0)+16>>2]<<3)-104|0;b=k>>>0>2147483639>>>0|(j|0)==0;f=b?0:j;j=b?0:k;c[e>>2]=f;c[e+12>>2]=j;c[e+16>>2]=j+8;c[e+4>>2]=f+(j>>3);c[e+8>>2]=0;if((l1(c[a>>2]|0,e,d|0)|0)<0){h=-1;i=d;return h|0}e=c[a>>2]|0;c[e+8>>2]=0;c[e+48>>2]=117;MT(g,64,c[e+104>>2]|0,c[e+108>>2]<<1);h=1;i=d;return h|0}function QM(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=d>>>31|e<<1;h=e>>31|((e|0)<0|0?-1:0)<<1;i=YGb((d>>>9|e<<23)&8191,(e>>>9|0<<23)&0,g,h)|0;j=F;if(((d>>>14|e<<18)&65280|d&255|0)==0&((e>>>14|0<<18)&0|e&0|0)==0){e=(c[c[a+12>>2]>>2]|0)+(b*400|0)+20|0;c[e>>2]=c[e>>2]|1}if((f|0)==0){return(F=j,i)|0}c[f>>2]=g;c[f+4>>2]=h;return(F=j,i)|0}function RM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[c[b+12>>2]>>2]|0;g=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;b=c[f+(e*400|0)>>2]|0;h=c[f+(e*400|0)+12>>2]|0;if((a[b+h|0]|0)!=75){i=0;return i|0}e=c[g+8>>2]|0;c[e+8>>2]=0;c[e+48>>2]=117;e=b+(h+12)|0;f=fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;e=b+(h+8)|0;MT(g,64,f,fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0);i=1;return i|0}function SM(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;f=d>>>30|e<<2;g=e>>>30|0<<2;h=d&1073741823;d=e&0;if(!((h|0)==0&(d|0)==0)){i=YGb(f,g,h,d)|0;j=F;return(F=j,i)|0}e=(c[c[a+12>>2]>>2]|0)+(b*400|0)+20|0;c[e>>2]=c[e>>2]|1;i=YGb(f,g,h,d)|0;j=F;return(F=j,i)|0}function TM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+32|0;g=f|0;h=c[c[b+12>>2]>>2]|0;j=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;k=c[h+(e*400|0)+12>>2]|0;l=c[h+(e*400|0)>>2]|0;m=l+k|0;if((a[m]|0)==-1){n=0;i=f;return n|0}o=c[h+(e*400|0)+16>>2]|0;e=o<<3;h=e>>>0>2147483639>>>0|(m|0)==0;p=h?0:m;m=h?8:e+8|0;e=m>>>0>1>>>0?1:m;h=p+(e>>>3)|0;q=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(e&1)>>>25;h=e+7|0;e=m>>>0>h>>>0?h:m;if((q|0)==4){eN(b,j+88|0,l+(k+4)|0,o-4|0)|0;n=1;i=f;return n|0}else if((q|0)==127){q=l+(k+17)|0;k=-e|0;l=m-e|0;if((k|0)>32){r=k}else{r=(l|0)<32?l:32}l=r+e|0;e=p+(l>>>3)|0;r=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(l&7);e=l+8|0;l=m>>>0>e>>>0?e:m;if((r&-16777216|0)!=16777216){n=-1;i=f;return n|0}r=-l|0;e=m-l|0;if((r|0)>24){s=r}else{s=(e|0)<24?e:24}e=s+l|0;l=-e|0;s=m-e|0;if((l|0)>32){t=l}else{t=(s|0)<32?s:32}s=t+e|0;e=p+(s>>>3)|0;t=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(s&7)&-65536;e=s+16|0;s=m>>>0>e>>>0?e:m;m=p+(s>>>3)|0;if(((fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(s&7)>>>16|t|0)!=34){n=-1;i=f;return n|0}t=j+8|0;X9(c[t>>2]|0,g,q);g=c[t>>2]|0;c[g+8>>2]=1;c[g+48>>2]=86028;c[j+236>>2]=2;if((BT(g,34)|0)<0){n=-12;i=f;return n|0}g=c[t>>2]|0;UGb(c[g+96>>2]|0,q|0,c[g+100>>2]|0)|0;MT(j,64,1,c[(c[t>>2]|0)+412>>2]|0);n=1;i=f;return n|0}else{n=1;i=f;return n|0}return 0}function UM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+16|0;e=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;f=c[c[a+12>>2]>>2]|0;a=RRa(86028)|0;if((a|0)==0){g=-1;i=d;return g|0}h=e+8|0;j=c[h>>2]|0;c[j+8>>2]=1;c[j+48>>2]=86028;c[a+176>>2]=1;TRa(a,j,d+8|0,d|0,(c[f+(b*400|0)>>2]|0)+(c[f+(b*400|0)+12>>2]|0)|0,c[f+(b*400|0)+16>>2]|0,0,-2147483648,0,-2147483648,-1,-1)|0;VRa(a);a=c[(c[h>>2]|0)+412>>2]|0;if((a|0)==0){g=1;i=d;return g|0}MT(e,64,1,a);g=0;i=d;return g|0}function VM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;f=i;i=i+8|0;g=f|0;h=c[c[b+12>>2]>>2]|0;j=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;k=c[h+(e*400|0)>>2]|0;l=c[h+(e*400|0)+12>>2]|0;m=h+(e*400|0)+16|0;e=c[m>>2]|0;if(!((e|0)>-1)){yDb(0,0,1979264,(n=i,i=i+24|0,c[n>>2]=1949448,c[n+8>>2]=1923904,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}h=e+l|0;o=k+h|0;if((e|0)<1){p=0;i=f;return p|0}q=a[k+l|0]|0;if((q&1)==0){p=0;i=f;return p|0}if((q<<24>>24|0)==1){r=e>>>0>1>>>0?1:e;s=r+l|0;t=e-r|0;do{if((t|0)<1){u=12}else{r=a[k+s|0]|0;if((r<<24>>24|0)==116){v=c[j+8>>2]|0;c[v+8>>2]=3;c[v+48>>2]=94210;w=k+((t>>>0>12>>>0?12:t)+s)|0;x=v;break}else if((r<<24>>24|0)!=118){u=12;break}r=j+8|0;c[(c[r>>2]|0)+8>>2]=0;v=t>>>0>8>>>0?8:t;y=v+s|0;z=k+y|0;if((h-s-v|0)<4){A=0;B=z}else{v=z;A=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;B=k+(y+4)|0}y=vT(1240808,A)|0;v=c[r>>2]|0;c[v+48>>2]=y;c[v+52>>2]=A;w=B;x=v}}while(0);do{if((u|0)==12){B=g|0;c[g>>2]=0;A=j+8|0;c[(c[A>>2]|0)+8>>2]=1;v=t>>>0>8>>>0?8:t;y=v+s|0;r=h-s-v|0;v=r>>>0>4>>>0?4:r;UGb(B|0,k+y|0,v)|0;r=k+(v+y)|0;a[g+4|0]=0;y=vT(1238064,kb(B|0,0,16)|0)|0;B=c[A>>2]|0;c[B+48>>2]=y;if((y|0)==86018){w=r;x=B;break}c[j+236>>2]=1;w=r;x=B}}while(0);if((o-w|0)<4){C=0;D=w}else{g=w;C=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;D=w+4|0}w=c[m>>2]|0;m=C>>>0>w>>>0?w:C;if((o-D|0)<8){E=0;G=0;H=D}else{C=D;w=C|0;g=C+4|0;E=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;G=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;H=D+8|0}do{if((o-H|0)>=8){D=H;w=D|0;g=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=D+4|0;D=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;if((G|0)==0&(E|0)==0|(g|0)==0&(D|0)==0){break}w=o-(H+8)|0;C=w>>>0>4>>>0?12:w+8|0;w=o-(H+C)|0;s=(w>>>0>8>>>0?8:w)+C|0;C=H+s|0;w=j+8|0;t=o-C|0;if((c[x+8>>2]|0)==0){if((t|0)<4){I=0;J=C}else{u=C;I=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;J=H+(s+4)|0}c[x+120>>2]=I;if((o-J|0)<4){K=0}else{u=J;K=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0}c[x+124>>2]=K;u=gHb(g,D,1e7,0)|0;MT(j,64,G,u);p=1;i=f;return p|0}if((t|0)<2){L=0;M=C}else{t=C;L=(d[t]|d[t+1|0]<<8)<<16>>16&65535;M=H+(s+2)|0}c[x+416>>2]=L;s=o-M|0;t=s>>>0>2>>>0?2:s;s=M+t|0;if((o-s|0)<4){N=0;O=s}else{C=s;N=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24)<<3;O=M+(t+4)|0}c[x+72>>2]=N;t=gHb(g,D,1e7,0)|0;D=hHb(t,F,G,E)|0;t=D;c[x+412>>2]=t;MT(j,64,1,t);do{if(m>>>0>55>>>0){if((c[(c[w>>2]|0)+48>>2]|0)!=86018){P=m;Q=O;break}t=o-O|0;P=m-4|0;Q=O+(t>>>0>4>>>0?4:t)|0}else{P=m;Q=O}}while(0);if(!(P>>>0>52>>>0)){p=1;i=f;return p|0}BT(c[w>>2]|0,P-52|0)|0;t=c[w>>2]|0;D=c[t+100>>2]|0;g=o-Q|0;UGb(c[t+96>>2]|0,Q|0,g>>>0>D>>>0?D:g)|0;p=1;i=f;return p|0}}while(0);yDb(b,16,2022656,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=-1094995529;i=f;return p|0}else if((q<<24>>24|0)==3){q=(e>>>0>7>>>0?7:e)+l|0;l=h-q|0;if(!(l>>>0>1>>>0)){p=1;i=f;return p|0}eN(b,j+88|0,k+q|0,l-1|0)|0;p=1;i=f;return p|0}else{p=1;i=f;return p|0}return 0}function WM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c[c[b+12>>2]>>2]|0;b=c[f+(e*400|0)>>2]|0;g=f+(e*400|0)+12|0;h=c[g>>2]|0;i=b+h|0;j=a[i]|0;if((j&8)==0){k=j}else{j=f+(e*400|0)+20|0;c[j>>2]=c[j>>2]|1;k=a[i]|0}i=k&255;k=i<<1&4|i>>>6;i=k+1|0;c[g>>2]=i+h;g=f+(e*400|0)+16|0;c[g>>2]=(c[g>>2]|0)-i;if((k|0)==0){return 0}i=f+(e*400|0)+24|0;e=k;k=c[i>>2]|0;while(1){f=e-1|0;g=((d[b+(e+h)|0]|0)<<(f<<3))+k|0;c[i>>2]=g;if((f|0)==0){break}else{e=f;k=g}}return 0}function XM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[c[b+12>>2]>>2]|0;g=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;b=c[f+(e*400|0)>>2]|0;h=c[f+(e*400|0)+12>>2]|0;i=a[b+h|0]|0;if((i&1)==0){j=0;return j|0}if(!(i<<24>>24==1)){j=1;return j|0}i=c[f+(e*400|0)+16>>2]|0;if(i>>>0<100>>>0){j=-1094995529;return j|0}e=b+(h+96)|0;f=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if((f|0)==89694080){if(i>>>0<184>>>0){j=-1094995529;return j|0}e=g+8|0;c[(c[e>>2]|0)+8>>2]=0;k=b+(h+68)|0;l=vT(1240808,d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0;c[(c[e>>2]|0)+48>>2]=l;l=b+(h+164)|0;MT(g,64,d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0,1e7);l=b+(h+176)|0;k=c[e>>2]|0;c[k+120>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(h+180)|0;c[k+124>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;j=1;return j|0}else if((f|0)==89694081){if(i>>>0<136>>>0){j=-1094995529;return j|0}i=g+8|0;c[(c[i>>2]|0)+8>>2]=1;g=b+(h+124)|0;f=vT(1238064,(d[g]|d[g+1|0]<<8)<<16>>16&65535)|0;g=c[i>>2]|0;c[g+48>>2]=f;f=b+(h+126)|0;c[g+416>>2]=(d[f]|d[f+1|0]<<8)<<16>>16&65535;f=b+(h+128)|0;c[g+412>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+132)|0;c[g+72>>2]=(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24)<<3;j=1;return j|0}else{j=1;return j|0}return 0}function YM(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[c[a+12>>2]>>2]|0;f=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;g=e+(b*400|0)+392|0;h=c[g>>2]|0;i=c[e+(b*400|0)>>2]|0;j=c[e+(b*400|0)+12>>2]|0;k=i+j|0;do{if((h|0)==0){l=cEb(16)|0;c[g>>2]=l;if((l|0)==0){m=-12}else{n=l;break}return m|0}else{n=h}}while(0);if((c[e+(b*400|0)+80>>2]&2|0)==0){h=n;if((c[h>>2]|0)==0){m=0;return m|0}g=c[e+(b*400|0)+16>>2]|0;if(g>>>0<8>>>0){m=-1094995529;return m|0}if((PGb(k,2070264,8)|0)!=0){m=-1094995529;return m|0}eN(a,f+88|0,i+(j+8)|0,g-8|0)|0;c[h>>2]=(c[h>>2]|0)-1;m=1;return m|0}else{h=e+(b*400|0)+16|0;if((c[h>>2]|0)>>>0<19>>>0){m=-1094995529;return m|0}if((d[i+(j+8)|0]|0)>>>0>15>>>0){m=-1094995529;return m|0}b=f+8|0;e=c[b>>2]|0;c[e+8>>2]=1;c[e+48>>2]=1330664787;c[e+416>>2]=d[i+(j+9)|0]|0;g=i+(j+10)|0;j=(d[g]|d[g+1|0]<<8)<<16>>16&65535;c[n+4>>2]=j;c[e+116>>2]=j;if((BT(e,c[h>>2]|0)|0)!=0){m=-12;return m|0}UGb(c[(c[b>>2]|0)+96>>2]|0,k|0,c[h>>2]|0)|0;h=c[b>>2]|0;c[h+412>>2]=48e3;b=IDb(80,0,48e3,0,1e3,0)|0;j0a(h,b);MT(f,64,1,48e3);c[n>>2]=1;m=1;return m|0}return 0}function ZM(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;f=c[c[b+12>>2]>>2]|0;g=c[(c[b+28>>2]|0)+(d<<2)>>2]|0;h=c[f+(d*400|0)+392>>2]|0;j=c[f+(d*400|0)>>2]|0;k=c[f+(d*400|0)+12>>2]|0;l=j+k|0;m=c[f+(d*400|0)+16>>2]|0;if((m|0)==0){n=-1094995529;i=e;return n|0}o=f+(d*400|0)+48|0;p=c[o>>2]|0;q=c[o+4>>2]|0;a:do{if((p|0)==0&(q|0)==0|(p|0)==0&(q|0)==(-2147483648|0)){if((c[f+(d*400|0)+80>>2]&4|0)!=0){r=q;s=p;break}t=c[f+(d*400|0)+96>>2]|0;u=a[l]|0;v=u&255;w=v>>>3;x=v&3;do{if((u&255)>>>0<96>>>0){v=(w&3)*960|0;y=v>>>0<480>>>0?480:v}else{if(u<<24>>24>-1){y=480<<(w&1);break}else{y=120<<(w&3);break}}}while(0);do{if((x|0)==0){z=1;A=13}else if((x|0)==3){if((m|0)<2){break}z=a[j+(k+1)|0]&63;A=13}else{z=2;A=13}}while(0);do{if((A|0)==13){x=ba(z,y)|0;if((x|0)<0){break}w=j+(m+k)|0;u=c[f+(d*400|0)+92>>2]|0;if((t|0)<(u|0)){v=t;B=x;C=w;D=w;while(1){w=a[f+(d*400|0)+100+v|0]|0;E=D+(w&255)|0;if(w<<24>>24==-1|(E|0)==(C|0)){G=C;H=B}else{w=E-C|0;I=a[C]|0;J=I&255;K=J>>>3;L=J&3;do{if((I&255)>>>0<96>>>0){J=(K&3)*960|0;M=J>>>0<480>>>0?480:J}else{if(I<<24>>24>-1){M=480<<(K&1);break}else{M=120<<(K&3);break}}}while(0);do{if((L|0)==0){N=1;A=26}else if((L|0)==3){if((w|0)<2){O=-1094995529;break}N=a[C+1|0]&63;A=26}else{N=2;A=26}}while(0);if((A|0)==26){A=0;O=ba(N,M)|0}G=E;H=((O|0)>0?O:0)+B|0}w=v+1|0;if((w|0)<(u|0)){v=w;B=H;C=G;D=E}else{P=H;break}}}else{P=x}D=f+(d*400|0)+32|0;C=ZGb(c[D>>2]|0,c[D+4>>2]|0,P,(P|0)<0|0?-1:0)|0;D=F;B=f+(d*400|0)+56|0;c[B>>2]=C;c[B+4>>2]=D;c[o>>2]=C;c[o+4>>2]=D;r=D;s=C;break a}}while(0);t=f+(d*400|0)+20|0;c[t>>2]=c[t>>2]|2;n=0;i=e;return n|0}else{r=q;s=p}}while(0);p=a[l]|0;l=p&255;q=l>>>3;P=l&3;do{if((p&255)>>>0<96>>>0){l=(q&3)*960|0;Q=l>>>0<480>>>0?480:l}else{if(p<<24>>24>-1){Q=480<<(q&1);break}else{Q=120<<(q&3);break}}}while(0);do{if((P|0)==0){R=1}else if((P|0)==3){if((m|0)<2){n=-1094995529;i=e;return n|0}else{R=a[j+(k+1)|0]&63;break}}else{R=2}}while(0);k=ba(R,Q)|0;if((k|0)<0){n=k;i=e;return n|0}Q=f+(d*400|0)+24|0;c[Q>>2]=k;if((s|0)==0&(r|0)==(-2147483648|0)){R=h+8|0;S=c[R+4>>2]|0;T=c[R>>2]|0}else{R=g+48|0;if((c[R>>2]|0)==0&(c[R+4>>2]|0)==(-2147483648|0)){c[R>>2]=s;c[R+4>>2]=r;U=c[o+4>>2]|0;V=c[o>>2]|0}else{U=r;V=s}s=ZGb(V,U,c[h+4>>2]|0,0)|0;U=F;c[o>>2]=s;c[o+4>>2]=U;o=f+(d*400|0)+56|0;c[o>>2]=s;c[o+4>>2]=U;o=h+8|0;c[o>>2]=s;c[o+4>>2]=U;S=U;T=s}s=k;k=0;U=h+8|0;o=YGb(T,S,s,k)|0;S=F;c[U>>2]=o;c[U+4>>2]=S;if((c[f+(d*400|0)+80>>2]&4|0)==0){n=0;i=e;return n|0}U=f+(d*400|0)+32|0;T=ZGb(o,S,c[U>>2]|0,c[U+4>>2]|0)|0;U=YGb(c[h+4>>2]|0,0,T,F)|0;T=F;h=(T|0)>(k|0)|(T|0)==(k|0)&U>>>0>s>>>0;S=h?s:U;U=h?k:T;T=0;if(!((U|0)>(T|0)|(U|0)==(T|0)&S>>>0>0>>>0)){n=0;i=e;return n|0}if((U|0)<(k|0)|(U|0)==(k|0)&S>>>0<s>>>0){T=ZGb(s,k,S,U)|0;W=T}else{W=1}c[Q>>2]=W;c[f+(d*400|0)+380>>2]=S;yDb(b,48,2134752,(b=i,i=i+8|0,c[b>>2]=W,b)|0);i=b;n=0;i=e;return n|0}function _M(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=c[a+12>>2]|0;j=h;k=c[j>>2]|0;l=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;m=c[k+(b*400|0)>>2]|0;n=c[k+(b*400|0)+12>>2]|0;o=m+n|0;p=l+8|0;UGb((c[p>>2]|0)+16|0,2222032,9)|0;c[(c[p>>2]|0)+8>>2]=2;p=c[k+(b*400|0)+16>>2]|0;if((c[k+(b*400|0)+80>>2]&4|0)!=0&(p|0)==0){q=1;i=e;return q|0}if(p>>>0<8>>>0){q=-1;i=e;return q|0}if((RGb(o,1923984,8)|0)==0){if(p>>>0<64>>>0){q=-1;i=e;return q|0}r=m+(n+8)|0;s=(d[r]|d[r+1|0]<<8)<<16>>16;if((s-3&65535)>>>0>1>>>0){r=m+(n+10)|0;t=(d[r]|d[r+1|0]<<8)<<16>>16&65535;yDb(a,24,2134696,(u=i,i=i+16|0,c[u>>2]=s&65535,c[u+8>>2]=t,u)|0);i=u;q=-1;i=e;return q|0}t=m+(n+12)|0;s=t|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=t+4|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=m+(n+20)|0;v=s|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=0;x=0;if(!(((s|0)>(v|0)|(s|0)==(v|0)&w>>>0>0>>>0)&((t|0)>(x|0)|(t|0)==(x|0)&r>>>0>0>>>0))){q=1;i=e;return q|0}iFb(f,g,r,t,w,s,2147483647,0)|0;MT(l,64,1,c[g>>2]|0);g=c[f>>2]|0;f=g;s=(g|0)<0|0?-1:0;g=l+48|0;c[g>>2]=f;c[g+4>>2]=s;g=k+(b*400|0)+48|0;c[g>>2]=f;c[g+4>>2]=s;q=1;i=e;return q|0}if((RGb(o,2070256,8)|0)!=0){q=1;i=e;return q|0}if(p>>>0<52>>>0){q=-1;i=e;return q|0}p=m+(n+12)|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=c[h+4>>2]|0;h=0;while(1){if((h|0)>=(p|0)){break}y=c[j>>2]|0;if((c[y+(h*400|0)+28>>2]|0)==(o|0)){z=14;break}else{h=h+1|0}}do{if((z|0)==14){o=m+(n+36)|0;j=o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=o+4|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;if((h|0)<0){break}j=y+(h*400|0)+40|0;if(!((c[j>>2]|0)==(-1|0)&(c[j+4>>2]|0)==(-1|0))){yDb(a,24,1979224,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;q=1;i=e;return q|0}if((p|0)==(-1|0)&(o|0)==(-1|0)){q=1;i=e;return q|0}c[j>>2]=p;c[j+4>>2]=o;q=1;i=e;return q|0}}while(0);yDb(a,24,2022600,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;q=1;i=e;return q|0}function $M(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;f=c[c[a+12>>2]>>2]|0;g=f+(b*400|0)+392|0;h=c[g>>2]|0;j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;k=c[f+(b*400|0)>>2]|0;l=c[f+(b*400|0)+12>>2]|0;m=k+l|0;if((h|0)==0){n=cEb(12)|0;c[g>>2]=n;o=n}else{o=h}h=o+8|0;n=c[h>>2]|0;if((n|0)>1){p=0;i=e;return p|0}do{if((n|0)==0){g=j+8|0;q=c[g>>2]|0;c[q+8>>2]=1;c[q+48>>2]=86052;r=f+(b*400|0)+16|0;if((c[r>>2]|0)>>>0<68>>>0){yDb(a,16,2221904,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;p=-1094995529;i=e;return p|0}t=k+(l+36)|0;c[q+412>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;t=k+(l+48)|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q+416>>2]=u;if((u-1|0)>>>0>1>>>0){yDb(a,16,2134640,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;p=-1094995529;i=e;return p|0}t=(u|0)==1;u=q+448|0;c[u>>2]=t?4:3;c[u+4>>2]=t?0:0;t=k+(l+56)|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=o;c[t>>2]=u;v=k+(l+64)|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;if((w|0)!=0){c[t>>2]=ba(w,u)|0}if((BT(q,c[r>>2]|0)|0)<0){p=-12;i=e;return p|0}else{r=c[g>>2]|0;UGb(c[r+96>>2]|0,m|0,c[r+100>>2]|0)|0;MT(j,64,1,c[(c[g>>2]|0)+412>>2]|0);break}}else{eN(a,j+88|0,m,c[f+(b*400|0)+16>>2]|0)|0}}while(0);c[h>>2]=(c[h>>2]|0)+1;p=1;i=e;return p|0}function aN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=c[c[b+12>>2]>>2]|0;b=c[e+(d*400|0)+392>>2]|0;f=c[b>>2]|0;g=e+(d*400|0)+80|0;h=e+(d*400|0)+48|0;i=c[h>>2]|0;j=c[h+4>>2]|0;do{if((c[g>>2]&4|0)==0){k=8}else{if((i|0)==0&(j|0)==(-2147483648|0)){break}h=e+(d*400|0)+32|0;l=c[h>>2]|0;m=c[h+4>>2]|0;if((l|0)==0&(m|0)==0){k=8;break}h=ZGb(l,m,i,j)|0;m=F;l=c[e+(d*400|0)+92>>2]|0;if((l|0)>0){n=0;o=0;do{o=((a[e+(d*400|0)+100+n|0]|0)!=-1)+o|0;n=n+1|0;}while((n|0)<(l|0));p=o-1|0}else{p=-1}l=ZGb(h,m,ba(p,f)|0,0)|0;c[b+4>>2]=l;k=8}}while(0);do{if((k|0)==8){p=e+(d*400|0)+48|0;if(!((i|0)==0&(j|0)==0)){break}l=e+(d*400|0)+32|0;n=c[l>>2]|0;q=c[l+4>>2]|0;if((n|0)==0&(q|0)==0){break}l=c[e+(d*400|0)+92>>2]|0;if((l|0)>0){r=0;s=0;while(1){t=((a[e+(d*400|0)+100+r|0]|0)!=-1)+s|0;u=r+1|0;if((u|0)<(l|0)){r=u;s=t}else{v=t;break}}}else{v=0}s=ba(v,f)|0;r=ZGb(n,q,s,(s|0)<0|0?-1:0)|0;s=F;l=e+(d*400|0)+56|0;c[l>>2]=r;c[l+4>>2]=s;c[p>>2]=r;c[p+4>>2]=s}}while(0);do{if((c[g>>2]&4|0)!=0){if((c[e+(d*400|0)+96>>2]|0)!=(c[e+(d*400|0)+92>>2]|0)){break}v=c[b+4>>2]|0;if((v|0)==0){break}c[e+(d*400|0)+24>>2]=v;return 0}}while(0);c[e+(d*400|0)+24>>2]=f;return 0}function bN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=i;g=c[c[b+12>>2]>>2]|0;h=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;j=g+(e*400|0)+392|0;k=c[j>>2]|0;l=h+8|0;m=g+(e*400|0)+16|0;n=(c[m>>2]|0)+(c[(c[l>>2]|0)+100>>2]|0)|0;o=n+2|0;p=g+(e*400|0)+12|0;q=c[p>>2]|0;r=g+(e*400|0)|0;e=c[r>>2]|0;g=a[e+q|0]|0;if(!(g<<24>>24<0)){s=0;i=f;return s|0}do{if((k|0)==0){t=cEb(12)|0;if((t|0)==0){s=-12;i=f;return s|0}else{c[j>>2]=t;u=c[p>>2]|0;v=c[r>>2]|0;w=t;x=u;y=v;z=a[v+u|0]|0;break}}else{w=k;x=q;y=e;z=g}}while(0);g=y+x|0;e=z&255;if((e|0)==128){z=c[m>>2]<<3;q=z>>>0>2147483639>>>0|(g|0)==0;k=q?0:g;g=q?8:z+8|0;z=(g|0)<56?g:56;q=k+(z>>>3)|0;j=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=j>>>8;u=z+24|0;z=g>>>0>u>>>0?u:g;u=w+8|0;c[u>>2]=q;if(j>>>0<50397184>>>0){yDb(b,16,2221832,(A=i,i=i+8|0,c[A>>2]=q,A)|0);i=A;s=-38;i=f;return s|0}q=k+(z>>>3)|0;j=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(z&7)>>>16;q=z+16|0;z=g>>>0>q>>>0?q:g;q=j<<4;j=c[l>>2]|0;v=j+120|0;c[v>>2]=q;t=k+(z>>>3)|0;B=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(z&7)>>>16;t=z+16|0;z=g>>>0>t>>>0?t:g;t=B<<4;B=j+124|0;c[B>>2]=t;j=c[u>>2]|0;if(j>>>0>197631>>>0){C=z+100|0;D=g>>>0>C>>>0?C:g;E=11}else{if(j>>>0>197119>>>0){D=z;E=11}else{F=z}}if((E|0)==11){z=k+(D>>>3)|0;j=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(D&7)>>>8;z=D+24|0;D=g>>>0>z>>>0?z:g;z=k+(D>>>3)|0;C=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(D&7)>>>8;z=D+24|0;D=g>>>0>z>>>0?z:g;do{if(j>>>0<=q>>>0&(j|0)>(q-16|0)){if(!(C>>>0<=t>>>0&(C|0)>(t-16|0))){break}c[v>>2]=j;c[B>>2]=C}}while(0);C=D+16|0;F=g>>>0>C>>>0?C:g}C=k+(F>>>3)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(F&7)&-65536;C=F+16|0;F=g>>>0>C>>>0?C:g;C=k+(F>>>3)|0;B=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(F&7)>>>16;C=F+16|0;F=g>>>0>C>>>0?C:g;C=B|D;D=k+(F>>>3)|0;B=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(F&7)&-65536;D=F+16|0;F=g>>>0>D>>>0?D:g;D=k+(F>>>3)|0;j=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(F&7)>>>16;D=F+16|0;F=g>>>0>D>>>0?D:g;D=j|B;if((D|0)>0&(C|0)>0){G=D;H=C}else{yDb(b,24,2134576,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;G=1;H=25}MT(h,64,G,H);H=k+(F>>>3)|0;G=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>8;H=F+24|0;F=g>>>0>H>>>0?H:g;c[h+80>>2]=G;G=k+(F>>>3)|0;H=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(F&7)>>>8;G=F+24|0;F=g>>>0>G>>>0?G:g;c[h+84>>2]=H;H=c[u>>2]|0;do{if(H>>>0>197119>>>0){u=-F|0;G=g-F|0;if((u|0)>38){I=u}else{I=(G|0)<38?G:38}G=I+F|0;if(!(H>>>0>3162111>>>0)){J=G;break}u=G+2|0;J=g>>>0>u>>>0?u:g}else{J=F}}while(0);F=k+(J>>>3)|0;k=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(J&7)>>>27;c[w>>2]=k;c[w+4>>2]=(1<<k)-1;k=c[l>>2]|0;c[k+8>>2]=0;c[k+48>>2]=31;c[h+236>>2]=2;K=k}else if((e|0)==129){eN(b,h+88|0,y+(x+7)|0,(c[m>>2]|0)-7|0)|0;E=24}else if((e|0)==130){E=24}else{yDb(b,16,2070232,(A=i,i=i+8|0,c[A>>2]=e,A)|0);i=A;s=-1094995529;i=f;return s|0}do{if((E|0)==24){if((c[w+8>>2]|0)==0){s=-1094995529;i=f;return s|0}else{K=c[l>>2]|0;break}}}while(0);w=_Db(K+96|0,n+18|0)|0;n=c[l>>2]|0;if((w|0)<0){c[n+100>>2]=0;s=w;i=f;return s|0}else{TGb((c[n+96>>2]|0)+o|0,0,16)|0;n=c[l>>2]|0;w=c[n+96>>2]|0;K=c[n+100>>2]|0;a[w+K|0]=(c[m>>2]|0)>>>8;a[w+(K+1)|0]=c[m>>2];UGb(w+(K+2)|0,(c[r>>2]|0)+(c[p>>2]|0)|0,c[m>>2]|0)|0;c[(c[l>>2]|0)+100>>2]=o;s=1;i=f;return s|0}return 0}function cN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[c[b+12>>2]>>2]|0;f=e+(d*400|0)+48|0;g=c[f>>2]|0;h=c[f+4>>2]|0;do{if((g|0)==0&(h|0)==0|(g|0)==0&(h|0)==(-2147483648|0)){if((c[e+(d*400|0)+80>>2]&4|0)!=0){break}i=c[e+(d*400|0)+96>>2]|0;j=c[e+(d*400|0)+92>>2]|0;if((i|0)<(j|0)){k=1;l=i;do{k=((a[e+(d*400|0)+100+l|0]|0)!=-1)+k|0;l=l+1|0;}while((l|0)<(j|0));m=(k|0)<0|0?-1:0;n=k}else{m=0;n=1}j=e+(d*400|0)+32|0;l=c[j>>2]|0;i=c[j+4>>2]|0;j=c[e+(d*400|0)+392>>2]|0;if((j|0)==0){o=-2147483648;p=0}else{q=$Gb(l|0,i|0,c[j>>2]|0)|0;r=c[j+4>>2]|0;s=r&l;l=((r|0)<0|0?-1:0)&i;i=(c[j+8>>2]|0)>>>0<197121>>>0|0;if((s|0)==0&(l|0)==0){j=e+(d*400|0)+20|0;c[j>>2]=c[j>>2]|1}j=YGb(s,l,q,F)|0;q=YGb(j,F,i,0)|0;o=F;p=q}q=ZGb(p,o,n,m)|0;i=F;j=e+(d*400|0)+56|0;c[j>>2]=q;c[j+4>>2]=i;c[f>>2]=q;c[f+4>>2]=i;j=c[(c[b+28>>2]|0)+(d<<2)>>2]|0;l=j+48|0;if(!((c[l>>2]|0)==0&(c[l+4>>2]|0)==(-2147483648|0))){break}c[l>>2]=q;c[l+4>>2]=i;l=j+56|0;j=c[l>>2]|0;s=c[l+4>>2]|0;if((j|0)==0&(s|0)==0){break}r=ZGb(j,s,q,i)|0;c[l>>2]=r;c[l+4>>2]=F}}while(0);if((c[e+(d*400|0)+16>>2]|0)==0){return 0}c[e+(d*400|0)+24>>2]=1;return 0}function dN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=c[c[a+12>>2]>>2]|0;a=c[g+(b*400|0)+392>>2]|0;if((a|0)==0){h=-2147483648;i=0;return(F=h,i)|0}j=$Gb(d|0,e|0,c[a>>2]|0)|0;k=c[a+4>>2]|0;l=k&d;d=((k|0)<0|0?-1:0)&e;e=YGb((c[a+8>>2]|0)>>>0<197121>>>0|0,0,j,F)|0;if((l|0)==0&(d|0)==0){j=g+(b*400|0)+20|0;c[j>>2]=c[j>>2]|1}j=YGb(e,F,l,d)|0;d=F;if((f|0)==0){h=d;i=j;return(F=h,i)|0}c[f>>2]=j;c[f+4>>2]=d;h=d;i=j;return(F=h,i)|0}function eN(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;h=i;i=i+72|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;r=h+64|0;s=f+g|0;if((g|0)<8){t=-1094995529;i=h;return t|0}g=f;u=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=s;if((-4-(f+4)+g|0)<(u|0)|(u|0)<0){t=-1094995529;i=h;return t|0}v=f+(u+8)|0;w=f+(u+4)|0;u=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=(u|0)==0;a:do{if((g-v|0)<4|w){x=v;y=u;z=w}else{f=b;A=p;B=q;C=r;D=(e|0)==0;E=o|0;F=o+4|0;G=b+1132|0;H=b+1136|0;I=v;J=u;b:while(1){K=I+4|0;L=I;M=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;L=K;if((g-L|0)<(M|0)|(M|0)<0){x=K;y=J;z=0;break a}N=I+(M+4)|0;O=J-1|0;P=Ib(K|0,61,M|0)|0;c:do{if((P|0)!=0){Q=P-L|0;R=M-Q|0;S=R-1|0;T=P+1|0;if((P|0)==(K|0)|(S|0)==0){break}U=WDb(Q+1|0)|0;c[p>>2]=U;V=WDb(R)|0;c[q>>2]=V;if((U|0)==0|(V|0)==0){break b}else{W=0;X=U}do{U=a[I+(W+4)|0]|0;a[X+W|0]=((U<<24>>24)-97|0)>>>0<26>>>0?U^32:U;W=W+1|0;X=c[p>>2]|0}while(W>>>0<Q>>>0);a[X+Q|0]=0;UGb(c[q>>2]|0,T|0,S)|0;a[(c[q>>2]|0)+S|0]=0;U=c[p>>2]|0;if((QGb(U,1923584)|0)==0){V=WDb(S)|0;c[r>>2]=V;if((V|0)==0){yDb(f,24,2221728,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;$Db(A);$Db(B);break}R=GAb(V,c[q>>2]|0,S)|0;if((R|0)>0){Z=fX(b,V,R)|0}else{Z=R}$Db(A);$Db(B);$Db(C);if((Z|0)>=0){break}yDb(f,24,2134528,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;break}R=c[q>>2]|0;V=SGb(U|0)|0;d:do{if((V|0)>=9){_=xd(U|0,1901944,(Y=i,i=i+8|0,c[Y>>2]=j,Y)|0)|0;i=Y;if((_|0)!=1){break}if((V|0)<11){_=xd(R|0,1882048,(Y=i,i=i+32|0,c[Y>>2]=k,c[Y+8>>2]=l,c[Y+16>>2]=m,c[Y+24>>2]=n,Y)|0)|0;i=Y;if((_|0)<4){break}_=c[j>>2]|0;c[E>>2]=1;c[F>>2]=1e3;$=((((((c[k>>2]|0)*60|0)+(c[l>>2]|0)|0)*60|0)+(c[m>>2]|0)|0)*1e3|0)+(c[n>>2]|0)|0;OT(b,_,o,$,($|0)<0|0?-1:0,0,-2147483648,0)|0;ZDb(R)}else{if((QGb(U+(V-4)|0,2339864)|0)!=0){break}$=c[G>>2]|0;_=c[j>>2]|0;aa=0;while(1){if(!(aa>>>0<$>>>0)){break d}ba=c[(c[H>>2]|0)+(aa<<2)>>2]|0;if((c[ba>>2]|0)==(_|0)){break}else{aa=aa+1|0}}if((ba|0)==0){break}CBb(ba+32|0,2316064,R,8)|0}ZDb(U);break c}}while(0);do{if(!D){if((BBb(c[e>>2]|0,c[p>>2]|0,0,0)|0)==0){break}CBb(e,c[p>>2]|0,2070208,32)|0}}while(0);CBb(e,c[p>>2]|0,c[q>>2]|0,36)|0;$Db(B)}}while(0);K=(O|0)==0;if((g-N|0)<4|K){x=N;y=O;z=K;break a}else{I=N;J=O}}$Db(A);$Db(B);t=-12;i=h;return t|0}}while(0);if((x|0)!=(s|0)){yDb(b,32,2022520,(Y=i,i=i+8|0,c[Y>>2]=g-x,Y)|0);i=Y}if(!z){yDb(b,32,1979136,(Y=i,i=i+8|0,c[Y>>2]=y,Y)|0);i=Y}QG(e,0,1087448);t=0;i=h;return t|0}function fN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;h=c[c[b+12>>2]>>2]|0;j=h+(e*400|0)+12|0;k=h+(e*400|0)|0;l=a[(c[k>>2]|0)+(c[j>>2]|0)|0]|0;m=l&255;n=h+(e*400|0)+392|0;o=c[n>>2]|0;do{if((o|0)==0){p=cEb(336)|0;c[n>>2]=p;if((p|0)==0){q=-12}else{r=p;break}i=f;return q|0}else{r=o}}while(0);if((m&1|0)==0){q=0;i=f;return q|0}o=h+(e*400|0)+16|0;h=c[o>>2]|0;if((h|0)==0|(l&255)>>>0>5>>>0){q=-1094995529;i=f;return q|0}n=m>>>1;m=r+12|0;p=m+(n<<2)|0;if((c[p>>2]|0)!=0){q=-1094995529;i=f;return q|0}do{if((l&255)>>>0>1>>>0){if((c[m>>2]|0)==0){q=-1094995529;i=f;return q|0}if(!((l&255)>>>0>3>>>0)){break}if((c[r+16>>2]|0)==0){q=-1094995529}else{break}i=f;return q|0}}while(0);c[r+(n<<2)>>2]=h;h=cEb(c[o>>2]|0)|0;c[p>>2]=h;if((h|0)==0){q=-12;i=f;return q|0}UGb(h|0,(c[k>>2]|0)+(c[j>>2]|0)|0,c[o>>2]|0)|0;h=c[j>>2]|0;j=c[k>>2]|0;k=a[j+h|0]|0;if((k<<24>>24|0)==3){if(!((iN(b,e)|0)>-1)){q=1;i=f;return q|0}e=r+16|0;p=c[e>>2]|0;n=p+7|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+16|0;if(!(l>>>0<4294967280>>>0)){q=1;i=f;return q|0}if(!(n>>>0<(c[o>>2]|0)>>>0)){q=1;i=f;return q|0}s=p+(l+11)|0;x=0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;a[(c[e>>2]|0)+(l+15)|0]=1;c[r+4>>2]=n;q=1;i=f;return q|0}else if((k<<24>>24|0)==1){if((c[o>>2]|0)!=30){q=-1094995529;i=f;return q|0}o=j+(h+7)|0;if((d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)!=0){q=-1094995529;i=f;return q|0}o=d[j+(h+11)|0]|0;k=c[g+8>>2]|0;n=k+416|0;l=c[n>>2]|0;if(!((l|0)==0|(o|0)==(l|0))){yDb(b,16,1923808,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;q=-1163346256;i=f;return q|0}c[n>>2]=o;o=j+(h+12)|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(h+20)|0;c[k+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=a[j+(h+28)|0]|0;b=o&255;l=b&15;if(l>>>0>b>>>4>>>0){q=-1094995529;i=f;return q|0}if(l>>>0<6>>>0|(o&255)>>>0>223>>>0){q=-1094995529;i=f;return q|0}if((a[j+(h+29)|0]|0)!=1){q=-1094995529;i=f;return q|0}c[k+8>>2]=1;c[k+48>>2]=86021;if((n|0)<=0){q=1;i=f;return q|0}c[k+412>>2]=n;MT(g,64,1,n);q=1;i=f;return q|0}else{n=g+8|0;g=(c[n>>2]|0)+96|0;k=r;h=r+4|0;j=r+8|0;o=(c[h>>2]|0)+(c[k>>2]|0)+(c[j>>2]|0)|0;l=((o|0)/255|0)+64+o|0;o=XDb(0,l)|0;c[g>>2]=o;do{if((o|0)==0){t=-12;u=(c[n>>2]|0)+100|0}else{TGb(o|0,0,l|0)|0;a[o]=2;b=(P0a(o+1|0,c[k>>2]|0)|0)+1|0;e=(P0a(o+b|0,c[h>>2]|0)|0)+b|0;UGb(o+e|0,c[m>>2]|0,c[k>>2]|0)|0;b=(c[k>>2]|0)+e|0;$Db(m);e=r+16|0;UGb(o+b|0,c[e>>2]|0,c[h>>2]|0)|0;s=(c[h>>2]|0)+b|0;$Db(e);e=r+20|0;UGb(o+s|0,c[e>>2]|0,c[j>>2]|0)|0;b=(c[j>>2]|0)+s|0;$Db(e);e=_Db(g,b+16|0)|0;s=(e|0)<0?e:b;b=c[n>>2]|0;e=b+100|0;if((s|0)<0){t=s;u=e;break}c[e>>2]=s;s=d4a(b,r+24|0)|0;if((s|0)==0){q=1;i=f;return q|0}$Db((c[n>>2]|0)+96|0);c[(c[n>>2]|0)+100>>2]=0;q=s;i=f;return q|0}}while(0);c[u>>2]=0;q=t;i=f;return q|0}return 0}function gN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+8|0;f=e|0;g=c[c[b+12>>2]>>2]|0;h=g+(d*400|0)|0;j=c[g+(d*400|0)+392>>2]|0;c[f>>2]=0;k=g+(d*400|0)+48|0;l=c[k>>2]|0;m=c[k+4>>2]|0;do{if((l|0)==0&(m|0)==0|(l|0)==0&(m|0)==(-2147483648|0)){if((c[g+(d*400|0)+80>>2]&4|0)!=0){break}n=g+(d*400|0)+32|0;o=c[n+4>>2]|0;p=-1;if(!((o|0)>(p|0)|(o|0)==(p|0)&(c[n>>2]|0)>>>0>-1>>>0)){break}p=c[h>>2]|0;o=c[g+(d*400|0)+12>>2]|0;q=j+24|0;f4a(q);r=c[g+(d*400|0)+96>>2]|0;s=e4a(q,p+o|0,1,f)|0;if((s|0)<0){t=g+(d*400|0)+20|0;c[t>>2]=c[t>>2]|2;i=e;return 0}if((c[f>>2]&2|0)!=0){iN(b,d)|0;c[f>>2]=0}t=p+((c[g+(d*400|0)+16>>2]|0)+o)|0;o=g+(d*400|0)+92|0;p=c[o>>2]|0;a:do{if((r|0)<(p|0)){u=r;v=s;w=t;x=t;y=p;while(1){z=g+(d*400|0)+100+u|0;if((a[z]|0)==-1){A=w;B=v;C=255;D=y}else{E=e4a(q,w,1,f)|0;if((E|0)<0){break}if((c[f>>2]&2|0)!=0){iN(b,d)|0;c[f>>2]=0}G=a[z]|0;A=x+(G&255)|0;B=E+v|0;C=G&255;D=c[o>>2]|0}G=u+1|0;if((G|0)<(D|0)){u=G;v=B;w=A;x=x+C|0;y=D}else{H=B;I=16;break a}}y=c[n>>2]|0;J=y;K=c[n+4>>2]|0;L=y}else{H=s;I=16}}while(0);if((I|0)==16){J=H;K=c[n+4>>2]|0;L=c[n>>2]|0}s=ZGb(L,K,J,(J|0)<0|0?-1:0)|0;o=F;p=g+(d*400|0)+56|0;c[p>>2]=s;c[p+4>>2]=o;c[k>>2]=s;c[k+4>>2]=o;p=c[(c[b+28>>2]|0)+(d<<2)>>2]|0;t=p+48|0;do{if((c[t>>2]|0)==0&(c[t+4>>2]|0)==(-2147483648|0)){r=0;y=(o|0)>(r|0)|(o|0)==(r|0)&s>>>0>0>>>0;r=y?s:0;x=y?o:0;c[t>>2]=r;c[t+4>>2]=x;y=p+56|0;w=c[y>>2]|0;v=c[y+4>>2]|0;if((w|0)==0&(v|0)==(-2147483648|0)){break}u=ZGb(w,v,r,x)|0;c[y>>2]=u;c[y+4>>2]=F}}while(0);p=j+320|0;c[p>>2]=0;c[p+4>>2]=-2147483648;f4a(q)}}while(0);if((c[g+(d*400|0)+16>>2]|0)!=0){J=e4a(j+24|0,(c[h>>2]|0)+(c[g+(d*400|0)+12>>2]|0)|0,1,f)|0;if((J|0)<0){h=g+(d*400|0)+20|0;c[h>>2]=c[h>>2]|2;i=e;return 0}if((c[f>>2]&2|0)!=0){iN(b,d)|0;c[f>>2]=0}c[g+(d*400|0)+24>>2]=J}if((c[g+(d*400|0)+80>>2]&4|0)==0){i=e;return 0}J=c[k>>2]|0;f=c[k+4>>2]|0;if(!((J|0)==0&(f|0)==(-2147483648|0))){k=j+320|0;c[k>>2]=J;c[k+4>>2]=f;c[j+328>>2]=0}if((c[g+(d*400|0)+96>>2]|0)==(c[g+(d*400|0)+92>>2]|0)){f=g+(d*400|0)+32|0;k=j+320|0;J=ZGb(c[f>>2]|0,c[f+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;k=j+328|0;f=ZGb(J,F,c[k>>2]|0,0)|0;J=f;c[g+(d*400|0)+24>>2]=J;M=J;N=k}else{M=c[g+(d*400|0)+24>>2]|0;N=j+328|0}c[N>>2]=(c[N>>2]|0)+M;i=e;return 0}function hN(a,b){a=a|0;b=b|0;var d=0;d=c[(c[c[a+12>>2]>>2]|0)+(b*400|0)+392>>2]|0;if((d|0)==0){return}$Db(d+12|0);$Db(d+16|0);$Db(d+20|0);return}function iN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[c[a+12>>2]>>2]|0;e=d+(b*400|0)+16|0;if((c[e>>2]|0)>>>0<9>>>0){f=0;return f|0}g=(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+88|0;DBb(g);h=eN(a,g,(c[d+(b*400|0)>>2]|0)+((c[d+(b*400|0)+12>>2]|0)+7)|0,(c[e>>2]|0)-8|0)|0;if((h|0)<0){f=h;return f|0}e=d+(b*400|0)+384|0;$Db(e);a=c[g>>2]|0;if((a|0)==0){c[e>>2]=WDb(1)|0;c[d+(b*400|0)+388>>2]=0;f=h;return f|0}else{c[e>>2]=KZ(a,d+(b*400|0)+388|0)|0;f=h;return f|0}return 0}function jN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=c[c[b+12>>2]>>2]|0;h=c[g+(e*400|0)>>2]|0;j=c[g+(e*400|0)+12>>2]|0;k=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;l=c[g+(e*400|0)+16>>2]|0;if(l>>>0<7>>>0){m=0;i=f;return m|0}if((a[h+j|0]|0)!=79){m=0;i=f;return m|0}e=d[h+(j+5)|0]|0;if((e|0)==2){if((a[h+(j+6)|0]|0)!=32){m=-1094995529;i=f;return m|0}eN(b,k+88|0,h+(j+7)|0,l-7|0)|0;m=1;i=f;return m|0}else if((e|0)==1){if(l>>>0<26>>>0){yDb(b,16,2221608,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=f;return m|0}l=a[h+(j+6)|0]|0;if(l<<24>>24==1){g=h+(j+8)|0;o=(de((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;g=k+8|0;p=c[g>>2]|0;c[p+120>>2]=o;o=h+(j+10)|0;c[p+124>>2]=(de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;c[k+80>>2]=d[h+(j+13)|0]<<8|d[h+(j+12)|0]<<16|d[h+(j+14)|0];c[k+84>>2]=d[h+(j+16)|0]<<8|d[h+(j+15)|0]<<16|d[h+(j+17)|0];o=h+(j+18)|0;p=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=h+(j+22)|0;MT(k,64,fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0,p);p=c[g>>2]|0;c[p+8>>2]=0;c[p+48>>2]=141;c[k+236>>2]=2;m=1;i=f;return m|0}else{k=d[h+(j+7)|0]|0;yDb(b,24,2134448,(n=i,i=i+16|0,c[n>>2]=l&255,c[n+8>>2]=k,n)|0);i=n;m=-1094995529;i=f;return m|0}}else{yDb(b,16,2070152,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;m=-1094995529;i=f;return m|0}return 0}function kN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=c[c[b+12>>2]>>2]|0;g=c[f+(e*400|0)>>2]|0;h=c[f+(e*400|0)+12>>2]|0;i=g+h|0;j=f+(e*400|0)+48|0;k=c[j>>2]|0;l=c[j+4>>2]|0;do{if((k|0)==0&(l|0)==0|(k|0)==0&(l|0)==(-2147483648|0)){if((c[f+(e*400|0)+80>>2]&4|0)!=0){break}m=c[f+(e*400|0)+96>>2]|0;n=(d[i]|0)>>>4&1;o=g+((c[f+(e*400|0)+16>>2]|0)+h)|0;p=c[f+(e*400|0)+92>>2]|0;if((m|0)<(p|0)){q=m;m=n;r=o;s=o;while(1){o=a[f+(e*400|0)+100+q|0]|0;t=o&255;if(o<<24>>24==-1){u=r;v=m;w=s+t|0}else{o=s+t|0;u=o;v=((d[r]|0)>>>4&1)+m|0;w=o}o=q+1|0;if((o|0)<(p|0)){q=o;m=v;r=u;s=w}else{x=v;break}}}else{x=n}s=f+(e*400|0)+32|0;r=c[s+4>>2]|0;if((c[s>>2]&1073741816|0)==0&(r&0|0)==0){s=f+(e*400|0)+20|0;c[s>>2]=c[s>>2]|1}s=ZGb(r,0,x,(x|0)<0|0?-1:0)|0;r=F;m=f+(e*400|0)+56|0;c[m>>2]=s;c[m+4>>2]=r;c[j>>2]=s;c[j+4>>2]=r;m=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;q=m+48|0;if(!((c[q>>2]|0)==0&(c[q+4>>2]|0)==(-2147483648|0))){break}c[q>>2]=s;c[q+4>>2]=r;q=m+56|0;m=c[q>>2]|0;p=c[q+4>>2]|0;if((m|0)==0&(p|0)==0){break}o=ZGb(m,p,s,r)|0;c[q>>2]=o;c[q+4>>2]=F}}while(0);if((c[f+(e*400|0)+16>>2]|0)==0){return 0}c[f+(e*400|0)+24>>2]=(d[i]|0)>>>4&1;return 0}function lN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=e;h=0;if((d&1073741816|0)==0&(e&0|0)==0){e=(c[c[a+12>>2]>>2]|0)+(b*400|0)+20|0;c[e>>2]=c[e>>2]|1}if((f|0)==0){return(F=h,g)|0}c[f>>2]=g;c[f+4>>2]=h;return(F=h,g)|0}function mN(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[b+4>>2]|0;e=b+8|0;do{if((c[e>>2]|0)>9){if((vE(d,2070096)|0)==0){f=0;break}f=wE(d)|0}else{f=0}}while(0);b=f+5|0;if((c[e>>2]|0)>>>0<b>>>0){g=(f|0)!=0?25:0;return g|0}do{if((PGb(d+f|0,2134632,3)|0)==0){if((a[d+(f+4)|0]|0)!=0){break}if((a[d+b|0]|0)==96){g=100}else{break}return g|0}}while(0);g=0;return g|0}function nN(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;g=i;i=i+176|0;h=g|0;j=g+40|0;k=g+48|0;l=g+64|0;m=g+160|0;n=g+168|0;c[m>>2]=0;o=f+12|0;p=c[o>>2]|0;yE(f,2070096,m);q=f+16|0;r=l|0;if((mz(c[q>>2]|0,r,96)|0)<96){s=-1;i=g;return s|0}t=n|0;a[t]=69;a[n+1|0]=65;a[n+2|0]=51;do{if((PGb(r,t,3)|0)==0){if((a[l+4|0]|0)!=0){break}if((a[l+5|0]|0)!=96){break}n=Ty(c[q>>2]|0,0,0,1)|0;u=p;c[u>>2]=n;c[u+4>>2]=F;u=l+6|0;n=de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;a:do{if(!((n<<16>>16|0)==(-1|0)|(n<<16>>16|0)==(-128|0))){u=c[m>>2]|0;v=j;w=k;y=k|0;z=c[o>>2]|0;c[z+8>>2]=1;A=f;yDb(A,32,1882024,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;b:do{if((u|0)==0){C=13}else{D=u;c:while(1){do{if((QGb(c[D>>2]|0,2339848)|0)==0){E=c[D+4>>2]|0;if((E|0)==0){break}G=c[E+12>>2]|0;if((QGb(G,2316016)|0)==0){break c}if((QGb(G,2295016)|0)==0){break c}}}while(0);G=c[D+8>>2]|0;if((G|0)==0){C=13;break b}else{D=G}}D=E;G=c[D>>2]|0;if(G>>>0<64>>>0){yDb(A,16,2263016,(B=i,i=i+8|0,c[B>>2]=G,B)|0);i=B;break}G=c[E+16>>2]|0;H=G;if(!((d[H]|d[H+1|0]<<8)<<16>>16<<16>>16==256)){yDb(A,24,2248096,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}H=G+2|0;I=de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0;H=z+12|0;b[H>>1]=I;J=G+4|0;K=de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0;J=z+14|0;b[J>>1]=K;L=G+6|0;M=de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0;L=z+16|0;b[L>>1]=M;N=G+8|0;b[z+18>>1]=de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0;if((PGb(G+16|0,2235200,12)|0)!=0){yDb(A,16,2221872,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}N=c[D>>2]|0;if(((I&65535)+24+(K&65535)+(M&65535)|0)>>>0>N>>>0|N>>>0<64>>>0){yDb(A,16,2212792,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}N=G+44|0;M=fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0;c[z+20>>2]=M;yDb(A,48,2203424,(B=i,i=i+8|0,c[B>>2]=M,B)|0);i=B;M=z+104|0;N=l+88|0;K=M;I=N|0;O=N+4|0;N=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=K|0;x=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;O=K+4|0;x=N;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;O=h|0;if((zDb()|0)>=48){ZT(O,M,8,1)|0;a[h+16|0]=0;yDb(A,48,2140664,(B=i,i=i+16|0,c[B>>2]=2196016,c[B+8>>2]=O,B)|0);i=B}M=b[H>>1]|0;H=b[J>>1]|0;J=b[L>>1]|0;if((zDb()|0)>=48){ZT(O,G+((M&65535)+16+(H&65535)+(J&65535))|0,8,1)|0;a[h+16|0]=0;yDb(A,48,2140664,(B=i,i=i+16|0,c[B>>2]=2181912,c[B+8>>2]=O,B)|0);i=B}J=c[f+1100>>2]|0;do{if((J|0)>0){H=c[f+1096>>2]|0;M=c[o>>2]|0;L=(H|0)!=0;N=(H|0)==0;if(N&(L^1)){break}K=(J|0)>16?16:J;if(L){L=M+24|0;if((L|0)!=(H|0)){TGb(L|0,0,24)|0;UGb(L|0,H|0,K)|0}L=H;I=M+40|0;P=L|0;Q=L+4|0;L=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=I|0;x=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=I+4|0;x=L;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x}if(N){break}N=M+48|0;if((N|0)!=(H|0)){TGb(N|0,0,24)|0;UGb(N|0,H|0,K)|0}K=H;H=M+64|0;M=K|0;N=K+4|0;K=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;N=H|0;x=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;N=H+4|0;x=K;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x}}while(0);J=z+24|0;c[j>>2]=0;c[j+4>>2]=0;do{if((PGb(J,v,8)|0)==0){R=z+48|0;C=40}else{if((qN(c[o>>2]|0,G,c[D>>2]|0,J)|0)>=0){break}N=z+48|0;if((rN(f,G,c[D>>2]|0,N)|0)<0){R=N;C=40}}}while(0);do{if((C|0)==40){N=k+8|0;K=0;while(1){if(!(K>>>0<6>>>0)){break}H=857928+(K<<3)|0;M=c[H>>2]|0;Q=c[H+4>>2]|0;c[y>>2]=M;c[y+4>>2]=Q;H=857928+((K|1)<<3)|0;L=c[H+4>>2]|0;c[N>>2]=c[H>>2];c[N+4>>2]=L;L=c[o>>2]|0;H=L+24|0;if((H|0)==(w|0)){S=Q;T=M}else{TGb(H|0,0,24)|0;UGb(H|0,w|0,16)|0;S=c[y+4>>2]|0;T=c[y>>2]|0}H=L+40|0;M=H|0;x=T;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;M=H+4|0;x=S;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;M=L+48|0;if((M|0)!=(w|0)){TGb(M|0,0,24)|0;UGb(M|0,w|0,16)|0}M=L+64|0;L=c[y+4>>2]|0;H=M|0;x=c[y>>2]|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=M+4|0;x=L;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;if((qN(c[o>>2]|0,G,c[D>>2]|0,J)|0)==0){C=48;break}if((rN(f,G,c[D>>2]|0,R)|0)==0){C=48;break}else{K=K+2|0}}if((C|0)==48){if(!(K>>>0>5>>>0)){break}}yDb(A,16,2168264,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}}while(0);D=z+112|0;vBb(D,z+72|0,64,0)|0;J=z+96|0;wBb(D,J,G+56|0,1,0,0);if((zDb()|0)>=48){ZT(O,J,8,1)|0;a[h+16|0]=0;yDb(A,48,2140664,(B=i,i=i+16|0,c[B>>2]=2160840,c[B+8>>2]=O,B)|0);i=B}vBb(D,J,64,1)|0;break a}}while(0);if((C|0)==13){yDb(A,16,2278456,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}zE(m);s=-1;i=g;return s|0}}while(0);zE(m);n=a[l+33|0]|0;z=d[l+34|0]|0;y=z<<8|(n&255)<<16|d[l+35|0];w=LT(f,0)|0;if((w|0)==0){s=-12;i=g;return s|0}v=w+48|0;c[v>>2]=0;c[v+4>>2]=0;v=w+8|0;u=c[v>>2]|0;c[u+8>>2]=1;J=l+32|0;D=d[J]|0;c[u+52>>2]=D;u=vT(1167112,D)|0;D=c[v>>2]|0;c[D+48>>2]=u;N=d[J]|0;do{if((N|0)==1){J=z>>>2&7;if((J|0)==0){yDb(f,16,1923720,(B=i,i=i+8|0,c[B>>2]=0,B)|0);i=B;s=-1094995529;i=g;return s|0}H=J-1|0;J=1167184+(H<<3)|0;L=c[J+4>>2]|0;M=D+448|0;c[M>>2]=c[J>>2];c[M+4>>2]=L;c[D+416>>2]=c[1167152+(H<<2)>>2];H=(y<<3&8184)+8|0;L=(e[1166928+(z>>>5<<1)>>1]|0)*100|0;if((L|0)!=0){c[D+412>>2]=L;c[D+72>>2]=(ba(H<<3,L)|0)/2048|0;MT(w,64,1,L);U=H;break}yDb(f,16,1979008,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;s=-1094995529;i=g;return s|0}else if((N|0)==3){c[w+236>>2]=1463898624;U=1024}else if((N|0)==4){c[D+416>>2]=2;H=D+448|0;c[H>>2]=3;c[H+4>>2]=0;c[D+412>>2]=44100;c[D+72>>2]=1411200;H=u0a(u)|0;L=c[v>>2]|0;c[L+792>>2]=H;MT(w,64,1,c[L+412>>2]|0);U=1024}else if((N|0)==0){L=(e[1166928+(z>>>5<<1)>>1]|0)*100|0;if((L|0)==44100){V=D}else if((L|0)==0){yDb(f,16,1979008,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;s=-1094995529;i=g;return s|0}else{DDb(f,1949256,(B=i,i=i+8|0,c[B>>2]=L,B)|0);i=B;V=c[v>>2]|0}H=y<<3&8184;c[V+416>>2]=2;M=V+448|0;c[M>>2]=3;c[M+4>>2]=0;c[V+412>>2]=L;c[V+72>>2]=(ba(H<<3,L)|0)/1024|0;if((BT(V,14)|0)==0){M=c[(c[v>>2]|0)+96>>2]|0;J=M;x=1;a[J]=x;x=x>>8;a[J+1|0]=x;J=M+2|0;x=L;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;J=(n&255)>>>1&1;L=M+6|0;x=J;a[L]=x;x=x>>8;a[L+1|0]=x;L=M+8|0;x=J;a[L]=x;x=x>>8;a[L+1|0]=x;L=M+10|0;x=1;a[L]=x;x=x>>8;a[L+1|0]=x;MT(w,64,1,c[(c[v>>2]|0)+412>>2]|0);U=H;break}else{s=-12;i=g;return s|0}}else{yDb(f,16,1901920,(B=i,i=i+8|0,c[B>>2]=N,B)|0);i=B;s=-38;i=g;return s|0}}while(0);c[(c[v>>2]|0)+432>>2]=U;s=0;i=g;return s|0}}while(0);yDb(f,16,2022360,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;s=-1094995529;i=g;return s|0}function oN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[b+12>>2]|0;f=c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+432>>2]|0;g=TS(c[b+16>>2]|0,d,f)|0;if((g|0)<(f|0)){b=d+36|0;c[b>>2]=c[b>>2]|2}if((g|0)<0){h=g;return h|0}if((g|0)==0){h=-541478725;return h|0}c[d+32>>2]=0;if((c[e+8>>2]|0)==0){h=g;return h|0}if((g|0)==(f|0)){b=c[d+24>>2]|0;wBb(e+112|0,b,b,f>>3,e+104|0,1);h=f;return h|0}else{f=e+104|0;e=f|0;x=0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=f+4|0;x=0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;h=g;return h|0}return 0}function pN(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c[b+12>>2]|0;i=EN(b,d,e,f,g)|0;if((c[h+8>>2]|0)==0){j=i;return j|0}do{if((i|0)==0){g=b+16|0;f=Ty(c[g>>2]|0,0,0,1)|0;e=F;d=h;k=c[d+4>>2]|0;if(e>>>0<k>>>0|e>>>0==k>>>0&f>>>0<(c[d>>2]|0)>>>0){l=0;break}d=Ty(c[g>>2]|0,-8,-1,1)|0;f=d;if((f|0)<0){l=f;break}f=mz(c[g>>2]|0,h+104|0,8)|0;if((f|0)<8){l=(f|0)>-1?-541478725:f;break}else{j=0;return j|0}}else{l=i}}while(0);i=h+104|0;h=i|0;x=0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=i+4|0;x=0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;j=l;return j|0}function qN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+392|0;g=f|0;if((b|0)==0|(d|0)==0){h=-1;i=f;return h|0}j=a+12|0;k=a+14|0;l=a+16|0;if(((e[j>>1]|0)+16+(e[k>>1]|0)+(e[l>>1]|0)|0)>>>0>c>>>0|c>>>0<49>>>0){h=-1;i=f;return h|0}vBb(g,d,192,1)|0;d=a+72|0;wBb(g,d,b+48|0,1,0,1);vBb(g,d,64,0)|0;d=a+80|0;wBb(g,d,0,1,0,0);c=(e[j>>1]|0)+16+(e[k>>1]|0)|0;vBb(g,d,64,0)|0;d=a+88|0;yBb(g,d,b+c|0,(e[l>>1]|0)>>>3);h=((PGb(b+((e[l>>1]|0)+c)|0,d,8)|0)!=0)<<31>>31;i=f;return h|0}function rN(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;j=i;i=i+392|0;k=j|0;l=b+12|0;m=c[l>>2]|0;if((f|0)==0|(h|0)==0){n=-1;i=j;return n|0}o=e[m+12>>1]|0;if((o+20|0)>>>0>g>>>0){n=-1;i=j;return n|0}p=o+16|0;o=p;q=0;r=(PGb(f+p|0,2154160,4)|0)==0;p=YGb(o,q,32,0)|0;s=r?p:o;o=r?F:q;q=g;r=0;p=YGb(s,o,44,0)|0;t=F;if(r>>>0<t>>>0|r>>>0==t>>>0&q>>>0<p>>>0){n=-1;i=j;return n|0}p=f+s|0;t=fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if((t|0)!=(c[m+20>>2]|0)){yDb(b,48,2146936,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b}b=YGb(s,o,32,0)|0;t=f+b|0;b=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=YGb(s,o,36,0)|0;p=f+t|0;t=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)>>>4;p=YGb(b+44|0,0,s,o)|0;o=F;s=t;b=YGb(s<<4|0>>>28,0<<4|s>>>28,p,o)|0;s=F;if(s>>>0>r>>>0|s>>>0==r>>>0&b>>>0>q>>>0){n=-1;i=j;return n|0}vBb(k,h,192,1)|0;h=m+24|0;q=h;if((h|0)==0){b=t;r=o;s=p;while(1){if((b|0)==0){n=-1;u=14;break}wBb(k,0,f+s|0,2,0,1);v=(qN(c[l>>2]|0,f,g,0)|0)==0;w=YGb(s,r,16,0)|0;if(v){n=0;u=14;break}else{b=b-1|0;r=F;s=w}}if((u|0)==14){i=j;return n|0}}else{y=t;z=o;A=p}while(1){if((y|0)==0){n=-1;u=14;break}wBb(k,h,f+A|0,2,0,1);p=c[l>>2]|0;o=p+24|0;if((p|0)!=(m|0)){TGb(o|0,0,24)|0;UGb(o|0,h|0,16)|0}o=p+40|0;p=q|0;t=q+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=o+4|0;x=s;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(qN(c[l>>2]|0,f,g,h)|0)==0;s=YGb(A,z,16,0)|0;if(t){n=0;u=14;break}else{y=y-1|0;z=F;A=s}}if((u|0)==14){i=j;return n|0}return 0}function sN(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[(c[c[d+28>>2]>>2]|0)+8>>2]|0;g=f+412|0;h=0;while(1){j=b[1166928+(h<<1)>>1]|0;if(j<<16>>16==0){k=3;break}if(((j&65535)*100|0|0)==(c[g>>2]|0)){break}else{h=h+1|0}}if((k|0)==3){yDb(d,16,207e4,(l=i,i=i+8|0,c[l>>2]=c[g>>2],l)|0);i=l;m=-22;i=e;return m|0}sX(d,3,2022328)|0;g=d+16|0;Yy(c[g>>2]|0,3359045);Py(c[g>>2]|0,0);Py(c[g>>2]|0,96);az(c[g>>2]|0,65535);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);k=c[f+52>>2]|0;if((k|0)==1){Zy(c[g>>2]|0,h<<13|c[f+416>>2]<<10|((c[f+432>>2]|0)/8|0)-1|16777216)}else if((k|0)==0){if((c[f+416>>2]|0)!=2){yDb(d,16,1949200,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=e;return m|0}j=c[f+100>>2]|0;if((j|0)==14){n=(a[(c[f+96>>2]|0)+6|0]|0)!=0}else if((j|0)==10){n=(a[(c[f+96>>2]|0)+8|0]|0)==18}else{yDb(d,16,1923672,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=e;return m|0}Zy(c[g>>2]|0,(n&1)<<17|h<<13|((c[f+432>>2]|0)/8|0))}else{yDb(d,16,1901880,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;m=-22;i=e;return m|0}Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);Yy(c[g>>2]|0,0);m=0;i=e;return m|0}function tN(){var a=0,b=0,d=0,e=0;a=WDb(1336)|0;b=a;if((a|0)==0){d=b;return d|0}TGb(a|0,0,1336)|0;c[a>>2]=1781296;DEb(a);e=cEb(4)|0;c[a+1296>>2]=e;if((e|0)!=0){d=b;return d|0}bT(b);d=0;return d|0}function uN(){return 1781296}function vN(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;if((b|0)!=0){d=c[b>>2]|0;return d|0}b=c[a+8>>2]|0;if((b|0)==0){d=1885952;return d|0}d=c[b>>2]|0;return d|0}function wN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if((b|0)==0){d=c[a+12>>2]|0;if((d|0)==0){break}e=c[a+4>>2]|0;do{if((e|0)!=0){if((c[e+20>>2]|0)==0){break}else{f=d}return f|0}}while(0);e=c[a+8>>2]|0;if((e|0)==0){break}if((c[e+36>>2]|0)==0){break}else{f=d}return f|0}}while(0);e=c[a+16>>2]|0;do{if((e|0)!=0){if((c[e>>2]|0)==0){break}a=e;if((a|0)==(b|0)){break}else{f=a}return f|0}}while(0);f=0;return f|0}function xN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)==0){b=1075176;return b|0}else{d=0}while(1){e=PC(d)|0;if((e|0)==0){f=0;g=4;break}if((c[e+20>>2]|0)==(a|0)){h=e;g=6;break}else{d=e}}a:do{if((g|0)==4){while(1){g=0;d=QC(f)|0;if((d|0)==0){h=0;g=6;break a}if((c[d+36>>2]|0)==(a|0)){i=d;break}else{f=d;g=4}}}}while(0);b:do{if((g|0)==6){while(1){g=0;f=PC(h)|0;if((f|0)==0){i=0;break b}a=c[f+20>>2]|0;if((a|0)==0){h=f;g=6}else{b=a;break}}return b|0}}while(0);while(1){h=QC(i)|0;if((h|0)==0){b=0;g=10;break}a=c[h+36>>2]|0;if((a|0)==0){i=h}else{b=a;g=10;break}}if((g|0)==10){return b|0}return 0}function yN(a){a=a|0;return((c[a+4>>2]|0)==0?3:4)|0}function zN(a){a=a|0;var b=0;do{if((c[a+8>>2]|0)>>>0>54>>>0){if((PGb(c[a+4>>2]|0,2133744,55)|0)==0){b=100}else{break}return b|0}}while(0);b=0;return b|0}function AN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;Vy(f,132,0)|0;g=LT(a,0)|0;if((g|0)==0){h=-12;return h|0}i=g+48|0;c[i>>2]=0;c[i+4>>2]=0;i=rz(f)|0;j=d+8|0;c[j>>2]=i;k=i;i=0;l=g+56|0;c[l>>2]=k;c[l+4>>2]=i;l=g+64|0;c[l>>2]=k;c[l+4>>2]=i;Vy(f,4,0)|0;i=rz(f)|0;l=g+8|0;c[(c[l>>2]|0)+120>>2]=i;i=rz(f)|0;c[(c[l>>2]|0)+124>>2]=i;Vy(f,4,0)|0;i=c[l>>2]|0;c[i+8>>2]=0;c[i+52>>2]=0;c[i+48>>2]=1346455126;MT(g,64,1,10);g=LT(a,0)|0;if((g|0)==0){h=-12;return h|0}a=g+48|0;c[a>>2]=0;c[a+4>>2]=0;a=c[g+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=0;c[a+48>>2]=1346455105;c[a+416>>2]=2;i=a+448|0;c[i>>2]=3;c[i+4>>2]=0;c[a+412>>2]=22050;MT(g,64,1,22050);g=d;c[g>>2]=rz(f)|0;a=d+16|0;c[a>>2]=rz(f)|0;i=d+4|0;c[i>>2]=rz(f)|0;l=d+12|0;c[l>>2]=rz(f)|0;k=d+20|0;c[k>>2]=rz(f)|0;m=rz(f)|0;n=d+24|0;c[n>>2]=m;o=c[g>>2]|0;if(o>>>0<175>>>0|m>>>0<2>>>0){h=-1094995529;return h|0}p=c[k>>2]|0;if((p|0)==0){h=-1094995529;return h|0}q=c[i>>2]|0;if((q|0)==0){h=-1094995529;return h|0}r=c[j>>2]|0;if((r|0)==0){h=-1094995529;return h|0}if((c[a>>2]|0)==0|o>>>0>2048>>>0|p>>>0>2048>>>0|m>>>0>2048>>>0|r>>>0>536870911>>>0|q>>>0>536870911>>>0){h=-1094995529;return h|0}q=d+40|0;c[q>>2]=cEb(r<<2)|0;r=d+44|0;c[r>>2]=cEb(c[j>>2]<<2)|0;m=d+48|0;c[m>>2]=cEb(c[i>>2]<<2)|0;p=ba(c[g>>2]|0,c[k>>2]|0)|0;c[d+56>>2]=p;k=d+52|0;c[k>>2]=cEb(p)|0;p=ba(c[g>>2]|0,c[n>>2]|0)|0;n=d+68|0;c[n>>2]=p;o=d+60|0;c[o>>2]=cEb(p)|0;p=cEb(c[n>>2]|0)|0;c[d+64>>2]=p;do{if((c[q>>2]|0)!=0){if((c[r>>2]|0)==0){break}if((c[m>>2]|0)==0){break}if((c[k>>2]|0)==0){break}if((c[o>>2]|0)==0|(p|0)==0){break}Ty(f,c[g>>2]|0,0,0)|0;n=c[q>>2]|0;a=c[j>>2]|0;s=c[e>>2]|0;if((a|0)==0){t=s}else{u=0;v=s;while(1){c[n+(u<<2)>>2]=rz(v)|0;s=u+1|0;w=c[e>>2]|0;if(s>>>0<a>>>0){u=s;v=w}else{t=w;break}}}Vy(t,(a+511&1073741312)-a<<2,0)|0;v=c[r>>2]|0;u=c[j>>2]|0;n=c[e>>2]|0;if((u|0)==0){x=n}else{w=0;s=n;while(1){c[v+(w<<2)>>2]=rz(s)|0;n=w+1|0;y=c[e>>2]|0;if(n>>>0<u>>>0){w=n;s=y}else{x=y;break}}}Vy(x,(u+511&1073741312)-u<<2,0)|0;s=c[m>>2]|0;w=c[i>>2]|0;v=c[e>>2]|0;if((w|0)==0){z=v}else{a=0;y=v;while(1){c[s+(a<<2)>>2]=rz(y)|0;v=a+1|0;n=c[e>>2]|0;if(v>>>0<w>>>0){a=v;y=n}else{z=n;break}}}Vy(z,(w+511&1073741312)-w<<2,0)|0;c[d+72>>2]=0;c[d+28>>2]=0;c[d+36>>2]=0;Ty(f,c[l>>2]|0,0,0)|0;h=0;return h|0}}while(0);l=c[b>>2]|0;$Db(l+40|0);$Db(l+44|0);$Db(l+48|0);$Db(l+52|0);$Db(l+60|0);$Db(l+64|0);h=-12;return h|0}function BN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;b=e+28|0;if(!((c[b>>2]|0)>>>0<(c[e+8>>2]|0)>>>0)){g=-541478725;return g|0}if((Xy(f)|0)!=0){g=-541478725;return g|0}h=e+72|0;if((c[h>>2]|0)!=0){i=e+68|0;if((wZ(d,c[i>>2]|0)|0)<0){g=-12;return g|0}UGb(c[d+24>>2]|0,c[e+64>>2]|0,c[i>>2]|0)|0;c[d+48>>2]=((c[i>>2]|0)/4922|0)*2205|0;i=d+36|0;c[i>>2]=c[i>>2]|1;c[d+32>>2]=1;c[h>>2]=0;g=c[d+28>>2]|0;return g|0}i=c[b>>2]|0;if((i|0)==0){j=e+16|0}else{j=(c[e+40>>2]|0)+(i-1<<2)|0}k=c[j>>2]|0;do{if((k|0)==0){l=i;m=e+56|0}else{j=e+36|0;n=e+4|0;o=e+48|0;p=e+68|0;q=e;r=e+60|0;s=e+24|0;t=e+64|0;u=e+56|0;v=e+52|0;w=0;x=c[j>>2]|0;a:while(1){if(!(x>>>0<(c[n>>2]|0)>>>0)){g=-1094995529;y=26;break}z=c[(c[o>>2]|0)+(x<<2)>>2]|0;A=z&2147483647;do{if((z|0)<0){B=c[q>>2]|0;if(A>>>0>((c[p>>2]|0)-B|0)>>>0){g=-1094995529;y=26;break a}mz(f,(c[r>>2]|0)+A|0,B)|0;if((A|0)!=(ba((c[s>>2]|0)-2|0,c[q>>2]|0)|0)){break}UGb(c[t>>2]|0,c[r>>2]|0,c[p>>2]|0)|0;c[h>>2]=1}else{B=c[q>>2]|0;if(A>>>0>((c[u>>2]|0)-B|0)>>>0){g=-1094995529;y=26;break a}mz(f,(c[v>>2]|0)+A|0,B)|0}}while(0);A=(c[j>>2]|0)+1|0;c[j>>2]=A;z=w+1|0;if(z>>>0<k>>>0){w=z;x=A}else{y=20;break}}if((y|0)==20){l=c[b>>2]|0;m=u;break}else if((y|0)==26){return g|0}}}while(0);y=e+44|0;k=c[(c[y>>2]|0)+(l<<2)>>2]|0;l=c[m>>2]|0;if(!(k>>>0<l>>>0)){g=-1094995529;return g|0}m=l-k|0;if((wZ(d,m)|0)<0){g=-12;return g|0}c[d+32>>2]=0;c[d+48>>2]=1;k=d+24|0;UGb(c[k>>2]|0,(c[e+52>>2]|0)+(c[(c[y>>2]|0)+(c[b>>2]<<2)>>2]|0)|0,m)|0;if(!((a[c[k>>2]|0]&32)==0)){k=d+36|0;c[k>>2]=c[k>>2]|1}c[b>>2]=(c[b>>2]|0)+1;g=c[d+28>>2]|0;return g|0}function CN(a){a=a|0;var b=0;b=c[a+12>>2]|0;$Db(b+40|0);$Db(b+44|0);$Db(b+48|0);$Db(b+52|0);$Db(b+60|0);$Db(b+64|0);return 0}function DN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+432>>2]<<10;if((d|0)<1){e=-22;return e|0}f=TS(c[a+16>>2]|0,b,d)|0;d=b+36|0;c[d>>2]=c[d>>2]&-3;c[b+32>>2]=0;e=f;return e|0}function EN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[c[a+28>>2]>>2]|0;g=b+8|0;h=c[g>>2]|0;i=c[h+432>>2]|0;if((i|0)==0){j=u0a(c[h+48>>2]|0)|0;k=c[g>>2]|0;l=(ba(c[k+416>>2]|0,j)|0)>>3;m=k}else{l=i;m=h}h=c[m+72>>2]|0;if((h|0)==0){n=ba(c[m+412>>2]|0,l)|0}else{n=h>>3}if((l|0)<1|(n|0)<1){return-1|0}else{h=0;m=(e|0)<(h|0)|(e|0)==(h|0)&d>>>0<0>>>0;h=n;i=(n|0)<0|0?-1:0;n=gHb(h,i,m?0:d,m?0:e)|0;e=F;m=c[b+40>>2]|0;d=m;k=(m|0)<0|0?-1:0;m=c[b+44>>2]|0;j=m;g=(m|0)<0|0?-1:0;m=l;o=(l|0)<0|0?-1:0;l=gHb(j,g,m,o)|0;p=HDb(n,e,d,k,l,F,f&1^3)|0;f=gHb(p,F,m,o)|0;o=F;m=gHb(d,k,h,i)|0;i=IDb(f,o,j,g,m,F)|0;m=b+208|0;c[m>>2]=i;c[m+4>>2]=F;m=c[a+16>>2]|0;i=a+1248|0;a=YGb(c[i>>2]|0,c[i+4>>2]|0,f,o)|0;o=Ty(m,a,F,0)|0;a=F;m=0;return((a|0)<(m|0)|(a|0)==(m|0)&o>>>0<0>>>0?o:0)|0}return 0}function FN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+12>>2]|0;e=LT(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=e+8|0;h=c[g>>2]|0;c[h+8>>2]=1;j=c[(c[a+4>>2]|0)+28>>2]|0;c[h+48>>2]=j;c[h+412>>2]=c[d+4>>2];c[h+416>>2]=c[d+8>>2];d=u0a(j)|0;j=c[g>>2]|0;c[j+792>>2]=d;if((d|0)<=0){yDb(0,0,1947304,(g=i,i=i+24|0,c[g>>2]=1945376,c[g+8>>2]=1943744,c[g+16>>2]=53,g)|0);i=g;Cd();return 0}c[j+432>>2]=(ba(c[j+416>>2]|0,d)|0)/8|0;MT(e,64,1,c[j+412>>2]|0);f=0;i=b;return f|0}function GN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+24|0;d=c[a+4>>2]|0;a=xd(d|0,1978128,(e=i,i=i+24|0,c[e>>2]=b+8,c[e+8>>2]=b+16,c[e+16>>2]=b,e)|0)|0;i=e;do{if((a|0)==3){e=(hc(d|0,2068208)|0)+1|0;f=e+(hc(d+e|0,2068208)|0)|0;if((hc(d|0,2132040)|0)>>>0>f>>>0){g=100}else{break}i=b;return g|0}}while(0);g=0;i=b;return g|0}function HN(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+4112|0;e=d|0;f=d+8|0;g=d+16|0;h=c[b+12>>2]|0;j=LT(b,0)|0;if((j|0)==0){k=-12;i=d;return k|0}MT(j,64,1,10);l=c[j+8>>2]|0;c[l+8>>2]=3;c[l+48>>2]=1349012051;l=b+16|0;a:do{if((Xy(c[l>>2]|0)|0)==0){b=g|0;j=h;b:while(1){m=Ty(c[l>>2]|0,0,0,1)|0;n=F;if((wz(c[l>>2]|0,b,4096)|0)==0){o=j;break a}a[g+(hc(b|0,2132040)|0)|0]=0;p=xd(b|0,2021400,(q=i,i=i+16|0,c[q>>2]=e,c[q+8>>2]=f,q)|0)|0;i=q;do{if((p|0)==2){q=hc(b|0,2068208)|0;r=((a[g+q|0]|0)!=0)+q|0;q=g+r|0;s=c[e>>2]|0;t=c[e+4>>2]|0;u=ZGb(c[f>>2]|0,c[f+4>>2]|0,s,t)|0;if((s|0)==0&(t|0)==(-2147483648|0)){break}a[g+((hc(q|0,2068208)|0)+r)|0]=0;r=uR(j,q,SGb(q|0)|0,0)|0;if((r|0)==0){k=-12;break b}q=r+64|0;c[q>>2]=m;c[q+4>>2]=n;q=r+8|0;c[q>>2]=s;c[q+4>>2]=t;c[r+48>>2]=u}}while(0);if((Xy(c[l>>2]|0)|0)!=0){o=j;break a}}i=d;return k|0}else{o=h}}while(0);vR(o);k=0;i=d;return k|0}function IN(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function JN(a){a=a|0;AR(c[a+12>>2]|0);return 0}function KN(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function LN(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1836084592){e=b+4|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==1){f=100}else{break}return f|0}}while(0);f=0;return f|0}function MN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=Wy(e)|0;g=F;h=LT(a,0)|0;if((h|0)==0){j=-12;i=b;return j|0}k=h+8|0;c[(c[k>>2]|0)+8>>2]=0;Vy(e,8,0)|0;l=rz(e)|0;if((l|0)==1){c[(c[k>>2]|0)+48>>2]=28}else if((l|0)==0){c[(c[k>>2]|0)+48>>2]=13}else{yDb(a,16,2021344,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}l=rz(e)|0;n=rz(e)|0;c[(c[k>>2]|0)+120>>2]=n;n=rz(e)|0;c[(c[k>>2]|0)+124>>2]=n;n=rz(e)|0;MT(h,32,n,rz(e)|0);n=l;k=0;o=h+64|0;c[o>>2]=n;c[o+4>>2]=k;o=h+56|0;c[o>>2]=n;c[o+4>>2]=k;o=rz(e)|0;if((o|0)==0){p=86017}else if((o|0)==1){yDb(a,16,1978088,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;p=86018}else{yDb(a,16,1948640,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;p=0}o=d+4|0;c[o>>2]=(pz(e)|0)+1;Vy(e,10,0)|0;d=rz(e)|0;q=(rz(e)|0)+1|0;r=Ty(e,0,0,1)|0;s=YGb(r,F,n<<2|0>>>30,k<<2|n>>>30)|0;n=F;k=0;a:do{if((g|0)>(k|0)|(g|0)==(k|0)&f>>>0>0>>>0){r=0;t=n;u=s;while(1){if(!(r>>>0<l>>>0)){v=15;break a}w=rz(e)|0;if((Xy(e)|0)!=0){v=17;break a}x=w>>>1;if(x>>>0<((c[o>>2]<<2)+9|0)>>>0){v=19;break a}jT(h,u,t,r,0,x,0,w&1)|0;w=YGb(x,0,u,t)|0;x=F;if((r|0)==0&(x>>>0>g>>>0|x>>>0==g>>>0&w>>>0>f>>>0)){break}else{r=r+1|0;t=x;u=w}}yDb(a,16,1881464,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;j=-1094995529;i=b;return j|0}else{u=0;t=n;r=s;while(1){if(!(u>>>0<l>>>0)){v=15;break a}w=rz(e)|0;if((Xy(e)|0)!=0){v=17;break a}x=w>>>1;if(x>>>0<((c[o>>2]<<2)+9|0)>>>0){v=19;break a}jT(h,r,t,u,0,x,0,w&1)|0;w=YGb(x,0,r,t)|0;u=u+1|0;t=F;r=w}}}while(0);if((v|0)==15){if((c[o>>2]|0)>>>0>1>>>0){y=1}else{j=0;i=b;return j|0}while(1){h=LT(a,0)|0;if((h|0)==0){j=-12;v=24;break}e=c[h+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=p;c[e+416>>2]=q;c[e+412>>2]=d;MT(h,32,1,d);h=y+1|0;if(h>>>0<(c[o>>2]|0)>>>0){y=h}else{j=0;v=24;break}}if((v|0)==24){i=b;return j|0}}else if((v|0)==17){yDb(a,8,1923168,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;j=-1094995529;i=b;return j|0}else if((v|0)==19){yDb(a,16,1901584,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;j=-1094995529;i=b;return j|0}return 0}function NN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;if((Xy(f)|0)!=0){g=-541478725;i=d;return g|0}h=e;do{if((c[h>>2]|0)==0){j=lz(f)|0;c[e+8>>2]=j;if((j|0)==0){yDb(a,16,2131896,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;g=-1094995529;i=d;return g|0}l=(ba((c[e+4>>2]|0)-1|0,j)|0)+1|0;Vy(f,8,0)|0;j=e+12|0;c[j>>2]=0;m=e+16|0;n=m;o=e+20|0;kEb(m,o,l<<2);if((c[o>>2]|0)==0){yDb(a,16,2068136,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;g=-12;i=d;return g|0}else{if((l|0)>0){p=0}else{q=j;r=n;break}while(1){o=rz(f)|0;c[(c[n>>2]|0)+(p<<2)>>2]=o;o=p+1|0;if((o|0)<(l|0)){p=o}else{q=j;r=n;break}}}}else{q=e+12|0;r=e+16|0}}while(0);p=TS(f,b,c[(c[r>>2]|0)+(c[q>>2]<<2)>>2]|0)|0;if((p|0)>-1){r=c[h>>2]|0;if((r|0)==0){f=(c[c[a+28>>2]>>2]|0)+208|0;a=c[f>>2]|0;k=c[f+4>>2]|0;n=YGb(a,k,1,0)|0;c[f>>2]=n;c[f+4>>2]=F;f=b+16|0;c[f>>2]=a;c[f+4>>2]=k}c[b+32>>2]=r;s=0}else{s=p}p=c[q>>2]|0;if(((p|0)%(c[e+8>>2]|0)|0|0)==0){c[h>>2]=((c[h>>2]|0)+1|0)%(c[e+4>>2]|0)|0}c[q>>2]=p+1;g=s;i=d;return g|0}function ON(a){a=a|0;$Db((c[a+12>>2]|0)+16|0);return 0}function PN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[c[a+12>>2]>>2]=0;return-1|0}function QN(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[b+4>>2]|0;f=c[b+8>>2]|0;if((f|0)<2352){g=0;return g|0}b=e;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==1179011410){b=e+8|0;h=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==1096303683?e+44|0:e}else{h=e}b=e+f|0;a:do{if((b-h|0)>2351){f=0;e=0;i=h;while(1){if((PGb(i,399784,12)|0)!=0){g=0;j=17;break}if((d[i+17|0]|0)>>>0>31>>>0){g=0;j=17;break}k=a[i+18|0]&14;if((k|0)==8|(k|0)==2){l=i+30|0;m=(d[l]|d[l+1|0]<<8)<<16>>16;l=i+36|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;if(!((n|0)>-1)){g=0;j=17;break}l=i+28|0;if(!(((d[l]|d[l+1|0]<<8)<<16>>16&65535)>>>0<(m&65535)>>>0)){g=0;j=17;break}if(((m&65535)*2016|0|0)<(n|0)){g=0;j=17;break}o=e;p=f+1|0}else if((k|0)==4){if(!((a[i+19|0]&42)==0)){g=0;j=17;break}o=e+1|0;p=f}else if((k|0)==0){o=e;p=f}else{g=0;j=17;break}k=i+2352|0;if((b-k|0)>2351){f=p;e=o;i=k}else{q=p;r=o;break a}}if((j|0)==17){return g|0}}else{q=0;r=0}}while(0);j=r+q|0;if((j|0)>3){g=50;return g|0}g=(j|0)!=0|0;return g|0}function RN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+2352|0;d=b|0;e=c[a+16>>2]|0;f=c[a+12>>2]|0;if((mz(e,d,44)|0)!=44){g=-5;i=b;return g|0}h=(c[d>>2]|0)==1179011410;Ty(e,h?44:0,h?0:0,0)|0;h=f;f=0;do{c[h+(f*96|0)+88>>2]=-1;c[h+(f*96|0)>>2]=-1;f=f+1|0;}while((f|0)<32);f=a+20|0;c[f>>2]=c[f>>2]|1;g=0;i=b;return g|0}function SN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+2352|0;g=f|0;h=c[b+16>>2]|0;j=g|0;k=g+17|0;l=g+18|0;m=b;n=g+28|0;o=g+30|0;p=g+36|0;q=c[b+12>>2]|0;r=g+40|0;s=g+42|0;t=g+56|0;a:while(1){if((mz(h,j,2352)|0)!=2352){u=-5;v=28;break}w=a[k]|0;x=w&255;if((w&255)>>>0>31>>>0){u=-1094995529;v=28;break}w=d[l]|0;y=w&14;b:do{if((y|0)==8|(y|0)==2){z=(d[n]|d[n+1|0]<<8)<<16>>16;A=z&65535;B=(d[o]|d[o+1|0]<<8)<<16>>16;C=B&65535;D=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;do{if((D|0)>-1&(z&65535)>>>0<(B&65535)>>>0){E=C*2016|0;if((E|0)<(D|0)){break}G=q+(x*96|0)|0;if((c[G>>2]|0)<0){H=LT(b,0)|0;if((H|0)==0){u=-12;v=28;break a}MT(H,64,1,15);c[G>>2]=c[H>>2];I=c[H+8>>2]|0;c[I+8>>2]=0;c[I+48>>2]=38;c[I+52>>2]=0;c[I+120>>2]=(d[r]|d[r+1|0]<<8)<<16>>16&65535;c[I+124>>2]=(d[s]|d[s+1|0]<<8)<<16>>16&65535}J=q+(x*96|0)+8|0;K=q+(x*96|0)+36|0;L=q+(x*96|0)+32|0;if((c[K>>2]|0)!=(E|0)){if((c[L>>2]|0)!=0){yDb(m,16,2068040,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M}BZ(J);if((wZ(J,E)|0)!=0){u=-5;v=28;break a}TGb(c[L>>2]|0,0,E|0)|0;E=Ty(h,0,0,1)|0;I=YGb(E,F,-2352,-1)|0;E=q+(x*96|0)+72|0;c[E>>2]=I;c[E+4>>2]=F;c[q+(x*96|0)+40>>2]=c[G>>2]}UGb((c[L>>2]|0)+(A*2016|0)|0,t|0,2016)|0;if((A|0)==(C-1|0)){v=17;break a}else{break b}}}while(0);yDb(m,16,2131744,(M=i,i=i+24|0,c[M>>2]=A,c[M+8>>2]=C,c[M+16>>2]=D,M)|0);i=M}else if((y|0)==4){v=18;break a}else{yDb(m,24,2021256,(M=i,i=i+8|0,c[M>>2]=w,M)|0);i=M}}while(0);if((Xy(h)|0)!=0){u=-5;v=28;break}}if((v|0)==17){c[K>>2]=D;UGb(e|0,J|0,80)|0;c[L>>2]=0;c[K>>2]=-1;c[J>>2]=0;c[q+(x*96|0)+60>>2]=0;u=0;i=f;return u|0}else if((v|0)==18){J=q+(x*96|0)+88|0;if((c[J>>2]|0)<0){x=d[g+19|0]|0;q=LT(b,0)|0;if((q|0)==0){u=-12;i=f;return u|0}c[J>>2]=c[q>>2];b=c[q+8>>2]|0;c[b+8>>2]=1;c[b+48>>2]=69640;c[b+52>>2]=0;K=b+416|0;if((x&1|0)==0){c[K>>2]=1;L=b+448|0;c[L>>2]=4;c[L+4>>2]=0;N=1}else{c[K>>2]=2;K=b+448|0;c[K>>2]=3;c[K+4>>2]=0;N=2}K=(x&4|0)!=0?18900:37800;c[b+412>>2]=K;c[b+432>>2]=128;MT(q,64,4032/(N>>>0)|0,K);K=q+48|0;c[K>>2]=0;c[K+4>>2]=0}if((wZ(e,2304)|0)!=0){u=-5;i=f;return u|0}UGb(c[e+24>>2]|0,g+24|0,2304)|0;c[e+32>>2]=c[J>>2];c[e+48>>2]=1;u=0;i=f;return u|0}else if((v|0)==28){i=f;return u|0}return 0}function TN(a){a=a|0;var b=0;b=c[a+12>>2]|0;a=0;do{if((c[b+(a*96|0)+32>>2]|0)!=0){BZ(b+(a*96|0)+8|0)}a=a+1|0;}while((a|0)<32);return 0}function UN(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[b+4>>2]|0;f=e+6|0;g=de((d[f]|d[f+1|0]<<8)<<16>>16|0)|0;f=e;if(!((d[f]|d[f+1|0]<<8)<<16>>16<<16>>16==22081)){h=0;return h|0}f=a[e+2|0]|0;if(f<<24>>24==0|(f&255)>>>0>2>>>0){h=0;return h|0}if((a[e+4|0]|0)!=85){h=0;return h|0}f=(d[e+5|0]|0)>>>0>31>>>0|(g&65535)>>>0>6136>>>0;i=f?-1:(g&65535)+8|0;if(f){h=0;return h|0}do{if((c[b+8>>2]|0)>=(i+8|0)){f=e+(i+6)|0;g=de((d[f]|d[f+1|0]<<8)<<16>>16|0)|0;f=e+i|0;if(!((d[f]|d[f+1|0]<<8)<<16>>16<<16>>16==22081)){break}f=a[e+(i+2)|0]|0;if(f<<24>>24==0|(f&255)>>>0>2>>>0){break}if((a[e+(i+4)|0]|0)!=85){break}if((g&65535)>>>0<6137>>>0&(d[e+(i+5)|0]|0)>>>0<32>>>0){h=50}else{break}return h|0}}while(0);h=25;return h|0}function VN(a){a=a|0;var b=0,d=0,e=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=0;c[e+48>>2]=2;c[b+236>>2]=1;MT(b,32,1,9e4);jT(b,0,0,0,0,0,0,1)|0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86016;c[b+236>>2]=1;MT(b,33,1,9e4);jT(b,0,0,0,0,0,0,1)|0;d=0;return d|0}function WN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[a+16>>2]|0;if((YN(a,e,f,g,1)|0)<0){j=-5;i=d;return j|0}a=TS(h,b,c[f>>2]|0)|0;if((a|0)<1){j=-5;i=d;return j|0}c[b+32>>2]=(c[g>>2]|0)-1;g=c[e+4>>2]|0;f=b+8|0;c[f>>2]=c[e>>2];c[f+4>>2]=g;j=a;i=d;return j|0}function XN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=c[a+16>>2]|0;m=c[a+12>>2]|0;c[k>>2]=0;c[k+4>>2]=-2147483648;n=c[d>>2]|0;o=c[d+4>>2]|0;p=YGb(n,o,49088,0)|0;q=F;r=YGb(n,o,e,f)|0;f=F;e=q>>>0>f>>>0|q>>>0==f>>>0&p>>>0>r>>>0;s=e?r:p;p=e?f:q;q=m;if((o|0)<(p|0)|(o|0)==(p|0)&n>>>0<s>>>0){t=o;u=n}else{v=-2147483648;w=0;c[q>>2]=0;i=g;return(F=v,w)|0}while(1){c[k>>2]=0;c[k+4>>2]=-2147483648;Ty(l,u,t,0)|0;c[q>>2]=0;if((YN(a,k,h,j,0)|0)==0){if(((c[j>>2]|0)-1|0)==(b|0)){n=c[k>>2]|0;o=c[k+4>>2]|0;if(!((n|0)==0&(o|0)==(-2147483648|0))){v=o;w=n;x=9;break}}n=Ty(l,0,0,1)|0;o=c[h>>2]|0;m=YGb(o,(o|0)<0|0?-1:0,n,F)|0;y=F;z=m}else{m=YGb(c[d>>2]|0,c[d+4>>2]|0,1,0)|0;y=F;z=m}c[d>>2]=z;c[d+4>>2]=y;if((y|0)<(p|0)|(y|0)==(p|0)&z>>>0<s>>>0){t=y;u=z}else{break}}if((x|0)==9){c[q>>2]=0;i=g;return(F=v,w)|0}v=c[k+4>>2]|0;w=c[k>>2]|0;c[q>>2]=0;i=g;return(F=v,w)|0}function YN(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;j=i;i=i+256|0;k=j|0;l=c[b+16>>2]|0;m=(h|0)==0;h=c[b+12>>2]|0;n=b;a:do{if(m){o=Ty(l,0,0,1)|0;p=F;q=tz(l)|0;r=lz(l)|0;lz(l)|0;lz(l)|0;s=lz(l)|0;t=tz(l)|0;if((q|0)!=16726){u=-5;i=j;return u|0}if((r-1|0)>>>0>1>>>0|(t|0)>6136){u=-5;i=j;return u|0}if(!((r|0)!=1|(s&16|0)==0)){v=p;w=o;x=t;y=20;break}if((r|0)!=2){z=-2147483648;A=0;B=t;C=r;break}r=c[h>>2]|0;if((r|0)!=0){D=t;E=-2147483648;G=0;H=p;I=o;J=r;y=35;break}r=uz(l)|0;lz(l)|0;s=tz(l)|0;q=tz(l)|0;K=lz(l)|0;if(!((r|0)!=1|(K|0)==0)){L=p;M=o;N=t;O=s;P=q;Q=K;y=26;break}K=t-9|0;Vy(l,K,(K|0)<0|0?-1:0)|0;u=-5;i=j;return u|0}else{while(1){K=Ty(l,0,0,1)|0;t=F;q=tz(l)|0;s=lz(l)|0;lz(l)|0;o=lz(l)|0;p=lz(l)|0;R=tz(l)|0;if((q|0)!=16726){y=9;break}if((s-1|0)>>>0>1>>>0){y=12;break}if((o|0)!=85){yDb(n,24,2021184,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}if((R|0)>6136){y=17;break}if(!((s|0)!=1|(p&16|0)==0)){v=t;w=K;x=R;y=20;break a}if((s|0)!=2){z=-2147483648;A=0;B=R;C=s;break a}s=c[h>>2]|0;if((s|0)!=0){D=R;E=-2147483648;G=0;H=t;I=K;J=s;y=35;break a}s=uz(l)|0;lz(l)|0;p=tz(l)|0;o=tz(l)|0;q=lz(l)|0;if(!((s|0)!=1|(q|0)==0)){L=t;M=K;N=R;O=p;P=o;Q=q;y=26;break a}yDb(n,24,1948528,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;q=R-9|0;Vy(l,q,(q|0)<0|0?-1:0)|0;}if((y|0)==9){if(m){u=-5;i=j;return u|0}yDb(n,16,2131664,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;u=-5;i=j;return u|0}else if((y|0)==12){if(m){u=-5;i=j;return u|0}yDb(n,16,2067976,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;u=-5;i=j;return u|0}else if((y|0)==17){if(m){u=-5;i=j;return u|0}yDb(n,16,1977960,(S=i,i=i+8|0,c[S>>2]=R,S)|0);i=S;u=-5;i=j;return u|0}}}while(0);do{if((y|0)==20){T=0;U=vz(l)|0;V=x-4|0;W=v;X=w;Y=1;y=40}else if((y|0)==26){R=k|0;q=mz(l,R,Q)|0;if((q|0)!=(Q|0)){u=(q|0)<0?q:-1094995529;i=j;return u|0}q=N-9-Q|0;o=O-3-Q|0;c[h>>2]=o;if((P&128|0)==0){D=q;E=-2147483648;G=0;H=L;I=M;J=o;y=35;break}p=a[R]|0;if(!((p&-16)<<24>>24==32)){D=q;E=-2147483648;G=0;H=L;I=M;J=o;y=35;break}if((Q|0)>=5){R=p&14;p=k+1|0;K=((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(R<<29|0>>>3);p=k+3|0;D=q;E=0<<29|R>>>3|0;G=K|((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;H=L;I=M;J=o;y=35;break}if(!m){yDb(n,16,1923088,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}Vy(l,q,(q|0)<0|0?-1:0)|0;u=-1094995529;i=j;return u|0}}while(0);if((y|0)==35){l=J-D|0;c[h>>2]=l;if((l|0)<0){if(!m){yDb(n,24,1901496,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}c[h>>2]=0}if((G|0)==0&(E|0)==(-2147483648|0)){z=-2147483648;A=0;B=D;C=2}else{T=E;U=G;V=D;W=H;X=I;Y=2;y=40}}if((y|0)==40){jT(c[(c[b+28>>2]|0)+(Y-1<<2)>>2]|0,X,W,U,T,0,0,1)|0;z=T;A=U;B=V;C=Y}c[e>>2]=A;c[e+4>>2]=z;c[f>>2]=B;c[g>>2]=C;u=0;i=j;return u|0}function ZN(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,2067776,5)|0)==0;return(b?100:0)|0}function _N(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+56|0;d=b+32|0;e=b+40|0;f=b+48|0;g=a+16|0;Vy(c[g>>2]|0,5,0)|0;h=b|0;wz(c[g>>2]|0,h,32)|0;g=xd(h|0,2131392,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=f,c[h+16>>2]=d,h)|0)|0;i=h;if((g|0)!=3|(c[e>>2]|0)<1|(c[d>>2]|0)<1){j=-1094995529;i=b;return j|0}if((c[f>>2]|0)<1){j=-1094995529;i=b;return j|0}g=LT(a,0)|0;if((g|0)==0){j=-12;i=b;return j|0}a=g+8|0;h=c[a>>2]|0;c[h+8>>2]=1;c[h+416>>2]=c[e>>2];c[h+412>>2]=c[f>>2];f=wT(c[d>>2]|0,0,1,65535)|0;h=c[a>>2]|0;c[h+48>>2]=f;c[h+792>>2]=c[d>>2];c[h+432>>2]=(ba(c[h+416>>2]|0,c[d>>2]|0)|0)/8|0;MT(g,64,1,c[h+412>>2]|0);j=0;i=b;return j|0}function $N(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1179011410){e=b+8|0;f=e|0;g=e+4|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)==1296256081&(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)==544501094){h=100}else{break}return h|0}}while(0);h=0;return h|0}function aO(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;g=c[d+16>>2]|0;h=c[d+12>>2]|0;j=LT(d,0)|0;if((j|0)==0){k=-12;i=e;return k|0}vz(g)|0;Vy(g,18,0)|0;l=j+8|0;j=c[l>>2]|0;c[j+8>>2]=1;c[j+416>>2]=1;m=j+448|0;c[m>>2]=4;c[m+4>>2]=0;m=f|0;mz(g,m,16)|0;do{if(((a[m]|0)-65&255)>>>0<2>>>0){if((PGb(f+1|0,986008,15)|0)!=0){n=5;break}c[(c[l>>2]|0)+48>>2]=86040}else{n=5}}while(0);do{if((n|0)==5){if((PGb(m,986024,16)|0)==0){c[(c[l>>2]|0)+48>>2]=1936029283;break}if((PGb(m,985992,16)|0)==0){c[(c[l>>2]|0)+48>>2]=1936944502;break}yDb(d,16,1977768,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;k=-1094995529;i=e;return k|0}}while(0);Vy(g,82,0)|0;m=pz(g)|0;c[(c[l>>2]|0)+72>>2]=m;c[d+1076>>2]=pz(g)|0;Vy(g,2,0)|0;m=pz(g)|0;c[(c[l>>2]|0)+412>>2]=m;Vy(g,2,0)|0;m=h+4|0;h=m;TGb(m|0,-1|0,10)|0;m=rz(g)|0;l=(m|0)>8?8:m;if((l|0)>0){m=d;d=0;do{n=lz(g)|0;f=lz(g)|0;if((f|0)>4){yDb(m,24,1948416,(o=i,i=i+16|0,c[o>>2]=f,c[o+8>>2]=n,o)|0);i=o}else{b[h+(f<<1)>>1]=n}d=d+1|0;}while((d|0)<(l|0))}d=36-(l<<1)|0;Vy(g,d,(d|0)<0|0?-1:0)|0;k=0;i=e;return k|0}function bO(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=c[a+16>>2]|0;g=c[a+12>>2]|0;if((Xy(f)|0)!=0){h=-541478725;i=e;return h|0}j=g;k=a+1076|0;l=a;a=g+4|0;a:while(1){do{if((c[j>>2]|0)==0){g=Ty(f,0,0,1)|0;do{if(!((g&1|0)==0&(F&0|0)==0)){if((lz(f)|0)==0){break}yDb(l,24,2020944,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}}while(0);g=rz(f)|0;n=rz(f)|0;if((g|0)==1952543350){if((rz(f)|0)!=0){c[k>>2]=0}Vy(f,4,0)|0;break}else if((g|0)==1635017060){c[j>>2]=n;break}else{Vy(f,n,0)|0;break}}else{n=lz(f)|0;o=c[k>>2]|0;if((o|0)!=0){p=5;break a}if((n|0)<=4){q=b[a+(n<<1)>>1]|0;if(!(q<<16>>16<0)){p=10;break a}}c[j>>2]=(c[j>>2]|0)-1}}while(0);if((Xy(f)|0)!=0){h=-541478725;p=26;break}}if((p|0)==5){r=o-1|0}else if((p|0)==10){r=q<<16>>16}else if((p|0)==26){i=e;return h|0}if((c[j>>2]|0)>>>0>r>>>0){s=r}else{yDb(l,24,2131200,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;s=(c[j>>2]|0)-1|0}r=TS(f,d,s)|0;if(!((r|0)>-1)){h=r;i=e;return h|0}if((s|0)!=(r|0)){yDb(l,16,2067616,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}c[j>>2]=(c[j>>2]|0)+~s;h=r;i=e;return h|0}function cO(a){a=a|0;var b=0;b=(c[a+4>>2]|0)+4|0;return((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==826557778?100:0)|0}function dO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+272|0;e=d|0;f=d+8|0;g=b+12|0;h=c[g>>2]|0;j=b+16|0;Ty(c[j>>2]|0,0,0,1)|0;k=vz(c[j>>2]|0)|0;do{if(!(k>>>0<8>>>0)){l=rz(c[j>>2]|0)|0;if((k|0)<0){break}if((l|0)!=826557778){yDb(b,16,1901448,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=d;return n|0}l=f|0;o=LT(b,0)|0;do{if((o|0)!=0){p=o+8|0;q=c[p>>2]|0;c[q+8>>2]=0;c[q+48>>2]=89;lz(c[j>>2]|0)|0;lz(c[j>>2]|0)|0;tz(c[j>>2]|0)|0;MT(o,32,1,vz(c[j>>2]|0)|0);vz(c[j>>2]|0)|0;Vy(c[j>>2]|0,32,0)|0;q=vz(c[j>>2]|0)|0;c[(c[p>>2]|0)+120>>2]=q;q=vz(c[j>>2]|0)|0;c[(c[p>>2]|0)+124>>2]=q;tz(c[j>>2]|0)|0;q=tz(c[j>>2]|0)|0;p=tz(c[j>>2]|0)|0;if((q|0)>0&(p|0)>0){c[o+92>>2]=q;c[o+96>>2]=p;p=o+92|0;q=o+412|0;r=c[p+4>>2]|0;c[q>>2]=c[p>>2];c[q+4>>2]=r}r=lz(c[j>>2]|0)|0;if((r|0)>0){q=LT(b,0)|0;if((q|0)==0){break}p=c[q+8>>2]|0;c[p+8>>2]=1;c[p+48>>2]=65545;c[p+416>>2]=r;MT(q,32,1,c[o+44>>2]|0)}mz(c[j>>2]|0,l,257)|0;a[f+257|0]=0;CBb(o+88|0,2294392,l,0)|0;q=Ty(c[j>>2]|0,0,0,1)|0;r=b+1248|0;c[r>>2]=q;c[r+4>>2]=F;q=c[j>>2]|0;if((c[q+88>>2]|0)==0){n=0;i=d;return n|0}p=Wy(q)|0;s=YGb(p,F,-56,-1)|0;Ty(q,s,F,0)|0;Ty(c[j>>2]|0,0,0,1)|0;s=vz(c[j>>2]|0)|0;if(s>>>0<8>>>0){t=826557778;u=16}else{q=rz(c[j>>2]|0)|0;if((s|0)<0){t=q;u=16}else{v=q}}if((u|0)==16){yDb(b,16,1881360,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;v=t}do{if((v|0)==1112491346|(v|0)==1179600210|(v|0)==1397704018){q=c[g>>2]|0;c[q+8>>2]=vz(c[j>>2]|0)|0;vz(c[j>>2]|0)|0;vz(c[j>>2]|0)|0;vz(c[j>>2]|0)|0;vz(c[j>>2]|0)|0;vz(c[j>>2]|0)|0;Vy(c[j>>2]|0,24,0)|0;q=c[h+8>>2]|0;if((q|0)==0){break}Ty(c[j>>2]|0,q,0,0)|0;Ty(c[j>>2]|0,0,0,1)|0;q=vz(c[j>>2]|0)|0;if(q>>>0<8>>>0){w=v;u=21}else{s=rz(c[j>>2]|0)|0;if((q|0)<0){w=s;u=21}else{x=s}}if((u|0)==21){yDb(b,16,2339304,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;x=w}if((x|0)!=1331053650){break}s=c[g>>2]|0;p=c[c[b+28>>2]>>2]|0;y=s;c[y>>2]=(q-8|0)>>>2;z=WDb(q)|0;q=s+4|0;c[q>>2]=z;if((z|0)==0){yDb(b,16,2315072,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;break}else{A=0}while(1){z=c[y>>2]|0;if(!(A>>>0<z>>>0)){B=z;break}z=vz(c[j>>2]|0)|0;c[(c[q>>2]|0)+(A<<2)>>2]=z;if((z|0)==0){u=26;break}else{A=A+1|0}}if((u|0)==26){c[y>>2]=A;B=A}q=c[p+92>>2]|0;if((q|0)==0){break}c[e>>2]=c[p+96>>2];c[e+4>>2]=q;q=KDb(B,0,e,p+40|0)|0;z=p+56|0;c[z>>2]=q;c[z+4>>2]=F}}while(0);Ty(c[j>>2]|0,c[r>>2]|0,c[r+4>>2]|0,0)|0;n=0;i=d;return n|0}}while(0);yDb(b,16,1923008,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-12;i=d;return n|0}}while(0);yDb(b,16,1948328,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=d;return n|0}function eO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=a+16|0;f=a+28|0;g=a+24|0;h=a;while(1){Ty(c[e>>2]|0,0,0,1)|0;j=vz(c[e>>2]|0)|0;if(j>>>0<8>>>0){k=-1;l=23;break}a=rz(c[e>>2]|0)|0;if((j|0)<0){k=-1;l=23;break}if((a|0)==1447314770){m=c[c[f>>2]>>2]|0;if((c[m+76>>2]|0)!=48){l=9;break}}else if((a|0)==1094993234){if((c[g>>2]|0)>>>0<2>>>0){k=-1;l=23;break}n=c[(c[f>>2]|0)+4>>2]|0;if((c[n+76>>2]|0)!=48){l=17;break}}Vy(c[e>>2]|0,j-8|0,0)|0;}if((l|0)==9){f=Ty(c[e>>2]|0,0,0,1)|0;g=F;a=vz(c[e>>2]|0)|0;vz(c[e>>2]|0)|0;lz(c[e>>2]|0)|0;lz(c[e>>2]|0)|0;if((tz(c[e>>2]|0)|0)>4){tz(c[e>>2]|0)|0;tz(c[e>>2]|0)|0;vz(c[e>>2]|0)|0;vz(c[e>>2]|0)|0;vz(c[e>>2]|0)|0}o=Ty(c[e>>2]|0,0,0,1)|0;p=F;q=YGb(f,g,j-8|0,0)|0;g=ZGb(q,F,o,p)|0;p=g;if((p|0)<0){k=-1;i=d;return k|0}if((TS(c[e>>2]|0,b,p)|0)<0){yDb(h,16,1977664,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;k=-1;i=d;return k|0}c[b+32>>2]=0;p=b+16|0;c[p>>2]=a;c[p+4>>2]=0;p=c[m+92>>2]|0;if((p|0)==0){k=0;i=d;return k|0}a=c[m+44>>2]|0;g=c[m+96>>2]|0;m=gHb(g,(g|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=hHb(m,F,p,(p|0)<0|0?-1:0)|0;c[b+48>>2]=a;k=0;i=d;return k|0}else if((l|0)==17){a=Ty(c[e>>2]|0,0,0,1)|0;p=F;m=vz(c[e>>2]|0)|0;g=vz(c[e>>2]|0)|0;o=n+8|0;c[(c[o>>2]|0)+412>>2]=g;if((g|0)<1){yDb(h,16,2067336,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;k=-1094995529;i=d;return k|0}g=vz(c[e>>2]|0)|0;vz(c[e>>2]|0)|0;tz(c[e>>2]|0)|0;lz(c[e>>2]|0)|0;lz(c[e>>2]|0)|0;vz(c[e>>2]|0)|0;q=Ty(c[e>>2]|0,0,0,1)|0;f=F;s=YGb(a,p,j-8|0,0)|0;j=ZGb(s,F,q,f)|0;f=j;if((f|0)<0){k=-1;i=d;return k|0}j=TS(c[e>>2]|0,b,f)|0;if((j|0)<0){yDb(h,16,2020736,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;k=j;i=d;return k|0}c[b+32>>2]=1;j=b+16|0;c[j>>2]=m;c[j+4>>2]=0;j=c[(c[o>>2]|0)+412>>2]|0;if((j|0)==0){k=0;i=d;return k|0}o=c[n+44>>2]|0;n=IDb(g,(g|0)<0|0?-1:0,o,(o|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;c[b+48>>2]=n;k=0;i=d;return k|0}else if((l|0)==23){i=d;return k|0}return 0}function fO(a){a=a|0;$Db((c[a+12>>2]|0)+4|0);return 0}function gO(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;i=i+8|0;b=f|0;g=c[c[a+28>>2]>>2]|0;h=c[g+92>>2]|0;if((h|0)==0){j=-1;i=f;return j|0}k=c[a+12>>2]|0;c[b>>2]=c[g+96>>2];c[b+4>>2]=h;h=KDb(d,e,g+40|0,b)|0;b=h;h=c[k>>2]|0;if(b>>>0<h>>>0){Ty(c[a+16>>2]|0,h,0,0)|0;h=F;((h|0)<0|0?-1:0)>>31|((h|0)<0|0?-1:0)<<1;j=h>>31|((h|0)<0|0?-1:0)<<1;i=f;return j|0}else{yDb(a,16,2130960,(a=i,i=i+8|0,c[a>>2]=b,a)|0);i=a;j=-1;i=f;return j|0}return 0}function hO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((wZ(b,1024)|0)<0){d=-12;return d|0}e=a+16|0;a=Ty(c[e>>2]|0,0,0,1)|0;f=b+64|0;c[f>>2]=a;c[f+4>>2]=F;c[b+32>>2]=0;f=oz(c[e>>2]|0,c[b+24>>2]|0,1024)|0;if((f|0)<0){BZ(b);d=f;return d|0}else{yZ(b,f);d=f;return d|0}return 0}function iO(a){a=a|0;var b=0,d=0,e=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[b+236>>2]=1463898624;a=b+48|0;c[a>>2]=0;c[a+4>>2]=0;d=0;return d|0}function jO(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=LT(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[d+8>>2]|0;c[f+8>>2]=0;c[f+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[d+236>>2]=1463898624;a=f+104|0;f=c[b+12>>2]|0;c[a>>2]=c[b+16>>2];c[a+4>>2]=f;MT(d,64,1,12e5);e=0;return e|0}function kO(a){a=a|0;var b=0,d=0,e=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=2;c[e+48>>2]=c[(c[a+4>>2]|0)+28>>2];a=b+48|0;c[a>>2]=0;c[a+4>>2]=0;d=0;return d|0}function lO(a,b){a=a|0;b=b|0;Ry(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function mO(a){a=a|0;var b=0,d=0,e=0;b=i;if((c[a+24>>2]|0)==1){d=0;i=b;return d|0}yDb(a,16,1964672,(e=i,i=i+8|0,c[e>>2]=c[c[a+8>>2]>>2],e)|0);i=e;d=-22;i=b;return d|0}function nO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=c[a+12>>2]|0;f=LT(a,0)|0;if((f|0)==0){g=-12;i=b;return g|0}h=f+8|0;j=c[h>>2]|0;c[j+8>>2]=0;c[j+48>>2]=c[(c[a+4>>2]|0)+28>>2];j=e+12|0;k=_Eb(c[j>>2]|0)|0;if((k|0)==-1){yDb(a,16,2066928,(a=i,i=i+8|0,c[a>>2]=c[j>>2],a)|0);i=a;g=-22;i=b;return g|0}else{MT(f,64,c[e+20>>2]|0,c[e+16>>2]|0);a=e+4|0;j=c[h>>2]|0;c[j+120>>2]=c[a>>2];l=e+8|0;c[j+124>>2]=c[l>>2];c[j+140>>2]=k;j=QZ(k,c[a>>2]|0,c[l>>2]|0)|0;c[d>>2]=8;c[d+4>>2]=1;l=KDb(j,(j|0)<0|0?-1:0,d,f+40|0)|0;c[(c[h>>2]|0)+72>>2]=l;g=0;i=b;return g|0}return 0}function oO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;e=QZ(c[d+140>>2]|0,c[d+120>>2]|0,c[d+124>>2]|0)|0;if((e|0)<0){f=-1;return f|0}d=TS(c[a+16>>2]|0,b,e)|0;a=b+64|0;g=eHb(c[a>>2]|0,c[a+4>>2]|0,e,(e|0)<0|0?-1:0)|0;e=F;a=b+16|0;c[a>>2]=g;c[a+4>>2]=e;a=b+8|0;c[a>>2]=g;c[a+4>>2]=e;c[b+32>>2]=0;f=(d|0)<0?d:0;return f|0}function pO(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=(zAb(((d[b+1|0]|0)<<8|(d[b]|0)<<16|(d[b+2|0]|0)|0)==15711167?b+3|0:b,2020336,7)|0)==0;return(a?50:0)|0}function qO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;d=i;i=i+1032|0;e=d|0;f=d+1024|0;g=c[b+12>>2]|0;h=LT(b,0)|0;a[f]=0;j=uO(2066888)|0;if((h|0)==0){k=-12;i=d;return k|0}MT(h,64,1,100);l=h+8|0;h=c[l>>2]|0;c[h+8>>2]=3;c[h+48>>2]=1381259348;IAb(e,0,-1);h=b+16|0;a:do{if((Xy(c[h>>2]|0)|0)==0){b=e|0;m=e+4|0;n=g;o=j;p=0;q=0;while(1){r=Ty(c[h>>2]|0,0,0,1)|0;s=ZGb(r,F,q,p)|0;r=F;if((BR(c[h>>2]|0,e,f)|0)==0){t=n;u=20;break a}v=(zAb(c[b>>2]|0,2020336,7)|0)==0;w=c[b>>2]|0;do{if(v){x=CR(w,1977360)|0;if((x|0)==0){y=o}else{y=uO(x)|0}x=eEb(c[b>>2]|0)|0;c[(c[l>>2]|0)+96>>2]=x;x=c[l>>2]|0;if((c[x+96>>2]|0)==0){z=-12;break a}c[x+100>>2]=(c[m>>2]|0)+1;A=y}else{x=(zAb(w,1948080,5)|0)!=0;B=uR(n,c[b>>2]|0,c[m>>2]|0,x&1)|0;if((B|0)==0){z=-12;break a}if(x){A=o;break}x=CR(c[b>>2]|0,1922744)|0;C=CR(c[b>>2]|0,1901288)|0;D=B+64|0;c[D>>2]=s;c[D+4>>2]=r;if((x|0)==0){E=0;G=0}else{D=uO(x)|0;E=(D|0)<0|0?-1:0;G=D}D=B+8|0;c[D>>2]=G;c[D+4>>2]=E;if((C|0)==0){H=o}else{x=uO(C)|0;C=ZGb(x,0,c[D>>2]|0,c[D+4>>2]|0)|0;H=C}c[B+48>>2]=H;A=o}}while(0);PAb(e);if((Xy(c[h>>2]|0)|0)!=0){t=n;u=20;break a}o=A;p=0;q=(a[f]|0)!=0|0}}else{t=g;u=20}}while(0);if((u|0)==20){vR(t);z=0}QAb(e,0)|0;k=z;i=d;return k|0}function rO(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function sO(a){a=a|0;AR(c[a+12>>2]|0);return 0}function tO(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function uO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=xd(a|0,1881168,(j=i,i=i+32|0,c[j>>2]=d,c[j+8>>2]=e,c[j+16>>2]=f,c[j+24>>2]=g,j)|0)|0;i=j;if((h|0)==4){k=((((c[e>>2]|0)*60|0)+((c[d>>2]|0)*3600|0)+(c[f>>2]|0)|0)*100|0)+(c[g>>2]|0)|0;i=b;return k|0}h=xd(a|0,2339168,(j=i,i=i+24|0,c[j>>2]=d,c[j+8>>2]=e,c[j+16>>2]=f,j)|0)|0;i=j;if((h|0)==3){k=(((c[e>>2]|0)*60|0)+((c[d>>2]|0)*3600|0)+(c[f>>2]|0)|0)*100|0;i=b;return k|0}d=xd(a|0,2314736,(j=i,i=i+24|0,c[j>>2]=e,c[j+8>>2]=f,c[j+16>>2]=g,j)|0)|0;i=j;if((d|0)==3){k=((((c[e>>2]|0)*60|0)+(c[f>>2]|0)|0)*100|0)+(c[g>>2]|0)|0;i=b;return k|0}d=xd(a|0,2294264,(j=i,i=i+16|0,c[j>>2]=e,c[j+8>>2]=f,j)|0)|0;i=j;if((d|0)==2){k=(((c[e>>2]|0)*60|0)+(c[f>>2]|0)|0)*100|0;i=b;return k|0}e=xd(a|0,2277776,(j=i,i=i+16|0,c[j>>2]=f,c[j+8>>2]=g,j)|0)|0;i=j;if((e|0)==2){k=((c[f>>2]|0)*100|0)+(c[g>>2]|0)|0;i=b;return k|0}else{k=(kb(a|0,0,10)|0)*100|0;i=b;return k|0}return 0}function vO(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;e=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)^1382376531;a=e<<11|e>>>21;f=b+4|0;b=((a<<3|e>>>18&7)+a^(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)|0)==1885434475&1382376531==1382376531;return(b?100:0)|0}function wO(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=c[b+16>>2]|0;g=c[b+12>>2]|0;h=LT(b,0)|0;if((h|0)==0){j=-12;i=e;return j|0}k=c[h+8>>2]|0;l=WDb(4112)|0;if((l|0)==0){j=-12;i=e;return j|0}m=(vz(f)|0)^1382376531;n=l;x=1399088466;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m<<11|m>>>21;m=4;o=l;do{o=o+4|0;n=(n<<3|n>>>29)+n|0;p=o;x=fe((vz(f)|0)^n|0)|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;m=m+4|0;}while((m|0)<4096);c[k+48>>2]=69650;c[k+8>>2]=1;m=l+60|0;n=fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;m=k+412|0;c[m>>2]=n;do{if((n-1|0)>>>0>95999>>>0){yDb(b,16,2066792,(f=i,i=i+8|0,c[f>>2]=n,f)|0);i=f;q=-1094995529}else{f=l+64|0;o=h+56|0;c[o>>2]=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)*14|0;c[o+4>>2]=0;c[g>>2]=0;o=a[l+78|0]|0;f=o&255;p=k+416|0;c[p>>2]=f;if(o<<24>>24==0){q=-1094995529;break}o=((a[l+79|0]|0)==0?84:100)+(f<<3)|0;if((o+(f*46|0)|0)>4096){q=-1094995529;break}if((BT(k,f<<5)|0)!=0){q=-12;break}if((c[p>>2]|0)>0){f=k+96|0;r=l+((o|0)>4096?4096:o)|0;o=0;while(1){UGb((c[f>>2]|0)+(o<<5)|0,r|0,32)|0;s=o+1|0;if((s|0)<(c[p>>2]|0)){r=r+46|0;o=s}else{break}}}MT(h,64,1,c[m>>2]|0);q=0}}while(0);ZDb(l);j=q;i=e;return j|0}function xO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+28|0;e=c[a+12>>2]|0;f=c[(c[(c[c[d>>2]>>2]|0)+8>>2]|0)+416>>2]<<3;g=a+16|0;if((Xy(c[g>>2]|0)|0)!=0){h=-541478725;return h|0}a=e;e=c[a>>2]|0;i=(c[c[d>>2]>>2]|0)+56|0;if((e|0)==(c[i>>2]|0)&(((e|0)<0|0?-1:0)|0)==(c[i+4>>2]|0)){h=-541478725;return h|0}if((TS(c[g>>2]|0,b,f)|0)==(f|0)){c[b+48>>2]=14;c[a>>2]=(c[a>>2]|0)+14;c[b+32>>2]=0;h=f;return h|0}else{BZ(b);h=-5;return h|0}return 0}function yO(a,b){a=a|0;b=b|0;var c=0,d=0;c=b|0;if((mz(a,c,16)|0)>=16){d=0;return d|0}TGb(c|0,0,16)|0;d=-1094995529;return d|0}function zO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=0;while(1){e=c[a+(d*20|0)>>2]|0;if((e|0)==0){f=0;g=4;break}if((PGb(a+(d*20|0)+4|0,b,16)|0)==0){f=e;g=4;break}else{d=d+1|0}}if((g|0)==4){return f|0}return 0}function AO(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=pz(b)|0;c[e+8>>2]=1;l=e+416|0;c[l>>2]=pz(b)|0;m=e+412|0;c[m>>2]=rz(b)|0;n=e+72|0;c[n>>2]=(rz(b)|0)<<3;c[e+432>>2]=pz(b)|0;if((f|0)==14){c[e+792>>2]=8;o=8}else{p=pz(b)|0;c[e+792>>2]=p;o=p}p=(k|0)==65534;q=e+52|0;if(p){c[q>>2]=0}else{c[q>>2]=k;r=vT(1238064,k)|0;if((r|0)==65536){s=wT(o,0,0,-2)|0;t=9}else if((r|0)==0){u=0}else if((r|0)==65557){s=wT(o,1,0,0)|0;t=9}else{s=r;t=9}if((t|0)==9){u=(s|0)==69633&(o|0)==8?65553:s}c[e+48>>2]=u}do{if((f|0)>17){u=pz(b)|0;s=f-18|0;o=(s|0)>(u|0)?u:s;if((o|0)<22|p^1){v=o;w=s}else{s=h;u=j|0;r=h;k=pz(b)|0;if((k|0)!=0){c[e+792>>2]=k}k=e+448|0;c[k>>2]=rz(b)|0;c[k+4>>2]=0;if((mz(b,s,16)|0)<16){TGb(s|0,0,16)|0}k=h+4|0;a[u]=0;a[j+1|0]=0;a[j+2|0]=16;a[j+3|0]=0;a[j+4|0]=-128;a[j+5|0]=0;a[j+6|0]=0;a[j+7|0]=-86;a[j+8|0]=0;a[j+9|0]=56;a[j+10|0]=-101;a[j+11|0]=113;do{if((PGb(k,u,12)|0)==0){x=c[h>>2]|0;c[q>>2]=x;y=c[e+792>>2]|0;z=vT(1238064,x)|0;if((z|0)==65536){A=wT(y,0,0,-2)|0;t=21}else if((z|0)==65557){A=wT(y,1,0,0)|0;t=21}else if((z|0)==0){B=0}else{A=z;t=21}if((t|0)==21){B=(A|0)==69633&(y|0)==8?65553:A}c[e+48>>2]=B}else{y=0;while(1){C=c[1238560+(y*20|0)>>2]|0;if((C|0)==0){t=26;break}if((PGb(1238564+(y*20|0)|0,s,16)|0)==0){t=25;break}else{y=y+1|0}}if((t|0)==25){c[e+48>>2]=C;break}else if((t|0)==26){c[e+48>>2]=0;y=d[r+1|0]|0;z=d[r+2|0]|0;x=d[r+3|0]|0;D=d[k]|0;E=d[r+5|0]|0;F=d[r+6|0]|0;G=d[r+7|0]|0;H=d[h+8|0]|0;I=d[r+9|0]|0;J=d[r+10|0]|0;K=d[r+11|0]|0;L=d[h+12|0]|0;M=d[r+13|0]|0;N=d[r+14|0]|0;O=d[r+15|0]|0;yDb(e,24,1947928,(P=i,i=i+128|0,c[P>>2]=d[s]|0,c[P+8>>2]=y,c[P+16>>2]=z,c[P+24>>2]=x,c[P+32>>2]=D,c[P+40>>2]=E,c[P+48>>2]=F,c[P+56>>2]=G,c[P+64>>2]=H,c[P+72>>2]=I,c[P+80>>2]=J,c[P+88>>2]=K,c[P+96>>2]=L,c[P+104>>2]=M,c[P+112>>2]=N,c[P+120>>2]=O,P)|0);i=P;break}}}while(0);v=o-22|0;w=f-40|0}do{if((v|0)>0){ZDb(c[e+96>>2]|0);if((CT(e,b,v)|0)<0){Q=-12;i=g;return Q|0}else{R=w-v|0;break}}else{R=w}}while(0);if((R|0)<=0){break}Vy(b,R,(R|0)<0|0?-1:0)|0;}}while(0);R=c[m>>2]|0;if((R|0)<1){yDb(0,16,1907024,(P=i,i=i+8|0,c[P>>2]=R,P)|0);i=P;Q=-1094995529;i=g;return Q|0}P=c[e+48>>2]|0;if((P|0)==86066){c[l>>2]=0;c[m>>2]=0;Q=0;i=g;return Q|0}else if((P|0)==69643){c[e+792>>2]=(c[n>>2]|0)/(R|0)|0;Q=0;i=g;return Q|0}else{Q=0;i=g;return Q|0}return 0}function BO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=vT(1238064,a)|0;if((c|0)==0){d=0;return d|0}else if((c|0)==65536){e=wT(b,0,0,-2)|0}else if((c|0)==65557){e=wT(b,1,0,0)|0}else{e=c}d=(e|0)==69633&(b|0)==8?65553:e;return d|0}function CO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=rz(a)|0;if((d|0)!=0){c[d>>2]=e}e=rz(a)|0;d=b+8|0;c[(c[d>>2]|0)+120>>2]=e;e=rz(a)|0;c[(c[d>>2]|0)+124>>2]=e;pz(a)|0;e=pz(a)|0;c[(c[d>>2]|0)+792>>2]=e;e=rz(a)|0;rz(a)|0;rz(a)|0;rz(a)|0;rz(a)|0;rz(a)|0;return e|0}function DO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+8|0;f=e|0;g=c[a+16>>2]|0;h=Ty(g,0,0,1)|0;j=YGb(h,F,b,d)|0;d=F;b=Ty(g,0,0,1)|0;h=F;k=-1;if(!((h|0)>(k|0)|(h|0)==(k|0)&b>>>0>-1>>>0)){l=0;i=e;return l|0}k=YGb(j,d,-8,-1)|0;m=F;n=f|0;o=g+52|0;p=f;f=a+1140|0;q=a;a=h;h=b;a:while(1){if((a|0)>(m|0)|(a|0)==(m|0)&h>>>0>k>>>0){l=0;r=23;break}TGb(n|0,0,5)|0;s=rz(g)|0;t=rz(g)|0;b=t;u=0;if((Xy(g)|0)!=0){r=5;break}if((u|0)>(d|0)|(u|0)==(d|0)&b>>>0>j>>>0){r=9}else{v=ZGb(j,d,b,u)|0;w=F;if((w|0)<(a|0)|(w|0)==(a|0)&v>>>0<h>>>0|(t|0)==-1){r=9}else{x=u;y=b;z=s}}if((r|0)==9){r=0;Ty(g,-9,-1,1)|0;b=rz(g)|0;u=rz(g)|0;v=u;w=0;if((w|0)>(d|0)|(w|0)==(d|0)&v>>>0>j>>>0){r=11;break}A=ZGb(j,d,v,w)|0;B=F;if((B|0)<(a|0)|(B|0)==(a|0)&A>>>0<h>>>0|(u|0)==-1){r=11;break}else{x=w;y=v;z=b}}b=YGb(y&1,x&0,y,x)|0;v=F;do{if((z|0)==0){if((b|0)==0&(v|0)==0){if((c[o>>2]|0)==0){break}else{r=16;break a}}else{Vy(g,b,v)|0;break}}else{w=YGb(b,v,1,0)|0;u=cEb(w)|0;if((u|0)==0){r=18;break a}c[p>>2]=z;w=mz(g,u,b)|0;if(!((w|0)==(b|0)&(((w|0)<0|0?-1:0)|0)==(v|0))){yDb(q,24,1977208,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C}CBb(f,n,u,8)|0}}while(0);v=Ty(g,0,0,1)|0;b=F;u=-1;if((b|0)>(u|0)|(b|0)==(u|0)&v>>>0>-1>>>0){a=b;h=v}else{l=0;r=23;break}}if((r|0)==5){if((t|s|0)==0){l=-541478725;i=e;return l|0}yDb(q,24,2214936,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;l=-1094995529;i=e;return l|0}else if((r|0)==11){yDb(q,24,2130032,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;l=-1094995529;i=e;return l|0}else if((r|0)==16){yDb(q,24,2066712,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;l=-541478725;i=e;return l|0}else if((r|0)==18){yDb(q,16,2020168,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;l=-12;i=e;return l|0}else if((r|0)==23){i=e;return l|0}return 0}function EO(a,b){a=a|0;b=b|0;Yy(a,(d[b+1|0]|0)<<8|(d[b]|0)|(d[b+2|0]|0)<<16|(d[b+3|0]|0)<<24);Yy(a,0);b=Ty(a,0,0,1)|0;return(F=F,b)|0}function FO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if(!((b&1|0)==0&(d&0|0)==0)){yDb(0,0,1906800,(f=i,i=i+24|0,c[f>>2]=2214920,c[f+8>>2]=2130008,c[f+16>>2]=42,f)|0);i=f;Cd()}f=Ty(a,0,0,1)|0;g=F;if(!((f&1|0)==0&(g&0|0)==0)){Py(a,0)}h=YGb(b,d,-4,-1)|0;Ty(a,h,F,0)|0;h=ZGb(f,g,b,d)|0;Yy(a,h);h=YGb(f,g,1,0)|0;Ty(a,h&-2,F|0,0)|0;i=e;return}function GO(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0;e=i;i=i+256|0;f=e|0;g=f|0;h=f;j=f;k=f;l=d+52|0;m=c[l>>2]|0;if((m|0)==0|m>>>0>65535>>>0){n=-1;i=e;return n|0}m=O0a(d,0)|0;if((m|0)==0){o=c[d+424>>2]|0}else{o=m}m=d+416|0;do{if((c[m>>2]|0)>2){p=d+448|0;if((c[p>>2]|0)==0&(c[p+4>>2]|0)==0){q=7;break}r=d+412|0;q=10}else{q=7}}while(0);do{if((q|0)==7){p=d+412|0;if((c[p>>2]|0)>48e3){r=p;q=10;break}s=d+48|0;t=c[s>>2]|0;if((t|0)==86057){r=p;q=10;break}if((u0a(t)|0)>16){r=p;q=10;break}az(a,c[l>>2]|0);u=0;v=p;w=s}}while(0);if((q|0)==10){az(a,65534);u=1;v=r;w=d+48|0}az(a,c[m>>2]|0);Yy(a,c[v>>2]|0);r=c[w>>2]|0;a:do{switch(r|0){case 86047:case 86069:case 86016:case 86017:case 86046:{y=0;break};default:{s=u0a(r)|0;if((s|0)!=0){y=s;break a}s=c[d+792>>2]|0;y=(s|0)==0?16:s}}}while(0);r=c[d+792>>2]|0;if(!((y|0)==(r|0)|(r|0)==0)){yDb(d,24,2066632,(s=i,i=i+16|0,c[s>>2]=r,c[s+8>>2]=y,s)|0);i=s}s=c[w>>2]|0;b:do{switch(s|0){case 86069:{z=24;q=22;break};case 86019:{z=3840;q=22;break};case 86018:{z=(c[m>>2]|0)*768|0;q=22;break};case 86016:case 86017:{A=o;break};default:{r=c[d+432>>2]|0;if((r|0)!=0){z=r;q=22;break b}r=ba(c[m>>2]|0,y)|0;p=GDb(8,0,y,(y|0)<0|0?-1:0)|0;z=eHb(r,(r|0)<0|0?-1:0,p,F)|0;q=22}}}while(0);if((q|0)==22){A=z}if((s|0)==86069){B=800}else if((s|0)==65541|(s|0)==65548|(s|0)==65544|(s|0)==65557|(s|0)==65559|(s|0)==65536){B=ba(c[v>>2]|0,A)|0}else{B=(c[d+72>>2]|0)/8|0}Yy(a,B);az(a,A);az(a,y);A=c[w>>2]|0;do{if((A|0)==86069){c[g>>2]=-1697775614;c[f+4>>2]=-1365051598;B=f+8|0;b[B>>1]=-21282;C=k;D=38;E=B+2|0}else if((A|0)==86046|(A|0)==69633){b[j>>1]=o;C=k;D=20;E=h+2|0}else if((A|0)==86016){b[j>>1]=2;B=k+2|0;x=c[d+72>>2]|0;b[B>>1]=x;b[B+2>>1]=x>>16;b[k+6>>1]=(c[m>>2]|0)==2?1:8;B=f+8|0;b[B>>1]=0;b[B+2>>1]=1;B=f+12|0;v=B;b[B>>1]=16;B=v+2|0;x=0;b[B>>1]=x;b[B+2>>1]=x>>16;B=v+6|0;x=0;b[B>>1]=x;b[B+2>>1]=x>>16;C=k;D=40;E=v+10|0}else if((A|0)==86017){b[j>>1]=1;v=k+2|0;x=2;b[v>>1]=x;b[v+2>>1]=x>>16;b[k+6>>1]=1152;v=f+8|0;b[v>>1]=1;b[v+2>>1]=1393;C=k;D=30;E=f+12|0}else{v=c[d+100>>2]|0;if((v|0)==0){C=k;D=18;E=k;break}B=c[d+96>>2]|0;C=B;D=v+18|0;E=B+v|0}}while(0);do{if(u){k=D+22|0;az(a,E+22-C|0);az(a,y);Yy(a,c[d+448>>2]|0);if((c[w>>2]|0)==86057){G=0}else{Yy(a,c[l>>2]|0);Yy(a,1048576);Yy(a,-1442840448);Yy(a,1905997824);H=k;break}while(1){f=c[1238560+(G*20|0)>>2]|0;if((f|0)==0){I=0;break}if((f|0)==86057){q=37;break}else{G=G+1|0}}if((q|0)==37){I=1238564+(G*20|0)|0}Ry(a,I|0,16);H=k}else{az(a,E-C|0);H=D}}while(0);Ry(a,C,E-C|0);if((H&1|0)==0){n=H;i=e;return n|0}Py(a,0);n=H+1|0;i=e;return n|0}function HO(a,b){a=a|0;b=b|0;Ry(a,b|0,16);return}function IO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=0;while(1){e=c[b+(d*20|0)>>2]|0;if((e|0)==0){f=0;g=5;break}if((e|0)==(a|0)){break}else{d=d+1|0}}if((g|0)==5){return f|0}f=b+(d*20|0)+4|0;return f|0}function JO(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;d=(f|0)!=0;if(d){g=40}else{g=(c[b+100>>2]|0)+40|0}Yy(a,g);g=b+120|0;Yy(a,c[g>>2]|0);f=b+52|0;h=b+124|0;i=c[h>>2]|0;Yy(a,(c[f>>2]|0)!=0?i:-i|0);az(a,1);i=b+792|0;j=c[i>>2]|0;az(a,(j|0)==0?24:j);Yy(a,c[f>>2]|0);f=ba(c[h>>2]|0,c[g>>2]|0)|0;g=c[i>>2]|0;Yy(a,((ba(f,(g|0)==0?24:g)|0)+7|0)/8|0);Yy(a,0);Yy(a,0);Yy(a,0);Yy(a,0);if(d){return}d=b+100|0;Ry(a,c[b+96>>2]|0,c[d>>2]|0);if((e|0)!=0){return}if((c[d>>2]&1|0)==0){return}Py(a,0);return}function KO(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=O0a(a,0)|0;if((f|0)==0){g=c[a+424>>2]|0;h=a+432|0;c[d>>2]=c[h>>2];if((g|0)==0){i=h;j=6}else{k=g;l=h;j=4}}else{h=a+432|0;c[d>>2]=c[h>>2];k=f;l=h;j=4}do{if((j|0)==4){h=a+412|0;if((c[h>>2]|0)==0){i=l;j=6;break}c[e>>2]=k;f=c[h>>2]|0;c[b>>2]=f;m=f}}while(0);do{if((j|0)==6){k=c[a+8>>2]|0;if((k|0)==0|(k|0)==2|(k|0)==3){c[e>>2]=c[a+104>>2];k=c[a+108>>2]|0;c[b>>2]=k;m=k;break}k=c[i>>2]|0;c[e>>2]=(k|0)==0?8:k<<3;k=c[a+72>>2]|0;if((k|0)==0){n=c[a+412>>2]<<3}else{n=k}c[b>>2]=n;m=n}}while(0);n=c[e>>2]|0;a=GDb(n,(n|0)<0|0?-1:0,m,(m|0)<0|0?-1:0)|0;m=a;c[e>>2]=(n|0)/(m|0)|0;c[b>>2]=(c[b>>2]|0)/(m|0)|0;return}function LO(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0;e=SGb(c|0)|0;if((e|0)<=0){return}f=e+1|0;Yy(a,(d[b+1|0]|0)<<8|(d[b]|0)|(d[b+2|0]|0)<<16|(d[b+3|0]|0)<<24);Yy(a,f);_y(a,c)|0;if((f&1|0)==0){return}Py(a,0);return}function MO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+16|0;d=c[b>>2]|0;e=a+1140|0;QG(e,1148752,0);a=0;while(1){if((a|0)==27){f=9;break}if((BBb(c[e>>2]|0,547528+(a*5|0)|0,0,1)|0)==0){a=a+1|0}else{break}}if((f|0)==9){return}Yy(d,1414744396);Yy(d,0);f=Ty(d,0,0,1)|0;a=F;Yy(d,1330007625);g=0;do{h=BBb(c[e>>2]|0,547528+(g*5|0)|0,0,1)|0;if((h|0)!=0){LO(c[b>>2]|0,c[h>>2]|0,c[h+4>>2]|0)}g=g+1|0;}while((g|0)!=27);FO(d,f,a);return}function NO(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297239878){a=b+8|0;b=((fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)-1380734514|0)>>>0<2>>>0;return(b?100:0)|0}else{return 0}return 0}function OO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;d=c[a+16>>2]|0;Vy(d,4,0)|0;e=rz(d)|0;f=vz(d)|0;Vy(d,4,0)|0;g=rz(d)|0;if(e>>>0>1073741823>>>0|g>>>0>536870911>>>0){h=-1094995529;i=b;return h|0}Vy(d,2,0)|0;j=pz(d)|0;k=pz(d)|0;l=pz(d)|0;m=pz(d)|0;n=LT(a,0)|0;if((n|0)==0){h=-12;i=b;return h|0}o=c[n+8>>2]|0;c[o+8>>2]=0;c[o+48>>2]=115;c[o+52>>2]=0;c[o+120>>2]=320;c[o+124>>2]=200;n=(f|0)!=1380734515|(e|0)==0?774:e+774|0;c[o+100>>2]=n;if((CT(o,d,n)|0)<0){h=-12;i=b;return h|0}do{if((j&65535)<<16>>16==0){p=1103;q=11025}else{n=l&65535;if((l&65535)<<16>>16==0|n>>>0>42>>>0){yDb(a,16,2129840,(o=i,i=i+8|0,c[o>>2]=n,o)|0);i=o;h=-1094995529;i=b;return h|0}o=k&65535;e=LT(a,0)|0;if((e|0)==0){h=-12;i=b;return h|0}else{f=c[e+8>>2]|0;c[f+8>>2]=1;c[f+48>>2]=65541;c[f+52>>2]=1;c[f+416>>2]=n;c[f+792>>2]=8;c[f+412>>2]=o;c[f+72>>2]=(ba(o,n)|0)<<3;c[f+432>>2]=n;MT(e,32,1,o);p=m&65535;q=o;break}}}while(0);m=a+28|0;MT(c[c[m>>2]>>2]|0,32,p,q);q=g<<2;p=WDb(q)|0;a=p;k=WDb(q)|0;o=k;e=WDb(q)|0;q=e;if((p|0)==0|(k|0)==0|(e|0)==0){ZDb(p);ZDb(k);ZDb(e);h=-12;i=b;return h|0}n=(g|0)==0;a:do{if(n){r=0}else{f=0;do{c[a+(f<<2)>>2]=rz(d)|0;f=f+1|0;}while(f>>>0<g>>>0);if(n){r=0;break}else{s=0}do{c[q+(s<<2)>>2]=rz(d)|0;s=s+1|0;}while(s>>>0<g>>>0);if(n){r=0;break}else{t=0}do{c[o+(t<<2)>>2]=(rz(d)|0)&65535;t=t+1|0;}while(t>>>0<g>>>0);if(n){r=0;break}f=l&65535;if((j&65535|0)==0){u=0;while(1){v=c[a+(u<<2)>>2]|0;if((v|0)<0){r=-1094995529;break a}w=c[o+(u<<2)>>2]|0;if((w|0)>(v|0)){r=-1094995529;break a}jT(c[c[m>>2]>>2]|0,w+(c[q+(u<<2)>>2]|0)|0,0,u,0,v-w|0,0,1)|0;w=u+1|0;if(w>>>0<g>>>0){u=w}else{r=0;break a}}}else{x=0;y=0}while(1){u=a+(y<<2)|0;w=c[u>>2]|0;if((w|0)<0){r=-1094995529;break a}v=o+(y<<2)|0;z=c[v>>2]|0;if((z|0)>(w|0)){r=-1094995529;break a}if((z|0)==0){A=x;B=0;C=w;D=q+(y<<2)|0}else{w=q+(y<<2)|0;jT(c[(c[m>>2]|0)+4>>2]|0,c[w>>2]|0,0,x,0,z,0,1)|0;z=c[v>>2]|0;A=((z|0)/(f|0)|0)+x|0;B=z;C=c[u>>2]|0;D=w}jT(c[c[m>>2]>>2]|0,B+(c[D>>2]|0)|0,0,y,0,C-B|0,0,1)|0;w=y+1|0;if(w>>>0<g>>>0){x=A;y=w}else{r=0;break}}}}while(0);ZDb(p);ZDb(k);ZDb(e);h=r;i=b;return h|0}function PO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=c[a+24>>2]|0;if((f|0)==0){g=-541478725;return g|0}h=d;i=c[a+28>>2]|0;a=0;j=0;k=-1;l=2147483647;m=-1;while(1){n=c[h+(j<<2)>>2]|0;o=c[i+(j<<2)>>2]|0;if(n>>>0<(c[o+404>>2]|0)>>>0){p=(c[o+400>>2]|0)+(n*24|0)|0;n=p|0;o=c[n>>2]|0;q=c[n+4>>2]|0;n=(q|0)<(l|0)|(q|0)==(l|0)&o>>>0<m>>>0;r=n?q:l;s=n?o:m;t=n?j:k;u=n?p:a}else{r=l;s=m;t=k;u=a}p=j+1|0;if(p>>>0<f>>>0){a=u;j=p;k=t;l=r;m=s}else{break}}if((t|0)==-1){g=-541478725;return g|0}s=d+(t<<2)|0;c[s>>2]=(c[s>>2]|0)+1;s=u|0;Ty(e,c[s>>2]|0,c[s+4>>2]|0,0)|0;s=u+16|0;d=TS(e,b,c[s>>2]>>2)|0;if((d|0)==(c[s>>2]>>2|0)){c[b+32>>2]=t;t=u+8|0;u=c[t+4>>2]|0;s=b+8|0;c[s>>2]=c[t>>2];c[s+4>>2]=u;g=d;return g|0}else{BZ(b);g=-5;return g|0}return 0}function QO(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a+28|0;h=c[(c[g>>2]|0)+(b<<2)>>2]|0;i=c[a+12>>2]|0;j=oT(h,d,e,f)|0;if((j|0)<0){k=-1;return k|0}e=i;c[e+(b<<2)>>2]=j;b=(c[h+400>>2]|0)+(j*24|0)+8|0;j=c[b>>2]|0;i=c[b+4>>2]|0;b=a+24|0;if((c[b>>2]|0)==0){k=0;return k|0}a=h+40|0;h=f|1;f=0;while(1){d=c[(c[g>>2]|0)+(f<<2)>>2]|0;l=KDb(j,i,a,d+40|0)|0;m=oT(d,l,F,h)|0;c[e+(f<<2)>>2]=(m|0)<0?0:m;m=f+1|0;if(m>>>0<(c[b>>2]|0)>>>0){f=m}else{k=0;break}}return k|0}function RO(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;k=i;i=i+256|0;l=k|0;m=k+128|0;MT(f,64,1,1e3);n=Ty(e,0,0,1)|0;o=F;p=vz(e)|0;a:do{if((p|0)==779248125){if((SO(b,e,f,g,0)|0)==0){break}else{q=-1}i=k;return q|0}else if((p|0)==1280525370){Ty(e,-4,-1,1)|0;r=f+8|0;if(h>>>0>16777215>>>0){q=-1;i=k;return q|0}s=(CT(c[r>>2]|0,e,h)|0)>>31&-12;if((s|0)<0){q=s;i=k;return q|0}else{s=c[r>>2]|0;c[s+8>>2]=1;t=c[s+96>>2]|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[s+52>>2]=u;s=vT(1146720,u)|0;c[(c[r>>2]|0)+48>>2]=s;break}}else{do{if((j|0)!=0){if((QGb(j,1906392)|0)!=0){break}JT(b,f);if((tz(e)|0)!=0){yDb(b,24,2214752,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;break a}s=(tz(e)|0)*6|0;Vy(e,s,(s|0)<0|0?-1:0)|0;s=(tz(e)|0)<<1;Vy(e,s,(s|0)<0|0?-1:0)|0;s=tz(e)|0;if((s|0)<=0){break a}r=l|0;u=m|0;t=b+1140|0;w=0;while(1){vz(e)|0;if((tz(e)|0)!=0){break}x=lz(e)|0;if((x|0)>0){y=r;z=0;while(1){A=lz(e)|0;if((z|0)<127){a[y]=A;B=y+1|0}else{B=y}A=z+1|0;if((A|0)<(x|0)){y=B;z=A}else{C=B;break}}}else{C=r}a[C]=0;z=(vz(e)|0)==2;y=tz(e)|0;if(z){if((y|0)>0){z=u;x=0;while(1){A=lz(e)|0;if((x|0)<127){a[z]=A;D=z+1|0}else{D=z}A=x+1|0;if((A|0)<(y|0)){z=D;x=A}else{E=D;break}}}else{E=u}a[E]=0;CBb(t,r,u,0)|0}else{Vy(e,y,0)|0;}w=w+1|0;if((w|0)>=(s|0)){break a}}yDb(b,24,2129792,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;break a}}while(0);do{if((rz(e)|0)==1329875286){s=rz(e)|0;w=f+8|0;c[(c[w>>2]|0)+52>>2]=s;u=vT(1146720,s)|0;c[(c[w>>2]|0)+48>>2]=u;if((u|0)==0){break}u=tz(e)|0;c[(c[w>>2]|0)+120>>2]=u;u=tz(e)|0;c[(c[w>>2]|0)+124>>2]=u;Vy(e,2,0)|0;Vy(e,4,0)|0;c[(c[w>>2]|0)+8>>2]=0;c[f+236>>2]=3;u=vz(e)|0;s=c[w>>2]|0;w=Ty(e,0,0,1)|0;r=F;t=YGb(n,o,h,0)|0;x=ZGb(t,F,w,r)|0;r=x;if(r>>>0>16777215>>>0){q=-1;i=k;return q|0}x=(CT(s,e,r)|0)>>31&-12;if((x|0)<0){q=x;i=k;return q|0}if((u|0)>0){x=f+92|0;iFb(f+96|0,x|0,65536,0,u,(u|0)<0|0?-1:0,1073741823,0)|0;u=x;x=f+412|0;r=c[u+4>>2]|0;c[x>>2]=c[u>>2];c[x+4>>2]=r;break a}if((c[b+1156>>2]&8|0)==0){break a}yDb(b,16,2020048,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;q=-1094995529;i=k;return q|0}}while(0);yDb(b,24,2066536,(v=i,i=i+8|0,c[v>>2]=p,v)|0);i=v}}while(0);v=Ty(e,0,0,1)|0;p=ZGb(v,F,n,o)|0;o=h-p|0;Vy(e,o,(o|0)<0|0?-1:0)|0;q=0;i=k;return q|0}function SO(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;j=i;i=i+256|0;k=j|0;l=k|0;m=tz(e)|0;if((m|0)==3){n=tz(e)|0;o=Ty(e,0,0,1)|0;p=F;Vy(e,8,0)|0;q=tz(e)|0;Vy(e,4,0)|0;aP(b,e,0);r=YGb(o,p,n,(n|0)<0|0?-1:0)|0;n=F;p=Ty(e,0,0,1)|0;o=YGb(p,F,2,0)|0;p=F;if(!((n|0)<(p|0)|(n|0)==(p|0)&r>>>0<o>>>0)){lz(e)|0;o=k;p=lz(e)|0;if((p|0)>0){s=o;t=0;while(1){u=lz(e)|0;if((t|0)<255){a[s]=u;v=s+1|0}else{v=s}u=t+1|0;if((u|0)<(p|0)){s=v;t=u}else{w=v;break}}}else{w=o}a[w]=0}w=Ty(e,0,0,1)|0;o=F;if((n|0)>(o|0)|(n|0)==(o|0)&r>>>0>w>>>0){w=Ty(e,0,0,1)|0;o=ZGb(r,n,w,F)|0;Vy(e,o,F)|0;}if((q|0)==0){x=c[f+8>>2]|0}else{o=q;q=hHb(o<<3|0>>>29,0<<3|o>>>29,60,0)|0;o=c[f+8>>2]|0;c[o+72>>2]=q;x=o}c[x+412>>2]=8e3;c[x+416>>2]=1;o=x+448|0;c[o>>2]=4;c[o+4>>2]=0;c[x+8>>2]=1;c[x+48>>2]=77824;c[g+204>>2]=812936777;y=0;i=j;return y|0}Vy(e,2,0)|0;vz(e)|0;vz(e)|0;tz(e)|0;vz(e)|0;x=tz(e)|0;o=vz(e)|0;q=g+132|0;c[q>>2]=o;vz(e)|0;w=vz(e)|0;if((m|0)!=4|(w|0)==0){z=f+8|0}else{n=w;w=hHb(n<<3|0>>>29,0<<3|n>>>29,60,0)|0;n=f+8|0;c[(c[n>>2]|0)+72>>2]=w;z=n}vz(e)|0;n=tz(e)|0;c[g+128>>2]=n;w=tz(e)|0;c[(c[z>>2]|0)+432>>2]=w;w=tz(e)|0;r=g+124|0;c[r>>2]=w;tz(e)|0;v=(m|0)==5;m=tz(e)|0;if(v){tz(e)|0;tz(e)|0;t=tz(e)|0;c[(c[z>>2]|0)+412>>2]=t;vz(e)|0;t=tz(e)|0;c[(c[z>>2]|0)+416>>2]=t;c[g+204>>2]=rz(e)|0;mz(e,k,4)|0;a[k+4|0]=0}else{c[(c[z>>2]|0)+412>>2]=m;vz(e)|0;m=tz(e)|0;c[(c[z>>2]|0)+416>>2]=m;m=k;c[l>>2]=0;t=lz(e)|0;if((t|0)>0){s=m;p=0;while(1){u=lz(e)|0;if((p|0)<255){a[s]=u;A=s+1|0}else{A=s}u=p+1|0;if((u|0)<(t|0)){s=A;p=u}else{B=A;break}}}else{B=m}a[B]=0;c[g+204>>2]=c[l>>2];B=lz(e)|0;if((B|0)>0){A=m;p=0;while(1){s=lz(e)|0;if((p|0)<255){a[A]=s;C=A+1|0}else{C=A}s=p+1|0;if((s|0)<(B|0)){A=C;p=s}else{D=C;break}}}else{D=m}a[D]=0}D=c[z>>2]|0;c[D+8>>2]=1;m=c[l>>2]|0;c[D+52>>2]=m;D=vT(1146720,m)|0;m=c[z>>2]|0;c[m+48>>2]=D;do{if((D|0)==77825){c[m+100>>2]=0;l=m+432|0;c[g+136>>2]=c[l>>2];c[l>>2]=o}else if((D|0)==86036){c[f+236>>2]=2;E=32}else if((D|0)==86019){c[f+236>>2]=1}else if((D|0)==86047|(D|0)==86058){E=32}else if((D|0)==86018){tz(e)|0;lz(e)|0;if(v){lz(e)|0}l=vz(e)|0;if(l>>>0>4294967279>>>0){yDb(b,16,2153840,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;y=-1;i=j;return y|0}if((l|0)<=0){break}lz(e)|0;C=l-1|0;if(C>>>0>16777215>>>0){y=-1;i=j;return y|0}l=(CT(c[z>>2]|0,e,C)|0)>>31&-12;if((l|0)<0){y=l}else{break}i=j;return y|0}else{sAb(m+16|0,k,32)|0}}while(0);do{if((E|0)==32){do{if((h|0)==0){tz(e)|0;lz(e)|0;if(v){lz(e)|0}k=vz(e)|0;if(!(k>>>0>4294967279>>>0)){f=c[z>>2]|0;H=k;I=f;J=c[f+48>>2]|0;break}yDb(b,16,2153840,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;y=-1;i=j;return y|0}else{H=0;I=m;J=D}}while(0);f=I+432|0;c[g+136>>2]=c[f>>2];do{if((J|0)==86058){if((x|0)<=3){K=d[1138112+x|0]|0;break}yDb(b,16,2146576,(G=i,i=i+8|0,c[G>>2]=x,G)|0);i=G;y=-1;i=j;return y|0}else{if((w|0)>=1){K=c[r>>2]|0;break}yDb(b,16,2140512,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;y=-1;i=j;return y|0}}while(0);c[f>>2]=K;if(H>>>0>16777215>>>0){y=-1;i=j;return y|0}k=(CT(I,e,H)|0)>>31&-12;if((k|0)<0){y=k}else{break}i=j;return y|0}}while(0);H=c[g+204>>2]|0;do{if((H|0)==880045641){I=c[q>>2]|0;K=c[g+136>>2]|0;if((I|0)>(K|0)|(n|0)<2){y=-1094995529;i=j;return y|0}w=ba(I,n)|0;if((w|0)>(ba(K,n&1|2)|0)){y=-1094995529;i=j;return y|0}if((w|0)==(K<<1|0)){E=64;break}DDb(b,2134232,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;y=-1094995529;i=j;return y|0}else if((H|0)==1919969651){E=65}else if((H|0)==1919837543){K=c[r>>2]|0;if((K|0)<1){y=-1094995529;i=j;return y|0}w=c[g+136>>2]|0;if((K|0)>(w|0)){y=-1094995529;i=j;return y|0}if(((w|0)%(K|0)|0|0)==0){E=64;break}else{y=-1094995529}i=j;return y|0}else if(!((H|0)==812936777|(H|0)==1718772342|(H|0)==1936876150)){yDb(b,16,2128112,(G=i,i=i+8|0,c[G>>2]=H,G)|0);i=G;y=-1094995529;i=j;return y|0}}while(0);if((E|0)==64){if((H|0)==880045641|(H|0)==1919837543|(H|0)==1919969651){E=65}}do{if((E|0)==65){H=c[(c[z>>2]|0)+432>>2]|0;if((H|0)<1){y=-1094995529;i=j;return y|0}G=ba(c[g+136>>2]|0,n)|0;if((G|0)<0|(G|0)<(H|0)){y=-1094995529;i=j;return y|0}if((wZ(g|0,G)|0)<0){y=-12}else{break}i=j;return y|0}}while(0);if((h|0)==0){y=0;i=j;return y|0}lz(e)|0;lz(e)|0;lz(e)|0;aP(b,e,0);y=0;i=j;return y|0}function TO(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0;n=i;o=c[b+12>>2]|0;p=e+8|0;q=c[(c[p>>2]|0)+8>>2]|0;a:do{if((q|0)==0){c[o+8>>2]=c[e+4>>2];r=lz(d)|0;s=r>>6;t=(s|0)==3;if(t){u=g-1|0;v=0;w=4}else{y=lz(d)|0;z=g-2|0;if((s|0)==1){A=0;B=0;C=0;D=z;E=y}else{u=z;v=y;w=4}}if((w|0)==4){y=(tz(d)|0)&32767;if(y>>>0>16383>>>0){G=y-16384|0;H=u-2|0}else{G=tz(d)|0|y<<16;H=u-4|0}y=(tz(d)|0)&32767;if(y>>>0>16383>>>0){I=y-16384|0;J=H-2|0}else{I=tz(d)|0|y<<16;J=H-4|0}A=I;B=G;C=lz(d)|0;D=J-1|0;E=v}do{if((D|0)<0){yDb(b,16,2212096,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;L=-1}else{y=o+12|0;c[y>>2]=D;if((s&1|0)!=0){z=t?A:l;M=t?(A|0)<0|0?-1:0:m;N=t?B:D;if((D|0)<(N|0)){yDb(b,16,2202944,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;L=-1;break}c[y>>2]=D-N;if((wZ(h,N+9|0)|0)<0){L=-5;break}O=h+24|0;a[c[O>>2]|0]=0;P=(c[O>>2]|0)+1|0;x=1;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;P=(c[O>>2]|0)+5|0;x=0;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;P=mz(d,(c[O>>2]|0)+9|0,N)|0;if((P|0)==(N|0)){Q=M;R=z;break a}BZ(h);yDb(b,16,2195760,(K=i,i=i+8|0,c[K>>2]=N,K)|0);i=K;N=(P|0)<0?P:-5;if((N|0)==0){Q=M;R=z;break a}else{L=N;break}}c[j>>2]=E;if((E&127|0)==1){w=20}else{if((c[f+88>>2]|0)!=(C|0)){w=20}}if((w|0)==20){if((B|0)>(SS(d,B)|0)){yDb(b,16,2180672,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;L=-1094995529;break}N=r<<1&126|1;z=f+96|0;c[z>>2]=N;M=f+80|0;c[M>>2]=B+(N<<3|1);N=f|0;BZ(N);if((wZ(N,c[M>>2]|0)|0)<0){L=-12;break}TGb(c[f+24>>2]|0,0,c[f+28>>2]|0)|0;c[f+84>>2]=c[z>>2]<<3|1;c[f+92>>2]=0;c[f+88>>2]=C;z=Ty(d,0,0,1)|0;M=f+104|0;c[M>>2]=z;c[M+4>>2]=F}M=(s|0)==2;if(M){S=(D|0)>(A|0)?A:D}else{S=D}z=f+92|0;N=(c[z>>2]|0)+1|0;c[z>>2]=N;P=f+96|0;if((N|0)>(c[P>>2]|0)){yDb(b,16,2167896,(K=i,i=i+8|0,c[K>>2]=N,K)|0);i=K;L=1;break}O=f+24|0;T=c[O>>2]|0;if((T|0)==0){L=-12;break}U=T+((N<<3)-7)|0;x=1;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=f+84|0;N=(c[O>>2]|0)+((c[z>>2]<<3)-3)|0;x=(c[U>>2]|0)-1-(c[P>>2]<<3)|0;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;N=c[U>>2]|0;T=f+80|0;if((N+S|0)>(c[T>>2]|0)){yDb(b,16,2160632,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;L=1;break}if((mz(d,(c[O>>2]|0)+N|0,S)|0)!=(S|0)){L=-5;break}c[U>>2]=(c[U>>2]|0)+S;c[y>>2]=(c[y>>2]|0)-S;if(!M){if((c[U>>2]|0)!=(c[T>>2]|0)){L=1;break}}a[c[O>>2]|0]=(c[z>>2]|0)+255;UGb(h|0,f|0,80)|0;c[O>>2]=0;c[f+28>>2]=0;c[f>>2]=0;c[f+52>>2]=0;O=c[P>>2]|0;T=c[z>>2]|0;if((O|0)==(T|0)){V=O;W=O}else{M=c[h+24>>2]|0;y=O<<3;VGb(M+(T<<3|1)|0,M+(y|1)|0,(c[U>>2]|0)+~y|0)|0;V=c[z>>2]|0;W=c[P>>2]|0}c[h+28>>2]=(V-W<<3)+(c[U>>2]|0);U=h+8|0;c[U>>2]=0;c[U+4>>2]=-2147483648;U=f+104|0;z=c[U+4>>2]|0;y=h+64|0;c[y>>2]=c[U>>2];c[y+4>>2]=z;c[P>>2]=0;Q=m;R=l;break a}}while(0);X=(L|0)>-1?-1:L;i=n;return X|0}else if((q|0)==1){s=f+204|0;r=c[s>>2]|0;if((r|0)==1919837543|(r|0)==880045641|(r|0)==1919969651){t=c[f+124>>2]|0;P=c[f+132>>2]|0;z=c[f+128>>2]|0;y=f+120|0;U=c[y>>2]|0;M=c[f+136>>2]|0;if((k&2|0)==0){if((U|0)==0){w=43}else{Y=U}}else{c[y>>2]=0;w=43}if((w|0)==43){U=f+112|0;c[U>>2]=l;c[U+4>>2]=m;Y=0}do{if((r|0)==880045641){U=(z|0)/2|0;if((z|0)<=1){break}T=f+24|0;O=M<<1;N=ba(Y,P)|0;Z=b;_=0;do{$=c[T>>2]|0;aa=(ba(O,_)|0)+N|0;ca=$+aa|0;da=mz(d,ca,P)|0;if((da|0)!=(P|0)){if((da|0)>-1){TGb($+(da+aa)|0,0,P-da|0)|0}else{TGb(ca|0,0,P|0)|0}yDb(Z,16,2221328,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}_=_+1|0;}while((_|0)<(U|0))}else if((r|0)==1919837543){U=(M|0)/(t|0)|0;if((U|0)<=0){break}_=f+24|0;Z=((z+1|0)/2|0)&-(Y&1);N=Y>>1;O=b;T=0;do{ca=c[_>>2]|0;da=ba((ba(T,z)|0)+N+Z|0,t)|0;aa=ca+da|0;$=mz(d,aa,t)|0;if(($|0)!=(t|0)){if(($|0)>-1){TGb(ca+(da+$)|0,0,t-$|0)|0}else{TGb(aa|0,0,t|0)|0}yDb(O,16,2221328,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}T=T+1|0;}while((T|0)<(U|0))}else if((r|0)==1919969651){U=c[f+24>>2]|0;T=ba(Y,M)|0;O=U+T|0;Z=mz(d,O,M)|0;if((Z|0)==(M|0)){break}if((Z|0)>-1){TGb(U+(Z+T)|0,0,M-Z|0)|0}else{TGb(O|0,0,M|0)|0}yDb(b,16,2221328,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}}while(0);t=(c[y>>2]|0)+1|0;c[y>>2]=t;if((t|0)<(z|0)){X=-1;i=n;return X|0}if((c[s>>2]|0)==1919969651){gP(c[f+24>>2]|0,z,M)}c[y>>2]=0;c[o+16>>2]=c[e>>2];t=ba(M,z)|0;c[o+20>>2]=(t|0)/(c[(c[p>>2]|0)+432>>2]|0)|0;Q=m;R=l;break}else if((r|0)==1718772342|(r|0)==1936876150){c[o+16>>2]=c[e>>2];t=(tz(d)|0)>>>4&15;P=f+120|0;c[P>>2]=t;if((t|0)==0){X=-1;i=n;return X|0}else{ea=0}do{c[f+140+(ea<<2)>>2]=tz(d)|0;ea=ea+1|0;fa=c[P>>2]|0;}while((ea|0)<(fa|0));c[o+20>>2]=fa;P=f+112|0;c[P>>2]=l;c[P+4>>2]=m;Q=m;R=l;break}else{TS(d,h,g)|0;if((c[(c[p>>2]|0)+48>>2]|0)!=86019){Q=m;R=l;break}P=h+28|0;if((c[P>>2]|0)<=0){Q=m;R=l;break}r=0;z=c[h+24>>2]|0;while(1){M=z+1|0;y=a[M]|0;a[M]=a[z]|0;a[z]=y;y=r+2|0;if((y|0)<(c[P>>2]|0)){r=y;z=z+2|0}else{Q=m;R=l;break}}}}else{TS(d,h,g)|0;Q=m;R=l}}while(0);c[h+32>>2]=c[e>>2];e=h+8|0;c[e>>2]=R;c[e+4>>2]=Q;if((k&2|0)!=0){k=h+36|0;c[k>>2]=c[k>>2]|1}if((c[(c[p>>2]|0)+8>>2]|0)!=1){X=0;i=n;return X|0}X=c[o+20>>2]|0;i=n;return X|0}function UO(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=(c[a+12>>2]|0)+20|0;a=c[h>>2]|0;if((a|0)<=0){yDb(0,0,1977136,(j=i,i=i+24|0,c[j>>2]=1947880,c[j+8>>2]=1922664,c[j+16>>2]=900,j)|0);i=j;Cd();return 0}j=c[e+204>>2]|0;do{if((j|0)==1718772342|(j|0)==1936876150){TS(b,f,c[e+140+((c[e+120>>2]|0)-a<<2)>>2]|0)|0}else{k=d+8|0;if((wZ(f,c[(c[k>>2]|0)+432>>2]|0)|0)<0){l=-12;i=g;return l|0}else{m=c[(c[k>>2]|0)+432>>2]|0;k=(ba(c[e+136>>2]|0,c[e+128>>2]|0)|0)/(m|0)|0;UGb(c[f+24>>2]|0,(c[e+24>>2]|0)+(ba(k-(c[h>>2]|0)|0,m)|0)|0,m)|0;break}}}while(0);c[h>>2]=(c[h>>2]|0)-1;a=e+112|0;e=c[a>>2]|0;b=c[a+4>>2]|0;j=f+8|0;c[j>>2]=e;c[j+4>>2]=b;if((e|0)==0&(b|0)==(-2147483648|0)){c[f+36>>2]=0}else{c[a>>2]=0;c[a+4>>2]=-2147483648;c[f+36>>2]=1}c[f+32>>2]=c[d>>2];l=c[h>>2]|0;i=g;return l|0}function VO(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;b=(a[d]|0)==46;do{if(b){if((a[d+1|0]|0)==82){do{if((a[d+2|0]|0)==77){if((a[d+3|0]|0)!=70){break}if((a[d+4|0]|0)!=0){break}if((a[d+5|0]|0)==0){e=100}else{break}return e|0}}while(0);if(!b){break}}if((a[d+1|0]|0)!=114){break}if((a[d+2|0]|0)!=97){break}if((a[d+3|0]|0)==-3){e=100}else{break}return e|0}}while(0);e=0;return e|0}function WO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0;d=i;i=i+256|0;e=d|0;f=d+128|0;g=b+12|0;h=c[g>>2]|0;j=b+16|0;k=c[j>>2]|0;l=rz(k)|0;if((l|0)==1179472430){m=(vz(k)|0)-8|0;Vy(k,m,(m|0)<0|0?-1:0)|0;if((Xy(k)|0)!=0){n=-1;i=d;return n|0}m=e|0;e=f|0;f=b+1064|0;o=0;p=0;q=0;a:while(1){while(1){r=rz(k)|0;s=vz(k)|0;tz(k)|0;if(!((s|0)>9|(r|0)==1096040772)){n=-1;t=52;break a}if((r|0)==1096040772){t=25;break a}else if((r|0)==1380992077){u=LT(b,0)|0;if((u|0)==0){n=-12;t=52;break a}c[u+4>>2]=tz(k)|0;vz(k)|0;v=vz(k)|0;w=u+8|0;c[(c[w>>2]|0)+72>>2]=v;vz(k)|0;vz(k)|0;v=vz(k)|0;vz(k)|0;x=vz(k)|0;y=u+48|0;c[y>>2]=v;c[y+4>>2]=0;y=u+56|0;c[y>>2]=x;c[y+4>>2]=0;if((x|0)!=0){c[f>>2]=0;c[f+4>>2]=-2147483648}x=lz(k)|0;if((x|0)>0){y=m;v=0;while(1){z=lz(k)|0;if((v|0)<127){a[y]=z;A=y+1|0}else{A=y}z=v+1|0;if((z|0)<(x|0)){y=A;v=z}else{B=A;break}}}else{B=m}a[B]=0;v=lz(k)|0;if((v|0)>0){y=e;x=0;while(1){z=lz(k)|0;if((x|0)<127){a[y]=z;C=y+1|0}else{C=y}z=x+1|0;if((z|0)<(v|0)){y=C;x=z}else{D=C;break}}}else{D=e}a[D]=0;c[(c[w>>2]|0)+8>>2]=2;x=cEb(208)|0;c[x+88>>2]=-1;c[u+12>>2]=x;y=c[j>>2]|0;if((RO(b,y,u,x,vz(k)|0,e)|0)<0){n=-1;t=52;break a}}else if((r|0)==1414418243){aP(b,k,1)}else if((r|0)==1347375696){break}else{x=s-10|0;Vy(k,x,(x|0)<0|0?-1:0)|0;}if((Xy(k)|0)!=0){n=-1;t=52;break a}}vz(k)|0;vz(k)|0;vz(k)|0;vz(k)|0;vz(k)|0;x=IDb(vz(k)|0,0,1e6,0,1e3,0)|0;c[f>>2]=x;c[f+4>>2]=F;vz(k)|0;x=vz(k)|0;y=vz(k)|0;tz(k)|0;v=tz(k)|0;if((Xy(k)|0)==0){o=y;p=x;q=v}else{n=-1;t=52;break}}if((t|0)==25){f=vz(k)|0;e=h;c[e>>2]=f;do{if((f|0)==0){if((q&4|0)==0){break}c[e>>2]=9e4}}while(0);vz(k)|0;if((o|0)==0){e=Ty(k,0,0,1)|0;q=YGb(e,F,-18,0)|0;E=q}else{E=o}if((p|0)==0){n=0;i=d;return n|0}if((c[k+88>>2]|0)==0){n=0;i=d;return n|0}if((c[b+1084>>2]&2|0)!=0){n=0;i=d;return n|0}o=Ty(k,p,0,0)|0;p=F;q=-1;if(!((p|0)>(q|0)|(p|0)==(q|0)&o>>>0>-1>>>0)){n=0;i=d;return n|0}o=c[j>>2]|0;b:do{if((rz(o)|0)==1480871497){q=b+28|0;p=b+24|0;e=b;f=0;while(1){if((vz(o)|0)>>>0<20>>>0){break b}Vy(o,2,0)|0;h=vz(o)|0;D=tz(o)|0;C=vz(o)|0;B=c[p>>2]|0;m=0;while(1){if(!(m>>>0<B>>>0)){G=f;break}A=c[(c[q>>2]|0)+(m<<2)>>2]|0;if((c[A+4>>2]|0)==(D|0)){G=A;break}else{m=m+1|0}}do{if((m|0)==(B|0)){s=Ty(o,0,0,1)|0;r=F;yDb(e,16,2262024,(H=i,i=i+24|0,c[H>>2]=D,c[H+8>>2]=s,c[H+16>>2]=r,H)|0);i=H}else{r=Wy(o)|0;s=F;u=Ty(o,0,0,1)|0;w=ZGb(r,s,u,F)|0;u=eHb(w,F,14,0)|0;w=F;s=0;if((w|0)<(s|0)|(w|0)==(s|0)&u>>>0<h>>>0){u=Wy(o)|0;s=F;w=Ty(o,0,0,1)|0;r=F;A=Wy(o)|0;v=F;x=Ty(o,0,0,1)|0;y=ZGb(A,v,x,F)|0;x=eHb(y,F,14,0)|0;y=F;yDb(e,16,2247416,(H=i,i=i+56|0,c[H>>2]=D,c[H+8>>2]=u,c[H+16>>2]=s,c[H+24>>2]=w,c[H+32>>2]=r,c[H+40>>2]=x,c[H+48>>2]=y,H)|0);i=H;break}if((h|0)==0){break}else{I=0}do{Vy(o,2,0)|0;y=vz(o)|0;x=vz(o)|0;Vy(o,4,0)|0;jT(G,x,0,y,0,0,0,1)|0;I=I+1|0;}while(I>>>0<h>>>0)}}while(0);if((C|0)==0){break b}h=Ty(o,0,0,1)|0;D=F;B=C;m=0;if((D|0)<(m|0)|(D|0)==(m|0)&h>>>0<B>>>0){h=Ty(o,B,m,0)|0;m=F;B=0;if((m|0)<(B|0)|(m|0)==(B|0)&h>>>0<0>>>0){break}}if((rz(o)|0)==1480871497){f=G}else{break b}}yDb(e,16,2234688,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}}while(0);Ty(k,E+18|0,0,0)|0;n=0;i=d;return n|0}else if((t|0)==52){i=d;return n|0}}else if((l|0)==(-43945426|0)){c[(c[g>>2]|0)+4>>2]=1;g=LT(b,0)|0;if((g|0)==0){n=-1;i=d;return n|0}l=cEb(208)|0;c[l+88>>2]=-1;c[g+12>>2]=l;n=SO(b,c[j>>2]|0,g,l,1)|0;i=d;return n|0}else{n=-5;i=d;return n|0}return 0}function XO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+40|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=c[a+12>>2]|0;c[f>>2]=1;l=k+16|0;m=k+20|0;n=k+4|0;k=a+28|0;o=a+16|0;p=0;while(1){if((c[m>>2]|0)==0){do{if((c[n>>2]|0)==0){q=$O(a,g,j,e,h)|0;if((q|0)<=0){r=q;s=p;t=11;break}u=c[(c[k>>2]|0)+(c[e>>2]<<2)>>2]|0;v=q}else{q=c[c[k>>2]>>2]|0;w=c[q+12>>2]|0;c[g>>2]=0;c[g+4>>2]=-2147483648;if((c[w+136>>2]|0)==0){x=1e3}else{x=(ba(c[w+128>>2]|0,c[w+132>>2]|0)|0)/2|0}w=c[f>>2]|0;c[f>>2]=w+1;c[j>>2]=(w|0)==1?2:0;w=Ty(c[o>>2]|0,0,0,1)|0;c[h>>2]=w;c[h+4>>2]=F;r=x;s=q;t=11}}while(0);if((t|0)==11){t=0;if((r|0)<0){y=-5;t=21;break}else{u=s;v=r}}if((Xy(c[o>>2]|0)|0)!=0){y=-5;t=21;break}q=TO(a,c[o>>2]|0,u,c[u+12>>2]|0,v,b,f,c[j>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;if((q|0)<-1){y=q;t=21;break}w=c[j>>2]|0;do{if((w&2|0)!=0){if((c[f>>2]&127|0)!=1){break}jT(u,c[h>>2]|0,c[h+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0,0,0,1)|0}}while(0);if((q|0)==0){z=u;A=w}else{p=u;continue}}else{B=c[(c[k>>2]|0)+(c[l>>2]<<2)>>2]|0;C=UO(a,c[o>>2]|0,B,c[B+12>>2]|0,b)|0;if((C|0)<0){y=C;t=21;break}c[j>>2]=0;z=B;A=0}B=c[z+76>>2]|0;if((B|0)<=31){y=0;t=21;break}if(!((A&2|0)==0|(B|0)>47)){y=0;t=21;break}BZ(b);p=z}if((t|0)==21){i=d;return y|0}return 0}function YO(a){a=a|0;var b=0,d=0;b=a+24|0;if((c[b>>2]|0)==0){return 0}d=a+28|0;a=0;do{BZ(c[(c[(c[d>>2]|0)+(a<<2)>>2]|0)+12>>2]|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return 0}function ZO(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=c[a+12>>2]|0;if((pT(a,b,d,e,f)|0)<0){h=-1;return h|0}c[g+20>>2]=0;h=0;return h|0}function _O(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+32|0;e=f|0;g=f+8|0;h=f+16|0;j=f+24|0;k=c[a+12>>2]|0;l=c[d>>2]|0;m=c[d+4>>2]|0;c[e>>2]=l;c[e+4>>2]=m;if((c[k+4>>2]|0)!=0){n=-2147483648;o=0;i=f;return(F=n,o)|0}p=a+16|0;q=Ty(c[p>>2]|0,l,m,0)|0;m=F;l=0;if((m|0)<(l|0)|(m|0)==(l|0)&q>>>0<0>>>0){n=-2147483648;o=0;i=f;return(F=n,o)|0}c[k+12>>2]=0;k=$O(a,g,j,h,e)|0;if((k|0)<0){n=-2147483648;o=0;i=f;return(F=n,o)|0}q=a+28|0;l=k;while(1){k=c[h>>2]|0;m=c[(c[q>>2]|0)+(k<<2)>>2]|0;do{if((c[(c[m+8>>2]|0)+8>>2]|0)==0){if(((lz(c[p>>2]|0)|0)&64|0)!=0){r=1;s=l-1|0;break}r=((lz(c[p>>2]|0)|0)&127|0)==1;s=l-2|0}else{r=1;s=l}}while(0);if((c[j>>2]&2|0)!=0&r){t=c[e>>2]|0;u=c[e+4>>2]|0;v=c[g>>2]|0;w=c[g+4>>2]|0;jT(m,t,u,v,w,0,0,1)|0;if((k|0)==(b|0)){break}}Vy(c[p>>2]|0,s,(s|0)<0|0?-1:0)|0;x=$O(a,g,j,h,e)|0;if((x|0)<0){n=-2147483648;o=0;y=12;break}else{l=x}}if((y|0)==12){i=f;return(F=n,o)|0}c[d>>2]=t;c[d+4>>2]=u;n=w;o=v;i=f;return(F=n,o)|0}function $O(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;h=c[a+12>>2]|0;j=c[a+16>>2]|0;if((Xy(j)|0)!=0){k=-1;i=g;return k|0}l=h+12|0;m=h+8|0;h=a+28|0;n=a+24|0;o=a;a=-1;while(1){p=Ty(j,0,0,1)|0;q=YGb(p,F,-3,-1)|0;c[f>>2]=q;c[f+4>>2]=F;q=c[l>>2]|0;do{if((q|0)>0){p=c[m>>2]|0;c[b>>2]=0;c[b+4>>2]=-2147483648;r=a;s=p;t=q;u=0;v=13}else{p=(lz(j)|0)+(a<<8)|0;if((p|0)==1145132097){yDb(o,24,2277648,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=1145132097;break}else if((p|0)==1229866072){y=vz(j)|0;Vy(j,2,0)|0;z=vz(j)|0;A=(z*14|0)+20|0;do{if((y|0)==20){B=A}else{if((y|0)==(A|0)){B=y;break}yDb(o,24,2294144,(w=i,i=i+24|0,c[w>>2]=y,c[w+8>>2]=z,c[w+16>>2]=A,w)|0);i=w;B=y}}while(0);y=B-14|0;if((y|0)<0){x=1229866072;break}else{C=1229866072;D=y;v=17;break}}else{if((p-13|0)>>>0>65522>>>0){x=p;break}y=tz(j)|0;c[b>>2]=vz(j)|0;c[b+4>>2]=0;lz(j)|0;r=-1;s=y;t=p-12|0;u=lz(j)|0;v=13;break}}}while(0);if((v|0)==13){v=0;c[d>>2]=u;q=c[n>>2]|0;E=0;while(1){if(!(E>>>0<q>>>0)){break}if((s|0)==(c[(c[(c[h>>2]|0)+(E<<2)>>2]|0)+4>>2]|0)){break}else{E=E+1|0}}if((E|0)==(q|0)){C=r;D=t;v=17}else{break}}if((v|0)==17){v=0;Vy(j,D,(D|0)<0|0?-1:0)|0;c[l>>2]=0;x=C}if((Xy(j)|0)==0){a=x}else{k=-1;v=20;break}}if((v|0)==20){i=g;return k|0}c[e>>2]=E;k=t;i=g;return k|0}function aP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+1024|0;g=f|0;h=b+1140|0;if((e|0)==0){e=lz(d)|0;if((e|0)>0){b=g;j=0;while(1){k=lz(d)|0;if((j|0)<1023){a[b]=k;l=b+1|0}else{l=b}k=j+1|0;if((k|0)<(e|0)){b=l;j=k}else{m=l;break}}}else{m=g}a[m]=0;CBb(h,c[286656]|0,g,0)|0;m=lz(d)|0;if((m|0)>0){l=g;j=0;while(1){b=lz(d)|0;if((j|0)<1023){a[l]=b;n=l+1|0}else{n=l}b=j+1|0;if((b|0)<(m|0)){l=n;j=b}else{o=n;break}}}else{o=g}a[o]=0;CBb(h,c[286657]|0,g,0)|0;o=lz(d)|0;if((o|0)>0){n=g;j=0;while(1){l=lz(d)|0;if((j|0)<1023){a[n]=l;p=n+1|0}else{p=n}l=j+1|0;if((l|0)<(o|0)){n=p;j=l}else{q=p;break}}}else{q=g}a[q]=0;CBb(h,c[286658]|0,g,0)|0;q=lz(d)|0;if((q|0)>0){p=g;j=0;while(1){n=lz(d)|0;if((j|0)<1023){a[p]=n;r=p+1|0}else{r=p}n=j+1|0;if((n|0)<(q|0)){p=r;j=n}else{s=r;break}}}else{s=g}a[s]=0;CBb(h,c[286659]|0,g,0)|0;i=f;return}else{s=tz(d)|0;if((s|0)>0){r=g;j=0;while(1){p=lz(d)|0;if((j|0)<1023){a[r]=p;t=r+1|0}else{t=r}p=j+1|0;if((p|0)<(s|0)){r=t;j=p}else{u=t;break}}}else{u=g}a[u]=0;CBb(h,c[286656]|0,g,0)|0;u=tz(d)|0;if((u|0)>0){t=g;j=0;while(1){r=lz(d)|0;if((j|0)<1023){a[t]=r;v=t+1|0}else{v=t}r=j+1|0;if((r|0)<(u|0)){t=v;j=r}else{w=v;break}}}else{w=g}a[w]=0;CBb(h,c[286657]|0,g,0)|0;w=tz(d)|0;if((w|0)>0){v=g;j=0;while(1){t=lz(d)|0;if((j|0)<1023){a[v]=t;x=v+1|0}else{x=v}t=j+1|0;if((t|0)<(w|0)){v=x;j=t}else{y=x;break}}}else{y=g}a[y]=0;CBb(h,c[286658]|0,g,0)|0;y=tz(d)|0;if((y|0)>0){x=g;j=0;while(1){v=lz(d)|0;if((j|0)<1023){a[x]=v;z=x+1|0}else{z=x}v=j+1|0;if((v|0)<(y|0)){x=z;j=v}else{A=z;break}}}else{A=g}a[A]=0;CBb(h,c[286659]|0,g,0)|0;i=f;return}}function bP(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=c[a+12>>2]|0;e=a+24|0;f=c[e>>2]|0;if(f>>>0>2>>>0){yDb(a,16,2180608,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=b;return j|0}a:do{if((f|0)!=0){h=a+28|0;k=d;l=d+72|0;m=d+76|0;n=0;while(1){o=c[(c[h>>2]|0)+(n<<2)>>2]|0;c[o+4>>2]=n;p=c[o+8>>2]|0;o=k+(n*36|0)|0;TGb(o|0,0,36)|0;c[k+(n*36|0)+28>>2]=n;c[k+(n*36|0)+12>>2]=c[p+72>>2];c[k+(n*36|0)+32>>2]=p;q=c[p+8>>2]|0;if((q|0)==1){c[l>>2]=o;g[k+(n*36|0)+16>>2]=+(c[p+412>>2]|0)/+(c[p+424>>2]|0);c[k+(n*36|0)+8>>2]=1024;c[o>>2]=0;c[k+(n*36|0)+24>>2]=0}else if((q|0)==0){c[m>>2]=o;g[k+(n*36|0)+16>>2]=+(c[p+108>>2]|0)/+(c[p+104>>2]|0);c[k+(n*36|0)+8>>2]=4096;c[o>>2]=0;c[k+(n*36|0)+24>>2]=0}else{j=-1;break}n=n+1|0;if(!(n>>>0<(c[e>>2]|0)>>>0)){break a}}i=b;return j|0}}while(0);if((eP(a,0)|0)!=0){j=-1094995529;i=b;return j|0}Sy(c[a+16>>2]|0);j=0;i=b;return j|0}function cP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[d+24>>2]|0;f=c[d+28>>2]|0;g=c[d+36>>2]|0;h=c[b+12>>2]|0;i=b+16|0;j=c[i>>2]|0;if((c[(c[(c[(c[b+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==1){d=c[h+72>>2]|0;b=WDb(f)|0;fP(c[i>>2]|0,d,f,g&1);if((c[(c[d+32>>2]|0)+48>>2]|0)==86019){if((f|0)>0){i=0;do{k=i|1;a[b+i|0]=a[e+k|0]|0;a[b+k|0]=a[e+i|0]|0;i=i+2|0;}while((i|0)<(f|0))}Ry(j,b,f)}else{Ry(j,e,f)}i=d+20|0;c[i>>2]=(c[i>>2]|0)+1;ZDb(b);return 0}b=c[h+76>>2]|0;h=g&1;g=(f|0)>16383;fP(j,b,f+7+((g&1)<<2)|0,h);Py(j,129);if((h|0)==0){Py(j,1)}else{Py(j,129)}if(g){Zy(j,f);Zy(j,f)}else{g=f|16384;fz(j,g);fz(j,g)}g=b+20|0;Py(j,c[g>>2]&255);Ry(j,e,f);c[g>>2]=(c[g>>2]|0)+1;return 0}function dP(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;if((c[d+88>>2]|0)==0){Zy(d,0);Zy(d,0);return 0}e=Ty(d,0,0,1)|0;f=e-(c[b+80>>2]|0)|0;Zy(d,0);Zy(d,0);Ty(d,0,0,0)|0;d=a+24|0;if((c[d>>2]|0)!=0){e=b;b=0;do{c[e+(b*36|0)+24>>2]=c[e+(b*36|0)+20>>2];b=b+1|0;}while(b>>>0<(c[d>>2]|0)>>>0)}eP(a,f)|0;return 0}function eP(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;f=c[b+12>>2]|0;h=c[b+16>>2]|0;j=h+12|0;k=c[j>>2]|0;Yy(h,1179472430);Zy(h,18);fz(h,0);Zy(h,0);l=b+24|0;Zy(h,(c[l>>2]|0)+4|0);Yy(h,1347375696);Zy(h,50);fz(h,0);m=c[l>>2]|0;if((m|0)==0){n=0;o=0;p=0;q=0;r=0}else{s=f;t=0;u=0;v=0;w=0;x=0;y=0;while(1){z=(c[s+(v*36|0)+12>>2]|0)+w|0;A=c[s+(v*36|0)+8>>2]|0;B=(A|0)>(u|0)?A:u;A=(c[s+(v*36|0)>>2]|0)+x|0;C=(c[s+(v*36|0)+4>>2]|0)+t|0;D=~~(+(c[s+(v*36|0)+24>>2]|0)*1.0e3/+g[s+(v*36|0)+16>>2]);E=(D|0)>(y|0)?D:y;D=v+1|0;if(D>>>0<m>>>0){t=C;u=B;v=D;w=z;x=A;y=E}else{n=C;o=B;p=z;q=A;r=E;break}}}Zy(h,p);Zy(h,p);Zy(h,o);if((q|0)>0){F=(n|0)/(q|0)|0}else{F=0}Zy(h,F);Zy(h,q);Zy(h,r);Zy(h,0);Zy(h,0);r=c[j>>2]|0;Zy(h,0);fz(h,c[l>>2]|0);F=h+88|0;fz(h,(c[F>>2]|0)==0?7:3);Yy(h,1414418243);n=b+1140|0;o=c[286656]|0;p=BBb(c[n>>2]|0,o,0,0)|0;if((p|0)==0){G=18}else{G=(SGb(c[p+4>>2]|0)|0)+18|0}p=c[286657]|0;y=BBb(c[n>>2]|0,p,0,0)|0;if((y|0)==0){H=G}else{H=(SGb(c[y+4>>2]|0)|0)+G|0}G=c[286658]|0;y=BBb(c[n>>2]|0,G,0,0)|0;if((y|0)==0){I=H}else{I=(SGb(c[y+4>>2]|0)|0)+H|0}H=c[286659]|0;y=BBb(c[n>>2]|0,H,0,0)|0;if((y|0)==0){J=I}else{J=(SGb(c[y+4>>2]|0)|0)+I|0}Zy(h,J);fz(h,0);J=BBb(c[n>>2]|0,o,0,0)|0;if((J|0)==0){K=9203072}else{K=c[J+4>>2]|0}fz(h,SGb(K|0)|0);J=a[K]|0;if(!(J<<24>>24==0)){o=K;K=J;do{o=o+1|0;Py(h,K<<24>>24);K=a[o]|0;}while(!(K<<24>>24==0))}K=BBb(c[n>>2]|0,p,0,0)|0;if((K|0)==0){L=9203072}else{L=c[K+4>>2]|0}fz(h,SGb(L|0)|0);K=a[L]|0;if(!(K<<24>>24==0)){p=L;L=K;do{p=p+1|0;Py(h,L<<24>>24);L=a[p]|0;}while(!(L<<24>>24==0))}L=BBb(c[n>>2]|0,G,0,0)|0;if((L|0)==0){M=9203072}else{M=c[L+4>>2]|0}fz(h,SGb(M|0)|0);L=a[M]|0;if(!(L<<24>>24==0)){G=M;M=L;do{G=G+1|0;Py(h,M<<24>>24);M=a[G]|0;}while(!(M<<24>>24==0))}M=BBb(c[n>>2]|0,H,0,0)|0;if((M|0)==0){N=9203072}else{N=c[M+4>>2]|0}fz(h,SGb(N|0)|0);M=a[N]|0;if(!(M<<24>>24==0)){H=N;N=M;do{H=H+1|0;Py(h,N<<24>>24);N=a[H]|0;}while(!(N<<24>>24==0))}a:do{if((c[l>>2]|0)!=0){N=f;H=0;b:while(1){M=N+(H*36|0)+32|0;n=(c[(c[M>>2]|0)+8>>2]|0)==1;G=n?1881072:2314656;L=n?1901208:2339096;p=n?73:34;Yy(h,1380992077);Zy(h,p+82|0);fz(h,0);fz(h,H);n=N+(H*36|0)+12|0;Zy(h,c[n>>2]|0);Zy(h,c[n>>2]|0);Zy(h,c[N+(H*36|0)+8>>2]|0);n=c[N+(H*36|0)>>2]|0;if((n|0)>0){O=(c[N+(H*36|0)+4>>2]|0)/(n|0)|0}else{O=0}Zy(h,O);Zy(h,0);Zy(h,0);do{if((c[F>>2]|0)==0){P=18}else{n=c[N+(H*36|0)+24>>2]|0;if((n|0)==0){P=18;break}Zy(h,~~(+(n*1e3|0|0)/+g[N+(H*36|0)+16>>2]))}}while(0);if((P|0)==18){P=0;Zy(h,36e5)}Py(h,16);n=a[L]|0;if(!(n<<24>>24==0)){K=L;o=n;do{K=K+1|0;Py(h,o<<24>>24);o=a[K]|0;}while(!(o<<24>>24==0))}Py(h,20);o=a[G]|0;if(!(o<<24>>24==0)){K=G;L=o;do{K=K+1|0;Py(h,L<<24>>24);L=a[K]|0;}while(!(L<<24>>24==0))}Zy(h,p);L=c[M>>2]|0;do{if((c[L+8>>2]|0)==1){K=c[L+412>>2]|0;G=(ba(c[L+424>>2]|0,c[L+72>>2]|0)|0)/(K<<3|0)|0;Ry(h,2277632,3);Py(h,253);Zy(h,262144);Yy(h,878801454);Zy(h,28652848);fz(h,4);Zy(h,57);if((K|0)==48e3|(K|0)==24e3|(K|0)==12e3){Q=1}else if((K|0)==8e3|(K|0)==16e3|(K|0)==32e3){Q=3}else{Q=2}fz(h,Q);K=(((G|0)==557)<<31>>31)+G|0;Zy(h,K);Zy(h,333120);Zy(h,((c[(c[M>>2]|0)+72>>2]|0)/8|0)*60|0);Zy(h,((c[(c[M>>2]|0)+72>>2]|0)/8|0)*60|0);fz(h,1);fz(h,K);Zy(h,0);fz(h,c[(c[M>>2]|0)+412>>2]|0);Zy(h,16);fz(h,c[(c[M>>2]|0)+416>>2]|0);Py(h,4);Py(h,73);Py(h,110);Py(h,116);Py(h,48);if((c[(c[M>>2]|0)+52>>2]|0)==0){break b}Py(h,4);Yy(h,c[(c[M>>2]|0)+52>>2]|0);fz(h,0);fz(h,0);fz(h,0);Py(h,0)}else{Zy(h,34);Yy(h,1329875286);if((c[(c[M>>2]|0)+48>>2]|0)==6){Yy(h,808539730)}else{Yy(h,808605266)}fz(h,c[(c[M>>2]|0)+120>>2]|0);fz(h,c[(c[M>>2]|0)+124>>2]|0);K=N+(H*36|0)+16|0;fz(h,~~+g[K>>2]);Zy(h,0);fz(h,~~+g[K>>2]);Zy(h,0);fz(h,8);if((c[(c[M>>2]|0)+48>>2]|0)==6){Zy(h,268435456);break}else{Zy(h,537931777);break}}}while(0);H=H+1|0;if(!(H>>>0<(c[l>>2]|0)>>>0)){break a}}yDb(b,16,2234664,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;R=-1;i=e;return R|0}}while(0);b=(c[j>>2]|0)-k|0;c[f+80>>2]=b;a[r]=b>>>24;a[r+1|0]=b>>>16;a[r+2|0]=b>>>8;a[r+3|0]=b;Yy(h,1096040772);Zy(h,d+18|0);fz(h,0);Zy(h,q);Zy(h,0);R=0;i=e;return R|0}function fP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=b|0;c[f>>2]=(c[f>>2]|0)+1;f=b+4|0;c[f>>2]=(c[f>>2]|0)+d;f=b+8|0;if((c[f>>2]|0)<(d|0)){c[f>>2]=d}fz(a,0);fz(a,d+12|0);fz(a,c[b+28>>2]|0);Zy(a,~~(+(c[b+20>>2]|0)*1.0e3/+g[b+16>>2]));Py(a,0);Py(a,(e|0)!=0?2:0);return}function gP(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=ba(c<<1,e)|0;e=(f|0)/96|0;if((f|0)>95){g=0}else{return}do{f=ba(d[436064+(g<<1)|0]|0,e)|0;c=ba(d[436065+(g<<1)|0]|0,e)|0;h=0;while(1){i=b+(f>>1)|0;j=f<<2&4;k=b+(c>>1)|0;l=d[k]|0;m=c<<2&4;a[k]=((d[i]|0)>>>(j>>>0)&15)<<m|l&15<<(m^4);a[i]=(l>>>(m>>>0)&15)<<j|(d[i]|0)&15<<(j^4);j=h+1|0;if((j|0)<(e|0)){f=f+1|0;c=c+1|0;h=j}else{break}}g=g+1|0;}while((g|0)<38);return}function hP(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,1881056,8)|0)==0;return(b?100:0)|0}function iP(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0;d=i;i=i+544|0;e=d|0;f=d+8|0;g=d+264|0;h=d+520|0;j=d+528|0;k=d+536|0;l=c[b+16>>2]|0;m=c[b+12>>2]|0;n=g|0;o=0;while(1){p=lz(l)|0;if((p|0)==0){q=o;r=5;break}else if((p|0)==10){r=3;break}a[g+o|0]=p;p=o+1|0;if((p|0)<255){o=p}else{q=p;r=5;break}}if((r|0)==3){a[g+o|0]=0;s=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==5){a[g+q|0]=0;s=-1}q=0;while(1){o=lz(l)|0;if((o|0)==0){t=q;r=10;break}else if((o|0)==10){r=8;break}a[g+q|0]=o;o=q+1|0;if((o|0)<255){q=o}else{t=o;r=10;break}}if((r|0)==8){a[g+q|0]=0;u=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==10){a[g+t|0]=0;u=-1}t=u|s;s=b+1140|0;CBb(s,2129632,n,0)|0;u=0;while(1){q=lz(l)|0;if((q|0)==10){r=13;break}else if((q|0)==0){v=u;r=15;break}a[g+u|0]=q;q=u+1|0;if((q|0)<255){u=q}else{v=q;r=15;break}}if((r|0)==13){a[g+u|0]=0;w=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==15){a[g+v|0]=0;w=-1}v=t|w;CBb(s,2066448,n,0)|0;w=0;while(1){t=lz(l)|0;if((t|0)==10){r=18;break}else if((t|0)==0){x=w;r=20;break}a[g+w|0]=t;t=w+1|0;if((t|0)<255){w=t}else{x=t;r=20;break}}if((r|0)==18){a[g+w|0]=0;y=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==20){a[g+x|0]=0;y=-1}x=v|y;CBb(s,2019952,n,0)|0;s=LT(b,0)|0;if((s|0)==0){z=-12;i=d;return z|0}y=s+8|0;c[(c[y>>2]|0)+8>>2]=0;v=f|0;w=0;while(1){t=lz(l)|0;if((t|0)==10){r=24;break}else if((t|0)==0){A=w;r=26;break}a[f+w|0]=t;t=w+1|0;if((t|0)<255){w=t}else{A=t;r=26;break}}if((r|0)==24){a[f+w|0]=0;B=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==26){a[f+A|0]=0;B=-1}A=x|B;B=a[v]|0;if((B-48&255)>>>0<10>>>0){x=v;w=0;t=B;B=A;while(1){u=w>>>0>214748363>>>0?-1:B;q=(w*10|0)-48+(t<<24>>24)|0;o=x+1|0;p=a[o]|0;if((p-48&255)>>>0<10>>>0){x=o;w=q;t=p;B=u}else{C=q;D=u;break}}}else{C=0;D=A}c[(c[y>>2]|0)+52>>2]=C;C=0;while(1){A=lz(l)|0;if((A|0)==10){r=31;break}else if((A|0)==0){E=C;r=33;break}a[f+C|0]=A;A=C+1|0;if((A|0)<255){C=A}else{E=A;r=33;break}}if((r|0)==31){a[f+C|0]=0;G=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==33){a[f+E|0]=0;G=-1}E=G|D;D=a[v]|0;if((D-48&255)>>>0<10>>>0){G=v;C=0;A=D;D=E;while(1){B=C>>>0>214748363>>>0?-1:D;t=(C*10|0)-48+(A<<24>>24)|0;w=G+1|0;x=a[w]|0;if((x-48&255)>>>0<10>>>0){G=w;C=t;A=x;D=B}else{H=t;I=B;break}}}else{H=0;I=E}c[(c[y>>2]|0)+120>>2]=H;H=0;while(1){E=lz(l)|0;if((E|0)==0){J=H;r=40;break}else if((E|0)==10){r=38;break}a[f+H|0]=E;E=H+1|0;if((E|0)<255){H=E}else{J=E;r=40;break}}if((r|0)==38){a[f+H|0]=0;K=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==40){a[f+J|0]=0;K=-1}J=K|I;I=a[v]|0;if((I-48&255)>>>0<10>>>0){K=v;H=0;E=I;I=J;while(1){D=H>>>0>214748363>>>0?-1:I;A=(H*10|0)-48+(E<<24>>24)|0;C=K+1|0;G=a[C]|0;if((G-48&255)>>>0<10>>>0){K=C;H=A;E=G;I=D}else{L=A;M=D;break}}}else{L=0;M=J}c[(c[y>>2]|0)+124>>2]=L;L=0;while(1){J=lz(l)|0;if((J|0)==10){r=45;break}else if((J|0)==0){N=L;r=47;break}a[f+L|0]=J;J=L+1|0;if((J|0)<255){L=J}else{N=J;r=47;break}}if((r|0)==45){a[f+L|0]=0;O=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==47){a[f+N|0]=0;O=-1}N=O|M;M=a[v]|0;if((M-48&255)>>>0<10>>>0){O=v;L=0;J=M;M=N;while(1){I=L>>>0>214748363>>>0?-1:M;E=(L*10|0)-48+(J<<24>>24)|0;H=O+1|0;K=a[H]|0;if((K-48&255)>>>0<10>>>0){O=H;L=E;J=K;M=I}else{P=E;Q=I;break}}}else{P=0;Q=N}c[(c[y>>2]|0)+792>>2]=P;P=0;while(1){N=lz(l)|0;if((N|0)==0){R=P;r=54;break}else if((N|0)==10){r=52;break}a[g+P|0]=N;N=P+1|0;if((N|0)<255){P=N}else{R=N;r=54;break}}if((r|0)==52){a[g+P|0]=0;S=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==54){a[g+R|0]=0;S=-1}R=S|Q;Q=e;S=a[n]|0;if((S-48&255)>>>0<10>>>0){P=n;N=0;M=S;J=R;do{J=N>>>0>214748363>>>0?-1:J;N=(N*10|0)-48+(M<<24>>24)|0;P=P+1|0;M=a[P]|0;}while((M-48&255)>>>0<10>>>0);T=P;U=(N|0)<0|0?-1:0;V=N;W=M;X=J}else{T=n;U=0;V=0;W=S;X=R}R=W<<24>>24==46?T+1|0:T;T=a[R]|0;if((T-48&255)>>>0>9>>>0){Y=U;Z=V;_=0;$=1}else{W=R;R=U;U=V;V=0;S=1;J=T;while(1){T=gHb(U,R,10,0)|0;M=F;N=YGb(J<<24>>24,J<<24>>24<0|0?-1:0,-48,-1)|0;P=YGb(N,F,T,M)|0;M=F;T=gHb(S,V,10,0)|0;N=F;L=W+1|0;O=a[L]|0;I=214748364;E=214748364;if((O-48&255)>>>0>9>>>0|((M|0)>(I|0)|(M|0)==(I|0)&P>>>0>-858993461>>>0)|((N|0)>(E|0)|(N|0)==(E|0)&T>>>0>-858993460>>>0)){Y=M;Z=P;_=N;$=T;break}else{W=L;R=M;U=P;V=N;S=T;J=O}}}J=(Z|0)==0&(Y|0)==0?-1:X;iFb(e,Q+4|0,Z,Y,$,_,2147483647,0)|0;MT(s,32,c[e+4>>2]|0,c[e>>2]|0);e=c[y>>2]|0;_=c[e+52>>2]|0;if((_|0)==124){c[e+48>>2]=116;c[e+792>>2]=16;aa=0}else if((_|0)==130){c[e+48>>2]=1160852272;aa=0}else{EDb(b,1977040,(ca=i,i=i+8|0,c[ca>>2]=_,ca)|0);i=ca;c[(c[y>>2]|0)+48>>2]=0;aa=0}while(1){_=lz(l)|0;if((_|0)==10){r=65;break}else if((_|0)==0){da=aa;r=67;break}a[f+aa|0]=_;_=aa+1|0;if((_|0)<255){aa=_}else{da=_;r=67;break}}if((r|0)==65){a[f+aa|0]=0;ea=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==67){a[f+da|0]=0;ea=-1}da=ea|J;J=a[v]|0;do{if((J-48&255)>>>0<10>>>0){ea=v;aa=0;_=J;e=da;do{e=aa>>>0>214748363>>>0?-1:e;aa=(aa*10|0)-48+(_<<24>>24)|0;ea=ea+1|0;_=a[ea]|0;}while((_-48&255)>>>0<10>>>0);if((aa|0)==0){fa=e;r=69;break}_=LT(b,0)|0;if((_|0)==0){z=-12;i=d;return z|0}ea=_+8|0;$=c[ea>>2]|0;c[$+8>>2]=1;c[$+52>>2]=aa;$=0;while(1){Y=lz(l)|0;if((Y|0)==10){r=75;break}else if((Y|0)==0){ga=$;r=77;break}a[f+$|0]=Y;Y=$+1|0;if((Y|0)<255){$=Y}else{ga=Y;r=77;break}}if((r|0)==75){a[f+$|0]=0;ha=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==77){a[f+ga|0]=0;ha=-1}Y=ha|e;Z=a[v]|0;if((Z-48&255)>>>0<10>>>0){Q=v;X=0;S=Z;Z=Y;while(1){V=X>>>0>214748363>>>0?-1:Z;U=(X*10|0)-48+(S<<24>>24)|0;R=Q+1|0;W=a[R]|0;if((W-48&255)>>>0<10>>>0){Q=R;X=U;S=W;Z=V}else{ia=U;ja=V;break}}}else{ia=0;ja=Y}c[(c[ea>>2]|0)+412>>2]=ia;Z=0;while(1){S=lz(l)|0;if((S|0)==10){r=82;break}else if((S|0)==0){ka=Z;r=84;break}a[f+Z|0]=S;S=Z+1|0;if((S|0)<255){Z=S}else{ka=S;r=84;break}}if((r|0)==82){a[f+Z|0]=0;la=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==84){a[f+ka|0]=0;la=-1}Y=la|ja;S=a[v]|0;if((S-48&255)>>>0<10>>>0){X=v;Q=0;e=S;S=Y;while(1){$=Q>>>0>214748363>>>0?-1:S;V=(Q*10|0)-48+(e<<24>>24)|0;U=X+1|0;W=a[U]|0;if((W-48&255)>>>0<10>>>0){X=U;Q=V;e=W;S=$}else{ma=V;na=$;break}}}else{ma=0;na=Y}c[(c[ea>>2]|0)+416>>2]=ma;S=0;while(1){e=lz(l)|0;if((e|0)==10){r=89;break}else if((e|0)==0){oa=S;r=91;break}a[f+S|0]=e;e=S+1|0;if((e|0)<255){S=e}else{oa=e;r=91;break}}if((r|0)==89){a[f+S|0]=0;pa=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==91){a[f+oa|0]=0;pa=-1}Y=pa|na;e=a[v]|0;if((e-48&255)>>>0<10>>>0){Q=v;X=0;Z=e;e=Y;do{e=X>>>0>214748363>>>0?-1:e;X=(X*10|0)-48+(Z<<24>>24)|0;Q=Q+1|0;Z=a[Q]|0;}while((Z-48&255)>>>0<10>>>0);Z=c[ea>>2]|0;Q=Z+792|0;if((X|0)==0){qa=e;ra=Z;sa=Q;r=96}else{ta=X;ua=e;va=Z;wa=Q}}else{Q=c[ea>>2]|0;qa=Y;ra=Q;sa=Q+792|0;r=96}if((r|0)==96){ta=4;ua=qa;va=ra;wa=sa}c[wa>>2]=ta;Q=ba(ta,c[va+412>>2]|0)|0;Z=ba(Q,c[va+416>>2]|0)|0;c[va+72>>2]=Z;Q=va+48|0;c[Q>>2]=0;do{if((aa|0)==101){if((ta|0)==8){c[Q>>2]=65541;xa=Z;break}else if((ta|0)==4){c[Q>>2]=69655;xa=Z;break}else{r=103;break}}else if((aa|0)==1){if((ta|0)!=16){r=103;break}c[Q>>2]=65536;xa=Z}else{r=103}}while(0);if((r|0)==103){DDb(b,1947840,(ca=i,i=i+8|0,c[ca>>2]=aa,ca)|0);i=ca;xa=c[(c[ea>>2]|0)+72>>2]|0}MT(_,32,1,xa);ya=_;za=ua}else{fa=da;r=69}}while(0);if((r|0)==69){da=0;while(1){ua=lz(l)|0;if((ua|0)==10){r=106;break}else if((ua|0)==0){Aa=da;r=108;break}a[g+da|0]=ua;ua=da+1|0;if((ua|0)<255){da=ua}else{Aa=ua;r=108;break}}if((r|0)==106){a[g+da|0]=0;Ba=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==108){a[g+Aa|0]=0;Ba=-1}Aa=Ba|fa;fa=0;while(1){Ba=lz(l)|0;if((Ba|0)==10){r=181;break}else if((Ba|0)==0){Ca=fa;r=183;break}a[g+fa|0]=Ba;Ba=fa+1|0;if((Ba|0)<255){fa=Ba}else{Ca=Ba;r=183;break}}if((r|0)==181){a[g+fa|0]=0;Da=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==183){a[g+Ca|0]=0;Da=-1}Ca=Da|Aa;Aa=0;while(1){Da=lz(l)|0;if((Da|0)==10){r=186;break}else if((Da|0)==0){Ea=Aa;r=188;break}a[g+Aa|0]=Da;Da=Aa+1|0;if((Da|0)<255){Aa=Da}else{Ea=Da;r=188;break}}if((r|0)==186){a[g+Aa|0]=0;Fa=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==188){a[g+Ea|0]=0;Fa=-1}ya=0;za=Fa|Ca}Ca=0;while(1){Fa=lz(l)|0;if((Fa|0)==10){r=112;break}else if((Fa|0)==0){Ga=Ca;r=114;break}a[f+Ca|0]=Fa;Fa=Ca+1|0;if((Fa|0)<255){Ca=Fa}else{Ga=Fa;r=114;break}}if((r|0)==112){a[f+Ca|0]=0;Ha=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==114){a[f+Ga|0]=0;Ha=-1}Ga=Ha|za;za=a[v]|0;do{if((za-48&255)>>>0<10>>>0){Ha=v;Ca=0;Fa=za;Ea=Ga;do{Ea=Ca>>>0>214748363>>>0?-1:Ea;Ca=(Ca*10|0)-48+(Fa<<24>>24)|0;Ha=Ha+1|0;Fa=a[Ha]|0;}while((Fa-48&255)>>>0<10>>>0);Fa=m;c[Fa>>2]=Ca;if((Ca|0)<=1){Ia=Ea;Ja=Fa;break}Ha=c[(c[y>>2]|0)+52>>2]|0;if((Ha|0)==124){Ia=Ea;Ja=Fa;break}yDb(b,24,1922560,(ca=i,i=i+8|0,c[ca>>2]=Ha,ca)|0);i=ca;Ia=Ea;Ja=Fa}else{Fa=m;c[Fa>>2]=0;Ia=Ga;Ja=Fa}}while(0);Ga=0;while(1){m=lz(l)|0;if((m|0)==10){r=123;break}else if((m|0)==0){Ka=Ga;r=125;break}a[f+Ga|0]=m;m=Ga+1|0;if((m|0)<255){Ga=m}else{Ka=m;r=125;break}}if((r|0)==123){a[f+Ga|0]=0;La=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==125){a[f+Ka|0]=0;La=-1}Ka=La|Ia;Ia=a[v]|0;if((Ia-48&255)>>>0<10>>>0){La=v;Ga=0;m=Ia;Ia=Ka;do{Ia=Ga>>>0>214748363>>>0?-1:Ia;Ga=(Ga*10|0)-48+(m<<24>>24)|0;La=La+1|0;m=a[La]|0;}while((m-48&255)>>>0<10>>>0);Ma=Ga+1|0;Na=Ia}else{Ma=1;Na=Ka}Ka=0;while(1){Ia=lz(l)|0;if((Ia|0)==10){r=131;break}else if((Ia|0)==0){Oa=Ka;r=133;break}a[g+Ka|0]=Ia;Ia=Ka+1|0;if((Ia|0)<255){Ka=Ia}else{Oa=Ia;r=133;break}}if((r|0)==131){a[g+Ka|0]=0;Pa=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==133){a[g+Oa|0]=0;Pa=-1}Oa=Pa|Na;Na=0;while(1){Pa=lz(l)|0;if((Pa|0)==10){r=136;break}else if((Pa|0)==0){Qa=Na;r=138;break}a[g+Na|0]=Pa;Pa=Na+1|0;if((Pa|0)<255){Na=Pa}else{Qa=Pa;r=138;break}}if((r|0)==136){a[g+Na|0]=0;Ra=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==138){a[g+Qa|0]=0;Ra=-1}Qa=Oa|Ra;Ra=0;while(1){Oa=lz(l)|0;if((Oa|0)==10){r=141;break}else if((Oa|0)==0){Sa=Ra;r=143;break}a[f+Ra|0]=Oa;Oa=Ra+1|0;if((Oa|0)<255){Ra=Oa}else{Sa=Oa;r=143;break}}if((r|0)==141){a[f+Ra|0]=0;Ta=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==143){a[f+Sa|0]=0;Ta=-1}Sa=Qa|Ta;Ta=a[v]|0;if((Ta-48&255)>>>0<10>>>0){Qa=v;v=0;f=Ta;Ta=Sa;do{Ta=v>>>0>214748363>>>0?-1:Ta;v=(v*10|0)-48+(f<<24>>24)|0;Qa=Qa+1|0;f=a[Qa]|0;}while((f-48&255)>>>0<10>>>0);Ua=(v|0)<0|0?-1:0;Va=v;Wa=Ta}else{Ua=0;Va=0;Wa=Sa}Sa=0;while(1){Ta=lz(l)|0;if((Ta|0)==0){Xa=Sa;r=151;break}else if((Ta|0)==10){r=149;break}a[g+Sa|0]=Ta;Ta=Sa+1|0;if((Ta|0)<255){Sa=Ta}else{Xa=Ta;r=151;break}}if((r|0)==149){a[g+Sa|0]=0;Ya=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==151){a[g+Xa|0]=0;Ya=-1}Xa=Ya|Wa;Wa=0;while(1){Ya=lz(l)|0;if((Ya|0)==10){r=154;break}else if((Ya|0)==0){Za=Wa;r=156;break}a[g+Wa|0]=Ya;Ya=Wa+1|0;if((Ya|0)<255){Wa=Ya}else{Za=Ya;r=156;break}}if((r|0)==154){a[g+Wa|0]=0;_a=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==156){a[g+Za|0]=0;_a=-1}Za=Xa|_a;_a=0;while(1){Xa=lz(l)|0;if((Xa|0)==10){r=159;break}else if((Xa|0)==0){$a=_a;r=161;break}a[g+_a|0]=Xa;Xa=_a+1|0;if((Xa|0)<255){_a=Xa}else{$a=Xa;r=161;break}}if((r|0)==159){a[g+_a|0]=0;ab=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==161){a[g+$a|0]=0;ab=-1}Ty(l,Va,Ua,0)|0;Ua=(Za|ab|0)==0;a:do{if(Ua&(Ma|0)!=0){if((ya|0)==0){ab=0;while(1){Za=0;while(1){Va=lz(l)|0;if((Va|0)==10){r=166;break}else if((Va|0)==0){bb=Za;r=168;break}a[g+Za|0]=Va;Va=Za+1|0;if((Va|0)<255){Za=Va}else{bb=Va;r=168;break}}if((r|0)==166){r=0;a[g+Za|0]=0;cb=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==168){r=0;a[g+bb|0]=0;cb=-1}Va=xd(n|0,1901184,(ca=i,i=i+24|0,c[ca>>2]=h,c[ca+8>>2]=j,c[ca+16>>2]=k,ca)|0)|0;i=ca;if((Va|0)!=3){db=0;break a}Va=c[Ja>>2]|0;$a=ba(Va,ab)|0;jT(s,c[h>>2]|0,c[h+4>>2]|0,$a,0,c[j>>2]|0,Va,0)|0;Va=ab+1|0;$a=(cb|0)==0;if($a&Va>>>0<Ma>>>0){ab=Va}else{db=$a;break}}}else{ab=0;Ea=0;while(1){Ca=0;while(1){$a=lz(l)|0;if(($a|0)==0){eb=Ca;r=175;break}else if(($a|0)==10){r=173;break}a[g+Ca|0]=$a;$a=Ca+1|0;if(($a|0)<255){Ca=$a}else{eb=$a;r=175;break}}if((r|0)==173){r=0;a[g+Ca|0]=0;fb=((Xy(l)|0)!=0)<<31>>31}else if((r|0)==175){r=0;a[g+eb|0]=0;fb=-1}Za=xd(n|0,1901184,(ca=i,i=i+24|0,c[ca>>2]=h,c[ca+8>>2]=j,c[ca+16>>2]=k,ca)|0)|0;i=ca;if((Za|0)!=3){db=0;break a}Za=c[Ja>>2]|0;$a=ba(Za,ab)|0;jT(s,c[h>>2]|0,c[h+4>>2]|0,$a,0,c[j>>2]|0,Za,0)|0;Za=YGb(c[j>>2]|0,c[j+4>>2]|0,c[h>>2]|0,c[h+4>>2]|0)|0;$a=c[k>>2]|0;jT(ya,Za,F,Ea,(Ea|0)<0|0?-1:0,$a,$a<<3|0>>>29,0)|0;$a=c[k>>2]|0;Za=YGb($a<<3|0>>>29,c[k+4>>2]<<3|$a>>>29,Ea,0)|0;$a=ab+1|0;Va=(fb|0)==0;if(Va&$a>>>0<Ma>>>0){ab=$a;Ea=Za}else{db=Va;break}}}}else{db=Ua}}while(0);z=db?0:-5;i=d;return z|0}function jP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=d+8|0;g=c[f>>2]|0;h=d+4|0;i=c[h>>2]|0;if((g|0)==(c[a+24>>2]|0)){j=i+1|0;c[h>>2]=j;c[f>>2]=0;k=0;l=j}else{k=g;l=i}i=c[(c[a+28>>2]|0)+(k<<2)>>2]|0;k=d+4|0;if(!(l>>>0<(c[i+404>>2]|0)>>>0)){m=-541478725;return m|0}a=c[i+400>>2]|0;g=d+12|0;do{if((c[g>>2]|0)==0){j=a+(l*24|0)|0;h=Ty(e,c[j>>2]|0,c[j+4>>2]|0,0)|0;j=F;n=0;if((j|0)<(n|0)|(j|0)==(n|0)&h>>>0<0>>>0){m=-5}else{break}return m|0}}while(0);h=i+8|0;i=c[h>>2]|0;do{if((c[i+8>>2]|0)==0){if((c[i+52>>2]|0)!=124){o=13;break}Vy(e,4,0)|0;n=rz(e)|0;j=Ty(e,-8,-1,1)|0;p=F;q=0;if((p|0)<(q|0)|(p|0)==(q|0)&j>>>0<0>>>0){m=-5;return m|0}if((TS(e,b,n)|0)==(n|0)){c[b+48>>2]=1;j=a+(l*24|0)+8|0;q=YGb(c[g>>2]|0,0,c[j>>2]|0,c[j+4>>2]|0)|0;j=b+8|0;c[j>>2]=q;c[j+4>>2]=F;c[b+32>>2]=c[f>>2];j=(c[g>>2]|0)+1|0;c[g>>2]=j;if((j|0)!=(c[d>>2]|0)){r=n;break}c[g>>2]=0;c[f>>2]=(c[f>>2]|0)+1;r=n;break}else{BZ(b);m=-5;return m|0}}else{o=13}}while(0);if((o|0)==13){o=a+(l*24|0)+16|0;i=TS(e,b,c[o>>2]>>2)|0;if((i|0)!=(c[o>>2]>>2|0)){BZ(b);m=-5;return m|0}if((c[(c[h>>2]|0)+8>>2]|0)==0){c[b+48>>2]=c[d>>2]}else{c[b+48>>2]=i<<3}d=a+(l*24|0)+8|0;l=c[d+4>>2]|0;a=b+8|0;c[a>>2]=c[d>>2];c[a+4>>2]=l;c[b+32>>2]=c[f>>2];c[f>>2]=(c[f>>2]|0)+1;r=i}if((c[k>>2]|0)!=0){m=r;return m|0}if((c[g>>2]|0)!=0){m=r;return m|0}g=b+36|0;c[g>>2]=c[g>>2]|1;m=r;return m|0}function kP(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;if((PGb(b,2019944,3)|0)!=0){e=0;return e|0}if(((d[b+3|0]|0)-50|0)>>>0>4>>>0){e=0;return e|0}a=b+8|0;f=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(f>>>0>256>>>0|(f|0)==0){e=12;return e|0}else{e=b+16|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;return(b>>>0>384e3>>>0|(b|0)==0?12:100)|0}return 0}function lP(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=b+16|0;g=c[f>>2]|0;h=LT(b,0)|0;if((h|0)==0){j=-12;i=e;return j|0}Vy(g,3,0)|0;k=lz(g)|0;l=c[h+8>>2]|0;c[l+8>>2]=1;m=rz(g)|0;n=l+52|0;c[n>>2]=m;o=vT(546656,m)|0;m=l+48|0;c[m>>2]=o;if((o|0)==0){o=e|0;I0a(o,5,c[n>>2]|0)|0;p=0;while(1){if(!(p>>>0<5>>>0)){q=7;break}if((c[n>>2]|0)==(c[546632+(p<<2)>>2]|0)){q=6;break}else{p=p+1|0}}if((q|0)==6){DDb(b,2129584,(r=i,i=i+8|0,c[r>>2]=o,r)|0);i=r;j=-1163346256;i=e;return j|0}else if((q|0)==7){yDb(b,16,2066408,(r=i,i=i+8|0,c[r>>2]=o,r)|0);i=r;j=-1094995529;i=e;return j|0}}r=rz(g)|0;o=l+416|0;c[o>>2]=r;if((r|0)==0){j=-1094995529;i=e;return j|0}Vy(g,4,0)|0;r=rz(g)|0;b=l+412|0;c[b>>2]=r;if((r|0)==0){j=-1094995529;i=e;return j|0}Vy(g,4,0)|0;r=c[m>>2]|0;do{if((r|0)==1380008992){c[l+432>>2]=(c[o>>2]|0)*20|0;if((c[g+88>>2]|0)==0){s=2048;break}m=Wy(g)|0;q=YGb(m,F,-2048,0)|0;m=O0a(l,q)|0;q=h+56|0;c[q>>2]=m;c[q+4>>2]=(m|0)<0|0?-1:0;s=2048}else if((r|0)==65536|(r|0)==65537){if((k|0)==52){t=2048}else{t=rz(g)|0}if((c[g+88>>2]|0)==0){s=t;break}m=Wy(g)|0;q=ZGb(m,F,t,(t|0)<0|0?-1:0)|0;m=eHb(q,F,2,0)|0;q=c[o>>2]|0;p=eHb(m,F,q,(q|0)<0|0?-1:0)|0;q=h+56|0;c[q>>2]=p;c[q+4>>2]=F;s=t}else if((r|0)==69650){q=rz(g)|0;if((CT(l,c[f>>2]|0,32)|0)<0){j=-12;i=e;return j|0}p=l+96|0;m=c[p>>2]|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+2|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+4|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+6|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+8|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+10|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+12|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+14|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+16|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+18|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+20|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+22|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+24|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+26|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+28|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+30|0;x=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;if((c[g+88>>2]|0)==0){s=q;break}m=Wy(g)|0;p=ZGb(m,F,q,(q|0)<0|0?-1:0)|0;m=eHb(p,F,8,0)|0;p=gHb(m,F,14,0)|0;m=h+56|0;c[m>>2]=p;c[m+4>>2]=F;s=q}else{s=2048}}while(0);l=Ty(g,0,0,1)|0;f=ZGb(s,(s|0)<0|0?-1:0,l,F)|0;Vy(g,f,F)|0;MT(h,64,1,c[b>>2]|0);j=0;i=e;return j|0}function mP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;e=a+16|0;if((Xy(c[e>>2]|0)|0)!=0){f=-541478725;return f|0}a=c[e>>2]|0;if((c[d+48>>2]|0)==1380008992){g=TS(a,b,c[d+432>>2]|0)|0}else{g=TS(a,b,1024)|0}do{if((g|0)!=1024){if((g|0)>=0){yZ(b,g);break}BZ(b);f=g;return f|0}}while(0);c[b+32>>2]=0;f=g;return f|0}function nP(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+16>>2]|0;e=tz(d)|0;f=tz(d)|0;g=tz(d)|0;tz(d)|0;d=vT(1238704,e)|0;if((d|0)==69633){EDb(a,2129568,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=b;return j|0}k=u0a(d)|0;if((k|0)==0){DDb(a,2066384,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=b;return j|0}h=LT(a,0)|0;if((h|0)==0){j=-12;i=b;return j|0}a=h+56|0;c[a>>2]=(f<<3>>>0)/(k>>>0)|0;c[a+4>>2]=0;a=c[h+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=e;c[a+48>>2]=d;c[a+416>>2]=1;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;c[a+412>>2]=g;c[a+432>>2]=1;MT(h,64,1,g);j=0;i=b;return j|0}function oP(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;f=c[e+52>>2]|0;if((f|0)==0){g=-1094995529;i=b;return g|0}if((c[e+416>>2]|0)!=1){yDb(a,16,2066360,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1094995529;i=b;return g|0}if((c[d+88>>2]|0)==0){yDb(a,16,2019896,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1094995529;i=b;return g|0}j=e+412|0;if((c[j>>2]|0)>>>0>65535>>>0){yDb(a,16,1977008,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1094995529;i=b;return g|0}if((c[e+48>>2]|0)==69633){yDb(a,16,1947808,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1163346256;i=b;return g|0}else{fz(d,f);fz(d,0);fz(d,c[j>>2]|0);fz(d,0);Sy(d);g=0;i=b;return g|0}return 0}function pP(a,b){a=a|0;b=b|0;Ry(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function qP(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+16>>2]|0;e=Ty(d,0,0,1)|0;f=F;g=0;if((f|0)<(g|0)|(f|0)==(g|0)&e>>>0<0>>>0){h=e;i=b;return h|0}g=0;if((f|0)>(g|0)|(f|0)==(g|0)&e>>>0>65543>>>0){yDb(a,24,2129496,(a=i,i=i+16|0,c[a>>2]=e,c[a+8>>2]=f,a)|0);i=a;j=65535}else{a=YGb(e,f,65528,0)|0;j=a&65535}Ty(d,2,0,0)|0;fz(d,j);Ty(d,e,f,0)|0;h=0;i=b;return h|0}function rP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[a+12>>2]|0;g=a+16|0;Py(c[g>>2]|0,128);Py(c[g>>2]|0,c[f+12>>2]&127|e<<7&128);e=f+24|0;fz(c[g>>2]|0,c[e>>2]|0);Zy(c[g>>2]|0,c[f+28>>2]|0);Zy(c[g>>2]|0,c[f+16>>2]|0);Ry(c[g>>2]|0,b,d);Sy(c[g>>2]|0);c[e>>2]=(c[e>>2]|0)+1&65535;e=f+68|0;c[e>>2]=(c[e>>2]|0)+d;d=f+64|0;c[d>>2]=(c[d>>2]|0)+1;return}function sP(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[b+12>>2]|0;if((c[b+24>>2]|0)!=1){yDb(b,16,2019840,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=d;return k|0}l=c[c[b+28>>2]>>2]|0;m=l+8|0;n=c[m>>2]|0;o=c[n+48>>2]|0;if(!((o|0)==5|(o|0)==20|(o|0)==28|(o|0)==1|(o|0)==2|(o|0)==13|(o|0)==86018|(o|0)==86016|(o|0)==86017|(o|0)==65543|(o|0)==65542|(o|0)==65540|(o|0)==65537|(o|0)==65536|(o|0)==65539|(o|0)==65538|(o|0)==65541|(o|0)==131072|(o|0)==73728|(o|0)==73729|(o|0)==86021|(o|0)==31|(o|0)==141|(o|0)==69660|(o|0)==69643|(o|0)==86076|(o|0)==8|(o|0)==86052|(o|0)==1330664787)){p=H0a(o)|0;yDb(b,16,1976984,(j=i,i=i+8|0,c[j>>2]=p,j)|0);i=j;k=-1;i=d;return k|0}p=h+12|0;o=c[p>>2]|0;q=l+4|0;if((o|0)<0){r=c[q>>2]|0;if((r|0)<96){s=DX(b,n,-1)|0;c[q>>2]=s;t=s}else{t=r}c[p>>2]=t}else{c[q>>2]=o}o=hFb()|0;c[h+32>>2]=o;c[h+28>>2]=o;c[h+36>>2]=0;o=h+16|0;if((c[o>>2]|0)==0){c[o>>2]=hFb()|0}c[h+76>>2]=1;o=TT()|0;q=h+56|0;c[q>>2]=o;c[q+4>>2]=F;o=b+1144|0;t=c[o>>2]|0;p=c[o+4>>2]|0;if(!((t|0)==0&(p|0)==0)){o=fHb(t,p,1e3,0)|0;r=F;s=YGb(t,p,1220321280,514320)|0;p=ZGb(s,F,o,r)|0;c[q>>2]=p;c[q+4>>2]=F}q=h+24|0;p=c[q>>2]|0;do{if((p|0)<0){if((c[(c[m>>2]|0)+88>>2]&8388608|0)==0){c[q>>2]=(hFb()|0)&4095;break}else{c[q>>2]=0;break}}else{c[q>>2]=p&65535}}while(0);p=b+1076|0;q=c[p>>2]|0;r=c[(c[b+16>>2]|0)+60>>2]|0;do{if((q|0)==0){c[p>>2]=r;u=r}else{if((r|0)==0){u=q;break}o=q>>>0>r>>>0?r:q;c[p>>2]=o;u=o}}while(0);if(u>>>0<13>>>0){yDb(b,16,1947776,(j=i,i=i+8|0,c[j>>2]=u,j)|0);i=j;k=-5;i=d;return k|0}q=WDb(u)|0;u=h+80|0;r=u;c[r>>2]=q;if((q|0)==0){k=-12;i=d;return k|0}q=h+40|0;c[q>>2]=(c[p>>2]|0)-12;p=h+88|0;c[p>>2]=0;o=b+1080|0;do{if((c[o>>2]|0)>0){s=c[m>>2]|0;a:do{if((c[s+8>>2]|0)==1){t=O0a(s,0)|0;n=c[m>>2]|0;do{if((t|0)==0){v=c[n+424>>2]|0;if((v|0)!=0){w=v;break}yDb(b,16,1922512,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;break a}else{w=t}}while(0);t=c[o>>2]|0;c[e>>2]=1;c[e+4>>2]=1e6;c[f>>2]=w;c[f+4>>2]=c[n+412>>2];v=JDb(t,(t|0)<0|0?-1:0,e,f,2)|0;c[p>>2]=v}}while(0);s=c[m>>2]|0;if((c[s+8>>2]|0)!=0){break}v=c[o>>2]|0;c[g>>2]=1;c[g+4>>2]=1e6;t=KDb(v,(v|0)<0|0?-1:0,g,s+104|0)|0;c[p>>2]=t}}while(0);MT(l,32,1,9e4);g=c[m>>2]|0;m=c[g+48>>2]|0;do{if((m|0)==69660){MT(l,32,1,8e3);k=0;i=d;return k|0}else if((m|0)==86021|(m|0)==31){o=c[p>>2]|0;if((o|0)==0){c[p>>2]=15;x=15;y=43}else{if((o|0)<1){z=1}else{x=o;y=43}}if((y|0)==43){z=(x|0)>15?15:x}c[p>>2]=z;c[q>>2]=(c[q>>2]|0)-6;c[h+44>>2]=0}else if((m|0)==86018){y=60}else if((m|0)==1330664787){if((c[g+416>>2]|0)>2){yDb(b,16,1901144,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;y=64;break}MT(l,32,1,48e3);k=0;i=d;return k|0}else if((m|0)==73728|(m|0)==73729){o=c[p>>2]|0;if((o|0)==0){c[p>>2]=12;A=12}else{A=o}if((A+1+((m|0)==73728?31:61)|0)>(c[q>>2]|0)){yDb(b,16,2339048,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;y=64;break}if((c[g+416>>2]|0)==1){y=60;break}yDb(b,16,2314632,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;y=64}else if((m|0)==1|(m|0)==2){k=0;i=d;return k|0}else if((m|0)==131072){o=c[q>>2]|0;c[q>>2]=(o|0)<188?188:o-((o|0)%188|0)|0;c[h+84>>2]=c[r>>2];k=0;i=d;return k|0}else if((m|0)==86016|(m|0)==86017){c[h+84>>2]=(c[r>>2]|0)+4;k=0;i=d;return k|0}else if((m|0)==86076){o=g+432|0;f=c[o>>2]|0;if(!((f|0)==38|(f|0)==50)){yDb(b,16,1881016,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;y=64;break}e=c[p>>2]|0;if((e|0)==0){c[p>>2]=1;B=1;C=c[o>>2]|0}else{B=e;C=f}f=(c[q>>2]|0)/(C|0)|0;c[p>>2]=(B|0)>(f|0)?f:B}else if((m|0)==28){if((c[g+100>>2]|0)<=4){k=0;i=d;return k|0}f=c[g+96>>2]|0;if((a[f]|0)!=1){k=0;i=d;return k|0}c[h+92>>2]=(a[f+4|0]&3)+1;k=0;i=d;return k|0}}while(0);if((y|0)==60){c[h+44>>2]=0}else if((y|0)==64){$Db(u);k=-22;i=d;return k|0}if((c[g+8>>2]|0)==1){MT(l,32,1,c[g+412>>2]|0)}c[h+84>>2]=c[r>>2];k=0;i=d;return k|0}function tP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=i;i=i+8|0;f=e|0;g=b+12|0;h=c[g>>2]|0;j=b+28|0;k=c[c[j>>2]>>2]|0;l=c[d+28>>2]|0;m=h+68|0;n=h+72|0;o=h+76|0;do{if((c[o>>2]|0)==0){if(!((((c[m>>2]|0)-(c[n>>2]|0)|0)*5|0)>>>0>27999>>>0)){break}p=TT()|0;q=h+48|0;r=ZGb(p,F,c[q>>2]|0,c[q+4>>2]|0)|0;q=F;p=0;if(q>>>0>p>>>0|q>>>0==p>>>0&r>>>0>5e6>>>0){s=4}}else{s=4}}while(0);do{if((s|0)==4){if((c[h+96>>2]&4|0)!=0){break}r=TT()|0;vP(b,r,F,0);c[n>>2]=c[m>>2];c[o>>2]=0}}while(0);o=d+8|0;m=YGb(c[h+32>>2]|0,0,c[o>>2]|0,c[o+4>>2]|0)|0;c[h+36>>2]=m;m=c[k+8>>2]|0;k=c[m+48>>2]|0;do{if((k|0)==69660){t=wP(b,c[d+24>>2]|0,l,c[m+416>>2]<<3)|0;i=e;return t|0}else if((k|0)==1|(k|0)==2){GP(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==86018){o=c[d+24>>2]|0;if((c[h+96>>2]&1|0)==0){xP(b,o,l);t=0;i=e;return t|0}else{FP(b,o,l);t=0;i=e;return t|0}}else if((k|0)==73728|(k|0)==73729){yP(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==131072){o=c[g>>2]|0;if((l|0)<=187){t=0;i=e;return t|0}n=o+40|0;r=o+84|0;p=o+80|0;o=b+16|0;q=l;u=c[d+24>>2]|0;v=c[r>>2]|0;w=c[p>>2]|0;while(1){x=(c[n>>2]|0)+(w-v)|0;y=(x|0)>(q|0)?q:x;UGb(v|0,u|0,y)|0;x=q-y|0;z=(c[r>>2]|0)+y|0;c[r>>2]=z;A=c[p>>2]|0;B=z-A|0;if((B|0)<(c[n>>2]|0)){C=z;D=A}else{z=c[g>>2]|0;Py(c[o>>2]|0,128);Py(c[o>>2]|0,c[z+12>>2]&127);E=z+24|0;fz(c[o>>2]|0,c[E>>2]|0);Zy(c[o>>2]|0,c[z+28>>2]|0);Zy(c[o>>2]|0,c[z+16>>2]|0);Ry(c[o>>2]|0,A,B);Sy(c[o>>2]|0);c[E>>2]=(c[E>>2]|0)+1&65535;E=z+68|0;c[E>>2]=(c[E>>2]|0)+B;B=z+64|0;c[B>>2]=(c[B>>2]|0)+1;B=c[p>>2]|0;c[r>>2]=B;C=B;D=B}if((x|0)>187){q=x;u=u+y|0;v=C;w=D}else{t=0;break}}i=e;return t|0}else if((k|0)==28){DP(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==5){if((c[h+96>>2]&2|0)==0){s=38;break}c[f>>2]=0;w=HZ(d,3,f)|0;if((w|0)==0){yDb(b,16,2129440,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;t=-12;i=e;return t|0}else{CP(b,c[d+24>>2]|0,l,w,c[f>>2]|0);t=0;i=e;return t|0}}else if((k|0)==20){s=38}else if((k|0)==86021|(k|0)==31){IP(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==141){HP(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==86076){w=c[d+24>>2]|0;v=c[g>>2]|0;u=(c[c[j>>2]>>2]|0)+8|0;q=O0a(c[u>>2]|0,0)|0;r=c[(c[u>>2]|0)+432>>2]|0;u=(l|0)/(r|0)|0;if((u|0)<=0){t=0;i=e;return t|0}p=v+88|0;o=v+44|0;n=v+80|0;y=v+84|0;x=v+36|0;B=v+28|0;v=b+16|0;z=u;u=w;w=c[o>>2]|0;while(1){E=(c[p>>2]|0)-w|0;A=(E|0)>(z|0)?z:E;if((w|0)==0){E=c[n>>2]|0;c[y>>2]=E;c[B>>2]=c[x>>2];H=E}else{H=c[y>>2]|0}E=ba(A,r)|0;UGb(H|0,u|0,E)|0;I=z-A|0;J=(c[o>>2]|0)+A|0;c[o>>2]=J;K=(c[y>>2]|0)+E|0;c[y>>2]=K;L=ba(A,q)|0;c[x>>2]=(c[x>>2]|0)+L;if((J|0)==(c[p>>2]|0)){L=c[n>>2]|0;A=K-L|0;K=c[g>>2]|0;Py(c[v>>2]|0,128);Py(c[v>>2]|0,c[K+12>>2]&127|128);M=K+24|0;fz(c[v>>2]|0,c[M>>2]|0);Zy(c[v>>2]|0,c[K+28>>2]|0);Zy(c[v>>2]|0,c[K+16>>2]|0);Ry(c[v>>2]|0,L,A);Sy(c[v>>2]|0);c[M>>2]=(c[M>>2]|0)+1&65535;M=K+68|0;c[M>>2]=(c[M>>2]|0)+A;A=K+64|0;c[A>>2]=(c[A>>2]|0)+1;c[o>>2]=0;N=0}else{N=J}if((I|0)>0){z=I;u=u+E|0;w=N}else{t=0;break}}i=e;return t|0}else if((k|0)==65542|(k|0)==65543|(k|0)==65541|(k|0)==65540){t=wP(b,c[d+24>>2]|0,l,c[m+416>>2]<<3)|0;i=e;return t|0}else if((k|0)==86016|(k|0)==86017){w=c[d+24>>2]|0;u=c[g>>2]|0;z=c[u+40>>2]|0;o=u+84|0;v=c[o>>2]|0;n=u+80|0;p=c[n>>2]|0;x=v-p|0;if((x+l|0)>(z|0)&(x|0)>4){q=b+16|0;Py(c[q>>2]|0,128);Py(c[q>>2]|0,c[u+12>>2]&127);y=u+24|0;fz(c[q>>2]|0,c[y>>2]|0);Zy(c[q>>2]|0,c[u+28>>2]|0);Zy(c[q>>2]|0,c[u+16>>2]|0);Ry(c[q>>2]|0,p,x);Sy(c[q>>2]|0);c[y>>2]=(c[y>>2]|0)+1&65535;y=u+68|0;c[y>>2]=(c[y>>2]|0)+x;x=u+64|0;c[x>>2]=(c[x>>2]|0)+1;x=c[n>>2]|0;y=x+4|0;c[o>>2]=y;O=y;P=x}else{O=v;P=p}p=(O|0)==(P+4|0);if(p){c[u+28>>2]=c[u+36>>2]}if((z|0)>=(l|0)){if(p){a[P]=0;a[(c[n>>2]|0)+1|0]=0;a[(c[n>>2]|0)+2|0]=0;a[(c[n>>2]|0)+3|0]=0;Q=c[o>>2]|0}else{Q=O}UGb(Q|0,w|0,l)|0;c[o>>2]=(c[o>>2]|0)+l;t=0;i=e;return t|0}if((l|0)<=0){t=0;i=e;return t|0}o=z-4|0;z=b+16|0;p=l;u=0;v=w;w=P;while(1){x=(o|0)>(p|0)?p:o;a[w]=0;a[(c[n>>2]|0)+1|0]=0;a[(c[n>>2]|0)+2|0]=u>>>8;a[(c[n>>2]|0)+3|0]=u;UGb((c[n>>2]|0)+4|0,v|0,x)|0;y=c[n>>2]|0;q=x+4|0;r=c[g>>2]|0;Py(c[z>>2]|0,128);Py(c[z>>2]|0,c[r+12>>2]&127);B=r+24|0;fz(c[z>>2]|0,c[B>>2]|0);Zy(c[z>>2]|0,c[r+28>>2]|0);Zy(c[z>>2]|0,c[r+16>>2]|0);Ry(c[z>>2]|0,y,q);Sy(c[z>>2]|0);c[B>>2]=(c[B>>2]|0)+1&65535;B=r+68|0;c[B>>2]=(c[B>>2]|0)+q;q=r+64|0;c[q>>2]=(c[q>>2]|0)+1;q=p-x|0;if((q|0)<=0){t=0;break}p=q;u=x+u|0;v=v+x|0;w=c[n>>2]|0}i=e;return t|0}else if((k|0)==69643){t=wP(b,c[d+24>>2]|0,l,ba(c[m+416>>2]|0,c[m+792>>2]|0)|0)|0;i=e;return t|0}else if((k|0)==8){EP(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==1330664787){n=c[h+40>>2]|0;if((l|0)<=(n|0)){break}yDb(b,16,2066304,(G=i,i=i+16|0,c[G>>2]=l,c[G+8>>2]=n,G)|0);i=G;t=-22;i=e;return t|0}else if((k|0)==65539|(k|0)==65538|(k|0)==65537|(k|0)==65536){t=wP(b,c[d+24>>2]|0,l,c[m+416>>2]<<4)|0;i=e;return t|0}}while(0);if((s|0)==38){BP(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}s=c[g>>2]|0;m=c[s+40>>2]|0;if((l|0)<=0){t=0;i=e;return t|0}k=s+36|0;G=s+28|0;h=b+16|0;b=l;l=c[d+24>>2]|0;d=s;while(1){s=(m|0)>(b|0)?b:m;c[G>>2]=c[k>>2];Py(c[h>>2]|0,128);Py(c[h>>2]|0,c[d+12>>2]&127|((s|0)==(b|0))<<7);P=d+24|0;fz(c[h>>2]|0,c[P>>2]|0);Zy(c[h>>2]|0,c[d+28>>2]|0);Zy(c[h>>2]|0,c[d+16>>2]|0);Ry(c[h>>2]|0,l,s);Sy(c[h>>2]|0);c[P>>2]=(c[P>>2]|0)+1&65535;P=d+68|0;c[P>>2]=(c[P>>2]|0)+s;P=d+64|0;c[P>>2]=(c[P>>2]|0)+1;P=b-s|0;if((P|0)<=0){t=0;break}b=P;l=l+s|0;d=c[g>>2]|0}i=e;return t|0}function uP(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;do{if((c[a+16>>2]|0)!=0){if((c[b+96>>2]&16|0)==0){break}d=TT()|0;vP(a,d,F,1)}}while(0);$Db(b+80|0);return 0}function vP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+8|0;g=f|0;h=c[a+12>>2]|0;j=h+48|0;c[j>>2]=b;c[j+4>>2]=d;j=h+56|0;k=ZGb(b,d,c[j>>2]|0,c[j+4>>2]|0)|0;c[g>>2]=1;c[g+4>>2]=1e6;j=KDb(k,F,g,(c[c[a+28>>2]>>2]|0)+40|0)|0;g=YGb(c[h+32>>2]|0,0,j,F)|0;j=a+16|0;Py(c[j>>2]|0,128);Py(c[j>>2]|0,200);fz(c[j>>2]|0,6);a=h+16|0;Zy(c[j>>2]|0,c[a>>2]|0);k=c[j>>2]|0;l=IDb(b,d,0,1,1e6,0)|0;ez(k,l,F);Zy(c[j>>2]|0,g);Zy(c[j>>2]|0,c[h+64>>2]|0);Zy(c[j>>2]|0,c[h+68>>2]|0);g=h+20|0;h=c[g>>2]|0;do{if((h|0)!=0){l=SGb(h|0)|0;k=l>>>0>255>>>0?255:l;Py(c[j>>2]|0,129);Py(c[j>>2]|0,202);fz(c[j>>2]|0,(k+10|0)/4|0);Zy(c[j>>2]|0,c[a>>2]|0);Py(c[j>>2]|0,1);Py(c[j>>2]|0,k);Ry(c[j>>2]|0,c[g>>2]|0,k);Py(c[j>>2]|0,0);l=(k+7|0)%4|0;if((l&3|0)==0){break}else{m=l}do{Py(c[j>>2]|0,0);m=m+1|0;}while((m&3|0)!=0)}}while(0);if((e|0)==0){n=c[j>>2]|0;Sy(n);i=f;return}Py(c[j>>2]|0,129);Py(c[j>>2]|0,203);fz(c[j>>2]|0,1);Zy(c[j>>2]|0,c[a>>2]|0);n=c[j>>2]|0;Sy(n);i=f;return}function wP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=a+12|0;g=c[f>>2]|0;h=e;i=(e|0)<0|0?-1:0;j=GDb(h,i,8,0)|0;k=eHb(h,i,j,F)|0;j=c[g+40>>2]|0;i=j-((j|0)%(k|0)|0)|0;do{if((e&7|0)==0){if(((d<<3|0)%(e|0)|0|0)==0){break}else{l=-22}return l|0}}while(0);if((d|0)<=0){l=0;return l|0}k=g+80|0;j=g+84|0;h=g+36|0;m=g+28|0;g=a+16|0;a=d;d=b;b=0;n=c[k>>2]|0;while(1){c[j>>2]=n;o=(i|0)>(a|0)?a:i;UGb(n|0,d|0,o)|0;p=(c[j>>2]|0)+o|0;c[j>>2]=p;q=a-o|0;c[m>>2]=((b<<3|0)/(e|0)|0)+(c[h>>2]|0);r=c[k>>2]|0;s=p-r|0;p=c[f>>2]|0;Py(c[g>>2]|0,128);Py(c[g>>2]|0,c[p+12>>2]&127);t=p+24|0;fz(c[g>>2]|0,c[t>>2]|0);Zy(c[g>>2]|0,c[p+28>>2]|0);Zy(c[g>>2]|0,c[p+16>>2]|0);Ry(c[g>>2]|0,r,s);Sy(c[g>>2]|0);c[t>>2]=(c[t>>2]|0)+1&65535;t=p+68|0;c[t>>2]=(c[t>>2]|0)+s;s=p+64|0;c[s>>2]=(c[s>>2]|0)+1;s=c[k>>2]|0;if((q|0)>0){a=q;d=d+o|0;b=(c[j>>2]|0)+b-s|0;n=s}else{l=0;break}}return l|0}function xP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[b+12>>2]|0;g=c[f+88>>2]|0;h=(g|0)==0?5:g;g=(h<<1)+2|0;if((c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+100>>2]|0)==0){i=d+7|0;j=e-7|0}else{i=d;j=e}e=f+40|0;d=c[e>>2]|0;k=d-g|0;l=f+84|0;m=c[l>>2]|0;n=f+80|0;o=c[n>>2]|0;p=m;q=o;r=f+44|0;s=c[r>>2]|0;do{if((s|0)==(h|0)){t=6}else{if((m|0)!=(o|0)){if((p+j-q|0)>(d|0)){t=6;break}}if((s|0)==0){u=o;t=10}else{v=o;w=s}}}while(0);if((t|0)==6){d=s<<1;q=g-d|0;p=q-2|0;m=o+p|0;if((p|0)!=0){VGb(o+q|0,o+2|0,d|0)|0}a[m]=s>>>4;a[o+(q-1)|0]=s<<4;rP(b,m,(c[l>>2]|0)-m|0,1);c[r>>2]=0;u=c[n>>2]|0;t=10}if((t|0)==10){c[l>>2]=u+g;c[f+28>>2]=c[f+36>>2];v=u;w=0}if((j|0)<=(k|0)){c[r>>2]=w+1;r=w<<1;a[v+(r+2)|0]=j>>>5;a[v+(r+3)|0]=j<<3;UGb(c[l>>2]|0,i|0,j)|0;c[l>>2]=(c[l>>2]|0)+j;return}l=(c[e>>2]|0)-4|0;a[v]=0;a[v+1|0]=16;if((j|0)<=0){return}e=j>>>5&255;r=v+2|0;w=j<<3&255;k=v+3|0;u=v+4|0;f=j;j=i;while(1){i=(f|0)>(l|0)?l:f;a[r]=e;a[k]=w;UGb(u|0,j|0,i)|0;rP(b,v,i+4|0,(i|0)==(f|0)|0);g=f-i|0;if((g|0)>0){f=g;j=j+i|0}else{break}}return}function yP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[b+12>>2]|0;g=c[f+88>>2]|0;h=g+1|0;i=f+84|0;j=c[i>>2]|0;k=f+80|0;l=c[k>>2]|0;m=j;n=l;o=f+44|0;p=c[o>>2]|0;do{if((p|0)==(g|0)){q=4}else{if((j|0)!=(l|0)){if((e-1+m-n|0)>(c[f+40>>2]|0)){q=4;break}}if((p|0)==0){r=l;q=8;break}s=l+p|0;a[s]=a[s]|-128;t=c[k>>2]|0}}while(0);if((q|0)==4){n=h+~p|0;m=l+n|0;if((n|0)==0){u=j}else{VGb(m|0,l|0,p+1|0)|0;u=c[i>>2]|0}rP(b,m,u-m|0,1);c[o>>2]=0;r=c[k>>2]|0;q=8}if((q|0)==8){a[r]=-16;r=c[k>>2]|0;c[i>>2]=r+h;c[f+28>>2]=c[f+36>>2];t=r}r=a[d]&124;f=(c[o>>2]|0)+1|0;c[o>>2]=f;a[t+f|0]=r;r=e-1|0;UGb(c[i>>2]|0,d+1|0,r)|0;c[i>>2]=(c[i>>2]|0)+r;return}function zP(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=UC(1904160,0,0)|0;c[k>>2]=0;do{if((m|0)==0){n=-38;o=0}else{p=tN()|0;if((p|0)==0){n=-12;o=0;break}c[p+8>>2]=m;if((LT(p,0)|0)==0){n=-12;o=p;break}q=b+1160|0;r=p+1160|0;s=c[q+4>>2]|0;c[r>>2]=c[q>>2];c[r+4>>2]=s;c[p+1080>>2]=c[b+1080>>2];s=p+28|0;r=d+80|0;q=(c[c[s>>2]>>2]|0)+80|0;t=c[r+4>>2]|0;c[q>>2]=c[r>>2];c[q+4>>2]=t;t=p+1084|0;c[t>>2]=c[t>>2]|c[b+1084>>2]&32768;t=c[d+4>>2]|0;if((t|0)<96){q=DX(b,c[d+8>>2]|0,g)|0;c[(c[c[s>>2]>>2]|0)+4>>2]=q}else{c[(c[c[s>>2]>>2]|0)+4>>2]=t}if((xEb(b,2213936,1,j)|0)>-1){CBb(k,2213936,c[j>>2]|0,8)|0}t=b+1144|0;q=c[t+4>>2]|0;r=p+1144|0;c[r>>2]=c[t>>2];c[r+4>>2]=q;BRa(c[(c[c[s>>2]>>2]|0)+8>>2]|0,c[d+8>>2]|0)|0;s=(e|0)!=0;q=p+16|0;do{if(s){r=Cz(q,e)|0;if((r|0)>=0){u=r;v=13;break}Ey(e)|0;w=r;v=14}else{u=Nz(q,f)|0;v=13}}while(0);do{if((v|0)==13){if((u|0)!=0){w=u;v=14;break}r=FK(p,k)|0;DBb(k);if((r|0)!=0){x=r;break}c[a>>2]=p;y=0;i=h;return y|0}}while(0);if((v|0)==14){DBb(k);x=w}r=c[q>>2]|0;t=(r|0)==0;do{if(s){if(t){break}Iz(r)|0}else{if(t){break}Oz(r,l)|0;ZDb(c[l>>2]|0)}}while(0);bT(p);y=x;i=h;return y|0}}while(0);ZDb(o);if((e|0)==0){y=n;i=h;return y|0}Ey(e)|0;y=n;i=h;return y|0}function AP(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=c-1|0;e=b+1|0;if(d>>>0>e>>>0){f=d}else{g=c;return g|0}while(1){if((a[f]|0)==0){d=(a[f+1|0]|0)==0;if(d){if((a[f+2|0]|0)!=0){g=f;h=7;break}}b=f-1|0;if(!((a[b]|0)!=0|d)){g=b;h=7;break}}b=f-2|0;if(b>>>0>e>>>0){f=b}else{g=c;h=7;break}}if((h|0)==7){return g|0}return 0}function BP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[b+12>>2]|0;if((e|0)<=0){return}g=f+80|0;h=(c[f+40>>2]|0)-2|0;i=f+36|0;j=f+28|0;f=e;e=d;while(1){d=c[g>>2]|0;do{if((f|0)>1){if((a[e]|0)!=0){k=7;break}if((a[e+1|0]|0)!=0){k=7;break}a[d]=4;l=e+2|0;m=f-2|0}else{k=7}}while(0);if((k|0)==7){k=0;a[d]=0;l=e;m=f}n=d+2|0;a[d+1|0]=0;o=(h|0)>(m|0)?m:h;if((o|0)<(m|0)){p=l+o|0;q=o-1|0;r=l+1|0;a:do{if((q|0)>1){s=l+q|0;while(1){do{if((a[s]|0)==0){if((a[s+1|0]|0)==0){if((a[s+2|0]|0)==0){break}else{t=s;break a}}else{u=s-1|0;if((a[u]|0)==0){t=u;break a}else{break}}}}while(0);u=s-2|0;if(u>>>0>r>>>0){s=u}else{t=p;break}}}else{t=p}}while(0);v=t-l|0}else{v=o}UGb(n|0,l|0,v)|0;c[j>>2]=c[i>>2];p=c[g>>2]|0;rP(b,p,d+(v+2)-p|0,(v|0)==(m|0)|0);p=m-v|0;if((p|0)>0){f=p;e=l+v|0}else{break}}return}function CP(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;j=i;k=b+12|0;l=c[k>>2]|0;m=(h|0)/12|0;c[l+28>>2]=c[l+36>>2];h=f<<3;n=h>>>0>2147483639>>>0|(e|0)==0;o=n?0:e;p=n?8:h+8|0;h=o;n=fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;h=p>>>0>22>>>0?22:p;if((n&-1024|0)==32768){n=o+(h>>>3)|0;q=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&6)>>>24;n=h+8|0;h=(p>>>0>n>>>0?n:p)+2|0;n=(p>>>0>h>>>0?h:p)+3|0;h=p>>>0>n>>>0?n:p;n=o+(h>>>3)|0;r=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>29;n=h+3|0;h=p>>>0>n>>>0?n:p;n=o+(h>>>3)|0;s=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>31;n=h+1|0;h=p>>>0>n>>>0?n:p;n=o+(h>>>3)|0;t=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>31;n=h+1|0;h=p>>>0>n>>>0?n:p;n=o+(h>>>3)|0;u=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>31;n=h+1|0;h=p>>>0>n>>>0?n:p;p=o+(h>>>3)|0;v=r;w=s;y=t;z=u;A=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(h&7)>>>31;B=q}else{v=0;w=0;y=0;z=0;A=0;B=0}if((f|0)<=0){i=j;return}q=l+40|0;l=e;h=b;p=(((w<<1|y)<<1|z)<<1|A)<<7;u=0;t=0;s=0;r=0;o=0;n=0;C=0;D=0;E=0;F=f;f=e;while(1){e=(c[q>>2]|0)-8|0;G=(e|0)>(F|0)?F:e;do{if((G|0)<(F|0)){e=AP(f,f+G|0)|0;H=f;I=e-H|0;if((I|0)!=((c[q>>2]|0)-8|0)){J=I;K=0;L=D;M=C;N=n;O=o;P=r;Q=s;R=t;S=u;break}T=H-l|0;U=o;while(1){if((U|0)>=(m|0)){break}V=g+(U*12|0)|0;if((d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>3>>>0<T>>>0){U=U+1|0}else{break}}T=e-l|0;V=U;while(1){W=V+1|0;if((W|0)>=(m|0)){break}X=g+(W*12|0)|0;if((d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)>>>3>>>0<T>>>0){V=W}else{break}}if((V|0)>=(m|0)){yDb(h,16,2213832,(Y=i,i=i+8|0,c[Y>>2]=I,Y)|0);i=Y;J=I;K=0;L=D;M=C;N=n;O=V;P=r;Q=s;R=t;S=u;break}U=V*12|0;e=g+U|0;X=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=(X+7|0)>>>3;if(e>>>0>T>>>0){yDb(h,16,1903912,(Y=i,i=i+8|0,c[Y>>2]=I,Y)|0);i=Y;J=I;K=0;L=D;M=C;N=n;O=V;P=r;Q=s;R=t;S=u;break}else{Z=g+(U+6)|0;J=l-H+e|0;K=(e<<3)-X|0;L=d[g+(U+4)|0]|0;M=a[g+(U+11)|0]|0;N=a[g+(U+10)|0]|0;O=W;P=d[g+(U+5)|0]|0;Q=(d[Z]|d[Z+1|0]<<8)<<16>>16&65535;R=a[g+(U+8)|0]|0;S=a[g+(U+9)|0]|0;break}}else{J=G;K=0;L=D;M=C;N=n;O=o;P=r;Q=s;R=t;S=u}}while(0);do{if((F|0)>2){if((a[f]|0)!=0){_=22;break}if((a[f+1|0]|0)!=0){_=22;break}G=(c[k>>2]|0)+80|0;U=c[G>>2]|0;Z=U;x=fe((((((K<<3|v)<<1|w)<<1|y)<<1|z)<<1|A)<<17|B|0)|0;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;UGb((c[G>>2]|0)+4|0,f|0,J)|0;rP(b,c[G>>2]|0,J+4|0,(J|0)==(F|0)|0)}else{_=22}}while(0);if((_|0)==22){_=0;G=(c[k>>2]|0)+80|0;Z=c[G>>2]|0;U=Z;x=fe(((((v|(K|E<<3)<<3)<<5|D)<<5|r)<<9|s)<<2|-2147483648|0)|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=Z+4|0;x=fe((((p|t)<<7|u)<<7|n)<<7|C|0)|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;UGb((c[G>>2]|0)+8|0,f|0,J)|0;rP(b,c[G>>2]|0,J+8|0,(J|0)==(F|0)|0)}if((K|0)==0){$=J;aa=0}else{$=J-1|0;aa=8-K|0}G=F-$|0;if((G|0)>0){u=S;t=R;s=Q;r=P;o=O;n=N;C=M;D=L;E=aa;F=G;f=f+$|0}else{break}}i=j;return}function DP(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;h=e+f|0;j=b+12|0;k=c[j>>2]|0;c[k+28>>2]=c[k+36>>2];l=k+92|0;k=c[l>>2]|0;do{if((k|0)==0){m=$W(e,h)|0}else{n=h;if((k|0)>(f|0)){i=g;return}else{o=e;p=k;q=0}while(1){r=p-1|0;s=d[o]|q<<8;if((r|0)==0){break}else{o=o+1|0;p=r;q=s}}if(s>>>0>(n-(e+k)|0)>>>0){i=g;return}else{m=(e+(s+k)|0)!=0?e:h;break}}}while(0);if(!(m>>>0<h>>>0)){i=g;return}e=b;k=h;s=m;while(1){m=c[l>>2]|0;if((m|0)==0){q=s;while(1){t=q+1|0;if((a[q]|0)==0){q=t}else{break}}u=$W(t,h)|0;v=t}else{do{if((k-s|0)<(m|0)){w=0;x=s+m|0}else{q=s;n=m;p=0;while(1){o=n-1|0;y=d[q]|p<<8;if((o|0)==0){break}else{q=q+1|0;n=o;p=y}}p=s+m|0;if(y>>>0>(k-p|0)>>>0){w=0;x=p;break}w=s+(y+m)|0;x=p}}while(0);u=(w|0)==0?h:w;v=x}m=u-v|0;p=(u|0)==(h|0)|0;n=c[j>>2]|0;yDb(e,48,1903800,(q=i,i=i+24|0,c[q>>2]=a[v]&31,c[q+8>>2]=m,c[q+16>>2]=p,q)|0);i=q;o=n+40|0;f=c[o>>2]|0;do{if((f|0)<(m|0)){r=a[v]|0;if((c[n+96>>2]&8|0)!=0){yDb(e,16,2213784,(q=i,i=i+24|0,c[q>>2]=m,c[q+8>>2]=f,c[q+16>>2]=f,q)|0);i=q;break}yDb(e,48,2129232,(q=i,i=i+16|0,c[q>>2]=m,c[q+8>>2]=f,q)|0);i=q;z=n+80|0;a[c[z>>2]|0]=28;A=c[z>>2]|0;a[A]=a[A]|r&96;a[(c[z>>2]|0)+1|0]=r&31;r=(c[z>>2]|0)+1|0;a[r]=a[r]|-128;r=v+1|0;A=m-1|0;B=m+1|0;C=c[o>>2]|0;D=c[z>>2]|0;if((B|0)>(C|0)){E=A;F=r;G=C;C=D;while(1){UGb(C+2|0,F|0,G-2|0)|0;rP(b,c[z>>2]|0,c[o>>2]|0,0);H=(c[o>>2]|0)-2|0;I=F+H|0;J=E-H|0;H=(c[z>>2]|0)+1|0;a[H]=a[H]&127;H=J+2|0;K=c[o>>2]|0;L=c[z>>2]|0;if((H|0)>(K|0)){E=J;F=I;G=K;C=L}else{M=J;N=I;O=H;P=L;break}}}else{M=A;N=r;O=B;P=D}C=P+1|0;a[C]=a[C]|64;UGb((c[z>>2]|0)+2|0,N|0,M)|0;rP(b,c[z>>2]|0,O,p)}else{rP(b,v,m,p)}}while(0);if(u>>>0<h>>>0){s=u}else{break}}i=g;return}function EP(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;h=c[b+12>>2]|0;j=h+80|0;k=h+84|0;c[k>>2]=c[j>>2];c[h+28>>2]=c[h+36>>2];l=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;m=(c[l+120>>2]|0)>>>3;n=(c[l+124>>2]|0)>>>3;o=c[l+140>>2]|0;if((o|0)==13){p=0}else if((o|0)==12){p=1}else{yDb(b,16,1903720,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;i=g;return}a:do{if((f|0)>0){o=b;l=0;r=0;s=0;b:while(1){t=s+1|0;do{if((a[e+s|0]|0)==-1){u=a[e+t|0]|0;if((u<<24>>24|0)==(-64|0)){if((a[e+(s+14)|0]|0)!=17){v=14;break b}if((a[e+(s+17)|0]|0)==17){w=r;y=l;break}else{v=14;break b}}else if((u<<24>>24|0)==(-38|0)){v=15;break b}else if((u<<24>>24|0)!=(-37|0)){w=r;y=l;break}u=s+4|0;z=e+u|0;if((a[z]|0)!=0){yDb(o,24,2213680,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}A=e+(s+2)|0;B=(((de((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535)/65|0)&65535;if(((B*65|0)+u|0)>(f|0)){v=11;break b}else{w=z;y=B}}else{w=r;y=l}}while(0);if((t|0)<(f|0)){l=y;r=w;s=t}else{C=t;D=y;E=w;break a}}if((v|0)==11){yDb(o,16,2129096,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;i=g;return}else if((v|0)==14){yDb(o,16,2066144,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;i=g;return}else if((v|0)==15){B=s+2|0;z=e+B|0;C=B+((de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)|0;D=l;E=r;break}}else{C=0;D=0;E=0}}while(0);v=e+C|0;q=f-C|0;f=q-2|0;w=C+1|0;c:do{if((f|0)>-1){y=f;while(1){if((a[e+(y+C)|0]|0)==-1){if((a[e+(w+y)|0]|0)==-39){F=y;break c}}if((y|0)>0){y=y-1|0}else{F=q;break}}}else{F=q}}while(0);q=c[k>>2]|0;if((F|0)<=0){i=g;return}k=h+40|0;h=m&255;m=n&255;n=D<<6;w=de(n&65535|0)|0;e=n|12;if((D|0)==0){n=F;C=0;f=v;y=q;while(1){r=(c[k>>2]|0)-8|0;l=(n|0)>(r|0)?r:n;a[y]=0;a[y+3|0]=C;a[y+2|0]=C>>>8;a[y+1|0]=C>>>16;a[y+4|0]=p;a[y+5|0]=-1;a[y+6|0]=h;a[y+7|0]=m;UGb(y+8|0,f|0,l)|0;rP(b,c[j>>2]|0,l+8|0,(n|0)==(l|0)|0);r=n-l|0;if((r|0)>0){n=r;C=l+C|0;f=f+l|0;y=c[j>>2]|0}else{break}}i=g;return}if((D|0)<=0){y=F;f=0;C=v;n=q;while(1){l=(f|0)!=0;r=l?8:e;s=(c[k>>2]|0)-r|0;o=(y|0)>(s|0)?s:y;a[n]=0;a[n+3|0]=f;a[n+2|0]=f>>>8;a[n+1|0]=f>>>16;a[n+4|0]=p;a[n+5|0]=-1;a[n+6|0]=h;a[n+7|0]=m;s=n+8|0;if(l){G=s}else{a[s]=0;a[n+9|0]=0;s=n+10|0;x=w;a[s]=x;x=x>>8;a[s+1|0]=x;G=n+12|0}UGb(G|0,C|0,o)|0;rP(b,c[j>>2]|0,o+r|0,(y|0)==(o|0)|0);r=y-o|0;if((r|0)>0){y=r;f=o+f|0;C=C+o|0;n=c[j>>2]|0}else{break}}i=g;return}n=D<<6|12;C=F;F=0;f=v;v=q;while(1){q=(F|0)!=0;y=q?8:e;G=(c[k>>2]|0)-y|0;o=(C|0)>(G|0)?G:C;a[v]=0;a[v+3|0]=F;a[v+2|0]=F>>>8;a[v+1|0]=F>>>16;a[v+4|0]=p;a[v+5|0]=-1;a[v+6|0]=h;a[v+7|0]=m;G=v+8|0;if(q){H=G}else{a[G]=0;a[v+9|0]=0;G=v+10|0;x=w;a[G]=x;x=x>>8;a[G+1|0]=x;G=v+12|0;q=0;while(1){UGb(G|0,E+((q*65|0)+1)|0,64)|0;r=q+1|0;if((r|0)<(D|0)){G=G+64|0;q=r}else{break}}H=v+n|0}UGb(H|0,f|0,o)|0;rP(b,c[j>>2]|0,o+y|0,(C|0)==(o|0)|0);q=C-o|0;if((q|0)>0){C=q;F=o+F|0;f=f+o|0;v=c[j>>2]|0}else{break}}i=g;return}function FP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[b+12>>2]|0;if((c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+100>>2]|0)==0){g=d+7|0;h=e-7|0}else{g=d;h=e}e=(h|0)/255|0;d=e+1|0;i=f+80|0;TGb(c[i>>2]|0,-1|0,e|0)|0;a[(c[i>>2]|0)+e|0]=(h|0)%255|0;c[f+28>>2]=c[f+36>>2];if((h|0)<=0){return}e=f+40|0;f=h;h=0;while(1){j=(h|0)!=0;k=(c[e>>2]|0)-(j?0:d)|0;l=(f|0)>(k|0)?k:f;k=f-l|0;if(j){rP(b,g+h|0,l,(f|0)==(l|0)|0)}else{UGb((c[i>>2]|0)+d|0,g|0,l)|0;rP(b,c[i>>2]|0,l+d|0,(f|0)==(l|0)|0)}if((k|0)>0){f=k;h=l+h|0}else{break}}return}function GP(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;i=i+8|0;h=g|0;j=c[b+12>>2]|0;k=e+f|0;l=c[j+40>>2]|0;if((f|0)<=0){i=g;return}m=l-4|0;n=j+80|0;o=j+36|0;p=j+28|0;j=f;f=1;q=0;r=0;s=e;while(1){a:do{if((m|0)<(j|0)){e=s;if((f|0)==0){c[h>>2]=-1;t=f1a(s,k,h)|0;u=c[h>>2]|0;if((u&-256|0)!=256){v=0;w=r;x=q;y=0;z=m;break}if((u|0)==256){A=d[t+1|0]|0;B=(d[t]|0)<<2|A>>>6;C=A>>>3&7}else{B=r;C=q}A=(u|0)==440|0;u=t;t=u-e-4|0;if((t|0)>(m|0)){D=s;E=C;F=B;G=A;H=u}else{v=A;w=B;x=C;y=1;z=t;break}}else{t=s;A=0;u=r;I=q;while(1){c[h>>2]=-1;J=f1a(t,k,h)|0;K=c[h>>2]|0;if((K&-256|0)!=256){v=A;w=u;x=I;y=0;z=m;break a}if((K|0)==256){L=d[J+1|0]|0;M=(d[J]|0)<<2|L>>>6;N=L>>>3&7}else{M=u;N=I}L=(K|0)==440?1:A;K=J;if((K-e-4|0)>(m|0)){D=t;E=N;F=M;G=L;H=K;break}else{t=J;A=L;u=M;I=N}}}I=D;u=I-e|0;if((u|0)<=4){v=G;w=F;x=E;y=0;z=m;break}A=(H-I|0)<(l|0);v=G;w=F;x=E;y=A&1;z=A?u-4|0:m}else{v=0;w=r;x=q;y=1;z=j}}while(0);u=y<<11|f<<12|x<<8|w<<16|v<<13;A=c[n>>2]|0;a[A]=u>>>24;a[A+1|0]=u>>>16;a[A+2|0]=u>>>8;a[A+3|0]=0;UGb(A+4|0,s|0,z)|0;c[p>>2]=c[o>>2];u=c[n>>2]|0;rP(b,u,A+(z+4)-u|0,(z|0)==(j|0)|0);u=j-z|0;if((u|0)>0){j=u;f=y;q=x;r=w;s=s+z|0}else{break}}i=g;return}function HP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[b+12>>2]|0;g=f+80|0;h=c[g>>2]|0;i=f+84|0;c[f+28>>2]=c[f+36>>2];c[i>>2]=h+1;a[h]=-112;h=c[i>>2]|0;c[i>>2]=h+1;a[h]=-128;h=f+100|0;j=c[h>>2]|0;c[h>>2]=j+1;h=c[i>>2]|0;c[i>>2]=h+1;a[h]=j&127;j=c[i>>2]|0;h=j-(c[g>>2]|0)|0;k=(c[f+40>>2]|0)-h|0;if((e|0)>0){l=e;m=d;n=j}else{return}while(1){j=(l|0)>(k|0)?k:l;UGb(n|0,m|0,j)|0;rP(b,c[g>>2]|0,j+h|0,(l|0)==(j|0)|0);d=l-j|0;e=c[g>>2]|0;a[e]=a[e]&-17;if((d|0)<=0){break}l=d;m=m+j|0;n=c[i>>2]|0}return}function IP(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=c[b+12>>2]|0;h=c[g+40>>2]|0;switch(d[e]|0|0){case 3:case 129:{i=2;break};case 1:case 5:case 128:case 130:{i=1;break};default:{i=0}}j=g+80|0;k=c[j>>2]|0;a[k]=-2;a[k+1|0]=-51;l=k+3|0;a[k+2|0]=-70;m=(h|0)<(f|0);n=m&1;if(!((i|0)==0&(m^1))){m=g+44|0;if((c[m>>2]|0)==0){o=g+84|0}else{p=c[j>>2]|0;q=g+84|0;rP(b,p,(c[q>>2]|0)-p|0,0);o=q}c[g+28>>2]=c[g+36>>2];c[m>>2]=0;c[o>>2]=l;if((f|0)<=0){return}m=i<<4;i=n;n=f;q=e;p=l;while(1){r=(i|0)==0|(i|0)==3?n:h;a[p]=i<<6|m;a[p+1|0]=r>>>8;a[p+2|0]=r;UGb(p+3|0,q|0,r)|0;s=n-r|0;t=c[j>>2]|0;rP(b,t,p+(r+3)-t|0,0);if((s|0)<=0){break}i=(s|0)<=(h|0)?3:2;n=s;q=q+r|0;p=c[o>>2]|0}return}o=g+84|0;p=g+44|0;q=c[p>>2]|0;if((q|0)>0){n=c[o>>2]|0;i=c[j>>2]|0;if((i+(h+6)-(n+(f+2))|0)<0){u=i;v=n;w=9}else{w=7}}else{w=7}do{if((w|0)==7){if((q|0)==(c[g+88>>2]|0)){u=c[j>>2]|0;v=c[o>>2]|0;w=9;break}else{if((q|0)==0){w=11;break}else{x=q;break}}}}while(0);if((w|0)==9){rP(b,u,v-u|0,0);c[p>>2]=0;w=11}if((w|0)==11){c[g+28>>2]=c[g+36>>2];x=0}g=x+1|0;c[p>>2]=g;a[l]=g;if((c[p>>2]|0)>1){y=c[o>>2]|0}else{y=k+4|0}a[y]=f>>>8;a[y+1|0]=f;UGb(y+2|0,e|0,f)|0;c[o>>2]=y+(f+2);return}function JP(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=(RGb(((d[b+1|0]|0)<<8|(d[b]|0)<<16|(d[b+2|0]|0)|0)==15711167?b+3|0:b,1947656,6)|0)==0;return(a?100:0)|0}function KP(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+2056|0;e=d|0;f=d+1024|0;g=d+2048|0;h=c[b+12>>2]|0;j=LT(b,0)|0;a[g]=0;if((j|0)==0){k=-12;i=d;return k|0}MT(j,64,1,1e3);l=j+8|0;j=c[l>>2]|0;c[j+8>>2]=3;c[j+48>>2]=1396788553;IAb(e,0,-1);IAb(f,0,-1);j=b+16|0;a:do{if((Xy(c[j>>2]|0)|0)==0){b=e|0;m=h;n=e+4|0;o=0;p=0;q=0;while(1){r=Ty(c[j>>2]|0,0,0,1)|0;s=ZGb(r,F,q,p)|0;r=F;if((BR(c[j>>2]|0,e,g)|0)==0){t=14;break a}u=(zAb(c[b>>2]|0,2066096,5)|0)!=0;v=u?o:1;w=c[b>>2]|0;do{if((v|0)==0){KAb(f,2019520,(x=i,i=i+8|0,c[x>>2]=w,x)|0);i=x}else{x=uR(m,w,c[n>>2]|0,u&1)|0;if((x|0)==0){y=-12;break a}if(u){break}z=CR(c[b>>2]|0,1976856)|0;A=x+64|0;c[A>>2]=s;c[A+4>>2]=r;if((z|0)==0){B=0;C=0}else{A=kb(z|0,0,10)|0;B=(A|0)<0|0?-1:0;C=A}A=x+8|0;c[A>>2]=C;c[A+4>>2]=B;c[x+48>>2]=-1}}while(0);PAb(e);if((Xy(c[j>>2]|0)|0)!=0){t=14;break a}o=v;p=0;q=(a[g]|0)!=0|0}}else{t=14}}while(0);do{if((t|0)==14){g=e1a(c[l>>2]|0,f)|0;if((g|0)<0){y=g;break}vR(h);y=g}}while(0);QAb(e,0)|0;k=y;i=d;return k|0}function LP(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function MP(a){a=a|0;AR(c[a+12>>2]|0);return 0}function NP(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function OP(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+40|0;h=g|0;j=c[b+16>>2]|0;k=Wy(j)|0;l=F;m=YGb(k,l,-128,-1)|0;Ty(j,m,F,0)|0;m=h|0;if((mz(j,m,7)|0)!=7){n=-1;i=g;return n|0}if((PGb(m,1903456,7)|0)!=0){n=-1;i=g;return n|0}o=(mz(j,m,35)|0)!=35;if(!(o|(a[m]|0)==0)){a[h+35|0]=0;CBb(b+1140|0,2213608,m,0)|0}o=(mz(j,m,20)|0)!=20;if(!(o|(a[m]|0)==0)){a[h+20|0]=0;CBb(b+1140|0,2129024,m,0)|0}o=(mz(j,m,20)|0)!=20;if(!(o|(a[m]|0)==0)){a[h+20|0]=0;CBb(b+1140|0,2066072,m,0)|0}o=(mz(j,m,8)|0)!=8;if(!(o|(a[m]|0)==0)){a[h+8|0]=0;CBb(b+1140|0,2019488,m,0)|0}Vy(j,4,0)|0;o=lz(j)|0;p=lz(j)|0;q=pz(j)|0;r=pz(j)|0;s=lz(j)|0;Vy(j,1,0)|0;Vy(j,4,0)|0;t=(mz(j,m,22)|0)!=22;if(!(t|(a[m]|0)==0)){a[h+22|0]=0;CBb(b+1140|0,1976808,m,0)|0}a:do{if(!((e|0)==0|(o|0)==0|(p|0)==0)){do{if(!((o|0)==1&(p|0)<3)){h=(o|0)==5;if(h&(p|0)==255|(o|0)==6){break}if(!h){break a}c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+120>>2]=((p|0)==1?q:p)<<4;c[e>>2]=1;if((f|0)==0|(r|0)==0){break a}c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+124>>2]=r<<4;break a}}while(0);if((q|0)!=0){c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+120>>2]=q<<3;c[e>>2]=1}if((f|0)==0|(r|0)==0){break}c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+124>>2]=r<<4}}while(0);r=YGb(c[d>>2]|0,c[d+4>>2]|0,-128,-1)|0;c[d>>2]=r;c[d+4>>2]=F;if((s|0)<=0){n=0;i=g;return n|0}r=s<<6;f=YGb(k,l,-133,-1)|0;l=ZGb(f,F,r,(r|0)<0|0?-1:0)|0;Ty(j,l,F,0)|0;if((mz(j,m,5)|0)!=5){n=0;i=g;return n|0}if((PGb(m,1947576,5)|0)!=0){n=0;i=g;return n|0}m=WDb((s*65|0)+1|0)|0;l=r|5;r=ZGb(c[d>>2]|0,c[d+4>>2]|0,l,(l|0)<0|0?-1:0)|0;c[d>>2]=r;c[d+4>>2]=F;if((m|0)==0){n=0;i=g;return n|0}else{u=0}while(1){d=u*65|0;if((mz(j,m+d|0,64)|0)!=64){v=u;break}a[m+(d+64)|0]=10;d=u+1|0;if((d|0)<(s|0)){u=d}else{v=d;break}}a[m+(v*65|0)|0]=0;CBb(b+1140|0,1922416,m,8)|0;n=0;i=g;return n|0}function PP(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+88|0;d=b|0;e=d;TGb(e|0,0,88)|0;do{if((UP(0,c[a+4>>2]|0,c[a+8>>2]|0,d)|0)<0){f=0}else{if((c[d+20>>2]|0)==0){f=0;break}f=(c[d+24>>2]|0)!=0?33:0}}while(0);$Db(e);$Db(d+4|0);$Db(d+8|0);$Db(d+12|0);$Db(d+16|0);$Db(d+72|0);i=b;return f|0}function QP(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;d=i;i=i+248|0;e=d|0;f=d+24|0;g=d+48|0;h=d+72|0;j=d+120|0;k=d+128|0;l=d+136|0;m=d+144|0;n=d+232|0;o=c[b+12>>2]|0;c[l>>2]=0;p=m;TGb(p|0,0,88)|0;TGb(n|0,0,12)|0;q=c[b+16>>2]|0;r=c[o+12>>2]|0;s=0;t=0;u=0;while(1){if((s-t|0)<1024){v=s<<1;w=(v|0)>8192?v:8192;v=(w|0)>(r|0)?r:w;if((v-t|0)<2){y=-27;z=u;A=8;break}w=YDb(u,v,1)|0;if((w|0)==0){y=-12;z=0;A=8;break}else{B=v;C=w}}else{B=s;C=u}w=mz(q,C,B+~t|0)|0;if((w|0)==-541478725){A=7;break}if((w|0)<0){y=t;z=C;A=8;break}else{s=B;t=w+t|0;u=C}}if((A|0)==7){a[C+t|0]=0;c[l>>2]=C;D=t}else if((A|0)==8){ZDb(z);D=y}a:do{if((D|0)<0){E=D}else{y=b;z=UP(y,c[l>>2]|0,D,m)|0;if((z|0)<0){E=z;break}z=o+4|0;t=c[z>>2]|0;C=m+76|0;if((t|0)==0){c[z>>2]=c[C>>2]}else{c[C>>2]=t}t=o+8|0;if((c[t>>2]|0)==0){C=c[z>>2]|0;if((C|0)<10){G=1}else{G=(C|0)/10|0}c[t>>2]=G}C=m+72|0;if((c[C>>2]|0)!=0){yDb(y,24,2128848,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}c[k>>2]=0;u=m+24|0;B=c[u>>2]|0;if((B|0)>0){s=c[m+8>>2]|0;q=0;r=0;while(1){w=((a[s+(r<<5)+8|0]|0)==78)+q|0;v=r+1|0;if((v|0)<(B|0)){q=w;r=v}else{I=w;break}}}else{I=0}do{if((I|0)==(B|0)){r=m+40|0;if((c[r>>2]|0)==0&(c[r+4>>2]|0)==(-2147483648|0)){J=0;K=0;L=r;break}yDb(y,24,1880888,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;J=0;K=0;L=r}else{if((I|0)==0){r=m+40|0;q=c[r>>2]|0;s=c[r+4>>2]|0;if(!((q|0)==0&(s|0)==(-2147483648|0))){J=s;K=q;L=r;break}}if((a[m+80|0]|0)!=0){r=m+40|0;q=c[r>>2]|0;s=c[r+4>>2]|0;if(!((q|0)==0&(s|0)==(-2147483648|0))){J=s;K=q;L=r;break}q=c[m+8>>2]|0;s=c[q>>2]|0;w=c[q+4>>2]|0;c[r>>2]=s;c[r+4>>2]=w;J=w;K=s;L=r;break}yDb(y,24,2338840,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ee(j|0)|0;r=ub(j|0)|0;if((r|0)==0){M=(c[j>>2]|0)%86400|0}else{M=((c[r+4>>2]|0)*60|0)+((c[r+8>>2]|0)*3600|0)+(c[r>>2]|0)|0}r=M;s=(M|0)<0|0?-1:0;w=eHb(r,s,3600,0)|0;q=eHb(r,s,60,0)|0;yDb(y,32,2314568,(H=i,i=i+24|0,c[H>>2]=w,c[H+8>>2]=(q|0)%60|0,c[H+16>>2]=(M|0)%60|0,H)|0);i=H;q=gHb(r,s,1e6,0)|0;s=F;r=c[u>>2]|0;if((r|0)>0){w=m+8|0;v=0;N=r;while(1){r=c[w>>2]|0;O=r+(v<<5)+8|0;if((a[O]|0)==78){P=r+(v<<5)|0;r=YGb(c[P>>2]|0,c[P+4>>2]|0,q,s)|0;c[P>>2]=r;c[P+4>>2]=F;a[O]=84;Q=c[u>>2]|0}else{Q=N}O=v+1|0;if((O|0)<(Q|0)){v=O;N=Q}else{break}}}J=s;K=q;L=m+40|0}}while(0);B=c[L>>2]|0;N=c[L+4>>2]|0;if((B|0)==0&(N|0)==(-2147483648|0)){if((a[m+80|0]|0)==0){R=J;S=K}else{v=c[m+8>>2]|0;R=c[v+4>>2]|0;S=c[v>>2]|0}c[L>>2]=S;c[L+4>>2]=R;T=R;U=S}else{T=N;U=B}B=m+64|0;N=c[B>>2]|0;v=c[B+4>>2]|0;B=(N|0)==0&(v|0)==0;w=YGb(N,v,U,T)|0;v=m+48|0;c[v>>2]=B?0:w;c[v+4>>2]=B?-2147483648:F;B=c[u>>2]|0;w=(B|0)>0;N=m+8|0;do{if(w){O=c[N>>2]|0;P=J;r=K;V=0;W=0;X=0;do{Y=O+(X<<5)|0;Z=c[Y>>2]|0;_=c[Y+4>>2]|0;$=YGb(Z,_,W,V)|0;aa=F;ba=(aa|0)<(P|0)|(aa|0)==(P|0)&$>>>0<r>>>0;$=YGb(W,V,500654080,20)|0;W=ba?$:W;V=ba?F:V;r=YGb(W,V,Z,_)|0;P=F;c[Y>>2]=r;c[Y+4>>2]=P;X=X+1|0;}while((X|0)<(B|0));if(w){ca=0}else{break}do{X=XP(y,m,k,0,0,(c[N>>2]|0)+(ca<<5)|0)|0;if((X|0)<0){E=X;break a}ca=ca+1|0;}while((ca|0)<(c[u>>2]|0))}}while(0);u=m+28|0;w=c[u>>2]|0;if((w|0)==0){yDb(y,16,1947496,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;E=-1094995529;break}if((a[m+81|0]|0)==0){da=m+16|0}else{B=m+16|0;X=(c[B>>2]|0)+((w-1|0)*48|0)|0;w=c[X+4>>2]|0;c[v>>2]=c[X>>2];c[v+4>>2]=w;da=B}$Db(l);B=c[z>>2]|0;w=h;X=m+56|0;P=eHb(c[X>>2]|0,c[X+4>>2]|0,2,0)|0;X=F;r=c[u>>2]|0;V=r-1|0;W=c[da>>2]|0;O=W+(V*48|0)|0;q=W|0;s=c[q>>2]|0;Y=c[q+4>>2]|0;q=ZGb(c[O>>2]|0,c[O+4>>2]|0,s,Y)|0;O=YGb(q,F,500654079,20)|0;q=F;_=fHb(O,q,500654080,20)|0;Z=ZGb(O,q,_,F)|0;_=F;q=20;O=(_|0)>(q|0)|(_|0)==(q|0)&Z>>>0>500654080>>>0;q=O?Z:500654080;Z=O?_:20;if((r|0)>0){_=0;O=Y;Y=s;while(1){s=_+1|0;ba=(s|0)%(r|0)|0;$=W+(_*48|0)+8|0;c[$>>2]=Y;c[$+4>>2]=O;if((a[W+(_*48|0)+42|0]|0)==0){$=W+(ba*48|0)|0;aa=(_|0)<(ba|0);ba=YGb(c[$>>2]|0,c[$+4>>2]|0,aa?0:q,aa?0:Z)|0;ea=F;fa=ba}else{ea=O;fa=Y}ba=W+(_*48|0)+16|0;c[ba>>2]=fa;c[ba+4>>2]=ea;if((s|0)>=(r|0)){ga=0;break}ba=W+(s*48|0)|0;_=s;O=c[ba+4>>2]|0;Y=c[ba>>2]|0}while(1){Y=ga+1|0;O=(Y|0)==(r|0)?0:Y;if((a[W+(ga*48|0)+42|0]|0)==0){_=W+(ga*48|0)+8|0;ba=c[_>>2]|0;s=c[_+4>>2]|0;_=W+(ga*48|0)+16|0;aa=ZGb(c[_>>2]|0,c[_+4>>2]|0,P,X)|0;$=F;ha=(s|0)>($|0)|(s|0)==($|0)&ba>>>0>aa>>>0;c[_>>2]=ha?ba:aa;c[_+4>>2]=ha?s:$;$=W+(O*48|0)+16|0;s=c[$>>2]|0;ha=c[$+4>>2]|0;$=W+(O*48|0)+8|0;_=YGb(c[$>>2]|0,c[$+4>>2]|0,P,X)|0;aa=F;ba=(ha|0)>(aa|0)|(ha|0)==(aa|0)&s>>>0>_>>>0;ia=ba?_:s;s=ba?aa:ha;c[$>>2]=ia;c[$+4>>2]=s;ja=s;ka=ia}else{ia=W+(O*48|0)+8|0;ja=c[ia+4>>2]|0;ka=c[ia>>2]|0}ia=(ga|0)<(O|0);O=YGb(ka,ja,ia?0:q,ia?0:Z)|0;ia=W+(ga*48|0)+24|0;c[ia>>2]=O;c[ia+4>>2]=F;if((Y|0)<(r|0)){ga=Y}else{break}}}X=W+(V*48|0)|0;c[w>>2]=c[X>>2];c[w+4>>2]=c[X+4>>2];c[w+8>>2]=c[X+8>>2];c[w+12>>2]=c[X+12>>2];c[w+16>>2]=c[X+16>>2];c[w+20>>2]=c[X+20>>2];c[w+24>>2]=c[X+24>>2];c[w+28>>2]=c[X+28>>2];c[w+32>>2]=c[X+32>>2];c[w+36>>2]=c[X+36>>2];c[w+40>>2]=c[X+40>>2];c[w+44>>2]=c[X+44>>2];X=h+8|0;P=ZGb(c[X>>2]|0,c[X+4>>2]|0,q,Z)|0;c[X>>2]=P;c[X+4>>2]=F;X=h+16|0;P=ZGb(c[X>>2]|0,c[X+4>>2]|0,q,Z)|0;c[X>>2]=P;c[X+4>>2]=F;X=h+24|0;P=ZGb(c[X>>2]|0,c[X+4>>2]|0,q,Z)|0;c[X>>2]=P;c[X+4>>2]=F;if((r|0)>-1){X=B;P=(B|0)<0|0?-1:0;Y=-1;do{if((Y|0)<0){la=h}else{la=W+(Y*48|0)|0}ia=la+8|0;O=IDb(c[ia>>2]|0,c[ia+4>>2]|0,X,P,1e6,0)|0;c[ia>>2]=O;c[ia+4>>2]=F;ia=la+16|0;O=IDb(c[ia>>2]|0,c[ia+4>>2]|0,X,P,1e6,0)|0;c[ia>>2]=O;c[ia+4>>2]=F;ia=la+24|0;O=IDb(c[ia>>2]|0,c[ia+4>>2]|0,X,P,1e6,0)|0;c[ia>>2]=O;c[ia+4>>2]=F;Y=Y+1|0;}while((Y|0)<(r|0))}r=m+32|0;Y=m+4|0;if((c[r>>2]|0)>0){P=c[Y>>2]|0;X=0;do{c[P+(X*24|0)+20>>2]=-1;c[P+(X*24|0)+16>>2]=-1;X=X+1|0;}while((X|0)<(c[r>>2]|0))}r=e;X=f;P=g;W=e+12|0;B=f+12|0;Z=g+8|0;q=f+16|0;w=e|0;V=f|0;ia=e+4|0;O=f+4|0;s=e+8|0;$=f+8|0;ha=-1;while(1){aa=c[u>>2]|0;if((ha|0)>=(aa|0)){break}ba=c[da>>2]|0;if((ha|0)<0){ma=h}else{ma=ba+(ha*48|0)|0}_=ha+1|0;na=ma+8|0;oa=c[na>>2]|0;pa=c[na+4>>2]|0;na=ma+16|0;qa=c[na>>2]|0;ra=c[na+4>>2]|0;sa=ma+32|0;ta=ma+36|0;ua=0;while(1){va=c[ta>>2]|0;if((ua|0)>=(va|0)){break}wa=(c[Y>>2]|0)+(((c[sa>>2]|0)+ua|0)*24|0)|0;xa=VP(y,m,n,oa,pa,qa,ra,wa,wa,0)|0;if((xa|0)<0){E=xa;break a}else{ua=ua+1|0}}ua=(_|0)%(aa|0)|0;ra=c[na>>2]|0;qa=c[na+4>>2]|0;pa=ma+24|0;oa=c[pa>>2]|0;xa=c[pa+4>>2]|0;pa=YGb(oa>>>1|xa<<31,xa>>1|((xa|0)<0|0?-1:0)<<31,ra>>>1|qa<<31,qa>>1|((qa|0)<0|0?-1:0)<<31)|0;wa=YGb(pa,F,ra&1&oa,qa&0&xa)|0;pa=F;ya=ma+42|0;za=ba+(ua*48|0)+36|0;Aa=c[za>>2]|0;Ba=(va|0)>(Aa|0)?va:Aa;Aa=(Ba|0)>0;Ca=ba+(ua*48|0)+32|0;Da=(a[ba+(ua*48|0)+40|0]&a[ma+41|0]|a[ya])<<24>>24==3;ua=0;b:while(1){if(Aa){Ea=(ua|0)==0;Fa=0;do{if((Fa|0)<(c[ta>>2]|0)){Ga=(c[Y>>2]|0)+(((c[sa>>2]|0)+Fa|0)*24|0)|0}else{Ga=e}if((Fa|0)<(c[za>>2]|0)){Ha=(c[Y>>2]|0)+(((c[Ca>>2]|0)+Fa|0)*24|0)|0}else{Ha=f}if((Ga|0)==(e|0)){TGb(r|0,0,24)|0}else{Ia=Ga;c[r>>2]=c[Ia>>2];c[r+4>>2]=c[Ia+4>>2];c[r+8>>2]=c[Ia+8>>2];c[r+12>>2]=c[Ia+12>>2];c[r+16>>2]=c[Ia+16>>2];c[r+20>>2]=c[Ia+20>>2]}if((Ha|0)==(f|0)){TGb(X|0,0,24)|0}else{Ia=Ha;c[X>>2]=c[Ia>>2];c[X+4>>2]=c[Ia+4>>2];c[X+8>>2]=c[Ia+8>>2];c[X+12>>2]=c[Ia+12>>2];c[X+16>>2]=c[Ia+16>>2];c[X+20>>2]=c[Ia+20>>2]}do{if((a[ya]|0)!=0){if((c[W>>2]|0)==0){c[r>>2]=c[X>>2];c[r+4>>2]=c[X+4>>2];c[r+8>>2]=c[X+8>>2];c[r+12>>2]=c[X+12>>2];c[r+16>>2]=c[X+16>>2];c[r+20>>2]=c[X+20>>2];c[s>>2]=0;break}if((c[B>>2]|0)!=0){break}c[X>>2]=c[r>>2];c[X+4>>2]=c[r+4>>2];c[X+8>>2]=c[r+8>>2];c[X+12>>2]=c[r+12>>2];c[X+16>>2]=c[r+16>>2];c[X+20>>2]=c[r+20>>2];c[$>>2]=0}}while(0);Ia=c[W>>2]|0;do{if((Ia|0)!=(c[B>>2]|0)|(Ia|0)==3){A=104}else{if(!Da){if((c[w>>2]|0)!=(c[V>>2]|0)){A=104;break}if((c[ia>>2]|0)!=(c[O>>2]|0)){A=104;break}}if(!Ea){break}Ja=VP(y,m,n,ra,qa,oa,xa,e,f,3)|0;if((Ja|0)<0){Ka=Ja;break b}Ja=Ha+16|0;La=c[q+4>>2]|0;c[Ja>>2]=c[q>>2];c[Ja+4>>2]=La}}while(0);do{if((A|0)==104){A=0;if(Ea){c[P>>2]=c[r>>2];c[P+4>>2]=c[r+4>>2];c[P+8>>2]=c[r+8>>2];c[P+12>>2]=c[r+12>>2];c[P+16>>2]=c[r+16>>2];c[P+20>>2]=c[r+20>>2];c[Z>>2]=0;Ia=VP(y,m,n,ra,qa,wa,pa,e,g,1)|0;if((Ia|0)<0){Ka=Ia;break b}else{break}}c[P>>2]=c[X>>2];c[P+4>>2]=c[X+4>>2];c[P+8>>2]=c[X+8>>2];c[P+12>>2]=c[X+12>>2];c[P+16>>2]=c[X+16>>2];c[P+20>>2]=c[X+20>>2];c[Z>>2]=0;Ia=VP(y,m,n,wa,pa,oa,xa,g,f,2)|0;if((Ia|0)<0){Ka=Ia;break b}Ia=Ha+16|0;La=c[q+4>>2]|0;c[Ia>>2]=c[q>>2];c[Ia+4>>2]=La}}while(0);Fa=Fa+1|0;}while((Fa|0)<(Ba|0))}Fa=ua+1|0;if((Fa|0)<2){ua=Fa}else{Ka=0;break}}if((Ka|0)<0){E=Ka;break a}else{ha=_}}ha=n+4|0;q=c[ha>>2]|0;if((q|0)==0){yDb(y,24,2066024,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}Z=LT(b,0)|0;if((Z|0)==0){Ma=-12;i=d;return Ma|0}X=Z+8|0;P=c[X>>2]|0;c[P+8>>2]=1;c[P+48>>2]=1179014995;c[P+416>>2]=2;r=P+448|0;c[r>>2]=3;c[r+4>>2]=0;r=c[z>>2]|0;c[P+412>>2]=r;c[P+424>>2]=c[t>>2];MT(Z,64,1,r);c[Z+228>>2]=0;r=m+40|0;P=c[z>>2]|0;O=P;ia=(P|0)<0|0?-1:0;P=IDb(c[r>>2]|0,c[r+4>>2]|0,O,ia,1e6,0)|0;V=F;w=Z+48|0;c[w>>2]=P;c[w+4>>2]=V;w=c[v>>2]|0;B=c[v+4>>2]|0;if((w|0)==0&(B|0)==(-2147483648|0)){Na=-2147483648;Oa=0}else{W=ZGb(w,B,c[r>>2]|0,c[r+4>>2]|0)|0;r=IDb(W,F,O,ia,1e6,0)|0;Na=F;Oa=r}r=Z+56|0;c[r>>2]=Oa;c[r+4>>2]=Na;r=Z+208|0;c[r>>2]=P;c[r+4>>2]=V;V=c[X>>2]|0;X=n|0;r=c[X>>2]|0;P=4;Z=0;while(1){if((Z|0)>=(q|0)){break}ia=c[r+(Z*48|0)+16>>2]|0;if((ia|0)==1162758483){Pa=44}else{Pa=(ia|0)==1397313358?32:0}ia=Pa+P|0;if((ia|0)<0){E=-12;break a}else{P=ia;Z=Z+1|0}}if((BT(V,P)|0)!=0){E=-12;break}Z=V+96|0;v=c[Z>>2]|0;z=v;x=q;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;z=v+4|0;c:do{if((q|0)>0){v=0;t=z;y=r;while(1){ia=y+(v*48|0)|0;O=c[ia+4>>2]|0;W=t;B=W|0;x=c[ia>>2]|0;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;B=W+4|0;x=O;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;B=(c[X>>2]|0)+(v*48|0)+8|0;O=c[B+4>>2]|0;W=t+8|0;ia=W|0;x=c[B>>2]|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=W+4|0;x=O;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=t+16|0;x=c[(c[X>>2]|0)+(v*48|0)+16>>2]|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=t+20|0;x=c[(c[X>>2]|0)+(v*48|0)+20>>2]|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=t+24|0;O=c[X>>2]|0;W=c[O+(v*48|0)+16>>2]|0;if((W|0)==1162758483){B=ia;x=c[O+(v*48|0)+24>>2]|0;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;B=t+28|0;x=c[(c[X>>2]|0)+(v*48|0)+28>>2]|0;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;B=t+32|0;x=c[(c[X>>2]|0)+(v*48|0)+32>>2]|0;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;B=t+36|0;x=c[(c[X>>2]|0)+(v*48|0)+36>>2]|0;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;B=t+40|0;x=c[(c[X>>2]|0)+(v*48|0)+40>>2]|0;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;Qa=t+44|0}else if((W|0)==1397313358){W=ia;x=c[O+(v*48|0)+32>>2]|0;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;W=t+28|0;x=c[(c[X>>2]|0)+(v*48|0)+36>>2]|0;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;Qa=t+32|0}else{Qa=ia}ia=v+1|0;if((ia|0)>=(c[ha>>2]|0)){Ra=Qa;break c}v=ia;t=Qa;y=c[X>>2]|0}}else{Ra=z}}while(0);if((Ra|0)!=((c[Z>>2]|0)+P|0)){E=-558323010;break}ZDb(c[X>>2]|0);$Db(p);$Db(Y);$Db(N);$Db(m+12|0);$Db(da);$Db(C);Ma=0;i=d;return Ma|0}}while(0);ZDb(c[n>>2]|0);$Db(p);$Db(m+4|0);$Db(m+8|0);$Db(m+12|0);$Db(m+16|0);$Db(m+72|0);ZDb(c[l>>2]|0);Ma=E;i=d;return Ma|0}function RP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[c[b+28>>2]>>2]|0;b=e+208|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=c[(c[e+8>>2]|0)+424>>2]|0;h=YGb(b,(b|0)<0|0?-1:0,f,g)|0;b=F;i=e+56|0;j=c[i>>2]|0;k=c[i+4>>2]|0;if((j|0)==0&(k|0)==(-2147483648|0)){l=b;m=h}else{i=e+48|0;e=YGb(c[i>>2]|0,c[i+4>>2]|0,j,k)|0;k=F;j=(k|0)>(b|0)|(k|0)==(b|0)&e>>>0>h>>>0;l=j?b:k;m=j?h:e}if(!((l|0)>(g|0)|(l|0)==(g|0)&m>>>0>f>>>0)){n=-541478725;return n|0}if((wZ(d,12)|0)<0){n=-12;return n|0}e=d+8|0;c[e>>2]=f;c[e+4>>2]=g;e=d+16|0;c[e>>2]=f;c[e+4>>2]=g;e=ZGb(m,l,f,g)|0;l=d+48|0;c[l>>2]=e;e=d+24|0;m=c[e>>2]|0;h=m|0;x=f;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=m+4|0;x=g;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=(c[e>>2]|0)+8|0;x=c[l>>2]|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;n=c[d+28>>2]|0;return n|0}function SP(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;if((b|0)>0){h=-22;i=f;return h|0}if((b|0)<0){c[g>>2]=1;c[g+4>>2]=1e6;b=a+28|0;j=KDb(d,e,g,(c[c[b>>2]>>2]|0)+40|0)|0;k=F;l=j;m=b}else{k=e;l=d;m=a+28|0}a=(c[c[m>>2]>>2]|0)+208|0;c[a>>2]=l;c[a+4>>2]=k;h=0;i=f;return h|0}function TP(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0;j=i;i=i+8|0;h=j|0;if((k|0)!=0|(b|0)>0){l=-22;i=j;return l|0}if((b|0)<0){c[h>>2]=1;c[h+4>>2]=1e6;b=a+28|0;k=KDb(f,g,h,(c[c[b>>2]>>2]|0)+40|0)|0;m=F;n=k;o=b}else{m=g;n=f;o=a+28|0}a=(c[c[o>>2]>>2]|0)+208|0;c[a>>2]=n;c[a+4>>2]=m;l=0;i=j;return l|0}function UP(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0.0,oa=0,pa=0.0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0.0,hb=0,ib=0.0,jb=0,lb=0.0,mb=0,nb=0,ob=0.0,pb=0,qb=0.0,rb=0.0,sb=0,tb=0.0,ub=0,vb=0.0,wb=0,xb=0,yb=0,zb=0.0,Ab=0,Bb=0.0,Cb=0,Db=0,Eb=0.0,Fb=0,Gb=0,Hb=0,Jb=0,Kb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0;g=i;i=i+360|0;j=g|0;k=g+8|0;l=g+16|0;m=g+24|0;n=g+32|0;o=g+40|0;p=g+48|0;q=g+56|0;r=g+64|0;s=g+72|0;t=g+80|0;u=g+88|0;v=u|0;c[v>>2]=b;c[u+4>>2]=d;w=u+8|0;x=d+e|0;c[w>>2]=x;y=u+12|0;c[y>>2]=d;z=u+16|0;A=z;TGb(A|0,0,88)|0;B=u+56|0;c[B>>2]=0;c[B+4>>2]=-2147483648;C=u+72|0;c[C>>2]=6e7;c[C+4>>2]=0;D=u+92|0;c[D>>2]=44100;F=u+120|0;G=u+124|0;H=u+128|0;I=u+140|0;TGb(u+104|0,0,36)|0;c[I>>2]=1;J=u+144|0;TGb(J|0,0,128)|0;a:do{if((e|0)>0){K=d;while(1){L=a[K]|0;if(!((L<<24>>24|0)==32|(L<<24>>24|0)==9|(L<<24>>24|0)==13)){M=K;break a}L=K+1|0;c[y>>2]=L;if(L>>>0<x>>>0){K=L}else{M=L;break}}}else{M=d}}while(0);b:do{if(M>>>0<x>>>0){d=u+96|0;e=u+97|0;K=u+80|0;L=u+88|0;N=M;O=x;c:while(1){d:do{if((N|0)==(O|0)){R=119}else{if((a[N]|0)!=45){R=119;break}e:do{if(N>>>0<O>>>0){S=N+1|0;c[y>>2]=S;if((S|0)==(O|0)){T=0;U=O;V=O;break}else{W=O;X=0;Y=S}while(1){S=a[Y]|0;if(S<<24>>24==10){T=X;U=W;V=Y;break e}f:do{if(Y>>>0<W>>>0){Z=Y;_=S;while(1){if((_<<24>>24|0)==10|(_<<24>>24|0)==32|(_<<24>>24|0)==9|(_<<24>>24|0)==13){$=Z;break f}ba=Z+1|0;if(!(ba>>>0<W>>>0)){$=ba;break f}Z=ba;_=a[ba]|0}}else{$=Y}}while(0);c[y>>2]=$;g:do{if($>>>0<W>>>0){S=$;while(1){_=a[S]|0;if(!((_<<24>>24|0)==32|(_<<24>>24|0)==9|(_<<24>>24|0)==13)){ca=S;break g}_=S+1|0;c[y>>2]=_;if(_>>>0<W>>>0){S=_}else{ca=_;break}}}else{ca=$}}while(0);if(Y>>>0<$>>>0){S=Y;_=X;while(1){da=a[S]|0;switch(da|0){case 114:{Z=c[y>>2]|0;ba=c[w>>2]|0;if((Z|0)==(ba|0)){R=99;break c}ea=a[Z]|0;if(ea<<24>>24==10){R=99;break c}h:do{if(Z>>>0<ba>>>0){fa=Z;ha=ea;while(1){if((ha<<24>>24|0)==10|(ha<<24>>24|0)==32|(ha<<24>>24|0)==9|(ha<<24>>24|0)==13){ia=fa;break h}ja=fa+1|0;if(!(ja>>>0<ba>>>0)){ia=ja;break h}fa=ja;ha=a[ja]|0}}else{ia=Z}}while(0);c[y>>2]=ia;i:do{if(ia>>>0<ba>>>0){ea=ia;do{ha=a[ea]|0;if(!((ha<<24>>24|0)==32|(ha<<24>>24|0)==9|(ha<<24>>24|0)==13)){break i}ea=ea+1|0;c[y>>2]=ea;}while(ea>>>0<ba>>>0)}}while(0);ba=kb(Z|0,t|0,10)|0;if((ia|0)!=(c[t>>2]|0)){R=101;break c}if((ba|0)<40){R=103;break c}c[D>>2]=ba;ka=_;break};case 105:{ka=105;break};case 113:{ba=c[y>>2]|0;ea=c[w>>2]|0;if((ba|0)==(ea|0)){R=85;break c}ha=a[ba]|0;if(ha<<24>>24==10){R=85;break c}j:do{if(ba>>>0<ea>>>0){fa=ba;ja=ha;while(1){if((ja<<24>>24|0)==10|(ja<<24>>24|0)==32|(ja<<24>>24|0)==9|(ja<<24>>24|0)==13){la=fa;break j}ma=fa+1|0;if(!(ma>>>0<ea>>>0)){la=ma;break j}fa=ma;ja=a[ma]|0}}else{la=ba}}while(0);c[y>>2]=la;k:do{if(la>>>0<ea>>>0){ha=la;do{Z=a[ha]|0;if(!((Z<<24>>24|0)==32|(Z<<24>>24|0)==9|(Z<<24>>24|0)==13)){break k}ha=ha+1|0;c[y>>2]=ha;}while(ha>>>0<ea>>>0)}}while(0);na=+OGb(ba,t);if((la|0)!=(c[t>>2]|0)){R=87;break c}if(na!=1.0){R=89;break c}else{ka=_}break};case 83:{a[d]=1;ka=_;break};case 69:{a[e]=1;ka=_;break};case 112:{ka=112;break};case 70:{ea=c[y>>2]|0;ha=c[w>>2]|0;if((ea|0)==(ha|0)){R=36;break c}Z=a[ea]|0;if(Z<<24>>24==10){R=36;break c}l:do{if(ea>>>0<ha>>>0){ja=ea;fa=Z;while(1){if((fa<<24>>24|0)==10|(fa<<24>>24|0)==32|(fa<<24>>24|0)==9|(fa<<24>>24|0)==13){oa=ja;break l}ma=ja+1|0;if(!(ma>>>0<ha>>>0)){oa=ma;break l}ja=ma;fa=a[ma]|0}}else{oa=ea}}while(0);c[y>>2]=oa;m:do{if(oa>>>0<ha>>>0){Z=oa;do{ba=a[Z]|0;if(!((ba<<24>>24|0)==32|(ba<<24>>24|0)==9|(ba<<24>>24|0)==13)){break m}Z=Z+1|0;c[y>>2]=Z;}while(Z>>>0<ha>>>0)}}while(0);na=+OGb(ea,t);if((oa|0)!=(c[t>>2]|0)){R=38;break c}pa=na*1.0e6/1.0e3;ha=(E=+pa,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[C>>2]=~~+pa>>>0;c[C+4>>2]=ha;ka=_;break};case 76:{ha=c[y>>2]|0;Z=c[w>>2]|0;if((ha|0)==(Z|0)){R=49;break c}ba=a[ha]|0;if(ba<<24>>24==10){R=49;break c}n:do{if(ha>>>0<Z>>>0){fa=ha;ja=ba;while(1){if((ja<<24>>24|0)==10|(ja<<24>>24|0)==32|(ja<<24>>24|0)==9|(ja<<24>>24|0)==13){qa=fa;break n}ma=fa+1|0;if(!(ma>>>0<Z>>>0)){qa=ma;break n}fa=ma;ja=a[ma]|0}}else{qa=ha}}while(0);c[y>>2]=qa;o:do{if(qa>>>0<Z>>>0){ba=qa;do{ea=a[ba]|0;if(!((ea<<24>>24|0)==32|(ea<<24>>24|0)==9|(ea<<24>>24|0)==13)){break o}ba=ba+1|0;c[y>>2]=ba;}while(ba>>>0<Z>>>0)}}while(0);if((qa|0)==(ha+(ZP(ha,K)|0)|0)){ka=_}else{R=51;break c}break};case 84:{Z=c[y>>2]|0;ba=c[w>>2]|0;if((Z|0)==(ba|0)){R=61;break c}ea=a[Z]|0;if(ea<<24>>24==10){R=61;break c}p:do{if(Z>>>0<ba>>>0){ja=Z;fa=ea;while(1){if((fa<<24>>24|0)==10|(fa<<24>>24|0)==32|(fa<<24>>24|0)==9|(fa<<24>>24|0)==13){ra=ja;break p}ma=ja+1|0;if(!(ma>>>0<ba>>>0)){ra=ma;break p}ja=ma;fa=a[ma]|0}}else{ra=Z}}while(0);c[y>>2]=ra;q:do{if(ra>>>0<ba>>>0){ea=ra;do{ha=a[ea]|0;if(!((ha<<24>>24|0)==32|(ha<<24>>24|0)==9|(ha<<24>>24|0)==13)){break q}ea=ea+1|0;c[y>>2]=ea;}while(ea>>>0<ba>>>0)}}while(0);if((ra|0)==(Z+(ZP(Z,B)|0)|0)){ka=_}else{R=63;break c}break};case 109:{ba=c[y>>2]|0;ea=c[w>>2]|0;if((ba|0)==(ea|0)){R=73;break c}ha=a[ba]|0;if(ha<<24>>24==10){R=73;break c}r:do{if(ba>>>0<ea>>>0){fa=ba;ja=ha;while(1){if((ja<<24>>24|0)==10|(ja<<24>>24|0)==32|(ja<<24>>24|0)==9|(ja<<24>>24|0)==13){sa=fa;break r}ma=fa+1|0;if(!(ma>>>0<ea>>>0)){sa=ma;break r}fa=ma;ja=a[ma]|0}}else{sa=ba}}while(0);c[y>>2]=sa;s:do{if(sa>>>0<ea>>>0){ha=sa;do{Z=a[ha]|0;if(!((Z<<24>>24|0)==32|(Z<<24>>24|0)==9|(Z<<24>>24|0)==13)){break s}ha=ha+1|0;c[y>>2]=ha;}while(ha>>>0<ea>>>0)}}while(0);ea=sa-ba|0;ha=WDb(ea+1|0)|0;c[t>>2]=ha;if((ha|0)==0){ta=-12;break b}UGb(ha|0,ba|0,ea)|0;a[ha+ea|0]=0;ZDb(c[L>>2]|0);c[L>>2]=ha;ka=_;break};default:{R=105;break c}}ha=S+1|0;if(ha>>>0<$>>>0){S=ha;_=ka}else{break}}ua=ka;va=c[y>>2]|0;wa=c[w>>2]|0}else{ua=X;va=ca;wa=W}if(!(va>>>0<wa>>>0)){xa=ua;ya=va;za=wa;R=13;break e}_=(a[va]|0)==45;S=va+(_&1)|0;c[y>>2]=S;if((S|0)==(wa|0)|_^1){T=ua;U=wa;V=S;break}else{W=wa;X=ua;Y=S}}}else{xa=0;ya=N;za=O;R=13}}while(0);if((R|0)==13){R=0;c[y>>2]=ya;T=xa;U=za;V=ya}S=T<<24>>24;if((S|0)==112){R=109;break c}else if((S|0)==105){R=108;break c}else if((S|0)!=0){ta=-558323010;break b}t:do{if(V>>>0<U>>>0){if((a[V]|0)==35){Aa=V}else{Ba=V;break}while(1){S=Aa+1|0;c[y>>2]=S;if(!(S>>>0<U>>>0)){Ba=S;break t}if((a[S]|0)==10){Ba=S;break}else{Aa=S}}}else{Ba=V}}while(0);if((Ba|0)==(U|0)){Ca=Ba;Da=U;break}if((a[Ba]|0)!=10){ta=-1094995529;break b}S=Ba+1|0;c[y>>2]=S;c[I>>2]=(c[I>>2]|0)+1;if(S>>>0<U>>>0){Ea=S}else{Ca=S;Da=U;break}while(1){S=a[Ea]|0;if(!((S<<24>>24|0)==32|(S<<24>>24|0)==9|(S<<24>>24|0)==13)){Ca=Ea;Da=U;break d}S=Ea+1|0;c[y>>2]=S;if(S>>>0<U>>>0){Ea=S}else{Ca=S;Da=U;break}}}}while(0);u:do{if((R|0)==119){R=0;v:do{if(N>>>0<O>>>0){if((a[N]|0)==35){Fa=N}else{Ga=N;break}while(1){S=Fa+1|0;c[y>>2]=S;if(!(S>>>0<O>>>0)){Ga=S;break v}if((a[S]|0)==10){Ga=S;break}else{Fa=S}}}else{Ga=N}}while(0);if((Ga|0)==(O|0)){Ca=Ga;Da=O;break}if((a[Ga]|0)!=10){Ha=Ga;Ia=O;R=126;break b}S=Ga+1|0;c[y>>2]=S;c[I>>2]=(c[I>>2]|0)+1;if(S>>>0<O>>>0){Ja=S}else{Ca=S;Da=O;break}while(1){S=a[Ja]|0;if(!((S<<24>>24|0)==32|(S<<24>>24|0)==9|(S<<24>>24|0)==13)){Ca=Ja;Da=O;break u}S=Ja+1|0;c[y>>2]=S;if(S>>>0<O>>>0){Ja=S}else{Ca=S;Da=O;break}}}}while(0);if(Ca>>>0<Da>>>0){N=Ca;O=Da}else{Ha=Ca;Ia=Da;R=126;break b}}if((R|0)==36){Lb(J|0,128,2065416,(Ka=i,i=i+8|0,c[Ka>>2]=70,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==38){Lb(J|0,128,2128008,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==49){Lb(J|0,128,2065416,(Ka=i,i=i+8|0,c[Ka>>2]=76,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==51){Lb(J|0,128,2121952,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==61){Lb(J|0,128,2065416,(Ka=i,i=i+8|0,c[Ka>>2]=84,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==63){Lb(J|0,128,2116896,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==73){Lb(J|0,128,2065416,(Ka=i,i=i+8|0,c[Ka>>2]=109,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==85){Lb(J|0,128,2065416,(Ka=i,i=i+8|0,c[Ka>>2]=113,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==87){Lb(J|0,128,2103928,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==89){Lb(J|0,128,2095024,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1163346256;break}else if((R|0)==99){Lb(J|0,128,2065416,(Ka=i,i=i+8|0,c[Ka>>2]=114,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==101){Lb(J|0,128,2089520,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==103){Lb(J|0,128,2084736,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1163346256;break}else if((R|0)==105){Lb(J|0,128,2079480,(Ka=i,i=i+8|0,c[Ka>>2]=da,Ka)|0)|0;i=Ka;ta=-1094995529;break}else if((R|0)==108){Lb(J|0,128,2069936,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1163346256;break}else if((R|0)==109){Lb(J|0,128,2074720,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1163346256;break}}else{Ha=M;Ia=x;R=126}}while(0);w:do{if((R|0)==126){x:do{if(Ha>>>0<Ia>>>0){x=z;M=u+36|0;da=z|0;Da=u+48|0;Ca=u+20|0;Ja=Ha;Ga=Ia;y:while(1){Fa=Ja;while(1){U=a[Fa]|0;if(!((U-97&255)>>>0<26>>>0|(U-65&255)>>>0<26>>>0|(U-48&255)>>>0<10>>>0)){if(!((U<<24>>24|0)==95|(U<<24>>24|0)==45)){La=Fa;break}}U=Fa+1|0;if(U>>>0<Ga>>>0){Fa=U}else{La=U;break}}z:do{if((La|0)==(Ja|0)){R=313}else{c[y>>2]=La;if(!(La>>>0<Ga>>>0)){c[y>>2]=La;R=313;break}Fa=(a[La]|0)==58;U=La+(Fa&1)|0;c[y>>2]=U;if(Fa&U>>>0<Ga>>>0){Ma=U}else{R=313;break}while(1){Fa=a[Ma]|0;if(!((Fa<<24>>24|0)==32|(Fa<<24>>24|0)==9|(Fa<<24>>24|0)==13)){Na=Ma;break}Fa=Ma+1|0;c[y>>2]=Fa;if(Fa>>>0<Ga>>>0){Ma=Fa}else{Na=Fa;break}}if(!(Na>>>0>U>>>0)){R=313;break}Fa=La-Ja|0;do{if((Fa|0)==6){if((PGb(Ja,2180576,4)|0)!=0){break}if(!(((a[Ja+4|0]|0)-48&255)>>>0<10>>>0)){break}if(((a[Ja+5|0]|0)-48&255)>>>0<10>>>0){R=146;break y}}}while(0);U=c[M>>2]|0;if((U|0)==(c[G>>2]|0)){Ea=U<<1;if((U|0)<1073741824&(Ea|0)<32){Oa=32}else{Oa=(U|0)>1073741823?2147483646:Ea}if((U|0)>=(Oa|0)){ta=-12;break w}Ea=YDb(c[x>>2]|0,Oa,20)|0;c[da>>2]=Ea;if((Ea|0)==0){ta=-12;break w}c[G>>2]=Oa;Pa=c[M>>2]|0;Qa=Ea}else{Pa=U;Qa=c[x>>2]|0}U=Pa*20|0;Ea=Qa+U|0;TGb(Ea|0,0,20)|0;c[M>>2]=(c[M>>2]|0)+1;if((Ea|0)==0){ta=-12;break w}c[Ea>>2]=Ja;c[Qa+(U+4)>>2]=Fa;Ea=c[y>>2]|0;Ba=c[w>>2]|0;do{if(Ea>>>0<Ba>>>0){V=(a[Ea]|0)==123;Aa=Ea+(V&1)|0;c[y>>2]=Aa;if(!V){break}A:do{if(Aa>>>0<Ba>>>0){V=Aa;while(1){T=a[V]|0;if(!((T<<24>>24|0)==32|(T<<24>>24|0)==9|(T<<24>>24|0)==13)){Ra=V;break A}T=V+1|0;c[y>>2]=T;if(T>>>0<Ba>>>0){V=T}else{Ra=T;break}}}else{Ra=Aa}}while(0);B:do{if(Ra>>>0<Ba>>>0){if((a[Ra]|0)==35){Sa=Ra}else{Ta=Ra;break}while(1){Aa=Sa+1|0;c[y>>2]=Aa;if(!(Aa>>>0<Ba>>>0)){Ta=Aa;break B}if((a[Aa]|0)==10){Ta=Aa;break}else{Sa=Aa}}}else{Ta=Ra}}while(0);C:do{if((Ta|0)!=(Ba|0)){if((a[Ta]|0)!=10){ta=-1094995529;break w}Aa=Ta+1|0;c[y>>2]=Aa;c[I>>2]=(c[I>>2]|0)+1;if(Aa>>>0<Ba>>>0){Ua=Aa}else{break}do{Aa=a[Ua]|0;if(!((Aa<<24>>24|0)==32|(Aa<<24>>24|0)==9|(Aa<<24>>24|0)==13)){break C}Ua=Ua+1|0;c[y>>2]=Ua;}while(Ua>>>0<Ba>>>0)}}while(0);Aa=c[F>>2]|0;do{V=YP(u,1)|0;if((V|0)<0){ta=V;break w}}while((V|0)!=0);Va=c[y>>2]|0;V=c[w>>2]|0;if(!(Va>>>0<V>>>0)){R=174;break y}ba=(a[Va]|0)==125;T=Va+(ba&1)|0;c[y>>2]=T;if(!ba){ta=-1094995529;break w}D:do{if(T>>>0<V>>>0){ba=T;while(1){ya=a[ba]|0;if(!((ya<<24>>24|0)==32|(ya<<24>>24|0)==9|(ya<<24>>24|0)==13)){Wa=ba;break D}ya=ba+1|0;c[y>>2]=ya;if(ya>>>0<V>>>0){ba=ya}else{Wa=ya;break}}}else{Wa=T}}while(0);E:do{if(Wa>>>0<V>>>0){if((a[Wa]|0)==35){Xa=Wa}else{Ya=Wa;break}while(1){T=Xa+1|0;c[y>>2]=T;if(!(T>>>0<V>>>0)){Ya=T;break E}if((a[T]|0)==10){Ya=T;break}else{Xa=T}}}else{Ya=Wa}}while(0);F:do{if((Ya|0)!=(V|0)){if((a[Ya]|0)!=10){ta=-1094995529;break w}T=Ya+1|0;c[y>>2]=T;c[I>>2]=(c[I>>2]|0)+1;if(T>>>0<V>>>0){Za=T}else{break}do{T=a[Za]|0;if(!((T<<24>>24|0)==32|(T<<24>>24|0)==9|(T<<24>>24|0)==13)){break F}Za=Za+1|0;c[y>>2]=Za;}while(Za>>>0<V>>>0)}}while(0);a[Qa+(U+16)|0]=66;c[Qa+(U+8)>>2]=Aa;V=c[F>>2]|0;c[Qa+(U+12)>>2]=V-Aa;_a=(V|0)==(Aa|0)?-1094995529:1;R=323;break z}else{c[y>>2]=Ea}}while(0);Ea=c[Da>>2]|0;Ba=Ea;G:while(1){if((Ba|0)==(c[H>>2]|0)){Fa=Ba<<1;if((Ba|0)<1073741824&(Fa|0)<32){$a=32}else{$a=(Ba|0)>1073741823?2147483646:Fa}if((Ba|0)>=($a|0)){ta=-12;break w}Fa=YDb(c[Ca>>2]|0,$a,24)|0;c[Ca>>2]=Fa;if((Fa|0)==0){ta=-12;break w}c[H>>2]=$a;ab=c[Da>>2]|0;bb=Fa}else{ab=Ba;bb=c[Ca>>2]|0}Fa=ab*24|0;V=bb+Fa|0;TGb(V|0,0,24)|0;T=(c[Da>>2]|0)+1|0;c[Da>>2]=T;if((V|0)==0){ta=-12;break w}ba=c[y>>2]|0;ya=c[w>>2]|0;if(ba>>>0<ya>>>0){za=(a[ba]|0)==45;xa=ba+(za&1)|0;c[y>>2]=xa;if(za){cb=xa}else{db=xa;R=201}}else{c[y>>2]=ba;db=ba;R=201}H:do{if((R|0)==201){R=0;ba=ya-db|0;do{if((ba|0)<4){if((ba|0)>=3){R=231}}else{if((PGb(db,2140456,4)|0)==0){eb=db+4|0;c[y>>2]=eb;if(!(eb>>>0<ya>>>0)){R=204;break y}xa=(a[eb]|0)==47;za=db+(xa&1|4)|0;c[y>>2]=za;if(!xa){fb=-1094995529;R=290;break y}if((za|0)==(ya|0)){fb=-1094995529;R=290;break y}xa=a[za]|0;if((xa<<24>>24|0)==32|(xa<<24>>24|0)==9|(xa<<24>>24|0)==13|(xa<<24>>24|0)==10){fb=-1094995529;R=290;break y}gb=+OGb(za,p);za=c[p>>2]|0;if(!(za>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;R=290;break y}c[y>>2]=za;hb=c[v>>2]|0;pa=gb*65536.0*.01;if(pa<-2147483648.0|pa>=2147483647.0){R=210;break y}c[bb+(Fa+12)>>2]=2;c[bb+(Fa+8)>>2]=~~pa;cb=za;break H}if((PGb(db,2146528,4)|0)!=0){R=231;break}za=db+4|0;c[y>>2]=za;if((za|0)==(ya|0)){fb=-1094995529;R=290;break y}xa=a[za]|0;if((xa<<24>>24|0)==32|(xa<<24>>24|0)==9|(xa<<24>>24|0)==13|(xa<<24>>24|0)==10){fb=-1094995529;R=290;break y}ib=+OGb(za,o);jb=c[o>>2]|0;if(!(jb>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;R=290;break y}c[y>>2]=jb;za=c[w>>2]|0;if(!(jb>>>0<za>>>0)){R=218;break y}xa=(a[jb]|0)==47;Y=jb+(xa&1)|0;c[y>>2]=Y;if(!xa){fb=-1094995529;R=290;break y}if((Y|0)==(za|0)){fb=-1094995529;R=290;break y}za=a[Y]|0;if((za<<24>>24|0)==32|(za<<24>>24|0)==9|(za<<24>>24|0)==13|(za<<24>>24|0)==10){fb=-1094995529;R=290;break y}lb=+OGb(Y,n);Y=c[n>>2]|0;if(!(Y>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;R=290;break y}c[y>>2]=Y;mb=c[v>>2]|0;pa=lb*65536.0*.01;if(pa<-2147483648.0|pa>=2147483647.0){R=224;break y}na=ib*65536.0;if(na<-2147483648.0|na>=2147483647.0){R=227;break y}c[bb+(Fa+12)>>2]=3;c[V>>2]=~~na;c[bb+(Fa+8)>>2]=~~pa;cb=Y;break H}}while(0);do{if((R|0)==231){R=0;if((PGb(db,2153760,3)|0)==0){nb=db+3|0;c[y>>2]=nb;if(!(nb>>>0<ya>>>0)){R=233;break y}Y=(a[nb]|0)==47;za=db+(Y?4:3)|0;c[y>>2]=za;if(!Y){fb=-1094995529;R=290;break y}if((za|0)==(ya|0)){fb=-1094995529;R=290;break y}Y=a[za]|0;if((Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==13|(Y<<24>>24|0)==10){fb=-1094995529;R=290;break y}ob=+OGb(za,m);za=c[m>>2]|0;if(!(za>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;R=290;break y}c[y>>2]=za;pb=c[v>>2]|0;pa=ob*65536.0*.01;if(pa<-2147483648.0|pa>=2147483647.0){R=239;break y}c[bb+(Fa+12)>>2]=4;c[bb+(Fa+8)>>2]=~~pa;cb=za;break H}if((ba|0)<5){break}if((PGb(db,2160560,5)|0)!=0){break}za=db+5|0;c[y>>2]=za;if((za|0)==(ya|0)){fb=-1094995529;R=290;break y}Y=a[za]|0;if((Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==13|(Y<<24>>24|0)==10){fb=-1094995529;R=290;break y}qb=+OGb(za,l);za=c[l>>2]|0;if(!(za>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;R=290;break y}c[y>>2]=za;if((za|0)==(c[w>>2]|0)){fb=-1094995529;R=290;break y}Y=a[za]|0;if((Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==13|(Y<<24>>24|0)==10){fb=-1094995529;R=290;break y}rb=+OGb(za,k);sb=c[k>>2]|0;if(!(sb>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;R=290;break y}c[y>>2]=sb;za=c[w>>2]|0;if(!(sb>>>0<za>>>0)){R=251;break y}Y=(a[sb]|0)==47;xa=sb+(Y&1)|0;c[y>>2]=xa;if(!Y){fb=-1094995529;R=290;break y}if((xa|0)==(za|0)){fb=-1094995529;R=290;break y}za=a[xa]|0;if((za<<24>>24|0)==32|(za<<24>>24|0)==9|(za<<24>>24|0)==13|(za<<24>>24|0)==10){fb=-1094995529;R=290;break y}tb=+OGb(xa,j);xa=c[j>>2]|0;if(!(xa>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;R=290;break y}c[y>>2]=xa;ub=c[v>>2]|0;pa=tb*65536.0*.01;if(pa<-2147483648.0|pa>=2147483647.0){R=257;break y}na=qb*65536.0;if(na<-2147483648.0|na>=2147483647.0){R=260;break y}vb=rb*65536.0;if(vb<-2147483648.0|vb>=2147483647.0){R=263;break y}c[bb+(Fa+12)>>2]=5;c[V>>2]=~~na;c[bb+(Fa|4)>>2]=~~vb;c[bb+(Fa+8)>>2]=~~pa;cb=xa;break H}}while(0);if((db|0)==(ya|0)){wb=ya;xb=T;yb=ya;R=291;break G}ba=a[db]|0;if((ba<<24>>24|0)==32|(ba<<24>>24|0)==9|(ba<<24>>24|0)==13|(ba<<24>>24|0)==10){wb=db;xb=T;yb=ya;R=291;break G}zb=+OGb(db,s);ba=c[s>>2]|0;Ab=c[y>>2]|0;if(!(ba>>>0>Ab>>>0)){R=269;break G}c[y>>2]=ba;do{if((ba|0)==(c[w>>2]|0)){Bb=0.0;Cb=ba}else{xa=a[ba]|0;if((xa<<24>>24|0)==32|(xa<<24>>24|0)==9|(xa<<24>>24|0)==13|(xa<<24>>24|0)==10){Bb=0.0;Cb=ba;break}pa=+OGb(ba,r);xa=c[r>>2]|0;za=c[y>>2]|0;if(!(xa>>>0>za>>>0)){Bb=0.0;Cb=za;break}c[y>>2]=xa;Bb=pa;Cb=xa}}while(0);ba=c[w>>2]|0;if(!(Cb>>>0<ba>>>0)){R=275;break y}xa=(a[Cb]|0)==47;za=Cb+(xa&1)|0;c[y>>2]=za;if(!xa){R=292;break y}if((za|0)==(ba|0)){Db=-1094995529;R=293;break y}ba=a[za]|0;if((ba<<24>>24|0)==32|(ba<<24>>24|0)==9|(ba<<24>>24|0)==13|(ba<<24>>24|0)==10){Db=-1094995529;R=293;break y}Eb=+OGb(za,q);za=c[q>>2]|0;if(!(za>>>0>(c[y>>2]|0)>>>0)){Db=-1094995529;R=293;break y}c[y>>2]=za;Fb=c[v>>2]|0;pa=Eb*65536.0*.01;if(pa<-2147483648.0|pa>=2147483647.0){R=281;break y}vb=zb*65536.0;if(vb<-2147483648.0|vb>=2147483647.0){R=284;break y}na=Bb*65536.0;if(na<-2147483648.0|na>=2147483647.0){R=287;break y}c[bb+(Fa+12)>>2]=1;c[V>>2]=~~vb;c[bb+(Fa|4)>>2]=~~na;c[bb+(Fa+8)>>2]=~~pa;cb=za}}while(0);Fa=c[w>>2]|0;if(cb>>>0<Fa>>>0){Gb=cb}else{Hb=cb;Jb=Fa;break}while(1){V=a[Gb]|0;if(!((V<<24>>24|0)==32|(V<<24>>24|0)==9|(V<<24>>24|0)==13)){Kb=Gb;break}V=Gb+1|0;c[y>>2]=V;if(V>>>0<Fa>>>0){Gb=V}else{Kb=V;break}}if(!(Kb>>>0>cb>>>0)){Hb=Kb;Jb=Fa;break}Ba=c[Da>>2]|0}if((R|0)==269){R=0;wb=Ab;xb=c[Da>>2]|0;yb=c[w>>2]|0;R=291}if((R|0)==291){R=0;c[Da>>2]=xb-1;Hb=wb;Jb=yb}I:do{if(Hb>>>0<Jb>>>0){Ba=Hb;while(1){V=a[Ba]|0;if(!((V<<24>>24|0)==32|(V<<24>>24|0)==9|(V<<24>>24|0)==13)){Mb=Ba;break I}V=Ba+1|0;c[y>>2]=V;if(V>>>0<Jb>>>0){Ba=V}else{Mb=V;break}}}else{Mb=Hb}}while(0);if((Ea|0)==(c[Da>>2]|0)){ta=-1094995529;break w}J:do{if(Mb>>>0<Jb>>>0){if((a[Mb]|0)==35){Nb=Mb}else{Ob=Mb;break}while(1){Ba=Nb+1|0;c[y>>2]=Ba;if(!(Ba>>>0<Jb>>>0)){Ob=Ba;break J}if((a[Ba]|0)==10){Ob=Ba;break}else{Nb=Ba}}}else{Ob=Mb}}while(0);K:do{if((Ob|0)!=(Jb|0)){if((a[Ob]|0)!=10){ta=-1094995529;break w}Ba=Ob+1|0;c[y>>2]=Ba;c[I>>2]=(c[I>>2]|0)+1;if(Ba>>>0<Jb>>>0){Pb=Ba}else{break}do{Ba=a[Pb]|0;if(!((Ba<<24>>24|0)==32|(Ba<<24>>24|0)==9|(Ba<<24>>24|0)==13)){break K}Pb=Pb+1|0;c[y>>2]=Pb;}while(Pb>>>0<Jb>>>0)}}while(0);a[Qa+(U+16)|0]=83;c[Qa+(U+8)>>2]=Ea;c[Qa+(U+12)>>2]=(c[Da>>2]|0)-Ea}}while(0);L:do{if((R|0)==313){R=0;c[y>>2]=Ja;Ba=YP(u,0)|0;if((Ba|0)!=0){_a=Ba;R=323;break}Ba=c[y>>2]|0;Fa=c[w>>2]|0;M:do{if(Ba>>>0<Fa>>>0){if((a[Ba]|0)==35){Qb=Ba}else{Rb=Ba;break}while(1){V=Qb+1|0;c[y>>2]=V;if(!(V>>>0<Fa>>>0)){Rb=V;break M}if((a[V]|0)==10){Rb=V;break}else{Qb=V}}}else{Rb=Ba}}while(0);if((Rb|0)==(Fa|0)){break}if((a[Rb]|0)!=10){ta=-1094995529;break w}Ba=Rb+1|0;c[y>>2]=Ba;c[I>>2]=(c[I>>2]|0)+1;if(Ba>>>0<Fa>>>0){Sb=Ba}else{break}do{Ba=a[Sb]|0;if(!((Ba<<24>>24|0)==32|(Ba<<24>>24|0)==9|(Ba<<24>>24|0)==13)){break L}Sb=Sb+1|0;c[y>>2]=Sb;}while(Sb>>>0<Fa>>>0)}}while(0);if((R|0)==323){R=0;if((_a|0)<0){ta=_a;break w}}Ja=c[y>>2]|0;Ga=c[w>>2]|0;if(!(Ja>>>0<Ga>>>0)){break x}}do{if((R|0)==146){Lb(J|0,128,2134080,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;ta=-1163346256;break w}else if((R|0)==174){c[y>>2]=Va;ta=-1094995529;break w}else if((R|0)==204){c[y>>2]=eb;fb=-1094995529;R=290}else if((R|0)==210){if((hb|0)==0){fb=-34;R=290;break}yDb(hb,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=gb,Ka)|0);i=Ka;fb=-34;R=290}else if((R|0)==218){c[y>>2]=jb;fb=-1094995529;R=290}else if((R|0)==224){if((mb|0)==0){fb=-34;R=290;break}yDb(mb,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=lb,Ka)|0);i=Ka;fb=-34;R=290}else if((R|0)==227){if((mb|0)==0){fb=-33;R=290;break}yDb(mb,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=ib,Ka)|0);i=Ka;fb=-33;R=290}else if((R|0)==233){c[y>>2]=nb;fb=-1094995529;R=290}else if((R|0)==239){if((pb|0)==0){fb=-34;R=290;break}yDb(pb,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=ob,Ka)|0);i=Ka;fb=-34;R=290}else if((R|0)==251){c[y>>2]=sb;fb=-1094995529;R=290}else if((R|0)==257){if((ub|0)==0){fb=-34;R=290;break}yDb(ub,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=tb,Ka)|0);i=Ka;fb=-34;R=290}else if((R|0)==260){if((ub|0)==0){fb=-33;R=290;break}yDb(ub,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=qb,Ka)|0);i=Ka;fb=-33;R=290}else if((R|0)==263){if((ub|0)==0){fb=-33;R=290;break}yDb(ub,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=rb,Ka)|0);i=Ka;fb=-33;R=290}else if((R|0)==275){c[y>>2]=Cb;R=292}else if((R|0)==281){if((Fb|0)==0){Db=-34;R=293;break}yDb(Fb,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=Eb,Ka)|0);i=Ka;Db=-34;R=293}else if((R|0)==284){if((Fb|0)==0){fb=-33;R=290;break}yDb(Fb,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=zb,Ka)|0);i=Ka;fb=-33;R=290}else if((R|0)==287){if((Fb|0)==0){fb=-33;R=290;break}yDb(Fb,16,2167768,(Ka=i,i=i+8|0,h[Ka>>3]=Bb,Ka)|0);i=Ka;fb=-33;R=290}}while(0);if((R|0)==290){c[Da>>2]=(c[Da>>2]|0)-1;ta=fb;break w}else if((R|0)==292){c[Da>>2]=(c[Da>>2]|0)-1;ta=-1094995529;break w}else if((R|0)==293){c[Da>>2]=(c[Da>>2]|0)-1;ta=Db;break w}}}while(0);UGb(f|0,A|0,88)|0;Tb=1;i=g;return Tb|0}}while(0);$Db(A);$Db(u+20|0);$Db(u+24|0);$Db(u+28|0);$Db(u+32|0);$Db(u+88|0);if((a[J]|0)==0&(ta|0)==-1094995529){Lb(J|0,128,2277528,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka}if((b|0)==0){Tb=ta;i=g;return Tb|0}if((a[J]|0)==0){Tb=ta;i=g;return Tb|0}u=c[y>>2]|0;y=c[w>>2]|0;w=u;A=Ib(u|0,10,y-w|0)|0;f=((A|0)!=0?A:y)-w|0;if((f|0)>0){w=f-1|0;Ub=(a[u+w|0]|0)==13?w:f}else{Ub=f}f=(Ub|0)==0;w=f?9203504:2261912;yDb(b,16,2221256,(Ka=i,i=i+48|0,c[Ka>>2]=c[I>>2],c[Ka+8>>2]=J,c[Ka+16>>2]=w,c[Ka+24>>2]=f?15:Ub,c[Ka+32>>2]=f?2247312:u,c[Ka+40>>2]=w,Ka)|0);i=Ka;Tb=ta;i=g;return Tb|0}function VP(a,b,d,e,f,g,h,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;m=i;i=i+56|0;n=m|0;if(!((h|0)>(f|0)|(h|0)==(f|0)&g>>>0>e>>>0)){o=0;i=m;return o|0}p=j+8|0;q=c[p>>2]|0;do{if((q|0)==0){if((c[k+8>>2]|0)==0){o=0}else{break}i=m;return o|0}}while(0);r=c[j+12>>2]|0;switch(r|0){case 3:{if((l|0)!=2){o=0;i=m;return o|0}l=c[j>>2]|0;s=c[k+8>>2]|0;t=c[b+76>>2]|0;c[n>>2]=2;c[n+4>>2]=s;c[n+8>>2]=4;b=(s|0)/4|0;c[n+12>>2]=s-b;c[n+16>>2]=8;c[n+20>>2]=(s|0)/2|0;c[n+24>>2]=16;c[n+28>>2]=b;c[n+32>>2]=25;c[n+36>>2]=(s|0)/10|0;c[n+40>>2]=50;c[n+44>>2]=(s|0)/80|0;c[n+48>>2]=75;c[n+52>>2]=0;b=(t|0)/20|0;t=b;u=(b|0)<0|0?-1:0;b=1;v=s;w=f;x=e;y=0;z=2;A=s;while(1){s=gHb(z,y,t,u)|0;B=YGb(s,F,e,f)|0;s=F;C=(s|0)<(h|0)|(s|0)==(h|0)&B>>>0<g>>>0;D=C?B:g;B=C?s:h;s=WP(d,1162758483,3,-1,x,w,l,v,D,B,l,A)|0;if((s|0)<0){o=s;E=20;break}if(!(b>>>0<7>>>0)){o=0;E=20;break}s=c[n+(b<<3)>>2]|0;C=c[n+(b<<3)+4>>2]|0;b=b+1|0;v=A;w=B;x=D;y=(s|0)<0|0?-1:0;z=s;A=C}if((E|0)==20){i=m;return o|0}break};case 2:{G=q;break};case 5:{yDb(a,24,2019416,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;G=c[p>>2]|0;break};case 1:{E=j+4|0;A=c[E>>2]|0;z=c[k+4>>2]|0;y=c[j+16>>2]|0;x=j|0;w=c[x>>2]|0;if((A|z|0)==0){v=WP(d,1162758483,3,y,e,f,w,q,g,h,c[k>>2]|0,c[k+8>>2]|0)|0;if((v|0)<0){o=v;i=m;return o|0}c[k+20>>2]=v;c[k+16>>2]=v;o=0;i=m;return o|0}v=k|0;b=k+8|0;n=WP(d,1162758483,1,y,e,f,((A|0)/2|0)+w|0,q,g,h,((z|0)/2|0)+(c[v>>2]|0)|0,c[b>>2]|0)|0;if((n|0)<0){o=n;i=m;return o|0}c[k+16>>2]=n;n=WP(d,1162758483,2,c[j+20>>2]|0,e,f,(c[x>>2]|0)-((c[E>>2]|0)/2|0)|0,c[p>>2]|0,g,h,(c[v>>2]|0)-((c[k+4>>2]|0)/2|0)|0,c[b>>2]|0)|0;if((n|0)<0){o=n;i=m;return o|0}c[k+20>>2]=n;o=0;i=m;return o|0};case 0:{o=0;i=m;return o|0};default:{yDb(a,16,1976752,(H=i,i=i+8|0,c[H>>2]=r,H)|0);i=H;o=-1163346256;i=m;return o|0}}H=c[k+8>>2]|0;r=WP(d,1397313358,3,c[j+16>>2]|0,e,f,0,G-((G|0)/4|0)|0,g,h,0,H-((H|0)/4|0)|0)|0;if((r|0)<0){o=r;i=m;return o|0}c[k+20>>2]=r;c[k+16>>2]=r;o=0;i=m;return o|0}function WP(a,b,d,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=(e|0)>-1;o=a|0;do{if(n){p=c[o>>2]|0;if((c[p+(e*48|0)+16>>2]|0)!=(b|0)){break}if((c[p+(e*48|0)+20>>2]|0)!=(d|0)){break}q=c[p+(e*48|0)+28>>2]|0;if(!((c[p+(e*48|0)+24>>2]|0)==(q|0)&(q|0)==(h|0)&(h|0)==(l|0))){break}q=c[p+(e*48|0)+36>>2]|0;if(!((c[p+(e*48|0)+32>>2]|0)==(q|0)&(q|0)==(i|0)&(i|0)==(m|0))){break}q=p+(e*48|0)+8|0;if(!((c[q>>2]|0)==(f|0)&(c[q+4>>2]|0)==(g|0))){break}c[q>>2]=j;c[q+4>>2]=k;r=e;return r|0}}while(0);q=a;p=a+4|0;s=a+8|0;a=c[p>>2]|0;do{if((a|0)==(c[s>>2]|0)){t=a<<1;if((a|0)<1073741824&(t|0)<32){u=32}else{u=(a|0)>1073741823?2147483646:t}if((a|0)>=(u|0)){r=-12;return r|0}t=YDb(c[q>>2]|0,u,48)|0;c[o>>2]=t;if((t|0)==0){r=-12;return r|0}else{c[s>>2]=u;v=c[p>>2]|0;w=t;break}}else{v=a;w=c[q>>2]|0}}while(0);q=v*48|0;v=w+q|0;TGb(v|0,0,48)|0;c[p>>2]=(c[p>>2]|0)+1;if((v|0)==0){r=-12;return r|0}p=v;c[p>>2]=f;c[p+4>>2]=g;g=w+(q|8)|0;c[g>>2]=j;c[g+4>>2]=k;c[w+(q+16)>>2]=b;c[w+(q+20)>>2]=d;c[w+(q+24)>>2]=h;c[w+(q+28)>>2]=l;c[w+(q+32)>>2]=i;c[w+(q+36)>>2]=m;c[w+(q+40)>>2]=n?e|-2147483648:0;r=(v-(c[o>>2]|0)|0)/48|0;return r|0}function XP(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;k=h+24|0;l=c[k>>2]|0;c[k>>2]=l+1;if((l|0)!=0){l=c[h+16>>2]|0;yDb(b,16,1922368,(m=i,i=i+16|0,c[m>>2]=c[h+20>>2],c[m+8>>2]=l,m)|0);i=m;n=-22;i=j;return n|0}l=h|0;o=YGb(c[l>>2]|0,c[l+4>>2]|0,f,g)|0;g=F;f=c[d+20>>2]|0;a:do{if((f|0)>0){p=c[d>>2]|0;q=c[h+20>>2]|0;r=h+16|0;s=0;while(1){if((c[p+(s*20|0)+4>>2]|0)==(q|0)){if((PGb(c[p+(s*20|0)>>2]|0,c[r>>2]|0,q)|0)==0){t=s;break a}}u=s+1|0;if((u|0)<(f|0)){s=u}else{t=u;break}}}else{t=0}}while(0);if((t|0)>=(f|0)){f=c[h+16>>2]|0;yDb(b,16,1901040,(m=i,i=i+16|0,c[m>>2]=c[h+20>>2],c[m+8>>2]=f,m)|0);i=m;n=-22;i=j;return n|0}m=c[d>>2]|0;b:do{if((a[m+(t*20|0)+16|0]|0)==66){f=c[d+12>>2]|0;s=c[m+(t*20|0)+8>>2]|0;q=m+(t*20|0)+12|0;r=0;while(1){if((r|0)>=(c[q>>2]|0)){break b}p=XP(b,d,e,o,g,f+(r+s<<5)|0)|0;if((p|0)<0){n=p;break}else{r=r+1|0}}i=j;return n|0}else{r=d+16|0;s=d+28|0;f=c[s>>2]|0;if((f|0)==(c[e>>2]|0)){q=f<<1;if((f|0)<1073741824&(q|0)<32){v=32}else{v=(f|0)>1073741823?2147483646:q}q=YDb(c[r>>2]|0,v,48)|0;c[r>>2]=q;c[e>>2]=v;w=c[s>>2]|0;x=q}else{w=f;x=c[r>>2]|0}r=w*48|0;f=x+r|0;TGb(f|0,0,48)|0;c[s>>2]=(c[s>>2]|0)+1;s=c[l+4>>2]|0;q=f;c[q>>2]=c[l>>2];c[q+4>>2]=s;c[x+(r+32)>>2]=c[m+(t*20|0)+8>>2];c[x+(r+36)>>2]=c[m+(t*20|0)+12>>2];s=x+(r+40)|0;r=h+28|0;a[s]=a[r]|0;a[s+1|0]=a[r+1|0]|0;a[s+2|0]=a[r+2|0]|0}}while(0);c[k>>2]=(c[k>>2]|0)-1;n=0;i=j;return n|0}function YP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;c[f>>2]=0;c[f+4>>2]=0;j=b+8|0;k=c[j>>2]|0;l=b+12|0;m=c[l>>2]|0;do{if((k-m|0)<3){n=4}else{if((PGb(m,2195712,3)|0)!=0){n=4;break}o=m+3|0;c[l>>2]=o;p=1;q=78;r=o;s=k}}while(0);if((n|0)==4){k=ZP(m,f)|0;m=(c[l>>2]|0)+k|0;c[l>>2]=m;o=(k|0)>0;p=o&1;q=o?84:0;r=m;s=c[j>>2]|0}a:do{if(r>>>0<s>>>0){m=0;o=0;k=p;t=r;u=s;while(1){v=(a[t]|0)==43;w=t+(v&1)|0;c[l>>2]=w;if(!v){x=m;y=o;z=k;A=w;B=u;break a}v=ZP(w,g)|0;w=(c[l>>2]|0)+v|0;c[l>>2]=w;if((v|0)<=0){C=-1094995529;break}v=YGb(c[g>>2]|0,c[g+4>>2]|0,o,m)|0;D=F;E=c[j>>2]|0;if(w>>>0<E>>>0){m=D;o=v;k=1;t=w;u=E}else{G=D;H=v;I=1;J=w;K=E;n=6;break a}}i=e;return C|0}else{G=0;H=0;I=p;J=r;K=s;n=6}}while(0);if((n|0)==6){c[l>>2]=J;x=G;y=H;z=I;A=J;B=K}if((z|0)==0){C=0;i=e;return C|0}if(A>>>0<B>>>0){L=A}else{C=-1094995529;i=e;return C|0}while(1){z=a[L]|0;if(!((z<<24>>24|0)==32|(z<<24>>24|0)==9|(z<<24>>24|0)==13)){M=L;break}z=L+1|0;c[l>>2]=z;if(z>>>0<B>>>0){L=z}else{M=z;break}}if(!(M>>>0>A>>>0)){C=-1094995529;i=e;return C|0}A=c[f>>2]|0;L=c[f+4>>2]|0;f=(d|0)!=0;do{if(q<<24>>24==0){d=a[b+112|0]|0;if(!(d<<24>>24==0&(f^1))){N=d;break}Lb(b+144|0,128,2211984,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0)|0;i=d;C=-1094995529;i=e;return C|0}else{if(f){C=-1094995529;i=e;return C|0}else{a[b+112|0]=q;d=b+104|0;c[d>>2]=A;c[d+4>>2]=L;N=q;break}}}while(0);q=b+104|0;L=YGb(c[q>>2]|0,c[q+4>>2]|0,y,x)|0;x=F;if(M>>>0<B>>>0){y=(a[M]|0)==60;q=M+(y&1)|0;c[l>>2]=q;if(y){O=0;P=q;n=29}else{Q=q;n=23}}else{c[l>>2]=M;Q=M;n=23}do{if((n|0)==23){if(Q>>>0<B>>>0){M=(a[Q]|0)==45;q=Q+(M&1)|0;c[l>>2]=q;if(M){O=1;P=q;n=29;break}else{R=q}}else{c[l>>2]=Q;R=Q}if(R>>>0<B>>>0){q=(a[R]|0)==61;M=R+(q&1)|0;c[l>>2]=M;if(q){O=3;P=M;n=29;break}else{S=1;T=1;U=M;break}}else{c[l>>2]=R;S=1;T=1;U=R;break}}}while(0);do{if((n|0)==29){if(P>>>0<B>>>0){R=(a[P]|0)==62;Q=P+(R&1)|0;c[l>>2]=Q;if(R){S=O;T=0;U=Q;break}else{V=Q}}else{c[l>>2]=P;V=P}if(V>>>0<B>>>0){Q=(a[V]|0)==45;R=V+(Q&1)|0;c[l>>2]=R;if(Q){S=O;T=1;U=R;break}else{W=R}}else{c[l>>2]=V;W=V}if(W>>>0<B>>>0){R=(a[W]|0)==61;Q=W+(R&1)|0;c[l>>2]=Q;if(R){S=O;T=3;U=Q;break}else{C=-1094995529}i=e;return C|0}else{c[l>>2]=W;C=-1094995529;i=e;return C|0}}}while(0);b:do{if(U>>>0<B>>>0){W=U;while(1){O=a[W]|0;if(!((O<<24>>24|0)==32|(O<<24>>24|0)==9|(O<<24>>24|0)==13)){X=W;break b}O=W+1|0;c[l>>2]=O;if(O>>>0<B>>>0){W=O}else{X=O;break}}}else{X=U}}while(0);if(X>>>0<B>>>0){Y=X}else{C=-1094995529;i=e;return C|0}while(1){U=a[Y]|0;if(!((U-97&255)>>>0<26>>>0|(U-65&255)>>>0<26>>>0|(U-48&255)>>>0<10>>>0)){if(!((U<<24>>24|0)==95|(U<<24>>24|0)==45)){Z=Y;break}}U=Y+1|0;if(U>>>0<B>>>0){Y=U}else{Z=U;break}}if((Z|0)==(X|0)){C=-1094995529;i=e;return C|0}c[l>>2]=Z;c:do{if(Z>>>0<B>>>0){Y=Z;while(1){U=a[Y]|0;if(!((U<<24>>24|0)==32|(U<<24>>24|0)==9|(U<<24>>24|0)==13)){_=Y;break c}U=Y+1|0;c[l>>2]=U;if(U>>>0<B>>>0){Y=U}else{_=U;break}}}else{_=Z}}while(0);d:do{if((B-_|0)<2){$=0;aa=_}else{if((PGb(_,2202904,2)|0)!=0){$=0;aa=_;break}Y=_+2|0;c[l>>2]=Y;if(Y>>>0<B>>>0){ba=Y}else{$=3;aa=Y;break}while(1){Y=a[ba]|0;if(!((Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==13)){$=3;aa=ba;break d}Y=ba+1|0;c[l>>2]=Y;if(Y>>>0<B>>>0){ba=Y}else{$=3;aa=Y;break}}}}while(0);e:do{if(aa>>>0<B>>>0){if((a[aa]|0)==35){ca=aa}else{da=aa;break}while(1){ba=ca+1|0;c[l>>2]=ba;if(!(ba>>>0<B>>>0)){da=ba;break e}if((a[ba]|0)==10){da=ba;break}else{ca=ba}}}else{da=aa}}while(0);f:do{if((da|0)!=(B|0)){if((a[da]|0)!=10){C=-1094995529;i=e;return C|0}aa=da+1|0;c[l>>2]=aa;ca=b+140|0;c[ca>>2]=(c[ca>>2]|0)+1;if(aa>>>0<B>>>0){ea=aa}else{break}do{aa=a[ea]|0;if(!((aa<<24>>24|0)==32|(aa<<24>>24|0)==9|(aa<<24>>24|0)==13)){break f}ea=ea+1|0;c[l>>2]=ea;}while(ea>>>0<B>>>0)}}while(0);if(f){f=b+28|0;B=b+120|0;ea=b+136|0;l=c[B>>2]|0;do{if((l|0)==(c[ea>>2]|0)){da=l<<1;if((l|0)<1073741824&(da|0)<32){fa=32}else{fa=(l|0)>1073741823?2147483646:da}if((l|0)>=(fa|0)){C=-12;i=e;return C|0}da=YDb(c[f>>2]|0,fa,32)|0;c[f>>2]=da;if((da|0)==0){C=-12;i=e;return C|0}else{c[ea>>2]=fa;ga=c[B>>2]|0;ha=da;break}}else{ga=l;ha=c[f>>2]|0}}while(0);f=ha+(ga<<5)|0;TGb(f|0,0,32)|0;c[B>>2]=(c[B>>2]|0)+1;ia=f}else{f=b+24|0;B=b+40|0;ga=b+132|0;b=c[B>>2]|0;do{if((b|0)==(c[ga>>2]|0)){ha=b<<1;if((b|0)<1073741824&(ha|0)<32){ja=32}else{ja=(b|0)>1073741823?2147483646:ha}if((b|0)>=(ja|0)){C=-12;i=e;return C|0}ha=YDb(c[f>>2]|0,ja,32)|0;c[f>>2]=ha;if((ha|0)==0){C=-12;i=e;return C|0}else{c[ga>>2]=ja;ka=c[B>>2]|0;la=ha;break}}else{ka=b;la=c[f>>2]|0}}while(0);f=la+(ka<<5)|0;TGb(f|0,0,32)|0;c[B>>2]=(c[B>>2]|0)+1;ia=f}if((ia|0)==0){C=-12;i=e;return C|0}f=ia;c[f>>2]=L;c[f+4>>2]=x;a[ia+8|0]=N;N=ia+9|0;x=h|0;a[N]=a[x]|0;a[N+1|0]=a[x+1|0]|0;a[N+2|0]=a[x+2|0]|0;a[N+3|0]=a[x+3|0]|0;a[N+4|0]=a[x+4|0]|0;a[N+5|0]=a[x+5|0]|0;a[N+6|0]=a[x+6|0]|0;c[ia+16>>2]=X;c[ia+20>>2]=Z-X;a[ia+28|0]=S;a[ia+29|0]=T;a[ia+30|0]=$;C=1;i=e;return C|0}function ZP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0.0,n=0,o=0.0,p=0;e=i;i=i+8|0;f=e|0;if(((a[b]|0)-48&255)>>>0>9>>>0){g=0;i=e;return g|0}h=kb(b|0,f|0,10)|0;j=c[f>>2]|0;if((j|0)==(b|0)){g=0;i=e;return g|0}if((a[j]|0)!=58){g=0;i=e;return g|0}k=j+1|0;if(((a[k]|0)-48&255)>>>0>9>>>0){g=0;i=e;return g|0}j=kb(k|0,f|0,10)|0;l=c[f>>2]|0;if((l|0)==(k|0)){g=0;i=e;return g|0}if((a[l]|0)==58){k=l+1|0;m=+OGb(k,f);n=c[f>>2]|0;o=m;p=n>>>0>k>>>0?n:l}else{o=0.0;p=l}m=(+((j*60|0)+(h*3600|0)|0)+o)*1.0e6;h=(E=+m,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[d>>2]=~~+m>>>0;c[d+4>>2]=h;g=p-b|0;i=e;return g|0}function _P(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=i;i=i+32|0;n=m|0;o=m+8|0;p=m+16|0;q=m+24|0;r=c[e+8>>2]|0;e=DX(l,r,f)|0;f=c[r+8>>2]|0;if((f|0)==0){s=1902800}else if((f|0)==1){s=2213256}else if((f|0)==3){s=2128672}else{s=2065944}uAb(b,d,2019344,(f=i,i=i+24|0,c[f>>2]=s,c[f+8>>2]=j,c[f+16>>2]=e,f)|0)|0;i=f;a:do{if((g|0)!=0){j=(h|0)==0?1880808:h;do{if((k|0)>0){if((QGb(j,1880808)|0)!=0){break}uAb(b,d,1947264,(f=i,i=i+24|0,c[f>>2]=j,c[f+8>>2]=g,c[f+16>>2]=k,f)|0)|0;i=f;break a}}while(0);uAb(b,d,1945240,(f=i,i=i+16|0,c[f>>2]=j,c[f+8>>2]=g,f)|0)|0;i=f}}while(0);g=c[r+72>>2]|0;if((g|0)!=0){uAb(b,d,1976688,(f=i,i=i+8|0,c[f>>2]=(g|0)/1e3|0,f)|0)|0;i=f}g=r+48|0;k=c[g>>2]|0;b:do{if((k|0)==69660){if((e|0)<=95){t=0;break}h=c[r+416>>2]|0;uAb(b,d,2019056,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=8e3,c[f+16>>2]=h,f)|0)|0;i=f;t=0}else if((k|0)==28){do{if((l|0)==0){u=1}else{h=c[l+8>>2]|0;if((h|0)==0){u=1;break}if((c[h+36>>2]|0)==0){u=1;break}u=(AEb(c[l+12>>2]|0,2167752,2160528)|0)==0|0}}while(0);j=r+100|0;h=c[j>>2]|0;c:do{if((h|0)==0){v=0}else{if((h|0)>1073741818){yDb(r,16,1960024,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;v=0;break}s=r+96|0;do{if((a[c[s>>2]|0]|0)==1){w=S_(1955672)|0;if((w|0)==0){yDb(r,16,1953456,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;v=0;break c}x=c[j>>2]|0;y=cEb(x+16|0)|0;if((y|0)==0){T_(w);v=0;break c}else{UGb(y|0,c[s>>2]|0,x)|0;U_(w,r,0,o,p,0,0,0)|0;T_(w);z=x;A=y;break}}else{z=0;A=0}}while(0);y=cEb(1024)|0;if((y|0)==0){yDb(r,16,1951336,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;ZDb(A);v=0;break}UGb(y|0,1320008,23)|0;x=y+23|0;w=c[s>>2]|0;B=y;C=x;D=$W(w,w+(c[j>>2]|0)|0)|0;w=0;E=0;d:while(1){F=D;do{G=(c[s>>2]|0)+(c[j>>2]|0)|0;if(F>>>0<G>>>0){H=F}else{break d}while(1){I=H+1|0;if((a[H]|0)==0){H=I}else{break}}J=a[I]&31;F=$W(I,G)|0;}while(!((J-7&255)>>>0<2>>>0));if((C|0)==(x|0)){K=x}else{a[C]=44;K=C+1|0}J=(E|0)==0;L=B-K+1024|0;M=F-I|0;if((HAb(K,L,I,M)|0)==0){N=36;break}C=K+(SGb(K|0)|0)|0;D=F;w=J?F:w;E=J?I:E}if((N|0)==36){yDb(r,16,1949152,(f=i,i=i+16|0,c[f>>2]=L,c[f+8>>2]=M,f)|0);i=f;ZDb(y);v=0;break}do{if((E|0)!=0){if((w-E|0)<=3){break}UGb(C|0,1320032,19)|0;D=SGb(C|0)|0;ZT(C+D|0,E+1|0,3,0)|0;a[C+(D+6)|0]=0}}while(0);if((A|0)==0){v=y;break}ZDb(c[s>>2]|0);c[s>>2]=A;c[j>>2]=z;v=y}}while(0);uAb(b,d,2153696,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=e,c[f+16>>2]=u,c[f+24>>2]=(v|0)!=0?v:9203368,f)|0)|0;i=f;t=v}else if((k|0)==13){j=r+100|0;h=c[j>>2]|0;do{if((h|0)==0){O=0}else{if((h|0)>1073741818){yDb(r,16,1960024,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;O=0;break}C=WDb((h<<1)+10|0)|0;if((C|0)==0){yDb(r,16,1964592,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;O=0;break}else{UGb(C|0,1958112,9)|0;ZT(C+9|0,c[r+96>>2]|0,c[j>>2]|0,0)|0;a[C+((c[j>>2]<<1)+9)|0]=0;O=C;break}}}while(0);uAb(b,d,2127944,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=e,c[f+16>>2]=(O|0)!=0?O:9203368,f)|0)|0;i=f;t=O}else if((k|0)==5|(k|0)==20){do{if((l|0)!=0){if((c[(c[l+8>>2]|0)+36>>2]|0)==0){break}if((AEb(c[l+12>>2]|0,2167752,2140448)|0)==0){break}if((c[g>>2]|0)!=20){t=0;break b}}}while(0);j=c[r+120>>2]|0;h=c[r+124>>2]|0;uAb(b,d,2134024,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=e,c[f+16>>2]=j,c[f+24>>2]=h,f)|0)|0;i=f;t=0}else if((k|0)==73729){h=c[r+412>>2]|0;j=c[r+416>>2]|0;uAb(b,d,2069880,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=h,c[f+16>>2]=j,c[f+24>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==86021){if((c[r+100>>2]|0)==0){yDb(r,16,2065376,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}j=bQ(r)|0;if((j|0)==0){i=m;return}else{h=c[r+412>>2]|0;C=c[r+416>>2]|0;uAb(b,d,2061296,(f=i,i=i+40|0,c[f>>2]=e,c[f+8>>2]=h,c[f+16>>2]=C,c[f+24>>2]=e,c[f+32>>2]=j,f)|0)|0;i=f;t=j;break}}else if((k|0)==69643){if((e|0)<=95){t=0;break}j=c[r+792>>2]<<3;C=c[r+412>>2]|0;uAb(b,d,2014736,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=j,c[f+16>>2]=C,f)|0)|0;i=f;t=0}else if((k|0)==86076){C=c[r+412>>2]|0;j=(c[r+432>>2]|0)==38?20:30;uAb(b,d,2011560,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=C,c[f+16>>2]=e,c[f+24>>2]=j,f)|0)|0;i=f;t=0}else if((k|0)==86052){j=c[r+412>>2]|0;uAb(b,d,2001896,(f=i,i=i+16|0,c[f>>2]=e,c[f+8>>2]=j,f)|0)|0;i=f;if((c[r+12>>2]|0)==0){t=0;break}if((c[r+88>>2]&2|0)==0){j=(zEb(r,1992608,1,q)|0)==0;P=j&((c[q>>2]|0)!=0|(c[q+4>>2]|0)!=0)?1992608:1989120}else{P=1995744}uAb(b,d,1985400,(f=i,i=i+16|0,c[f>>2]=e,c[f+8>>2]=P,f)|0)|0;i=f;t=0}else if((k|0)==65543){if((e|0)<=95){t=0;break}j=c[r+412>>2]|0;C=c[r+416>>2]|0;uAb(b,d,2079448,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=j,c[f+16>>2]=C,f)|0)|0;i=f;t=0}else if((k|0)==73728){C=c[r+412>>2]|0;j=c[r+416>>2]|0;uAb(b,d,2074664,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=C,c[f+16>>2]=j,c[f+24>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==31){j=c[r+140>>2]|0;if((j|0)==4){Q=2047512}else if((j|0)==5){Q=2040744}else if((j|0)==0){Q=2058016}else{yDb(r,16,2037304,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}if((c[r+100>>2]|0)==0){yDb(r,16,2033848,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}j=bQ(r)|0;if((j|0)==0){i=m;return}else{C=c[r+120>>2]|0;h=c[r+124>>2]|0;uAb(b,d,2029568,(f=i,i=i+48|0,c[f>>2]=e,c[f+8>>2]=e,c[f+16>>2]=C,c[f+24>>2]=h,c[f+32>>2]=Q,c[f+40>>2]=j,f)|0)|0;i=f;t=j;break}}else if((k|0)==141){uAb(b,d,2025904,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==8){if((e|0)<=95){t=0;break}uAb(b,d,2022280,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==65537){if((e|0)<=95){t=0;break}j=c[r+412>>2]|0;h=c[r+416>>2]|0;uAb(b,d,2089496,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=j,c[f+16>>2]=h,f)|0)|0;i=f;t=0}else if((k|0)==86018){do{if((l|0)!=0){h=c[l+8>>2]|0;if((h|0)==0){break}if((c[h+36>>2]|0)==0){break}if((AEb(c[l+12>>2]|0,2167752,2121944)|0)==0){break}h=n|0;j=r+412|0;C=0;while(1){if((C|0)>=16){break}if((c[1743568+(C<<2)>>2]|0)==(c[j>>2]|0)){break}else{C=C+1|0}}if((C|0)==16){yDb(r,16,1972576,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}a[h]=64;a[n+1|0]=0;a[n+2|0]=C|32;y=r+416|0;a[n+3|0]=c[y>>2]<<4;a[n+4|0]=63;a[n+5|0]=-64;s=WDb(13)|0;if((s|0)==0){yDb(r,16,1964592,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}ZT(s,h,6,1)|0;a[s+12|0]=0;E=c[j>>2]|0;w=c[y>>2]|0;do{if((E|0)<24001){R=(w|0)<3?40:43}else{if((E|0)>=48001){R=43;break}if((w|0)<3){R=41;break}R=(w|0)<6?42:43}}while(0);uAb(b,d,2116808,(f=i,i=i+48|0,c[f>>2]=e,c[f+8>>2]=E,c[f+16>>2]=w,c[f+24>>2]=e,c[f+32>>2]=R,c[f+40>>2]=s,f)|0)|0;i=f;t=s;break b}}while(0);j=r+100|0;h=c[j>>2]|0;if((h|0)==0){yDb(r,16,2103872,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}if((h|0)>1073741818){yDb(r,16,1960024,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}C=WDb((h<<1)+10|0)|0;if((C|0)!=0){UGb(C|0,1958112,9)|0;ZT(C+9|0,c[r+96>>2]|0,c[j>>2]|0,0)|0;a[C+((c[j>>2]<<1)+9)|0]=0;j=c[r+412>>2]|0;h=c[r+416>>2]|0;uAb(b,d,2094896,(f=i,i=i+40|0,c[f>>2]=e,c[f+8>>2]=j,c[f+16>>2]=h,c[f+24>>2]=e,c[f+32>>2]=C,f)|0)|0;i=f;t=C;break}yDb(r,16,1964592,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}else if((k|0)==1330664787){uAb(b,d,1982120,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==65542){if((e|0)<=95){t=0;break}C=c[r+412>>2]|0;h=c[r+416>>2]|0;uAb(b,d,2084704,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=C,c[f+16>>2]=h,f)|0)|0;i=f;t=0}else{t=0}}while(0);ZDb(t);i=m;return}function $P(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;i=i+64|0;h=g|0;j=g+40|0;k=g+48|0;l=g+56|0;m=BBb(c[(c[b>>2]|0)+1140>>2]|0,1947448,0,0)|0;TGb(e|0,0,f|0)|0;if((m|0)==0){n=2338776}else{n=c[m+4>>2]|0}c[h>>2]=0;m=(d|0)==1;o=g+8|0;do{if(m){p=aQ(o,h,(c[b>>2]|0)+32|0)|0;q=j|0;c[h>>2]=0;if((a[o]|0)==0){r=p;s=6;break}t=(QGb(q,2314496)|0)==0;uAb(e,f,2221216,(u=i,i=i+48|0,c[u>>2]=0,c[u+8>>2]=0,c[u+16>>2]=0,c[u+24>>2]=t?2314496:1880808,c[u+32>>2]=t?2294024:1900952,c[u+40>>2]=n,u)|0)|0;i=u;uAb(e,f,1945240,(u=i,i=i+16|0,c[u>>2]=q,c[u+8>>2]=o,u)|0)|0;i=u;uAb(e,f,2211944,(u=i,i=i+16|0,c[u>>2]=0,c[u+8>>2]=0,u)|0)|0;i=u;a[o]=0;v=p}else{r=0;s=6}}while(0);do{if((s|0)==6){uAb(e,f,2221216,(u=i,i=i+48|0,c[u>>2]=0,c[u+8>>2]=0,c[u+16>>2]=0,c[u+24>>2]=1880808,c[u+32>>2]=1900952,c[u+40>>2]=n,u)|0)|0;i=u;uAb(e,f,2211944,(u=i,i=i+16|0,c[u>>2]=0,c[u+8>>2]=0,u)|0)|0;i=u;a[o]=0;if((d|0)>0){v=r;break}i=g;return 0}}while(0);r=j|0;j=0;n=v;v=0;while(1){s=b+(j<<2)|0;if(m){w=n}else{p=aQ(o,h,(c[s>>2]|0)+32|0)|0;c[h>>2]=0;w=p}p=c[s>>2]|0;if((c[p+24>>2]|0)==0){x=v}else{q=(w|0)<1;if((w|0)>0){t=0;y=v;z=p;while(1){A=y+1|0;_P(e,f,c[(c[z+28>>2]|0)+(t<<2)>>2]|0,y,(a[o]|0)!=0?o:0,r,(t<<1)+w|0,0,z);if(q){uAb(e,f,2277480,(u=i,i=i+8|0,c[u>>2]=t+j,u)|0)|0;i=u}B=c[s>>2]|0;C=B+16|0;D=c[C>>2]|0;do{if((D|0)==0){E=B}else{if((c[D>>2]|0)==0){E=B;break}c[k>>2]=0;c[l>>2]=0;xEb(c[C>>2]|0,2261872,1,k)|0;xEb(c[(c[s>>2]|0)+16>>2]|0,2247264,1,l)|0;F=c[k>>2]|0;do{if((F|0)==0){G=0}else{if((a[F]|0)==0){G=F;break}H=c[l>>2]|0;uAb(e,f,2234472,(u=i,i=i+16|0,c[u>>2]=F,c[u+8>>2]=H,u)|0)|0;i=u;G=c[k>>2]|0}}while(0);ZDb(G);ZDb(c[l>>2]|0);E=c[s>>2]|0}}while(0);C=t+1|0;if(C>>>0<(c[E+24>>2]|0)>>>0){t=C;y=A;z=E}else{x=A;break}}}else{z=0;y=v;t=p;while(1){C=y+1|0;_P(e,f,c[(c[t+28>>2]|0)+(z<<2)>>2]|0,y,(a[o]|0)!=0?o:0,r,0,0,t);if(q){uAb(e,f,2277480,(u=i,i=i+8|0,c[u>>2]=z+j,u)|0)|0;i=u}B=c[s>>2]|0;D=B+16|0;F=c[D>>2]|0;do{if((F|0)==0){I=B}else{if((c[F>>2]|0)==0){I=B;break}c[k>>2]=0;c[l>>2]=0;xEb(c[D>>2]|0,2261872,1,k)|0;xEb(c[(c[s>>2]|0)+16>>2]|0,2247264,1,l)|0;H=c[k>>2]|0;do{if((H|0)==0){J=0}else{if((a[H]|0)==0){J=H;break}K=c[l>>2]|0;uAb(e,f,2234472,(u=i,i=i+16|0,c[u>>2]=H,c[u+8>>2]=K,u)|0)|0;i=u;J=c[k>>2]|0}}while(0);ZDb(J);ZDb(c[l>>2]|0);I=c[s>>2]|0}}while(0);D=z+1|0;if(D>>>0<(c[I+24>>2]|0)>>>0){z=D;y=C;t=I}else{x=C;break}}}}t=j+1|0;if((t|0)<(d|0)){j=t;n=w;v=x}else{break}}i=g;return 0}function aQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+104|0;f=e|0;g=e+40|0;h=e+8|0;YT(h,32,0,0,a,32,f,0,0,d);c[b>>2]=0;do{if((QGb(h,2202896)|0)!=0){if((QGb(h,2195688)|0)==0){break}else{j=0}i=e;return j|0}}while(0);h=Vb(d|0,63)|0;do{if((h|0)!=0){d=g|0;if((WEb(d,64,2180568,h)|0)==0){c[b>>2]=5;break}else{c[b>>2]=kb(d|0,0,10)|0;break}}}while(0);j=c[f>>2]|0;i=e;return j|0}function bQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+32|0;e=d|0;f=d+16|0;g=c[b+48>>2]|0;if((g|0)==86021){h=30}else if((g|0)==31){h=42}else{yDb(b,16,1978936,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=0;i=d;return k|0}g=e|0;l=f|0;if((Bdb(c[b+96>>2]|0,c[b+100>>2]|0,h,g,l)|0)<0){yDb(b,16,1976472,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=0;i=d;return k|0}h=f+8|0;f=(c[h>>2]|0)+(c[l>>2]|0)|0;m=f+12|0;n=WDb(m)|0;do{if((n|0)!=0){o=((f+14|0)/3|0)<<2|1;p=WDb(o)|0;if((p|0)==0){ZDb(n);break}a[n+2|0]=0;a[n+1|0]=0;a[n]=0;a[n+3|0]=1;a[n+4|0]=-2;a[n+5|0]=-51;a[n+6|0]=-70;a[n+7|0]=f>>>8;a[n+8|0]=f;a[n+9|0]=2;q=c[l>>2]|0;a[n+10|0]=q;a[n+11|0]=0;UGb(n+12|0,c[g>>2]|0,q)|0;UGb(n+(q+12)|0,c[e+8>>2]|0,c[h>>2]|0)|0;HAb(p,o,n,m)|0;ZDb(n);k=p;i=d;return k|0}}while(0);yDb(b,16,1974072,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=0;i=d;return k|0}function cQ(a){a=a|0;var b=0;b=c[a+4>>2]|0;return((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==21058131?50:0)|0}function dQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=LT(a,0)|0;if((e|0)==0){d=-12;return d|0}f=a+16|0;Vy(c[f>>2]|0,20,0)|0;MT(e,64,1,rz(c[f>>2]|0)|0);a=e+8|0;c[(c[a>>2]|0)+8>>2]=0;g=rz(c[f>>2]|0)|0;c[(c[a>>2]|0)+120>>2]=g;g=rz(c[f>>2]|0)|0;h=c[a>>2]|0;c[h+124>>2]=g;c[h+48>>2]=28;c[e+236>>2]=1;e=c[b+8>>2]|0;c[e+8>>2]=1;c[e+416>>2]=1;c[e+412>>2]=8e3;c[e+48>>2]=65536;MT(b,64,1,8e3);Ty(c[f>>2]|0,168,0,0)|0;d=0;return d|0}function eQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a+16|0;a=Ty(c[d>>2]|0,0,0,1)|0;e=F;f=rz(c[d>>2]|0)|0;Vy(c[d>>2]|0,4,0)|0;g=rz(c[d>>2]|0)|0;if(g>>>0<53>>>0){h=-1094995529;return h|0}Vy(c[d>>2]|0,6,0)|0;i=rz(c[d>>2]|0)|0;Vy(c[d>>2]|0,30,0)|0;do{if((a|0)==168&(e|0)==0){if((wZ(b,g-28|0)|0)<0){h=-12;return h|0}j=b+24|0;UGb(c[j>>2]|0,981480,24)|0;k=mz(c[d>>2]|0,(c[j>>2]|0)+24|0,g-52|0)|0;if((k|0)>=0){yZ(b,k+24|0);l=k;break}BZ(b);h=k;return h|0}else{l=TS(c[d>>2]|0,b,g-52|0)|0}}while(0);c[b+32>>2]=(i|0)!=0;i=b+64|0;c[i>>2]=a;c[i+4>>2]=e;if((f&4096|0)==0){h=l;return h|0}f=b+36|0;c[f>>2]=c[f>>2]|1;h=l;return h|0}function fQ(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1296845126){e=0;return e|0}a=b+16|0;e=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1129530438?100:0;return e|0}function gQ(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+256|0;g=f|0;h=g|0;j=g;k=e+12|0;l=c[k>>2]|0;m=c[e+16>>2]|0;n=l+32|0;c[n>>2]=0;o=g;if((mz(m,o,16)|0)!=16){p=-5;i=f;return p|0}q=g+4|0;r=fe(c[q>>2]|0)|0;s=g+8|0;t=s;u=c[s>>2]|0;c[l+44>>2]=fe(u|0)|0;a:do{if((u|0)==0){if((mz(m,o,20)|0)==20){c[l+8>>2]=65540;c[l+12>>2]=22050;c[l+20>>2]=1;c[l+16>>2]=8;break}else{p=-5;i=f;return p|0}}else{if((mz(m,o,32)|0)!=32){p=-5;i=f;return p|0}c[l+12>>2]=(de(b[g+24>>1]|0)|0)&65535;v=a[j+21|0]|0;c[l+20>>2]=v&255;w=a[j+22|0]|0;c[l+16>>2]=w&255;x=v<<24>>24==0;do{if((a[j+23|0]|0)==2){if(x){break}c[l+8>>2]=69641;break a}else{if(x){break}if(w<<24>>24==8){c[l+8>>2]=65563;break a}v=l+8|0;if(w<<24>>24==16){c[v>>2]=1347637264;break a}else{c[v>>2]=0;break a}}}while(0);c[l+8>>2]=0}}while(0);if((c[h>>2]|0)!=1129530438){p=-1094995529;i=f;return p|0}j=c[s>>2]|0;do{if((j|0)==1684633187){c[l+24>>2]=44;y=22}else{u=l+24|0;if((j|0)==544694642){c[u>>2]=14;y=22;break}else{c[u>>2]=0;break}}}while(0);do{if((y|0)==22){j=l+24|0;u=LT(e,0)|0;if((u|0)==0){p=-12;i=f;return p|0}c[l>>2]=c[u>>2];w=c[u+8>>2]|0;c[w+8>>2]=0;c[w+48>>2]=c[j>>2];c[w+52>>2]=0;c[w+120>>2]=fe(c[g+16>>2]|0)|0;c[w+124>>2]=fe(c[g+12>>2]|0)|0;if((c[j>>2]|0)!=14){break}j=a[g+20|0]|0;if(j<<24>>24==24){c[w+140>>2]=2;break}yDb(e,16,2128280,(w=i,i=i+8|0,c[w>>2]=j&255,w)|0);i=w;p=-1;i=f;return p|0}}while(0);y=l+8|0;if((c[y>>2]|0)!=0){w=LT(e,0)|0;if((w|0)==0){p=-12;i=f;return p|0}c[l+4>>2]=c[w>>2];j=c[w+8>>2]|0;c[j+8>>2]=1;c[j+48>>2]=c[y>>2];c[j+52>>2]=1;u=c[l+20>>2]|0;c[j+416>>2]=u;x=c[l+12>>2]|0;c[j+412>>2]=x;if((c[y>>2]|0)==69641){c[j+792>>2]=4;c[j+432>>2]=u*18|0;c[w+236>>2]=1;z=4}else{w=c[l+16>>2]|0;c[j+792>>2]=w;c[j+432>>2]=(ba(w,u)|0)/8|0;z=w}c[j+72>>2]=ba(ba(x,u)|0,z)|0}if((mz(m,o,16)|0)!=16){p=-5;i=f;return p|0}if((c[h>>2]|0)!=1111577683){p=-1094995529;i=f;return p|0}z=l+40|0;c[z>>2]=fe(c[s>>2]|0)|0;u=fe(c[g+12>>2]|0)|0;g=l+28|0;c[g>>2]=u;if(u>>>0>107374181>>>0){p=-1;i=f;return p|0}x=WDb(u*40|0)|0;c[n>>2]=x;if((x|0)==0){p=-12;i=f;return p|0}x=e+24|0;if((c[x>>2]|0)!=0){u=e+28|0;e=l+12|0;j=0;do{w=c[(c[u>>2]|0)+(j<<2)>>2]|0;if((c[(c[w+8>>2]|0)+8>>2]|0)==0){MT(w,33,1,c[z>>2]|0)}else{MT(w,64,1,c[e>>2]|0)}j=j+1|0;}while(j>>>0<(c[x>>2]|0)>>>0)}b:do{if((c[g>>2]|0)!=0){x=l+4|0;j=l+20|0;e=l+16|0;z=l;u=0;w=0;while(1){if((mz(m,o,16)|0)!=16){A=-5;break}v=(fe(c[h>>2]|0)|0)+r|0;B=c[n>>2]|0;C=B+(u*40|0)+8|0;c[C>>2]=v;c[C+4>>2]=0;C=fe(c[q>>2]|0)|0;c[B+(u*40|0)+16>>2]=C;v=B+(u*40|0)|0;if(C>>>0>536870911>>>0){A=-1094995529;break}do{if((c[s>>2]|0)==-1){c[v>>2]=c[x>>2];D=B+(u*40|0)+24|0;c[D>>2]=w;c[D+4>>2]=0;D=c[y>>2]|0;if((D|0)==69641){E=((C<<5>>>0)/(((c[j>>2]|0)*18|0)>>>0)|0)+w|0;break}else if((D|0)==0){E=w;break}else{E=((C>>>0)/((ba(c[e>>2]|0,c[j>>2]|0)|0)>>>3>>>0)|0)+w|0;break}}else{c[v>>2]=c[z>>2];D=B+(u*40|0)+24|0;c[D>>2]=(fe(c[s>>2]|0)|0)&2147483647;c[D+4>>2]=0;c[B+(u*40|0)+32>>2]=(d[t]|0)>>>7&255^1;E=w}}while(0);B=u+1|0;if(B>>>0<(c[g>>2]|0)>>>0){u=B;w=E}else{break b}}$Db((c[k>>2]|0)+32|0);p=A;i=f;return p|0}}while(0);c[l+36>>2]=0;p=0;i=f;return p|0}function hQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;a=d+36|0;f=c[a>>2]|0;if(!(f>>>0<(c[d+28>>2]|0)>>>0)){g=-541478725;return g|0}h=c[d+32>>2]|0;d=h+(f*40|0)+8|0;Ty(e,c[d>>2]|0,c[d+4>>2]|0,0)|0;d=h+(f*40|0)+16|0;i=TS(e,b,c[d>>2]|0)|0;e=(i|0)==(c[d>>2]|0)?i:-5;c[b+32>>2]=c[h+(f*40|0)>>2];i=h+(f*40|0)+24|0;f=c[i+4>>2]|0;h=b+8|0;c[h>>2]=c[i>>2];c[h+4>>2]=f;c[a>>2]=(c[a>>2]|0)+1;g=e;return g|0}function iQ(a){a=a|0;$Db((c[a+12>>2]|0)+32|0);return 0}function jQ(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=i;i=i+56|0;e=d|0;f=d+24|0;g=d+32|0;j=d+40|0;k=d+48|0;l=b+12|0;m=c[l>>2]|0;c[m+12>>2]=0;n=m+108|0;if((c[n>>2]|0)==0){c[m+104>>2]=0}o=m+52|0;p=c[o>>2]|0;q=(p|0)!=0;r=c[m+64>>2]|0;s=(r|0)!=0;t=c[m+76>>2]|0;u=(t|0)!=0;if(((s&1)+(q&1)+(u&1)|0)>1){yDb(b,16,1898072,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=d;return w|0}do{if(s){x=b;y=m+68|0;z=m+72|0;A=eEb(r)|0;c[j>>2]=0;if((A|0)==0){w=-12;i=d;return w|0}c[z>>2]=1;B=A;C=1;while(1){D=a[B]|0;if((D<<24>>24|0)==0){break}else if((D<<24>>24|0)==44){D=C+1|0;c[z>>2]=D;E=D}else{E=C}B=B+1|0;C=E}B=WDb(C<<3)|0;c[y>>2]=B;a:do{if((B|0)==0){yDb(x,16,2345352,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;F=-12}else{if((c[z>>2]|0)>0){G=0;H=A}else{F=0;break}while(1){I=xAb(H,1879200,j)|0;if((I|0)==0){J=16;break}if((a[I]|0)==0){J=16;break}D=VEb(k,I,1)|0;if((D|0)<0){J=18;break}K=c[k>>2]|0;L=c[k+4>>2]|0;M=c[y>>2]|0;N=M+(G<<3)|0;c[N>>2]=K;c[N+4>>2]=L;if((G|0)!=0){N=M+(G-1<<3)|0;O=c[N>>2]|0;P=c[N+4>>2]|0;if((P|0)>(L|0)|(P|0)==(L|0)&O>>>0>K>>>0){J=21;break}}N=G+1|0;if((N|0)<(c[z>>2]|0)){G=N;H=0}else{F=D;break a}}if((J|0)==16){yDb(x,16,2343640,(v=i,i=i+8|0,c[v>>2]=r,v)|0);i=v;F=-22;break}else if((J|0)==18){yDb(x,16,2342336,(v=i,i=i+16|0,c[v>>2]=I,c[v+8>>2]=r,v)|0);i=v;F=-22;break}else if((J|0)==21){yDb(x,16,2341192,(v=i,i=i+16|0,h[v>>3]=(+(K>>>0)+ +(L|0)*4294967296.0)/1.0e6,h[v+8>>3]=(+(O>>>0)+ +(P|0)*4294967296.0)/1.0e6,v)|0);i=v;F=-22;break}}}while(0);ZDb(A);if((F|0)<0){w=F}else{break}i=d;return w|0}else{if(!u){if(q){Q=p}else{x=eEb(1892544)|0;c[o>>2]=x;Q=x}x=VEb(m+56|0,Q,1)|0;if((x|0)>=0){break}yDb(b,16,1889168,(v=i,i=i+8|0,c[v>>2]=c[o>>2],v)|0);i=v;w=x;i=d;return w|0}x=b;z=m+80|0;y=m+84|0;B=eEb(t)|0;c[f>>2]=0;if((B|0)==0){w=-12;i=d;return w|0}c[y>>2]=1;C=B;D=1;while(1){N=a[C]|0;if((N<<24>>24|0)==44){M=D+1|0;c[y>>2]=M;R=M}else if((N<<24>>24|0)==0){break}else{R=D}C=C+1|0;D=R}C=WDb(D<<2)|0;c[z>>2]=C;b:do{if((C|0)==0){yDb(x,16,1880696,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;S=-12}else{if((c[y>>2]|0)>0){T=0;U=B}else{S=0;break}while(1){V=xAb(U,1879200,f)|0;if((V|0)==0){J=34;break}W=kb(V|0,g|0,10)|0;if((a[c[g>>2]|0]|0)!=0){J=37;break}if((W|0)<1|(W|0)==2147483647){J=37;break}A=c[z>>2]|0;c[A+(T<<2)>>2]=W;if((T|0)!=0){X=c[A+(T-1<<2)>>2]|0;if((X|0)>(W|0)){J=40;break}}A=T+1|0;if((A|0)<(c[y>>2]|0)){T=A;U=0}else{S=0;break b}}if((J|0)==34){yDb(x,16,2355352,(v=i,i=i+8|0,c[v>>2]=t,v)|0);i=v;S=-22;break}else if((J|0)==37){yDb(x,16,2350128,(v=i,i=i+8|0,c[v>>2]=V,v)|0);i=v;S=-22;break}else if((J|0)==40){yDb(x,16,2346608,(v=i,i=i+16|0,c[v>>2]=W,c[v+8>>2]=X,v)|0);i=v;S=-22;break}}}while(0);ZDb(B);if((S|0)<0){w=S}else{break}i=d;return w|0}}while(0);S=m+28|0;X=c[S>>2]|0;W=m+44|0;if((X|0)==0){J=59}else{do{if((c[W>>2]|0)==-1){if((TC(X,2134016)|0)!=0){c[W>>2]=1;break}if((TC(c[S>>2]|0,2121936)|0)!=0){c[W>>2]=3;break}if((TC(c[S>>2]|0,2089488)|0)!=0){c[W>>2]=2;break}if((TC(c[S>>2]|0,1887312)|0)==0){c[W>>2]=0;break}else{c[W>>2]=4;break}}}while(0);X=nQ(b)|0;if((X|0)<0){Y=X}else{J=59}}c:do{if((J|0)==59){if((c[W>>2]|0)==3){yDb(b,24,1885752,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v}X=c[l>>2]|0;V=X+132|0;c[V>>2]=-1;t=X+128|0;X=c[t>>2]|0;d:do{if((QGb(X,1947336)|0)==0){TGb(e|0,-1|0,20)|0;U=c[b+24>>2]|0;if((U|0)==0){Z=0}else{T=c[b+28>>2]|0;g=0;while(1){f=c[T+(g<<2)>>2]|0;R=c[(c[f+8>>2]|0)+8>>2]|0;do{if(R>>>0<5>>>0){o=e+(R<<2)|0;if(!((c[o>>2]|0)==-1)){break}if((c[f+72>>2]&1024|0)!=0){break}c[o>>2]=g}}while(0);f=g+1|0;if(f>>>0<U>>>0){g=f}else{Z=0;break}}}while(1){if(!(Z>>>0<5>>>0)){_=X;J=79;break d}g=c[e+(c[472672+(Z<<2)>>2]<<2)>>2]|0;c[V>>2]=g;if((g|0)>-1){break}else{Z=Z+1|0}}$=b+28|0}else{g=b+24|0;U=b+28|0;T=0;while(1){if(!(T>>>0<(c[g>>2]|0)>>>0)){J=76;break}f=hU(b,c[(c[U>>2]|0)+(T<<2)>>2]|0,c[t>>2]|0)|0;if((f|0)<0){Y=f;break c}if((f|0)>0){J=75;break}else{T=T+1|0}}if((J|0)==75){c[V>>2]=T;aa=T}else if((J|0)==76){aa=c[V>>2]|0}if((aa|0)>=0){$=U;break}_=c[t>>2]|0;J=79}}while(0);if((J|0)==79){yDb(b,16,1881944,(v=i,i=i+8|0,c[v>>2]=_,v)|0);i=v;Y=-22;break}t=b;V=c[m+132>>2]|0;X=lGb(c[(c[(c[(c[$>>2]|0)+(V<<2)>>2]|0)+8>>2]|0)+8>>2]|0)|0;yDb(t,40,1884256,(v=i,i=i+16|0,c[v>>2]=V,c[v+8>>2]=X,v)|0);i=v;X=UC(c[m+24>>2]|0,b+32|0,0)|0;c[m+16>>2]=X;if((X|0)==0){Y=-1481985528;break}if((c[X+28>>2]&1|0)!=0){yDb(t,16,1883128,(v=i,i=i+8|0,c[v>>2]=c[X>>2],v)|0);i=v;Y=-22;break}X=pQ(b)|0;if((X|0)<0){Y=X;break}X=c[m+20>>2]|0;V=qQ(b)|0;if((V|0)<0){Y=V;break}V=X+16|0;do{if((c[n>>2]|0)==0){B=WDb(32768)|0;if((B|0)==0){Y=-12;break c}g=Oy(B,32768,2,0,0,0,0)|0;c[V>>2]=g;if((g|0)!=0){break}ZDb(B);Y=-12;break c}else{B=X+32|0;g=Hz(V,B,2,b+1160|0,0)|0;if((g|0)>=0){break}yDb(t,16,1906472,(v=i,i=i+8|0,c[v>>2]=B,v)|0);i=v;Y=g;break c}}while(0);t=FK(X,0)|0;if((t|0)<0){Iz(c[V>>2]|0)|0;Y=t;break}c[m+192>>2]=1;do{if((c[X+1204>>2]|0)>0){g=b+1204|0;if((c[g>>2]|0)>=0){break}c[g>>2]=1}}while(0);if((c[n>>2]|0)==0){g=c[V>>2]|0;ZDb(c[g+4>>2]|0);ZDb(g);ba=Hz(V,X+32|0,2,b+1160|0,0)|0}else{ba=t}if((ba|0)==0){w=0}else{Y=ba;break}i=d;return w|0}}while(0);if((c[S>>2]|0)!=0){Iz(c[m+48>>2]|0)|0}S=c[m+20>>2]|0;if((S|0)==0){w=Y;i=d;return w|0}bT(S);w=Y;i=d;return w|0}function kQ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,Q=0.0,R=0,S=0,T=0,U=0;e=i;i=i+376|0;f=e|0;g=e+8|0;j=e+16|0;k=e+48|0;l=e+80|0;m=e+112|0;n=e+144|0;o=e+176|0;p=e+208|0;q=e+240|0;r=e+248|0;s=e+280|0;t=e+312|0;u=e+344|0;v=b+12|0;w=c[v>>2]|0;x=d+32|0;y=c[x>>2]|0;z=c[(c[b+28>>2]|0)+(y<<2)>>2]|0;A=c[w+68>>2]|0;do{if((A|0)==0){B=c[w+80>>2]|0;if((B|0)==0){C=w+56|0;D=(c[w+12>>2]|0)+1|0;E=gHb(D,(D|0)<0|0?-1:0,c[C>>2]|0,c[C+4>>2]|0)|0;G=2147483647;H=F;I=E;break}E=c[w+12>>2]|0;if((E|0)>(c[w+84>>2]|0)){G=2147483647;H=2147483647;I=-1;break}G=c[B+(E<<2)>>2]|0;H=2147483647;I=-1}else{E=c[w+12>>2]|0;if((E|0)>=(c[w+72>>2]|0)){G=2147483647;H=2147483647;I=-1;break}B=A+(E<<3)|0;G=2147483647;H=c[B+4>>2]|0;I=c[B>>2]|0}}while(0);A=w+132|0;do{if((y|0)==(c[A>>2]|0)){if((c[d+36>>2]&1|0)==0){J=26;break}if((c[w+88>>2]|0)<(G|0)){B=d+8|0;E=c[B>>2]|0;C=c[B+4>>2]|0;if((E|0)==0&(C|0)==(-2147483648|0)){J=26;break}B=w+96|0;D=ZGb(I,H,c[B>>2]|0,c[B+4>>2]|0)|0;c[f>>2]=1;c[f+4>>2]=1e6;if(!((LDb(E,C,z+40|0,D,F,f)|0)>-1)){J=26;break}}D=w+104|0;C=mQ(b,c[D>>2]|0,0)|0;if((C|0)<0){K=C;break}C=c[v>>2]|0;E=C+20|0;B=c[E>>2]|0;L=(c[D>>2]|0)!=0;if(L){bT(B);c[E>>2]=0;D=pQ(b)|0;if((D|0)<0){K=D;break}M=c[E>>2]|0}else{M=B}B=C+4|0;c[B>>2]=(c[B>>2]|0)+1;B=qQ(b)|0;if((B|0)<0){K=B;break}B=M+32|0;E=Hz(M+16|0,B,2,b+1160|0,0)|0;if((E|0)<0){yDb(b,16,1906472,(N=i,i=i+8|0,c[N>>2]=B,N)|0);i=N;K=E;break}do{if((c[(c[M+8>>2]|0)+36>>2]|0)!=0){E=c[M+12>>2]|0;if((E|0)==0){break}rEb(E,1904904,1903056,0)|0}}while(0);if(L){E=FK(M,0)|0;if((E|0)<0){K=E;break}}c[C+192>>2]=1;c[w+136>>2]=c[w+4>>2];E=d+8|0;B=c[E>>2]|0;D=c[E+4>>2]|0;E=z+40|0;h[w+144>>3]=(+(B>>>0)+ +(D|0)*4294967296.0)*(+(c[E>>2]|0)/+(c[z+44>>2]|0));c[g>>2]=1;c[g+4>>2]=1e6;O=KDb(B,D,E,g)|0;E=w+160|0;c[E>>2]=O;c[E+4>>2]=F;J=28}else{J=26}}while(0);do{if((J|0)==26){g=d+8|0;M=c[g>>2]|0;v=c[g+4>>2]|0;if((M|0)==0&(v|0)==(-2147483648|0)){J=28;break}g=w+152|0;P=+h[g>>3];f=c[d+48>>2]|0;H=YGb(f,(f|0)<0|0?-1:0,M,v)|0;Q=(+(H>>>0)+ +(F|0)*4294967296.0)*(+(c[z+40>>2]|0)/+(c[z+44>>2]|0));h[g>>3]=P>Q?P:Q;J=28}}while(0);if((J|0)==28){J=w+192|0;g=b;if((c[J>>2]|0)!=0){H=(c[w+20>>2]|0)+32|0;v=c[x>>2]|0;M=j|0;TGb(M|0,0,32)|0;a[M]=0;j=d+8|0;f=c[j>>2]|0;I=c[j+4>>2]|0;if((f|0)==0&(I|0)==(-2147483648|0)){Lb(M|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(M|0,32,1908176,(N=i,i=i+16|0,c[N>>2]=f,c[N+8>>2]=I,N)|0)|0;i=N}I=k|0;TGb(I|0,0,32)|0;a[I]=0;k=c[j>>2]|0;f=c[j+4>>2]|0;if((k|0)==0&(f|0)==(-2147483648|0)){Lb(I|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(I|0,32,1909536,(N=i,i=i+8|0,h[N>>3]=(+(k>>>0)+ +(f|0)*4294967296.0)*(+(c[z+40>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}f=c[w+88>>2]|0;yDb(g,40,1922112,(N=i,i=i+40|0,c[N>>2]=H,c[N+8>>2]=v,c[N+16>>2]=M,c[N+24>>2]=I,c[N+32>>2]=f,N)|0);i=N;c[J>>2]=0}J=c[x>>2]|0;f=l|0;TGb(f|0,0,32)|0;a[f]=0;l=w+160|0;I=c[l>>2]|0;M=c[l+4>>2]|0;if((I|0)==0&(M|0)==(-2147483648|0)){Lb(f|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(f|0,32,1909536,(N=i,i=i+8|0,h[N>>3]=(+(I>>>0)+ +(M|0)*4294967296.0)*1.0e-6,N)|0)|0;i=N}M=m|0;TGb(M|0,0,32)|0;a[M]=0;m=d+8|0;I=c[m>>2]|0;v=c[m+4>>2]|0;if((I|0)==0&(v|0)==(-2147483648|0)){Lb(M|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(M|0,32,1908176,(N=i,i=i+16|0,c[N>>2]=I,c[N+8>>2]=v,N)|0)|0;i=N}v=n|0;TGb(v|0,0,32)|0;a[v]=0;n=c[m>>2]|0;I=c[m+4>>2]|0;H=z+40|0;if((n|0)==0&(I|0)==(-2147483648|0)){Lb(v|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(v|0,32,1909536,(N=i,i=i+8|0,h[N>>3]=(+(n>>>0)+ +(I|0)*4294967296.0)*(+(c[H>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}I=o|0;TGb(I|0,0,32)|0;a[I]=0;o=d+16|0;n=c[o>>2]|0;k=c[o+4>>2]|0;if((n|0)==0&(k|0)==(-2147483648|0)){Lb(I|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(I|0,32,1908176,(N=i,i=i+16|0,c[N>>2]=n,c[N+8>>2]=k,N)|0)|0;i=N}k=p|0;TGb(k|0,0,32)|0;a[k]=0;p=c[o>>2]|0;n=c[o+4>>2]|0;if((p|0)==0&(n|0)==(-2147483648|0)){Lb(k|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(k|0,32,1909536,(N=i,i=i+8|0,h[N>>3]=(+(p>>>0)+ +(n|0)*4294967296.0)*(+(c[H>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}yDb(g,48,1920536,(N=i,i=i+48|0,c[N>>2]=J,c[N+8>>2]=f,c[N+16>>2]=M,c[N+24>>2]=v,c[N+32>>2]=I,c[N+40>>2]=k,N)|0);i=N;k=w+120|0;if((c[w+112>>2]|0)==0){R=0;S=0}else{R=c[l+4>>2]|0;S=c[l>>2]|0}l=ZGb(c[k>>2]|0,c[k+4>>2]|0,S,R)|0;c[q>>2]=1;c[q+4>>2]=1e6;R=KDb(l,F,q,H)|0;q=F;l=c[m>>2]|0;S=c[m+4>>2]|0;if((l|0)==0&(S|0)==(-2147483648|0)){T=-2147483648;U=0}else{k=YGb(l,S,R,q)|0;S=F;c[m>>2]=k;c[m+4>>2]=S;T=S;U=k}k=c[o>>2]|0;S=c[o+4>>2]|0;if(!((k|0)==0&(S|0)==(-2147483648|0))){l=YGb(k,S,R,q)|0;c[o>>2]=l;c[o+4>>2]=F}l=r|0;TGb(l|0,0,32)|0;a[l]=0;if((U|0)==0&(T|0)==(-2147483648|0)){Lb(l|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(l|0,32,1908176,(N=i,i=i+16|0,c[N>>2]=U,c[N+8>>2]=T,N)|0)|0;i=N}T=s|0;TGb(T|0,0,32)|0;a[T]=0;s=c[m>>2]|0;U=c[m+4>>2]|0;if((s|0)==0&(U|0)==(-2147483648|0)){Lb(T|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(T|0,32,1909536,(N=i,i=i+8|0,h[N>>3]=(+(s>>>0)+ +(U|0)*4294967296.0)*(+(c[H>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}U=t|0;TGb(U|0,0,32)|0;a[U]=0;t=c[o>>2]|0;s=c[o+4>>2]|0;if((t|0)==0&(s|0)==(-2147483648|0)){Lb(U|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(U|0,32,1908176,(N=i,i=i+16|0,c[N>>2]=t,c[N+8>>2]=s,N)|0)|0;i=N}s=u|0;TGb(s|0,0,32)|0;a[s]=0;u=c[o>>2]|0;t=c[o+4>>2]|0;if((u|0)==0&(t|0)==(-2147483648|0)){Lb(s|0,32,1912944,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Lb(s|0,32,1909536,(N=i,i=i+8|0,h[N>>3]=(+(u>>>0)+ +(t|0)*4294967296.0)*(+(c[H>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}yDb(g,48,1918904,(N=i,i=i+32|0,c[N>>2]=l,c[N+8>>2]=T,c[N+16>>2]=U,c[N+24>>2]=s,N)|0);i=N;K=OK(c[w+20>>2]|0,c[x>>2]|0,d,b)|0}if((c[x>>2]|0)!=(c[A>>2]|0)){i=e;return K|0}A=w+88|0;c[A>>2]=(c[A>>2]|0)+1;i=e;return K|0}function lQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=c[b+20>>2]|0;do{if((c[b+108>>2]|0)==0){e=mQ(a,0,1)|0;if((e|0)<0){f=e;break}e=d+16|0;g=WDb(32768)|0;do{if((g|0)!=0){h=Oy(g,32768,2,0,0,0,0)|0;c[e>>2]=h;if((h|0)!=0){break}ZDb(g)}}while(0);g=NK(d)|0;h=c[e>>2]|0;ZDb(c[h+4>>2]|0);ZDb(h);f=g}else{f=mQ(a,1,1)|0}}while(0);if((c[b+28>>2]|0)!=0){Iz(c[b+48>>2]|0)|0}HEb(b);$Db(b+68|0);$Db(b+80|0);a=c[b+184>>2]|0;if((a|0)==0){bT(d);return f|0}else{i=a}while(1){a=c[i+44>>2]|0;ZDb(c[i+40>>2]|0);ZDb(i);if((a|0)==0){break}else{i=a}}bT(d);return f|0}function mQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+8|0;f=e|0;g=c[a+12>>2]|0;h=g+20|0;j=c[h>>2]|0;GK(j,0)|0;do{if((b|0)==0){k=0}else{l=NK(j)|0;if((l|0)>=0){k=l;break}yDb(a,16,1978888,(m=i,i=i+8|0,c[m>>2]=j+32,m)|0);i=m;k=l}}while(0);if((c[g+28>>2]|0)==0){n=k}else{b=g+36|0;do{if((c[b>>2]|0)==0){l=c[g+44>>2]|0;if((l|0)==2){o=7;break}oQ(c[g+48>>2]|0,l,g+136|0,a);p=k}else{o=7}}while(0);do{if((o|0)==7){k=cEb(48)|0;l=k;c[f>>2]=l;if((k|0)==0){q=-12;r=j+16|0;s=c[r>>2]|0;t=Iz(s)|0;i=e;return q|0}u=g+136|0;c[k>>2]=c[u>>2];c[k+4>>2]=c[u+4>>2];c[k+8>>2]=c[u+8>>2];c[k+12>>2]=c[u+12>>2];c[k+16>>2]=c[u+16>>2];c[k+20>>2]=c[u+20>>2];c[k+24>>2]=c[u+24>>2];c[k+28>>2]=c[u+28>>2];c[k+32>>2]=c[u+32>>2];c[k+36>>2]=c[u+36>>2];c[k+40>>2]=c[u+40>>2];c[k+44>>2]=c[u+44>>2];u=g+184|0;k=g+188|0;if((c[u>>2]|0)==0){c[k>>2]=l;c[u>>2]=l}else{c[(c[k>>2]|0)+44>>2]=l}c[k>>2]=c[f>>2];k=c[b>>2]|0;do{if((k|0)!=0){if((c[g+12>>2]|0)<=(k|0)){break}c[f>>2]=c[u>>2];c[u>>2]=c[(c[u>>2]|0)+44>>2];ZDb(c[(c[f>>2]|0)+40>>2]|0);$Db(f)}}while(0);k=g+48|0;Iz(c[k>>2]|0)|0;l=nQ(a)|0;if((l|0)<0){q=l;r=j+16|0;s=c[r>>2]|0;t=Iz(s)|0;i=e;return q|0}v=c[u>>2]|0;c[f>>2]=v;w=g+44|0;if((v|0)!=0){x=a;y=v;do{oQ(c[k>>2]|0,c[w>>2]|0,y,x);y=c[(c[f>>2]|0)+44>>2]|0;c[f>>2]=y;}while((y|0)!=0)}if((c[w>>2]|0)!=2|(d|0)==0){p=l;break}Kz(c[k>>2]|0,1976456,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;p=l}}while(0);Sy(c[g+48>>2]|0);n=p}p=g+12|0;g=c[p>>2]|0;yDb(a,40,1974040,(m=i,i=i+16|0,c[m>>2]=(c[h>>2]|0)+32,c[m+8>>2]=g,m)|0);i=m;c[p>>2]=(c[p>>2]|0)+1;q=n;r=j+16|0;s=c[r>>2]|0;t=Iz(s)|0;i=e;return q|0}function nQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0.0,l=0.0,m=0.0,n=0.0;b=i;d=c[a+12>>2]|0;e=d+48|0;f=d+28|0;g=Hz(e,c[f>>2]|0,2,a+1160|0,0)|0;if((g|0)<0){yDb(a,16,1945200,(j=i,i=i+8|0,c[j>>2]=c[f>>2],j)|0);i=j;i=b;return g|0}f=c[d+44>>2]|0;if((f|0)==4){Kz(c[e>>2]|0,1923632,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;i=b;return g|0}else if((f|0)==2){f=d+184|0;if((c[f>>2]|0)==0){i=b;return g|0}Kz(c[e>>2]|0,1943696,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;Kz(c[e>>2]|0,1936568,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;Kz(c[e>>2]|0,1932080,(j=i,i=i+8|0,c[j>>2]=c[c[f>>2]>>2],j)|0)|0;i=j;Kz(c[e>>2]|0,1930264,(j=i,i=i+8|0,c[j>>2]=(c[d+32>>2]&1|0)!=0?1928544:1926792,j)|0)|0;i=j;d=c[f>>2]|0;if((d|0)==0){k=0.0}else{l=0.0;f=d;while(1){m=+h[f+16>>3]- +h[f+8>>3];n=l>m?l:m;d=c[f+44>>2]|0;if((d|0)==0){k=n;break}else{l=n;f=d}}}l=+aa(k);f=(E=+l,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Kz(c[e>>2]|0,1925184,(j=i,i=i+16|0,c[j>>2]=~~+l>>>0,c[j+8>>2]=f,j)|0)|0;i=j;i=b;return g|0}else{i=b;return g|0}return 0}function oQ(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0.0;g=i;i=i+8|0;j=g|0;switch(d|0){case 4:{d=e+40|0;if((BAb(j,c[d>>2]|0,0,0,1)|0)<0){yDb(f,24,1958064,(k=i,i=i+8|0,c[k>>2]=c[d>>2],k)|0);i=k;i=g;return}else{Kz(b,1955656,(k=i,i=i+8|0,c[k>>2]=c[j>>2],k)|0)|0;i=k;ZDb(c[j>>2]|0);i=g;return}break};case 2:{j=c[e+40>>2]|0;Kz(b,196e4,(k=i,i=i+16|0,h[k>>3]=+h[e+16>>3]- +h[e+8>>3],c[k+8>>2]=j,k)|0)|0;i=k;i=g;return};case 0:{Kz(b,1972568,(k=i,i=i+8|0,c[k>>2]=c[e+40>>2],k)|0)|0;i=k;i=g;return};case 1:case 3:{j=c[e+40>>2]|0;d=(a[j+(hc(j|0,1947256)|0)|0]|0)!=0;if(d){Py(b,34);l=j}else{l=j}while(1){j=a[l]|0;if((j<<24>>24|0)==0){break}else if((j<<24>>24|0)==34){Py(b,34);m=a[l]|0}else{m=j}Py(b,m<<24>>24);l=l+1|0}if(d){Py(b,34)}n=+h[e+16>>3];Kz(b,1964584,(k=i,i=i+16|0,h[k>>3]=+h[e+8>>3],h[k+8>>3]=n,k)|0)|0;i=k;i=g;return};default:{yDb(0,0,1953424,(k=i,i=i+24|0,c[k>>2]=1951312,c[k+8>>2]=1949128,c[k+16>>2]=286,k)|0);i=k;Cd()}}}function pQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[a+12>>2]|0;d=tN()|0;c[b+20>>2]=d;if((d|0)==0){e=-12;return e|0}f=d+8|0;c[f>>2]=c[b+16>>2];b=a+1160|0;g=d+1160|0;h=c[b+4>>2]|0;c[g>>2]=c[b>>2];c[g+4>>2]=h;EBb(d+1140|0,c[a+1140>>2]|0,0);h=a+24|0;if((c[h>>2]|0)==0){e=0;return e|0}g=a+28|0;a=0;while(1){b=LT(d,0)|0;if((b|0)==0){e=-12;i=11;break}j=c[(c[(c[g>>2]|0)+(a<<2)>>2]|0)+8>>2]|0;k=c[b+8>>2]|0;BRa(k,j)|0;l=c[(c[f>>2]|0)+32>>2]|0;m=j+52|0;do{if((l|0)==0){i=8}else{n=zT(l,c[m>>2]|0)|0;if((n|0)==(c[k+48>>2]|0)){i=8;break}if((xT(c[(c[f>>2]|0)+32>>2]|0,c[j+48>>2]|0)|0)==0){i=8;break}c[k+52>>2]=0}}while(0);if((i|0)==8){i=0;c[k+52>>2]=c[m>>2]}j=(c[(c[g>>2]|0)+(a<<2)>>2]|0)+80|0;l=b+80|0;n=c[j+4>>2]|0;c[l>>2]=c[j>>2];c[l+4>>2]=n;n=a+1|0;if(n>>>0<(c[h>>2]|0)>>>0){a=n}else{e=0;i=11;break}}if((i|0)==11){return e|0}return 0}function qQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+12>>2]|0;e=c[d+20>>2]|0;f=c[d+8>>2]|0;g=d+4|0;h=c[g>>2]|0;if((f|0)==0){j=h}else{k=(h|0)%(f|0)|0;c[g>>2]=k;j=k}k=e+32|0;g=a+32|0;if((XS(k,1024,g,j)|0)<0){yDb(e,16,1901808,(l=i,i=i+8|0,c[l>>2]=g,l)|0);i=l;m=-22;i=b;return m|0}g=(SGb(AAb(k)|0)|0)+1|0;e=d+40|0;j=c[e>>2]|0;if((j|0)==0){n=g}else{n=(SGb(j|0)|0)+g|0}g=cEb(n)|0;c[d+176>>2]=g;if((g|0)==0){m=-12;i=b;return m|0}d=c[e>>2]|0;e=AAb(k)|0;Lb(g|0,n|0,1900760,(l=i,i=i+16|0,c[l>>2]=(d|0)==0?9203016:d,c[l+8>>2]=e,l)|0)|0;i=l;m=0;i=b;return m|0}function rQ(a){a=a|0;var b=0,e=0,f=0,g=0;if((c[a+8>>2]|0)<806){b=0;return b|0}e=c[a+4>>2]|0;a=e;if(!((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==814)){b=0;return b|0}a=e+12|0;f=(d[a]|d[a+1|0]<<8)<<16>>16;a=e+14|0;g=(d[a]|d[a+1|0]<<8)<<16>>16;a=e+804|0;e=(d[a]|d[a+1|0]<<8)<<16>>16;do{if(f<<16>>16==0|(f&65535)>>>0>2048>>>0){if(e<<16>>16==22050){break}else{b=0}return b|0}else{if((g&65535)>>>0<2049>>>0&g<<16>>16!=0|e<<16>>16==22050){break}else{b=0}return b|0}}while(0);b=50;return b|0}function sQ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;e=i;i=i+40|0;f=e|0;g=e+8|0;h=e+24|0;j=e+32|0;k=c[b+12>>2]|0;l=c[b+16>>2]|0;Ty(l,0,0,0)|0;m=k+44|0;if((mz(l,m,816)|0)!=816){n=-5;i=e;return n|0}o=k+56|0;p=(d[o]|d[o+1|0]<<8)<<16>>16;o=p&65535;q=k+58|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;q=r&65535;do{if(p<<16>>16==0|r<<16>>16==0){s=0}else{do{if((a[k+68|0]|0)==105){if((a[k+69|0]|0)!=118){t=7;break}if((a[k+70|0]|0)!=51){t=7;break}c[k+24>>2]=1}else{t=7}}while(0);if((t|0)==7){c[k+24>>2]=0}u=LT(b,0)|0;if((u|0)==0){n=-12;i=e;return n|0}MT(u,33,1,10);c[k>>2]=c[u>>2];v=u+8|0;w=c[v>>2]|0;c[w+8>>2]=0;x=k+24|0;c[w+48>>2]=(c[x>>2]|0)!=0?29:53;c[w+52>>2]=0;y=w+120|0;c[y>>2]=o;z=w+124|0;c[z>>2]=q;if((c[x>>2]|0)!=0&(p&65535)>>>0>320>>>0){c[y>>2]=o>>>1;c[z>>2]=q>>>1}if((BT(w,816)|0)==0){UGb(c[(c[v>>2]|0)+96>>2]|0,m|0,816)|0;s=u;break}else{n=-12;i=e;return n|0}}}while(0);m=k+848|0;q=(d[m]|d[m+1|0]<<8)<<16>>16;m=k+28|0;c[m>>2]=q&65535;if(q<<16>>16==0){A=0}else{q=LT(b,0)|0;if((q|0)==0){n=-12;i=e;return n|0}c[k+4>>2]=c[q>>2];o=c[q+8>>2]|0;c[o+8>>2]=1;c[o+48>>2]=86027;c[o+52>>2]=0;p=o+416|0;if((a[k+855|0]|0)<0){c[p>>2]=2;r=o+448|0;c[r>>2]=3;c[r+4>>2]=0;B=2}else{c[p>>2]=1;r=o+448|0;c[r>>2]=4;c[r+4>>2]=0;B=1}r=c[m>>2]|0;m=o+412|0;c[m>>2]=r;u=k+850|0;v=(d[u]|d[u+1|0]<<8)<<16>>16&65535;u=o+432|0;c[u>>2]=v;w=o+792|0;if((v&32768|0)==0){c[w>>2]=8;C=8;D=v}else{c[w>>2]=16;w=65536-v|0;c[u>>2]=w;C=16;D=w}c[o+72>>2]=ba(ba(C,r)|0,B)|0;c[h>>2]=D;B=ba(c[p>>2]|0,c[m>>2]|0)|0;c[j>>2]=B;iFb(h,j,D,(D|0)<0|0?-1:0,B,(B|0)<0|0?-1:0,2147483647,0)|0;if((s|0)!=0){MT(s,33,c[h>>2]|0,c[j>>2]|0)}MT(q,33,c[h>>2]|0,c[j>>2]|0);A=q}q=k+856|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+50|0;h=k+8|0;c[h>>2]=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=k+62|0;s=k+12|0;c[s>>2]=(d[q]|d[q+1|0]<<8)<<16>>16&65535;Ty(l,j,0,0)|0;c[f>>2]=0;j=k+16|0;q=j;c[q>>2]=0;B=k+852|0;D=(d[B]|d[B+1|0]<<8)<<16>>16&65535;B=c[h>>2]|0;m=B*6|0;if(!((ba(c[s>>2]|0,B)|0)>>>0<(76695844-D|0)>>>0)){yDb(b,16,1976392,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;n=-1;i=e;return n|0}c[f>>2]=WDb(m)|0;B=WDb(((ba(c[s>>2]|0,c[h>>2]|0)|0)+D|0)*56|0)|0;c[q>>2]=B;p=c[f>>2]|0;a:do{if((p|0)==0|(B|0)==0){G=-12}else{if((mz(l,p,m)|0)!=(m|0)){G=-5;break}r=c[h>>2]|0;b:do{if((r|0)==0){H=0}else{C=g|0;o=g+2|0;w=(A|0)==0;u=k+4|0;v=D-1|0;z=v;y=(v|0)<0|0?-1:0;v=k;x=0;I=0;J=0;K=0;L=c[s>>2]|0;M=r;c:while(1){N=(c[f>>2]|0)+((x*6|0)+2)|0;O=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;N=0;if((L|0)==0){P=I;Q=J;R=K;S=0;T=M}else{U=x;V=(x|0)<0|0?-1:0;if(w){W=0;X=N;Y=O;Z=I;while(1){_=mz(l,C,16)|0;if((_|0)!=16){$=_;t=40;break c}_=a[C]|0;aa=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;if(aa>>>0>1073741823>>>0){t=42;break c}if((aa|0)!=0|_<<24>>24==1){if(_<<24>>24==2){_=c[q>>2]|0;ca=_+(Z*56|0)+8|0;c[ca>>2]=Y;c[ca+4>>2]=X;c[_+(Z*56|0)>>2]=c[v>>2];c[_+(Z*56|0)+16>>2]=aa;UGb(_+(Z*56|0)+36|0,C|0,16)|0;_=(c[q>>2]|0)+(Z*56|0)+24|0;c[_>>2]=U;c[_+4>>2]=V;da=Z+1|0}else{da=Z}_=YGb(aa,0,Y,X)|0;ea=da;fa=F;ga=_}else{ea=Z;fa=X;ga=Y}_=W+1|0;aa=c[s>>2]|0;if(_>>>0<aa>>>0){W=_;X=fa;Y=ga;Z=ea}else{ha=ea;ia=J;ja=K;ka=aa;break}}}else{Z=0;Y=N;X=O;W=I;aa=J;_=K;while(1){ca=mz(l,C,16)|0;if((ca|0)!=16){$=ca;t=40;break c}ca=a[C]|0;la=ca&255;ma=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;if(ma>>>0>1073741823>>>0){t=42;break c}if((ma|0)!=0|ca<<24>>24==1){if((la|0)==2){ca=c[q>>2]|0;na=ca+(W*56|0)+8|0;c[na>>2]=X;c[na+4>>2]=Y;c[ca+(W*56|0)>>2]=c[v>>2];c[ca+(W*56|0)+16>>2]=ma;UGb(ca+(W*56|0)+36|0,C|0,16)|0;ca=(c[q>>2]|0)+(W*56|0)+24|0;c[ca>>2]=U;c[ca+4>>2]=V;oa=aa;pa=_;qa=W+1|0}else if((la|0)==1){la=c[q>>2]|0;ca=la+(W*56|0)+8|0;c[ca>>2]=X;c[ca+4>>2]=Y;c[la+(W*56|0)>>2]=c[u>>2];c[la+(W*56|0)+16>>2]=ma;UGb(la+(W*56|0)+36|0,C|0,16)|0;la=(c[q>>2]|0)+(W*56|0)+24|0;c[la>>2]=_;c[la+4>>2]=aa;la=(_|0)==0&(aa|0)==0;ca=YGb(_,aa,1,0)|0;oa=la?y:F;pa=la?z:ca;qa=W+1|0}else{oa=aa;pa=_;qa=W}ca=YGb(ma,0,X,Y)|0;ra=oa;sa=pa;ta=qa;ua=F;va=ca}else{ra=aa;sa=_;ta=W;ua=Y;va=X}ca=Z+1|0;ma=c[s>>2]|0;if(ca>>>0<ma>>>0){Z=ca;Y=ua;X=va;W=ta;aa=ra;_=sa}else{ha=ta;ia=ra;ja=sa;ka=ma;break}}}P=ha;Q=ia;R=ja;S=ka;T=c[h>>2]|0}_=x+1|0;if(_>>>0<T>>>0){x=_;I=P;J=Q;K=R;L=S;M=T}else{H=P;break b}}if((t|0)==40){yDb(b,16,1947216,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;G=($|0)>-1?-1094995529:$;break a}else if((t|0)==42){yDb(b,16,1922064,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;G=-1094995529;break a}}}while(0);ZDb(c[f>>2]|0);c[k+20>>2]=0;c[h>>2]=H;n=0;i=e;return n|0}}while(0);$Db(f);$Db(j);n=G;i=e;return n|0}function tQ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=c[b+12>>2]|0;g=c[b+16>>2]|0;h=f+20|0;j=c[h>>2]|0;if(!(j>>>0<(c[f+8>>2]|0)>>>0)){k=-541478725;i=e;return k|0}l=c[f+16>>2]|0;m=l+(j*56|0)+8|0;Ty(g,c[m>>2]|0,c[m+4>>2]|0,0)|0;m=l+(j*56|0)+16|0;n=SS(g,c[m>>2]|0)|0;if((n|0)!=(c[m>>2]|0)){k=-5;i=e;return k|0}if((wZ(d,n+16|0)|0)!=0){k=-12;i=e;return k|0}n=Ty(g,0,0,1)|0;o=d+64|0;c[o>>2]=n;c[o+4>>2]=F;o=d+24|0;n=l+(j*56|0)+36|0;UGb(c[o>>2]|0,n|0,16)|0;do{if((c[f+24>>2]|0)==0){p=7}else{if((a[n]|0)!=2){p=7;break}q=mz(g,c[o>>2]|0,c[m>>2]|0)|0}}while(0);if((p|0)==7){q=mz(g,(c[o>>2]|0)+16|0,c[m>>2]|0)|0}if((q|0)==(c[m>>2]|0)){r=q}else{BZ(d);r=-5}c[d+32>>2]=c[l+(j*56|0)>>2];q=l+(j*56|0)+24|0;j=c[q>>2]|0;l=c[q+4>>2]|0;q=d+8|0;c[q>>2]=j;c[q+4>>2]=l;q=(c[m>>2]|0)+16|0;yDb(b,48,2127808,(b=i,i=i+32|0,c[b>>2]=(a[n]|0)==2?2065272:2018864,c[b+8>>2]=q,c[b+16>>2]=j,c[b+24>>2]=l,b)|0);i=b;c[h>>2]=(c[h>>2]|0)+1;k=r;i=e;return k|0}function uQ(a){a=a|0;$Db((c[a+12>>2]|0)+16|0);return 0}function vQ(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1179011411){e=0;return e|0}a=b+8|0;b=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((b|0)==1314213715|(b|0)==827736662)){e=0;return e|0}e=100;return e|0}function wQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+16>>2]|0;e=c[a+12>>2]|0;if((rz(d)|0)!=1179011411){f=-1094995529;i=b;return f|0}Vy(d,4,0)|0;g=rz(d)|0;do{if((g|0)==827736662){if((rz(d)|0)!=1145586262){yDb(a,16,1976328,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}if((vz(d)|0)!=32){yDb(a,16,1947160,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}if((pz(d)|0)!=1){yDb(a,16,1922032,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}j=pz(d)|0;k=pz(d)|0;Vy(d,4,0)|0;l=pz(d)|0;m=e;c[m>>2]=l;if((l|0)==0){yDb(a,16,1900704,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}l=e+12|0;c[l>>2]=pz(d)|0;n=pz(d)|0;o=e+8|0;c[o>>2]=n;c[e+16>>2]=ba(c[l>>2]>>3,n)|0;Vy(d,16,0)|0;n=LT(a,0)|0;if((n|0)==0){f=-12;i=b;return f|0}l=c[n+8>>2]|0;c[l+8>>2]=0;c[l+48>>2]=109;c[l+52>>2]=827736662;c[l+120>>2]=j;c[l+124>>2]=k;c[l+140>>2]=11;l=c[m>>2]|0;m=l;k=(l|0)<0|0?-1:0;l=n+56|0;c[l>>2]=m;c[l+4>>2]=k;l=n+64|0;c[l>>2]=m;c[l+4>>2]=k;MT(n,16,1,12);c[e+4>>2]=0;c[e+20>>2]=1;n=(c[o>>2]|0)!=0;c[e+24>>2]=n&1;c[e+28>>2]=-1;if(!n){break}n=LT(a,0)|0;if((n|0)==0){f=-12;i=b;return f|0}else{k=c[n+8>>2]|0;c[k+8>>2]=1;c[k+48>>2]=65541;c[k+416>>2]=1;l=k+448|0;c[l>>2]=4;c[l+4>>2]=0;c[k+792>>2]=8;c[k+412>>2]=c[o>>2];MT(n,16,1,c[o>>2]|0);o=n+48|0;c[o>>2]=0;c[o+4>>2]=0;break}}else if((g|0)==1314213715){if((rz(d)|0)!=1380206675){yDb(a,16,1976328,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}if((vz(d)|0)!=8){yDb(a,16,1947160,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}Vy(d,4,0)|0;o=e+8|0;c[o>>2]=pz(d)|0;n=pz(d)|0;c[e+12>>2]=n;c[e+16>>2]=ba(c[o>>2]|0,n>>3)|0;n=LT(a,0)|0;if((n|0)==0){f=-12;i=b;return f|0}else{k=c[n+8>>2]|0;c[k+8>>2]=1;c[k+48>>2]=65541;c[k+416>>2]=1;l=k+448|0;c[l>>2]=4;c[l+4>>2]=0;c[k+792>>2]=8;c[k+412>>2]=c[o>>2];MT(n,16,1,c[o>>2]|0);o=n+48|0;c[o>>2]=0;c[o+4>>2]=0;break}}else{yDb(a,16,2065208,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}}while(0);if((rz(d)|0)==1497648962){Vy(d,4,0)|0;f=0;i=b;return f|0}else{yDb(a,16,2018784,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}return 0}function xQ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[b+12>>2]|0;a:do{if((c[e+20>>2]|0)==0){f=TS(c[b+16>>2]|0,d,c[e+16>>2]|0)|0;if((f|0)==0){g=-541478725;return g|0}if((f|0)<0){g=-5;return g|0}else{c[d+48>>2]=f;break}}else{f=e+4|0;if((c[f>>2]|0)>=(c[e>>2]|0)){g=-541478725;return g|0}h=e+28|0;i=c[h>>2]|0;if((i|0)==-1){j=b+16|0;c[e+32>>2]=(rz(c[j>>2]|0)|0)-4;k=pz(c[j>>2]|0)|0;l=e+44|0;c[l>>2]=k;m=k&1;n=m<<2;c[e+36>>2]=n;if((m|0)==0){o=k}else{mz(c[j>>2]|0,e+48|0,n)|0;o=c[l>>2]|0}if((o&4|0)==0){p=0;q=o}else{n=rz(c[j>>2]|0)|0;p=n;q=c[l>>2]|0}c[e+40>>2]=p;l=q>>>2&1;c[h>>2]=l;r=l}else{r=i}do{if((r|0)==0){i=e+32|0;l=e+40|0;n=e+36|0;j=b+16|0;k=SS(c[j>>2]|0,(c[i>>2]|0)-2-(c[l>>2]|0)-(c[n>>2]|0)|0)|0;if((k|0)<0){g=-1094995529;return g|0}if((c[i>>2]|0)<(c[l>>2]|0)){g=-1094995529;return g|0}if((wZ(d,k+2+(c[n>>2]|0)|0)|0)<0){g=-12;return g|0}l=d+24|0;i=c[l>>2]|0;x=c[e+44>>2]&65535;a[i]=x;x=x>>8;a[i+1|0]=x;i=c[n>>2]|0;if((i|0)==0){s=2}else{UGb((c[l>>2]|0)+2|0,e+48|0,i)|0;s=(c[n>>2]|0)+2|0}if((mz(c[j>>2]|0,(c[l>>2]|0)+s|0,k)|0)==(k|0)){c[d+32>>2]=0;c[h>>2]=-1;break}BZ(d);g=-1094995529;return g|0}else{k=TS(c[b+16>>2]|0,d,(c[e+40>>2]|0)-4|0)|0;if((k|0)<0){g=-5;return g|0}else{c[d+32>>2]=1;c[d+48>>2]=k;c[h>>2]=0;if((c[f>>2]|0)==0){break}else{break a}}}}while(0);k=d+36|0;c[k>>2]=c[k>>2]|1;if(!((c[h>>2]|0)==-1)){break}c[f>>2]=(c[f>>2]|0)+1}}while(0);g=c[d+28>>2]|0;return g|0}function yQ(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((e|0)==843795795|(e|0)==877350227)){f=0;return f|0}e=b+4|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>0>32768>>>0){f=25;return f|0}else{f=b+8|0;return((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)>>>0>32768>>>0?25:100)|0}return 0}function zQ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0;e=i;i=i+8|0;f=e|0;g=c[b+16>>2]|0;h=c[b+12>>2]|0;j=rz(g)|0;k=h;c[k>>2]=j;if(!((j|0)==843795795|(j|0)==877350227)){l=-1094995529;i=e;return l|0}j=h+4|0;c[j>>2]=rz(g)|0;m=h+8|0;c[m>>2]=rz(g)|0;n=h+12|0;c[n>>2]=rz(g)|0;o=h+16|0;c[o>>2]=rz(g)|0;p=rz(g)|0;c[h+20>>2]=p;if((p&1|0)!=0){c[n>>2]=(c[n>>2]|0)+1}c[h+24>>2]=rz(g)|0;c[h+28>>2]=rz(g)|0;c[h+32>>2]=rz(g)|0;c[h+36>>2]=rz(g)|0;c[h+40>>2]=rz(g)|0;c[h+44>>2]=rz(g)|0;c[h+48>>2]=rz(g)|0;p=rz(g)|0;q=h+52|0;c[q>>2]=p;if(p>>>0>1073741822>>>0){yDb(b,16,2018760,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;l=-1094995529;i=e;return l|0}p=h+56|0;c[p>>2]=rz(g)|0;s=h+60|0;c[s>>2]=rz(g)|0;t=h+64|0;c[t>>2]=rz(g)|0;u=h+68|0;c[u>>2]=rz(g)|0;v=h+80|0;w=v;c[v>>2]=qz(g)|0;a[h+72|0]=lz(g)|0;c[h+84>>2]=qz(g)|0;a[h+73|0]=lz(g)|0;c[h+88>>2]=qz(g)|0;a[h+74|0]=lz(g)|0;c[h+92>>2]=qz(g)|0;a[h+75|0]=lz(g)|0;c[h+96>>2]=qz(g)|0;a[h+76|0]=lz(g)|0;c[h+100>>2]=qz(g)|0;a[h+77|0]=lz(g)|0;c[h+104>>2]=qz(g)|0;a[h+78|0]=lz(g)|0;c[h+108>>2]=rz(g)|0;v=c[n>>2]|0;if(v>>>0>16777215>>>0){yDb(b,16,1976304,(r=i,i=i+8|0,c[r>>2]=v,r)|0);i=r;l=-1094995529;i=e;return l|0}x=h+112|0;y=x;c[y>>2]=WDb(v<<2)|0;v=WDb(c[n>>2]|0)|0;z=h+116|0;A=z;c[A>>2]=v;if((c[y>>2]|0)==0|(v|0)==0){$Db(x);$Db(z);l=-12;i=e;return l|0}c[h+124>>2]=(c[k>>2]|0)!=843795795;do{if((c[n>>2]|0)!=0){v=0;do{B=rz(g)|0;c[(c[y>>2]|0)+(v<<2)>>2]=B;v=v+1|0;C=c[n>>2]|0;}while(v>>>0<C>>>0);if((C|0)==0){break}else{D=0}do{v=(lz(g)|0)&255;a[(c[A>>2]|0)+D|0]=v;D=D+1|0;}while(D>>>0<(c[n>>2]|0)>>>0)}}while(0);D=LT(b,0)|0;if((D|0)==0){l=-12;i=e;return l|0}c[h+932>>2]=c[D>>2];A=D+8|0;C=c[A>>2]|0;c[C+120>>2]=c[j>>2];c[C+124>>2]=c[m>>2];c[C+140>>2]=11;c[C+8>>2]=0;c[C+48>>2]=84;c[C+52>>2]=c[k>>2];k=c[o>>2]|0;if((k|0)<0){E=-k|0}else{E=k*100|0}c[o>>2]=E;c[f>>2]=1e5;E=c[o>>2]|0;iFb(f,o,1e5,0,E,(E|0)<0|0?-1:0,2147483647,0)|0;MT(D,33,c[o>>2]|0,c[f>>2]|0);f=D+56|0;c[f>>2]=c[n>>2];c[f+4>>2]=0;f=h+904|0;n=0;do{D=f+(n<<2)|0;c[D>>2]=-1;o=w+(n<<2)|0;if((c[o>>2]|0)!=0){E=LT(b,0)|0;if((E|0)==0){l=-12;G=40;break}c[D>>2]=c[E>>2];D=c[E+8>>2]|0;c[D+8>>2]=1;k=h+(n+72)|0;C=d[k]|0;do{if((C&8|0)==0){if((C&4|0)!=0){c[D+48>>2]=86065;H=86065;break}m=D+48|0;if((C&128|0)==0){c[m>>2]=65541;H=65541;break}else{c[m>>2]=86039;c[D+52>>2]=1095454035;H=86039;break}}else{c[D+48>>2]=86064;H=86064}}while(0);C=D+416|0;if((a[k]&16)==0){c[C>>2]=1;m=D+448|0;c[m>>2]=4;c[m+4>>2]=0;I=1}else{c[C>>2]=2;C=D+448|0;c[C>>2]=3;c[C+4>>2]=0;I=2}C=c[o>>2]|0;c[D+412>>2]=C;m=(a[k]&32)!=0;j=m?16:8;c[D+792>>2]=j;if(m&(H|0)==65541){c[D+48>>2]=65536}MT(E,64,1,(ba(ba(I,C)|0,j)|0)/8|0)}n=n+1|0;}while((n|0)<7);if((G|0)==40){i=e;return l|0}if((BT(c[A>>2]|0,(c[q>>2]|0)+16|0)|0)!=0){yDb(b,16,1947120,(r=i,i=i+8|0,c[r>>2]=(c[q>>2]|0)+16,r)|0);i=r;$Db(x);$Db(z);l=-12;i=e;return l|0}r=c[A>>2]|0;q=mz(g,(c[r+96>>2]|0)+16|0,(c[r+100>>2]|0)-16|0)|0;r=c[A>>2]|0;if((q|0)==((c[r+100>>2]|0)-16|0)){q=c[r+96>>2]|0;c[q>>2]=c[p>>2];c[q+4>>2]=c[s>>2];c[q+8>>2]=c[t>>2];c[q+12>>2]=c[u>>2];c[h+1020>>2]=-1;u=Ty(g,0,0,1)|0;g=h+1024|0;c[g>>2]=u;c[g+4>>2]=F;l=0;i=e;return l|0}else{$Db(x);$Db(z);l=-5;i=e;return l|0}return 0}function AQ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;f=i;i=i+768|0;g=f|0;h=c[b+12>>2]|0;j=b+16|0;if((Xy(c[j>>2]|0)|0)!=0){k=-541478725;i=f;return k|0}l=h+120|0;if(!((c[l>>2]|0)>>>0<(c[h+12>>2]|0)>>>0)){k=-541478725;i=f;return k|0}m=h+1020|0;n=c[m>>2]|0;if((n|0)>=0){o=h+992|0;if((c[o+(n<<2)>>2]|0)<0){k=-1094995529;i=f;return k|0}p=h+936|0;if((c[p+(n<<2)>>2]|0)==0){k=-1094995529;i=f;return k|0}q=h+964|0;if((wZ(e,c[q+(n<<2)>>2]|0)|0)!=0){k=-12;i=f;return k|0}n=e+24|0;r=c[m>>2]|0;UGb(c[n>>2]|0,c[p+(r<<2)>>2]|0,c[q+(r<<2)>>2]|0)|0;c[e+28>>2]=c[q+(c[m>>2]<<2)>>2];c[e+32>>2]=c[o+(c[m>>2]<<2)>>2];o=h+1032+(c[m>>2]<<3)|0;q=c[o+4>>2]|0;r=e+8|0;c[r>>2]=c[o>>2];c[r+4>>2]=q;q=c[n>>2]|0;n=YGb(c[o>>2]|0,c[o+4>>2]|0,d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0,0)|0;c[o>>2]=n;c[o+4>>2]=F;c[m>>2]=(c[m>>2]|0)-1;k=0;i=f;return k|0}o=h+1024|0;Ty(c[j>>2]|0,c[o>>2]|0,c[o+4>>2]|0,0)|0;n=c[l>>2]|0;q=h+112|0;r=c[(c[q>>2]|0)+(n<<2)>>2]&-4;p=d[(c[h+116>>2]|0)+n|0]|0;if((p&1|0)==0){s=0;t=r}else{n=h+136|0;UGb(g|0,n|0,768)|0;u=(lz(c[j>>2]|0)|0)<<2;if((u|0)>(r|0)){k=-1094995529;i=f;return k|0}v=r-1+(1-u)|0;r=Ty(c[j>>2]|0,0,0,1)|0;w=YGb(r,F,u-1|0,0)|0;u=0;r=n;n=c[j>>2]|0;a:while(1){x=lz(n)|0;do{if((x&128|0)==0){if((x&64|0)==0){a[r]=a[435728+x|0]|0;a[r+1|0]=a[435728+((lz(c[j>>2]|0)|0)&63)|0]|0;a[r+2|0]=a[435728+((lz(c[j>>2]|0)|0)&63)|0]|0;y=r+3|0;z=u+1|0;break}A=lz(c[j>>2]|0)|0;B=(x&63)+1|0;if((A+B|0)>256){C=12;break a}if((u|0)>=256){C=14;break a}D=(x|-64)^63;E=u-256|0;G=D>>>0>E>>>0?D:E;E=G*-3|0;D=u;H=A*3|0;I=B;J=r;while(1){K=I-1|0;a[J]=a[g+H|0]|0;a[J+1|0]=a[g+(H+1)|0]|0;a[J+2|0]=a[g+(H+2)|0]|0;L=D+1|0;if((K|0)!=0&(L|0)<256){D=L;H=H+3|0;I=K;J=J+3|0}else{break}}y=r+E|0;z=u-G|0}else{J=(x&127)+1|0;y=r+(J*3|0)|0;z=J+u|0}}while(0);x=c[j>>2]|0;if((z|0)<256){u=z;r=y;n=x}else{M=x;break}}if((C|0)==12){yDb(b,16,2127688,(N=i,i=i+16|0,c[N>>2]=A,c[N+8>>2]=B,N)|0);i=N;k=-1094995529;i=f;return k|0}else if((C|0)==14){M=c[j>>2]|0}B=w;Ty(M,B,(B|0)<0|0?-1:0,0)|0;s=1;t=v}c[m>>2]=-1;v=h+936|0;B=h+964|0;M=h+904|0;w=h+992|0;A=t;t=0;n=p>>>1;while(1){if((n&1|0)==0){O=A}else{p=rz(c[j>>2]|0)|0;y=p-4|0;if((y|0)==0|p>>>0>A>>>0){C=23;break}r=(c[m>>2]|0)+1|0;c[m>>2]=r;P=_Db(v+(r<<2)|0,y)|0;Q=B+(c[m>>2]<<2)|0;if((P|0)<0){C=25;break}c[Q>>2]=y;if((mz(c[j>>2]|0,c[v+(c[m>>2]<<2)>>2]|0,y)|0)!=(y|0)){k=-5;C=39;break}c[w+(c[m>>2]<<2)>>2]=c[M+(t<<2)>>2];O=A-4+(4-p)|0}p=t+1|0;if((p|0)<7){A=O;t=p;n=n>>1}else{C=29;break}}if((C|0)==23){yDb(b,16,2065176,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;k=-1094995529;i=f;return k|0}else if((C|0)==25){c[Q>>2]=0;k=P;i=f;return k|0}else if((C|0)==29){if(O>>>0>1073741822>>>0){k=-1094995529;i=f;return k|0}P=O+769|0;if((wZ(e,P)|0)!=0){k=-12;i=f;return k|0}if((c[(c[q>>2]|0)+(c[l>>2]<<2)>>2]&1|0)==0){R=s&255}else{R=(s|2)&255}s=e+24|0;a[c[s>>2]|0]=R;UGb((c[s>>2]|0)+1|0,h+136|0,768)|0;if((mz(c[j>>2]|0,(c[s>>2]|0)+769|0,O)|0)!=(O|0)){k=-5;i=f;return k|0}c[e+32>>2]=c[h+932>>2];h=c[l>>2]|0;O=e+8|0;c[O>>2]=h;c[O+4>>2]=(h|0)<0|0?-1:0;c[e+28>>2]=P;c[l>>2]=(c[l>>2]|0)+1;l=Ty(c[j>>2]|0,0,0,1)|0;c[o>>2]=l;c[o+4>>2]=F;k=0;i=f;return k|0}else if((C|0)==39){i=f;return k|0}return 0}function BQ(a){a=a|0;var b=0;b=c[a+12>>2]|0;$Db(b+936|0);$Db(b+940|0);$Db(b+944|0);$Db(b+948|0);$Db(b+952|0);$Db(b+956|0);$Db(b+960|0);$Db(b+112|0);$Db(b+116|0);return 0}function CQ(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,2338632,8)|0)==0;return(b?100:0)|0}function DQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+8|0;e=d|0;f=c[b+12>>2]|0;g=c[b+16>>2]|0;Vy(g,8,0)|0;h=vz(g)|0;if((h|0)!=0){DDb(b,2018728,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j}h=vz(g)|0;if((Xy(g)|0)!=0){k=-541478725;i=d;return k|0}l=b+1140|0;m=h;h=0;n=f;o=f+4|0;f=0;p=0;a:while(1){q=p;b:while(1){while(1){r=rz(g)|0;if((r|0)==1145980232){k=0;s=24;break a}else if((r|0)==1145983839){break}else if((r|0)==1145656927){break b}else if((r|0)!=1415074911){s=23;break a}t=vz(g)|0;if((t|0)==0|t>>>0>512>>>0){k=-1094995529;s=24;break a}u=WDb(t+1|0)|0;c[e>>2]=u;if((u|0)==0){k=-12;s=24;break a}if((mz(g,u,t)|0)!=(t|0)){s=11;break a}a[u+t|0]=0;CBb(l,1947104,u,8)|0;if((Xy(g)|0)!=0){k=-541478725;s=24;break a}}if((q|0)!=0){s=14;break a}u=vz(g)|0;if(u>>>0<8>>>0){k=-1094995529;s=24;break a}t=LT(b,0)|0;if((t|0)==0){k=-12;s=24;break a}v=t+8|0;c[(c[v>>2]|0)+8>>2]=1;w=tz(g)|0;c[(c[v>>2]|0)+412>>2]=w;w=lz(g)|0;c[(c[v>>2]|0)+792>>2]=w;w=lz(g)|0;c[(c[v>>2]|0)+416>>2]=w;w=rz(g)|0;c[(c[v>>2]|0)+52>>2]=w;x=vT(1238680,w)|0;c[(c[v>>2]|0)+48>>2]=x;x=t+56|0;c[x>>2]=m;c[x+4>>2]=h;c[n>>2]=c[t>>2];MT(t,32,1,1e3);Vy(g,u-8|0,0)|0;if((Xy(g)|0)==0){q=t}else{k=-541478725;s=24;break a}}if((f|0)!=0){s=19;break}t=vz(g)|0;if(t>>>0<12>>>0){k=-1094995529;s=24;break}u=LT(b,0)|0;if((u|0)==0){k=-12;s=24;break}x=u+64|0;c[x>>2]=vz(g)|0;c[x+4>>2]=0;x=u+8|0;c[(c[x>>2]|0)+8>>2]=0;v=tz(g)|0;c[(c[x>>2]|0)+120>>2]=v;v=tz(g)|0;c[(c[x>>2]|0)+124>>2]=v;v=rz(g)|0;c[(c[x>>2]|0)+52>>2]=v;w=vT(1238664,v)|0;c[(c[x>>2]|0)+48>>2]=w;w=u+56|0;c[w>>2]=m;c[w+4>>2]=h;c[o>>2]=c[u>>2];MT(u,32,1,1e3);Vy(g,t-12|0,0)|0;if((Xy(g)|0)==0){f=u;p=q}else{k=-541478725;s=24;break}}if((s|0)==11){$Db(e);yDb(b,16,1976264,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=d;return k|0}else if((s|0)==14){DDb(b,1921984,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1163346256;i=d;return k|0}else if((s|0)==19){DDb(b,1900664,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=d;return k|0}else if((s|0)==23){yDb(b,16,1880632,(j=i,i=i+8|0,c[j>>2]=r,j)|0);i=j;k=-1094995529;i=d;return k|0}else if((s|0)==24){i=d;return k|0}return 0}function EQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a+12>>2]|0;f=a+16|0;if((Xy(c[f>>2]|0)|0)!=0){g=-541478725;i=d;return g|0}h=Ty(c[f>>2]|0,0,0,1)|0;j=F;k=rz(c[f>>2]|0)|0;if((k|0)==1147431286){l=vz(c[f>>2]|0)|0;m=vz(c[f>>2]|0)|0;n=TS(c[f>>2]|0,b,m)|0;c[b+32>>2]=c[e+4>>2];m=b+8|0;c[m>>2]=l;c[m+4>>2]=0;m=b+64|0;c[m>>2]=h;c[m+4>>2]=j;g=n;i=d;return g|0}else if((k|0)==1162760004){g=-541478725;i=d;return g|0}else if((k|0)==1147432563){n=vz(c[f>>2]|0)|0;m=vz(c[f>>2]|0)|0;l=TS(c[f>>2]|0,b,m)|0;c[b+32>>2]=c[e>>2];e=b+8|0;c[e>>2]=n;c[e+4>>2]=0;e=b+64|0;c[e>>2]=h;c[e+4>>2]=j;g=l;i=d;return g|0}else{yDb(a,16,2065096,(a=i,i=i+8|0,c[a>>2]=k,a)|0);i=a;g=-1094995529;i=d;return g|0}return 0}function FQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+16>>2]|0;e=a+24|0;if((c[e>>2]|0)>>>0>2>>>0){yDb(a,16,2127632,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}Ry(d,2065080,8);Zy(d,0);Zy(d,0);h=a+1140|0;j=BBb(c[h>>2]|0,9203224,0,2)|0;if((j|0)!=0){k=j;do{Yy(d,1415074911);j=k|0;l=SGb(c[j>>2]|0)|0;m=k+4|0;Zy(d,l+3+(SGb(c[m>>2]|0)|0)|0);l=c[j>>2]|0;Ry(d,l,SGb(l|0)|0);Ry(d,1976256,3);l=c[m>>2]|0;Ry(d,l,SGb(l|0)|0);k=BBb(c[h>>2]|0,9203224,k,2)|0;}while((k|0)!=0)}a:do{if((c[e>>2]|0)!=0){k=a+28|0;h=0;while(1){l=c[(c[k>>2]|0)+(h<<2)>>2]|0;m=c[l+8>>2]|0;j=c[m+8>>2]|0;if((j|0)==0){n=uT(1238664,c[m+48>>2]|0)|0;if((n|0)==0){o=12;break}Yy(d,1145656927);Zy(d,12);Zy(d,0);fz(d,c[m+120>>2]|0);fz(d,c[m+124>>2]|0);Yy(d,n);MT(l,32,1,1e3)}else if((j|0)==1){j=uT(1238680,c[m+48>>2]|0)|0;if((j|0)==0){o=9;break}Yy(d,1145983839);Zy(d,8);fz(d,c[m+412>>2]|0);Py(d,c[m+792>>2]|0);Py(d,c[m+416>>2]|0);Yy(d,j);MT(l,32,1,1e3)}h=h+1|0;if(!(h>>>0<(c[e>>2]|0)>>>0)){break a}}if((o|0)==9){yDb(a,16,1947072,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else if((o|0)==12){yDb(a,16,1921952,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}}}while(0);Yy(d,1145980232);Sy(d);g=0;i=b;return g|0}function GQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=c[(c[(c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0)+8>>2]|0)+8>>2]|0;if((f|0)==1){Yy(e,1147432563)}else if((f|0)==0){Yy(e,1147431286)}else{return 0}f=b+8|0;Zy(e,c[f>>2]|0);a=b+28|0;Zy(e,c[a>>2]|0);Ry(e,c[b+24>>2]|0,c[a>>2]|0);a=d;d=c[a>>2]|0;e=0;g=c[b+48>>2]|0;b=YGb(g,(g|0)<0|0?-1:0,c[f>>2]|0,c[f+4>>2]|0)|0;f=F;c[a>>2]=(e|0)>(f|0)|(e|0)==(f|0)&d>>>0>b>>>0?d:b;return 0}function HQ(a){a=a|0;var b=0,d=0,e=0;b=c[a+16>>2]|0;if((c[b+88>>2]|0)==0){Yy(b,1162760004);return 0}d=c[a+12>>2]|0;a=Ty(b,0,0,1)|0;e=F;Ty(b,12,0,0)|0;Zy(b,c[d>>2]|0);Ty(b,a,e,0)|0;Yy(b,1162760004);return 0}function IQ(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;b=i;i=i+40|0;e=b|0;f=b+8|0;g=b+16|0;h=b+24|0;j=c[a+12>>2]|0;k=a+32|0;a:do{if((gb(k|0,511)|0)<0){yDb(a,16,2195608,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-(c[(ld()|0)>>2]|0)|0;n=41}else{o=UC(2180480,0,0)|0;if((o|0)==0){p=-1481985528;break}q=a+24|0;r=cEb((c[q>>2]|0)*33880|0)|0;s=r;t=j+24|0;c[t>>2]=s;if((r|0)==0){p=-12;break}b:do{if((c[q>>2]|0)==0){u=j+28|0}else{r=a+28|0;v=a+1160|0;w=h|0;x=j+12|0;y=j+28|0;z=j+32|0;A=0;B=s;c:while(1){C=B+(A*33880|0)|0;c[g>>2]=0;D=c[(c[(c[(c[r>>2]|0)+(A<<2)>>2]|0)+8>>2]|0)+72>>2]|0;if((D|0)==0){n=9;break}E=B+(A*33880|0)+8|0;Lb(E|0,1024,2160456,(l=i,i=i+16|0,c[l>>2]=k,c[l+8>>2]=D,l)|0)|0;i=l;if((gb(E|0,511)|0)<0){n=11;break}E=tN()|0;if((E|0)==0){p=-12;break a}D=C|0;c[D>>2]=E;c[E+8>>2]=o;F=E+1160|0;G=c[v+4>>2]|0;c[F>>2]=c[v>>2];c[F+4>>2]=G;G=LT(E,0)|0;if((G|0)==0){p=-12;break a}F=G+8|0;BRa(c[F>>2]|0,c[(c[(c[r>>2]|0)+(A<<2)>>2]|0)+8>>2]|0)|0;H=(c[(c[r>>2]|0)+(A<<2)>>2]|0)+80|0;I=G+80|0;J=c[H+4>>2]|0;c[I>>2]=c[H>>2];c[I+4>>2]=J;J=Oy(B+(A*33880|0)+1032|0,32768,2,C,0,84,598)|0;C=E+16|0;c[C>>2]=J;if((J|0)==0){p=-12;break a}Lb(w|0,10,2153664,(l=i,i=i+8|0,c[l>>2]=c[x>>2],l)|0)|0;i=l;CBb(g,2146488,w,0)|0;CBb(g,2140408,2133984,0)|0;J=FK(E,g)|0;if((J|0)<0){p=J;break a}c[B+(A*33880|0)+4>>2]=1;Sy(c[C>>2]|0);DBb(g);C=G+40|0;G=(c[(c[r>>2]|0)+(A<<2)>>2]|0)+40|0;J=c[C+4>>2]|0;c[G>>2]=c[C>>2];c[G+4>>2]=J;do{if((c[(c[F>>2]|0)+8>>2]|0)==0){c[y>>2]=1;c[B+(A*33880|0)+33844>>2]=2127912;J=c[(c[F>>2]|0)+48>>2]|0;if((J|0)==28){c[B+(A*33880|0)+33864>>2]=2121784;break}else if((J|0)==71){c[B+(A*33880|0)+33864>>2]=2116784;break}else{n=20;break c}}else{c[z>>2]=1;c[B+(A*33880|0)+33844>>2]=2094840;J=c[(c[F>>2]|0)+48>>2]|0;if((J|0)==86018){c[B+(A*33880|0)+33864>>2]=2089472;c[B+(A*33880|0)+33876>>2]=255}else if((J|0)==86054){c[B+(A*33880|0)+33864>>2]=2084672;c[B+(A*33880|0)+33876>>2]=354}else{n=24;break c}J=c[(c[F>>2]|0)+432>>2]|0;c[B+(A*33880|0)+33872>>2]=(J|0)==0?4:J}}while(0);F=c[(c[c[(c[D>>2]|0)+28>>2]>>2]|0)+8>>2]|0;J=F+96|0;G=c[J>>2]|0;c[e>>2]=G;c[f>>2]=c[F+100>>2];do{if((c[F+48>>2]|0)==28){dX(G,e,f)|0;if((c[e>>2]|0)!=0){n=30;break}C=c[J>>2]|0;c[e>>2]=C;K=C;n=29}else{K=G;n=29}}while(0);if((n|0)==29){n=0;if((K|0)!=0){n=30}}do{if((n|0)==30){n=0;G=cEb(c[f>>2]<<1|1)|0;F=B+(A*33880|0)+33868|0;c[F>>2]=G;do{if((c[f>>2]|0)>0){Lb(G|0,3,2069792,(l=i,i=i+8|0,c[l>>2]=d[c[e>>2]|0]|0,l)|0)|0;i=l;if((c[f>>2]|0)>1){L=1}else{break}do{Lb((c[F>>2]|0)+(L<<1)|0,3,2069792,(l=i,i=i+8|0,c[l>>2]=d[(c[e>>2]|0)+L|0]|0,l)|0)|0;i=l;L=L+1|0;}while((L|0)<(c[f>>2]|0))}}while(0);F=c[e>>2]|0;if((F|0)==(c[J>>2]|0)){break}ZDb(F)}}while(0);J=A+1|0;if(!(J>>>0<(c[q>>2]|0)>>>0)){u=y;break b}A=J;B=c[t>>2]|0}if((n|0)==9){yDb(a,16,2167584,(l=i,i=i+8|0,c[l>>2]=A,l)|0);i=l;p=-22;break a}else if((n|0)==11){B=-(c[(ld()|0)>>2]|0)|0;yDb(a,16,2195608,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=B;n=41;break a}else if((n|0)==20){yDb(a,16,2103824,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;p=-22;break a}else if((n|0)==24){yDb(a,16,2079400,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;p=-22;break a}}}while(0);do{if((c[u>>2]|0)==0){if((c[j+16>>2]|0)>=1){break}yDb(a,24,2074528,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}}while(0);m=NQ(a,0)|0;n=41}}while(0);do{if((n|0)==41){if((m|0)==0){M=0}else{p=m;break}i=b;return M|0}}while(0);MQ(a);M=p;i=b;return M|0}function JQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=c[b+32>>2]|0;h=c[(c[a+28>>2]|0)+(g<<2)>>2]|0;j=c[f+24>>2]|0;k=f+36|0;l=c[k>>2]|0;m=YGb(l,(l|0)<0|0?-1:0,1,0)|0;l=c[f+16>>2]|0;n=gHb(m,F,l,(l|0)<0|0?-1:0)|0;l=F;m=h+200|0;o=c[m>>2]|0;p=c[m+4>>2]|0;if((o|0)==0&(p|0)==(-2147483648|0)){q=b+16|0;r=c[q>>2]|0;s=c[q+4>>2]|0;c[m>>2]=r;c[m+4>>2]=s;t=s;u=r}else{t=p;u=o}if((c[f+28>>2]|0)==0){v=5}else{if((c[(c[h+8>>2]|0)+8>>2]|0)==0){v=5}}do{if((v|0)==5){f=b+16|0;o=ZGb(c[f>>2]|0,c[f+4>>2]|0,u,t)|0;c[e>>2]=1;c[e+4>>2]=1e6;if(!((LDb(o,F,h+40|0,n,l,e)|0)>-1)){break}if((c[b+36>>2]&1|0)==0){break}if((c[j+(g*33880|0)+33840>>2]|0)==0){break}o=LQ(a,0)|0;if((o|0)<0){w=o;i=d;return w|0}else{c[k>>2]=(c[k>>2]|0)+1;break}}}while(0);k=j+(g*33880|0)+33840|0;c[k>>2]=(c[k>>2]|0)+1;w=OK(c[j+(g*33880|0)>>2]|0,0,b,a)|0;i=d;return w|0}function KQ(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+1024|0;d=c[a+12>>2]|0;LQ(a,1)|0;if((c[d+20>>2]|0)==0){MQ(a);i=b;return 0}d=b|0;e=a+32|0;Lb(d|0,1024,2127608,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;Zd(d|0)|0;_c(e|0)|0;MQ(a);i=b;return 0}



function LQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;d=i;i=i+11304|0;e=d|0;f=d+8|0;g=d+8208|0;h=c[a+12>>2]|0;j=a+24|0;a:do{if((c[j>>2]|0)==0){k=0}else{l=h+24|0;m=d+8232|0;n=a+1160|0;o=d+8216|0;p=d+10280|0;q=d+9256|0;r=d+16|0;s=0;t=0;u=0;v=0;w=0;x=0;b:while(1){y=c[l>>2]|0;z=y+(x*33880|0)+33816|0;A=c[z>>2]|0;B=c[z+4>>2]|0;C=y+(x*33880|0)+33840|0;c:do{if((c[C>>2]|0)==0){D=w;E=u;G=v;H=s;I=t}else{J=y+(x*33880|0)+8|0;Lb(m|0,1024,2065064,(K=i,i=i+8|0,c[K>>2]=J,K)|0)|0;i=K;L=y+(x*33880|0)+33800|0;M=Dy(L,m,2,n,0)|0;if((M|0)<0){k=M;break a}M=c[z+4>>2]|0;N=y+(x*33880|0)+33832|0;c[N>>2]=c[z>>2];c[N+4>>2]=M;M=y+(x*33880|0)|0;GK(c[M>>2]|0,0)|0;Sy(c[(c[M>>2]|0)+16>>2]|0);c[C>>2]=0;M=c[L>>2]|0;if((M|0)==0){O=-5;P=54;break b}if((c[y+(x*33880|0)+33808>>2]|0)!=0){O=-5;P=54;break b}Ey(M)|0;c[L>>2]=0;L=ZGb(c[z>>2]|0,c[z+4>>2]|0,A,B)|0;M=F;N=Hz(g,m,1,n,0)|0;if((N|0)<0){k=N;break a}N=vz(c[g>>2]|0)|0;Q=N;R=0;d:do{if(N>>>0<8>>>0|((R|0)>(M|0)|(R|0)==(M|0)&Q>>>0>L>>>0)){S=-5;T=u;U=v;V=s;W=t}else{if((rz(c[g>>2]|0)|0)!=1718579053){S=-5;T=u;U=v;V=s;W=t;break}X=vz(c[g>>2]|0)|0;if(X>>>0>N>>>0){S=-5;T=u;U=v;V=s;W=t;break}if((rz(c[g>>2]|0)|0)!=1684563565){S=-5;T=u;U=v;V=s;W=t;break}Ty(c[g>>2]|0,X-8|0,0,1)|0;vz(c[g>>2]|0)|0;if((rz(c[g>>2]|0)|0)!=1717662324){S=-5;T=u;U=v;V=s;W=t;break}X=Ty(c[g>>2]|0,0,0,1)|0;Y=F;if(!((Y|0)<(R|0)|(Y|0)==(R|0)&X>>>0<Q>>>0)){S=-5;T=u;U=v;V=s;W=t;break}while(1){X=vz(c[g>>2]|0)|0;Y=rz(c[g>>2]|0)|0;Z=Ty(c[g>>2]|0,0,0,1)|0;_=F;$=YGb(X,0,-8,-1)|0;aa=YGb($,F,Z,_)|0;_=F;if(!(X>>>0>7>>>0&X>>>0<N>>>0)){S=-5;T=u;U=v;V=s;W=t;break d}if((Y|0)==1684632949){mz(c[g>>2]|0,o,16)|0;if((PGb(o,592664,16)|0)==0&X>>>0>43>>>0){break}}Ty(c[g>>2]|0,aa,_,0)|0;_=Ty(c[g>>2]|0,0,0,1)|0;aa=F;if(!((aa|0)<(R|0)|(aa|0)==(R|0)&_>>>0<Q>>>0)){S=-5;T=u;U=v;V=s;W=t;break d}}Ty(c[g>>2]|0,4,0,1)|0;_=Az(c[g>>2]|0)|0;aa=F;X=Az(c[g>>2]|0)|0;S=0;T=F;U=X;V=aa;W=_}}while(0);Iz(c[g>>2]|0)|0;if((S|0)<0){k=S;break a}_=y+(x*33880|0)+33844|0;aa=c[_>>2]|0;Lb(p|0,1024,2018696,(K=i,i=i+32|0,c[K>>2]=J,c[K+8>>2]=aa,c[K+16>>2]=W,c[K+24>>2]=V,K)|0)|0;i=K;aa=c[_>>2]|0;Lb(q|0,1024,1976232,(K=i,i=i+32|0,c[K>>2]=J,c[K+8>>2]=aa,c[K+16>>2]=W,c[K+24>>2]=V,K)|0)|0;i=K;do{if((Hz(e,m,1,n,0)|0)>=0){if((Hz(f,p,2,n,0)|0)<0){Iz(c[e>>2]|0)|0;break}e:do{if((N|0)!=0){aa=R;_=Q;do{X=0;Y=mz(c[e>>2]|0,r,(aa|0)>(X|0)|(aa|0)==(X|0)&_>>>0>8192>>>0?8192:_)|0;if((Y|0)<1){break e}Ry(c[f>>2]|0,r,Y);_=ZGb(_,aa,Y,(Y|0)<0|0?-1:0)|0;aa=F;Y=0;}while((aa|0)>(Y|0)|(aa|0)==(Y|0)&_>>>0>0>>>0)}}while(0);Sy(c[f>>2]|0);Iz(c[f>>2]|0)|0;Iz(c[e>>2]|0)|0}}while(0);Bc(m|0,q|0)|0;Q=y+(x*33880|0)+33848|0;R=y+(x*33880|0)+33852|0;N=c[R>>2]|0;do{if((c[Q>>2]|0)>=(N|0)){K=(N<<1)+2|0;c[R>>2]=K;if((_Db(y+(x*33880|0)+33860|0,K<<2)|0)>=0){break}c[R>>2]=0;c[Q>>2]=0;D=S;E=T;G=U;H=V;I=W;break c}}while(0);R=cEb(2088)|0;if((R|0)==0){D=S;E=T;G=U;H=V;I=W;break}sAb(R,q,1024)|0;sAb(R+1024|0,p,1024)|0;N=R+2048|0;c[N>>2]=W;c[N+4>>2]=V;N=R+2056|0;c[N>>2]=U;c[N+4>>2]=T;N=R+2072|0;c[N>>2]=A;c[N+4>>2]=B;N=R+2080|0;c[N>>2]=L;c[N+4>>2]=M;N=y+(x*33880|0)+33856|0;K=c[N>>2]|0;c[R+2064>>2]=K;J=c[Q>>2]|0;c[Q>>2]=J+1;c[(c[y+(x*33880|0)+33860>>2]|0)+(J<<2)>>2]=R;c[N>>2]=K+1;D=S;E=T;G=U;H=V;I=W}}while(0);y=x+1|0;if(y>>>0<(c[j>>2]|0)>>>0){s=H;t=I;u=E;v=G;w=D;x=y}else{k=D;break a}}if((P|0)==54){i=d;return O|0}}}while(0);D=h+4|0;G=c[D>>2]|0;do{if((G|0)==0){if((b|0)==0){break}if((c[h+20>>2]|0)!=0){P=36}}else{P=36}}while(0);f:do{if((P|0)==36){if((c[j>>2]|0)==0){break}E=h+24|0;I=h+8|0;H=h+12|0;W=h+20|0;if((b|0)==0){V=0;U=G;while(1){T=c[E>>2]|0;S=T+(V*33880|0)+33848|0;e=(c[S>>2]|0)-U-(c[I>>2]|0)-(c[H>>2]|0)|0;if((e|0)>0){f=T+(V*33880|0)+33860|0;T=0;do{Zd(c[(c[f>>2]|0)+(T<<2)>>2]|0)|0;Zd((c[(c[f>>2]|0)+(T<<2)>>2]|0)+1024|0)|0;ZDb(c[(c[f>>2]|0)+(T<<2)>>2]|0);T=T+1|0;}while((T|0)<(e|0));T=(c[S>>2]|0)-e|0;c[S>>2]=T;g=c[f>>2]|0;VGb(g|0,g+(e<<2)|0,T<<2|0)|0}T=V+1|0;if(!(T>>>0<(c[j>>2]|0)>>>0)){break f}V=T;U=c[D>>2]|0}}else{ba=0;ca=G}while(1){U=c[E>>2]|0;V=U+(ba*33880|0)+33848|0;T=c[V>>2]|0;g=c[W>>2]|0;x=(g|0)==0?T-ca-(c[I>>2]|0)-(c[H>>2]|0)|0:T;if((x|0)>0){T=U+(ba*33880|0)+33860|0;w=0;do{Zd(c[(c[T>>2]|0)+(w<<2)>>2]|0)|0;Zd((c[(c[T>>2]|0)+(w<<2)>>2]|0)+1024|0)|0;ZDb(c[(c[T>>2]|0)+(w<<2)>>2]|0);w=w+1|0;}while((w|0)<(x|0));w=(c[V>>2]|0)-x|0;c[V>>2]=w;e=c[T>>2]|0;VGb(e|0,e+(x<<2)|0,w<<2|0)|0;da=c[W>>2]|0}else{da=g}if((da|0)!=0){_c(U+(ba*33880|0)+8|0)|0}w=ba+1|0;if(!(w>>>0<(c[j>>2]|0)>>>0)){break f}ba=w;ca=c[D>>2]|0}}}while(0);if(!((k|0)>-1)){O=k;i=d;return O|0}O=NQ(a,b)|0;i=d;return O|0}function MQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(c[a+12>>2]|0)+24|0;d=b;e=c[d>>2]|0;if((e|0)==0){return}f=a+24|0;a:do{if((c[f>>2]|0)!=0){a=0;g=e;while(1){h=g+(a*33880|0)+33800|0;Ey(c[h>>2]|0)|0;i=g+(a*33880|0)+33804|0;Ey(c[i>>2]|0)|0;j=g+(a*33880|0)+33808|0;Ey(c[j>>2]|0)|0;c[j>>2]=0;c[i>>2]=0;c[h>>2]=0;h=g+(a*33880|0)|0;i=c[h>>2]|0;do{if((i|0)!=0){if((c[g+(a*33880|0)+4>>2]|0)==0){k=i}else{NK(i)|0;j=c[h>>2]|0;if((j|0)==0){break}else{k=j}}j=c[k+16>>2]|0;if((j|0)==0){l=k}else{ZDb(j);l=c[h>>2]|0}if((l|0)==0){break}bT(l)}}while(0);ZDb(c[g+(a*33880|0)+33868>>2]|0);h=g+(a*33880|0)+33848|0;i=g+(a*33880|0)+33860|0;j=c[i>>2]|0;if((c[h>>2]|0)>0){m=0;n=j;while(1){ZDb(c[n+(m<<2)>>2]|0);o=m+1|0;p=c[i>>2]|0;if((o|0)<(c[h>>2]|0)){m=o;n=p}else{q=p;break}}}else{q=j}ZDb(q);n=a+1|0;if(!(n>>>0<(c[f>>2]|0)>>>0)){break a}a=n;g=c[d>>2]|0}}}while(0);$Db(b);return}function NQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;i=i+2056|0;e=d|0;f=c[a+12>>2]|0;g=d+8|0;h=a+32|0;Lb(g|0,1024,2127608,(j=i,i=i+8|0,c[j>>2]=h,j)|0)|0;i=j;k=d+1032|0;Lb(k|0,1024,1947056,(j=i,i=i+8|0,c[j>>2]=h,j)|0)|0;i=j;h=Hz(e,k,2,a+1160|0,0)|0;if((h|0)<0){yDb(a,16,1921920,(j=i,i=i+8|0,c[j>>2]=k,j)|0);i=j;l=h;i=d;return l|0}Kz(c[e>>2]|0,1900624,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;h=a+24|0;m=c[h>>2]|0;if((m|0)==0){n=0;o=0;p=0;q=0;r=0;s=0}else{t=c[f+24>>2]|0;u=c[a+28>>2]|0;v=0;w=0;x=0;y=0;z=0;A=0;B=0;while(1){C=c[t+(B*33880|0)+33848>>2]|0;if((C|0)>0){D=c[(c[t+(B*33880|0)+33860>>2]|0)+(C-1<<2)>>2]|0;E=D+2048|0;G=D+2056|0;D=YGb(c[G>>2]|0,c[G+4>>2]|0,c[E>>2]|0,c[E+4>>2]|0)|0;H=F;I=D}else{H=x;I=y}if((c[(c[(c[u+(B<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==0){J=C;K=z;L=w;M=v+1|0}else{J=A;K=C;L=w+1|0;M=v}C=B+1|0;if(C>>>0<m>>>0){v=M;w=L;x=H;y=I;z=K;A=J;B=C}else{n=M;o=L;p=H;q=I;r=K;s=J;break}}}J=(b|0)!=0;K=J?r:0;r=J?s:0;s=f+4|0;I=c[s>>2]|0;if((I|0)==0){N=r;O=K}else{N=(r|0)>(I|0)?I:r;O=(K|0)>(I|0)?I:K}Kz(c[e>>2]|0,1880560,(j=i,i=i+16|0,c[j>>2]=J?q:0,c[j+8>>2]=J?p:0,j)|0)|0;i=j;if(!J){Kz(c[e>>2]|0,2338568,(j=i,i=i+8|0,c[j>>2]=c[f+12>>2],j)|0)|0;i=j}Kz(c[e>>2]|0,2314392,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;if((c[f+28>>2]|0)!=0){Kz(c[e>>2]|0,2293704,(j=i,i=i+16|0,c[j>>2]=n,c[j+8>>2]=N,j)|0)|0;i=j;N=c[h>>2]|0;n=f+24|0;J=c[n>>2]|0;if((N|0)==0){P=-1;Q=J}else{p=a+28|0;q=-1;K=0;I=0;r=J;J=N;while(1){N=c[(c[(c[p>>2]|0)+(I<<2)>>2]|0)+8>>2]|0;if((c[N+8>>2]|0)==0){H=c[N+72>>2]|0;L=c[r+(I*33880|0)+33864>>2]|0;M=c[N+120>>2]|0;B=c[N+124>>2]|0;N=c[r+(I*33880|0)+33868>>2]|0;Kz(c[e>>2]|0,2277128,(j=i,i=i+48|0,c[j>>2]=K,c[j+8>>2]=H,c[j+16>>2]=L,c[j+24>>2]=M,c[j+32>>2]=B,c[j+40>>2]=N,j)|0)|0;i=j;R=K+1|0;S=I;T=c[h>>2]|0;U=c[n>>2]|0}else{R=K;S=q;T=J;U=r}N=I+1|0;if(N>>>0<T>>>0){q=S;K=R;I=N;r=U;J=T}else{P=S;Q=U;break}}}OQ(Q+(P*33880|0)|0,c[e>>2]|0,b,c[f+12>>2]|0,c[s>>2]|0);Kz(c[e>>2]|0,2261712,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}if((c[f+32>>2]|0)!=0){Kz(c[e>>2]|0,2247032,(j=i,i=i+16|0,c[j>>2]=o,c[j+8>>2]=O,j)|0)|0;i=j;O=c[h>>2]|0;o=f+24|0;P=c[o>>2]|0;if((O|0)==0){V=-1;W=P}else{Q=a+28|0;a=0;U=-1;S=0;T=P;P=O;while(1){O=c[(c[(c[Q>>2]|0)+(a<<2)>>2]|0)+8>>2]|0;if((c[O+8>>2]|0)==1){J=c[O+72>>2]|0;r=c[T+(a*33880|0)+33864>>2]|0;I=c[O+412>>2]|0;R=c[O+416>>2]|0;O=c[T+(a*33880|0)+33872>>2]|0;K=c[T+(a*33880|0)+33876>>2]|0;q=c[T+(a*33880|0)+33868>>2]|0;Kz(c[e>>2]|0,2234176,(j=i,i=i+64|0,c[j>>2]=S,c[j+8>>2]=J,c[j+16>>2]=r,c[j+24>>2]=I,c[j+32>>2]=R,c[j+40>>2]=O,c[j+48>>2]=K,c[j+56>>2]=q,j)|0)|0;i=j;X=S+1|0;Y=a;Z=c[h>>2]|0;_=c[o>>2]|0}else{X=S;Y=U;Z=P;_=T}q=a+1|0;if(q>>>0<Z>>>0){a=q;U=Y;S=X;T=_;P=Z}else{V=Y;W=_;break}}}OQ(W+(V*33880|0)|0,c[e>>2]|0,b,c[f+12>>2]|0,c[s>>2]|0);Kz(c[e>>2]|0,2261712,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}Kz(c[e>>2]|0,2221056,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;Sy(c[e>>2]|0);Iz(c[e>>2]|0)|0;Bc(k|0,g|0)|0;l=0;i=d;return l|0}function OQ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=a+33848|0;j=c[h>>2]|0;if((j|0)<1){i=g;return}k=a+33860|0;a=c[k>>2]|0;l=(d|0)!=0;d=l?0:e;e=j-d|0;if((f|0)==0){m=0}else{j=e-f|0;m=(j|0)>0?j:0}if((m|0)>=(e|0)){i=g;return}if(l&(c[(c[a>>2]|0)+2064>>2]|0)<1){l=m;e=a;while(1){j=c[e+(l<<2)>>2]|0;f=j+2056|0;n=c[f>>2]|0;o=c[f+4>>2]|0;Kz(b,2202720,(p=i,i=i+24|0,c[p>>2]=c[j+2064>>2],c[p+8>>2]=n,c[p+16>>2]=o,p)|0)|0;i=p;o=l+1|0;if((o|0)>=((c[h>>2]|0)-d|0)){break}l=o;e=c[k>>2]|0}i=g;return}else{e=m;m=a;while(1){a=c[m+(e<<2)>>2]|0;l=a+2048|0;o=c[l+4>>2]|0;n=a+2056|0;a=c[n>>2]|0;j=c[n+4>>2]|0;Kz(b,2211880,(p=i,i=i+32|0,c[p>>2]=c[l>>2],c[p+8>>2]=o,c[p+16>>2]=a,c[p+24>>2]=j,p)|0)|0;i=p;j=e+1|0;if((j|0)>=((c[h>>2]|0)-d|0)){break}e=j;m=c[k>>2]|0}i=g;return}}function PQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=c[a+33800>>2]|0;if((e|0)!=0){Hy(e,b,d)|0}e=c[a+33804>>2]|0;if((e|0)!=0){Hy(e,b,d)|0}b=a+33824|0;e=YGb(c[b>>2]|0,c[b+4>>2]|0,d,(d|0)<0|0?-1:0)|0;f=F;c[b>>2]=e;c[b+4>>2]=f;b=a+33816|0;a=c[b+4>>2]|0;if((f|0)<(a|0)|(f|0)==(a|0)&e>>>0<(c[b>>2]|0)>>>0){return d|0}c[b>>2]=e;c[b+4>>2]=f;return d|0}function QQ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+8|0;g=f|0;if((e|0)!=0){h=-1;j=-38;i=f;return(F=h,j)|0}e=a+33808|0;if((c[e>>2]|0)!=0){k=a+33800|0;l=c[k>>2]|0;if((l|0)!=0){Ey(l)|0}l=a+33804|0;m=c[l>>2]|0;if((m|0)!=0){Ey(m)|0}c[k>>2]=c[e>>2];c[l>>2]=0;c[e>>2]=0}l=a+33832|0;k=c[l>>2]|0;m=c[l+4>>2]|0;if(!((m|0)>(d|0)|(m|0)==(d|0)&k>>>0>b>>>0)){l=c[a+33800>>2]|0;if((l|0)!=0){n=ZGb(b,d,k,m)|0;Ay(l,n,F,0)|0;}n=a+33824|0;c[n>>2]=b;c[n+4>>2]=d;h=d;j=b;i=f;return(F=h,j)|0}n=c[a+33848>>2]|0;if((n|0)<=0){h=-1;j=-5;i=f;return(F=h,j)|0}l=c[a+33860>>2]|0;m=n;while(1){n=m-1|0;o=c[l+(n<<2)>>2]|0;p=o+2072|0;k=c[p>>2]|0;q=c[p+4>>2]|0;if(!((q|0)>(d|0)|(q|0)==(d|0)&k>>>0>b>>>0)){r=o+2080|0;s=YGb(c[r>>2]|0,c[r+4>>2]|0,k,q)|0;q=F;if((q|0)>(d|0)|(q|0)==(d|0)&s>>>0>b>>>0){break}}if((n|0)>0){m=n}else{h=-1;j=-5;t=22;break}}if((t|0)==22){i=f;return(F=h,j)|0}c[g>>2]=0;t=a+33800|0;c[e>>2]=c[t>>2];CBb(g,2065328,2061168,0)|0;m=a;l=Dy(t,o|0,3,(c[m>>2]|0)+1160|0,g)|0;DBb(g);if((l|0)<0){c[t>>2]=c[e>>2];c[e>>2]=0;h=(l|0)<0|0?-1:0;j=l;i=f;return(F=h,j)|0}CBb(g,2065328,2061168,0)|0;l=a+33804|0;Dy(l,o+1024|0,3,(c[m>>2]|0)+1160|0,g)|0;DBb(g);g=c[t>>2]|0;t=ZGb(b,d,c[p>>2]|0,c[p+4>>2]|0)|0;Ay(g,t,F,0)|0;t=c[l>>2]|0;if((t|0)!=0){l=ZGb(b,d,c[p>>2]|0,c[p+4>>2]|0)|0;Ay(t,l,F,0)|0;}l=a+33824|0;c[l>>2]=b;c[l+4>>2]=d;h=d;j=b;i=f;return(F=h,j)|0}function RQ(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;do{if((e|0)==1296974163){a=b+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1380206675){f=100}else{break}return f|0}else if((e|0)==1296649793){a=b+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1380206657){f=100}else{break}return f|0}}while(0);f=0;return f|0}function SQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+1024|0;e=d|0;f=c[b+12>>2]|0;g=c[b+16>>2]|0;h=vz(g)|0;Vy(g,4,0)|0;if((h|0)==1095649613){if((vz(g)|0)!=1095255122){j=-1094995529;i=d;return j|0}k=vz(g)|0;if(k>>>0<774>>>0){j=-1094995529;i=d;return j|0}c[f>>2]=0;l=pz(g)|0;m=pz(g)|0;Vy(g,2,0)|0;n=0;do{c[e+(n<<2)>>2]=uz(g)|0;n=n+1|0;}while(n>>>0<256>>>0);Vy(g,k-774|0,0)|0;o=m;p=0;q=0;r=0;s=0;t=0;u=l&65535}else if((h|0)==1396788813){if((vz(g)|0)!=1397245010){j=-1094995529;i=d;return j|0}h=vz(g)|0;if(h>>>0<14>>>0){j=-1094995529;i=d;return j|0}c[f>>2]=1;l=pz(g)|0;m=rz(g)|0;Vy(g,2,0)|0;k=pz(g)|0;n=pz(g)|0;Vy(g,2,0)|0;Vy(g,h-14|0,0)|0;if((vz(g)|0)!=1179404356){j=-1094995529;i=d;return j|0}h=vz(g)|0;v=0;while(1){w=v+8|0;if(!(w>>>0<h>>>0)){y=v;z=0;A=0;B=0;break}if((Xy(g)|0)!=0){j=-541478725;C=26;break}D=vz(g)|0;E=vz(g)|0;if((D|0)==1466005093){C=15;break}else if(!((D|0)==1114386742|(D|0)==1095650895)){j=-1094995529;C=26;break}Vy(g,E,0)|0;v=E+w|0}if((C|0)==15){v=rz(g)|0;D=rz(g)|0;Vy(g,E-8|0,0)|0;y=E+w|0;z=1;A=v;B=D}else if((C|0)==26){i=d;return j|0}Vy(g,h-y|0,0)|0;o=m;p=B;q=A;r=z;s=n;t=k;u=l&65535}else{yDb(b,16,2127320,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=-1094995529;i=d;return j|0}l=LT(b,0)|0;if((l|0)==0){j=-12;i=d;return j|0}c[f+8>>2]=c[l>>2];k=l+48|0;c[k>>2]=0;c[k+4>>2]=0;k=o;o=0;n=l+64|0;c[n>>2]=k;c[n+4>>2]=o;n=l+56|0;c[n>>2]=k;c[n+4>>2]=o;o=l+8|0;n=c[o>>2]|0;c[n+8>>2]=0;c[n+48>>2]=1396788813;c[n+52>>2]=0;c[n+120>>2]=t;c[n+124>>2]=s;MT(l,64,66667,1e6);if((c[f>>2]|0)==0){if((BT(c[o>>2]|0,1026)|0)!=0){j=-12;i=d;return j|0}l=c[(c[o>>2]|0)+96>>2]|0;x=u;a[l]=x;x=x>>8;a[l+1|0]=x;l=0;do{u=(c[(c[o>>2]|0)+96>>2]|0)+(l<<2|2)|0;x=c[e+(l<<2)>>2]|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;l=l+1|0;}while(l>>>0<256>>>0)}if((r|0)==0){j=0;i=d;return j|0}r=LT(b,0)|0;if((r|0)==0){j=-12;i=d;return j|0}c[f+4>>2]=c[r>>2];f=r+48|0;c[f>>2]=0;c[f+4>>2]=0;f=c[r+8>>2]|0;c[f+8>>2]=1;c[f+48>>2]=1447644481;c[f+52>>2]=0;c[f+412>>2]=q;c[f+416>>2]=p;MT(r,64,1,q);j=0;i=d;return j|0}function TQ(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[a+12>>2]|0;f=c[a+16>>2]|0;a=e;g=e+8|0;h=b+32|0;i=b+48|0;j=e+4|0;e=b+36|0;k=b+24|0;while(1){if((Xy(f)|0)!=0){l=-541478725;m=14;break}n=vz(f)|0;o=vz(f)|0;if((n|0)==1179798853){if((c[a>>2]|0)==0){m=6;break}else{continue}}else if((n|0)==1466005093){m=10;break}else if((n|0)==1114386742){m=8;break}else{Vy(f,o,0)|0;continue}}if((m|0)==6){if((TS(f,b,o)|0)<0){l=-5;return l|0}c[h>>2]=c[g>>2];l=0;return l|0}else if((m|0)==8){if((TS(f,b,o)|0)<0){l=-5;return l|0}c[h>>2]=c[g>>2];c[i>>2]=1;l=0;return l|0}else if((m|0)==10){if(o>>>0<13>>>0){l=-1094995529;return l|0}if((TS(f,b,o)|0)<13){l=-5;return l|0}c[h>>2]=c[j>>2];c[e>>2]=c[e>>2]|1;e=c[k>>2]|0;k=e;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[i>>2]=fe(j|0)|0;if(!((j|0)==-1)){l=0;return l|0}j=e+8|0;c[i>>2]=fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;l=0;return l|0}else if((m|0)==14){return l|0}return 0}function UQ(b){b=b|0;var e=0,f=0,g=0;e=c[b+4>>2]|0;b=e;f=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24)&65535;do{if((f|0)==2957|(f|0)==3085|(f|0)==3213){if((a[e+2|0]|0)!=83){break}if((a[e+3|0]|0)!=79){break}if((a[e+4|0]|0)!=76){break}if((a[e+5|0]|0)==0){g=100}else{break}return g|0}}while(0);g=0;return g|0}function VQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a+16>>2]|0;d=pz(b)|0;if((rz(b)|0)!=5001043){e=-1;return e|0}f=pz(b)|0;g=lz(b)|0;Vy(b,4,0)|0;h=(d|0)==2957;do{if(h){i=g&1;j=i;k=(i|0)!=0?81923:65541;l=1}else{lz(b)|0;i=g&1;if((i|0)==0){m=(g&4|0)==0?65541:65536}else{m=81923}n=(g>>>4&1)+1|0;o=(m|0)!=81923;if(o|h){j=o&1^1;k=m;l=n;break}if((i|0)==0){j=-1;k=m;l=n;break}if((g&4|0)!=0){j=3;k=m;l=n;break}j=(d|0)==3213?1:2;k=m;l=n}}while(0);m=LT(a,0)|0;if((m|0)==0){e=-1;return e|0}a=c[m+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=j;c[a+48>>2]=k;c[a+416>>2]=l;k=(l|0)==1;l=a+448|0;c[l>>2]=k?4:3;c[l+4>>2]=k?0:0;c[a+412>>2]=f;MT(m,64,1,f);e=0;return e|0}function WQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+16|0;if((Xy(c[d>>2]|0)|0)!=0){e=-5;return e|0}a=TS(c[d>>2]|0,b,4096)|0;if((a|0)<0){e=a;return e|0}a=b+36|0;c[a>>2]=c[a>>2]&-3;c[b+32>>2]=0;e=0;return e|0}function XQ(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;if((a|0)==1483690798){return 100}else{return((a|0)==777219928?100:0)|0}return 0}function YQ(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0.0;d=i;i=i+8|0;e=d|0;f=c[b+16>>2]|0;g=LT(b,0)|0;if((g|0)==0){j=-12;i=d;return j|0}l=g+8|0;c[(c[l>>2]|0)+8>>2]=1;m=(rz(f)|0)==1483690798;n=(c[l>>2]|0)+48|0;if(m){c[n>>2]=65544;m=rz(f)|0;Vy(f,8,0)|0;o=sz(f)|0;p=F;q=rz(f)|0;c[(c[l>>2]|0)+416>>2]=q;r=m;s=p;t=o;u=rz(f)|0}else{c[n>>2]=65545;n=vz(f)|0;Vy(f,8,0)|0;o=Az(f)|0;p=F;m=vz(f)|0;c[(c[l>>2]|0)+416>>2]=m;r=n;s=p;t=o;u=vz(f)|0}v=(c[k>>2]=t,c[k+4>>2]=s,+h[k>>3]);if(u>>>0>4294967263>>>0){yDb(b,16,2127288,(w=i,i=i+8|0,c[w>>2]=u,w)|0);i=w;j=-1094995529;i=d;return j|0}if(v<=0.0|v>2147483647.0){yDb(b,16,2064808,(w=i,i=i+8|0,h[w>>3]=v,w)|0);i=w;j=-1094995529;i=d;return j|0}x=v- +P(v);if(x!=0.0){yDb(b,24,2018432,(w=i,i=i+8|0,h[w>>3]=x,w)|0);i=w}do{if((r+4&7|0)==0){if(r>>>0<(u+28|0)>>>0){break}if((c[(c[l>>2]|0)+416>>2]|0)>65535){break}do{if(!((u|0)==(-1|0)|(u|0)==0)){s=WDb(u+1|0)|0;c[e>>2]=s;if((s|0)==0){j=-12;i=d;return j|0}if((mz(f,s,u)|0)==(u|0)){a[s+u|0]=0;CBb(b+1140|0,1947016,s,8)|0;break}$Db(e);j=-5;i=d;return j|0}}while(0);Vy(f,-28-u+r|0,0)|0;s=~~v;t=c[l>>2]|0;c[t+412>>2]=s;c[t+792>>2]=32;o=c[t+416>>2]|0;c[t+72>>2]=ba(s<<5,o)|0;c[t+432>>2]=(o<<5|0)/8|0;MT(g,64,1,s);j=0;i=d;return j|0}}while(0);yDb(b,16,1976168,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;j=-1094995529;i=d;return j|0}function ZQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;g=BBb(c[a+1140>>2]|0,2127280,0,0)|0;if((g|0)==0){j=0}else{j=SGb(c[g+4>>2]|0)|0}l=j+7&-8;m=d;c[m>>2]=l+28;c[m+4>>2]=0;d=c[f+48>>2]|0;if((d|0)==65545){Yy(e,777219928);Zy(e,c[m>>2]|0);ez(e,0,0);h[k>>3]=+(c[f+412>>2]|0);ez(e,c[k>>2]|0,c[k+4>>2]|0);Zy(e,c[f+416>>2]|0);Zy(e,l)}else if((d|0)==65544){Yy(e,1483690798);Yy(e,c[m>>2]|0);dz(e,0,0);h[k>>3]=+(c[f+412>>2]|0);dz(e,c[k>>2]|0,c[k+4>>2]|0);Yy(e,c[f+416>>2]|0);Yy(e,l)}else{yDb(a,16,1976120,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;n=-1;i=b;return n|0}if((j|0)!=0){Ry(e,c[g+4>>2]|0,j)}Qy(e,0,l-j|0);Sy(e);n=0;i=b;return n|0}function _Q(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+16>>2]|0;if((c[b+88>>2]|0)==0){return 0}d=c[a+12>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;a=Ty(b,0,0,1)|0;f=F;g=d;d=c[g>>2]|0;h=c[g+4>>2]|0;g=YGb(a,f,-4,-1)|0;i=ZGb(g,F,d,h)|0;h=F;d=i>>>2|h<<30;i=h>>2|((h|0)<0|0?-1:0)<<30;Ty(b,8,0,0)|0;if((c[e+48>>2]|0)==65544){dz(b,d,i)}else{ez(b,d,i)}Ty(b,a,f,0)|0;Sy(b);return 0}function $Q(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+8|0;h=g|0;j=e-1|0;k=(j|0)<32768?j:32768;if((k|0)<=0){l=0;i=g;return l|0}m=b+e|0;e=b+j|0;j=b;n=b+k|0;k=b+7|0;b=0;o=0;p=0;a:while(1){q=d[j]|0|b;do{if((q|0)==1928863566){r=a[j+1|0]|0;if(!((r&255)>>>0<55>>>0)){s=p;t=o;u=k;v=n;w=j;break}x=o+1|0;if((j|0)==(k|0)){if((p|0)>0){l=100;y=15;break a}else{z=p+1|0}}else{z=0}if((j+11|0)>>>0>m>>>0){A=x;break a}B=j+16384|0;C=B>>>0>e>>>0?e:B;if((aR(0,(d[j+2|0]|0)<<8|r&255,j+5|0,h,f)|0)!=0){s=z;t=x;u=k;v=C;w=j;break}r=c[h>>2]|0;B=j+r|0;if(!(B>>>0<m>>>0)){A=x;break a}s=z;t=x;u=B;v=C;w=j+(r-7)|0}else{s=p;t=o;u=k;v=n;w=j}}while(0);r=w+1|0;if(!(r>>>0<v>>>0)){A=t;break}j=r;n=v;k=u;b=q<<8;o=t;p=s}if((y|0)==15){i=g;return l|0}if((A|0)==0){l=0;i=g;return l|0}l=(A|0)>5?50:12;i=g;return l|0}function aR(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+48|0;h=g|0;j=g+24|0;a:do{switch(b&255|0){case 6:{c[e>>2]=4608;c[f>>2]=86017;k=0;break};case 5:{c[e>>2]=1536;c[f>>2]=86017;k=0;break};case 9:{c[e>>2]=9216;c[f>>2]=86016;k=0;break};case 12:{c[e>>2]=4096;c[f>>2]=86020;k=0;break};case 13:{c[e>>2]=8192;c[f>>2]=86020;k=0;break};case 11:{c[e>>2]=2048;c[f>>2]=86020;k=0;break};case 8:{c[e>>2]=3072;c[f>>2]=86059;k=0;break};case 4:{c[e>>2]=1536;c[f>>2]=86059;k=0;break};case 10:{c[e>>2]=4608;c[f>>2]=86017;k=0;break};case 7:{l=(d|0)==0?0:56;c[j>>2]=d;c[j+12>>2]=l;c[j+16>>2]=l+8;c[j+4>>2]=d+(l>>>3);c[j+8>>2]=0;if((FX(j,h)|0)>=0){c[e>>2]=c[h+4>>2]<<2;c[f>>2]=86018;k=0;break a}if((a|0)==0){k=-1094995529;break a}yDb(a,16,2018392,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;k=-1094995529;break};case 1:{c[e>>2]=6144;c[f>>2]=86019;k=0;break};default:{if((a|0)==0){k=-1163346256;break a}DDb(a,1976088,(m=i,i=i+8|0,c[m>>2]=b,m)|0);i=m;k=-1163346256}}}while(0);i=g;return k|0}function bR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[a+16>>2]|0;h=0;while(1){if((h|0)==1928863566){break}j=lz(g)|0|h<<8;if((Xy(g)|0)==0){h=j}else{k=-541478725;l=20;break}}if((l|0)==20){i=d;return k|0}l=pz(g)|0;h=pz(g)|0;if((h&15|0)!=0){DDb(a,1898384,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}j=wZ(b,h+15>>3&-2)|0;if((j|0)!=0){k=j;i=d;return k|0}j=Ty(g,0,0,1)|0;h=YGb(j,F,-8,-1)|0;j=b+64|0;c[j>>2]=h;c[j+4>>2]=F;j=b+24|0;h=b+28|0;n=mz(g,c[j>>2]|0,c[h>>2]|0)|0;o=c[h>>2]|0;if((n|0)<(o|0)){BZ(b);k=-541478725;i=d;return k|0}n=c[j>>2]|0;EX(n,n,o>>1);o=aR(a,l,c[j>>2]|0,f,e)|0;if((o|0)!=0){BZ(b);k=o;i=d;return k|0}o=(c[f>>2]|0)-8-(c[h>>2]|0)|0;Vy(g,o,(o|0)<0|0?-1:0)|0;do{if((c[a+24>>2]|0)==0){o=LT(a,0)|0;if((o|0)!=0){g=c[o+8>>2]|0;c[g+8>>2]=1;c[g+48>>2]=c[e>>2];break}BZ(b);k=-12;i=d;return k|0}else{if((c[e>>2]|0)==(c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+48>>2]|0)){break}EDb(a,2211008,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;k=-1163346256;i=d;return k|0}}while(0);m=a+1072|0;if((c[m>>2]|0)!=0){k=0;i=d;return k|0}e=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+412>>2]|0;if((e|0)==0){k=0;i=d;return k|0}c[m>>2]=e<<5;k=0;i=d;return k|0}function cR(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=$Q(c[a+4>>2]|0,c[a+8>>2]|0,b|0)|0;i=b;return d|0}function dR(a){a=a|0;var b=0;b=a+20|0;c[b>>2]=c[b>>2]|1;return 0}function eR(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+12>>2]|0;a:do{switch(c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+48>>2]|0){case 86018:{c[d+72>>2]=506;break};case 86059:case 86016:case 86017:{c[d+72>>2]=496;break};case 86019:{c[d+72>>2]=404;break};case 86020:{c[d+72>>2]=70;break};case 86061:{c[d+72>>2]=498;e=WDb(61424)|0;c[d+40>>2]=e;if((e|0)==0){f=-12}else{break a}i=b;return f|0};case 86057:{c[d+72>>2]=190;break};default:{yDb(a,16,2018368,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1163346256;i=b;return f|0}}}while(0);f=0;i=b;return f|0}function fR(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[a+12>>2]|0;g=f+24|0;c[g>>2]=c[b+24>>2];h=b+28|0;j=f+28|0;c[j>>2]=c[h>>2];k=f+8|0;c[k>>2]=(c[h>>2]<<3)+8&-16;h=f+32|0;c[h>>2]=1;l=f+36|0;c[l>>2]=0;m=Oe[c[f+72>>2]&1023](a,b)|0;if((m|0)<0){n=m;i=e;return n|0}m=f+12|0;b=c[m>>2]|0;if((b|0)==0){n=0;i=e;return n|0}o=c[h>>2]|0;h=b-(o<<3)-(c[j>>2]|0)&-2;if((h|0)<0){yDb(a,16,2127248,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=-22;i=e;return n|0}do{if((o|0)==0){q=f+68|0}else{b=a+16|0;r=c[b>>2]|0;s=f+68|0;if((c[s>>2]&1|0)==0){az(r,63602)}else{fz(r,63602)}r=c[b>>2]|0;if((c[s>>2]&1|0)==0){az(r,19999)}else{fz(r,19999)}r=c[b>>2]|0;t=c[f+4>>2]|0;if((c[s>>2]&1|0)==0){az(r,t)}else{fz(r,t)}t=c[b>>2]|0;b=c[k>>2]|0;if((c[s>>2]&1|0)==0){az(t,b);q=s;break}else{fz(t,b);q=s;break}}}while(0);do{if((c[l>>2]|0)==(c[q>>2]&1|0)){k=f+16|0;o=k;kEb(k,f+20|0,(c[j>>2]|0)+16|0);k=c[o>>2]|0;if((k|0)==0){n=-12;i=e;return n|0}else{EX(k,c[g>>2]|0,c[j>>2]>>1);Ry(c[a+16>>2]|0,c[o>>2]|0,c[j>>2]&-2);break}}else{Ry(c[a+16>>2]|0,c[g>>2]|0,c[j>>2]&-2)}}while(0);l=c[j>>2]|0;o=a+16|0;do{if((l&1|0)!=0){k=c[o>>2]|0;s=(d[(c[g>>2]|0)+(l-1)|0]|0)<<8;if((c[q>>2]&1|0)==0){az(k,s);break}else{fz(k,s);break}}}while(0);Qy(c[o>>2]|0,0,h);h=c[j>>2]|0;j=c[m>>2]|0;yDb(a,48,2064736,(p=i,i=i+24|0,c[p>>2]=c[f+4>>2],c[p+8>>2]=h,c[p+16>>2]=j,p)|0);i=p;n=0;i=e;return n|0}function gR(a){a=a|0;var b=0;b=c[a+12>>2]|0;$Db(b+16|0);$Db(b+40|0);return 0}function hR(a,b){a=a|0;b=b|0;var e=0;e=c[a+12>>2]|0;c[e+4>>2]=(d[(c[b+24>>2]|0)+5|0]|0)<<8&1792|1;c[e+12>>2]=6144;return 0}function iR(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[a+12>>2]|0;a=b+24|0;f=d[(c[a>>2]|0)+4|0]|0;if((f&192|0)==192){g=1}else{g=d[431848+(f>>>4&3)|0]|0}f=e+40|0;h=e+52|0;i=b+28|0;b=jEb(c[f>>2]|0,e+44|0,(c[i>>2]|0)+(c[h>>2]|0)|0)|0;c[f>>2]=b;if((b|0)==0){j=-12;return j|0}UGb(b+(c[h>>2]|0)|0,c[a>>2]|0,c[i>>2]|0)|0;a=(c[h>>2]|0)+(c[i>>2]|0)|0;c[h>>2]=a;i=e+48|0;b=(c[i>>2]|0)+1|0;c[i>>2]=b;if((b|0)<(g|0)){c[e+12>>2]=0;j=0;return j|0}else{c[e+4>>2]=21;c[e+12>>2]=24576;c[e+24>>2]=c[f>>2];c[e+28>>2]=a;c[e+8>>2]=a;c[i>>2]=0;c[h>>2]=0;j=0;return j|0}return 0}function jR(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=c[b+12>>2]|0;j=c[f+24>>2]|0;f=d[j+1|0]|0;k=f>>>3;l=k&3;m=f>>>1&3;f=m^3;n=a[j+2|0]&1;j=b;if((m|0)==0|(l|0)==1){yDb(j,16,2234096,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=g;return p|0}yDb(j,48,2221e3,(o=i,i=i+24|0,c[o>>2]=l,c[o+8>>2]=f,c[o+16>>2]=n,o)|0);i=o;if((l|0)!=2|(n|0)==0){n=k&1;c[h+4>>2]=c[644984+(n*12|0)+(f<<2)>>2];c[h+12>>2]=e[431776+(n*6|0)+(f<<1)>>1]|0;p=0;i=g;return p|0}else{c[h+4>>2]=6;c[h+12>>2]=4608;p=0;i=g;return p|0}return 0}function kR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;f=i;g=c[b+12>>2]|0;h=e+24|0;j=c[h>>2]|0;k=j;l=fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0;k=e+28|0;if((c[k>>2]|0)<9){m=-1094995529;i=f;return m|0}if((l|0)==(-14745368|0)){e=(d[j+7|0]|0)>>>2&15|(d[j+4|0]|0)<<4&112;c[g+36>>2]=1;n=0;o=0;p=e}else if((l|0)==1683496997){yDb(b,16,1900568,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;m=-1094995529;i=f;return m|0}else if((l|0)==(-25230976|0)){e=j+4|0;r=((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>2&127;c[g+36>>2]=1;n=0;o=0;p=r}else if((l|0)==536864768){n=0;o=0;p=(d[j+6|0]|0)>>>2&15|(d[j+5|0]|0)<<4&112}else if((l|0)==2147385345){r=j+4|0;e=((de((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535)>>>2&127;n=(((d[j+6|0]|0)<<8|(d[j+5|0]|0)<<16|(d[j+7|0]|0))>>>4&16383)+1|0;o=c[1744272+(((d[j+8|0]|0)>>>2&15)<<2)>>2]|0;p=e}else{yDb(b,16,1880488,(q=i,i=i+8|0,c[q>>2]=l,q)|0);i=q;m=-1094995529;i=f;return m|0}l=p+1|0;e=c[g+60>>2]|0;if((e|0)==0){if((p|0)==31){c[g+4>>2]=12}else if((p|0)==63){c[g+4>>2]=13}else if((p|0)==15){c[g+4>>2]=11}else{yDb(b,16,2338480,(q=i,i=i+8|0,c[q>>2]=l<<5,q)|0);i=q;m=-38;i=f;return m|0}do{if((n|0)!=0){if((n|0)>=(c[k>>2]|0)){break}c[g+28>>2]=n;c[g+8>>2]=n<<3}}while(0);p=l<<7;c[g+12>>2]=p;j=c[g+28>>2]|0;if((j|0)==(p|0)){c[g+32>>2]=0;m=0;i=f;return m|0}if((j|0)<=(p-8|0)){m=0;i=f;return m|0}DDb(b,2314272,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;m=0;i=f;return m|0}p=c[k>>2]|0;if((n|0)==0){yDb(b,16,2293608,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;m=-22;i=f;return m|0}if((o|0)==0){yDb(b,16,2277064,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;m=-1094995529;i=f;return m|0}k=l<<5;l=(ba(e,k)|0)/(o|0)|0;if((l|0)==512){s=17}else if((l|0)==2048){s=529}else if((l|0)==8192){s=1041}else if((l|0)==4096){s=785}else if((l|0)==16384){s=1297}else if((l|0)==1024){s=273}else{yDb(b,16,2261488,(q=i,i=i+32|0,c[q>>2]=e,c[q+8>>2]=l,c[q+16>>2]=k,c[q+24>>2]=o,q)|0);i=q;m=-22;i=f;return m|0}e=l<<2;c[g+12>>2]=e;c[g+4>>2]=s;s=g+56|0;l=c[s>>2]|0;do{if((p+12|0)>>>0>(e-8|0)>>>0){if((l|0)==0){yDb(b,24,2246928,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}j=c[g+64>>2]|0;if((j|0)>0){r=(ba(j,o)|0)/(k|0)|0;c[s>>2]=r;t=r;u=27;break}else{c[s>>2]=1;v=1;w=j;u=29;break}}else{t=l;u=27}}while(0);do{if((u|0)==27){if((t|0)==0){y=p;break}v=t;w=c[g+64>>2]|0;u=29}}while(0);do{if((u|0)==29){if(!((w|0)>-1)){y=n;break}c[s>>2]=v-1;y=n}}while(0);n=y+12|0;c[g+28>>2]=n;c[g+8>>2]=(y+35&-16)-8;v=g+40|0;s=v;kEb(v,g+44|0,n);n=c[s>>2]|0;if((n|0)==0){m=-12;i=f;return m|0}c[g+24>>2]=n;UGb(n|0,431856,10)|0;n=de(y&65535|0)|0;g=(c[s>>2]|0)+10|0;x=n;a[g]=x;x=x>>8;a[g+1|0]=x;UGb((c[s>>2]|0)+12|0,c[h>>2]|0,y)|0;m=0;i=f;return m|0}function lR(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+48|0;f=e|0;g=e+24|0;h=c[a+12>>2]|0;j=c[b+24>>2]|0;b=(j|0)==0?0:56;c[g>>2]=j;c[g+12>>2]=b;c[g+16>>2]=b+8;c[g+4>>2]=j+(b>>>3);c[g+8>>2]=0;if((FX(g,f)|0)<0){yDb(a,16,1946992,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=e;return l|0}g=f+4|0;c[h+12>>2]=c[g>>2]<<2;b=d[f+16|0]|0;if((b|0)==2){c[h+4>>2]=19;l=0;i=e;return l|0}else if((b|0)==4){c[h+4>>2]=51;l=0;i=e;return l|0}else if((b|0)==1){c[h+4>>2]=7;l=0;i=e;return l|0}else{yDb(a,16,1921808,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0);i=k;l=-22;i=e;return l|0}return 0}function mR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=c[a+12>>2]|0;f=e+48|0;g=c[f>>2]|0;if((g|0)==0){UGb(c[e+40>>2]|0,431792,20)|0;h=28}else if((g|0)==12){UGb((c[e+40>>2]|0)+30708|0,431816,12)|0;h=8}else{h=0}g=b+28|0;j=c[g>>2]|0;k=2560-h|0;if((j|0)>(k|0)){DDb(a,1976048,(a=i,i=i+8|0,c[a>>2]=j,a)|0);i=a;l=-1163346256;i=d;return l|0}a=h-8|0;h=e+40|0;UGb((c[h>>2]|0)+(a+((c[f>>2]|0)*2560|0))|0,c[b+24>>2]|0,j)|0;j=c[g>>2]|0;TGb((c[h>>2]|0)+(a+((c[f>>2]|0)*2560|0)+j)|0,0,k-j|0)|0;j=(c[f>>2]|0)+1|0;c[f>>2]=j;if((j|0)<24){c[e+12>>2]=0;l=0;i=d;return l|0}else{UGb((c[h>>2]|0)+61408|0,431832,16)|0;c[f>>2]=0;c[e+4>>2]=22;c[e+12>>2]=61440;c[e+24>>2]=c[h>>2];c[e+28>>2]=61424;c[e+8>>2]=61424;l=0;i=d;return l|0}return 0}function nR(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+8|0;f=e|0;g=c[b+4>>2]|0;b=((d[g+1|0]|0)<<8|(d[g]|0)<<16|(d[g+2|0]|0)|0)==15711167?g+3|0:g;while(1){g=a[b]|0;if(!((g<<24>>24|0)==13|(g<<24>>24|0)==10)){break}b=b+1|0}g=xd(b|0,2018312,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((g|0)==1){j=100;i=e;return j|0}g=gd(b|0)|0;k=hc(b|0,2064728)|0;l=a[b+k|0]|0;if(l<<24>>24==13){m=k+1|0;n=m;o=a[b+m|0]|0}else{n=k;o=l}do{if(g>>>0<2>>>0){l=xd(b+((o<<24>>24==10)+n)|0,2018312,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((l|0)==1){j=100}else{break}i=e;return j|0}}while(0);j=0;i=e;return j|0}function oR(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=i;i=i+1120|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+1088|0;p=d+1096|0;q=d+1104|0;r=d+1112|0;s=c[b+12>>2]|0;t=LT(b,0)|0;if((t|0)==0){u=-12;i=d;return u|0}MT(t,64,1,1e3);v=c[t+8>>2]|0;c[v+8>>2]=3;c[v+48>>2]=1397909872;IAb(n,0,-1);v=b+16|0;b=n+4|0;t=n|0;w=s;s=0;a:while(1){do{if((Xy(c[v>>2]|0)|0)!=0){y=22;break a}DR(c[v>>2]|0,n);}while((c[b>>2]|0)==0);z=Ty(c[v>>2]|0,0,0,1)|0;A=F;B=c[t>>2]|0;c[o>>2]=-1;c[p>>2]=-1;c[q>>2]=-1;c[r>>2]=-1;C=xd(B|0,2127152,(D=i,i=i+96|0,c[D>>2]=e,c[D+8>>2]=f,c[D+16>>2]=g,c[D+24>>2]=h,c[D+32>>2]=j,c[D+40>>2]=k,c[D+48>>2]=l,c[D+56>>2]=m,c[D+64>>2]=o,c[D+72>>2]=q,c[D+80>>2]=p,c[D+88>>2]=r,D)|0)|0;i=D;do{if((C|0)>7){E=B;y=7}else{G=hc(B|0,2064728)|0;H=a[B+G|0]|0;if(H<<24>>24==13){I=G+1|0;J=I;K=a[B+I|0]|0}else{J=G;K=H}H=(K<<24>>24==10)+J|0;G=B+H|0;I=xd(G|0,2127152,(D=i,i=i+96|0,c[D>>2]=e,c[D+8>>2]=f,c[D+16>>2]=g,c[D+24>>2]=h,c[D+32>>2]=j,c[D+40>>2]=k,c[D+48>>2]=l,c[D+56>>2]=m,c[D+64>>2]=o,c[D+72>>2]=q,c[D+80>>2]=p,c[D+88>>2]=r,D)|0)|0;i=D;if((I|0)>7){E=G;y=7;break}I=hc(G|0,2064728)|0;G=a[B+(I+H)|0]|0;if(G<<24>>24==13){L=I+1|0;M=L;N=a[B+(L+H)|0]|0}else{M=I;N=G}O=-2147483648;P=0;Q=B+(M+H+(N<<24>>24==10))|0;R=s}}while(0);if((y|0)==7){y=0;B=c[e>>2]|0;D=gHb(B,(B|0)<0|0?-1:0,3600,0)|0;B=F;C=c[f>>2]|0;H=gHb(C,(C|0)<0|0?-1:0,60,0)|0;C=YGb(H,F,D,B)|0;B=c[g>>2]|0;D=YGb(C,F,B,(B|0)<0|0?-1:0)|0;B=gHb(D,F,1e3,0)|0;D=c[h>>2]|0;C=YGb(B,F,D,(D|0)<0|0?-1:0)|0;D=F;B=c[j>>2]|0;H=gHb(B,(B|0)<0|0?-1:0,3600,0)|0;B=F;G=c[k>>2]|0;I=gHb(G,(G|0)<0|0?-1:0,60,0)|0;G=YGb(I,F,H,B)|0;B=c[l>>2]|0;H=YGb(G,F,B,(B|0)<0|0?-1:0)|0;B=gHb(H,F,1e3,0)|0;H=F;G=ZGb(c[m>>2]|0,0,C,D)|0;I=YGb(G,F,B,H)|0;H=hc(E|0,2064728)|0;B=a[E+H|0]|0;if(B<<24>>24==13){G=H+1|0;S=G;T=a[E+G|0]|0}else{S=H;T=B}O=D;P=C;Q=E+((T<<24>>24==10)+S)|0;R=I}if((P|0)==0&(O|0)==(-2147483648|0)){s=R;continue}I=(c[t>>2]|0)-Q+(c[b>>2]|0)|0;if((I|0)<1){s=R;continue}C=uR(w,Q,I,0)|0;if((C|0)==0){U=-12;break}I=C+64|0;c[I>>2]=z;c[I+4>>2]=A;I=C+8|0;c[I>>2]=P;c[I+4>>2]=O;c[C+48>>2]=R;if((c[o>>2]|0)==-1){s=R;continue}I=GZ(C,73,16)|0;if((I|0)==0){s=R;continue}C=I;x=c[o>>2]|0;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=I+4|0;x=c[p>>2]|0;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=I+8|0;x=c[q>>2]|0;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=I+12|0;x=c[r>>2]|0;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;s=R}if((y|0)==22){vR(w);U=0}QAb(n,0)|0;u=U;i=d;return u|0}function pR(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function qR(a){a=a|0;AR(c[a+12>>2]|0);return 0}function rR(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function sR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+12>>2]|0;do{if((c[a+24>>2]|0)==1){e=c[c[a+28>>2]>>2]|0;f=c[e+8>>2]|0;if((c[f+8>>2]|0)!=3){break}g=c[f+48>>2]|0;if((g|0)==94210|(g|0)==1397909872|(g|0)==94216){MT(e,64,1,1e3);c[d>>2]=1;h=0;i=b;return h|0}else{e=H0a(g)|0;yDb(a,16,1880448,(j=i,i=i+8|0,c[j>>2]=e,j)|0);i=j;h=-22;i=b;return h|0}}}while(0);yDb(a,16,1900392,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-22;i=b;return h|0}function tR(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+8|0;f=e|0;g=c[a+12>>2]|0;h=(c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+48>>2]|0)!=94216;if(h){j=b+8|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=c[b+48>>2]|0;m=HZ(b,73,f)|0;n=(m|0)!=0;if(n&(c[f>>2]|0)==16){f=m;o=m+4|0;p=m+8|0;q=m+12|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;u=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0}else{r=-1;s=-1;t=-1;u=-1}if((j|0)<1){f=b+72|0;v=c[f+4>>2]|0;w=c[f>>2]|0}else{v=(j|0)<0|0?-1:0;w=j}j=0;if((k|0)==0&(l|0)==(-2147483648|0)|((v|0)<(j|0)|(v|0)==(j|0)&w>>>0<0>>>0)){yDb(a,24,2064680,(x=i,i=i+8|0,c[x>>2]=c[g>>2],x)|0);i=x;i=e;return 0}j=YGb(w,v,k,l)|0;v=F;w=a+16|0;f=c[w>>2]|0;o=c[g>>2]|0;p=eHb(k,l,36e5,0)|0;q=eHb(k,l,6e4,0)|0;m=eHb(k,l,1e3,0)|0;y=fHb(k,l,1e3,0)|0;l=eHb(j,v,36e5,0)|0;k=eHb(j,v,6e4,0)|0;z=eHb(j,v,1e3,0)|0;A=fHb(j,v,1e3,0)|0;Kz(f,2018264,(x=i,i=i+72|0,c[x>>2]=o,c[x+8>>2]=p,c[x+16>>2]=(q|0)%60|0,c[x+24>>2]=(m|0)%60|0,c[x+32>>2]=y,c[x+40>>2]=l,c[x+48>>2]=(k|0)%60|0,c[x+56>>2]=(z|0)%60|0,c[x+64>>2]=A,x)|0)|0;i=x;if(n){Kz(c[w>>2]|0,1975992,(x=i,i=i+32|0,c[x>>2]=u,c[x+8>>2]=s,c[x+16>>2]=t,c[x+24>>2]=r,x)|0)|0;i=x}Kz(c[w>>2]|0,1946984,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0)|0;i=x;B=w}else{B=a+16|0}Ry(c[B>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);if(h){Ry(c[B>>2]|0,1921784,2)}B=g;c[B>>2]=(c[B>>2]|0)+1;i=e;return 0}function uR(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=c[a+4>>2]|0;if((e|0)!=0&(f|0)>0){e=f-1|0;g=c[a>>2]|0;h=g+(e*80|0)|0;i=c[g+(e*80|0)+28>>2]|0;if((zZ(h,d)|0)<0){j=0;return j|0}UGb((c[g+(e*80|0)+24>>2]|0)+i|0,b|0,d)|0;j=h;return j|0}h=a+4|0;if(f>>>0>26843543>>>0){j=0;return j|0}i=a|0;e=jEb(c[i>>2]|0,a+8|0,(f*80|0)+80|0)|0;f=e;if((e|0)==0){j=0;return j|0}c[i>>2]=f;i=c[h>>2]|0;c[h>>2]=i+1;h=f+(i*80|0)|0;if((wZ(h,d)|0)<0){j=0;return j|0}e=f+(i*80|0)+36|0;c[e>>2]=c[e>>2]|1;TGb(f+(i*80|0)+8|0,0,16)|0;UGb(c[f+(i*80|0)+24>>2]|0,b|0,d)|0;j=h;return j|0}function vR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a|0;d=a+4|0;Yc(c[b>>2]|0,c[d>>2]|0,80,((c[a+16>>2]|0)==0?464:416)|0);a=c[d>>2]|0;if((a|0)<=0){return}e=c[b>>2]|0;b=0;f=a;while(1){a=e+(b*80|0)+48|0;do{if((c[a>>2]|0)==-1){if((b|0)>=(f-1|0)){g=f;break}h=e+((b+1|0)*80|0)+8|0;i=e+(b*80|0)+8|0;j=ZGb(c[h>>2]|0,c[h+4>>2]|0,c[i>>2]|0,c[i+4>>2]|0)|0;c[a>>2]=j;g=c[d>>2]|0}else{g=f}}while(0);a=b+1|0;if((a|0)<(g|0)){b=a;f=g}else{break}}return}function wR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+8|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=b+8|0;g=c[d>>2]|0;h=c[d+4>>2]|0;if(!((e|0)==(g|0)&(f|0)==(h|0))){i=(f|0)>(h|0)|(f|0)==(h|0)&e>>>0>g>>>0?1:-1;return i|0}g=a+64|0;a=c[g>>2]|0;e=c[g+4>>2]|0;g=b+64|0;b=c[g>>2]|0;h=c[g+4>>2]|0;if((a|0)==(b|0)&(e|0)==(h|0)){i=0;return i|0}i=(e|0)>(h|0)|(e|0)==(h|0)&a>>>0>b>>>0?1:-1;return i|0}function xR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+64|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=b+64|0;g=c[d>>2]|0;h=c[d+4>>2]|0;if(!((e|0)==(g|0)&(f|0)==(h|0))){i=(f|0)>(h|0)|(f|0)==(h|0)&e>>>0>g>>>0?1:-1;return i|0}g=a+8|0;a=c[g>>2]|0;e=c[g+4>>2]|0;g=b+8|0;b=c[g>>2]|0;h=c[g+4>>2]|0;if((a|0)==(b|0)&(e|0)==(h|0)){i=0;return i|0}i=(e|0)>(h|0)|(e|0)==(h|0)&a>>>0>b>>>0?1:-1;return i|0}function yR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+12|0;e=c[d>>2]|0;if((e|0)==(c[a+4>>2]|0)){f=-541478725;return f|0}if((EZ(b,(c[a>>2]|0)+(e*80|0)|0)|0)<0){f=-12;return f|0}e=b+8|0;a=c[e+4>>2]|0;g=b+16|0;c[g>>2]=c[e>>2];c[g+4>>2]=a;c[d>>2]=(c[d>>2]|0)+1;f=0;return f|0}function zR(a,b,d,e,f,g,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((k&2|0)!=0){l=-38;return l|0}if((k&8|0)!=0){k=0;if((h|0)<(k|0)|(h|0)==(k|0)&g>>>0<0>>>0){l=-34;return l|0}k=c[a+4>>2]|0;b=(k|0)<0|0?-1:0;if(!((b|0)>(h|0)|(b|0)==(h|0)&k>>>0>g>>>0)){l=-34;return l|0}c[a+12>>2]=g;l=0;return l|0}k=c[a+4>>2]|0;b=k-1|0;if((b|0)<0){l=-34;return l|0}do{if((b|0)==0){m=0}else{n=a|0;o=0;p=b;while(1){if((o|0)==(p-1|0)){q=10;break}r=(o+p|0)/2|0;s=(c[n>>2]|0)+(r*80|0)+8|0;t=c[s+4>>2]|0;u=(t|0)>(h|0)|(t|0)==(h|0)&(c[s>>2]|0)>>>0>g>>>0;s=u?o:r;t=u?r:p;if((s|0)==(t|0)){v=s;break}else{o=s;p=t}}if((q|0)==10){t=c[n>>2]|0;s=t+(o*80|0)+8|0;r=c[s+4>>2]|0;u=t+(p*80|0)+8|0;t=c[u+4>>2]|0;v=(r|0)<=(t|0)&((r|0)<(t|0)|(c[s>>2]|0)>>>0<=(c[u>>2]|0)>>>0)?o:p}if((v|0)<0){l=v}else{m=v;break}return l|0}}while(0);a:do{if((m|0)<(k|0)){v=c[a>>2]|0;if((d|0)==-1){q=m;g=m;while(1){h=v+(g*80|0)+8|0;b=c[h+4>>2]|0;if(!((b|0)<(f|0)|(b|0)==(f|0)&(c[h>>2]|0)>>>0<e>>>0)){w=q;break a}h=g+1|0;if((h|0)<(k|0)){q=g;g=h}else{w=g;break}}}else{g=m;q=m;while(1){p=v+(q*80|0)+8|0;o=c[p+4>>2]|0;if(!((o|0)<(f|0)|(o|0)==(f|0)&(c[p>>2]|0)>>>0<e>>>0)){w=g;break a}p=(c[v+(q*80|0)+32>>2]|0)==(d|0)?q:g;o=q+1|0;if((o|0)<(k|0)){g=p;q=o}else{w=p;break}}}}else{w=m}}while(0);m=c[a>>2]|0;b:do{if((w|0)>0){if((d|0)==-1){k=w;q=w;while(1){g=m+(q*80|0)+8|0;v=c[g+4>>2]|0;if(!((v|0)>(j|0)|(v|0)==(j|0)&(c[g>>2]|0)>>>0>i>>>0)){x=k;break b}g=q-1|0;if((g|0)>0){k=q;q=g}else{x=q;break}}}else{q=w;k=w;while(1){g=m+(k*80|0)+8|0;v=c[g+4>>2]|0;if(!((v|0)>(j|0)|(v|0)==(j|0)&(c[g>>2]|0)>>>0>i>>>0)){x=q;break b}g=(c[m+(k*80|0)+32>>2]|0)==(d|0)?k:q;v=k-1|0;if((v|0)>0){q=g;k=v}else{x=g;break}}}}else{x=w}}while(0);w=m+(x*80|0)+8|0;k=c[w>>2]|0;q=c[w+4>>2]|0;if((q|0)<(f|0)|(q|0)==(f|0)&k>>>0<e>>>0|((q|0)>(j|0)|(q|0)==(j|0)&k>>>0>i>>>0)){l=-34;return l|0}i=(d|0)==-1;j=x;c:while(1){x=j-1|0;if((j|0)<=0){break}d:do{if(i){w=x;while(1){g=c[m+(w*80|0)+48>>2]|0;if((g|0)>=1){y=w;z=w;A=g;break d}if((w|0)>0){w=w-1|0}else{break c}}}else{w=x;while(1){g=c[m+(w*80|0)+48>>2]|0;if((g|0)>=1){if((c[m+(w*80|0)+32>>2]|0)==(d|0)){y=w;z=w;A=g;break d}}if((w|0)>0){w=w-1|0}else{break c}}}}while(0);x=m+(z*80|0)+8|0;w=c[x>>2]|0;g=c[x+4>>2]|0;if((g|0)<(f|0)|(g|0)==(f|0)&w>>>0<e>>>0){break}x=ZGb(k,q,A,(A|0)<0|0?-1:0)|0;v=F;if((g|0)>(v|0)|(g|0)==(v|0)&w>>>0>x>>>0){j=y}else{break}}e:do{if(i){y=j;while(1){if((y|0)<=0){B=y;break e}A=y-1|0;q=m+(A*80|0)+8|0;k=m+(y*80|0)+8|0;if((c[q>>2]|0)==(c[k>>2]|0)&(c[q+4>>2]|0)==(c[k+4>>2]|0)){y=A}else{B=y;break}}}else{B=j}}while(0);c[a+12>>2]=B;l=0;return l|0}function AR(a){a=a|0;var b=0,d=0,e=0;b=a+4|0;if((c[b>>2]|0)>0){d=a|0;e=0;do{BZ((c[d>>2]|0)+(e*80|0)|0);e=e+1|0;}while((e|0)<(c[b>>2]|0))}$Db(a);c[a+12>>2]=0;c[a+8>>2]=0;c[b>>2]=0;return}function BR(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=a[d]|0;do{if(e<<24>>24==0){f=(lz(b)|0)&255;a[d]=f;if(f<<24>>24==0){g=0}else{h=f;break}return g|0}else{h=e}}while(0);e=h<<24>>24==60;f=e?62:60;i=0;j=h;do{MAb(c,j,1);j=(lz(b)|0)&255;a[d]=j;i=i+1|0;}while(!((j<<24>>24|0)==(f|0)|j<<24>>24==0));if(!e){g=i;return g|0}MAb(c,62,1);a[d]=0;g=i;return g|0}function CR(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=SGb(c|0)|0;e=a[b]|0;if(e<<24>>24==0){f=0;return f|0}else{g=b;h=0;i=e}while(1){a:do{if(i<<24>>24==0){j=g;k=h}else{e=g;b=h;l=i;while(1){if((b|0)==0){if((EAb(l<<24>>24)|0)!=0){j=e;k=0;break a}m=a[e]|0}else{m=l}n=m<<24>>24==34^b;o=e+1|0;p=a[o]|0;if(p<<24>>24==0){j=o;k=n;break}else{e=o;b=n;l=p}}}}while(0);q=j;while(1){if((EAb(a[q]|0)|0)==0){break}q=q+1|0}if((zAb(q,c,d)|0)==0){if((a[q+d|0]|0)==61){break}}l=a[q]|0;if(l<<24>>24==0){f=0;r=14;break}else{g=q;h=k;i=l}}if((r|0)==14){return f|0}r=d+1|0;f=q+(r+((a[q+r|0]|0)==34))|0;return f|0}function DR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+8|0;f=e|0;PAb(d);g=f|0;h=0;j=0;k=0;a:while(1){b:do{if((k|0)==0){while(1){l=(lz(b)|0)&255;if((l<<24>>24|0)==0){m=11;break a}else if((l<<24>>24|0)==13){h=h;j=j;k=0;continue a}else if((l<<24>>24|0)!=10){n=0;o=j;p=h;q=l;break}}}else{l=h;r=j;s=0;while(1){t=(lz(b)|0)&255;if(t<<24>>24==0){m=11;break a}if(!((t<<24>>24|0)==13|(t<<24>>24|0)==10)){n=s;o=r;p=l;q=t;break b}u=(t<<24>>24==10?1:l&255)+r|0;if((u|0)==2){m=11;break a}v=s+1|0;a[f+s|0]=t;if((v|0)==4){m=11;break a}else{l=t<<24>>24==13|0;r=u;s=v}}}}while(0);if((n|0)==0){w=o}else{a[f+n|0]=0;KAb(d,1897984,(s=i,i=i+8|0,c[s>>2]=g,s)|0);i=s;w=0}MAb(d,q,1);h=p;j=w;k=k+1|0}if((m|0)==11){i=e;return}}function ER(a){a=a|0;var b=0;b=(yb(c[a+4>>2]|0,1921656)|0)==0;return(b?0:50)|0}function FR(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;d=i;i=i+4128|0;e=d|0;f=d+8|0;g=d+4104|0;h=d+4112|0;j=d+4120|0;c[e>>2]=0;k=c[b+12>>2]|0;l=LT(b,0)|0;if((l|0)==0){m=-12;i=d;return m|0}MT(l,64,1,1);n=c[l+8>>2]|0;c[n+8>>2]=3;c[n+48>>2]=1398953521;n=b+16|0;a:do{if((Xy(c[n>>2]|0)|0)==0){b=f|0;l=k;o=0;while(1){p=o+8|0;q=o+48|0;b:do{if((o|0)==0){while(1){if((wz(c[n>>2]|0,b,4096)|0)==0){r=l;break a}if((RGb(b,2064472,7)|0)==0){wz(c[n>>2]|0,b,4096)|0;xd(b|0,2018056,(s=i,i=i+8|0,c[s>>2]=e,s)|0)|0;i=s}t=xd(b|0,1975904,(s=i,i=i+24|0,c[s>>2]=g,c[s+8>>2]=h,c[s+16>>2]=j,s)|0)|0;i=s;u=c[n>>2]|0;if((t|0)==3){break}if((Xy(u)|0)!=0){r=l;break a}}t=Ty(u,0,0,1)|0;v=F;w=c[g>>2]|0;x=c[h>>2]|0;y=c[j>>2]|0;z=c[e>>2]|0;A=wz(c[n>>2]|0,b,4096)|0;a[f+(hc(b|0,1946864)|0)|0]=0;if((a[b]|0)==0){B=0;break}C=gHb(x,(x|0)<0|0?-1:0,60,0)|0;x=F;D=gHb(w,(w|0)<0|0?-1:0,3600,0)|0;w=YGb(C,x,D,F)|0;D=YGb(w,F,y,(y|0)<0|0?-1:0)|0;y=YGb(D,F,z,(z|0)<0|0?-1:0)|0;E=v;G=t;H=F;I=y;J=A;K=20}else{while(1){if((wz(c[n>>2]|0,b,4096)|0)==0){r=l;break a}if((RGb(b,2064472,7)|0)==0){wz(c[n>>2]|0,b,4096)|0;xd(b|0,2018056,(s=i,i=i+8|0,c[s>>2]=e,s)|0)|0;i=s}A=xd(b|0,1975904,(s=i,i=i+24|0,c[s>>2]=g,c[s+8>>2]=h,c[s+16>>2]=j,s)|0)|0;i=s;if((A|0)==3){A=Ty(c[n>>2]|0,0,0,1)|0;y=F;t=c[g>>2]|0;v=gHb(t,(t|0)<0|0?-1:0,3600,0)|0;t=F;z=c[h>>2]|0;D=gHb(z,(z|0)<0|0?-1:0,60,0)|0;z=YGb(D,F,v,t)|0;t=c[j>>2]|0;v=YGb(z,F,t,(t|0)<0|0?-1:0)|0;t=c[e>>2]|0;z=YGb(v,F,t,(t|0)<0|0?-1:0)|0;t=F;v=wz(c[n>>2]|0,b,4096)|0;a[f+(hc(b|0,1946864)|0)|0]=0;if((a[b]|0)!=0){E=y;G=A;H=t;I=z;J=v;K=20;break b}v=ZGb(z,t,c[p>>2]|0,c[p+4>>2]|0)|0;c[q>>2]=v}if((Xy(c[n>>2]|0)|0)!=0){r=l;break a}}}}while(0);if((K|0)==20){K=0;q=uR(l,b,J,0)|0;if((q|0)==0){m=-12;break}p=q+64|0;c[p>>2]=G;c[p+4>>2]=E;p=q+8|0;c[p>>2]=I;c[p+4>>2]=H;c[q+48>>2]=-1;B=q}if((Xy(c[n>>2]|0)|0)==0){o=B}else{r=l;break a}}i=d;return m|0}else{r=k}}while(0);vR(r);m=0;i=d;return m|0}function GR(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function HR(a){a=a|0;AR(c[a+12>>2]|0);return 0}function IR(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function JR(a){a=a|0;var b=0,e=0,f=0,g=0;b=i;i=i+8|0;e=c[a+4>>2]|0;a=((d[e+1|0]|0)<<8|(d[e]|0)<<16|(d[e+2|0]|0)|0)==15711167?e+3|0:e;e=xd(a|0,2246824,(f=i,i=i+8|0,c[f>>2]=b,f)|0)|0;i=f;if((e|0)==1){g=50;i=b;return g|0}e=(RGb(a,2293416,13)|0)==0;g=e?33:0;i=b;return g|0}function KR(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;d=i;i=i+3296|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+1088|0;p=d+3136|0;q=d+3168|0;r=c[b+12>>2]|0;s=LT(b,0)|0;if((s|0)==0){t=-12;i=d;return t|0}MT(s,64,1,100);u=s+8|0;s=c[u>>2]|0;c[s+8>>2]=3;c[s+48>>2]=1400201814;IAb(n,0,-1);s=b+16|0;a:do{if((Xy(c[s>>2]|0)|0)==0){v=o|0;w=b+1140|0;x=p|0;y=q|0;z=r;A=-2147483648;B=0;C=-1;D=0;E=1;while(1){if((wz(c[s>>2]|0,v,2048)|0)==0){G=D;H=z;I=37;break a}a[o+(hc(v|0,2064408)|0)|0]=0;b:do{if((a[v]|0)==91){if((RGb(v,2017944,4)|0)==0){I=26;break}if((yb(v|0,1975808)|0)!=0){J=E;K=D;L=C;M=A;N=B;break}if((yb(v|0,1946792)|0)!=0){J=E;K=D;L=C;M=A;N=B;break}if((yb(v|0,1921608)|0)!=0){J=E;K=D;L=C;M=A;N=B;break}if((yb(v|0,1900272)|0)!=0){J=E;K=D;L=C;M=A;N=B;break}if((c[(c[u>>2]|0)+96>>2]|0)!=0){J=E;K=D;L=C;M=A;N=B;break}KAb(n,1880296,(O=i,i=i+8|0,c[O>>2]=v,O)|0);i=O;do{if((RGb(v,2338256,17)|0)!=0){if((RGb(v,2314144,10)|0)==0){break}if((RGb(v,2293416,13)|0)==0){J=E;K=D;L=C;M=A;N=B;break b}else{P=1}while(1){Q=a[o+P|0]|0;if((Q<<24>>24|0)==93|(Q<<24>>24|0)==0){R=P;S=Q;break}a[p+(P-1)|0]=((Q<<24>>24)-65|0)>>>0<26>>>0?Q^32:Q;T=P+1|0;if(T>>>0<31>>>0){P=T}else{I=19;break}}if((I|0)==19){I=0;R=T;S=a[o+T|0]|0}a[p+(R-1)|0]=0;Q=(S<<24>>24==93)+R|0;while(1){U=a[o+Q|0]|0;if(U<<24>>24==32){Q=Q+1|0}else{V=Q;W=0;X=U;break}}while(1){if((X<<24>>24|0)==0|(X<<24>>24|0)==93){Y=W;break}Q=V+1|0;U=W+1|0;a[q+W|0]=X;if(!(U>>>0<127>>>0)){Y=U;break}V=Q;W=U;X=a[o+Q|0]|0}a[q+Y|0]=0;CBb(w,x,y,0)|0;J=E;K=D;L=C;M=A;N=B;break b}}while(0);Q=e1a(c[u>>2]|0,n)|0;if((Q|0)<0){Z=Q;break a}else{J=E;K=Q;L=C;M=A;N=B}}else{I=26}}while(0);do{if((I|0)==26){I=0;Q=xd(v|0,2261384,(O=i,i=i+64|0,c[O>>2]=e,c[O+8>>2]=f,c[O+16>>2]=g,c[O+24>>2]=h,c[O+32>>2]=j,c[O+40>>2]=k,c[O+48>>2]=l,c[O+56>>2]=m,O)|0)|0;i=O;if((Q|0)==8){Q=c[j>>2]|0;U=gHb(Q,(Q|0)<0|0?-1:0,3600,0)|0;Q=F;_=c[k>>2]|0;$=gHb(_,(_|0)<0|0?-1:0,60,0)|0;_=YGb($,F,U,Q)|0;Q=c[l>>2]|0;U=YGb(_,F,Q,(Q|0)<0|0?-1:0)|0;Q=gHb(U,F,100,0)|0;U=YGb(Q,F,c[m>>2]|0,0)|0;Q=F;_=c[e>>2]|0;$=gHb(_,(_|0)<0|0?-1:0,3600,0)|0;_=F;aa=c[f>>2]|0;ba=gHb(aa,(aa|0)<0|0?-1:0,60,0)|0;aa=YGb(ba,F,$,_)|0;_=c[g>>2]|0;$=YGb(aa,F,_,(_|0)<0|0?-1:0)|0;_=gHb($,F,100,0)|0;$=c[h>>2]|0;aa=YGb(_,F,$,($|0)<0|0?-1:0)|0;$=F;_=ZGb(U,Q,aa,$)|0;ca=1;da=_;ea=$;fa=aa}else{ca=0;da=C;ea=A;fa=B}if(ca){Ty(c[s>>2]|0,0,0,1)|0;J=1;K=D;L=da;M=ea;N=fa;break}if((a[v]|0)==0){J=E;K=D;L=da;M=ea;N=fa;break}aa=(E|0)!=0;if(!aa){if((uR(z,2276944,1,1)|0)==0){Z=-12;break a}}$=uR(z,v,SGb(v|0)|0,E^1)|0;if(($|0)==0){Z=-12;break a}if(!aa){J=0;K=D;L=da;M=ea;N=fa;break}aa=$+64|0;c[aa>>2]=0;c[aa+4>>2]=0;aa=$+8|0;c[aa>>2]=fa;c[aa+4>>2]=ea;c[$+48>>2]=da;J=0;K=D;L=da;M=ea;N=fa}}while(0);if((Xy(c[s>>2]|0)|0)==0){A=M;B=N;C=L;D=K;E=J}else{G=K;H=z;I=37;break}}}else{G=0;H=r;I=37}}while(0);if((I|0)==37){vR(H);Z=G}QAb(n,0)|0;t=Z;i=d;return t|0}function LR(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function MR(a){a=a|0;AR(c[a+12>>2]|0);return 0}function NR(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function OR(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<15){b=0;return b|0}e=c[a+4>>2]|0;a=(d[e+1|0]|0)<<8|(d[e]|0)<<16|(d[e+2|0]|0);if(!((a|0)==4413267|(a|0)==4609875)){b=0;return b|0}b=(d[e+3|0]|0)>>>0>19>>>0?25:100;return b|0}function PR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=(vz(e)|0)&-256;rz(e)|0;if((f|0)==1180128e3){g=e}else if((f|0)==1129796352){h=2}else{j=-5;i=b;return j|0}do{if((h|0)==2){f=a;yDb(f,32,2314072,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;k=d+64|0;c[k>>2]=WDb(4096)|0;l=WDb(4096)|0;m=d+68|0;c[m>>2]=l;n=Oy(l,4096,0,f,134,0,0)|0;l=d+60|0;c[l>>2]=n;if((c[k>>2]|0)==0){j=-12;i=b;return j|0}if((c[m>>2]|0)==0|(n|0)==0){j=-12;i=b;return j|0}c[n+88>>2]=0;if((Qd(d+72|0,2293400,56)|0)==0){g=c[l>>2]|0;break}yDb(f,16,2276896,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;j=-22;i=b;return j|0}}while(0);h=(((lz(g)|0)>>3<<2)+4|0)/8|0;Vy(g,h,(h|0)<0|0?-1:0)|0;c[d+40>>2]=pz(g)|0;pz(g)|0;c[d+24>>2]=0;d=a+20|0;c[d>>2]=c[d>>2]|1;j=0;i=b;return j|0}function QR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;f=i;i=i+1048|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=c[b+12>>2]|0;m=c[l+60>>2]|0;n=(m|0)==0?c[b+16>>2]|0:m;m=Ty(n,0,0,1)|0;o=F;if((Xy(n)|0)!=0){p=-541478725;i=f;return p|0}q=b;r=k;s=j;t=h;u=b+24|0;v=l+40|0;w=b+28|0;y=l+24|0;l=o;o=m;a:while(1){m=pz(n)|0;z=m&63;A=m>>6;if((z|0)==63){B=rz(n)|0}else{B=z}if((A|0)<0){p=A;C=113;break}if((B|0)<0){C=7;break}b:do{switch(A|0){case 14:{D=pz(n)|0;z=c[u>>2]|0;if((z|0)==0){C=28;break a}m=c[w>>2]|0;E=0;while(1){G=c[m+(E<<2)>>2]|0;if((c[(c[G+8>>2]|0)+8>>2]|0)==1){if((c[G+4>>2]|0)==(D|0)){H=B;break b}}G=E+1|0;if(G>>>0<z>>>0){E=G}else{C=28;break a}}break};case 61:{E=pz(n)|0;z=B-2|0;m=c[u>>2]|0;if((m|0)==0){H=z;break b}G=c[w>>2]|0;I=0;while(1){J=c[G+(I<<2)>>2]|0;if((c[(c[J+8>>2]|0)+8>>2]|0)==0){if((c[J+4>>2]|0)==(E|0)){break}}K=I+1|0;if(K>>>0<m>>>0){I=K}else{H=z;break b}}L=pz(n)|0;M=B-4|0;if((M|0)<1){H=M}else{C=38;break a}break};case 60:{z=pz(n)|0;I=B-2|0;m=c[u>>2]|0;if((m|0)!=0){E=c[w>>2]|0;G=0;do{K=c[E+(G<<2)>>2]|0;if((c[(c[K+8>>2]|0)+8>>2]|0)==0){if((c[K+4>>2]|0)==(z|0)){H=I;break b}}G=G+1|0;}while(G>>>0<m>>>0)}pz(n)|0;pz(n)|0;pz(n)|0;lz(n)|0;m=LT(b,0)|0;if((m|0)==0){p=-12;C=113;break a}c[m+4>>2]=z;G=m+8|0;c[(c[G>>2]|0)+8>>2]=0;I=vT(1130216,lz(n)|0)|0;c[(c[G>>2]|0)+48>>2]=I;MT(m,16,256,c[v>>2]|0);H=B-10|0;break};case 45:case 18:{m=c[u>>2]|0;if((m|0)!=0){I=c[w>>2]|0;G=0;do{E=c[I+(G<<2)>>2]|0;if((c[(c[E+8>>2]|0)+8>>2]|0)==1){if((c[E+4>>2]|0)==-1){H=B;break b}}G=G+1|0;}while(G>>>0<m>>>0)}lz(n)|0;m=lz(n)|0;c[y>>2]=pz(n)|0;if((SR(b,-1,m)|0)==0){p=-12;C=113;break a}H=B-4|0;break};default:{N=(A|0)==36;if((A|0)==36|(A|0)==20){c[h>>2]=0;c[j>>2]=0;TGb(r|0,0,1024)|0;m=N?4:3;pz(n)|0;O=lz(n)|0;P=pz(n)|0;Q=pz(n)|0;G=B-7|0;if((O|0)==3){R=(lz(n)|0)+1|0;S=P;T=B-8|0;C=51}else if((O|0)==4){R=0;S=P<<1;T=G;C=51}else if((O|0)==5){R=0;S=P<<2;T=G;C=51}else{yDb(q,16,2064128,(U=i,i=i+8|0,c[U>>2]=O,U)|0);i=U;V=G}c:do{if((C|0)==51){C=0;G=S+3&-4;do{if((hDb(P,Q,0,q)|0)>=0){if((G|0)>=(2147483647/(Q|0)|0|0)){break}W=ba(G,Q)|0;X=ba(R,m)|0;if((W|0)>=(2147483647-X|0)){break}I=W+X|0;c[g>>2]=I;c[j>>2]=WDb(T)|0;z=WDb(I)|0;c[h>>2]=z;I=c[j>>2]|0;if((I|0)==0|(z|0)==0){Y=-12;C=80;break a}z=mz(n,I,T)|0;if((z|0)>=0){if((Zb(c[h>>2]|0,g|0,c[j>>2]|0,z|0)|0)==0){C=58;break a}}yDb(q,24,1975704,(U=i,i=i+1|0,i=i+7&-8,c[U>>2]=0,U)|0);i=U;V=z;break c}}while(0);yDb(q,16,2017672,(U=i,i=i+16|0,c[U>>2]=P,c[U+8>>2]=Q,U)|0);i=U;V=T}}while(0);$Db(s);$Db(t);H=V;break b}else if((A|0)==19){m=c[u>>2]|0;if((m|0)==0){H=B;break b}G=c[w>>2]|0;z=0;while(1){Z=c[G+(z<<2)>>2]|0;_=c[Z+8>>2]|0;if((c[_+8>>2]|0)==1){if((c[Z+4>>2]|0)==-1){break}}I=z+1|0;if(I>>>0<m>>>0){z=I}else{H=B;break b}}if((c[_+48>>2]|0)==86017){Vy(n,4,0)|0;$=B-4|0;if(($|0)<1){H=$;break b}else{C=86;break a}}else{if((B|0)<1){H=B;break b}else{C=88;break a}}}else if((A|0)==21){z=c[u>>2]|0;if((z|0)==0){C=95}else{m=c[w>>2]|0;G=0;while(1){aa=c[m+(G<<2)>>2]|0;if((c[(c[aa+8>>2]|0)+48>>2]|0)==8){if((c[aa+4>>2]|0)==-2){ca=G;break}}I=G+1|0;if(I>>>0<z>>>0){G=I}else{ca=I;break}}if((ca|0)==(z|0)){C=95}else{da=aa}}if((C|0)==95){C=0;G=LT(b,0)|0;if((G|0)==0){p=-12;C=113;break a}c[G+4>>2]=-2;m=c[G+8>>2]|0;c[m+8>>2]=0;c[m+48>>2]=8;MT(G,64,256,c[v>>2]|0);da=G}pz(n)|0;ea=B-2|0;if((ea|0)<4){H=ea;break b}else{C=98;break a}}else{yDb(q,48,1880176,(U=i,i=i+8|0,c[U>>2]=A,U)|0);i=U;H=B;break b}}}}while(0);A=(H|0)<0;if(A){yDb(q,24,2338160,(U=i,i=i+8|0,c[U>>2]=H,U)|0);i=U}Vy(n,A?0:H,A?0:(H|0)<0|0?-1:0)|0;A=Ty(n,0,0,1)|0;G=F;if((Xy(n)|0)==0){l=G;o=A}else{p=-541478725;C=113;break}}do{if((C|0)==7){yDb(q,16,2126280,(U=i,i=i+8|0,c[U>>2]=B,U)|0);i=U;p=-1094995529;i=f;return p|0}else if((C|0)==28){H=lz(n)|0;aa=SR(b,D,H)|0;if((aa|0)==0){p=-12;i=f;return p|0}ca=aa+56|0;c[ca>>2]=rz(n)|0;c[ca+4>>2]=0;if((H&240|0)==32){c[aa+448>>2]=pz(n)|0;fa=B-2|0}else{fa=B}H=TS(n,e,fa-7|0)|0;if((H|0)<0){p=H;i=f;return p|0}H=e+64|0;c[H>>2]=o;c[H+4>>2]=l;c[e+32>>2]=c[aa>>2];p=c[e+28>>2]|0;i=f;return p|0}else if((C|0)==38){aa=TS(n,e,M)|0;if((aa|0)<0){p=aa;i=f;return p|0}aa=e+64|0;c[aa>>2]=o;c[aa+4>>2]=l;aa=e+8|0;c[aa>>2]=L;c[aa+4>>2]=(L|0)<0|0?-1:0;c[e+32>>2]=c[J>>2];p=c[e+28>>2]|0;i=f;return p|0}else if((C|0)==58){aa=c[u>>2]|0;if((aa|0)==0){C=65}else{H=c[w>>2]|0;ca=0;while(1){ga=c[H+(ca<<2)>>2]|0;if((c[(c[ga+8>>2]|0)+48>>2]|0)==14){if((c[ga+4>>2]|0)==-3){ha=ca;break}}_=ca+1|0;if(_>>>0<aa>>>0){ca=_}else{ha=_;break}}if((ha|0)==(aa|0)){C=65}else{ia=ga}}if((C|0)==65){ca=LT(b,0)|0;if((ca|0)==0){Y=-12;C=80;break}c[ca+4>>2]=-3;H=c[ca+8>>2]|0;c[H+8>>2]=0;c[H+48>>2]=14;MT(ca,64,256,c[v>>2]|0);ia=ca}ca=ia+8|0;H=c[ca>>2]|0;c[H+120>>2]=P;c[H+124>>2]=Q;H=wZ(e,(c[g>>2]|0)-X|0)|0;if((H|0)<0){Y=H;C=80;break}H=e+64|0;c[H>>2]=o;c[H+4>>2]=l;c[e+32>>2]=c[ia>>2];if((O|0)==5){c[(c[ca>>2]|0)+140>>2]=N?27:295}else if((O|0)==3){c[(c[ca>>2]|0)+140>>2]=11;if((R|0)>0){H=c[h>>2]|0;_=H+3|0;if(N){V=0;do{T=V<<2;c[k+(V<<2)>>2]=(d[H+T|0]|0)<<16|(d[_]|0)<<24|(d[H+(T|1)|0]|0)<<8|(d[H+(T|2)|0]|0);V=V+1|0;}while((V|0)<(R|0))}else{V=0;do{_=V*3|0;c[k+(V<<2)>>2]=(d[H+_|0]|0)<<16|(d[H+(_+1)|0]|0)<<8|(d[H+(_+2)|0]|0)|-16777216;V=V+1|0;}while((V|0)<(R|0))}}V=GZ(e,0,1024)|0;if((V|0)==0){Y=-12;C=80;break}UGb(V|0,r|0,1024)|0}else if((O|0)==4){c[(c[ca>>2]|0)+140>>2]=46}else{yDb(0,0,1946672,(U=i,i=i+24|0,c[U>>2]=1921536,c[U+8>>2]=1900192,c[U+16>>2]=384,U)|0);i=U;Cd();return 0}V=e+28|0;if((W|0)>(c[V>>2]|0)){Y=-1094995529;C=80;break}UGb(c[e+24>>2]|0,(c[h>>2]|0)+X|0,W)|0;Y=c[V>>2]|0;C=80}else if((C|0)==86){V=TS(n,e,$)|0;if((V|0)<0){p=V}else{C=89;break}i=f;return p|0}else if((C|0)==88){V=TS(n,e,B)|0;if((V|0)<0){p=V}else{C=89;break}i=f;return p|0}else if((C|0)==98){V=wZ(e,ea)|0;if((V|0)<0){p=V;i=f;return p|0}V=e+24|0;if((mz(n,c[V>>2]|0,4)|0)!=4){BZ(e);p=-1094995529;i=f;return p|0}H=c[V>>2]|0;_=H;aa=fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0;if((aa|0)==(-2555943|0)|(aa|0)==(-2490408|0)){aa=e+28|0;_=(c[aa>>2]|0)-4|0;c[aa>>2]=_;T=H+_|0;x=0;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;ja=mz(n,c[V>>2]|0,c[aa>>2]|0)|0}else{aa=mz(n,H+4|0,(c[e+28>>2]|0)-4|0)|0;ja=(aa|0)>-1?aa+4|0:aa}aa=e+28|0;do{if((ja|0)==(c[aa>>2]|0)){ka=ja}else{if((ja|0)>=0){yZ(e,ja);ka=c[aa>>2]|0;break}BZ(e);p=ja;i=f;return p|0}}while(0);aa=e+64|0;c[aa>>2]=o;c[aa+4>>2]=l;c[e+32>>2]=c[da>>2];p=ka;i=f;return p|0}else if((C|0)==113){i=f;return p|0}}while(0);if((C|0)==80){$Db(s);$Db(t);p=Y;i=f;return p|0}else if((C|0)==89){C=e+64|0;c[C>>2]=o;c[C+4>>2]=l;c[e+32>>2]=c[Z>>2];p=c[e+28>>2]|0;i=f;return p|0}return 0}function RR(a){a=a|0;var b=0;b=c[a+12>>2]|0;he(b+72|0)|0;$Db(b+64|0);$Db(b+68|0);$Db(b+60|0);return 0}function SR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=LT(a,0)|0;if((e|0)==0){f=0;return f|0}c[e+4>>2]=b;b=e+8|0;a=c[b>>2]|0;g=a+416|0;if((d&1|0)==0){c[g>>2]=1;h=a+448|0;c[h>>2]=4;c[h+4>>2]=0}else{c[g>>2]=2;g=a+448|0;c[g>>2]=3;c[g+4>>2]=0}c[a+8>>2]=1;a=vT(403056,d>>>4&15)|0;g=c[b>>2]|0;b=g+48|0;c[b>>2]=a;c[e+236>>2]=1;if((d&2|0)==0&(a|0)==65536){c[b>>2]=65541}b=44100>>>((d>>>2&3^3)>>>0);c[g+412>>2]=b;MT(e,64,1,b);f=e;return f|0}function TR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[a+12>>2]|0;f=e+72|0;g=f;h=e+76|0;i=a+16|0;a=e+64|0;j=f;f=e+84|0;k=e+88|0;while(1){if((c[h>>2]|0)==0){e=mz(c[i>>2]|0,c[a>>2]|0,4096)|0;if((e|0)<0){l=e;m=9;break}c[j>>2]=c[a>>2];c[h>>2]=e}c[f>>2]=b;c[k>>2]=d;e=$c(g|0,0)|0;if((e|0)<0){l=-22;m=9;break}if((e|0)==1){l=-541478725;m=9;break}n=c[k>>2]|0;if((n|0)!=(d|0)){m=8;break}}if((m|0)==8){l=d-n|0;return l|0}else if((m|0)==9){return l|0}return 0}function UR(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+280|0;e=d|0;f=d+24|0;g=b+12|0;h=c[g>>2]|0;j=b+16|0;k=c[j>>2]|0;c[h+28>>2]=0;c[h+32>>2]=0;c[h+36>>2]=0;l=b+24|0;m=c[l>>2]|0;a:do{if((m|0)==0){n=h+56|0}else{o=b+28|0;p=h+52|0;q=h+48|0;r=h+56|0;s=0;t=m;while(1){u=c[(c[(c[o>>2]|0)+(s<<2)>>2]|0)+8>>2]|0;if((c[u+8>>2]|0)==1){if((c[p>>2]|0)!=0){v=6;break}if((c[u+48>>2]|0)!=86017){v=12;break}if((c[u+424>>2]|0)==0){v=9;break}c[p>>2]=u;w=UBb(65536)|0;c[q>>2]=w;if((w|0)==0){y=-12;v=52;break}z=c[l>>2]|0}else{if((c[r>>2]|0)!=0){v=14;break}w=c[u+48>>2]|0;if(!((w|0)==93|(w|0)==22|(w|0)==8)){v=17;break}c[r>>2]=u;z=t}u=s+1|0;if(u>>>0<z>>>0){s=u;t=z}else{n=r;break a}}if((v|0)==6){yDb(b,16,2314e3,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;y=-1094995529;i=d;return y|0}else if((v|0)==9){yDb(b,16,2293360,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;y=-1;i=d;return y|0}else if((v|0)==12){yDb(b,16,2276848,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;y=-1;i=d;return y|0}else if((v|0)==14){yDb(b,16,2261256,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;y=-1094995529;i=d;return y|0}else if((v|0)==17){yDb(b,16,2246632,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;y=-1;i=d;return y|0}else if((v|0)==52){i=d;return y|0}}}while(0);v=c[n>>2]|0;if((v|0)==0){B=1;C=10;D=200;E=320}else{B=c[v+104>>2]|0;C=c[v+108>>2]|0;D=c[v+124>>2]|0;E=c[v+120>>2]|0}v=h+52|0;z=c[v>>2]|0;if((z|0)==0){c[h+24>>2]=~~(+(B|0)*44100.0/+(C|0))}else{c[h+24>>2]=(ba(c[z+412>>2]|0,B)|0)/(C|0)|0}Ry(k,2233968,3);do{if((QGb(2063888,c[c[b+8>>2]>>2]|0)|0)==0){G=9}else{z=c[n>>2]|0;if((z|0)!=0){l=c[z+48>>2]|0;if((l|0)==93){G=8;break}if((l|0)==22){G=6;break}}G=4}}while(0);Py(k,G);Yy(k,104857600);_R(k,E*20|0,D*20|0);az(k,(C<<8|0)/(B|0)|0);l=Ty(k,0,0,1)|0;z=h;c[z>>2]=l;c[z+4>>2]=F;z=gHb(C,(C|0)<0|0?-1:0,600,0)|0;C=eHb(z,F,B,(B|0)<0|0?-1:0)|0;az(k,C&65535);if((G|0)==9){G=c[g>>2]|0;C=c[j>>2]|0;B=Ty(C,0,0,1)|0;z=G+8|0;c[z>>2]=B;c[z+4>>2]=F;c[G+44>>2]=69;az(C,0);Yy(k,8);XR(c[g>>2]|0,c[j>>2]|0)}C=c[n>>2]|0;do{if((C|0)!=0){if((c[C+48>>2]|0)!=8){break}n=c[g>>2]|0;G=c[j>>2]|0;z=Ty(G,0,0,1)|0;B=n+8|0;c[B>>2]=z;c[B+4>>2]=F;c[n+44>>2]=2;az(G,0);az(k,1);_R(k,E,D);Py(k,1);Py(k,65);az(k,0);ZR(k,65536,65536);Py(k,0);G=f|0;c[e+20>>2]=2048;n=e+8|0;c[n>>2]=G;c[e+16>>2]=f+256;B=e+12|0;c[B>>2]=G;z=e+4|0;l=e|0;c[l>>2]=262921;c[z>>2]=10;$R(e,E,0);$R(e,0,D);$R(e,-E|0,0);$R(e,0,-D|0);m=c[l>>2]|0;r=c[z>>2]|0;if((r|0)>1){H=r-1|0;I=m<<1}else{t=fe(m<<r|0)|0;m=c[B>>2]|0;x=t;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;H=r+31|0;I=0}c[l>>2]=I;c[z>>2]=H;if((H|0)>5){J=H-5|0;K=I<<5}else{r=fe(I<<H|0)|0;m=c[B>>2]|0;x=r;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;J=H+27|0;K=0}c[l>>2]=K;c[z>>2]=J;b:do{if((J|0)<32){m=K<<J;c[l>>2]=m;r=m>>>24&255;while(1){m=c[B>>2]|0;c[B>>2]=m+1;a[m]=r;m=c[l>>2]|0;c[l>>2]=m<<8;t=(c[z>>2]|0)+8|0;c[z>>2]=t;if((t|0)>=32){break b}r=m>>>16&255}}}while(0);c[z>>2]=32;c[l>>2]=0;Ry(k,G,(c[B>>2]|0)-(c[n>>2]|0)|0);XR(c[g>>2]|0,c[j>>2]|0)}}while(0);k=c[v>>2]|0;do{if((k|0)!=0){if((c[k+48>>2]|0)!=86017){break}J=c[g>>2]|0;K=c[j>>2]|0;H=Ty(K,0,0,1)|0;I=J+8|0;c[I>>2]=H;c[I+4>>2]=F;c[J+44>>2]=45;az(K,0);K=c[v>>2]|0;J=c[K+412>>2]|0;if((J|0)==11025){L=6}else if((J|0)==22050){L=10}else if((J|0)==44100){L=14}else{yDb(b,16,2220856,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;y=-1;i=d;return y|0}J=(c[K+416>>2]|0)==2|L;Py(c[j>>2]|0,J);Py(c[j>>2]|0,J|32);az(c[j>>2]|0,c[h+24>>2]|0);az(c[j>>2]|0,0);XR(c[g>>2]|0,c[j>>2]|0)}}while(0);Sy(c[j>>2]|0);y=0;i=d;return y|0}function VR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[(c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0)+8>>2]|0;f=c[b+24>>2]|0;g=c[b+28>>2]|0;if((c[e+8>>2]|0)!=1){YR(a,e,f,g);h=0;i=d;return h|0}b=c[a+12>>2]|0;if((c[b+32>>2]|0)==16e3){yDb(e,32,1900088,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}k=b+48|0;if(((WBb(c[k>>2]|0)|0)+g|0)>65536){yDb(a,16,2338016,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-1;i=d;return h|0}_Bb(c[k>>2]|0,f,g,0)|0;g=b+28|0;c[g>>2]=(c[g>>2]|0)+(c[e+424>>2]|0);if((c[b+56>>2]|0)!=0){h=0;i=d;return h|0}YR(a,e,0,0);h=0;i=d;return h|0}function WR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;g=a+24|0;h=c[g>>2]|0;if((h|0)==0){i=0;j=d;k=f}else{l=a+28|0;a=d+48|0;m=0;n=0;o=h;while(1){h=c[(c[(c[l>>2]|0)+(n<<2)>>2]|0)+8>>2]|0;if((c[h+8>>2]|0)==0){p=h;q=o}else{VBb(c[a>>2]|0);c[a>>2]=0;p=m;q=c[g>>2]|0}h=n+1|0;if(h>>>0<q>>>0){m=p;n=h;o=q}else{break}}i=p;j=c[b>>2]|0;k=c[e>>2]|0}p=Ty(k,0,0,1)|0;q=j+8|0;c[q>>2]=p;c[q+4>>2]=F;c[j+44>>2]=0;az(k,0);XR(c[b>>2]|0,c[e>>2]|0);if((c[(c[e>>2]|0)+88>>2]|0)==0|(i|0)==0){return 0}i=Ty(f,0,0,1)|0;e=i;Ty(f,4,0,0)|0;Yy(f,e);i=d;Ty(f,c[i>>2]|0,c[i+4>>2]|0,0)|0;i=d+36|0;az(f,c[i>>2]|0);b=d+16|0;d=c[b>>2]|0;k=c[b+4>>2]|0;if(!((d|0)==0&(k|0)==0)){Ty(f,d,k,0)|0;az(f,c[i>>2]|0)}Ty(f,e,(e|0)<0|0?-1:0,0)|0;return 0}function XR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=Ty(b,0,0,1)|0;f=F;g=a+8|0;h=c[g>>2]|0;j=c[g+4>>2]|0;g=YGb(e,f,-2,0)|0;k=ZGb(g,F,h,j)|0;g=k;k=c[a+44>>2]|0;Ty(b,h,j,0)|0;if((k&256|0)!=0){az(b,k<<6&-16448|63);Yy(b,g-4|0);l=Ty(b,e,f,0)|0;m=F;i=d;return}if((g|0)>=63){yDb(0,0,1975552,(j=i,i=i+24|0,c[j>>2]=1946624,c[j+8>>2]=1921440,c[j+16>>2]=60,j)|0);i=j;Cd()}az(b,k<<6|g);l=Ty(b,e,f,0)|0;m=F;i=d;return}function YR(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;f=i;g=a+12|0;h=c[g>>2]|0;j=a+16|0;a=c[j>>2]|0;k=h+32|0;if((c[k>>2]|0)==16e3){yDb(b,32,1900088,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}l=b+48|0;m=c[l>>2]|0;if((m|0)==8){if((c[k>>2]|0)>0){n=c[g>>2]|0;o=c[j>>2]|0;p=Ty(o,0,0,1)|0;q=n+8|0;c[q>>2]=p;c[q+4>>2]=F;c[n+44>>2]=5;az(o,0);az(a,1);az(a,1);XR(c[g>>2]|0,c[j>>2]|0);o=c[g>>2]|0;n=c[j>>2]|0;q=Ty(n,0,0,1)|0;p=o+8|0;c[p>>2]=q;c[p+4>>2]=F;c[o+44>>2]=3;az(n,0);az(a,0);XR(c[g>>2]|0,c[j>>2]|0)}n=c[g>>2]|0;o=c[j>>2]|0;p=Ty(o,0,0,1)|0;q=n+8|0;c[q>>2]=p;c[q+4>>2]=F;c[n+44>>2]=277;az(o,0);Yy(o,0);az(a,0);Zy(a,-2555943);Ry(a,d,e);XR(c[g>>2]|0,c[j>>2]|0);o=c[g>>2]|0;n=c[j>>2]|0;q=Ty(n,0,0,1)|0;p=o+8|0;c[p>>2]=q;c[p+4>>2]=F;c[o+44>>2]=4;az(n,0);az(a,1);az(a,1);ZR(a,1310720,1310720);XR(c[g>>2]|0,c[j>>2]|0)}else if((m|0)==93|(m|0)==22){m=h+36|0;n=(c[m>>2]|0)==0;o=c[g>>2]|0;p=c[j>>2]|0;q=Ty(p,0,0,1)|0;r=o+8|0;c[r>>2]=q;c[r+4>>2]=F;r=o+44|0;if(n){c[r>>2]=60;az(p,0);az(a,0);n=Ty(a,0,0,1)|0;o=h+16|0;c[o>>2]=n;c[o+4>>2]=F;az(a,15e3);az(a,c[b+120>>2]|0);az(a,c[b+124>>2]|0);Py(a,0);Py(a,uT(1130216,c[l>>2]|0)|0);XR(c[g>>2]|0,c[j>>2]|0);l=c[g>>2]|0;b=c[j>>2]|0;o=Ty(b,0,0,1)|0;n=l+8|0;c[n>>2]=o;c[n+4>>2]=F;c[l+44>>2]=26;az(b,0);Py(a,54);az(a,1);az(a,0);ZR(a,65536,65536);az(a,c[m>>2]|0);Ry(a,1879984,5);Py(a,0);XR(c[g>>2]|0,c[j>>2]|0)}else{c[r>>2]=26;az(p,0);Py(a,17);az(a,1);az(a,c[m>>2]|0);XR(c[g>>2]|0,c[j>>2]|0)}p=c[g>>2]|0;r=c[j>>2]|0;b=Ty(r,0,0,1)|0;l=p+8|0;c[l>>2]=b;c[l+4>>2]=F;c[p+44>>2]=317;az(r,0);Yy(r,0);az(a,0);r=c[m>>2]|0;c[m>>2]=r+1;az(a,r);Ry(a,d,e);XR(c[g>>2]|0,c[j>>2]|0)}c[k>>2]=(c[k>>2]|0)+1;if((c[h+52>>2]|0)==0){s=c[g>>2]|0;t=c[j>>2]|0;u=0;v=0;w=Ty(t,u,v,1)|0;x=F;y=s+8|0;z=y;A=z|0;c[A>>2]=w;B=z+4|0;c[B>>2]=x;C=s+44|0;D=C;c[D>>2]=1;az(t,0);E=c[g>>2]|0;G=c[j>>2]|0;XR(E,G);i=f;return}k=h+48|0;if((WBb(c[k>>2]|0)|0)==0){s=c[g>>2]|0;t=c[j>>2]|0;u=0;v=0;w=Ty(t,u,v,1)|0;x=F;y=s+8|0;z=y;A=z|0;c[A>>2]=w;B=z+4|0;c[B>>2]=x;C=s+44|0;D=C;c[D>>2]=1;az(t,0);E=c[g>>2]|0;G=c[j>>2]|0;XR(E,G);i=f;return}e=WBb(c[k>>2]|0)|0;d=c[g>>2]|0;r=c[j>>2]|0;m=Ty(r,0,0,1)|0;p=d+8|0;c[p>>2]=m;c[p+4>>2]=F;c[d+44>>2]=275;az(r,0);Yy(r,0);r=h+28|0;az(a,c[r>>2]|0);az(a,0);ZBb(c[k>>2]|0,a,e,1902)|0;XR(c[g>>2]|0,c[j>>2]|0);c[r>>2]=0;s=c[g>>2]|0;t=c[j>>2]|0;u=0;v=0;w=Ty(t,u,v,1)|0;x=F;y=s+8|0;z=y;A=z|0;c[A>>2]=w;B=z+4|0;c[B>>2]=x;C=s+44|0;D=C;c[D>>2]=1;az(t,0);E=c[g>>2]|0;G=c[j>>2]|0;XR(E,G);i=f;return}function ZR(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;i=i+256|0;g=f|0;h=g|0;j=g;k=1;do{if((d|0)==0){l=1}else{m=(d|0)>-1?d:-d|0;if((m|0)==0){l=1;break}else{n=m;o=1}do{o=o+1|0;n=n>>1;}while((n|0)!=0);l=(o|0)>1?o:1}}while(0);if((e|0)==0){p=l}else{o=(e|0)>-1?e:-e|0;if((o|0)==0){q=1}else{n=o;o=1;while(1){m=o+1|0;r=n>>1;if((r|0)==0){q=m;break}else{n=r;o=m}}}p=(q|0)>(l|0)?q:l}l=p|32;k=l;if((p|0)<26){s=26;t=l<<p|d;u=j}else{c[h>>2]=fe(l<<26|d>>>((p-26|0)>>>0)|0)|0;s=58;t=d;u=g+4|0}d=s-p|0;k=t;if((d|0)>(p|0)){v=d-p|0;w=t<<p|e;y=u}else{s=u;x=fe(e>>>((p-d|0)>>>0)|t<<d|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;v=32-p+d|0;w=e;y=u+4|0}k=w;if((v|0)>1){z=v-1|0;A=w<<1|1;B=y}else{u=y;x=fe(1>>>((1-v|0)>>>0)|w<<v|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;z=v+31|0;A=1;B=y+4|0}k=A;if((z|0)>5){C=z-5|0;D=A<<5|1;E=B}else{y=B;x=fe(1>>>((5-z|0)>>>0)|A<<z|0)|0;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;C=z+27|0;D=1;E=B+4|0}k=D;if((C|0)>1){F=C-1|0;G=D<<1;H=E}else{B=E;x=fe(D<<C|0)|0;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;F=C+31|0;G=0;H=E+4|0}k=G;if((F|0)>1){I=F-1|0;J=G<<1;K=H}else{E=H;x=fe(G<<F|0)|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;I=F+31|0;J=0;K=H+4|0}k=J;if((I|0)>5){L=I-5|0;M=J<<5|1;N=K}else{H=K;x=fe(1>>>((5-I|0)>>>0)|J<<I|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;L=I+27|0;M=1;N=K+4|0}k=M;if((L|0)>1){O=L-1|0;P=M<<1;Q=N}else{K=N;x=fe(M<<L|0)|0;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;O=L+31|0;P=0;Q=N+4|0}k=P;if((O|0)>1){R=O-1|0;S=P<<1;T=Q}else{N=Q;x=fe(P<<O|0)|0;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;R=O+31|0;S=0;T=Q+4|0}k=S;if((R|0)>=32){U=T;V=U;W=g;X=V-W|0;Ry(b,j,X);i=f;return}Q=S<<R;k=Q;S=((31-R|0)>>>3)+1|0;O=Q>>>24&255;Q=R;R=T;while(1){a[R]=O;N=k;k=N<<8;P=Q+8|0;if((P|0)<32){O=N>>>16&255;Q=P;R=R+1|0}else{break}}U=T+S|0;V=U;W=g;X=V-W|0;Ry(b,j,X);i=f;return}function _R(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=i;i=i+256|0;g=f|0;h=g|0;j=g;k=0;do{if((d|0)==0){l=0}else{m=(d|0)>-1?d:-d|0;if((m|0)==0){n=1}else{o=m;m=1;do{m=m+1|0;o=o>>1;}while((o|0)!=0);if((m|0)>0){n=m}else{l=0;break}}l=n}}while(0);if((e|0)==0){p=l}else{n=(e|0)>-1?e:-e|0;if((n|0)==0){q=1}else{o=n;n=1;while(1){r=n+1|0;s=o>>1;if((s|0)==0){q=r;break}else{o=s;n=r}}}p=(q|0)>(l|0)?q:l}l=(1<<p)-1|0;k=p;if((p|0)<27){t=27;u=p<<p;v=j}else{c[h>>2]=fe(p<<27|0)|0;t=59;u=0;v=g+4|0}h=t-p|0;k=u;t=l&d;if((h|0)>(p|0)){w=h-p|0;y=u<<p|t;z=v}else{d=v;x=fe(t>>>((p-h|0)>>>0)|u<<h|0)|0;a[d]=x;x=x>>8;a[d+1|0]=x;x=x>>8;a[d+2|0]=x;x=x>>8;a[d+3|0]=x;w=32-p+h|0;y=t;z=v+4|0}k=y;if((w|0)>(p|0)){A=w-p|0;B=y<<p;C=z}else{v=z;x=fe(y<<w|0)|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;A=32-p+w|0;B=0;C=z+4|0}k=B;z=l&e;if((A|0)>(p|0)){D=A-p|0;E=B<<p|z;F=C}else{e=C;x=fe(z>>>((p-A|0)>>>0)|B<<A|0)|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;D=32-p+A|0;E=z;F=C+4|0}k=E;if((D|0)>=32){G=F;H=G;I=g;J=H-I|0;Ry(b,j,J);i=f;return}C=E<<D;k=C;E=((31-D|0)>>>3)+1|0;z=C>>>24&255;C=D;D=F;while(1){a[D]=z;A=k;k=A<<8;p=C+8|0;if((p|0)<32){z=A>>>16&255;C=p;D=D+1|0}else{break}}G=F+E|0;H=G;I=g;J=H-I|0;Ry(b,j,J);i=f;return}function $R(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=b|0;g=c[f>>2]|0;h=b+4|0;i=c[h>>2]|0;if((i|0)>1){j=i-1|0;k=g<<1|1}else{l=fe(1>>>((1-i|0)>>>0)|g<<i|0)|0;g=b+12|0;m=c[g>>2]|0;x=l;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;j=i+31|0;k=1}c[f>>2]=k;c[h>>2]=j;if((j|0)>1){n=j-1|0;o=k<<1|1}else{i=fe(1>>>((1-j|0)>>>0)|k<<j|0)|0;k=b+12|0;g=c[k>>2]|0;x=i;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;n=j+31|0;o=1}c[f>>2]=o;c[h>>2]=n;j=(d|0)==0;do{if(j){p=2}else{k=(d|0)>-1?d:-d|0;if((k|0)==0){p=2;break}else{q=k;r=1}do{r=r+1|0;q=q>>1;}while((q|0)!=0);p=(r|0)>2?r:2}}while(0);r=(e|0)==0;if(r){s=p}else{q=(e|0)>-1?e:-e|0;if((q|0)==0){t=1}else{k=q;q=1;while(1){g=q+1|0;i=k>>1;if((i|0)==0){t=g;break}else{k=i;q=g}}}s=(t|0)>(p|0)?t:p}p=(1<<s)-1|0;t=s-2|0;if((n|0)>4){u=n-4|0;v=o<<4|t}else{q=fe(t>>>((4-n|0)>>>0)|o<<n|0)|0;o=b+12|0;k=c[o>>2]|0;x=q;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;u=n+28|0;v=t}c[f>>2]=v;c[h>>2]=u;t=(u|0)>1;if(j){if(t){w=u-1|0;y=v<<1}else{j=fe(v<<u|0)|0;n=b+12|0;o=c[n>>2]|0;x=j;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;w=u+31|0;y=0}c[f>>2]=y;c[h>>2]=w;if((w|0)>1){z=w-1|0;A=y<<1|1}else{n=fe(1>>>((1-w|0)>>>0)|y<<w|0)|0;y=b+12|0;o=c[y>>2]|0;x=n;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;z=w+31|0;A=1}c[f>>2]=A;c[h>>2]=z;w=p&e;if((z|0)>(s|0)){B=z-s|0;C=A<<s|w}else{y=fe(w>>>((s-z|0)>>>0)|A<<z|0)|0;A=b+12|0;o=c[A>>2]|0;x=y;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;B=32-s+z|0;C=w}c[f>>2]=C;c[h>>2]=B;return}if(r){if(t){D=u-1|0;E=v<<1}else{r=fe(v<<u|0)|0;B=b+12|0;C=c[B>>2]|0;x=r;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;D=u+31|0;E=0}c[f>>2]=E;c[h>>2]=D;if((D|0)>1){F=D-1|0;G=E<<1}else{B=fe(E<<D|0)|0;E=b+12|0;C=c[E>>2]|0;x=B;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;F=D+31|0;G=0}c[f>>2]=G;c[h>>2]=F;D=p&d;if((F|0)>(s|0)){H=F-s|0;I=G<<s|D}else{E=fe(D>>>((s-F|0)>>>0)|G<<F|0)|0;G=b+12|0;C=c[G>>2]|0;x=E;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;H=32-s+F|0;I=D}c[f>>2]=I;c[h>>2]=H;return}else{if(t){J=u-1|0;K=v<<1|1}else{t=fe(1>>>((1-u|0)>>>0)|v<<u|0)|0;v=b+12|0;H=c[v>>2]|0;x=t;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;J=u+31|0;K=1}c[f>>2]=K;c[h>>2]=J;u=p&d;if((J|0)>(s|0)){L=J-s|0;M=K<<s|u}else{d=fe(u>>>((s-J|0)>>>0)|K<<J|0)|0;K=b+12|0;v=c[K>>2]|0;x=d;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[K>>2]=(c[K>>2]|0)+4;L=32-s+J|0;M=u}c[f>>2]=M;c[h>>2]=L;u=p&e;if((L|0)>(s|0)){N=L-s|0;O=M<<s|u}else{e=fe(u>>>((s-L|0)>>>0)|M<<L|0)|0;M=b+12|0;b=c[M>>2]|0;x=e;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[M>>2]=(c[M>>2]|0)+4;N=32-s+L|0;O=u}c[f>>2]=O;c[h>>2]=N;return}}function aS(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,1900064,4)|0)==0;return(b?50:0)|0}function bS(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;b=i;i=i+104|0;e=b|0;f=b+24|0;g=b+32|0;h=b+48|0;j=c[a+12>>2]|0;k=a+16|0;l=c[k>>2]|0;c[f>>2]=0;m=LT(a,0)|0;if((m|0)==0){n=-12;i=b;return n|0}o=m+8|0;p=c[o>>2]|0;c[p+8>>2]=1;c[p+48>>2]=1950507339;c[m+236>>2]=1463898624;p=j;c[p>>2]=0;if((rz(l)|0)!=1264665204){Ty(l,-4,-1,1)|0;n=0;i=b;return n|0}if((Xy(l)|0)!=0){n=-541478725;i=b;return n|0}q=h+48|0;r=m+56|0;s=h+20|0;t=h+40|0;u=h+12|0;v=h+16|0;w=m+48|0;x=e+8|0;y=e+16|0;z=e|0;A=j+8|0;j=f;B=a;C=e+12|0;D=e+4|0;E=a+1156|0;G=g|0;a:while(1){H=(lz(l)|0)&127;I=qz(l)|0;switch(H|0){case 1:case 7:case 4:{if((I|0)<4){n=-1094995529;J=35;break a}K=I-3|0;L=WDb(I+13|0)|0;c[f>>2]=L;if((L|0)==0){n=-12;J=35;break a}TGb(L+K|0,0,16)|0;kz(l,304,13501623);if((mz(l,c[f>>2]|0,K)|0)!=(K|0)){J=10;break a}if((jz(c[k>>2]|0)|0)!=(uz(l)|0)){yDb(B,16,2125392,(M=i,i=i+8|0,c[M>>2]=H,M)|0);i=M;if((c[E>>2]&8|0)!=0){J=13;break a}}L=c[f>>2]|0;N=K>>>0>268435455>>>0?-8:K<<3;K=N>>>0>2147483639>>>0|(L|0)==0;O=K?0:L;L=K?0:N;c[z>>2]=O;c[C>>2]=L;c[y>>2]=L+8;c[D>>2]=O+(L>>3);c[x>>2]=0;break};case 6:{if((I|0)!=19){n=-1094995529;J=35;break a}kz(l,304,13501623);mz(l,G,16)|0;if((jz(c[k>>2]|0)|0)!=(uz(l)|0)){yDb(B,16,2063680,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;if((c[E>>2]&8|0)!=0){n=-1094995529;J=35;break a}}yDb(B,40,2017352,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;L=0;do{yDb(B,40,1975464,(M=i,i=i+8|0,c[M>>2]=d[g+L|0]|0,M)|0);i=M;L=L+1|0;}while((L|0)<16);yDb(B,40,1946560,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;break};case 0:{J=21;break a;break};default:{L=Vy(l,I,(I|0)<0|0?-1:0)|0;O=L;if((O|0)<0){n=O;J=35;break a}}}if((H|0)==7){if((I|0)!=11){n=-1094995529;J=35;break}c[p>>2]=1;O=c[x>>2]|0;L=c[y>>2]|0;N=c[z>>2]|0;K=N+(O>>>3)|0;P=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((O&7)>>>0)&65535;K=O+16|0;O=L>>>0>K>>>0?K:L;c[x>>2]=O;K=N+(O>>>3)|0;Q=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((O&7)>>>0);K=O+16|0;O=L>>>0>K>>>0?K:L;c[x>>2]=O;K=N+(O>>>3)|0;R=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((O&7)>>>0)&255;K=O+8|0;O=L>>>0>K>>>0?K:L;c[x>>2]=O;K=N+(O>>>3)|0;N=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((O&7)>>>0)&16777215;K=O+24|0;c[x>>2]=L>>>0>K>>>0?K:L;L=YGb(N,0,Q<<16|P|0,R|0)|0;c[A>>2]=L;c[A+4>>2]=F;$Db(j)}else if((H|0)==1){c_a(e,h);L=c[q>>2]|0;R=c[q+4>>2]|0;P=0;if((R|0)>(P|0)|(R|0)==(P|0)&L>>>0>0>>>0){c[r>>2]=L;c[r+4>>2]=R}R=c[o>>2]|0;c[R+792>>2]=c[s>>2];L=c[t>>2]|0;P=c[t+4>>2]|0;if(!((L|0)==0&(P|0)==0)){Q=R+448|0;c[Q>>2]=L;c[Q+4>>2]=P}P=c[u>>2]|0;c[R+412>>2]=P;c[R+416>>2]=c[v>>2];c[w>>2]=0;c[w+4>>2]=0;MT(m,64,1,P);c[(c[o>>2]|0)+96>>2]=c[f>>2];c[(c[o>>2]|0)+100>>2]=I-3;c[f>>2]=0}else if((H|0)==4){P=c[x>>2]|0;R=c[y>>2]|0;Q=(c[z>>2]|0)+(P>>>3)|0;L=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((P&7)>>>0)&16777215;Q=P+24|0;c[x>>2]=R>>>0>Q>>>0?Q:R;yDb(B,40,1921400,(M=i,i=i+8|0,c[M>>2]=L,M)|0);i=M;$Db(j)}if((Xy(l)|0)!=0){n=-541478725;J=35;break}}if((J|0)==10){$Db(j);n=-5;i=b;return n|0}else if((J|0)==13){$Db(j);n=-1094995529;i=b;return n|0}else if((J|0)==21){j=Ty(l,0,0,1)|0;M=F;if((c[l+88>>2]|0)!=0){tx(a)|0;Ty(l,j,M,0)|0;}l=YGb(c[A>>2]|0,c[A+4>>2]|0,j,M)|0;c[A>>2]=l;c[A+4>>2]=F;n=0;i=b;return n|0}else if((J|0)==35){i=b;return n|0}return 0}function cS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;if((c[d>>2]|0)==0){e=hO(a,b)|0;return e|0}f=c[a+16>>2]|0;a=d+8|0;d=c[a>>2]|0;g=c[a+4>>2]|0;a=Ty(f,0,0,1)|0;h=ZGb(d,g,a,F)|0;a=F;g=0;d=(a|0)>(g|0)|(a|0)==(g|0)&h>>>0>1024>>>0;g=d?1024:h;h=d?0:a;a=0;if((h|0)<(a|0)|(h|0)==(a|0)&g>>>0<1>>>0){e=-541478725;return e|0}a=TS(f,b,g)|0;if((a|0)<0){e=a;return e|0}c[b+32>>2]=0;e=a;return e|0}function dS(a,b,c){a=a|0;b=b|0;c=c|0;return uBb(tBb(12)|0,a,b,c)|0}function eS(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[b+4>>2]|0;if((a[d+(qd(d|0,2246576)|0)|0]|0)!=123){e=0;return e|0}b=yb(d|0,2337904)|0;if((b|0)==0){f=0}else{f=(a[b+((qd(b+10|0,2246576)|0)+10)|0]|0)==58|0}b=yb(d|0,2313920)|0;if((b|0)==0){g=f}else{g=((a[b+((qd(b+10|0,2246576)|0)+10)|0]|0)==58)+f|0}f=yb(d|0,2293296)|0;if((f|0)==0){h=g}else{h=((a[f+((qd(f+9|0,2246576)|0)+9)|0]|0)==58)+g|0}g=yb(d|0,2276776)|0;if((g|0)==0){i=h}else{i=((a[g+((qd(g+18|0,2246576)|0)+18)|0]|0)==58)+h|0}h=yb(d|0,2261192)|0;if((h|0)==0){j=i}else{j=((a[h+((qd(h+11|0,2246576)|0)+11)|0]|0)==58)+i|0}if((j|0)==5){e=100;return e|0}e=(j|0)!=0?50:0;return e|0}function fS(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;e=i;i=i+2280|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+88|0;s=e+96|0;t=e+104|0;u=e+112|0;v=e+120|0;w=e+128|0;x=e+136|0;y=e+144|0;z=e+152|0;A=e+160|0;B=e+168|0;C=e+176|0;D=e+184|0;E=e+192|0;G=e+200|0;H=e+208|0;I=e+216|0;J=e+224|0;K=e+232|0;L=e+1256|0;M=c[b+12>>2]|0;N=b+16|0;O=c[N>>2]|0;P=M+16|0;Q=P;R=mz(O,I,1)|0;if((R|0)>0){S=d[I]|0}else{S=(R|0)==0?-541478725:R}c[J>>2]=S;R=S;a:while(1){switch(R|0){case 32:case 9:case 10:case 13:{break};case 123:{T=10;break a;break};default:{U=-1094995529;break a}}S=mz(O,H,1)|0;if((S|0)>0){V=d[H]|0}else{V=(S|0)==0?-541478725:S}c[J>>2]=V;R=V}b:do{if((T|0)==10){V=mz(O,G,1)|0;if((V|0)>0){W=d[G]|0}else{W=(V|0)==0?-541478725:V}c[J>>2]=W;if((jS(O,J,K,0)|0)<0){U=-1094995529;break}V=c[J>>2]|0;c:while(1){switch(V|0){case 32:case 9:case 10:case 13:{break};case 58:{break c;break};default:{U=-1094995529;break b}}R=mz(O,E,1)|0;if((R|0)>0){X=d[E]|0}else{X=(R|0)==0?-541478725:R}c[J>>2]=X;V=X}V=mz(O,D,1)|0;if((V|0)>0){Y=d[D]|0}else{Y=(V|0)==0?-541478725:V}c[J>>2]=Y;V=K|0;if((QGb(c[V>>2]|0,2063448)|0)==0){Z=Y}else{U=-1094995529;break}d:while(1){switch(Z|0){case 91:{break d;break};case 32:case 9:case 10:case 13:{break};default:{U=-1094995529;break b}}R=mz(O,C,1)|0;if((R|0)>0){_=d[C]|0}else{_=(R|0)==0?-541478725:R}c[J>>2]=_;Z=_}R=mz(O,B,1)|0;if((R|0)>0){$=d[B]|0}else{$=(R|0)==0?-541478725:R}c[J>>2]=$;R=L+8|0;H=L|0;S=L+4|0;I=$;e:while(1){c[R>>2]=0;aa=I;f:while(1){switch(aa|0){case 123:{break f;break};case 32:case 9:case 10:case 13:{break};default:{T=39;break e}}ba=mz(O,A,1)|0;if((ba|0)>0){ca=d[A]|0}else{ca=(ba|0)==0?-541478725:ba}c[J>>2]=ca;aa=ca}ba=mz(O,z,1)|0;if((ba|0)>0){da=d[z]|0}else{da=(ba|0)==0?-541478725:ba}c[J>>2]=da;ba=Ty(O,0,0,1)|0;ea=YGb(ba,F,-1,-1)|0;ba=F;fa=jS(O,J,K,0)|0;if((fa|0)<0){U=fa;break b}else{ga=-2147483648;ha=0;ia=-2147483648;ja=0}g:while(1){ka=c[J>>2]|0;h:while(1){switch(ka|0){case 58:{break h;break};case 32:case 9:case 10:case 13:{break};default:{T=54;break e}}fa=mz(O,y,1)|0;if((fa|0)>0){la=d[y]|0}else{la=(fa|0)==0?-541478725:fa}c[J>>2]=la;ka=la}fa=mz(O,x,1)|0;if((fa|0)>0){ma=d[x]|0}else{ma=(fa|0)==0?-541478725:fa}c[J>>2]=ma;fa=c[V>>2]|0;i:do{if((QGb(fa,2017224)|0)==0){na=ma;while(1){if(!((na|0)==32|(na|0)==9|(na|0)==10|(na|0)==13)){oa=0;break}pa=mz(O,w,1)|0;if((pa|0)>0){qa=d[w]|0}else{qa=(pa|0)==0?-541478725:pa}c[J>>2]=qa;na=qa}while(1){if((oa|0)>=2){U=-1094995529;break b}ra=c[592696+(oa<<2)>>2]|0;sa=a[ra]|0;if((na|0)==(sa<<24>>24|0)){break}else{oa=oa+1|0}}if(sa<<24>>24==0){ta=na}else{pa=ra;ua=sa;va=na;while(1){if((va|0)!=(ua<<24>>24|0)){U=-1094995529;break b}wa=pa+1|0;xa=mz(O,v,1)|0;if((xa|0)>0){ya=d[v]|0}else{ya=(xa|0)==0?-541478725:xa}c[J>>2]=ya;xa=a[wa]|0;if(xa<<24>>24==0){ta=ya;break}else{pa=wa;ua=xa;va=ya}}}if(((ta|32)-97|0)>>>0<26>>>0){U=-1094995529;break b}else{za=ia;Aa=ja;Ba=ga;Ca=ha;Da=ta}}else{if((QGb(fa,1975312)|0)==0){va=jS(O,J,L,1)|0;if((va|0)<0){U=va;break b}za=ia;Aa=ja;Ba=ga;Ca=ha;Da=c[J>>2]|0;break}if((QGb(fa,1946528)|0)==0){va=ma;while(1){if(!((va|0)==32|(va|0)==9|(va|0)==10|(va|0)==13)){break}ua=mz(O,u,1)|0;if((ua|0)>0){Ea=d[u]|0}else{Ea=(ua|0)==0?-541478725:ua}c[J>>2]=Ea;va=Ea}ua=va-48|0;if(ua>>>0>9>>>0){U=-1094995529;break b}else{Fa=0;Ga=0;Ha=ua}while(1){ua=gHb(Ga,Fa,10,0)|0;pa=YGb(ua,F,Ha,(Ha|0)<0|0?-1:0)|0;ua=F;na=mz(O,t,1)|0;if((na|0)>0){Ia=d[t]|0}else{Ia=(na|0)==0?-541478725:na}c[J>>2]=Ia;na=Ia-48|0;if(na>>>0<10>>>0){Fa=ua;Ga=pa;Ha=na}else{za=ia;Aa=ja;Ba=ua;Ca=pa;Da=Ia;break i}}}if((QGb(fa,1921344)|0)==0){Ja=ma}else{U=-1094995529;break b}while(1){if(!((Ja|0)==32|(Ja|0)==9|(Ja|0)==10|(Ja|0)==13)){break}va=mz(O,s,1)|0;if((va|0)>0){Ka=d[s]|0}else{Ka=(va|0)==0?-541478725:va}c[J>>2]=Ka;Ja=Ka}va=Ja-48|0;if(va>>>0>9>>>0){U=-1094995529;break b}else{La=0;Ma=0;Na=va}while(1){va=gHb(Ma,La,10,0)|0;pa=YGb(va,F,Na,(Na|0)<0|0?-1:0)|0;va=F;ua=mz(O,r,1)|0;if((ua|0)>0){Oa=d[r]|0}else{Oa=(ua|0)==0?-541478725:ua}c[J>>2]=Oa;ua=Oa-48|0;if(ua>>>0<10>>>0){La=va;Ma=pa;Na=ua}else{za=va;Aa=pa;Ba=ga;Ca=ha;Da=Oa;break}}}}while(0);fa=Da;j:while(1){switch(fa|0){case 32:case 9:case 10:case 13:{break};case 44:{break j;break};default:{Pa=fa;break g}}pa=mz(O,q,1)|0;if((pa|0)>0){Qa=d[q]|0}else{Qa=(pa|0)==0?-541478725:pa}c[J>>2]=Qa;fa=Qa}fa=mz(O,p,1)|0;if((fa|0)>0){Ra=d[p]|0}else{Ra=(fa|0)==0?-541478725:fa}c[J>>2]=Ra;fa=jS(O,J,K,0)|0;if((fa|0)<0){U=fa;break b}else{ga=Ba;ha=Ca;ia=za;ja=Aa}}k:while(1){switch(Pa|0){case 125:{break k;break};case 32:case 9:case 10:case 13:{break};default:{T=109;break e}}fa=mz(O,o,1)|0;if((fa|0)>0){Sa=d[o]|0}else{Sa=(fa|0)==0?-541478725:fa}c[J>>2]=Sa;Pa=Sa}fa=mz(O,n,1)|0;if((fa|0)>0){Ta=d[n]|0}else{Ta=(fa|0)==0?-541478725:fa}c[J>>2]=Ta;if((c[R>>2]|0)==0|(Ca|0)==0&(Ba|0)==(-2147483648|0)|(Aa|0)==0&(za|0)==(-2147483648|0)){U=-1094995529;break b}fa=uR(Q,c[H>>2]|0,c[S>>2]|0,0)|0;if((fa|0)==0){U=-12;break b}pa=fa+64|0;c[pa>>2]=ea;c[pa+4>>2]=ba;pa=fa+8|0;c[pa>>2]=Ca;c[pa+4>>2]=Ba;c[fa+48>>2]=Aa;QAb(L,0)|0;fa=c[J>>2]|0;l:while(1){switch(fa|0){case 44:{break l;break};case 32:case 9:case 10:case 13:{break};default:{Ua=fa;T=125;break e}}pa=mz(O,m,1)|0;if((pa|0)>0){Va=d[m]|0}else{Va=(pa|0)==0?-541478725:pa}c[J>>2]=Va;fa=Va}fa=mz(O,l,1)|0;if((fa|0)>0){Wa=d[l]|0}else{Wa=(fa|0)==0?-541478725:fa}c[J>>2]=Wa;I=Wa}if((T|0)==39){U=(aa|0)<0?aa:-1094995529;break}else if((T|0)==54){U=(ka|0)<0?ka:-1094995529;break}else if((T|0)==109){U=(Pa|0)<0?Pa:-1094995529;break}else if((T|0)==125){m:while(1){T=0;switch(Ua|0){case 93:{break m;break};case 32:case 9:case 10:case 13:{break};default:{T=130;break m}}I=mz(O,k,1)|0;if((I|0)>0){Xa=d[k]|0}else{Xa=(I|0)==0?-541478725:I}c[J>>2]=Xa;Ua=Xa;T=125}if((T|0)==130){U=(Ua|0)<0?Ua:-1094995529;break}I=mz(O,j,1)|0;if((I|0)>0){Ya=d[j]|0}else{Ya=(I|0)==0?-541478725:I}c[J>>2]=Ya;I=Ya;n:while(1){switch(I|0){case 32:case 9:case 10:case 13:{break};case 125:{break n;break};default:{T=140;break n}}S=mz(O,h,1)|0;if((S|0)>0){Za=d[h]|0}else{Za=(S|0)==0?-541478725:S}c[J>>2]=Za;I=Za}if((T|0)==140){U=(I|0)<0?I:-1094995529;break}S=mz(O,g,1)|0;if((S|0)>0){_a=d[g]|0}else{_a=(S|0)==0?-541478725:S}c[J>>2]=_a;S=_a;while(1){if((S|0)==(-541478725|0)){U=0;break b}else if(!((S|0)==32|(S|0)==9|(S|0)==10|(S|0)==13)){break}H=mz(O,f,1)|0;if((H|0)>0){$a=d[f]|0}else{$a=(H|0)==0?-541478725:H}c[J>>2]=$a;S=$a}U=(S|0)<0?S:-1094995529;break}}}while(0);if((U|0)<0){if((U|0)==-1094995529){$a=Ty(c[N>>2]|0,0,0,1)|0;N=F;yDb(b,16,2125112,(J=i,i=i+16|0,c[J>>2]=$a,c[J+8>>2]=N,J)|0);i=J}AR(Q);ab=U;i=e;return ab|0}vR(Q);Q=c[M+20>>2]|0;if((Q|0)>0){U=M+8|0;M=c[P>>2]|0;J=0;while(1){N=M+(J*80|0)+8|0;$a=YGb(c[N>>2]|0,c[N+4>>2]|0,c[U>>2]|0,c[U+4>>2]|0)|0;c[N>>2]=$a;c[N+4>>2]=F;N=J+1|0;if((N|0)<(Q|0)){J=N}else{bb=M;break}}}else{bb=c[P>>2]|0}P=Q-1|0;Q=LT(b,0)|0;if((Q|0)==0){ab=-12;i=e;return ab|0}b=c[Q+8>>2]|0;c[b+8>>2]=3;c[b+48>>2]=94210;MT(Q,64,1,1e3);c[Q+228>>2]=0;b=Q+48|0;c[b>>2]=0;c[b+4>>2]=0;b=bb+(P*80|0)+8|0;M=c[bb+(P*80|0)+48>>2]|0;P=YGb(M,(M|0)<0|0?-1:0,c[b>>2]|0,c[b+4>>2]|0)|0;b=Q+56|0;c[b>>2]=P;c[b+4>>2]=F;b=Q+208|0;c[b>>2]=0;c[b+4>>2]=0;ab=0;i=e;return ab|0}function gS(a,b){a=a|0;b=b|0;return yR((c[a+12>>2]|0)+16|0,b)|0}function hS(a){a=a|0;AR((c[a+12>>2]|0)+16|0);return 0}function iS(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR((c[a+12>>2]|0)+16|0,a,b,d,e,f,g,h,i,j)|0}function jS(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+56|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=g+40|0;o=g+48|0;p=(f|0)!=0;IAb(e,0,p?-1:1);f=c[b>>2]|0;a:while(1){switch(f|0){case 32:case 9:case 10:case 13:{break};case 34:{q=8;break a;break};default:{q=7;break a}}r=mz(a,o,1)|0;if((r|0)>0){s=d[o]|0}else{s=(r|0)==0?-541478725:r}c[b>>2]=s;f=s}b:do{if((q|0)==7){t=(f|0)<0?f:-1094995529}else if((q|0)==8){s=mz(a,n,1)|0;if((s|0)>0){u=d[n]|0}else{u=(s|0)==0?-541478725:s}c[b>>2]=u;c:do{if((u|0)<1|(u|0)==34){v=u}else{s=u;d:while(1){do{if((s|0)==92){o=mz(a,m,1)|0;if((o|0)>0){r=d[m]|0;c[b>>2]=r;w=r}else{r=(o|0)==0?-541478725:o;c[b>>2]=r;if((r|0)<0){t=-1094995529;break b}else{w=r}}if((w|32|0)!=117){MAb(e,w&255,1);break}r=mz(a,l,1)|0;if((r|0)>0){x=d[l]|0}else{x=(r|0)==0?-541478725:r}c[b>>2]=x;r=x-48|0;if(r>>>0<10>>>0){y=r}else{o=x|32;if(!((o-97|0)>>>0<26>>>0)){z=x;break d}y=(x|0)<58?r:o-87|0}o=mz(a,l,1)|0;if((o|0)>0){A=d[l]|0}else{A=(o|0)==0?-541478725:o}c[b>>2]=A;o=A-48|0;if(o>>>0<10>>>0){B=o}else{r=A|32;if(!((r-97|0)>>>0<26>>>0)){z=A;break d}B=(A|0)<58?o:r-87|0}r=B+(y<<4)|0;o=mz(a,l,1)|0;if((o|0)>0){C=d[l]|0}else{C=(o|0)==0?-541478725:o}c[b>>2]=C;o=C-48|0;if(o>>>0<10>>>0){D=o}else{E=C|32;if(!((E-97|0)>>>0<26>>>0)){z=C;break d}D=(C|0)<58?o:E-87|0}E=D+(r<<4)|0;r=mz(a,l,1)|0;if((r|0)>0){F=d[l]|0}else{F=(r|0)==0?-541478725:r}c[b>>2]=F;r=F-48|0;if(r>>>0<10>>>0){G=r}else{o=F|32;if(!((o-97|0)>>>0<26>>>0)){z=F;break d}G=(F|0)<58?r:o-87|0}o=G+(E<<4)|0;if(o>>>0<128>>>0){MAb(e,o&255,1);break}E=o>>>0>65535>>>0;r=E?o>>>16:o;H=E?16:0;if((r&65280|0)==0){I=H;J=r}else{I=H|8;J=r>>>8}r=I-2+(d[1191992+J|0]|0)|0;H=(r|0)/5|0;MAb(e,(o>>>((H*6|0)>>>0)|65408>>>(H>>>0))&255,1);if((r|0)>4){K=H}else{break}do{K=K-1|0;MAb(e,(o>>>((K*6|0)>>>0)&63|128)&255,1);}while((K|0)>0)}else{MAb(e,s&255,1)}}while(0);o=mz(a,k,1)|0;if((o|0)>0){L=d[k]|0}else{L=(o|0)==0?-541478725:o}c[b>>2]=L;if((L|0)<1|(L|0)==34){v=L;break c}else{s=L}}t=(z|0)<0?z:-1094995529;break b}}while(0);e:while(1){switch(v|0){case 32:case 9:case 10:case 13:{break};case 34:{break e;break};default:{q=41;break e}}s=mz(a,j,1)|0;if((s|0)>0){M=d[j]|0}else{M=(s|0)==0?-541478725:s}c[b>>2]=M;v=M}if((q|0)==41){t=(v|0)<0?v:-1094995529;break}s=mz(a,h,1)|0;if((s|0)>0){N=d[h]|0}else{N=(s|0)==0?-541478725:s}c[b>>2]=N;if(!p){O=0;i=g;return O|0}if((c[e+4>>2]|0)>>>0<(c[e+8>>2]|0)>>>0){O=0}else{t=-12;break}i=g;return O|0}}while(0);QAb(e,0)|0;O=t;i=g;return O|0}function kS(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;d=i;i=i+248|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+112|0;n=d+176|0;o=d+184|0;p=b+12|0;q=c[p>>2]|0;r=b+32|0;c[n>>2]=r;a:do{if((a[r]|0)==0){s=3}else{t=0;while(1){if((t|0)==16){s=6;break}u=wAb(n,2103624)|0;v=t+1|0;c[o+(t<<2)>>2]=u;if((u|0)==0){w=-12;s=89;break}u=c[n>>2]|0;if((qd(u|0,2103624)|0)==0){x=u}else{y=u+1|0;c[n>>2]=y;x=y}if((a[x]|0)==0){s=2;break}else{t=v}}b:do{if((s|0)==2){if((v|0)==0){s=3;break a}t=q+8|0;y=l|0;u=m|0;z=b;A=b+1140|0;B=b+24|0;C=b+28|0;D=0;while(1){E=o+(D<<2)|0;F=c[E>>2]|0;G=t+(D*12|0)|0;c[j>>2]=0;c[k>>2]=0;c:do{if((qd(F|0,2116696)|0)==0){H=0;I=F}else{J=F+1|0;c[f>>2]=J;if((qd(J|0,2121688)|0)!=0){H=0;I=F+2|0;break}J=GEb(f,2140328,2127768,0,g,h)|0;d:do{if((J|0)<0){K=J;s=15}else{while(1){L=CBb(j,c[g>>2]|0,c[h>>2]|0,12)|0;if((L|0)<0){M=L;break d}L=c[f>>2]|0;N=L+1|0;if((qd(L|0,2121688)|0)!=0){H=0;I=N;break c}c[f>>2]=N;N=GEb(f,2140328,2127768,0,g,h)|0;if((N|0)<0){K=N;s=15;break}}}}while(0);if((s|0)==15){s=0;yDb(z,16,2133880,(O=i,i=i+8|0,c[O>>2]=c[f>>2],O)|0);i=O;M=K}DBb(j);H=M;I=0}}while(0);e:do{if((H|0)<0){P=H}else{J=BBb(c[j>>2]|0,2293272,0,0)|0;if((J|0)==0){Q=0}else{N=J+4|0;J=c[N>>2]|0;c[N>>2]=0;CBb(j,2293272,0,0)|0;Q=J}J=BBb(c[j>>2]|0,2276752,0,0)|0;if((J|0)==0){R=0}else{N=J+4|0;J=c[N>>2]|0;c[N>>2]=0;CBb(j,2276752,0,0)|0;R=J}J=EK(k,0,Q,I)|0;f:do{if((J|0)<0){S=J}else{EBb((c[k>>2]|0)+1140|0,c[A>>2]|0,0);N=dEb(c[B>>2]|0,4)|0;L=N;T=t+(D*12|0)+8|0;c[T>>2]=L;if((N|0)==0){S=-12;break}g:do{if((c[B>>2]|0)!=0){if((R|0)==0){N=0;U=L;while(1){V=c[(c[C>>2]|0)+(N<<2)>>2]|0;c[U+(N<<2)>>2]=N;W=LT(c[k>>2]|0,0)|0;if((W|0)==0){S=-12;break f}c[W+4>>2]=c[V+4>>2];X=V+412|0;Y=W+412|0;Z=c[X+4>>2]|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=Z;Z=V+40|0;Y=W+40|0;X=c[Z+4>>2]|0;c[Y>>2]=c[Z>>2];c[Y+4>>2]=X;X=V+48|0;Y=c[X+4>>2]|0;Z=W+48|0;c[Z>>2]=c[X>>2];c[Z+4>>2]=Y;Y=V+56|0;Z=c[Y+4>>2]|0;X=W+56|0;c[X>>2]=c[Y>>2];c[X+4>>2]=Z;Z=V+64|0;X=c[Z+4>>2]|0;Y=W+64|0;c[Y>>2]=c[Z>>2];c[Y+4>>2]=X;c[W+72>>2]=c[V+72>>2];X=V+80|0;Y=W+80|0;Z=c[X+4>>2]|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=Z;Z=V+92|0;Y=W+92|0;X=c[Z+4>>2]|0;c[Y>>2]=c[Z>>2];c[Y+4>>2]=X;EBb(W+88|0,c[V+88>>2]|0,0);X=BRa(c[W+8>>2]|0,c[V+8>>2]|0)|0;if((X|0)<0){S=X;break f}X=N+1|0;if(!(X>>>0<(c[B>>2]|0)>>>0)){break g}N=X;U=c[T>>2]|0}}else{_=0;$=0}while(1){U=c[(c[C>>2]|0)+(_<<2)>>2]|0;aa=hU(b,U,R)|0;if((aa|0)<0){break}N=(c[T>>2]|0)+(_<<2)|0;if((aa|0)==0){c[N>>2]=-1;ba=$}else{c[N>>2]=$;N=LT(c[k>>2]|0,0)|0;if((N|0)==0){S=-12;break f}c[N+4>>2]=c[U+4>>2];X=U+412|0;V=N+412|0;W=c[X+4>>2]|0;c[V>>2]=c[X>>2];c[V+4>>2]=W;W=U+40|0;V=N+40|0;X=c[W+4>>2]|0;c[V>>2]=c[W>>2];c[V+4>>2]=X;X=U+48|0;V=c[X+4>>2]|0;W=N+48|0;c[W>>2]=c[X>>2];c[W+4>>2]=V;V=U+56|0;W=c[V+4>>2]|0;X=N+56|0;c[X>>2]=c[V>>2];c[X+4>>2]=W;W=U+64|0;X=c[W+4>>2]|0;V=N+64|0;c[V>>2]=c[W>>2];c[V+4>>2]=X;c[N+72>>2]=c[U+72>>2];X=U+80|0;V=N+80|0;W=c[X+4>>2]|0;c[V>>2]=c[X>>2];c[V+4>>2]=W;W=U+92|0;V=N+92|0;X=c[W+4>>2]|0;c[V>>2]=c[W>>2];c[V+4>>2]=X;EBb(N+88|0,c[U+88>>2]|0,0);X=BRa(c[N+8>>2]|0,c[U+8>>2]|0)|0;if((X|0)<0){S=X;break f}else{ba=$+1|0}}X=_+1|0;if(X>>>0<(c[B>>2]|0)>>>0){_=X;$=ba}else{break g}}yDb(z,16,2261136,(O=i,i=i+16|0,c[O>>2]=R,c[O+8>>2]=F,O)|0);i=O;S=aa;break f}}while(0);T=c[k>>2]|0;do{if((c[(c[T+8>>2]|0)+28>>2]&1|0)==0){L=Gz(T+16|0,I,2)|0;if((L|0)<0){TGb(y|0,0,64)|0;a[y]=0;GBb(L,y,64)|0;yDb(z,16,2246536,(O=i,i=i+16|0,c[O>>2]=F,c[O+8>>2]=y,O)|0);i=O;S=L;break f}else{ca=c[k>>2]|0;break}}else{ca=T}}while(0);T=FK(ca,j)|0;if((T|0)<0){TGb(u|0,0,64)|0;a[u]=0;GBb(T,u,64)|0;yDb(z,16,2233856,(O=i,i=i+16|0,c[O>>2]=F,c[O+8>>2]=u,O)|0);i=O;S=T;break}L=c[k>>2]|0;c[G>>2]=L;X=dEb(c[L+24>>2]|0,12)|0;L=t+(D*12|0)+4|0;c[L>>2]=X;if((X|0)==0){S=-12;break}X=BBb(c[j>>2]|0,2220808,0,2)|0;h:do{if((X|0)==0){da=T}else{U=T;N=X;i:while(1){ea=N|0;fa=c[ea>>2]|0;V=fa+4|0;ga=a[V]|0;if(ga<<24>>24==0){ha=V}else{if((qd(V|0,2146328)|0)!=1){s=50;break}ha=fa+5|0}V=c[k>>2]|0;if((c[V+24>>2]|0)==0){ia=U;ja=fa}else{ka=N+4|0;la=0;W=V;while(1){ma=hU(W,c[(c[W+28>>2]|0)+(la<<2)>>2]|0,ha)|0;if((ma|0)<0){s=55;break i}do{if((ma|0)>0){V=c[ka>>2]|0;yDb(z,48,2195400,(O=i,i=i+32|0,c[O>>2]=ha,c[O+8>>2]=V,c[O+16>>2]=la,c[O+24>>2]=I,O)|0);i=O;V=(c[L>>2]|0)+(la<<2)|0;if((c[V>>2]|0)!=0){yDb(z,24,2180104,(O=i,i=i+16|0,c[O>>2]=la,c[O+8>>2]=I,O)|0);i=O;na=ma;break}Y=eEb(c[ka>>2]|0)|0;if((Y|0)==0){oa=-12;s=65;break i}Z=xAb(Y,1879856,e)|0;j:do{if((Z|0)==0){pa=0}else{qa=V;ra=Z;while(1){sa=S_(ra)|0;if((sa|0)==0){break}c[qa>>2]=sa;ta=xAb(0,1879856,e)|0;if((ta|0)==0){pa=0;break j}else{qa=sa+12|0;ra=ta}}yDb(z,16,2153456,(O=i,i=i+8|0,c[O>>2]=ra,O)|0);i=O;pa=-1313558101}}while(0);ZDb(Y);if((pa|0)<0){oa=pa;s=65;break i}else{na=0}}else{na=0}}while(0);Z=la+1|0;V=c[k>>2]|0;if(Z>>>0<(c[V+24>>2]|0)>>>0){la=Z;W=V}else{break}}ia=na;ja=c[ea>>2]|0}CBb(j,ja,0,0)|0;W=BBb(c[j>>2]|0,2220808,0,2)|0;if((W|0)==0){da=ia;break h}else{U=ia;N=W}}if((s|0)==50){s=0;yDb(z,16,2211568,(O=i,i=i+24|0,c[O>>2]=fa,c[O+8>>2]=ga<<24>>24,c[O+16>>2]=2146328,O)|0);i=O;P=-22;break e}else if((s|0)==55){s=0;N=c[ea>>2]|0;yDb(z,16,2202512,(O=i,i=i+24|0,c[O>>2]=ha,c[O+8>>2]=N,c[O+16>>2]=I,O)|0);i=O;S=ma;break f}else if((s|0)==65){s=0;yDb(z,16,2166920,(O=i,i=i+24|0,c[O>>2]=c[ka>>2],c[O+8>>2]=la,c[O+16>>2]=I,O)|0);i=O;S=oa;break f}}}while(0);L=c[j>>2]|0;if((L|0)==0){S=da;break}X=BBb(L,9203632,0,2)|0;if((X|0)==0){S=-1414549496;break}else{ua=X}while(1){yDb(c[k>>2]|0,16,2160264,(O=i,i=i+8|0,c[O>>2]=c[ua>>2],O)|0);i=O;X=BBb(c[j>>2]|0,9203632,ua,2)|0;if((X|0)==0){S=-1414549496;break}else{ua=X}}}}while(0);ZDb(Q);ZDb(R);DBb(j);P=S}}while(0);if((P|0)<0){w=P;s=89;break b}F=G|0;J=c[F>>2]|0;X=c[c[J+8>>2]>>2]|0;yDb(z,40,1975152,(O=i,i=i+16|0,c[O>>2]=J+32,c[O+8>>2]=X,O)|0);i=O;X=c[F>>2]|0;if((c[X+24>>2]|0)!=0){J=t+(D*12|0)+4|0;L=0;T=X;do{X=c[(c[J>>2]|0)+(L<<2)>>2]|0;N=(c[(c[T+28>>2]|0)+(L<<2)>>2]|0)+8|0;U=H0a(c[(c[N>>2]|0)+48>>2]|0)|0;W=lGb(c[(c[N>>2]|0)+8>>2]|0)|0;yDb(z,40,1946416,(O=i,i=i+24|0,c[O>>2]=L,c[O+8>>2]=U,c[O+16>>2]=W,O)|0);i=O;if((X|0)!=0){yDb(z,40,1921328,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;W=X;do{X=W+12|0;U=(c[X>>2]|0)!=0?1879856:9203632;yDb(z,40,1899968,(O=i,i=i+16|0,c[O>>2]=c[c[W+4>>2]>>2],c[O+8>>2]=U,O)|0);i=O;W=c[X>>2]|0;}while((W|0)!=0)}yDb(z,40,2313864,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;L=L+1|0;T=c[F>>2]|0;}while(L>>>0<(c[T+24>>2]|0)>>>0)}$Db(E);T=D+1|0;if(T>>>0<v>>>0){D=T}else{va=B;wa=v;break a}}}else if((s|0)==6){yDb(b,16,2063144,(O=i,i=i+8|0,c[O>>2]=16,O)|0);i=O;xa=16;ya=-1163346256;s=90}}while(0);if((s|0)==89){if((v|0)==0){za=w}else{xa=v;ya=w;s=90}}if((s|0)==90){B=0;while(1){$Db(o+(B<<2)|0);D=B+1|0;if(D>>>0<xa>>>0){B=D}else{za=ya;break}}}nS(c[p>>2]|0);Aa=za;i=d;return Aa|0}}while(0);if((s|0)==3){va=b+24|0;wa=0}za=q+4|0;c[za>>2]=wa;p=c[va>>2]|0;if((p|0)==0){Aa=0;i=d;return Aa|0}ya=b;b=q+8|0;q=0;xa=p;p=wa;while(1){if((p|0)==0){s=86}else{wa=0;o=0;do{o=((c[(c[b+(wa*12|0)+8>>2]|0)+(q<<2)>>2]|0)>>>31^1)+o|0;wa=wa+1|0;}while(wa>>>0<p>>>0);if((o|0)==0){s=86}else{Ba=xa}}if((s|0)==86){s=0;yDb(ya,24,2016936,(O=i,i=i+8|0,c[O>>2]=q,O)|0);i=O;Ba=c[va>>2]|0}wa=q+1|0;if(!(wa>>>0<Ba>>>0)){Aa=0;break}q=wa;xa=Ba;p=c[za>>2]|0}i=d;return Aa|0}function lS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;i=i+168|0;e=d|0;f=d+80|0;g=d+160|0;h=g;j=i;i=i+8|0;k=j;l=c[a+12>>2]|0;m=l+4|0;if((c[m>>2]|0)==0){n=0;i=d;return n|0}o=l+8|0;l=b+32|0;p=a+28|0;a=b+8|0;q=f+8|0;r=b+16|0;s=f+16|0;t=b+48|0;u=f+48|0;v=f+32|0;w=e;x=f;y=e+24|0;z=e+28|0;A=f+24|0;B=f+28|0;C=f+36|0;D=e+52|0;E=e|0;G=0;H=0;while(1){I=c[o+(G*12|0)>>2]|0;J=c[l>>2]|0;K=c[(c[o+(G*12|0)+8>>2]|0)+(J<<2)>>2]|0;do{if((K|0)<0){L=H}else{if((EZ(f,b)|0)<0){if((H|0)==0){L=0;break}}else{if((CZ(f)|0)<0&(H|0)==0){L=0;break}}M=(c[(c[p>>2]|0)+(J<<2)>>2]|0)+40|0;N=c[M+4>>2]|0;c[g>>2]=c[M>>2];c[g+4>>2]=N;N=I+28|0;M=(c[(c[N>>2]|0)+(K<<2)>>2]|0)+40|0;O=c[M+4>>2]|0;c[j>>2]=c[M>>2];c[j+4>>2]=O;O=KDb(c[a>>2]|0,c[a+4>>2]|0,h,k)|0;c[q>>2]=O;c[q+4>>2]=F;O=KDb(c[r>>2]|0,c[r+4>>2]|0,h,k)|0;c[s>>2]=O;c[s+4>>2]=F;O=c[t>>2]|0;M=KDb(O,(O|0)<0|0?-1:0,h,k)|0;c[u>>2]=M;c[v>>2]=K;M=I;O=c[(c[o+(G*12|0)+4>>2]|0)+(K<<2)>>2]|0;P=c[(c[(c[N>>2]|0)+(K<<2)>>2]|0)+8>>2]|0;do{if((O|0)!=0){N=O;a:while(1){UGb(w|0,x|0,80)|0;Q=U_(N,P,0,y,z,c[A>>2]|0,c[B>>2]|0,c[C>>2]&1)|0;do{if((Q|0)==0){if((c[y>>2]|0)==(c[A>>2]|0)){R=0;break}if((c[D>>2]|0)==0){S=12;break}if((EZ(e,f)|0)<0){T=N;break a}else{U=1;S=13}}else{S=12}}while(0);if((S|0)==12){S=0;if((Q|0)>0){U=Q;S=13}else{R=Q}}if((S|0)==13){S=0;BZ(f);V=SAb(c[y>>2]|0,c[z>>2]|0,98,0,0)|0;c[E>>2]=V;if((V|0)==0){W=U;X=N;S=15;break}else{R=U}}UGb(x|0,w|0,80)|0;V=c[N+12>>2]|0;if((V|0)==0){W=R;X=0;S=15;break}else{N=V}}if((S|0)==15){S=0;if((W|0)<0){T=X}else{break}}N=c[c[T+4>>2]>>2]|0;V=c[v>>2]|0;Y=H0a(c[P+48>>2]|0)|0;yDb(M,16,2124528,(Z=i,i=i+32|0,c[Z>>2]=N,c[Z+8>>2]=V,c[Z+16>>2]=I+32,c[Z+24>>2]=Y,Z)|0);i=Z}}while(0);M=MK(I,f)|0;L=(M|0)<0&(H|0)==0?M:H}}while(0);I=G+1|0;if(I>>>0<(c[m>>2]|0)>>>0){G=I;H=L}else{n=L;break}}i=d;return n|0}function mS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+12|0;a=c[b>>2]|0;d=a+4|0;if((c[d>>2]|0)==0){e=0;f=a;nS(f);return e|0}g=a+8|0;a=0;h=0;while(1){i=c[g+(h*12|0)>>2]|0;j=NK(i)|0;k=(j|0)<0&(a|0)==0?j:a;if((c[(c[i+8>>2]|0)+28>>2]&1|0)==0){j=i+16|0;i=Iz(c[j>>2]|0)|0;c[j>>2]=0;l=(i|0)<0&(k|0)==0?i:k}else{l=k}k=h+1|0;if(k>>>0<(c[d>>2]|0)>>>0){a=l;h=k}else{break}}e=l;f=c[b>>2]|0;nS(f);return e|0}function nS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a+4|0;if((c[b>>2]|0)==0){return}d=a+8|0;a=0;do{e=d+(a*12|0)|0;f=c[e>>2]|0;g=f+24|0;h=c[g>>2]|0;i=d+(a*12|0)+4|0;if((h|0)!=0){j=0;k=h;while(1){h=c[(c[i>>2]|0)+(j<<2)>>2]|0;if((h|0)==0){l=k}else{m=h;while(1){h=c[m+12>>2]|0;T_(m);if((h|0)==0){break}else{m=h}}l=c[g>>2]|0}m=j+1|0;if(m>>>0<l>>>0){j=m;k=l}else{break}}}$Db(d+(a*12|0)+8|0);$Db(i);k=f+16|0;Iz(c[k>>2]|0)|0;c[k>>2]=0;bT(f);c[e>>2]=0;a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function oS(a){a=a|0;var b=0,e=0,f=0.0,i=0.0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=5261396){e=0;return e|0}a=b+16|0;b=fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0;f=(c[k>>2]=b,+g[k>>2]);i=f;if(i<.1|f>1.0e3){e=25;return e|0}else{h[k>>3]=i;e=c[k+4>>2]&2147483647;b=2146435072;return(e>>>0>b>>>0|e>>>0==b>>>0&(c[k>>2]|0)>>>0>0>>>0?25:100)|0}return 0}function pS(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=i;i=i+8|0;e=d|0;f=c[b+12>>2]|0;h=c[b+16>>2]|0;j=Wy(h)|0;l=F;vz(h)|0;m=f;c[m>>2]=vz(h)|0;vz(h)|0;vz(h)|0;n=f+24|0;o=vz(h)|0;lFb(e,(c[k>>2]=o,+g[k>>2]),2147483647);o=n;p=c[e+4>>2]|0;c[o>>2]=c[e>>2];c[o+4>>2]=p;p=f+20|0;c[p>>2]=vz(h)|0;o=f+8|0;c[o>>2]=vz(h)|0;e=vz(h)|0;q=e;r=0;s=h+96|0;c[s>>2]=q;c[s+4>>2]=r;t=0;do{if((l|0)>(t|0)|(l|0)==(t|0)&j>>>0>0>>>0){if(!((e|0)==0|((l|0)<(r|0)|(l|0)==(r|0)&j>>>0<q>>>0))){break}c[s>>2]=j;c[s+4>>2]=l}}while(0);l=f+16|0;c[l>>2]=vz(h)|0;vz(h)|0;s=f+4|0;c[s>>2]=vz(h)|0;c[f+12>>2]=vz(h)|0;c[f+48>>2]=c[o>>2];o=f+40|0;c[o>>2]=c[s>>2];c[o+4>>2]=0;o=c[l>>2]|0;Ty(h,o,(o|0)<0|0?-1:0,0)|0;o=f+60|0;c[o>>2]=vz(h)|0;mz(h,f+64|0,16)|0;l=f+84|0;s=f+80|0;if((c[o>>2]|0)<=0){u=0;i=d;return u|0}j=f+28|0;q=n;n=f+52|0;r=f+56|0;e=0;a:while(1){t=a[f+(e+64)|0]|0;do{if((t<<24>>24|0)==1){if((c[l>>2]|0)!=0){u=0;v=15;break a}w=LT(b,0)|0;if((w|0)==0){u=-12;v=15;break a}x=w+8|0;y=c[x>>2]|0;c[y+8>>2]=1;c[y+48>>2]=69650;c[y+52>>2]=0;y=vz(h)|0;c[(c[x>>2]|0)+416>>2]=y;y=vz(h)|0;c[(c[x>>2]|0)+412>>2]=y;MT(w,64,1,y);c[r>>2]=c[w>>2];c[l>>2]=1}else if((t<<24>>24|0)==0){if((c[s>>2]|0)!=0){u=0;v=15;break a}w=LT(b,0)|0;if((w|0)==0){u=-12;v=15;break a}MT(w,64,c[j>>2]|0,c[q>>2]|0);y=w+8|0;x=c[y>>2]|0;c[x+8>>2]=0;c[x+48>>2]=101;c[x+52>>2]=0;x=vz(h)|0;c[(c[y>>2]|0)+120>>2]=x;x=vz(h)|0;c[(c[y>>2]|0)+124>>2]=x;x=c[p>>2]|0;y=0;z=w+56|0;c[z>>2]=x;c[z+4>>2]=y;z=w+64|0;c[z>>2]=x;c[z+4>>2]=y;c[s>>2]=w;c[n>>2]=c[w>>2];if((c[m>>2]|0)!=69632){break}vz(h)|0}}while(0);t=e+1|0;if((t|0)<(c[o>>2]|0)){e=t}else{u=0;v=15;break}}if((v|0)==15){i=d;return u|0}return 0}function qS(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[a+12>>2]|0;f=c[a+16>>2]|0;a=e+88|0;g=c[a>>2]|0;if((g|0)!=0){h=TS(f,b,g)|0;if((h|0)!=(c[a>>2]|0)){BZ(b);i=-5;return i|0}c[b+32>>2]=c[e+56>>2];if((c[a>>2]|0)>>>0>7>>>0){h=(c[b+24>>2]|0)+4|0;c[b+48>>2]=fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0}c[a>>2]=0;h=e+32|0;c[h>>2]=(c[h>>2]|0)+1;i=0;return i|0}h=e+32|0;if(!((c[h>>2]|0)>>>0<(c[e+20>>2]|0)>>>0)){i=-541478725;return i|0}g=e+40|0;Ty(f,c[g>>2]|0,c[g+4>>2]|0,0)|0;j=e+48|0;k=c[j>>2]|0;l=k>>>0>1>>>0;m=YGb(l?k:1,l?0:0,c[g>>2]|0,c[g+4>>2]|0)|0;c[g>>2]=m;c[g+4>>2]=F;c[j>>2]=vz(f)|0;vz(f)|0;j=vz(f)|0;if((c[e+84>>2]|0)==0){c[h>>2]=(c[h>>2]|0)+1}else{c[a>>2]=vz(f)|0}if((TS(f,b,j)|0)==(j|0)){c[b+32>>2]=c[e+52>>2];i=0;return i|0}else{BZ(b);i=-5;return i|0}return 0}function rS(b){b=b|0;var d=0,e=0,f=0;if((c[b+8>>2]|0)<258){d=0;return d|0}e=c[b+4>>2]|0;b=0;while(1){if((b|0)>=256){break}if((a[e+b|0]|0)==0){b=b+1|0}else{d=0;f=8;break}}if((f|0)==8){return d|0}do{if((a[e+256|0]|0)==0){if((a[e+257|0]|0)==0){d=0}else{break}return d|0}}while(0);d=25;return d|0}function sS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;d=b;e=c[a+16>>2]|0;Ty(e,256,0,0)|0;f=0;while(1){if((f|0)>=30){break}g=pz(e)|0;if((g|0)==0){break}c[d+16+(f*12|0)>>2]=0;c[d+16+(f*12|0)+4>>2]=g;h=WDb(g)|0;c[d+16+(f*12|0)+8>>2]=h;if((h|0)==0){i=-12;j=11;break}else{f=f+1|0}}if((j|0)==11){return i|0}c[b+376>>2]=f;c[b+12>>2]=0;f=1;while(1){if((f|0)>=101){break}h=vS(d,e)|0;if((h|0)==0){f=f+1|0}else{i=h;j=11;break}}if((j|0)==11){return i|0}c[b+8>>2]=0;c[b+404>>2]=0;j=LT(a,0)|0;if((j|0)==0){i=-12;return i|0}MT(j,32,1,25);c[b+4>>2]=c[j>>2];f=c[j+8>>2]|0;c[f+8>>2]=0;c[f+48>>2]=96;c[f+52>>2]=0;c[f+120>>2]=256;c[f+124>>2]=128;f=LT(a,0)|0;if((f|0)==0){i=-12;return i|0}a=f+48|0;c[a>>2]=0;c[a+4>>2]=0;MT(f,32,1,22050);c[b>>2]=c[f>>2];b=c[f+8>>2]|0;c[b+8>>2]=1;c[b+48>>2]=65537;c[b+52>>2]=0;c[b+416>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;c[b+412>>2]=22050;c[b+792>>2]=16;c[b+72>>2]=352800;c[b+432>>2]=2;i=0;return i|0}function tS(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;b=e+404|0;do{if((c[b>>2]|0)==0){g=vS(e,f)|0;if((g|0)!=0){h=g;return h|0}g=e+388|0;i=c[g>>2]|0;j=e+396|0;k=c[j>>2]|0;if((i|0)==(-k|0)){break}if((wZ(d,i+1+k|0)|0)!=0){h=-12;return h|0}k=d+24|0;a[c[k>>2]|0]=0;do{if((c[g>>2]|0)!=0){i=c[k>>2]|0;a[i]=a[i]|1;Ty(f,(c[e+392>>2]|0)+(c[e+12>>2]|0)|0,0,0)|0;i=mz(f,(c[k>>2]|0)+1|0,c[g>>2]|0)|0;if((i|0)==(c[g>>2]|0)){break}else{h=-5}return h|0}}while(0);if((c[j>>2]|0)!=0){i=c[k>>2]|0;a[i]=a[i]|2;UGb((c[k>>2]|0)+((c[g>>2]|0)+1)|0,c[e+400>>2]|0,c[j>>2]|0)|0}c[d+32>>2]=c[e+4>>2];i=c[e+8>>2]|0;l=d+8|0;c[l>>2]=i;c[l+4>>2]=(i|0)<0|0?-1:0;c[b>>2]=1;h=0;return h|0}}while(0);i=c[e+384>>2]|0;if((i|0)==0){h=-5;return h|0}Ty(f,(c[e+12>>2]|0)+i|0,0,0)|0;i=TS(f,d,c[e+380>>2]|0)|0;if((i|0)<0){h=i;return h|0}c[d+32>>2]=c[e>>2];d=e+8|0;c[d>>2]=(c[d>>2]|0)+1;c[b>>2]=0;h=0;return h|0}function uS(a){a=a|0;var b=0;b=(c[a+12>>2]|0)+16|0;a=0;do{ZDb(c[b+(a*12|0)+8>>2]|0);a=a+1|0;}while((a|0)<30);return 0}function vS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+32|0;e=d|0;f=d+16|0;g=a+12|0;h=(c[g>>2]|0)+6144|0;c[g>>2]=h;Ty(b,h,(h|0)<0|0?-1:0,0)|0;h=pz(b)|0;c[a+384>>2]=h;c[a+380>>2]=(h|0)==0?0:1764;h=pz(b)|0;c[a+392>>2]=h;c[a+388>>2]=(h|0)==0?0:768;h=lz(b)|0;c[f>>2]=h;c[f+4>>2]=lz(b)|0;c[f+8>>2]=lz(b)|0;c[f+12>>2]=lz(b)|0;j=pz(b)|0;c[e>>2]=j;c[e+4>>2]=pz(b)|0;c[e+8>>2]=pz(b)|0;c[e+12>>2]=pz(b)|0;k=1;l=j;while(1){if((l|0)!=0){j=k;while(1){m=c[e+(j<<2)>>2]|0;if((j|0)>=3){break}if((m|0)==0){j=j+1|0}else{break}}j=c[f+(k<<2)>>2]|0;n=m-l|0;if((j|0)>29){o=-1094995529;p=15;break}q=a+16+(j*12|0)|0;if(((c[q>>2]|0)+n|0)>(c[a+16+(j*12|0)+4>>2]|0)|(n|0)<1){o=-1094995529;p=15;break}Ty(b,(c[g>>2]|0)+l|0,0,0)|0;if((mz(b,(c[a+16+(j*12|0)+8>>2]|0)+(c[q>>2]|0)|0,n)|0)!=(n|0)){o=-5;p=15;break}c[q>>2]=(c[q>>2]|0)+n}if((k|0)>=3){p=11;break}n=c[e+(k<<2)>>2]|0;k=k+1|0;l=n}if((p|0)==11){if((h|0)==255){c[a+396>>2]=0;c[a+400>>2]=0;o=0;i=d;return o|0}if(h>>>0>29>>>0){o=-1094995529;i=d;return o|0}l=a+16+(h*12|0)|0;c[a+396>>2]=c[l>>2];c[a+400>>2]=c[a+16+(h*12|0)+8>>2];c[l>>2]=0;o=0;i=d;return o|0}else if((p|0)==15){i=d;return o|0}return 0}function wS(b){b=b|0;var e=0,f=0,g=0,h=0;e=c[b+4>>2]|0;b=e;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)!=1447120212){f=0;return f|0}b=e+4|0;if(!(((d[b]|d[b+1|0]<<8)<<16>>16&65535)>>>0>4999>>>0)){f=0;return f|0}b=e+6|0;if(!(((d[b]|d[b+1|0]<<8)<<16>>16&65535)>>>0>40>>>0)){f=0;return f|0}if((a[e+8|0]|0)!=0){f=0;return f|0}b=a[e+9|0]|0;if(b<<24>>24==0){f=0;return f|0}g=a[e+10|0]|0;if(g<<24>>24==0){f=0;return f|0}if(b<<24>>24==40){h=g<<24>>24==25?1:4}else{h=4}f=100/(h>>>0)|0;return f|0}function xS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+8|0;d=b|0;e=c[a+12>>2]|0;f=c[a+16>>2]|0;if((rz(f)|0)!=1447120212){g=-1;i=b;return g|0}h=LT(a,0)|0;if((h|0)==0){g=-12;i=b;return g|0}j=LT(a,0)|0;if((j|0)==0){g=-12;i=b;return g|0}k=pz(f)|0;l=j+8|0;c[(c[l>>2]|0)+412>>2]=k;if((k|0)==0){yDb(a,16,2124368,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;g=-1;i=b;return g|0}k=pz(f)|0;n=e;c[n>>2]=k;if((k|0)==0){yDb(a,16,2062928,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;g=-1;i=b;return g|0}k=lz(f)|0;if((k|0)!=0){yDb(a,16,2016752,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;g=-1;i=b;return g|0}k=lz(f)|0;o=lz(f)|0;p=e+4|0;c[p>>2]=ba(k<<1,o)|0;q=lz(f)|0;f=q&-4;if((f|0)!=0){yDb(a,16,1974968,(m=i,i=i+8|0,c[m>>2]=f,m)|0);i=m;g=-1;i=b;return g|0}m=c[l>>2]|0;c[m+8>>2]=1;c[m+48>>2]=65541;f=m+416|0;if((q&2|0)==0){c[f>>2]=1;a=m+448|0;c[a>>2]=4;c[a+4>>2]=0}else{c[f>>2]=2;f=m+448|0;c[f>>2]=3;c[f+4>>2]=0}c[m+792>>2]=8;f=c[m+412>>2]|0;c[m+72>>2]=f<<3;MT(j,32,1,f);f=c[l>>2]|0;l=ba(c[f+416>>2]|0,c[f+412>>2]|0)|0;f=d|0;c[f>>2]=l;j=c[n>>2]|0;m=d+4|0;c[m>>2]=j;iFb(f,m,l,(l|0)<0|0?-1:0,j,(j|0)<0|0?-1:0,-1,0)|0;j=h+8|0;l=c[j>>2]|0;c[l+8>>2]=0;c[l+48>>2]=127;c[l+140>>2]=11;c[l+120>>2]=k<<3;c[l+124>>2]=o<<3;MT(h,32,c[m>>2]|0,c[f>>2]|0);h=c[p>>2]|0;if((q&1|0)==0){r=c[e+8>>2]|0}else{q=(c[n>>2]|0)+h|0;n=(q+511&-512)-q|0;c[e+8>>2]=n;r=n}n=ba(c[f>>2]<<3,r+h|0)|0;c[(c[j>>2]|0)+72>>2]=(n>>>0)/((c[m>>2]|0)>>>0)|0;g=0;i=b;return g|0}function yS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;a=d+12|0;f=c[((c[a>>2]|0)==0?d+4|0:d)>>2]|0;if((Xy(e)|0)!=0){g=-541478725;return g|0}h=TS(e,b,f)|0;if((c[a>>2]|0)==0){i=0}else{Vy(e,c[d+8>>2]|0,0)|0;i=c[a>>2]|0}c[b+32>>2]=i;c[a>>2]=c[a>>2]^1;a=b+36|0;c[a>>2]=c[a>>2]|1;g=h;return g|0}function zS(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;f=c[a+12>>2]|0;if((b|0)!=0){g=-1;return g|0}b=gHb((c[f+4>>2]|0)+(c[f>>2]|0)+(c[f+8>>2]|0)|0,0,d,e)|0;e=c[a+16>>2]|0;a=YGb(b,F,12,0)|0;b=Ty(e,a,F,0)|0;a=F;e=0;if((a|0)<(e|0)|(a|0)==(e|0)&b>>>0<0>>>0){g=-1;return g|0}c[f+12>>2]=0;g=0;return g|0}function AS(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==826365012){e=b+4|0;if(!((((d[e]|d[e+1|0]<<8)<<16>>16)-1&65535)>>>0<2>>>0)){break}e=b+6|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}e=b+8|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}e=b+10|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==0){break}else{f=80}return f|0}}while(0);f=0;return f|0}function BS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;d=c[a+12>>2]|0;mX(a);e=a+16|0;f=Ty(c[e>>2]|0,0,0,1)|0;g=F;kz(c[e>>2]|0,180,-1);if((rz(c[e>>2]|0)|0)!=826365012){h=-1094995529;i=b;return h|0}Vy(c[e>>2]|0,2,0)|0;j=pz(c[e>>2]|0)|0;k=pz(c[e>>2]|0)|0;l=rz(c[e>>2]|0)|0;if((l-1|0)>>>0>999999>>>0){yDb(a,16,2062904,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}n=rz(c[e>>2]|0)|0;if((n|0)==0){yDb(a,16,2016720,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}o=~(jz(c[e>>2]|0)|0);if((rz(c[e>>2]|0)|0)!=(o|0)){yDb(a,16,1974944,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}o=(l<<8|0)/245|0;p=d+8|0;c[p>>2]=o;q=(n>>>0)%(o>>>0)|0;r=(q|0)==0?o:q;c[d+12>>2]=r;q=((r|0)<(o|0))+((n>>>0)/(o>>>0)|0)|0;o=d;c[o>>2]=q;c[d+4>>2]=0;if(q>>>0>1073741822>>>0|(q|0)<1){yDb(a,16,1946304,(m=i,i=i+8|0,c[m>>2]=q,m)|0);i=m;h=-1094995529;i=b;return h|0}q=LT(a,0)|0;if((q|0)==0){h=-12;i=b;return h|0}MT(q,64,1,l);d=q+48|0;c[d>>2]=0;c[d+4>>2]=0;d=q+56|0;c[d>>2]=n;c[d+4>>2]=0;d=Ty(c[e>>2]|0,0,0,1)|0;n=F;r=c[o>>2]|0;s=q+8|0;t=c[s>>2]|0;u=Ty(c[e>>2]|0,0,0,1)|0;v=ZGb(u,F,f,g)|0;if((BT(t,v)|0)!=0){h=-12;i=b;return h|0}Ty(c[e>>2]|0,f,g,0)|0;g=c[s>>2]|0;mz(c[e>>2]|0,c[g+96>>2]|0,c[g+100>>2]|0)|0;kz(c[e>>2]|0,180,-1);g=c[e>>2]|0;if((c[o>>2]|0)>0){f=r<<2;r=YGb(d,n,4,0)|0;n=YGb(r,F,f,(f|0)<0|0?-1:0)|0;f=F;r=n;n=0;d=g;while(1){v=rz(d)|0;t=ba(c[p>>2]|0,n)|0;jT(q,r,f,t,(t|0)<0|0?-1:0,v,0,1)|0;t=YGb(v,0,r,f)|0;v=n+1|0;u=c[e>>2]|0;if((v|0)<(c[o>>2]|0)){f=F;r=t;n=v;d=u}else{w=u;break}}}else{w=g}g=~(jz(w)|0);if((rz(c[e>>2]|0)|0)!=(g|0)){yDb(a,16,1921240,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}m=c[s>>2]|0;c[m+8>>2]=1;c[m+48>>2]=86038;c[m+416>>2]=j;c[m+412>>2]=l;c[m+792>>2]=k;k=c[e>>2]|0;if((c[k+88>>2]|0)==0){h=0;i=b;return h|0}m=Ty(k,0,0,1)|0;k=F;tx(a)|0;Ty(c[e>>2]|0,m,k,0)|0;h=0;i=b;return h|0}function CS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[a+12>>2]|0;e=d+4|0;f=c[e>>2]|0;g=d;if((f|0)>=(c[g>>2]|0)){h=-541478725;return h|0}i=(c[c[a+28>>2]>>2]|0)+400|0;j=TS(c[a+16>>2]|0,b,c[(c[i>>2]|0)+(f*24|0)+16>>2]>>2)|0;f=c[e>>2]|0;a=f+1|0;c[e>>2]=a;e=(c[i>>2]|0)+(f*24|0)+8|0;f=c[e+4>>2]|0;i=b+16|0;c[i>>2]=c[e>>2];c[i+4>>2]=f;c[b+48>>2]=c[((a|0)==(c[g>>2]|0)?d+12|0:d+8|0)>>2];h=j;return h|0}function DS(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[a+12>>2]|0;h=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=oT(h,d,e,f)|0;if((b|0)<0){i=-1;return i|0}f=(c[h+400>>2]|0)+(b*24|0)|0;h=Ty(c[a+16>>2]|0,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=F;a=0;if((f|0)<(a|0)|(f|0)==(a|0)&h>>>0<0>>>0){i=-1;return i|0}c[g+4>>2]=b;i=0;return i|0}function ES(a,b,c){a=a|0;b=b|0;c=c|0;return uBb(tBb(4)|0,a,b,c)|0}function FS(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0;d=i;i=i+40|0;e=d|0;f=b+12|0;g=c[f>>2]|0;h=LT(b,0)|0;if((h|0)==0){j=-12;i=d;return j|0}k=c[h+8>>2]|0;c[k+52>>2]=0;c[k+8>>2]=0;c[k+48>>2]=143;c[k+120>>2]=c[g+16>>2];c[k+124>>2]=c[g+20>>2];k=g+24|0;MT(h,60,c[g+28>>2]|0,c[k>>2]|0);l=k;k=h+92|0;m=c[l+4>>2]|0;c[k>>2]=c[l>>2];c[k+4>>2]=m;m=g+4|0;n=+(c[h+40>>2]|0)/+(c[h+44>>2]|0)*+(c[m>>2]|0);if(n>1.0){o=~~n}else{o=1}c[m>>2]=o;o=b+16|0;k=c[o>>2]|0;if((c[k+88>>2]|0)==0){j=0;i=d;return j|0}l=Wy(k)|0;k=F;p=g+8|0;c[p>>2]=l;c[p+4>>2]=k;g=c[m>>2]|0;m=g;q=(g|0)<0|0?-1:0;g=YGb(l,k,-1,-1)|0;k=YGb(g,F,m,q)|0;g=hHb(k,F,m,q)|0;q=h+56|0;c[q>>2]=g;c[q+4>>2]=F;do{if((OP(b,p,0,0)|0)<0){q=YGb(c[p>>2]|0,c[p+4>>2]|0,-51,-1)|0;g=F;h=e|0;m=c[f>>2]|0;k=c[o>>2]|0;Ty(k,q,g,0)|0;if((lz(k)|0)!=26){break}l=lz(k)|0;if((l-1|0)>>>0>11>>>0){break}if((mz(k,h,12)|0)==12){a[e+l|0]=0;CBb(b+1140|0,2062872,h,0)|0}l=lz(k)|0;if((l-1|0)>>>0>35>>>0){break}if((mz(k,h,36)|0)==36){a[e+l|0]=0;CBb(b+1140|0,2016712,h,0)|0}h=m+8|0;c[h>>2]=q;c[h+4>>2]=g}}while(0);Ty(c[o>>2]|0,0,0,0)|0;j=0;i=d;return j|0}function GS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[a+12>>2]|0;e=a+16|0;if((Xy(c[e>>2]|0)|0)!=0){f=-541478725;return f|0}a=d+4|0;g=c[a>>2]|0;h=d+8|0;do{if((c[h>>2]|0)==0&(c[h+4>>2]|0)==0){i=g}else{d=Ty(c[e>>2]|0,0,0,1)|0;j=F;k=c[h>>2]|0;l=c[h+4>>2]|0;if((d|0)==(k|0)&(j|0)==(l|0)){f=-541478725;return f|0}m=c[a>>2]|0;n=YGb(m,(m|0)<0|0?-1:0,d,j)|0;m=F;if(!(m>>>0>l>>>0|m>>>0==l>>>0&n>>>0>k>>>0)){i=g;break}n=ZGb(k,l,d,j)|0;i=n}}while(0);g=TS(c[e>>2]|0,b,i)|0;c[b+28>>2]=g;if((g|0)<0){f=g;return f|0}g=b+36|0;c[g>>2]=c[g>>2]|1;f=0;return f|0}function HS(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==22){e=b+8|0;f=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if((f|0)==402915327|(f|0)==268697599){g=100}else{break}return g|0}}while(0);g=0;return g|0}function IS(a){a=a|0;var b=0,d=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=106;c[a+108>>2]=5;c[a+104>>2]=1;d=0;return d|0}function JS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=a+16|0;f=c[e>>2]|0;g=rz(f)|0;h=rz(f)|0;j=rz(f)|0;if((Xy(c[e>>2]|0)|0)==0){k=g;l=h;m=j}else{n=-541478725;i=d;return n|0}while(1){if(!((m|0)==402915327|(m|0)==268697599)){o=3;break}if((k|0)==3){o=6}else if((k|0)==1){if(l>>>0>100>>>0){o=9;break}else{o=6}}else if(!((k|0)==22|(k|0)==21)){o=8;break}if((o|0)==6){o=0;Vy(c[e>>2]|0,l,0)|0;}j=rz(f)|0;h=rz(f)|0;g=rz(f)|0;if((Xy(c[e>>2]|0)|0)==0){k=j;l=h;m=g}else{n=-541478725;o=11;break}}if((o|0)==3){yDb(a,16,2124168,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=-1094995529;i=d;return n|0}else if((o|0)==8){yDb(a,16,2062800,(p=i,i=i+8|0,c[p>>2]=k,p)|0);i=p;n=-1094995529;i=d;return n|0}else if((o|0)==9){p=TS(c[e>>2]|0,b,l)|0;if((p|0)<0){n=p;i=d;return n|0}c[b+32>>2]=0;n=0;i=d;return n|0}else if((o|0)==11){i=d;return n|0}return 0}function KS(a,b){a=a|0;b=b|0;return-38|0}function LS(a,e,f,j){a=a|0;e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=i;i=i+1048|0;l=k|0;m=k+24|0;if((j&1|0)!=0){n=0;i=k;return n|0}IAb(m,0,-1);j=(c[f>>2]|0)+136|0;o=c[j>>2]|0;p=c[j+4>>2]|0;KAb(m,2124144,(j=i,i=i+24|0,c[j>>2]=e,c[j+8>>2]=o,c[j+16>>2]=p,j)|0);i=j;p=c[(c[(c[(c[a+28>>2]|0)+(e<<2)>>2]|0)+8>>2]|0)+8>>2]|0;e=lGb(p)|0;KAb(m,2062776,(j=i,i=i+8|0,c[j>>2]=(e|0)!=0?e:2016616,j)|0);i=j;a:do{if((p|0)==1){e=c[f>>2]|0;o=vCb(e)|0;q=e+76|0;r=c[q>>2]|0;s=e+80|0;if((CFb(c[s>>2]|0)|0)==0){t=1;u=ba(r,o)|0}else{t=o;u=r}r=wFb(c[s>>2]|0)|0;KAb(m,1974904,(j=i,i=i+8|0,c[j>>2]=c[q>>2],j)|0);i=j;KAb(m,2062776,(j=i,i=i+8|0,c[j>>2]=(r|0)!=0?r:2016616,j)|0);i=j;if((t|0)<=0){break}r=e+64|0;if((u|0)==0){e=0;while(1){if(!((c[s>>2]|0)>>>0<10>>>0)){break}KAb(m,1879712,(j=i,i=i+8|0,c[j>>2]=0,j)|0);i=j;e=e+1|0;if((e|0)>=(t|0)){break a}}yDb(0,0,1946224,(j=i,i=i+24|0,c[j>>2]=1921192,c[j+8>>2]=1899840,c[j+16>>2]=116,j)|0);i=j;Cd();return 0}else{v=0}b:while(1){e=c[(c[r>>2]|0)+(v<<2)>>2]|0;switch(c[s>>2]|0){case 4:case 9:{q=u;o=e;w=0;x=0;while(1){y=((~~(+h[o>>3]*2147483648.0+2147483648.0)+w|0)>>>0)%65521|0;z=((y+x|0)>>>0)%65521|0;A=q-1|0;if((A|0)==0){break}else{q=A;o=o+8|0;w=y;x=z}}B=z<<16|y;break};case 0:case 5:{x=u;w=e;o=0;q=0;while(1){C=(((d[w]|0)+o|0)>>>0)%65521|0;D=((C+q|0)>>>0)%65521|0;A=x-1|0;if((A|0)==0){break}else{x=A;w=w+1|0;o=C;q=D}}B=D<<16|C;break};case 1:case 6:{q=u;o=e;w=0;x=0;while(1){E=((w+32768+(b[o>>1]|0)|0)>>>0)%65521|0;F=((E+x|0)>>>0)%65521|0;A=q-1|0;if((A|0)==0){break}else{q=A;o=o+2|0;w=E;x=F}}B=F<<16|E;break};case 2:case 7:{x=u;w=e;o=0;q=0;while(1){G=(((c[w>>2]^-2147483648)+o|0)>>>0)%65521|0;H=((G+q|0)>>>0)%65521|0;A=x-1|0;if((A|0)==0){break}else{x=A;w=w+4|0;o=G;q=H}}B=H<<16|G;break};case 3:case 8:{q=u;o=e;w=0;x=0;while(1){I=((~~(+g[o>>2]*2147483648.0+2147483648.0)+w|0)>>>0)%65521|0;J=((I+x|0)>>>0)%65521|0;A=q-1|0;if((A|0)==0){break}else{q=A;o=o+4|0;w=I;x=J}}B=J<<16|I;break};default:{break b}}KAb(m,1879712,(j=i,i=i+8|0,c[j>>2]=B,j)|0);i=j;v=v+1|0;if((v|0)>=(t|0)){break a}}yDb(0,0,1946224,(j=i,i=i+24|0,c[j>>2]=1921192,c[j+8>>2]=1899840,c[j+16>>2]=116,j)|0);i=j;Cd();return 0}else if((p|0)==0){s=c[f>>2]|0;r=s+80|0;x=bFb(c[r>>2]|0)|0;TGb(l|0,0,20)|0;w=s+68|0;o=s+72|0;q=c[o>>2]|0;KAb(m,2337776,(j=i,i=i+16|0,c[j>>2]=c[w>>2],c[j+8>>2]=q,j)|0);i=j;if((x|0)==0){KAb(m,2313608,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;break}q=l|0;if((dDb(q,c[r>>2]|0,c[w>>2]|0)|0)<0){break}KAb(m,2062776,(j=i,i=i+8|0,c[j>>2]=c[x>>2],j)|0);i=j;w=c[q>>2]|0;if((w|0)==0){break}q=x+4|0;r=x+6|0;x=0;e=w;do{w=c[o>>2]|0;do{if((x-1|0)>>>0<2>>>0){if(!((d[q]|0)>>>0>2>>>0)){K=w;break}K=-(-w>>d[r])|0}else{K=w}}while(0);if((K|0)>0){w=c[s+32+(x<<2)>>2]|0;A=0;L=c[s+(x<<2)>>2]|0;M=0;while(1){N=eAb(M,L,e)|0;O=A+1|0;if((O|0)<(K|0)){A=O;L=L+w|0;M=N}else{P=N;break}}}else{P=0}KAb(m,1879712,(j=i,i=i+8|0,c[j>>2]=P,j)|0);i=j;x=x+1|0;e=c[l+(x<<2)>>2]|0;}while((e|0)!=0)}}while(0);MAb(m,10,1);l=c[m+4>>2]|0;if(l>>>0<(c[m+8>>2]|0)>>>0){Ry(c[a+16>>2]|0,c[m>>2]|0,l);Q=0}else{Q=-12}QAb(m,0)|0;n=Q;i=k;return n|0}function MS(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((d|0)!=0){do{if((yb(d|0,2062696)|0)!=0){if((a[e]|0)!=47){break}if((d|0)!=(b|0)){sAb(b,d,c)|0}f=yb(b|0,2062696)|0;do{if((f|0)!=0){if((a[e+1|0]|0)==47){a[f+1|0]=0;break}g=Vb(f+3|0,47)|0;if((g|0)==0){break}a[g]=0}}while(0);tAb(b,e,c)|0;return}}while(0);if((yb(e|0,2062696)|0)!=0){break}if((a[e]|0)==47){break}if((d|0)!=(b|0)){sAb(b,d,c)|0}f=Vb(b|0,63)|0;if((f|0)!=0){a[f]=0}if((a[e]|0)==63){tAb(b,e,c)|0;return}f=cc(b|0,47)|0;if((f|0)==0){a[b]=0;h=0}else{a[f+1|0]=0;h=f}a:do{if((qAb(e,2016528,0)|0)==0|(h|0)==0){i=e}else{f=h;g=e;while(1){a[f]=0;j=cc(b|0,47)|0;k=(j|0)!=0;l=j+1|0;if((QGb(k?l:b,1974872)|0)==0){break}if(k){a[l]=0}else{a[b]=0}l=g+3|0;if((qAb(l,2016528,0)|0)==0|(j|0)==0){i=l;break a}else{f=j;g=l}}tAb(b,1946192,c)|0;i=g}}while(0);tAb(b,i,c)|0;return}}while(0);sAb(b,e,c)|0;return}function NS(){return 3613028}function OS(){return 1888040}function PS(a,b){a=a|0;b=b|0;c[a+1304>>2]=b;return}function QS(a,b){a=a|0;b=b|0;c[a+1308>>2]=b;return}function RS(a,b){a=a|0;b=b|0;c[a+1312>>2]=b;return}function SS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=a+96|0;f=c[e>>2]|0;g=c[e+4>>2]|0;h=-1;if(!((g|0)>(h|0)|(g|0)==(h|0)&f>>>0>-1>>>0)){j=b;i=d;return j|0}h=Ty(a,0,0,1)|0;k=ZGb(f,g,h,F)|0;h=F;g=b;f=(b|0)<0|0?-1:0;if((h|0)<(f|0)|(h|0)==(f|0)&k>>>0<g>>>0){l=Wy(a)|0;m=F;n=c[e>>2]|0;o=c[e+4>>2]|0;if((n|0)==0&(o|0)==0|((o|0)<(m|0)|(o|0)==(m|0)&n>>>0<l>>>0)){p=ZGb(l,m,(l|0)==0&(m|0)==0&1,0)|0;m=F;c[e>>2]=p;c[e+4>>2]=m;q=m;r=p}else{q=o;r=n}n=Ty(a,0,0,1)|0;a=ZGb(r,q,n,F)|0;n=F;q=0;r=(n|0)>(q|0)|(n|0)==(q|0)&a>>>0>0>>>0;s=r?n:0;t=r?a:0}else{s=h;t=k}k=c[e+4>>2]|0;h=-1;if(!((k|0)>(h|0)|(k|0)==(h|0)&(c[e>>2]|0)>>>0>-1>>>0)){j=b;i=d;return j|0}e=YGb(t,s,1,0)|0;h=F;if(!((h|0)<(f|0)|(h|0)==(f|0)&e>>>0<g>>>0)){j=b;i=d;return j|0}yDb(0,(t|0)!=0|(s|0)!=0?16:48,2123984,(s=i,i=i+24|0,c[s>>2]=b,c[s+8>>2]=e,c[s+16>>2]=h,s)|0);i=s;j=e;i=d;return j|0}function TS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;vZ(b);c[b+24>>2]=0;c[b+28>>2]=0;e=Ty(a,0,0,1)|0;f=b+64|0;c[f>>2]=e;c[f+4>>2]=F;return US(a,b,d)|0}function US(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=b+64|0;f=c[e>>2]|0;g=c[e+4>>2]|0;h=b+28|0;i=c[h>>2]|0;j=a+96|0;k=b+24|0;l=d;d=i;while(1){do{if((l|0)>5e6){m=SS(a,l)|0;n=c[j+4>>2]|0;o=0;if(!((n|0)<(o|0)|(n|0)==(o|0)&(c[j>>2]|0)>>>0<0>>>0)){p=m;break}p=(m|0)>5e7?5e7:m}else{p=l}}while(0);m=zZ(b,p)|0;if((m|0)<0){q=m;r=10;break}s=mz(a,(c[k>>2]|0)+d|0,p)|0;if((s|0)!=(p|0)){r=7;break}m=l-p|0;if((m|0)<=0){t=p;break}l=m;d=c[h>>2]|0}if((r|0)==7){yZ(b,((s|0)>0?s:0)+d|0);q=s;r=10}do{if((r|0)==10){if((l|0)<=0){t=q;break}s=b+36|0;c[s>>2]=c[s>>2]|2;t=q}}while(0);c[e>>2]=f;c[e+4>>2]=g;g=c[h>>2]|0;if((g|0)!=0){u=g;v=(u|0)>(i|0);w=u-i|0;x=v?w:t;return x|0}BZ(b);u=c[h>>2]|0;v=(u|0)>(i|0);w=u-i|0;x=v?w:t;return x|0}function VS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=b+28|0;if((c[e>>2]|0)==0){vZ(b);c[b+24>>2]=0;c[e>>2]=0;e=Ty(a,0,0,1)|0;f=b+64|0;c[f>>2]=e;c[f+4>>2]=F;g=US(a,b,d)|0;return g|0}else{g=US(a,b,d)|0;return g|0}return 0}function WS(a){a=a|0;var b=0,c=0;b=i;i=i+1024|0;if((a|0)==0){c=0;i=b;return c|0}c=(XS(b|0,1024,a,1)|0)>>>31^1;i=b;return c|0}function XS(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+24|0;h=b;j=d-1|0;d=g|0;k=0;l=b;b=e;a:while(1){m=l;e=b;while(1){n=m-h|0;if((n|0)>=(j|0)){o=e;p=9;break}q=e+1|0;r=a[e]|0;if((r<<24>>24|0)==37){s=0;t=q;while(1){if((CAb(a[t]|0)|0)==0){u=t+1|0;v=a[t]|0;w=v<<24>>24;if((CAb(w)|0)==0){break}else{s=0;t=u;continue}}else{s=(s*10|0)-48+(a[t]|0)|0;t=t+1|0;continue}}if((w|0)==100){x=u;y=s;break}else if((w|0)==37){z=u;A=v}else{break a}}else if((r<<24>>24|0)==0){p=18;break a}else{z=q;A=r}a[m]=A;m=m+1|0;e=z}if((p|0)==9){while(1){p=0;e=o+1|0;t=a[o]|0;if((t<<24>>24|0)==0){p=18;break a}else if((t<<24>>24|0)==37){B=0;C=e}else{o=e;p=9;continue}while(1){if((CAb(a[C]|0)|0)==0){D=C+1|0;E=a[C]|0;if((CAb(E)|0)==0){break}else{B=0;C=D;continue}}else{B=(B*10|0)-48+(a[C]|0)|0;C=C+1|0;continue}}if((E|0)==100){x=D;y=B;break}else if((E|0)==37){o=D;p=9}else{break a}}}if((k|0)!=0){break}Lb(d|0,20,1949088,(r=i,i=i+16|0,c[r>>2]=y,c[r+8>>2]=f,r)|0)|0;i=r;r=SGb(d|0)|0;if((n+r|0)>(j|0)){break}UGb(m|0,d|0,r)|0;k=1;l=m+r|0;b=x}do{if((p|0)==18){if((k|0)==0){break}else{F=0}a[m]=0;i=g;return F|0}}while(0);F=-1;a[m]=0;i=g;return F|0}function YS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+16|0;f=e|0;g=f;h=a;c[g>>2]=c[h>>2];c[g+4>>2]=c[h+4>>2];c[g+8>>2]=c[h+8>>2];h=f+4|0;g=c[h>>2]|0;if((g|0)==0){c[h>>2]=8882112;j=8882112}else{j=g}g=f+8|0;do{if((c[g>>2]|0)>10){if((vE(j,2062672)|0)==0){k=0;break}a=wE(c[h>>2]|0)|0;l=c[g>>2]|0;if((l|0)<=(a+16|0)){k=1;break}c[h>>2]=(c[h>>2]|0)+a;c[g>>2]=l-a;k=0}else{k=0}}while(0);g=(b|0)==0|0;b=f|0;h=(k|0)!=0?24:1;j=0;a=0;a:while(1){l=a;m=a;while(1){n=l;do{n=PC(n)|0;if((n|0)==0){break a}}while((g|0)==(c[n+8>>2]&1^1|0));o=c[n+36>>2]|0;do{if((o|0)==0){p=c[n+12>>2]|0;if((p|0)==0){q=0;break}r=(TC(c[b>>2]|0,p)|0)==0;q=r?0:50}else{r=re[o&4095](f)|0;p=c[n+12>>2]|0;if((p|0)==0){q=r;break}if((TC(c[b>>2]|0,p)|0)==0){q=r;break}q=(r|0)>(h|0)?r:h}}while(0);if((q|0)>(j|0)){j=q;a=n;continue a}l=n;m=(q|0)==(j|0)?0:m}}if((k|0)==0){s=j;c[d>>2]=s;i=e;return m|0}s=(j|0)<24?j:24;c[d>>2]=s;i=e;return m|0}function ZS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;g=YS(a,b,f)|0;b=c[f>>2]|0;if((b|0)<=(c[d>>2]|0)){h=0;i=e;return h|0}c[d>>2]=b;h=g;i=e;return h|0}function _S(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;i=i+40|0;j=h|0;k=h+8|0;l=h+24|0;m=h+32|0;c[k>>2]=(d|0)!=0?d:9203216;d=k+4|0;c[d>>2]=0;n=k+8|0;c[n>>2]=0;c[l>>2]=0;do{if((g|0)==0|g>>>0>1048576>>>0){o=1048576}else{if(!(g>>>0<2048>>>0)){o=g;break}yDb(e,16,1974816,(p=i,i=i+16|0,c[p>>2]=g,c[p+8>>2]=2048,p)|0);i=p;q=-22;i=h;return q|0}}while(0);if(!(o>>>0>f>>>0)){q=-22;i=h;return q|0}do{if((c[b>>2]|0)==0){if((c[a>>2]|0)==0){break}g=(xEb(a,1946168,1,m)|0)>-1;r=c[m>>2]|0;if(!(g&(r|0)!=0)){break}if((yAb(r,1921168)|0)==0){c[b>>2]=WC(1899832)|0}$Db(m)}}while(0);m=(c[b>>2]|0)==0;a:do{if(o>>>0<2048>>>0){s=0;t=0;u=m;v=26}else{r=l;g=0;w=2048;x=0;y=m;while(1){if(!y){z=g;A=x;break a}B=_Db(r,w+32|0)|0;if((B|0)<0){q=B;v=29;break}B=w>>>0<o>>>0?25:0;C=mz(a,(c[l>>2]|0)+x|0,w-x|0)|0;if((C|0)<0){if((C|0)==-541478725){D=0;E=0}else{break}}else{D=C;E=B}B=D+x|0;do{if(B>>>0<f>>>0){F=E}else{c[n>>2]=B-f;G=c[l>>2]|0;c[d>>2]=G+f;TGb(G+B|0,0,32)|0;G=YS(k,1,j)|0;H=c[j>>2]|0;if((H|0)<=(E|0)){c[b>>2]=0;F=E;break}c[b>>2]=G;if((G|0)==0){F=H;break}I=c[G>>2]|0;if((H|0)<26){yDb(e,24,1879640,(p=i,i=i+16|0,c[p>>2]=I,c[p+8>>2]=H,p)|0);i=p;F=H;break}else{yDb(e,48,2337728,(p=i,i=i+24|0,c[p>>2]=I,c[p+8>>2]=w,c[p+16>>2]=H,p)|0);i=p;F=H;break}}}while(0);H=w<<1;I=w+1|0;G=o>>>0>I>>>0?o:I;I=H>>>0>G>>>0?G:H;H=(c[b>>2]|0)==0;if(I>>>0>o>>>0){s=F;t=B;u=H;v=26;break a}else{g=F;w=I;x=B;y=H}}if((v|0)==29){i=h;return q|0}ZDb(c[l>>2]|0);q=C;i=h;return q|0}}while(0);do{if((v|0)==26){if(!u){z=s;A=t;break}ZDb(c[l>>2]|0);q=-1094995529;i=h;return q|0}}while(0);t=Fz(a,l,A)|0;q=(t|0)<0?t:z;i=h;return q|0}function $S(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=_S(a,b,c,d,e,f)|0;return((g|0)<0?g:0)|0}function aT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+1144|0;g=f|0;h=f+80|0;j=f+1104|0;k=f+1112|0;l=f+1128|0;m=f+1136|0;n=c[a>>2]|0;c[l>>2]=0;c[m>>2]=0;do{if((n|0)==0){o=tN()|0;if((o|0)==0){p=-12}else{q=o;break}i=f;return p|0}else{q=n}}while(0);if((c[q>>2]|0)==0){yDb(0,16,2313504,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=-22;i=f;return p|0}if((d|0)!=0){c[q+4>>2]=d}d=(e|0)!=0;if(d){EBb(l,c[e>>2]|0,0)}n=q;o=IEb(n,l)|0;a:do{if((o|0)<0){s=o;t=q+16|0}else{c[k>>2]=b;c[k+4>>2]=0;c[k+8>>2]=0;u=q+16|0;v=c[u>>2]|0;b:do{if((v|0)==0){w=q+4|0;x=c[w>>2]|0;do{if((x|0)==0){y=YS(k,0,j)|0;z=c[j>>2]|0;if((z|0)>25){c[w>>2]=y;if((y|0)==0){break}else{A=z;B=w;break b}}else{c[w>>2]=0;break}}else{if((c[x+8>>2]&1|0)!=0){A=25;B=w;break b}}}while(0);x=Hz(u,b,c[q+1208>>2]|1,q+1160|0,l)|0;if((x|0)<0){s=x;t=u;break a}if((c[w>>2]|0)!=0){A=0;B=w;break}C=_S(c[u>>2]|0,w,b,n,0,c[q+1088>>2]|0)|0;D=24}else{x=q+1084|0;c[x>>2]=c[x>>2]|128;x=q+4|0;z=c[x>>2]|0;if((z|0)==0){C=_S(v,x,b,n,0,c[q+1088>>2]|0)|0;D=24;break}if((c[z+8>>2]&1|0)==0){A=0;B=x;break}yDb(n,24,2241408,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;A=0;B=x}}while(0);if((D|0)==24){if((C|0)<0){s=C;t=u;break}A=C;B=q+4|0}c[q+1232>>2]=A;Vy(c[u>>2]|0,c[q+1216>>2]|0,0)|0;if((c[(c[B>>2]|0)+8>>2]&2|0)!=0){if((b|0)==0){s=-22;t=u;break}if((XS(h|0,1024,b,1)|0)<0){s=-22;t=u;break}}v=q+1056|0;c[v>>2]=0;c[v+4>>2]=-2147483648;v=q+1064|0;c[v>>2]=0;c[v+4>>2]=-2147483648;sAb(q+32|0,(b|0)!=0?b:9203216,1024)|0;v=c[(c[B>>2]|0)+32>>2]|0;do{if((v|0)>0){x=cEb(v)|0;z=q+12|0;c[z>>2]=x;if((x|0)==0){s=-12;t=u;break a}y=c[(c[B>>2]|0)+20>>2]|0;if((y|0)==0){break}c[x>>2]=y;DEb(c[z>>2]|0);y=IEb(c[z>>2]|0,l)|0;if((y|0)<0){s=y;t=u;break a}}}while(0);if((c[u>>2]|0)!=0){yE(q,2062672,m)}v=q+1084|0;do{if((c[v>>2]&131072|0)==0){y=c[(c[B>>2]|0)+40>>2]|0;if((y|0)==0){break}z=re[y&4095](q)|0;if((z|0)<0){s=z;t=u;break a}}}while(0);c:do{if((c[m>>2]|0)!=0){z=c[c[B>>2]>>2]|0;do{if((QGb(z,2293176)|0)!=0){if((QGb(z,1899832)|0)==0){break}if((QGb(z,2276696)|0)==0){break}yDb(n,48,2261016,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break c}}while(0);z=BE(q,m)|0;if((z|0)<0){s=z;t=u;break a}}}while(0);zE(m);z=g|0;w=q+24|0;if((c[w>>2]|0)!=0){y=q+28|0;x=q+1256|0;E=q+1260|0;G=0;do{H=c[(c[y>>2]|0)+(G<<2)>>2]|0;do{if((c[H+72>>2]&1024|0)!=0){if((c[H+76>>2]|0)>=48){break}I=c[H+104>>2]|0;UGb(z|0,H+108|0,76)|0;J=WAb(I)|0;if((J|0)==0){s=-12;t=u;break a}I=cEb(88)|0;K=I;if((I|0)==0){break}if((c[x>>2]|0)==0){c[x>>2]=K}else{c[(c[E>>2]|0)+80>>2]=K}c[E>>2]=K;c[I>>2]=J;UGb(I+4|0,z|0,76)|0}}while(0);G=G+1|0;}while(G>>>0<(c[w>>2]|0)>>>0)}do{if((c[v>>2]&131072|0)==0){w=c[u>>2]|0;if((w|0)==0){break}G=q+1248|0;if(!((c[G>>2]|0)==0&(c[G+4>>2]|0)==0)){break}z=Ty(w,0,0,1)|0;c[G>>2]=z;c[G+4>>2]=F}}while(0);c[q+1272>>2]=25e5;if(d){DBb(e);c[e>>2]=c[l>>2]}c[a>>2]=q;p=0;i=f;return p|0}}while(0);zE(m);DBb(l);l=c[t>>2]|0;do{if((l|0)!=0){if((c[q+1084>>2]&128|0)!=0){break}Iz(l)|0}}while(0);bT(q);c[a>>2]=0;p=s;i=f;return p|0}function bT(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((a|0)==0){return}b=a;HEb(b);d=c[a+4>>2]|0;do{if((d|0)!=0){if((c[d+20>>2]|0)==0){break}e=c[a+12>>2]|0;if((e|0)==0){break}HEb(e)}}while(0);d=(c[a+24>>2]|0)-1|0;if((d|0)>-1){e=a+28|0;f=d;do{JT(a,c[(c[e>>2]|0)+(f<<2)>>2]|0);f=f-1|0;}while((f|0)>-1)}f=(c[a+1104>>2]|0)-1|0;e=a+1108|0;if((f|0)>-1){d=f;do{DBb((c[(c[e>>2]|0)+(d<<2)>>2]|0)+20|0);$Db((c[(c[e>>2]|0)+(d<<2)>>2]|0)+12|0);$Db((c[e>>2]|0)+(d<<2)|0);d=d-1|0;}while((d|0)>-1)}$Db(e);$Db(a+12|0);e=a+1132|0;d=c[e>>2]|0;f=d-1|0;c[e>>2]=f;g=a+1136|0;if((d|0)!=0){d=f;do{DBb((c[(c[g>>2]|0)+(d<<2)>>2]|0)+32|0);$Db((c[g>>2]|0)+(c[e>>2]<<2)|0);f=c[e>>2]|0;d=f-1|0;c[e>>2]=d;}while((f|0)!=0)}$Db(g);DBb(a+1140|0);$Db(a+28|0);$Db(a+1296|0);ZDb(b);return}function cT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;d=i;i=i+8|0;e=d|0;f=a+1256|0;g=b;h=b+32|0;j=a+28|0;k=a+1272|0;l=b+24|0;m=b+28|0;n=a+4|0;o=a+24|0;p=a+1084|0;q=b+16|0;r=b+8|0;s=a+1220|0;t=a+1104|0;u=a+1108|0;v=a+1200|0;w=a+1260|0;x=e|0;y=e+4|0;z=a+1112|0;A=a+1116|0;B=a+1120|0;C=a;D=b+36|0;a:while(1){E=c[f>>2]|0;G=(E|0)!=0;if(G){H=E;UGb(g|0,H|0,80)|0;I=c[(c[j>>2]|0)+(c[h>>2]<<2)>>2]|0;if((c[k>>2]|0)<1){dT(a,I,0)}if((c[I+440>>2]|0)<1){J=6;break}}c[l>>2]=0;c[m>>2]=0;vZ(b);I=Oe[c[(c[n>>2]|0)+44>>2]&1023](a,b)|0;if((I|0)<0){if((I|0)==-11|G^1){K=I;J=109;break}else{L=0}while(1){if(!(L>>>0<(c[o>>2]|0)>>>0)){continue a}M=c[(c[j>>2]|0)+(L<<2)>>2]|0;if((c[M+228>>2]|0)!=0){dT(a,M,0)}if((c[M+440>>2]|0)>=1){J=14;break a}L=L+1|0}}do{if((c[p>>2]&256|0)!=0){if((c[D>>2]&2|0)==0){break}yDb(C,24,2211512,(N=i,i=i+8|0,c[N>>2]=c[h>>2],N)|0);i=N;BZ(b);continue a}}while(0);M=c[h>>2]|0;O=c[o>>2]|0;if(!(M>>>0<O>>>0)){yDb(C,16,2202472,(N=i,i=i+8|0,c[N>>2]=M,N)|0);i=N;continue}P=c[j>>2]|0;Q=c[P+(M<<2)>>2]|0;R=c[q>>2]|0;S=c[q+4>>2]|0;if((R|0)==0&(S|0)==(-2147483648|0)){T=c[r+4>>2]|0;U=c[r>>2]|0}else{T=S;U=R}R=Q+464|0;do{if((c[R>>2]|0)==0&(c[R+4>>2]|0)==(-2147483648|0)){S=Q+188|0;V=c[S>>2]|0;if((V|0)>62|(U|0)==0&(T|0)==(-2147483648|0)){break}if((c[s>>2]|0)==0){break}W=_Gb(1,0,V|0)|0;X=F;Y=YGb(W,X,-1,-1)|0;Z=Y&U;Y=F&T;_=c[Q+44>>2]|0;$=c[Q+40>>2]|0;aa=IDb(60,0,_,(_|0)<0|0?-1:0,$,($|0)<0|0?-1:0)|0;$=F;_=ZGb(Z,Y,aa,$)|0;ba=F;ca=_Gb(1,0,V-3|0)|0;V=ZGb(W,X,ca,F)|0;ca=F;if((Y|0)<(ca|0)|(Y|0)==(ca|0)&Z>>>0<V>>>0){da=1}else{V=ZGb(W,X,aa,$)|0;$=F;da=(Y|0)<($|0)|(Y|0)==($|0)&Z>>>0<V>>>0?1:-1}V=c[t>>2]|0;b:do{if((V|0)==0){J=34}else{Z=c[u>>2]|0;$=0;c:while(1){ea=c[Z+($<<2)>>2]|0;d:do{if((ea|0)!=0){fa=c[ea+16>>2]|0;Y=ea+12|0;aa=0;while(1){if(!(aa>>>0<fa>>>0)){break d}ga=c[Y>>2]|0;if((c[ga+(aa<<2)>>2]|0)==(M|0)){ha=ea;break c}else{aa=aa+1|0}}}}while(0);aa=$+1|0;if(aa>>>0<V>>>0){$=aa}else{J=34;break b}}e:while(1){$=ha+56|0;ia=c[$>>2]|0;ja=c[$+4>>2]|0;if((ia|0)==0&(ja|0)==(-2147483648|0)){ka=ha;la=0}else{J=46;break}f:while(1){ma=c[Z+(la<<2)>>2]|0;g:do{if((ma|0)==(ka|0)){na=0}else{if((ka|0)!=0){na=ka;break}$=c[ma+16>>2]|0;aa=ma+12|0;Y=0;while(1){if(!(Y>>>0<$>>>0)){na=0;break g}if((c[(c[aa>>2]|0)+(Y<<2)>>2]|0)==(M|0)){break f}else{Y=Y+1|0}}}}while(0);Y=la+1|0;if(Y>>>0<V>>>0){ka=na;la=Y}else{oa=ba;pa=_;qa=da;break e}}if((ma|0)==0){oa=ba;pa=_;qa=da;break}else{ha=ma}}if((J|0)==46){J=0;oa=ja;pa=ia;qa=c[ha+64>>2]|0}Y=ea;aa=V;$=fa;X=ga;while(1){W=Y+56|0;if((c[W>>2]|0)==(pa|0)&(c[W+4>>2]|0)==(oa|0)){ra=aa}else{ca=Y+16|0;if(($|0)!=0){sa=0;do{ta=c[P+(c[X+(sa<<2)>>2]<<2)>>2]|0;ua=ta+464|0;c[ua>>2]=pa;c[ua+4>>2]=oa;c[ta+472>>2]=qa;sa=sa+1|0;}while(sa>>>0<(c[ca>>2]|0)>>>0)}c[W>>2]=pa;c[W+4>>2]=oa;c[Y+64>>2]=qa;ra=c[t>>2]|0}if((ra|0)==0){break b}else{va=Y;wa=0}h:while(1){xa=c[Z+(wa<<2)>>2]|0;i:do{if((xa|0)==(va|0)){ya=0}else{if((va|0)!=0){ya=va;break}za=c[xa+16>>2]|0;ca=xa+12|0;sa=0;while(1){if(!(sa>>>0<za>>>0)){ya=0;break i}Aa=c[ca>>2]|0;if((c[Aa+(sa<<2)>>2]|0)==(M|0)){break h}else{sa=sa+1|0}}}}while(0);sa=wa+1|0;if(sa>>>0<ra>>>0){va=ya;wa=sa}else{break b}}if((xa|0)==0){break}else{Y=xa;aa=ra;$=za;X=Aa}}}}while(0);do{if((J|0)==34){J=0;V=(O|0)==0;j:do{if(V){Ba=-1}else{X=-1;$=0;while(1){aa=c[P+($<<2)>>2]|0;Y=c[(c[aa+8>>2]|0)+8>>2]|0;if((Y|0)==0){if((c[aa+72>>2]&1024|0)==0){Ba=$;break j}}if((X|0)<0){Ca=(Y|0)==1?$:X}else{Ca=X}Y=$+1|0;if(Y>>>0<O>>>0){X=Ca;$=Y}else{break}}Ba=(Ca|0)<0?0:Ca}}while(0);$=c[P+(Ba<<2)>>2]|0;X=$+464|0;Y=c[X>>2]|0;aa=c[X+4>>2]|0;if(!((Y|0)==0&(aa|0)==(-2147483648|0))){c[R>>2]=Y;c[R+4>>2]=aa;c[Q+472>>2]=c[$+472>>2];break}if(V){break}else{Da=0}do{$=c[P+(Da<<2)>>2]|0;aa=$+464|0;c[aa>>2]=_;c[aa+4>>2]=ba;c[$+472>>2]=da;Da=Da+1|0;}while(Da>>>0<(c[o>>2]|0)>>>0)}}while(0);if(!((c[Q+472>>2]|0)==-1)){break}ba=Q+200|0;_=c[ba>>2]|0;V=c[ba+4>>2]|0;$=2147352575;if(!((V|0)>($|0)|(V|0)==($|0)&_>>>0>-1>>>0)){$=c[R>>2]|0;aa=c[R+4>>2]|0;if(($|0)==0&(aa|0)==(-2147483648|0)|(_|0)==0&(V|0)==(-2147483648|0)|((aa|0)>(V|0)|(aa|0)==(V|0)&$>>>0>_>>>0)){Ea=V;Fa=_}else{$=_Gb(1,0,c[S>>2]|0)|0;aa=ZGb(_,V,$,F)|0;Ea=F;Fa=aa}c[ba>>2]=Fa;c[ba+4>>2]=Ea}ba=Q+48|0;aa=c[ba>>2]|0;$=c[ba+4>>2]|0;V=2147352575;if(!(($|0)>(V|0)|($|0)==(V|0)&aa>>>0>-1>>>0)){V=c[R>>2]|0;_=c[R+4>>2]|0;if((V|0)==0&(_|0)==(-2147483648|0)|(aa|0)==0&($|0)==(-2147483648|0)|((_|0)>($|0)|(_|0)==($|0)&V>>>0>aa>>>0)){Ga=$;Ha=aa}else{V=_Gb(1,0,c[S>>2]|0)|0;_=ZGb(aa,$,V,F)|0;Ga=F;Ha=_}c[ba>>2]=Ha;c[ba+4>>2]=Ga}ba=Q+208|0;_=c[ba>>2]|0;V=c[ba+4>>2]|0;$=2147352575;if((V|0)>($|0)|(V|0)==($|0)&_>>>0>-1>>>0){break}$=c[R>>2]|0;aa=c[R+4>>2]|0;if(($|0)==0&(aa|0)==(-2147483648|0)|(_|0)==0&(V|0)==(-2147483648|0)|((aa|0)>(V|0)|(aa|0)==(V|0)&$>>>0>_>>>0)){Ia=V;Ja=_}else{$=_Gb(1,0,c[S>>2]|0)|0;aa=ZGb(_,V,$,F)|0;Ia=F;Ja=aa}c[ba>>2]=Ja;c[ba+4>>2]=Ia}}while(0);P=c[q>>2]|0;O=c[q+4>>2]|0;M=c[Q+472>>2]|0;do{if((M|0)==0){c[q>>2]=P;c[q+4>>2]=O;Ka=c[r+4>>2]|0;La=c[r>>2]|0}else{ba=c[R>>2]|0;aa=c[R+4>>2]|0;do{if((ba|0)==0&(aa|0)==(-2147483648|0)|(P|0)==0&(O|0)==(-2147483648|0)){Ma=O;Na=P}else{$=(aa|0)>(O|0)|(aa|0)==(O|0)&ba>>>0>P>>>0;if((M|0)==1&$){V=_Gb(1,0,c[Q+188>>2]|0)|0;_=YGb(V,F,P,O)|0;Ma=F;Na=_;break}if((M|0)!=-1|$){Ma=O;Na=P;break}$=_Gb(1,0,c[Q+188>>2]|0)|0;_=ZGb(P,O,$,F)|0;Ma=F;Na=_}}while(0);c[q>>2]=Na;c[q+4>>2]=Ma;ba=c[r>>2]|0;aa=c[r+4>>2]|0;S=c[R>>2]|0;_=c[R+4>>2]|0;if((S|0)==0&(_|0)==(-2147483648|0)|(ba|0)==0&(aa|0)==(-2147483648|0)){Ka=aa;La=ba;break}$=(_|0)>(aa|0)|(_|0)==(aa|0)&S>>>0>ba>>>0;if((M|0)==1&$){S=_Gb(1,0,c[Q+188>>2]|0)|0;_=YGb(S,F,ba,aa)|0;Ka=F;La=_;break}if((M|0)!=-1|$){Ka=aa;La=ba;break}$=_Gb(1,0,c[Q+188>>2]|0)|0;_=ZGb(ba,aa,$,F)|0;Ka=F;La=_}}while(0);c[r>>2]=La;c[r+4>>2]=Ka;M=c[Q+8>>2]|0;R=c[M+8>>2]|0;do{if((R|0)==0){O=c[z>>2]|0;if((O|0)==0){break}c[M+48>>2]=O}else if((R|0)==1){O=c[A>>2]|0;if((O|0)==0){break}c[M+48>>2]=O}else if((R|0)==3){O=c[B>>2]|0;if((O|0)==0){break}c[M+48>>2]=O}}while(0);if((c[v>>2]|0)!=0){M=WFb()|0;c[x>>2]=1;c[y>>2]=1e6;R=KDb(M,F,e,Q+40|0)|0;M=F;c[r>>2]=R;c[r+4>>2]=M;c[q>>2]=R;c[q+4>>2]=M}if(!G){if((c[Q+440>>2]|0)<1){K=I;J=109;break}}M=cEb(88)|0;R=M;if((M|0)!=0){if((c[f>>2]|0)==0){c[f>>2]=R}else{c[(c[w>>2]|0)+80>>2]=R}c[w>>2]=R;UGb(M|0,g|0,80)|0}c[k>>2]=(c[k>>2]|0)-(c[m>>2]|0);dT(a,Q,b)}if((J|0)==6){c[f>>2]=c[E+80>>2];c[k>>2]=(c[k>>2]|0)+(c[m>>2]|0);ZDb(H);K=0;i=d;return K|0}else if((J|0)==14){yDb(0,0,2246464,(N=i,i=i+24|0,c[N>>2]=2233792,c[N+8>>2]=2220768,c[N+16>>2]=776,N)|0);i=N;Cd();return 0}else if((J|0)==109){i=d;return K|0}return 0}function dT(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+8|0;g=f|0;h=b+440|0;if((c[h>>2]|0)<=0){i=f;return}j=b+248|0;k=a;l=b|0;m=b+228|0;n=c[m>>2]|0;yDb(k,48,2262912,(o=i,i=i+16|0,c[o>>2]=c[l>>2],c[o+8>>2]=n,o)|0);i=o;c[m>>2]=(c[m>>2]|0)-1;do{if((e|0)==0){p=b+256|0;q=7}else{n=b+252|0;r=b+256|0;s=e+28|0;t=XDb(c[n>>2]|0,(c[r>>2]|0)+32+(c[s>>2]|0)|0)|0;if((t|0)==0){yDb(k,24,2261728,(o=i,i=i+8|0,c[o>>2]=c[l>>2],o)|0);i=o;p=r;q=7;break}else{c[n>>2]=t;UGb(t+(c[r>>2]|0)|0,c[e+24>>2]|0,c[s>>2]|0)|0;t=(c[r>>2]|0)+(c[s>>2]|0)|0;c[r>>2]=t;TGb((c[n>>2]|0)+t|0,0,32)|0;break}}}while(0);do{if((q|0)==7){c[m>>2]=0;if((c[p>>2]|0)!=0){break}yDb(k,24,2260400,(o=i,i=i+8|0,c[o>>2]=c[l>>2],o)|0);i=o}}while(0);do{if((c[a+1272>>2]|0)<1){u=1}else{if((c[m>>2]|0)<1){u=1;break}p=c[b+256>>2]|0;q=p>>>0>65535>>>0;t=q?p>>>16:p;n=q?16:0;if((t&65280|0)==0){v=n;w=t}else{v=n|8;w=t>>>8}t=p-(c[e+28>>2]|0)|0;p=t>>>0>65535>>>0;n=p?t>>>16:t;t=p?16:0;if((n&65280|0)==0){x=t;y=n}else{x=t|8;y=n>>>8}if(((d[1191992+w|0]|0)+v|0)!=((d[1191992+y|0]|0)+x|0)){u=0;break}i=f;return}}while(0);x=YS(j,1,g)|0;a:do{if((x|0)==0){z=c[g>>2]|0}else{j=c[g>>2]|0;if((c[h>>2]|0)>(j|0)){z=j;break}y=2500-(c[m>>2]|0)|0;v=x|0;w=c[v>>2]|0;yDb(k,48,2245e3,(o=i,i=i+32|0,c[o>>2]=c[b+256>>2],c[o+8>>2]=y,c[o+16>>2]=w,c[o+24>>2]=j,o)|0);i=o;w=0;while(1){if((w|0)==10){z=j;break a}if((QGb(c[v>>2]|0,c[472008+(w*12|0)>>2]|0)|0)==0){break}else{w=w+1|0}}v=c[b+8>>2]|0;c[v+48>>2]=c[472012+(w*12|0)>>2];c[v+8>>2]=c[472016+(w*12|0)>>2];z=j}}while(0);x=b+8|0;do{if((c[(c[x>>2]|0)+48>>2]|0)!=0&(z|0)>24|u){c[b+256>>2]=0;$Db(b+252|0);c[h>>2]=-1;m=c[l>>2]|0;if((c[(c[x>>2]|0)+48>>2]|0)==0){yDb(k,24,2255840,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;break}else{yDb(k,48,2259616,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;break}}}while(0);o=c[x>>2]|0;x=c[o+8>>2]|0;if((x|0)==0){k=c[a+1112>>2]|0;if((k|0)==0){i=f;return}c[o+48>>2]=k;i=f;return}else if((x|0)==1){k=c[a+1116>>2]|0;if((k|0)==0){i=f;return}c[o+48>>2]=k;i=f;return}else if((x|0)==3){x=c[a+1120>>2]|0;if((x|0)==0){i=f;return}c[o+48>>2]=x;i=f;return}else{i=f;return}}function eT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=(d|0)!=0;do{if(!e){d=c[a+424>>2]|0;if((d|0)>1){f=d}else{break}return f|0}}while(0);d=O0a(a,b)|0;if((d|0)>0){f=d;return f|0}d=c[a+424>>2]|0;g=(d|0)>1;if(g|e){f=g?d:-1;return f|0}d=c[a+72>>2]|0;if(!((d|0)>0&(b|0)>0)){f=-1;return f|0}g=c[a+412>>2]|0;if((g|0)<=0){f=-1;return f|0}if((c[a+432>>2]|0)<=1){f=-1;return f|0}if(!(((c[a+48>>2]|0)-86023|0)>>>0<2>>>0)){f=-1;return f|0}a=b;e=gHb(a<<3|0>>>29,((b|0)<0|0?-1:0)<<3|a>>>29,g,(g|0)<0|0?-1:0)|0;g=eHb(e,F,d,(d|0)<0|0?-1:0)|0;f=g;return f|0}function fT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[a>>2]=0;c[b>>2]=0;g=d+8|0;h=c[g>>2]|0;i=c[h+8>>2]|0;if((i|0)==0){j=d+412|0;if((c[j>>2]|0)!=0&(e|0)==0){c[a>>2]=c[d+416>>2];c[b>>2]=c[j>>2];return}j=c[d+40>>2]|0;k=gHb(j,(j|0)<0|0?-1:0,1e3,0)|0;l=F;m=d+44|0;d=c[m>>2]|0;n=(d|0)<0|0?-1:0;if((l|0)>(n|0)|(l|0)==(n|0)&k>>>0>d>>>0){c[a>>2]=j;c[b>>2]=c[m>>2];return}m=c[h+104>>2]|0;j=gHb(m,(m|0)<0|0?-1:0,1e3,0)|0;d=F;k=h+108|0;n=c[k>>2]|0;l=(n|0)<0|0?-1:0;if(!((d|0)>(l|0)|(d|0)==(l|0)&j>>>0>n>>>0)){return}c[a>>2]=m;m=c[k>>2]|0;c[b>>2]=m;k=(e|0)!=0;do{if(k){n=c[e+36>>2]|0;if((n|0)==0){return}j=c[a>>2]|0;l=n+1|0;if((j|0)>(2147483647/(l|0)|0|0)){c[b>>2]=(m|0)/(l|0)|0;break}c[a>>2]=ba(j,l)|0;return}}while(0);if((c[h+112>>2]|0)<2|k){return}c[b>>2]=0;c[a>>2]=0;return}else if((i|0)==1){i=c[f+28>>2]|0;f=h+424|0;k=c[f>>2]|0;do{if((k|0)>1){o=k}else{m=O0a(h,i)|0;if((m|0)>0){o=m;break}m=c[f>>2]|0;e=(m|0)>1;do{if(e){p=e?m:-1}else{l=c[h+72>>2]|0;if(!((l|0)>0&(i|0)>0)){return}j=c[h+412>>2]|0;if((j|0)<=0){return}if((c[h+432>>2]|0)<=1){return}if(((c[h+48>>2]|0)-86023|0)>>>0<2>>>0){n=i;d=gHb(n<<3|0>>>29,((i|0)<0|0?-1:0)<<3|n>>>29,j,(j|0)<0|0?-1:0)|0;j=eHb(d,F,l,(l|0)<0|0?-1:0)|0;p=j;break}else{return}}}while(0);if((p|0)>=1){o=p;break}return}}while(0);p=(c[g>>2]|0)+412|0;if((c[p>>2]|0)<1){return}c[a>>2]=o;c[b>>2]=c[p>>2];return}else{return}}function gT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a+1236|0;do{if((c[a+1084>>2]&1|0)==0){h=c[g>>2]|0;if((h|0)==0){j=hT(a,b)|0;if((j|0)<0){k=j}else{l=j;break}i=d;return k|0}c[f>>2]=h;UGb(b|0,h|0,80)|0;j=h+80|0;c[g>>2]=c[j>>2];if((c[j>>2]|0)==0){c[a+1240>>2]=0}$Db(f);l=0}else{j=a+1240|0;h=b;m=a+28|0;n=1;a:while(1){while(1){o=c[g>>2]|0;if((o|0)==0){p=0}else{q=o+16|0;r=c[q>>2]|0;s=c[q+4>>2]|0;if((r|0)==0&(s|0)==(-2147483648|0)){t=o;u=o+8|0}else{v=o+32|0;w=o+8|0;x=_Gb(2,0,(c[(c[(c[m>>2]|0)+(c[v>>2]<<2)>>2]|0)+188>>2]|0)-1|0)|0;y=F;z=o;A=s;s=r;while(1){if(!((c[w>>2]|0)==0&(c[w+4>>2]|0)==(-2147483648|0))){B=A;C=s;break}do{if((c[z+32>>2]|0)==(c[v>>2]|0)){r=z+16|0;D=MDb(c[q>>2]|0,c[q+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0,x,y)|0;E=F;G=0;if(!((E|0)<(G|0)|(E|0)==(G|0)&D>>>0<0>>>0)){H=A;I=s;break}D=z+8|0;G=MDb(c[D>>2]|0,c[D+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0,x,y)|0;if(!((G|0)==0&(F|0)==0)){G=c[r+4>>2]|0;c[w>>2]=c[r>>2];c[w+4>>2]=G}if((s|0)==0&(A|0)==(-2147483648|0)){H=-2147483648;I=0;break}H=c[r+4>>2]|0;I=c[r>>2]|0}else{H=A;I=s}}while(0);r=c[z+80>>2]|0;if((r|0)==0){B=H;C=I;break}else{z=r;A=H;s=I}}do{if(!n){if((c[w>>2]|0)!=0|(c[w+4>>2]|0)!=(-2147483648|0)|(C|0)==0&(B|0)==(-2147483648|0)){break}s=c[o+48>>2]|0;A=YGb(s,(s|0)<0|0?-1:0,C,B)|0;c[w>>2]=A;c[w+4>>2]=F}}while(0);t=c[g>>2]|0;u=w}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==(-2147483648|0))){J=26;break a}if(((c[q>>2]|0)!=0|(c[q+4>>2]|0)!=(-2147483648|0))&n){p=t}else{J=26;break a}}K=hT(a,b)|0;if((K|0)<0){break}o=cEb(88)|0;A=o;if((o|0)==0){L=0}else{if((c[g>>2]|0)==0){c[g>>2]=A}else{c[(c[j>>2]|0)+80>>2]=A}c[j>>2]=A;UGb(o|0,h|0,80)|0;L=o}if((CZ(L)|0)<0){k=-12;J=58;break a}}if((p|0)==0|(K|0)==-11){k=K;J=58;break}else{n=0}}if((J|0)==26){if((t|0)==0){yDb(0,0,2246464,(n=i,i=i+24|0,c[n>>2]=2264112,c[n+8>>2]=2220768,c[n+16>>2]=1415,n)|0);i=n;Cd();return 0}c[e>>2]=t;UGb(h|0,t|0,80)|0;n=t+80|0;c[g>>2]=c[n>>2];if((c[n>>2]|0)==0){c[j>>2]=0}$Db(e);l=0;break}else if((J|0)==58){i=d;return k|0}}}while(0);J=c[a+28>>2]|0;e=c[J+(c[b+32>>2]<<2)>>2]|0;do{if((c[(c[a+4>>2]|0)+8>>2]&256|0)!=0){if((c[b+36>>2]&1|0)==0){break}g=c[J+(c[e>>2]<<2)>>2]|0;t=g+404|0;K=c[t>>2]|0;if(!(K>>>0<(((c[a+1124>>2]|0)>>>0)/24|0)>>>0)){if((K|0)>0){K=g+400|0;g=0;p=0;while(1){L=c[K>>2]|0;u=L+(g*24|0)|0;B=L+(p*24|0)|0;c[u>>2]=c[B>>2];c[u+4>>2]=c[B+4>>2];c[u+8>>2]=c[B+8>>2];c[u+12>>2]=c[B+12>>2];c[u+16>>2]=c[B+16>>2];c[u+20>>2]=c[B+20>>2];B=g+1|0;u=B<<1;if((u|0)<(c[t>>2]|0)){g=B;p=u}else{M=B;break}}}else{M=0}c[t>>2]=M}p=b+64|0;g=c[p>>2]|0;K=c[p+4>>2]|0;p=b+16|0;j=c[p>>2]|0;h=c[p+4>>2]|0;p=c[e+472>>2]|0;do{if((p|0)==0){N=h;O=j}else{B=e+464|0;u=c[B>>2]|0;L=c[B+4>>2]|0;if((u|0)==0&(L|0)==(-2147483648|0)|(j|0)==0&(h|0)==(-2147483648|0)){N=h;O=j;break}B=(L|0)>(h|0)|(L|0)==(h|0)&u>>>0>j>>>0;if((p|0)==1&B){u=_Gb(1,0,c[e+188>>2]|0)|0;L=YGb(u,F,j,h)|0;N=F;O=L;break}if((p|0)!=-1|B){N=h;O=j;break}B=_Gb(1,0,c[e+188>>2]|0)|0;L=ZGb(j,h,B,F)|0;N=F;O=L}}while(0);mT(e+400|0,e+404|0,e+408|0,g,K,O,N,0,0,1)|0}}while(0);N=b+16|0;O=c[N>>2]|0;e=c[N+4>>2]|0;M=2147352575;if((e|0)>(M|0)|(e|0)==(M|0)&O>>>0>-1>>>0){M=YGb(O,e,1,-2147418112)|0;c[N>>2]=M;c[N+4>>2]=F}N=b+8|0;b=c[N>>2]|0;M=c[N+4>>2]|0;e=2147352575;if(!((M|0)>(e|0)|(M|0)==(e|0)&b>>>0>-1>>>0)){k=l;i=d;return k|0}e=YGb(b,M,1,-2147418112)|0;c[N>>2]=e;c[N+4>>2]=F;k=l;i=d;return k|0}function hT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;e=i;i=i+280|0;f=e|0;g=e+8|0;h=e+216|0;j=e+248|0;vZ(d);k=b+1264|0;l=g+32|0;m=b+28|0;n=g+8|0;o=b+1168|0;p=d;q=g;r=b+4|0;s=d+36|0;t=d+16|0;u=b+1124|0;v=d+64|0;w=b+1084|0;y=b;z=e+152|0;A=e+184|0;B=g+16|0;C=g+28|0;D=g+48|0;E=g+36|0;G=e+88|0;H=e+120|0;a:while(1){I=c[k>>2]|0;if((I|0)!=0){J=I;K=59;break}L=cT(b,g)|0;if((L|0)<0){K=4;break}I=c[l>>2]|0;M=c[(c[m>>2]|0)+(I<<2)>>2]|0;N=c[n>>2]|0;O=c[n+4>>2]|0;do{if(!((N|0)==0&(O|0)==(-2147483648|0))){P=c[B>>2]|0;Q=c[B+4>>2]|0;if(!(((P|0)!=0|(Q|0)!=(-2147483648|0))&((O|0)<(Q|0)|(O|0)==(Q|0)&N>>>0<P>>>0))){break}TGb(G|0,0,32)|0;a[G]=0;Lb(G|0,32,2265168,(R=i,i=i+16|0,c[R>>2]=N,c[R+8>>2]=O,R)|0)|0;i=R;TGb(H|0,0,32)|0;a[H]=0;P=c[B>>2]|0;Q=c[B+4>>2]|0;if((P|0)==0&(Q|0)==(-2147483648|0)){Lb(H|0,32,2266248,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Lb(H|0,32,2265168,(R=i,i=i+16|0,c[R>>2]=P,c[R+8>>2]=Q,R)|0)|0;i=R}Q=c[C>>2]|0;yDb(y,24,2281512,(R=i,i=i+32|0,c[R>>2]=I,c[R+8>>2]=G,c[R+16>>2]=H,c[R+24>>2]=Q,R)|0);i=R}}while(0);if((c[o>>2]&1|0)!=0){I=c[l>>2]|0;TGb(z|0,0,32)|0;a[z]=0;O=c[n>>2]|0;N=c[n+4>>2]|0;if((O|0)==0&(N|0)==(-2147483648|0)){Lb(z|0,32,2266248,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Lb(z|0,32,2265168,(R=i,i=i+16|0,c[R>>2]=O,c[R+8>>2]=N,R)|0)|0;i=R}TGb(A|0,0,32)|0;a[A]=0;N=c[B>>2]|0;O=c[B+4>>2]|0;if((N|0)==0&(O|0)==(-2147483648|0)){Lb(A|0,32,2266248,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Lb(A|0,32,2265168,(R=i,i=i+16|0,c[R>>2]=N,c[R+8>>2]=O,R)|0)|0;i=R}O=c[C>>2]|0;N=c[D>>2]|0;Q=c[E>>2]|0;yDb(y,48,2280472,(R=i,i=i+48|0,c[R>>2]=I,c[R+8>>2]=z,c[R+16>>2]=A,c[R+24>>2]=O,c[R+32>>2]=N,c[R+40>>2]=Q,R)|0);i=R}Q=M+236|0;b:do{if((c[Q>>2]|0)==0){K=33}else{N=M+240|0;do{if((c[N>>2]|0)==0){if((c[w>>2]&32|0)!=0){K=33;break b}O=M+8|0;I=RRa(c[(c[O>>2]|0)+48>>2]|0)|0;c[N>>2]=I;if((I|0)==0){P=H0a(c[(c[O>>2]|0)+48>>2]|0)|0;yDb(y,40,2133808,(R=i,i=i+8|0,c[R>>2]=P,R)|0);i=R;c[Q>>2]=0;K=33;break b}P=c[Q>>2]|0;if((P|0)==2){O=I+176|0;c[O>>2]=c[O>>2]|1;break}else if((P|0)==4){O=I+176|0;c[O>>2]=c[O>>2]|2;break}else if((P|0)==1463898624){O=I+176|0;c[O>>2]=c[O>>2]|4096;break}else if((P|0)==0){K=33;break b}else{break}}}while(0);if((c[M+76>>2]|0)<48){N=kU(b,g,c[l>>2]|0)|0;if((N|0)<0){S=N;K=77;break a}else{T=N;U=0;break}}else{BZ(g);T=0;U=0;break}}}while(0);do{if((K|0)==33){K=0;UGb(p|0,q|0,80)|0;lU(b,M,0,d);if((c[(c[r>>2]|0)+8>>2]&256|0)==0){T=0;U=1;break}if((c[s>>2]&1|0)==0){T=0;U=1;break}Q=c[t>>2]|0;N=c[t+4>>2]|0;if((Q|0)==0&(N|0)==(-2147483648|0)){T=0;U=1;break}P=c[(c[m>>2]|0)+(c[M>>2]<<2)>>2]|0;O=P+404|0;I=c[O>>2]|0;if(I>>>0<(((c[u>>2]|0)>>>0)/24|0)>>>0){V=N;W=Q}else{if((I|0)>0){I=P+400|0;P=0;X=0;do{Y=c[I>>2]|0;Z=Y+(P*24|0)|0;_=Y+(X*24|0)|0;c[Z>>2]=c[_>>2];c[Z+4>>2]=c[_+4>>2];c[Z+8>>2]=c[_+8>>2];c[Z+12>>2]=c[_+12>>2];c[Z+16>>2]=c[_+16>>2];c[Z+20>>2]=c[_+20>>2];P=P+1|0;X=P<<1;}while((X|0)<(c[O>>2]|0));$=P;aa=c[t+4>>2]|0;ba=c[t>>2]|0}else{$=0;aa=N;ba=Q}c[O>>2]=$;V=aa;W=ba}X=c[v>>2]|0;I=c[v+4>>2]|0;_=c[M+472>>2]|0;do{if((_|0)==0){ca=V;da=W}else{Z=M+464|0;Y=c[Z>>2]|0;ea=c[Z+4>>2]|0;if((Y|0)==0&(ea|0)==(-2147483648|0)|(W|0)==0&(V|0)==(-2147483648|0)){ca=V;da=W;break}Z=(ea|0)>(V|0)|(ea|0)==(V|0)&Y>>>0>W>>>0;if((_|0)==1&Z){Y=_Gb(1,0,c[M+188>>2]|0)|0;ea=YGb(Y,F,W,V)|0;ca=F;da=ea;break}if((_|0)!=-1|Z){ca=V;da=W;break}Z=_Gb(1,0,c[M+188>>2]|0)|0;ea=ZGb(W,V,Z,F)|0;ca=F;da=ea}}while(0);mT(M+400|0,M+404|0,M+408|0,X,I,da,ca,0,0,1)|0;T=0;U=1}}while(0);_=M+444|0;do{if((c[s>>2]&1|0)==0){if((c[_>>2]|0)==0){break}BZ(g);if((U|0)==0){continue a}UGb(p|0,q|0,80)|0;continue a}else{c[_>>2]=0}}while(0);if((U|0)!=0){fa=T;K=62;break}}if((K|0)==77){i=e;return S|0}if((K|0)==4){if((L|0)==-11){S=-11;i=e;return S|0}T=b+24|0;U=c[T>>2]|0;if((U|0)!=0){q=0;g=U;while(1){U=c[(c[m>>2]|0)+(q<<2)>>2]|0;do{if((c[U+240>>2]|0)==0){ga=g}else{if((c[U+236>>2]|0)==0){ga=g;break}kU(b,0,c[U>>2]|0)|0;ga=c[T>>2]|0}}while(0);U=q+1|0;if(U>>>0<ga>>>0){q=U;g=ga}else{break}}}ga=c[k>>2]|0;if((ga|0)==0){fa=L;K=62}else{J=ga;K=59}}if((K|0)==59){c[f>>2]=J;UGb(p|0,J|0,80)|0;p=J+80|0;c[k>>2]=c[p>>2];if((c[p>>2]|0)==0){c[b+1268>>2]=0}$Db(f);ha=0;K=63}else if((K|0)==62){if((fa|0)>-1){ha=fa;K=63}else{ia=fa}}do{if((K|0)==63){fa=(c[(c[m>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+448|0;do{if((c[fa>>2]|0)!=0){f=GZ(d,70,10)|0;if((f|0)==0){c[fa>>2]=0;break}else{b=f;x=c[fa>>2]|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;yDb(y,48,2279368,(R=i,i=i+8|0,c[R>>2]=c[fa>>2],R)|0);i=R;c[fa>>2]=0;break}}}while(0);if((c[w>>2]&262144|0)!=0){ia=ha;break}IZ(d)|0;ia=ha}}while(0);if((c[o>>2]&1|0)==0){S=ia;i=e;return S|0}o=c[d+32>>2]|0;ha=h|0;TGb(ha|0,0,32)|0;a[ha]=0;h=d+8|0;w=c[h>>2]|0;m=c[h+4>>2]|0;if((w|0)==0&(m|0)==(-2147483648|0)){Lb(ha|0,32,2266248,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Lb(ha|0,32,2265168,(R=i,i=i+16|0,c[R>>2]=w,c[R+8>>2]=m,R)|0)|0;i=R}m=j|0;TGb(m|0,0,32)|0;a[m]=0;j=c[t>>2]|0;w=c[t+4>>2]|0;if((j|0)==0&(w|0)==(-2147483648|0)){Lb(m|0,32,2266248,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Lb(m|0,32,2265168,(R=i,i=i+16|0,c[R>>2]=j,c[R+8>>2]=w,R)|0)|0;i=R}w=c[d+28>>2]|0;j=c[d+48>>2]|0;d=c[s>>2]|0;yDb(y,48,2278288,(R=i,i=i+48|0,c[R>>2]=o,c[R+8>>2]=ha,c[R+16>>2]=m,c[R+24>>2]=w,c[R+32>>2]=j,c[R+40>>2]=d,R)|0);i=R;S=ia;i=e;return S|0}function iT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=d+404|0;e=c[b>>2]|0;if(e>>>0<(((c[a+1124>>2]|0)>>>0)/24|0)>>>0){return}if((e|0)>0){e=d+400|0;d=0;a=0;while(1){f=c[e>>2]|0;g=f+(d*24|0)|0;h=f+(a*24|0)|0;c[g>>2]=c[h>>2];c[g+4>>2]=c[h+4>>2];c[g+8>>2]=c[h+8>>2];c[g+12>>2]=c[h+12>>2];c[g+16>>2]=c[h+16>>2];c[g+20>>2]=c[h+20>>2];h=d+1|0;g=h<<1;if((g|0)<(c[b>>2]|0)){d=h;a=g}else{i=h;break}}}else{i=0}c[b>>2]=i;return}function jT(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=c[a+472>>2]|0;do{if((j|0)==0){k=f;l=e}else{m=a+464|0;n=c[m>>2]|0;o=c[m+4>>2]|0;if((n|0)==0&(o|0)==(-2147483648|0)|(e|0)==0&(f|0)==(-2147483648|0)){k=f;l=e;break}m=(o|0)>(f|0)|(o|0)==(f|0)&n>>>0>e>>>0;if((j|0)==1&m){n=_Gb(1,0,c[a+188>>2]|0)|0;o=YGb(n,F,e,f)|0;k=F;l=o;break}if((j|0)!=-1|m){k=f;l=e;break}m=_Gb(1,0,c[a+188>>2]|0)|0;o=ZGb(e,f,m,F)|0;k=F;l=o}}while(0);return mT(a+400|0,a+404|0,a+408|0,b,d,l,k,g,h,i)|0}function kT(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=a+1264|0;h=a+1268|0;j=f;k=c[g>>2]|0;if((k|0)!=0){l=k;do{c[f>>2]=l;c[g>>2]=c[l+80>>2];BZ(l|0);$Db(j);l=c[g>>2]|0;}while((l|0)!=0)}c[h>>2]=0;h=a+1236|0;l=a+1240|0;g=e;j=c[h>>2]|0;if((j|0)!=0){f=j;do{c[e>>2]=f;c[h>>2]=c[f+80>>2];BZ(f|0);$Db(g);f=c[h>>2]|0;}while((f|0)!=0)}c[l>>2]=0;l=a+1256|0;f=a+1260|0;h=d;g=c[l>>2]|0;if((g|0)!=0){e=g;do{c[d>>2]=e;c[l>>2]=c[e+80>>2];BZ(e|0);$Db(h);e=c[l>>2]|0;}while((e|0)!=0)}c[f>>2]=0;c[a+1272>>2]=25e5;f=a+24|0;if((c[f>>2]|0)==0){i=b;return}e=a+28|0;a=0;do{l=c[(c[e>>2]|0)+(a<<2)>>2]|0;h=l+240|0;d=c[h>>2]|0;if((d|0)!=0){VRa(d);c[h>>2]=0}h=l+216|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=l+640|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=l+200|0;d=(c[h>>2]|0)==0&(c[h+4>>2]|0)==(-2147483648|0);h=l+208|0;c[h>>2]=d?-1:0;c[h+4>>2]=d?2147418111:-2147483648;c[l+228>>2]=2500;d=l+264|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+272|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+280|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+288|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+296|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+304|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+312|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+320|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+328|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+336|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+344|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+352|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+360|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+368|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+376|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+384|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+392|0;c[d>>2]=0;c[d+4>>2]=-2147483648;a=a+1|0;}while(a>>>0<(c[f>>2]|0)>>>0);i=b;return}function lT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c[a+24>>2]|0;if((f|0)==0){return}g=c[a+28>>2]|0;a=c[b+40>>2]|0;h=a;i=(a|0)<0|0?-1:0;a=c[b+44>>2]|0;b=a;j=(a|0)<0|0?-1:0;a=0;do{k=c[g+(a<<2)>>2]|0;l=c[k+44>>2]|0;m=gHb(h,i,l,(l|0)<0|0?-1:0)|0;l=F;n=c[k+40>>2]|0;o=gHb(b,j,n,(n|0)<0|0?-1:0)|0;n=IDb(d,e,m,l,o,F)|0;o=k+208|0;c[o>>2]=n;c[o+4>>2]=F;a=a+1|0;}while(a>>>0<f>>>0);return}function mT(a,b,d,e,f,g,h,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=i;n=c[b>>2]|0;if((n+1|0)>>>0>178956969>>>0){o=-1;i=m;return o|0}if((g|0)==0&(h|0)==(-2147483648|0)|j>>>0>1073741823>>>0){o=-22;i=m;return o|0}p=2147352575;q=(h|0)>(p|0)|(h|0)==(p|0)&g>>>0>-1>>>0;p=YGb(g,h,1,-2147418112)|0;r=q?p:g;g=q?F:h;h=jEb(c[a>>2]|0,d,(n*24|0)+24|0)|0;n=h;if((h|0)==0){o=-1;i=m;return o|0}c[a>>2]=n;a=c[b>>2]|0;h=(a|0)==0;if(h){s=0;t=-1}else{d=a-1|0;q=n+(d*24|0)+8|0;p=c[q+4>>2]|0;s=a;t=(p|0)<(g|0)|(p|0)==(g|0)&(c[q>>2]|0)>>>0<r>>>0?d:-1}if((s-t|0)>1){d=t;t=s;while(1){q=d+t>>1;p=n+(q*24|0)+8|0;u=c[p>>2]|0;v=c[p+4>>2]|0;p=(v|0)<(g|0)|(v|0)==(g|0)&u>>>0<r>>>0?t:q;w=(v|0)>(g|0)|(v|0)==(g|0)&u>>>0>r>>>0?d:q;if((p-w|0)>1){d=w;t=p}else{x=p;break}}}else{x=s}s=(x|0)==(a|0)?-1:x;do{if((s|0)<0){c[b>>2]=a+1;x=n+(a*24|0)|0;if(h){y=0;z=x;A=k;break}t=n+((a-1|0)*24|0)+8|0;d=c[t+4>>2]|0;if((d|0)<(g|0)|(d|0)==(g|0)&(c[t>>2]|0)>>>0<r>>>0){y=a;z=x;A=k;break}yDb(0,0,2246464,(x=i,i=i+24|0,c[x>>2]=2195336,c[x+8>>2]=2220768,c[x+16>>2]=1766,x)|0);i=x;Cd();return 0}else{x=n+(s*24|0)|0;t=n+(s*24|0)+8|0;d=c[t>>2]|0;p=c[t+4>>2]|0;if((d|0)==(r|0)&(p|0)==(g|0)){t=x|0;if(!((c[t>>2]|0)==(e|0)&(c[t+4>>2]|0)==(f|0))){y=s;z=x;A=k;break}t=c[n+(s*24|0)+20>>2]|0;y=s;z=x;A=(t|0)>(k|0)?t:k;break}if((p|0)>(g|0)|(p|0)==(g|0)&d>>>0>r>>>0){VGb(n+((s+1|0)*24|0)|0,x|0,(a-s|0)*24|0|0)|0;c[b>>2]=(c[b>>2]|0)+1;y=s;z=x;A=k;break}else{o=-1;i=m;return o|0}}}while(0);k=z|0;c[k>>2]=e;c[k+4>>2]=f;f=z+8|0;c[f>>2]=r;c[f+4>>2]=g;c[z+20>>2]=A;c[z+16>>2]=l&3|j<<2;o=y;i=m;return o|0}function nT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((b|0)==0){g=0;h=-1}else{i=b-1|0;j=a+(i*24|0)+8|0;k=c[j+4>>2]|0;g=b;h=(k|0)<(e|0)|(k|0)==(e|0)&(c[j>>2]|0)>>>0<d>>>0?i:-1}if((g-h|0)>1){i=h;j=g;while(1){k=j+i>>1;l=a+(k*24|0)+8|0;m=c[l>>2]|0;n=c[l+4>>2]|0;l=(n|0)<(e|0)|(n|0)==(e|0)&m>>>0<d>>>0?j:k;o=(n|0)>(e|0)|(n|0)==(e|0)&m>>>0>d>>>0?i:k;if((l-o|0)>1){i=o;j=l}else{p=o;q=l;break}}}else{p=h;q=g}g=f&1;h=(g|0)!=0?p:q;if((f&4|0)!=0){r=h;s=(r|0)==(b|0);t=s?-1:r;return t|0}if(!((h|0)>-1&(h|0)<(b|0))){r=h;s=(r|0)==(b|0);t=s?-1:r;return t|0}f=(g<<1^2)-1|0;g=h;while(1){if((c[a+(g*24|0)+16>>2]&1|0)!=0){r=g;u=10;break}h=f+g|0;if((h|0)>-1&(h|0)<(b|0)){g=h}else{r=h;u=10;break}}if((u|0)==10){s=(r|0)==(b|0);t=s?-1:r;return t|0}return 0}function oT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[a+400>>2]|0;g=c[a+404>>2]|0;if((g|0)==0){h=0;i=-1}else{a=g-1|0;j=f+(a*24|0)+8|0;k=c[j+4>>2]|0;h=g;i=(k|0)<(d|0)|(k|0)==(d|0)&(c[j>>2]|0)>>>0<b>>>0?a:-1}if((h-i|0)>1){a=i;j=h;while(1){k=a+j>>1;l=f+(k*24|0)+8|0;m=c[l>>2]|0;n=c[l+4>>2]|0;l=(n|0)<(d|0)|(n|0)==(d|0)&m>>>0<b>>>0?j:k;o=(n|0)>(d|0)|(n|0)==(d|0)&m>>>0>b>>>0?a:k;if((l-o|0)>1){a=o;j=l}else{p=o;q=l;break}}}else{p=i;q=h}h=e&1;i=(h|0)!=0?p:q;if((e&4|0)!=0){r=i;s=(r|0)==(g|0);t=s?-1:r;return t|0}if(!((i|0)>-1&(i|0)<(g|0))){r=i;s=(r|0)==(g|0);t=s?-1:r;return t|0}e=(h<<1^2)-1|0;h=i;while(1){if((c[f+(h*24|0)+16>>2]&1|0)!=0){r=h;u=10;break}i=e+h|0;if((i|0)>-1&(i|0)<(g|0)){h=i}else{r=i;u=10;break}}if((u|0)==10){s=(r|0)==(g|0);t=s?-1:r;return t|0}return 0}function pT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;g=i;i=i+8|0;h=g|0;j=c[a+4>>2]|0;if((b|0)<0){k=-1;i=g;return k|0}l=a+28|0;m=c[(c[l>>2]|0)+(b<<2)>>2]|0;n=c[m+400>>2]|0;do{if((n|0)==0){o=0;p=0;q=-2147483648;r=0;s=-2147483648;t=0;u=-1;v=-1;w=0;x=0}else{y=c[m+404>>2]|0;z=(y|0)==0;if(z){A=0;B=-1}else{C=y-1|0;D=n+(C*24|0)+8|0;E=c[D+4>>2]|0;A=y;B=(E|0)<(e|0)|(E|0)==(e|0)&(c[D>>2]|0)>>>0<d>>>0?C:-1}if((A-B|0)>1){C=B;D=A;while(1){E=C+D>>1;G=n+(E*24|0)+8|0;H=c[G>>2]|0;I=c[G+4>>2]|0;G=(I|0)<(e|0)|(I|0)==(e|0)&H>>>0<d>>>0?D:E;J=(I|0)>(e|0)|(I|0)==(e|0)&H>>>0>d>>>0?C:E;if((G-J|0)>1){C=J;D=G}else{K=J;break}}}else{K=B}D=(f&4|0)==0;a:do{if(D){if((K|0)>-1&(K|0)<(y|0)){L=K}else{M=K;break}while(1){if((c[n+(L*24|0)+16>>2]&1|0)!=0){M=L;break a}C=L-1|0;if((L|0)>0&(C|0)<(y|0)){L=C}else{M=C;break}}}else{M=K}}while(0);C=(M|0)==(y|0)?-1:M;J=(C|0)>0?C:0;C=n+(J*24|0)+8|0;G=c[C>>2]|0;E=c[C+4>>2]|0;C=n+(J*24|0)|0;H=c[C>>2]|0;I=c[C+4>>2]|0;if((E|0)>(e|0)|(E|0)==(e|0)&G>>>0>d>>>0){C=c[n+(J*24|0)+20>>2]|0;if((H|0)==(C|0)&(I|0)==(((C|0)<0|0?-1:0)|0)){N=13}else{O=0;P=0;Q=-2147483648;R=0}}else{N=13}if((N|0)==13){O=I;P=H;Q=E;R=G}if(z){S=0;T=-1}else{G=y-1|0;E=n+(G*24|0)+8|0;H=c[E+4>>2]|0;S=y;T=(H|0)<(e|0)|(H|0)==(e|0)&(c[E>>2]|0)>>>0<d>>>0?G:-1}if((S-T|0)>1){G=T;E=S;while(1){H=G+E>>1;I=n+(H*24|0)+8|0;C=c[I>>2]|0;J=c[I+4>>2]|0;I=(J|0)<(e|0)|(J|0)==(e|0)&C>>>0<d>>>0?E:H;U=(J|0)>(e|0)|(J|0)==(e|0)&C>>>0>d>>>0?G:H;if((I-U|0)>1){G=U;E=I}else{V=I;break}}}else{V=S}b:do{if(D){if((V|0)>-1&(V|0)<(y|0)){W=V}else{X=V;break}while(1){if((c[n+(W*24|0)+16>>2]&1|0)!=0){X=W;break b}E=W+1|0;if((E|0)>-1&(E|0)<(y|0)){W=E}else{X=E;break}}}else{X=V}}while(0);D=(X|0)==(y|0)?-1:X;if((D|0)>=(y|0)){yDb(0,0,2246464,(E=i,i=i+24|0,c[E>>2]=2179880,c[E+8>>2]=2220768,c[E+16>>2]=1887,E)|0);i=E;Cd();return 0}if(!((D|0)>-1)){o=O;p=P;q=-2147483648;r=0;s=Q;t=R;u=-1;v=-1;w=0;x=0;break}E=n+(D*24|0)|0;G=c[E>>2]|0;z=c[E+4>>2]|0;E=n+(D*24|0)+8|0;I=c[E>>2]|0;U=c[E+4>>2]|0;E=c[n+(D*24|0)+20>>2]|0;D=ZGb(G,z,E,(E|0)<0|0?-1:0)|0;o=O;p=P;q=U;r=I;s=Q;t=R;u=F;v=D;w=z;x=G}}while(0);R=qT(a,b,d,e,p,o,x,w,v,u,t,s,r,q,f,h,c[j+56>>2]|0)|0;j=F;f=0;if((j|0)<(f|0)|(j|0)==(f|0)&R>>>0<0>>>0){k=-1;i=g;return k|0}f=Ty(c[a+16>>2]|0,R,j,0)|0;j=F;R=0;if((j|0)<(R|0)|(j|0)==(R|0)&f>>>0<0>>>0){k=f;i=g;return k|0}kT(a);f=c[h>>2]|0;R=c[h+4>>2]|0;h=c[a+24>>2]|0;if((h|0)==0){k=0;i=g;return k|0}a=c[l>>2]|0;l=c[m+40>>2]|0;j=l;q=(l|0)<0|0?-1:0;l=c[m+44>>2]|0;m=l;r=(l|0)<0|0?-1:0;l=0;while(1){s=c[a+(l<<2)>>2]|0;t=c[s+44>>2]|0;u=gHb(t,(t|0)<0|0?-1:0,j,q)|0;t=F;v=c[s+40>>2]|0;w=gHb(v,(v|0)<0|0?-1:0,m,r)|0;v=IDb(f,R,u,t,w,F)|0;w=s+208|0;c[w>>2]=v;c[w+4>>2]=F;w=l+1|0;if(w>>>0<h>>>0){l=w}else{k=0;break}}i=g;return k|0}function qT(a,b,d,e,f,g,h,j,k,l,m,n,o,p,q,r,s){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;var t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;t=i;i=i+32|0;u=t|0;v=t+8|0;w=t+16|0;x=t+24|0;c[u>>2]=f;c[u+4>>2]=g;c[v>>2]=h;c[v+4>>2]=j;c[w>>2]=o;c[w+4>>2]=p;do{if((m|0)==0&(n|0)==(-2147483648|0)){p=a+1248|0;o=c[p+4>>2]|0;c[u>>2]=c[p>>2];c[u+4>>2]=o;o=Pe[s&255](a,b,u,-1,2147483647)|0;p=F;do{if((b|0)>-1){j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;h=c[j+472>>2]|0;if((h|0)==0){y=p;z=o;break}g=j+464|0;f=c[g>>2]|0;A=c[g+4>>2]|0;if((f|0)==0&(A|0)==(-2147483648|0)|(o|0)==0&(p|0)==(-2147483648|0)){y=p;z=o;break}g=(A|0)>(p|0)|(A|0)==(p|0)&f>>>0>o>>>0;if((h|0)==1&g){f=_Gb(1,0,c[j+188>>2]|0)|0;A=YGb(f,F,o,p)|0;y=F;z=A;break}if((h|0)!=-1|g){y=p;z=o;break}g=_Gb(1,0,c[j+188>>2]|0)|0;j=ZGb(o,p,g,F)|0;y=F;z=j}else{y=p;z=o}}while(0);if((z|0)==0&(y|0)==(-2147483648|0)){B=-1;C=-1}else{D=y;E=z;break}i=t;return(F=B,C)|0}else{D=n;E=m}}while(0);if(!((D|0)<(e|0)|(D|0)==(e|0)&E>>>0<d>>>0)){c[r>>2]=E;c[r+4>>2]=D;B=c[u+4>>2]|0;C=c[u>>2]|0;i=t;return(F=B,C)|0}m=c[w>>2]|0;n=c[w+4>>2]|0;do{if((m|0)==0&(n|0)==(-2147483648|0)){z=rT(a,b,w,v,s)|0;if((z|0)>=0){G=c[v+4>>2]|0;H=c[v>>2]|0;I=c[w+4>>2]|0;J=c[w>>2]|0;break}B=(z|0)<0|0?-1:0;C=z;i=t;return(F=B,C)|0}else{G=l;H=k;I=n;J=m}}while(0);if(!((I|0)>(e|0)|(I|0)==(e|0)&J>>>0>d>>>0)){c[r>>2]=J;c[r+4>>2]=I;B=c[v+4>>2]|0;C=c[v>>2]|0;i=t;return(F=B,C)|0}if((D|0)>(I|0)|(D|0)==(I|0)&E>>>0>J>>>0){B=-1;C=-1;i=t;return(F=B,C)|0}m=(E|0)==(J|0)&(D|0)==(I|0);I=c[u>>2]|0;J=c[u+4>>2]|0;n=(b|0)>-1;k=a+28|0;l=m?J:G;G=m?I:H;H=0;m=D;D=E;E=J;J=I;a:while(1){I=ZGb(d,e,D,m)|0;z=F;y=l;o=G;p=H;K=E;L=J;while(1){if(!((K|0)<(y|0)|(K|0)==(y|0)&L>>>0<o>>>0)){M=44;break a}if((p|0)==0){j=c[v>>2]|0;g=c[v+4>>2]|0;h=ZGb(j,g,L,K)|0;A=F;f=ZGb(c[w>>2]|0,c[w+4>>2]|0,D,m)|0;N=IDb(I,z,h,A,f,F)|0;f=F;A=YGb(L,K,o,y)|0;h=ZGb(A,F,j,g)|0;g=YGb(h,F,N,f)|0;f=F;O=f;P=g;Q=f;R=g;M=26}else if((p|0)==1){g=YGb(L,K,o,y)|0;f=F;N=g>>>1|f<<31;g=f>>1|((f|0)<0|0?-1:0)<<31;O=g;P=N;Q=g;R=N;M=26}else{c[x>>2]=L;c[x+4>>2]=K;M=27}do{if((M|0)==26){M=0;c[x>>2]=R;c[x+4>>2]=Q;if(!((O|0)>(K|0)|(O|0)==(K|0)&P>>>0>L>>>0)){M=27;break}if(!((O|0)>(y|0)|(O|0)==(y|0)&P>>>0>o>>>0)){S=O;T=P;break}c[x>>2]=o;c[x+4>>2]=y;S=y;T=o}}while(0);if((M|0)==27){M=0;N=YGb(L,K,1,0)|0;g=F;c[x>>2]=N;c[x+4>>2]=g;S=g;T=N}N=Pe[s&255](a,b,x,-1,2147483647)|0;g=F;do{if(n){f=c[(c[k>>2]|0)+(b<<2)>>2]|0;h=c[f+472>>2]|0;if((h|0)==0){U=g;V=N;break}j=f+464|0;A=c[j>>2]|0;W=c[j+4>>2]|0;if((A|0)==0&(W|0)==(-2147483648|0)|(N|0)==0&(g|0)==(-2147483648|0)){U=g;V=N;break}j=(W|0)>(g|0)|(W|0)==(g|0)&A>>>0>N>>>0;if((h|0)==1&j){A=_Gb(1,0,c[f+188>>2]|0)|0;W=YGb(A,F,N,g)|0;U=F;V=W;break}if((h|0)!=-1|j){U=g;V=N;break}j=_Gb(1,0,c[f+188>>2]|0)|0;f=ZGb(N,g,j,F)|0;U=F;V=f}else{U=g;V=N}}while(0);X=c[x>>2]|0;Y=c[x+4>>2]|0;Z=(X|0)==(c[v>>2]|0)&(Y|0)==(c[v+4>>2]|0)?p+1|0:0;if((V|0)==0&(U|0)==(-2147483648|0)){M=38;break a}if((U|0)<(e|0)|(U|0)==(e|0)&V>>>0<d>>>0){_=y;$=o}else{N=YGb(T,S,-1,-1)|0;c[v>>2]=X;c[v+4>>2]=Y;c[w>>2]=V;c[w+4>>2]=U;_=F;$=N}if(!((U|0)>(e|0)|(U|0)==(e|0)&V>>>0>d>>>0)){break}y=_;o=$;p=Z;K=c[u+4>>2]|0;L=c[u>>2]|0}c[u>>2]=X;c[u+4>>2]=Y;l=_;G=$;H=Z;m=U;D=V;E=Y;J=X}if((M|0)==38){yDb(a,16,2160224,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;B=-1;C=-1;i=t;return(F=B,C)|0}else if((M|0)==44){M=(q&1|0)!=0;q=M?L:c[v>>2]|0;L=M?K:c[v+4>>2]|0;c[x>>2]=q;c[x+4>>2]=L;x=M?m:c[w+4>>2]|0;c[r>>2]=M?D:c[w>>2]|0;c[r+4>>2]=x;B=L;C=q;i=t;return(F=B,C)|0}return 0}function rT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=Wy(c[a+16>>2]|0)|0;l=F;m=YGb(k,l,-1,-1)|0;n=F;c[h>>2]=m;c[h+4>>2]=n;o=(b|0)>-1;p=a+28|0;q=0;r=1024;s=n;n=m;while(1){m=ZGb(n,s,r,q)|0;t=F;u=0;v=(t|0)<(u|0)|(t|0)==(u|0)&m>>>0<0>>>0;c[h>>2]=v?0:m;c[h+4>>2]=v?0:t;t=Pe[f&255](a,b,h,n,s)|0;v=F;do{if(o){m=c[(c[p>>2]|0)+(b<<2)>>2]|0;u=c[m+472>>2]|0;if((u|0)==0){w=v;x=t;break}y=m+464|0;z=c[y>>2]|0;A=c[y+4>>2]|0;if((z|0)==0&(A|0)==(-2147483648|0)|(t|0)==0&(v|0)==(-2147483648|0)){w=v;x=t;break}y=(A|0)>(v|0)|(A|0)==(v|0)&z>>>0>t>>>0;if((u|0)==1&y){z=_Gb(1,0,c[m+188>>2]|0)|0;A=YGb(z,F,t,v)|0;w=F;x=A;break}if((u|0)!=-1|y){w=v;x=t;break}y=_Gb(1,0,c[m+188>>2]|0)|0;m=ZGb(t,v,y,F)|0;w=F;x=m}else{w=v;x=t}}while(0);t=r<<1|0>>>31;v=q<<1|r>>>31;B=(x|0)==0&(w|0)==(-2147483648|0);m=s<<1|n>>>31;if(!(B&((m|0)>(v|0)|(m|0)==(v|0)&(n<<1|0>>>31)>>>0>t>>>0))){break}q=v;r=t;s=c[h+4>>2]|0;n=c[h>>2]|0}if(B){C=-1;i=g;return C|0}B=c[h>>2]|0;n=c[h+4>>2]|0;a:do{if(o){s=w;r=x;q=n;t=B;while(1){v=YGb(t,q,1,0)|0;c[j>>2]=v;c[j+4>>2]=F;v=Pe[f&255](a,b,j,-1,2147483647)|0;m=F;y=c[(c[p>>2]|0)+(b<<2)>>2]|0;u=c[y+472>>2]|0;do{if((u|0)==0){D=m;E=v}else{A=y+464|0;z=c[A>>2]|0;G=c[A+4>>2]|0;if((z|0)==0&(G|0)==(-2147483648|0)|(v|0)==0&(m|0)==(-2147483648|0)){D=m;E=v;break}A=(G|0)>(m|0)|(G|0)==(m|0)&z>>>0>v>>>0;if((u|0)==1&A){z=_Gb(1,0,c[y+188>>2]|0)|0;G=YGb(z,F,v,m)|0;D=F;E=G;break}if((u|0)!=-1|A){D=m;E=v;break}A=_Gb(1,0,c[y+188>>2]|0)|0;G=ZGb(v,m,A,F)|0;D=F;E=G}}while(0);if((E|0)==0&(D|0)==(-2147483648|0)){H=s;I=r;break a}m=c[j>>2]|0;v=c[j+4>>2]|0;y=c[h+4>>2]|0;if(!((v|0)>(y|0)|(v|0)==(y|0)&m>>>0>(c[h>>2]|0)>>>0)){break}c[h>>2]=m;c[h+4>>2]=v;if((v|0)<(l|0)|(v|0)==(l|0)&m>>>0<k>>>0){s=D;r=E;q=v;t=m}else{H=D;I=E;break a}}yDb(0,0,2246464,(J=i,i=i+24|0,c[J>>2]=2166896,c[J+8>>2]=2220768,c[J+16>>2]=1937,J)|0);i=J;Cd();return 0}else{t=w;q=x;r=n;s=B;while(1){m=YGb(s,r,1,0)|0;c[j>>2]=m;c[j+4>>2]=F;m=Pe[f&255](a,b,j,-1,2147483647)|0;v=F;if((m|0)==0&(v|0)==(-2147483648|0)){H=t;I=q;break a}y=c[j>>2]|0;u=c[j+4>>2]|0;G=c[h+4>>2]|0;if(!((u|0)>(G|0)|(u|0)==(G|0)&y>>>0>(c[h>>2]|0)>>>0)){break}c[h>>2]=y;c[h+4>>2]=u;if((u|0)<(l|0)|(u|0)==(l|0)&y>>>0<k>>>0){t=v;q=m;r=u;s=y}else{H=v;I=m;break a}}yDb(0,0,2246464,(J=i,i=i+24|0,c[J>>2]=2166896,c[J+8>>2]=2220768,c[J+16>>2]=1937,J)|0);i=J;Cd();return 0}}while(0);if((d|0)!=0){c[d>>2]=I;c[d+4>>2]=H}if((e|0)==0){C=0;i=g;return C|0}H=c[h+4>>2]|0;c[e>>2]=c[h>>2];c[e+4>>2]=H;C=0;i=g;return C|0}function sT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;g=i;i=i+160|0;h=g|0;j=g+80|0;k=a+4|0;l=c[k>>2]|0;do{if((c[l+68>>2]|0)!=0){if((c[l+52>>2]|0)!=0){break}m=(f&1|0)==0;n=tT(a,b,m?d:0,m?e:-2147483648,d,e,m?-1:d,m?2147483647:e,f&-2)|0;i=g;return n|0}}while(0);a:do{if((f&2|0)==0){if((b|0)<0){m=c[a+24>>2]|0;if((m|0)==0){n=-1;i=g;return n|0}o=c[a+28>>2]|0;p=-1;q=0;while(1){r=c[o+(q<<2)>>2]|0;s=c[(c[r+8>>2]|0)+8>>2]|0;if((s|0)==0){if((c[r+72>>2]&1024|0)==0){t=18;break}}if((p|0)<0){u=(s|0)==1?q:p}else{u=p}s=q+1|0;if(s>>>0<m>>>0){p=u;q=s}else{t=17;break}}do{if((t|0)==17){p=(u|0)<0?0:u;v=p;w=c[o+(p<<2)>>2]|0}else if((t|0)==18){if((q|0)<0){n=-1}else{v=q;w=r;break}i=g;return n|0}}while(0);q=c[w+44>>2]|0;o=c[w+40>>2]|0;p=gHb(o,(o|0)<0|0?-1:0,1e6,0)|0;o=IDb(d,e,q,(q|0)<0|0?-1:0,p,F)|0;x=v;y=F;z=o}else{x=b;y=e;z=d}if((c[l+52>>2]|0)==0){A=l}else{kT(a);if((Pe[c[(c[k>>2]|0)+52>>2]&255](a,x,z,y,f)|0)>-1){break}A=c[k>>2]|0}o=c[A+8>>2]|0;do{if((c[A+56>>2]|0)==0){t=26}else{if((o&8192|0)!=0){t=26;break}kT(a);B=pT(a,x,z,y,f)|0}}while(0);b:do{if((t|0)==26){if((o&16384|0)!=0){n=-1;i=g;return n|0}kT(a);p=a+28|0;q=c[(c[p>>2]|0)+(x<<2)>>2]|0;m=q+400|0;s=c[m>>2]|0;C=q+404|0;D=c[C>>2]|0;E=(D|0)==0;if(E){G=0;H=-1}else{I=D-1|0;J=s+(I*24|0)+8|0;K=c[J+4>>2]|0;G=D;H=(K|0)<(y|0)|(K|0)==(y|0)&(c[J>>2]|0)>>>0<z>>>0?I:-1}if((G-H|0)>1){I=H;J=G;while(1){K=I+J>>1;L=s+(K*24|0)+8|0;M=c[L>>2]|0;N=c[L+4>>2]|0;L=(N|0)<(y|0)|(N|0)==(y|0)&M>>>0<z>>>0?J:K;O=(N|0)>(y|0)|(N|0)==(y|0)&M>>>0>z>>>0?I:K;if((L-O|0)>1){I=O;J=L}else{P=O;Q=L;break}}}else{P=H;Q=G}J=f&1;I=(J|0)!=0;L=I?P:Q;O=(f&4|0)==0;c:do{if(O){if(!((L|0)>-1&(L|0)<(D|0))){R=L;break}K=(J<<1^2)-1|0;M=L;while(1){if((c[s+(M*24|0)+16>>2]&1|0)!=0){R=M;break c}N=K+M|0;if((N|0)>-1&(N|0)<(D|0)){M=N}else{R=N;break}}}else{R=L}}while(0);L=(R|0)==(D|0)?-1:R;do{if((L|0)<0){if(E){t=49;break}M=s+8|0;K=c[M+4>>2]|0;if((K|0)>(y|0)|(K|0)==(y|0)&(c[M>>2]|0)>>>0>z>>>0){n=-1}else{t=41;break}i=g;return n|0}else{if((L|0)!=(D-1|0)){S=L;break}if(E){t=49}else{t=41}}}while(0);do{if((t|0)==41){if((s|0)==0){yDb(0,0,2246464,(T=i,i=i+24|0,c[T>>2]=2284160,c[T+8>>2]=2220768,c[T+16>>2]=2103,T)|0);i=T;Cd();return 0}E=D-1|0;L=s+(E*24|0)|0;M=Ty(c[a+16>>2]|0,c[L>>2]|0,c[L+4>>2]|0,0)|0;L=F;K=0;if((L|0)<(K|0)|(L|0)==(K|0)&M>>>0<0>>>0){B=M;break b}M=s+(E*24|0)+8|0;E=c[M>>2]|0;K=c[M+4>>2]|0;M=c[a+24>>2]|0;if((M|0)==0){t=48;break}L=c[p>>2]|0;N=c[q+40>>2]|0;U=N;V=(N|0)<0|0?-1:0;N=c[q+44>>2]|0;W=N;X=(N|0)<0|0?-1:0;N=0;while(1){Y=c[L+(N<<2)>>2]|0;Z=c[Y+44>>2]|0;_=gHb(Z,(Z|0)<0|0?-1:0,U,V)|0;Z=F;$=c[Y+40>>2]|0;aa=gHb($,($|0)<0|0?-1:0,W,X)|0;$=IDb(E,K,_,Z,aa,F)|0;aa=Y+208|0;c[aa>>2]=$;c[aa+4>>2]=F;aa=N+1|0;if(aa>>>0<M>>>0){N=aa}else{t=48;break}}}else if((t|0)==49){N=a+1248|0;M=Ty(c[a+16>>2]|0,c[N>>2]|0,c[N+4>>2]|0,0)|0;N=F;K=0;if(!((N|0)<(K|0)|(N|0)==(K|0)&M>>>0<0>>>0)){t=48;break}B=M;break b}}while(0);do{if((t|0)==48){s=h+32|0;D=h+16|0;M=h+36|0;K=q+8|0;N=0;d:while(1){while(1){E=gT(a,h)|0;if((E|0)==-11){continue}if((E|0)<0){break d}BZ(h);if((c[s>>2]|0)!=(x|0)){continue}E=c[D+4>>2]|0;if((E|0)>(y|0)|(E|0)==(y|0)&(c[D>>2]|0)>>>0>z>>>0){break}}if((c[M>>2]&1|0)!=0){break}ba=N+1|0;if((N|0)<=1e3){N=ba;continue}if((c[(c[K>>2]|0)+48>>2]|0)==133){N=ba}else{t=59;break}}if((t|0)==59){yDb(a,16,2282984,(T=i,i=i+8|0,c[T>>2]=ba,T)|0);i=T}N=c[m>>2]|0;K=c[C>>2]|0;if((K|0)==0){ca=0;da=-1}else{M=K-1|0;D=N+(M*24|0)+8|0;s=c[D+4>>2]|0;ca=K;da=(s|0)<(y|0)|(s|0)==(y|0)&(c[D>>2]|0)>>>0<z>>>0?M:-1}if((ca-da|0)>1){M=da;D=ca;while(1){s=M+D>>1;E=N+(s*24|0)+8|0;X=c[E>>2]|0;W=c[E+4>>2]|0;E=(W|0)<(y|0)|(W|0)==(y|0)&X>>>0<z>>>0?D:s;V=(W|0)>(y|0)|(W|0)==(y|0)&X>>>0>z>>>0?M:s;if((E-V|0)>1){M=V;D=E}else{ea=V;fa=E;break}}}else{ea=da;fa=ca}D=I?ea:fa;e:do{if(O){if(!((D|0)>-1&(D|0)<(K|0))){ga=D;break}M=(J<<1^2)-1|0;E=D;while(1){if((c[N+(E*24|0)+16>>2]&1|0)!=0){ga=E;break e}V=M+E|0;if((V|0)>-1&(V|0)<(K|0)){E=V}else{ga=V;break}}}else{ga=D}}while(0);D=(ga|0)==(K|0)?-1:ga;if((D|0)<0){n=-1}else{S=D;break}i=g;return n|0}}while(0);kT(a);J=c[(c[k>>2]|0)+52>>2]|0;if((J|0)!=0){if((Pe[J&255](a,x,z,y,f)|0)>-1){break a}}J=c[m>>2]|0;O=J+(S*24|0)|0;I=Ty(c[a+16>>2]|0,c[O>>2]|0,c[O+4>>2]|0,0)|0;O=F;C=0;if((O|0)<(C|0)|(O|0)==(C|0)&I>>>0<0>>>0){B=I;break}I=J+(S*24|0)+8|0;J=c[I>>2]|0;C=c[I+4>>2]|0;I=c[a+24>>2]|0;if((I|0)==0){break a}O=c[p>>2]|0;D=c[q+40>>2]|0;N=D;E=(D|0)<0|0?-1:0;D=c[q+44>>2]|0;M=D;V=(D|0)<0|0?-1:0;D=0;while(1){s=c[O+(D<<2)>>2]|0;X=c[s+44>>2]|0;W=gHb(X,(X|0)<0|0?-1:0,N,E)|0;X=F;U=c[s+40>>2]|0;L=gHb(U,(U|0)<0|0?-1:0,M,V)|0;U=IDb(J,C,W,X,L,F)|0;L=s+208|0;c[L>>2]=U;c[L+4>>2]=F;D=D+1|0;if(!(D>>>0<I>>>0)){break a}}}}while(0);if((B|0)>-1){break}else{n=B}i=g;return n|0}else{if((c[l+8>>2]&32768|0)!=0){n=-1;i=g;return n|0}kT(a);o=a+1248|0;I=c[o>>2]|0;D=c[o+4>>2]|0;o=a+16|0;C=Wy(c[o>>2]|0)|0;J=YGb(C,F,-1,-1)|0;C=F;if((D|0)>(e|0)|(D|0)==(e|0)&I>>>0>d>>>0){ha=D;ia=I}else{I=(C|0)<(e|0)|(C|0)==(e|0)&J>>>0<d>>>0;ha=I?C:e;ia=I?J:d}Ty(c[o>>2]|0,ia,ha,0)|0;c[a+1300>>2]=1}}while(0);ha=j|0;j=a+24|0;if((c[j>>2]|0)==0){n=0;i=g;return n|0}ia=a+28|0;d=a+1256|0;e=a+1260|0;a=0;f:while(1){l=c[(c[ia>>2]|0)+(a<<2)>>2]|0;do{if((c[l+72>>2]&1024|0)!=0){if((c[l+76>>2]|0)>=48){break}B=c[l+104>>2]|0;UGb(ha|0,l+108|0,76)|0;S=WAb(B)|0;if((S|0)==0){n=-12;t=89;break f}B=cEb(88)|0;f=B;if((B|0)==0){break}if((c[d>>2]|0)==0){c[d>>2]=f}else{c[(c[e>>2]|0)+80>>2]=f}c[e>>2]=f;c[B>>2]=S;UGb(B+4|0,ha|0,76)|0}}while(0);l=a+1|0;if(l>>>0<(c[j>>2]|0)>>>0){a=l}else{n=0;t=89;break}}if((t|0)==89){i=g;return n|0}return 0}function tT(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;l=i;i=i+88|0;m=l|0;n=l+80|0;o=n;p=i;i=i+8|0;if((e|0)>(g|0)|(e|0)==(g|0)&d>>>0>f>>>0|((j|0)<(g|0)|(j|0)==(g|0)&h>>>0<f>>>0)){q=-1;i=l;return q|0}if((b|0)<-1){q=-22;i=l;return q|0}r=a+24|0;if((c[r>>2]|0)<=(b|0)){q=-22;i=l;return q|0}s=((c[a+1224>>2]|0)>0?k|4:k)&-2;k=a+4|0;if((c[(c[k>>2]|0)+68>>2]|0)==0){t=ZGb(f,g,d,e)|0;u=F;v=ZGb(h,j,f,g)|0;w=F;x=u>>>0>w>>>0|u>>>0==w>>>0&t>>>0>v>>>0;v=s|x&1;t=sT(a,b,f,g,v)|0;if((t|0)>-1|(f|0)==(d|0)&(g|0)==(e|0)|(h|0)==(f|0)&(j|0)==(g|0)){q=t;i=l;return q|0}t=sT(a,b,x?h:d,x?j:e,v)|0;if(!((t|0)>-1)){q=t;i=l;return q|0}q=sT(a,b,f,g,v^1)|0;i=l;return q|0}kT(a);do{if((b|0)==-1){if((c[r>>2]|0)!=1){y=j;z=h;A=g;B=f;C=e;D=d;break}v=(c[c[a+28>>2]>>2]|0)+40|0;t=c[v+4>>2]|0;c[n>>2]=c[v>>2];c[n+4>>2]=t;c[p>>2]=1;c[p+4>>2]=1e6;t=KDb(f,g,p,o)|0;v=F;x=c[o+4>>2]|0;w=x;u=(x|0)<0|0?-1:0;x=c[n>>2]|0;E=gHb(x,(x|0)<0|0?-1:0,1e6,0)|0;x=F;G=HDb(d,e,w,u,E,x,8195)|0;H=F;I=HDb(h,j,w,u,E,x,8194)|0;y=F;z=I;A=v;B=t;C=H;D=G}else{y=j;z=h;A=g;B=f;C=e;D=d}}while(0);d=Ee[c[(c[k>>2]|0)+68>>2]&63](a,b,D,C,B,A,z,y,s)|0;if(!((d|0)>-1)){q=d;i=l;return q|0}d=m|0;if((c[r>>2]|0)==0){q=0;i=l;return q|0}m=a+28|0;s=a+1256|0;y=a+1260|0;a=0;a:while(1){z=c[(c[m>>2]|0)+(a<<2)>>2]|0;do{if((c[z+72>>2]&1024|0)!=0){if((c[z+76>>2]|0)>=48){break}A=c[z+104>>2]|0;UGb(d|0,z+108|0,76)|0;B=WAb(A)|0;if((B|0)==0){q=-12;J=23;break a}A=cEb(88)|0;C=A;if((A|0)==0){break}if((c[s>>2]|0)==0){c[s>>2]=C}else{c[(c[y>>2]|0)+80>>2]=C}c[y>>2]=C;c[A>>2]=B;UGb(A+4|0,d|0,76)|0}}while(0);z=a+1|0;if(z>>>0<(c[r>>2]|0)>>>0){a=z}else{q=0;J=23;break}}if((J|0)==23){i=l;return q|0}return 0}function uT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a;while(1){a=c[d>>2]|0;if((a|0)==0){e=0;f=5;break}if((a|0)==(b|0)){break}else{d=d+8|0}}if((f|0)==5){return e|0}e=c[d+4>>2]|0;return e|0}function vT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=0;while(1){e=c[a+(d<<3)>>2]|0;if((e|0)==0){f=0;break}if((c[a+(d<<3)+4>>2]|0)==(b|0)){g=e;h=7;break}else{d=d+1|0}}if((h|0)==7){return g|0}while(1){i=a+(f<<3)|0;if((c[i>>2]|0)==0){g=0;h=7;break}d=S0a(b)|0;if((d|0)==(S0a(c[a+(f<<3)+4>>2]|0)|0)){break}else{f=f+1|0}}if((h|0)==7){return g|0}g=c[i>>2]|0;return g|0}function wT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;do{if((b|0)==0){e=a+7>>3;if((1<<e-1&d|0)==0){if((e|0)==4){f=(c|0)!=0?65547:65546;break}else if((e|0)==1){f=65541;break}else if((e|0)==3){f=(c|0)!=0?65551:65550;break}else if((e|0)==2){f=(c|0)!=0?65539:65538;break}else{f=0;break}}else{if((e|0)==3){f=(c|0)!=0?65549:65548;break}else if((e|0)==1){f=65540;break}else if((e|0)==4){f=(c|0)!=0?65545:65544;break}else if((e|0)==2){f=(c|0)!=0?65537:65536;break}else{f=0;break}}}else{if((a|0)==64){f=(c|0)!=0?65558:65559;break}else if((a|0)==32){f=(c|0)!=0?65556:65557;break}else{f=0;break}}}while(0);return f|0}function xT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)==0){d=0;return d|0}e=c[a>>2]|0;if((e|0)==0){d=0;return d|0}else{f=0;g=e}a:while(1){h=g;while(1){e=c[h>>2]|0;if((e|0)==0){break}if((e|0)==(b|0)){break a}else{h=h+8|0}}e=f+1|0;i=c[a+(e<<2)>>2]|0;if((i|0)==0){d=0;j=8;break}else{f=e;g=i}}if((j|0)==8){return d|0}d=c[h+4>>2]|0;return d|0}function yT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a|0)==0){e=0;return e|0}else{f=0}a:while(1){g=c[a+(f<<2)>>2]|0;if((g|0)==0){e=0;h=7;break}else{i=g}while(1){g=c[i>>2]|0;if((g|0)==0){break}if((g|0)==(b|0)){break a}else{i=i+8|0}}f=f+1|0}if((h|0)==7){return e|0}c[d>>2]=c[i+4>>2];e=1;return e|0}function zT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)==0){d=0;return d|0}else{e=0}while(1){f=c[a+(e<<2)>>2]|0;if((f|0)==0){d=0;g=10;break}else{h=0}while(1){i=c[f+(h<<3)>>2]|0;if((i|0)==0){j=0;g=5;break}if((c[f+(h<<3)+4>>2]|0)==(b|0)){k=i;g=8;break}else{h=h+1|0}}a:do{if((g|0)==5){while(1){g=0;l=f+(j<<3)|0;if((c[l>>2]|0)==0){break a}i=S0a(b)|0;if((i|0)==(S0a(c[f+(j<<3)+4>>2]|0)|0)){break}else{j=j+1|0;g=5}}k=c[l>>2]|0;g=8}}while(0);if((g|0)==8){g=0;if((k|0)!=0){d=k;g=10;break}}e=e+1|0}if((g|0)==10){return d|0}return 0}function AT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0.0,qb=0.0,rb=0,sb=0.0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0;d=i;i=i+664|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+136|0;o=d+160|0;p=d+168|0;q=d+176|0;r=d+256|0;s=d+264|0;t=d+272|0;u=d+280|0;v=d+288|0;w=d+296|0;x=d+304|0;y=d+312|0;z=d+320|0;A=d+400|0;B=d+408|0;C=a+16|0;D=Ty(c[C>>2]|0,0,0,1)|0;E=F;G=a+24|0;H=c[G>>2]|0;I=a+1088|0;J=(c[I>>2]|0)==0;K=c[C>>2]|0;if((K|0)==0){L=H}else{M=Ty(K,0,0,1)|0;K=F;N=c[C>>2]|0;O=N+112|0;P=c[O>>2]|0;R=c[O+4>>2]|0;O=c[N+120>>2]|0;yDb(a,48,2140256,(S=i,i=i+40|0,c[S>>2]=M,c[S+8>>2]=K,c[S+16>>2]=P,c[S+24>>2]=R,c[S+32>>2]=O,S)|0);i=S;L=c[G>>2]|0}do{if((L|0)==0){T=6}else{O=a+28|0;R=a+1084|0;P=a;K=a+1304|0;M=a+1308|0;N=a+1312|0;U=(b|0)!=0;V=0;do{c[r>>2]=0;W=c[(c[O>>2]|0)+(V<<2)>>2]|0;X=W+8|0;Y=c[X>>2]|0;Z=c[Y+8>>2]|0;do{if((Z|0)==0|(Z|0)==3){_=Y+104|0;if((c[_>>2]|0)!=0){break}$=W+40|0;aa=_;_=c[$+4>>2]|0;c[aa>>2]=c[$>>2];c[aa+4>>2]=_}}while(0);Y=W+240|0;do{if((c[Y>>2]|0)==0){if((c[R>>2]&32|0)!=0){break}Z=RRa(c[(c[X>>2]|0)+48>>2]|0)|0;c[Y>>2]=Z;_=c[W+236>>2]|0;if((Z|0)==0){if((_|0)==0){break}aa=H0a(c[(c[X>>2]|0)+48>>2]|0)|0;yDb(P,40,2133808,(S=i,i=i+8|0,c[S>>2]=aa,S)|0);i=S;break}if((_|0)==1463898624){aa=Z+176|0;c[aa>>2]=c[aa>>2]|4096;break}else if((_|0)==2){_=Z+176|0;c[_>>2]=c[_>>2]|1;break}else{break}}}while(0);Y=c[X>>2]|0;_=c[Y+48>>2]|0;Z=c[Y+12>>2]|0;do{if((Z|0)==0){aa=c[Y+8>>2]|0;if((aa|0)==1){$=c[M>>2]|0;if(($|0)!=0){ca=$;break}}else if((aa|0)==0){$=c[K>>2]|0;if(($|0)!=0){ca=$;break}}else if((aa|0)==3){aa=c[N>>2]|0;if((aa|0)!=0){ca=aa;break}}ca=q0a(_)|0}else{ca=Z}}while(0);if(U){da=b+(V<<2)|0}else{da=r}CBb(da,2127680,2121680,0)|0;Z=c[X>>2]|0;_=(ca|0)==0;do{if(!((c[Z+8>>2]|0)!=3|_)){if((c[Z+12>>2]|0)!=0){break}if(U){ea=b+(V<<2)|0}else{ea=r}if((m0a(Z,ca,ea)|0)>=0){break}yDb(P,24,2116648,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}}while(0);do{if((FT(W,0)|0)==0){if((c[W+440>>2]|0)>0|_){break}Z=c[X>>2]|0;if((c[Z+12>>2]|0)!=0){break}if(U){fa=b+(V<<2)|0}else{fa=r}if((m0a(Z,ca,fa)|0)>=0){break}yDb(P,24,2116648,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}}while(0);if(!U){DBb(r)}V=V+1|0;ga=c[G>>2]|0;}while(V>>>0<ga>>>0);if((ga|0)==0){T=6;break}V=a+28|0;U=c[V>>2]|0;P=0;while(1){N=c[(c[U+(P<<2)>>2]|0)+184>>2]|0;K=N|0;c[K>>2]=0;c[K+4>>2]=-2147483648;K=N+72|0;c[K>>2]=0;c[K+4>>2]=-2147483648;K=N+88|0;c[K>>2]=0;c[K+4>>2]=-2147483648;K=P+1|0;if(K>>>0<ga>>>0){P=K}else{ha=V;break}}}}while(0);if((T|0)==6){ha=a+28|0}ga=a+1160|0;r=a+20|0;fa=a+1152|0;ca=a+1084|0;ea=a+1236|0;da=a+1240|0;L=q;V=s|0;P=s+4|0;U=t|0;K=t+4|0;N=u|0;M=u+4|0;R=v|0;O=v+4|0;X=w|0;_=w+4|0;W=x|0;Z=x+4|0;Y=y|0;aa=y+4|0;$=a+1092|0;ia=(b|0)!=0;ja=a;ka=o;la=0;ma=0;na=0;a:while(1){do{if((Ky(ga)|0)!=0){T=47;break a}if((c[G>>2]|0)==0){oa=0;T=64}else{pa=0;b:while(1){qa=c[(c[ha>>2]|0)+(pa<<2)>>2]|0;if((FT(qa,0)|0)==0){T=62;break}ra=c[fa>>2]|0;sa=(c[qa+72>>2]&1024|0)==0?(ra|0)>-1?ra:+(c[qa+40>>2]|0)/+(c[qa+44>>2]|0)>5.0e-4?40:20:0;ra=c[qa+8>>2]|0;ta=c[ra+108>>2]|0;ua=c[ra+104>>2]|0;do{if((ta|0)>=(ua*101|0|0)|(ta|0)<(ua*5|0|0)){T=52}else{if((c[ra+52>>2]|0)==1983148141){T=52;break}va=c[ra+48>>2]|0;if((va|0)==2|(va|0)==28){T=52}}}while(0);do{if((T|0)==52){T=0;if((c[qa+412>>2]|0)!=0){if((c[qa+92>>2]|0)!=0){break}}if((c[(c[qa+184>>2]|0)+16>>2]|0)>=(sa|0)){break}if((c[ra+8>>2]|0)==0){T=62;break b}}}while(0);sa=c[qa+240>>2]|0;do{if((sa|0)!=0){if((c[(c[sa+4>>2]|0)+36>>2]|0)==0){break}if((c[ra+96>>2]|0)==0){T=62;break b}}}while(0);sa=qa+200|0;if((c[sa>>2]|0)==0&(c[sa+4>>2]|0)==(-2147483648|0)){if((c[ra+8>>2]|0)>>>0<2>>>0){T=62;break}}sa=pa+1|0;ua=c[G>>2]|0;if(sa>>>0<ua>>>0){pa=sa}else{wa=sa;xa=ua;break}}if((T|0)==62){T=0;wa=pa;xa=c[G>>2]|0}if((wa|0)==(xa|0)){oa=wa;T=64}else{ya=wa}}if((T|0)==64){T=0;if((c[r>>2]&1|0)==0){T=65;break a}else{ya=oa}}za=c[I>>2]|0;ua=0;if(!((ma|0)<(ua|0)|(ma|0)==(ua|0)&na>>>0<za>>>0)){T=67;break a}Aa=hT(a,q)|0;}while((Aa|0)==-11);if((Aa|0)<0){Ba=Aa;T=130;break}if((c[ca>>2]&64|0)!=0){ua=c[ea>>2]|0;if((ua|0)!=0){sa=ua;do{c[o>>2]=sa;c[ea>>2]=c[sa+80>>2];BZ(sa|0);$Db(ka);sa=c[ea>>2]|0;}while((sa|0)!=0)}c[da>>2]=0}sa=cEb(88)|0;ua=sa;if((sa|0)==0){Ca=-12;break}if((c[ea>>2]|0)==0){c[ea>>2]=ua}else{c[(c[da>>2]|0)+80>>2]=ua}c[da>>2]=ua;ua=sa;UGb(sa|0,L|0,80)|0;Da=CZ(ua)|0;if((Da|0)<0){Ca=Da;break}ta=c[(c[ha>>2]|0)+(c[sa+32>>2]<<2)>>2]|0;if((c[ta+72>>2]&1024|0)==0){va=c[sa+28>>2]|0;Ea=YGb(va,(va|0)<0|0?-1:0,na,ma)|0;Fa=F;Ga=Ea}else{Fa=ma;Ga=na}Ea=sa+16|0;va=c[Ea>>2]|0;Ha=c[Ea+4>>2]|0;Ia=ta+232|0;do{if(!((va|0)==0&(Ha|0)==(-2147483648|0))){Ja=c[Ia>>2]|0;if((Ja|0)<=1){break}Ka=ta+184|0;La=c[Ka>>2]|0;Ma=La+88|0;Na=c[Ma>>2]|0;Oa=c[Ma+4>>2]|0;do{if((Na|0)==0&(Oa|0)==(-2147483648|0)|((Oa|0)<(Ha|0)|(Oa|0)==(Ha|0)&Na>>>0<va>>>0)){if((Na|0)==0&(Oa|0)==(-2147483648|0)){Pa=La;break}Ma=c[La+96>>2]|0;Qa=c[La+80>>2]|0;if((Ma|0)<=(Qa|0)){Pa=La;break}Ra=c[Ea>>2]|0;Sa=c[Ea+4>>2]|0;Ta=ZGb(Ra,Sa,Na,Oa)|0;Ua=eHb(Ta,F,1e3,0)|0;Ta=F;Va=La+72|0;Wa=ZGb(Na,Oa,c[Va>>2]|0,c[Va+4>>2]|0)|0;Va=Ma-Qa|0;Qa=eHb(Wa,F,Va,(Va|0)<0|0?-1:0)|0;Va=F;if(!((Ta|0)>(Va|0)|(Ta|0)==(Va|0)&Ua>>>0>Qa>>>0)){Pa=La;break}Qa=c[Ia>>2]|0;yDb(ja,24,2069648,(S=i,i=i+56|0,c[S>>2]=c[ta>>2],c[S+8>>2]=Ma,c[S+16>>2]=Na,c[S+24>>2]=Oa,c[S+32>>2]=Qa,c[S+40>>2]=Ra,c[S+48>>2]=Sa,S)|0);i=S;Sa=c[Ka>>2]|0;Ra=Sa+88|0;c[Ra>>2]=0;c[Ra+4>>2]=-2147483648;Ra=Sa+72|0;c[Ra>>2]=0;c[Ra+4>>2]=-2147483648;Pa=Sa}else{Sa=c[La+96>>2]|0;yDb(ja,48,2074328,(S=i,i=i+56|0,c[S>>2]=c[ta>>2],c[S+8>>2]=Sa,c[S+16>>2]=Na,c[S+24>>2]=Oa,c[S+32>>2]=Ja,c[S+40>>2]=va,c[S+48>>2]=Ha,S)|0);i=S;Sa=c[Ka>>2]|0;Ra=Sa+88|0;c[Ra>>2]=0;c[Ra+4>>2]=-2147483648;Ra=Sa+72|0;c[Ra>>2]=0;c[Ra+4>>2]=-2147483648;Pa=Sa}}while(0);Ka=Pa+72|0;if((c[Ka>>2]|0)==0&(c[Ka+4>>2]|0)==(-2147483648|0)){Ja=c[Ea+4>>2]|0;c[Ka>>2]=c[Ea>>2];c[Ka+4>>2]=Ja;c[Pa+80>>2]=c[Ia>>2]}Ja=c[Ea+4>>2]|0;Ka=Pa+88|0;c[Ka>>2]=c[Ea>>2];c[Ka+4>>2]=Ja;c[Pa+96>>2]=c[Ia>>2]}}while(0);do{if((c[Ia>>2]|0)>1){Ha=ta+40|0;if((c[ta+44>>2]|0)>0){va=(c[ta+184>>2]|0)+40|0;Ja=c[va>>2]|0;Ka=c[va+4>>2]|0;c[V>>2]=1;c[P>>2]=1e6;va=KDb(Ja,Ka,Ha,s)|0;Xa=F;Ya=va}else{Xa=0;Ya=0}va=ta+92|0;Ka=c[va>>2]|0;do{if((Ka|0)>0){Ja=c[Ia>>2]|0;Oa=ta+96|0;c[U>>2]=c[Oa>>2];c[K>>2]=Ka;c[N>>2]=1;c[M>>2]=1e6;Na=KDb(Ja,(Ja|0)<0|0?-1:0,t,u)|0;Ja=F;if((Xa|0)>(Ja|0)|(Xa|0)==(Ja|0)&Ya>>>0>Na>>>0){Za=Xa;_a=Ya;break}Na=c[Ia>>2]|0;Ja=c[va>>2]|0;c[R>>2]=c[Oa>>2];c[O>>2]=Ja;c[X>>2]=1;c[_>>2]=1e6;Ja=KDb(Na,(Na|0)<0|0?-1:0,v,w)|0;Za=F;_a=Ja}else{Za=Xa;_a=Ya}}while(0);do{if((_a|0)==0&(Za|0)==0){if((c[Ia>>2]|0)<=30){$a=0;ab=0;break}va=ta+184|0;Ka=c[va>>2]|0;Ja=Ka+72|0;Na=c[Ja>>2]|0;Oa=c[Ja+4>>2]|0;if((Na|0)==0&(Oa|0)==(-2147483648|0)){$a=0;ab=0;break}Ja=Ka+88|0;Ka=c[Ja>>2]|0;La=c[Ja+4>>2]|0;if((Ka|0)==0&(La|0)==(-2147483648|0)){$a=0;ab=0;break}Ja=ZGb(Ka,La,Na,Oa)|0;c[W>>2]=1;c[Z>>2]=1e6;Oa=KDb(Ja,F,Ha,x)|0;Ja=F;Na=0;if((Ja|0)<(Na|0)|(Ja|0)==(Na|0)&Oa>>>0<0>>>0){$a=0;ab=0;break}Oa=c[va>>2]|0;va=Oa+88|0;Na=Oa+72|0;Oa=ZGb(c[va>>2]|0,c[va+4>>2]|0,c[Na>>2]|0,c[Na+4>>2]|0)|0;c[Y>>2]=1;c[aa>>2]=1e6;Na=KDb(Oa,F,Ha,y)|0;$a=F;ab=Na}else{$a=Za;ab=_a}}while(0);bb=c[$>>2]|0;Ha=(bb|0)<0|0?-1:0;if(!(($a|0)<(Ha|0)|($a|0)==(Ha|0)&ab>>>0<bb>>>0)){T=112;break a}Ha=c[sa+48>>2]|0;if((Ha|0)==0){break}Na=c[ta+184>>2]|0;Oa=Na+40|0;va=YGb(c[Oa>>2]|0,c[Oa+4>>2]|0,Ha,(Ha|0)<0|0?-1:0)|0;c[Oa>>2]=va;c[Oa+4>>2]=F;Oa=c[ta+240>>2]|0;do{if((Oa|0)==0){cb=0;db=2}else{if((c[ta+236>>2]|0)==0){cb=0;db=2;break}if((c[(c[ta+8>>2]|0)+112>>2]|0)!=2){cb=0;db=2;break}va=(c[Oa+36>>2]|0)+1|0;cb=(va|0)<0|0?-1:0;db=va}}while(0);Oa=Na+48|0;va=YGb(c[Oa>>2]|0,c[Oa+4>>2]|0,db,cb)|0;c[Oa>>2]=va;c[Oa+4>>2]=F}}while(0);DT(0,ta,c[Ea>>2]|0,c[Ea+4>>2]|0)|0;Oa=c[ta+240>>2]|0;do{if((Oa|0)!=0){va=c[(c[Oa+4>>2]|0)+36>>2]|0;if((va|0)==0){break}Ha=ta+8|0;Ja=c[Ha>>2]|0;if((c[Ja+96>>2]|0)!=0){break}La=sa+24|0;Ka=ze[va&511](Ja,c[La>>2]|0,c[sa+28>>2]|0)|0;if(!((Ka-1|0)>>>0<268435439>>>0)){break}eb=c[Ha>>2]|0;Ja=WDb(Ka+16|0)|0;c[eb+96>>2]=Ja;if((Ja|0)==0){T=124;break a}TGb(Ja+Ka|0,0,16)|0;c[eb+100>>2]=Ka;Ka=c[Ha>>2]|0;UGb(c[Ka+96>>2]|0,c[La>>2]|0,c[Ka+100>>2]|0)|0}}while(0);if(ia&(ya|0)<(H|0)){fb=b+(ya<<2)|0}else{fb=0}GT(a,ta,ua,fb)|0;c[Ia>>2]=(c[Ia>>2]|0)+1;la=la+1|0;ma=Fa;na=Ga}do{if((T|0)==47){yDb(ja,48,2103464,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;Ba=-1414092869;T=130}else if((T|0)==65){yDb(ja,48,2094736,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;gb=la;T=131}else if((T|0)==67){yDb(ja,48,2089368,(S=i,i=i+8|0,c[S>>2]=za,S)|0);i=S;Ga=c[G>>2]|0;if((Ga|0)==0){Ba=la;T=130;break}na=a+4|0;Fa=0;ma=Ga;while(1){Ga=c[(c[ha>>2]|0)+(Fa<<2)>>2]|0;do{if((c[Ga+412>>2]|0)==0){if((c[(c[Ga+184>>2]|0)+16>>2]|0)>=2){hb=ma;break}if((c[(c[Ga+8>>2]|0)+8>>2]|0)!=0){hb=ma;break}if((QGb(c[c[na>>2]>>2]|0,2084560)|0)==0){hb=ma;break}yDb(ja,24,2079208,(S=i,i=i+8|0,c[S>>2]=Fa,S)|0);i=S;hb=c[G>>2]|0}else{hb=ma}}while(0);Ga=Fa+1|0;if(Ga>>>0<hb>>>0){Fa=Ga;ma=hb}else{Ba=la;T=130;break}}}else if((T|0)==112){yDb(ja,40,2065120,(S=i,i=i+24|0,c[S>>2]=bb,c[S+8>>2]=ab,c[S+16>>2]=$a,S)|0);i=S;Ba=Da;T=130}else if((T|0)==124){c[eb+100>>2]=0;ib=-12;i=d;return ib|0}}while(0);do{if((T|0)==130){if(J){gb=Ba;T=131;break}TGb(z|0,0,80)|0;vZ(z);if((c[G>>2]|0)==0){jb=Ba;T=142;break}else{kb=0}while(1){eb=c[(c[ha>>2]|0)+(kb<<2)>>2]|0;c:do{if((c[(c[eb+184>>2]|0)+56>>2]|0)==1){Da=ia&(kb|0)<(H|0);$a=b+(kb<<2)|0;while(1){lb=GT(a,eb,z,Da?$a:0)|0;if((lb|0)<=0){break}if((FT(eb,0)|0)!=0){break c}}if((lb|0)>=0){break}yDb(ja,32,2061048,(S=i,i=i+8|0,c[S>>2]=c[eb>>2],S)|0);i=S}}while(0);eb=kb+1|0;$a=c[G>>2]|0;if(eb>>>0<$a>>>0){kb=eb}else{mb=Ba;nb=$a;T=132;break}}}}while(0);if((T|0)==131){mb=gb;nb=c[G>>2]|0;T=132}do{if((T|0)==132){if((nb|0)==0){jb=mb;T=142;break}else{ob=0}while(1){E0a(c[(c[(c[ha>>2]|0)+(ob<<2)>>2]|0)+8>>2]|0)|0;gb=ob+1|0;if(gb>>>0<(c[G>>2]|0)>>>0){ob=gb}else{jb=mb;T=142;break}}}}while(0);do{if((T|0)==142){ET(a);if((c[G>>2]|0)!=0){mb=n|0;ob=n+4|0;nb=n+8|0;gb=n+12|0;Ba=n+16|0;kb=n+20|0;lb=0;do{z=c[(c[ha>>2]|0)+(lb<<2)>>2]|0;b=z+8|0;H=c[b>>2]|0;ia=c[H+8>>2]|0;d:do{if((ia|0)==0){do{if((c[H+48>>2]|0)==14){if((c[H+52>>2]|0)!=0){break}if((c[H+792>>2]|0)!=0){break}J=vUa(c[H+140>>2]|0)|0;$a=c0a(1149856,J)|0;eb=c[b>>2]|0;if(($a|0)!=(c[eb+140>>2]|0)){break}c[eb+52>>2]=J}}while(0);J=c[z+184>>2]|0;eb=J+48|0;$a=c[eb>>2]|0;Da=c[eb+4>>2]|0;do{if(!(($a|0)==0&(Da|0)==0)){eb=z+92|0;if((c[eb>>2]|0)!=0){break}ra=J+40|0;qa=c[ra>>2]|0;ab=c[ra+4>>2]|0;if((qa|0)==0&(ab|0)==0){break}ra=c[z+40>>2]|0;bb=ra;hb=(ra|0)<0|0?-1:0;ra=eHb(-1,2147483647,bb,hb)|0;za=eHb(ra,F,2,0)|0;ra=F;if(!((ab|0)<(ra|0)|(ab|0)==(ra|0)&qa>>>0<za>>>0)){break d}za=c[z+44>>2]|0;ra=za;ma=(za|0)<0|0?-1:0;za=eHb(-1,2147483647,ra,ma)|0;Fa=F;na=0;if((Da|0)>=(Fa|0)&((Da|0)>(Fa|0)|$a>>>0>=za>>>0)|((ab|0)<(na|0)|(ab|0)==(na|0)&qa>>>0<0>>>0)){break d}na=z+96|0;za=gHb(ra,ma,$a,Da)|0;ma=F;ra=gHb(qa<<1|0>>>31,ab<<1|qa>>>31,bb,hb)|0;iFb(eb,na,za,ma,ra,F,6e4,0)|0;pb=+(c[eb>>2]|0)/+(c[na>>2]|0);ra=0;ma=0;qb=.01;while(1){if((ra|0)<720){rb=(ra*1001|0)+1001|0}else{c[mb>>2]=24;c[ob>>2]=30;c[nb>>2]=60;c[gb>>2]=12;c[Ba>>2]=15;c[kb>>2]=48;rb=(c[n+(ra-720<<2)>>2]|0)*12e3|0}sb=+Q(+(pb/(+(rb|0)/12012.0)+-1.0));za=sb<qb;tb=za?rb:ma;hb=ra+1|0;if((hb|0)<726){ra=hb;ma=tb;qb=za?sb:qb}else{break}}if((tb|0)==0){break}iFb(eb,na,tb,(tb|0)<0|0?-1:0,12012,0,2147483647,0)|0}}while(0);Da=z+412|0;if((c[Da>>2]|0)!=0){break}$a=c[b>>2]|0;J=c[$a+108>>2]|0;ma=c[z+40>>2]|0;ra=gHb(ma,(ma|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;za=F;hb=$a+104|0;bb=$a+112|0;$a=ba(c[bb>>2]|0,c[hb>>2]|0)|0;qa=c[z+44>>2]|0;ab=gHb($a,($a|0)<0|0?-1:0,qa,(qa|0)<0|0?-1:0)|0;$a=F;if((za|0)>($a|0)|(za|0)==($a|0)&ra>>>0>ab>>>0){c[Da>>2]=qa;c[z+416>>2]=ma;break}else{c[Da>>2]=J;c[z+416>>2]=ba(c[bb>>2]|0,c[hb>>2]|0)|0;break}}else if((ia|0)==1){if((c[H+792>>2]|0)==0){hb=u0a(c[H+48>>2]|0)|0;bb=c[b>>2]|0;c[bb+792>>2]=hb;ub=bb}else{ub=H}switch(c[ub+464>>2]|0){case 1:{c[z+72>>2]=512;break d;break};case 2:{c[z+72>>2]=256;break d;break};case 3:{c[z+72>>2]=128;break d;break};case 5:{c[z+72>>2]=8;break d;break};case 8:{c[z+72>>2]=32;break d;break};default:{break d}}}}while(0);lb=lb+1|0;}while(lb>>>0<(c[G>>2]|0)>>>0)}if((c[I>>2]|0)!=0){lb=a+4|0;kb=c[lb>>2]|0;if((c[kb+8>>2]&1|0)==0){Ba=Wy(c[C>>2]|0)|0;gb=F;nb=0;ob=(gb|0)<(nb|0)|(gb|0)==(nb|0)&Ba>>>0<0>>>0;vb=ob?0:gb;wb=ob?0:Ba;xb=c[lb>>2]|0}else{vb=0;wb=0;xb=kb}kb=c[xb>>2]|0;if((QGb(kb,2315832)|0)==0){if((wb|0)==0&(vb|0)==0){T=227}else{T=181}}else{if((QGb(kb,2314400)|0)!=0|(wb|0)==0&(vb|0)==0){T=227}else{T=181}}do{if((T|0)==181){if((c[(c[C>>2]|0)+88>>2]|0)==0){T=227;break}kb=a+1264|0;lb=a+1268|0;Ba=l;ob=c[kb>>2]|0;if((ob|0)!=0){gb=ob;do{c[l>>2]=gb;c[kb>>2]=c[gb+80>>2];BZ(gb|0);$Db(Ba);gb=c[kb>>2]|0;}while((gb|0)!=0)}c[lb>>2]=0;gb=h;kb=c[ea>>2]|0;if((kb|0)!=0){Ba=kb;do{c[h>>2]=Ba;c[ea>>2]=c[Ba+80>>2];BZ(Ba|0);$Db(gb);Ba=c[ea>>2]|0;}while((Ba|0)!=0)}c[da>>2]=0;Ba=a+1256|0;gb=a+1260|0;lb=g;kb=c[Ba>>2]|0;if((kb|0)!=0){ob=kb;do{c[g>>2]=ob;c[Ba>>2]=c[ob+80>>2];BZ(ob|0);$Db(lb);ob=c[Ba>>2]|0;}while((ob|0)!=0)}c[gb>>2]=0;c[a+1272>>2]=25e5;if((c[G>>2]|0)!=0){ob=0;do{Ba=c[(c[ha>>2]|0)+(ob<<2)>>2]|0;lb=Ba+48|0;do{if((c[lb>>2]|0)==0&(c[lb+4>>2]|0)==(-2147483648|0)){kb=Ba+200|0;if(!((c[kb>>2]|0)==0&(c[kb+4>>2]|0)==(-2147483648|0))){break}kb=c[Ba+8>>2]|0;if((c[kb+8>>2]|0)==-1){break}yDb(kb,24,2305192,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}}while(0);lb=Ba+240|0;kb=c[lb>>2]|0;if((kb|0)!=0){VRa(kb);c[lb>>2]=0}ob=ob+1|0;}while(ob>>>0<(c[G>>2]|0)>>>0)}ob=c[C>>2]|0;if((ob|0)==0){yb=0;zb=0}else{gb=Wy(ob)|0;yb=F;zb=gb}gb=m+28|0;ob=m+32|0;lb=m+8|0;kb=0;do{nb=_Gb(25e4,0,kb|0)|0;mb=F;z=ZGb(zb,yb,nb,mb)|0;H=F;b=0;ia=(H|0)<(b|0)|(H|0)==(b|0)&z>>>0<0>>>0;Ty(c[C>>2]|0,ia?0:z,ia?0:H,0)|0;H=kb-1|0;ia=(H|0)>0;z=_Gb(25e4,0,H|0)|0;H=ia?z:25e4;z=ia?F:0;ia=0;e:do{if((z|0)>(ia|0)|(z|0)==(ia|0)&H>>>0>0>>>0){b=0;bb=-2147483648;hb=0;while(1){while(1){J=cT(a,m)|0;if((J|0)==0){break}else if((J|0)!=(-11|0)){Ab=bb;Bb=hb;break e}}J=(c[gb>>2]|0)+b|0;Da=c[(c[ha>>2]|0)+(c[ob>>2]<<2)>>2]|0;ma=c[lb>>2]|0;qa=c[lb+4>>2]|0;do{if((ma|0)==0&(qa|0)==(-2147483648|0)){Cb=bb;Db=hb}else{ab=Da+48|0;ra=c[ab>>2]|0;$a=c[ab+4>>2]|0;if((ra|0)==0&($a|0)==(-2147483648|0)){ab=Da+200|0;za=c[ab>>2]|0;Fa=c[ab+4>>2]|0;if((za|0)==0&(Fa|0)==(-2147483648|0)){Cb=bb;Db=hb;break}else{Eb=Fa;Fb=za}}else{Eb=$a;Fb=ra}ra=ZGb(ma,qa,Fb,Eb)|0;$a=F;za=0;if(!(($a|0)>(za|0)|($a|0)==(za|0)&ra>>>0>0>>>0)){Cb=qa;Db=ma;break}za=Da+56|0;Fa=c[za>>2]|0;ab=c[za+4>>2]|0;Ia=(c[Da+184>>2]|0)+64|0;do{if((Fa|0)==0&(ab|0)==(-2147483648|0)){T=210}else{ua=c[Ia>>2]|0;ta=c[Ia+4>>2]|0;Ga=0;if((ta|0)<(Ga|0)|(ta|0)==(Ga|0)&ua>>>0<1>>>0){T=210;break}if(!((ab|0)<($a|0)|(ab|0)==($a|0)&Fa>>>0<ra>>>0)){break}Ga=ZGb(ra,$a,ua,ta)|0;ta=F;ua=-1;Na=(ta|0)>(ua|0)|(ta|0)==(ua|0)&Ga>>>0>-1>>>0;ua=ZGb(0,0,Ga,ta)|0;fb=Na?ta:F;ta=c[Da+44>>2]|0;ya=gHb(ta,(ta|0)<0|0?-1:0,60,0)|0;ta=c[Da+40>>2]|0;cb=eHb(ya,F,ta,(ta|0)<0|0?-1:0)|0;ta=F;if((fb|0)<(ta|0)|(fb|0)==(ta|0)&(Na?Ga:ua)>>>0<cb>>>0){T=210}}}while(0);if((T|0)==210){T=0;c[za>>2]=ra;c[za+4>>2]=$a}c[Ia>>2]=ra;c[Ia+4>>2]=$a;Cb=qa;Db=ma}}while(0);BZ(m);ma=(J|0)<0|0?-1:0;if((ma|0)<(z|0)|(ma|0)==(z|0)&J>>>0<H>>>0){b=J;bb=Cb;hb=Db}else{Ab=Cb;Bb=Db;break}}}else{Ab=-2147483648;Bb=0}}while(0);if(!((Bb|0)==0&(Ab|0)==(-2147483648|0)&((yb|0)>(mb|0)|(yb|0)==(mb|0)&zb>>>0>nb>>>0))){break}kb=kb+1|0;}while((kb|0)<5);jU(a);if((c[G>>2]|0)!=0){kb=a+1056|0;lb=a+1064|0;ob=k|0;gb=k+4|0;H=j|0;z=j+4|0;ia=0;do{Ba=c[(c[ha>>2]|0)+(ia<<2)>>2]|0;hb=Ba+48|0;do{if((c[hb>>2]|0)==0&(c[hb+4>>2]|0)==(-2147483648|0)){bb=c[kb>>2]|0;b=c[kb+4>>2]|0;if(!((bb|0)==0&(b|0)==(-2147483648|0))){c[H>>2]=1;c[z>>2]=1e6;na=KDb(bb,b,j,Ba+40|0)|0;c[hb>>2]=na;c[hb+4>>2]=F}na=c[lb>>2]|0;b=c[lb+4>>2]|0;if((na|0)==0&(b|0)==(-2147483648|0)){break}c[ob>>2]=1;c[gb>>2]=1e6;bb=KDb(na,b,k,Ba+40|0)|0;b=Ba+56|0;c[b>>2]=bb;c[b+4>>2]=F}}while(0);ia=ia+1|0;}while(ia>>>0<(c[G>>2]|0)>>>0)}Ty(c[C>>2]|0,D,E,0)|0;ia=c[G>>2]|0;if((ia|0)!=0){gb=c[ha>>2]|0;ob=0;do{lb=c[gb+(ob<<2)>>2]|0;z=lb+200|0;H=c[z+4>>2]|0;kb=lb+208|0;c[kb>>2]=c[z>>2];c[kb+4>>2]=H;H=lb+216|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+640|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+264|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+272|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+280|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+288|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+296|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+304|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+312|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+320|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+328|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+336|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+344|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+352|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+360|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+368|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+376|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+384|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+392|0;c[H>>2]=0;c[H+4>>2]=-2147483648;ob=ob+1|0;}while(ob>>>0<ia>>>0)}c[a+1212>>2]=0}}while(0);f:do{if((T|0)==227){ia=c[G>>2]|0;ob=0;while(1){if(!(ob>>>0<ia>>>0)){T=230;break}gb=(c[(c[ha>>2]|0)+(ob<<2)>>2]|0)+56|0;if((c[gb>>2]|0)==0&(c[gb+4>>2]|0)==(-2147483648|0)){ob=ob+1|0}else{break}}do{if((T|0)==230){ob=a+1064|0;if(!((c[ob>>2]|0)==0&(c[ob+4>>2]|0)==(-2147483648|0))){break}ob=a+1072|0;g:do{if((c[ob>>2]|0)<1){h:do{if((ia|0)!=0){gb=c[ha>>2]|0;H=0;lb=0;while(1){kb=c[(c[(c[gb+(H<<2)>>2]|0)+8>>2]|0)+72>>2]|0;if((kb|0)>0){if((2147483647-kb|0)<(lb|0)){break h}Gb=kb+lb|0}else{Gb=lb}kb=H+1|0;if(kb>>>0<ia>>>0){H=kb;lb=Gb}else{break}}c[ob>>2]=Gb;if((Gb|0)==0){break g}else{T=249;break g}}}while(0);c[ob>>2]=0}else{T=249}}while(0);do{if((T|0)==249){lb=c[C>>2]|0;if((lb|0)==0){break}H=Wy(lb)|0;lb=F;gb=0;if(!((lb|0)>(gb|0)|(lb|0)==(gb|0)&H>>>0>0>>>0)){break}gb=c[G>>2]|0;if((gb|0)==0){break}J=c[ha>>2]|0;kb=c[ob>>2]|0;z=kb;Ba=(kb|0)<0|0?-1:0;kb=eHb(-1,2147483647,z,Ba)|0;hb=F;nb=H<<3|0>>>29;mb=lb<<3|H>>>29;H=0;lb=0;while(1){b=c[J+(H<<2)>>2]|0;bb=c[b+40>>2]|0;na=bb;eb=(bb|0)<0|0?-1:0;do{if((eb|0)>(hb|0)|(eb|0)==(hb|0)&na>>>0>kb>>>0){Hb=lb}else{bb=b+56|0;if(!((c[bb>>2]|0)==0&(c[bb+4>>2]|0)==(-2147483648|0))){Hb=lb;break}ma=c[b+44>>2]|0;qa=gHb(na,eb,z,Ba)|0;Da=IDb(nb,mb,ma,(ma|0)<0|0?-1:0,qa,F)|0;c[bb>>2]=Da;c[bb+4>>2]=F;Hb=1}}while(0);eb=H+1|0;if(eb>>>0<gb>>>0){H=eb;lb=Hb}else{break}}if((Hb|0)==0){break}yDb(ja,24,2310288,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}}while(0);c[a+1212>>2]=2;break f}}while(0);jU(a);if((c[G>>2]|0)!=0){ia=a+1056|0;ob=a+1064|0;lb=f|0;H=f+4|0;gb=e|0;mb=e+4|0;nb=0;do{Ba=c[(c[ha>>2]|0)+(nb<<2)>>2]|0;z=Ba+48|0;do{if((c[z>>2]|0)==0&(c[z+4>>2]|0)==(-2147483648|0)){kb=c[ia>>2]|0;hb=c[ia+4>>2]|0;if(!((kb|0)==0&(hb|0)==(-2147483648|0))){c[gb>>2]=1;c[mb>>2]=1e6;J=KDb(kb,hb,e,Ba+40|0)|0;c[z>>2]=J;c[z+4>>2]=F}J=c[ob>>2]|0;hb=c[ob+4>>2]|0;if((J|0)==0&(hb|0)==(-2147483648|0)){break}c[lb>>2]=1;c[H>>2]=1e6;kb=KDb(J,hb,f,Ba+40|0)|0;hb=Ba+56|0;c[hb>>2]=kb;c[hb+4>>2]=F}}while(0);nb=nb+1|0;}while(nb>>>0<(c[G>>2]|0)>>>0)}c[a+1212>>2]=1}}while(0);jU(a)}nb=c[G>>2]|0;if((jb|0)>-1){Ib=(nb|0)==0?jb:-1}else{Ib=jb}if((nb|0)==0){Jb=Ib}else{nb=B|0;H=Ib;lb=0;while(1){ob=c[(c[ha>>2]|0)+(lb<<2)>>2]|0;if((FT(ob,A)|0)==0){J0a(nb,256,c[ob+8>>2]|0,0);ob=c[A>>2]|0;yDb(ja,24,2057704,(S=i,i=i+24|0,c[S>>2]=lb,c[S+8>>2]=nb,c[S+16>>2]=ob,S)|0);i=S;Kb=H}else{Kb=0}ob=lb+1|0;if(ob>>>0<(c[G>>2]|0)>>>0){H=Kb;lb=ob}else{Jb=Kb;break}}}lb=a+1064|0;H=a+1056|0;nb=c[H>>2]|0;ob=c[H+4>>2]|0;H=(nb|0)==0&(ob|0)==(-2147483648|0);mb=YGb(H?0:nb,H?0:ob,c[lb>>2]|0,c[lb+4>>2]|0)|0;lb=F;ob=a+1132|0;H=c[ob>>2]|0;if((H|0)==0){Ca=Jb;break}nb=a+1136|0;gb=(mb|0)==0&(lb|0)==0;ia=p|0;Ba=p+4|0;z=0;hb=H;while(1){H=c[(c[nb>>2]|0)+(z<<2)>>2]|0;kb=H+24|0;if((c[kb>>2]|0)==0&(c[kb+4>>2]|0)==(-2147483648|0)){if(gb){Lb=2147483647;Mb=-1;Nb=hb}else{c[ia>>2]=1;c[Ba>>2]=1e6;J=KDb(mb,lb,p,H+4|0)|0;Lb=F;Mb=J;Nb=c[ob>>2]|0}if((Nb|0)==0){Ob=Lb;Pb=Mb;Qb=0}else{J=H+4|0;eb=H+16|0;na=Lb;b=Mb;bb=0;while(1){Da=c[(c[nb>>2]|0)+(bb<<2)>>2]|0;qa=Da+16|0;ma=KDb(c[qa>>2]|0,c[qa+4>>2]|0,Da+4|0,J)|0;Da=F;if((bb|0)==(z|0)){Rb=na;Sb=b}else{qa=c[eb+4>>2]|0;Fa=((Da|0)>(qa|0)|(Da|0)==(qa|0)&ma>>>0>(c[eb>>2]|0)>>>0)&((Da|0)<(na|0)|(Da|0)==(na|0)&ma>>>0<b>>>0);Rb=Fa?Da:na;Sb=Fa?ma:b}ma=bb+1|0;Fa=c[ob>>2]|0;if(ma>>>0<Fa>>>0){na=Rb;b=Sb;bb=ma}else{Ob=Rb;Pb=Sb;Qb=Fa;break}}}if((Pb|0)==(-1|0)&(Ob|0)==2147483647){bb=H+16|0;Tb=c[bb+4>>2]|0;Ub=c[bb>>2]|0}else{Tb=Ob;Ub=Pb}c[kb>>2]=Ub;c[kb+4>>2]=Tb;Vb=Qb}else{Vb=hb}bb=z+1|0;if(bb>>>0<Vb>>>0){z=bb;hb=Vb}else{Ca=Jb;break}}}}while(0);if((c[G>>2]|0)!=0){Jb=0;do{Vb=c[(c[ha>>2]|0)+(Jb<<2)>>2]|0;Qb=c[Vb+8>>2]|0;if((c[Qb+8>>2]|0)!=1){c[Qb+808>>2]=0}Qb=c[Vb+184>>2]|0;if((Qb|0)==0){Wb=Vb}else{$Db(Qb+32|0);Wb=c[(c[ha>>2]|0)+(Jb<<2)>>2]|0}$Db(Wb+184|0);Jb=Jb+1|0;}while(Jb>>>0<(c[G>>2]|0)>>>0)}G=c[C>>2]|0;if((G|0)==0){ib=Ca;i=d;return ib|0}Jb=Ty(G,0,0,1)|0;G=F;Wb=c[C>>2]|0;C=Wb+112|0;ha=c[C>>2]|0;Qb=c[C+4>>2]|0;C=c[Wb+120>>2]|0;yDb(ja,48,2047096,(S=i,i=i+48|0,c[S>>2]=Jb,c[S+8>>2]=G,c[S+16>>2]=ha,c[S+24>>2]=Qb,c[S+32>>2]=C,c[S+40>>2]=la,S)|0);i=S;ib=Ca;i=d;return ib|0}function BT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>2147483630>>>0){c[a+100>>2]=0;d=-22;return d|0}e=WDb(b+16|0)|0;c[a+96>>2]=e;if((e|0)==0){c[a+100>>2]=0;d=-12;return d|0}else{TGb(e+b|0,0,16)|0;c[a+100>>2]=b;d=0;return d|0}return 0}function CT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;if(d>>>0>2147483630>>>0){c[a+100>>2]=0;f=-22;i=e;return f|0}g=WDb(d+16|0)|0;h=a+96|0;c[h>>2]=g;if((g|0)==0){c[a+100>>2]=0;f=-12;i=e;return f|0}TGb(g+d|0,0,16)|0;j=a+100|0;c[j>>2]=d;k=mz(b,g,d)|0;if((k|0)==(d|0)){f=d;i=e;return f|0}$Db(h);c[j>>2]=0;yDb(a,16,2153344,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;f=(k|0)<0?k:-1094995529;i=e;return f|0}function DT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0.0,H=0,I=0.0,J=0,K=0,L=0,M=0,N=0.0,O=0;a=i;i=i+24|0;f=a|0;g=b+184|0;j=c[g>>2]|0;k=j|0;l=c[k>>2]|0;m=c[k+4>>2]|0;k=(d|0)!=0|(e|0)!=(-2147483648|0);n=ZGb(d,e,l,m)|0;o=F;p=2147483647;do{if(k&((l|0)!=0|(m|0)!=(-2147483648|0))&((m|0)<(e|0)|(m|0)==(e|0)&l>>>0<d>>>0)&(o>>>0<p>>>0|o>>>0==p>>>0&n>>>0<-1>>>0)){q=2147352575;r=(e|0)>(q|0)|(e|0)==(q|0)&d>>>0>-1>>>0;q=YGb(d,e,1,-2147418112)|0;s=(+((r?q:d)>>>0)+ +((r?F:e)|0)*4294967296.0)*(+(c[b+40>>2]|0)/+(c[b+44>>2]|0));q=c[j+32>>2]|0;do{if((q|0)==0){t=cEb(23232)|0;c[(c[g>>2]|0)+32>>2]=t;t=c[g>>2]|0;u=c[t+32>>2]|0;if((u|0)==0){v=-12}else{w=u;x=t;break}i=a;return v|0}else{w=q;x=j}}while(0);q=f|0;t=f+4|0;u=f+8|0;y=f+12|0;z=f+16|0;A=f+20|0;B=0;C=x;D=w;while(1){if(+h[D+5808+(B<<3)>>3]<1.0e10){if((B|0)<720){E=(B*1001|0)+1001|0}else{c[q>>2]=24;c[t>>2]=30;c[u>>2]=60;c[y>>2]=12;c[z>>2]=15;c[A>>2]=48;E=(c[f+(B-720<<2)>>2]|0)*12e3|0}G=s*+(E|0)/12012.0;H=ce(+(G+0.0))|0;I=G-(+(H>>>0)+ +(F|0)*4294967296.0)+0.0;H=c[(c[g>>2]|0)+32>>2]|0;J=H+(B<<3)|0;h[J>>3]=+h[J>>3]+I;J=H+5808+(B<<3)|0;h[J>>3]=I*I+ +h[J>>3];J=ce(+(G+.5))|0;I=G-(+(J>>>0)+ +(F|0)*4294967296.0)+.5;J=c[g>>2]|0;H=c[J+32>>2]|0;K=H+11616+(B<<3)|0;h[K>>3]=+h[K>>3]+I;K=H+17424+(B<<3)|0;h[K>>3]=I*I+ +h[K>>3];L=J;M=H}else{L=C;M=D}H=B+1|0;if((H|0)<726){B=H;C=L;D=M}else{break}}D=L+16|0;C=(c[D>>2]|0)+1|0;c[D>>2]=C;D=L+24|0;B=YGb(c[D>>2]|0,c[D+4>>2]|0,n,o)|0;c[D>>2]=B;c[D+4>>2]=F;if(((C|0)%10|0|0)==0){s=+(C|0);D=0;do{B=M+5808+(D<<3)|0;I=+h[B>>3];do{if(I<1.0e10){G=+h[M+(D<<3)>>3]/s;N=+h[M+11616+(D<<3)>>3]/s;if(!(I/s-G*G>.04)){break}A=M+17424+(D<<3)|0;if(!(+h[A>>3]/s-N*N>.04)){break}h[B>>3]=2.0e10;h[A>>3]=2.0e10}}while(0);D=D+1|0;}while((D|0)<726)}if((C|0)<=3){O=L;break}D=2147352575;if(r^((m|0)>(D|0)|(m|0)==(D|0)&l>>>0>-1>>>0)){O=L;break}D=L+8|0;B=GDb(c[D>>2]|0,c[D+4>>2]|0,n,o)|0;c[D>>2]=B;c[D+4>>2]=F;O=L}else{O=j}}while(0);if(!k){v=0;i=a;return v|0}k=O|0;c[k>>2]=d;c[k+4>>2]=e;v=0;i=a;return v|0}function ET(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,G=0.0,H=0,I=0,J=0.0,K=0,L=0.0,M=0,N=0,O=0.0,P=0,Q=0.0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0.0,Z=0,_=0,$=0;b=i;i=i+24|0;d=b|0;e=a+24|0;f=c[e>>2]|0;if((f|0)==0){i=b;return}g=a+28|0;a=d|0;j=d+4|0;k=d+8|0;l=d+12|0;m=d+16|0;n=d+20|0;o=0;p=f;while(1){f=c[(c[g>>2]|0)+(o<<2)>>2]|0;q=f+8|0;r=c[q>>2]|0;if((c[r+8>>2]|0)==0){s=c[r+108>>2]|0;t=c[r+104>>2]|0;do{if((s|0)>=(t*101|0|0)|(s|0)<(t*5|0|0)){u=8}else{if((c[r+52>>2]|0)==1983148141){u=8;break}v=c[r+48>>2]|0;if((v|0)==2|(v|0)==28){u=8;break}w=f+184|0}}while(0);do{if((u|0)==8){u=0;r=f+184|0;t=c[r>>2]|0;if((c[t+16>>2]|0)<=15){w=r;break}s=t+8|0;t=c[s>>2]|0;v=c[s+4>>2]|0;s=c[f+44>>2]|0;x=s;y=(s|0)<0|0?-1:0;s=c[f+40>>2]|0;z=s;A=(s|0)<0|0?-1:0;s=gHb(z,A,500,0)|0;B=eHb(x,y,s,F)|0;s=F;C=0;D=(s|0)<(C|0)|(s|0)==(C|0)&B>>>0<1>>>0;C=D?0:s;if(!((v|0)>(C|0)|(v|0)==(C|0)&t>>>0>(D?1:B)>>>0)){w=r;break}B=f+412|0;if((c[B>>2]|0)!=0){w=r;break}D=gHb(z,A,t,v)|0;iFb(B,f+416|0,x,y,D,F,2147483647,0)|0;w=r}}while(0);r=c[w>>2]|0;a:do{if((c[r+16>>2]|0)>1){D=f+412|0;if((c[D>>2]|0)!=0){break}y=c[q>>2]|0;x=c[y+108>>2]|0;B=c[y+104>>2]|0;do{if(!((x|0)>=(B*101|0|0)|(x|0)<(B*5|0|0))){if((c[y+52>>2]|0)==1983148141){break}v=c[y+48>>2]|0;if(!((v|0)==2|(v|0)==28)){break a}}}while(0);y=f+40|0;B=f+44|0;E=.01;x=0;v=0;t=r;while(1){A=t+40|0;z=c[A>>2]|0;C=c[A+4>>2]|0;A=(z|0)==0&(C|0)==0;do{if(A){u=24}else{G=(+(z>>>0)+ +(C|0)*4294967296.0)*(+(c[y>>2]|0)/+(c[B>>2]|0));if((v|0)<720){H=(v*1001|0)+1001|0}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;H=(c[d+(v-720<<2)>>2]|0)*12e3|0}if(G<12012.0/+(H|0)){I=x;J=E;break}if(A){u=24}else{u=28}}}while(0);if((u|0)==24){u=0;if((v|0)<720){K=(v*1001|0)+1001|0}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;K=(c[d+(v-720<<2)>>2]|0)*12e3|0}if(12012.0/+(K|0)>1.0){I=x;J=E}else{u=28}}do{if((u|0)==28){u=0;A=t+24|0;C=c[t+16>>2]|0;G=+(C|0);L=+(c[y>>2]|0)/+(c[B>>2]|0)*(+((c[A>>2]|0)>>>0)+ +(c[A+4>>2]|0)*4294967296.0)/G;A=(v|0)<720;if(A){M=(v*1001|0)+1001|0}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;M=(c[d+(v-720<<2)>>2]|0)*12e3|0}if(L<9609.6/+(M|0)){I=x;J=E;break}z=(v*1001|0)+1001|0;s=d+(v-720<<2)|0;N=c[t+32>>2]|0;L=+h[N+(v<<3)>>3]/G;O=+h[N+5808+(v<<3)>>3]/G-L*L;do{if(O<E&E>1.0e-9){if(A){P=z;Q=O;break}c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;P=(c[s>>2]|0)*12e3|0;Q=O}else{P=x;Q=E}}while(0);if(O<.02){if(A){R=z}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;R=(c[s>>2]|0)*12e3|0}yDb(0,48,2146312,(S=i,i=i+16|0,h[S>>3]=+(R|0)/12.0/1001.0,h[S+8>>3]=O,S)|0);i=S;T=c[w>>2]|0;U=c[T+16>>2]|0;V=c[T+32>>2]|0}else{U=C;V=N}L=+(U|0);G=+h[V+11616+(v<<3)>>3]/L;W=+h[V+17424+(v<<3)>>3]/L-G*G;do{if(W<Q&Q>1.0e-9){if(A){X=z;Y=W;break}c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;X=(c[s>>2]|0)*12e3|0;Y=W}else{X=P;Y=Q}}while(0);if(!(W<.02)){I=X;J=Y;break}if(A){Z=z}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;Z=(c[s>>2]|0)*12e3|0}yDb(0,48,2146312,(S=i,i=i+16|0,h[S>>3]=+(Z|0)/12.0/1001.0,h[S+8>>3]=W,S)|0);i=S;I=X;J=Y}}while(0);N=v+1|0;if((N|0)>=726){break}E=J;x=I;v=N;t=c[w>>2]|0}if((I|0)==0){break}t=c[D>>2]|0;if((t|0)==0){_=f+416|0}else{v=f+416|0;if(+(I|0)/12012.0<+(t|0)/+(c[v>>2]|0)*1.01){_=v}else{break}}iFb(D,_,I,(I|0)<0|0?-1:0,12012,0,2147483647,0)|0}}while(0);$Db((c[w>>2]|0)+32|0);f=c[w>>2]|0;r=f|0;c[r>>2]=0;c[r+4>>2]=-2147483648;c[f+16>>2]=0;r=f+24|0;c[r>>2]=0;c[r+4>>2]=0;$=c[e>>2]|0}else{$=p}r=o+1|0;if(r>>>0<$>>>0){o=r;p=$}else{break}}i=b;return}function FT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[a+8>>2]|0;e=c[d+8>>2]|0;do{if((e|0)==1){do{if((c[d+424>>2]|0)==0){f=c[d+48>>2]|0;if(!((f|0)==86059|(f|0)==86016|(f|0)==86017)){break}if((b|0)==0){g=0;return g|0}c[b>>2]=2301928;g=0;return g|0}}while(0);f=(c[(c[a+184>>2]|0)+56>>2]|0)>-1;do{if(f){if(!((c[d+420>>2]|0)==-1)){break}if((b|0)==0){g=0;return g|0}c[b>>2]=2300352;g=0;return g|0}}while(0);if((c[d+412>>2]|0)==0){if((b|0)==0){g=0;return g|0}c[b>>2]=2299024;g=0;return g|0}if((c[d+416>>2]|0)==0){if((b|0)==0){g=0;return g|0}c[b>>2]=2297496;g=0;return g|0}if(!f){break}if((c[a+452>>2]|0)!=0){break}if((c[d+48>>2]|0)!=86020){break}if((b|0)==0){g=0;return g|0}c[b>>2]=2296264;g=0;return g|0}else if((e|0)==3){if((c[d+48>>2]|0)!=94214){break}if((c[d+120>>2]|0)!=0){break}if((b|0)==0){g=0;return g|0}c[b>>2]=2294936;g=0;return g|0}else if((e|0)==2){if((c[d+48>>2]|0)==0){g=1}else{break}return g|0}else if((e|0)==0){if((c[d+120>>2]|0)==0){if((b|0)==0){g=0;return g|0}c[b>>2]=2294936;g=0;return g|0}do{if((c[(c[a+184>>2]|0)+56>>2]|0)>-1){if(!((c[d+140>>2]|0)==-1)){break}if((b|0)==0){g=0;return g|0}c[b>>2]=2293824;g=0;return g|0}}while(0);if(!(((c[d+48>>2]|0)-69|0)>>>0<2>>>0)){break}if((c[a+80>>2]|0)!=0){break}if((c[d+224>>2]|0)!=0){break}if((c[a+232>>2]|0)!=0){break}if((b|0)==0){g=0;return g|0}c[b>>2]=2292160;g=0;return g|0}}while(0);if((c[d+48>>2]|0)!=0){g=1;return g|0}if((b|0)==0){g=0;return g|0}c[b>>2]=2291344;g=0;return g|0}function GT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=i;i=i+136|0;g=f|0;h=f+8|0;j=f+16|0;k=f+48|0;l=f+128|0;c[g>>2]=1;m=ICb()|0;c[h>>2]=m;UGb(k|0,d|0,80)|0;if((m|0)==0){n=-12;i=f;return n|0}m=b+8|0;d=(o0a(c[m>>2]|0)|0)==0;o=b+184|0;p=c[o>>2]|0;q=c[p+56>>2]|0;r=(q|0)==0;a:do{if(d){if(!r){s=19;break}c[l>>2]=0;t=c[m>>2]|0;u=c[t+48>>2]|0;v=c[t+12>>2]|0;do{if((v|0)==0){w=c[t+8>>2]|0;if((w|0)==3){x=c[a+1312>>2]|0;if((x|0)!=0){y=x;break}}else if((w|0)==1){x=c[a+1308>>2]|0;if((x|0)!=0){y=x;break}}else if((w|0)==0){w=c[a+1304>>2]|0;if((w|0)!=0){y=w;break}}w=q0a(u)|0;if((w|0)!=0){y=w;break}c[(c[o>>2]|0)+56>>2]=-1;z=-1;break a}else{y=v}}while(0);v=(e|0)!=0;u=v?e:l;CBb(u,2127680,2121680,0)|0;t=m0a(c[m>>2]|0,y,u)|0;if(!v){DBb(l)}v=(c[o>>2]|0)+56|0;if((t|0)<0){c[v>>2]=-1;z=t;break}else{c[v>>2]=1;A=t;s=18;break}}else{if(!r){s=19;break}c[p+56>>2]=1;A=0;s=18}}while(0);if((s|0)==18){B=A;s=20}else if((s|0)==19){if((q|0)<0){z=-1}else{B=0;s=20}}b:do{if((s|0)==20){q=b+184|0;A=k+24|0;p=k+28|0;r=b+452|0;o=b+232|0;l=B;c:while(1){C=l;y=c[p>>2]|0;while(1){if((y|0)>0){if(!((C|0)>-1)){break c}}else{if((c[A>>2]|0)!=0){z=C;break b}if(!((c[g>>2]|0)!=0&(C|0)>-1)){break c}}e=(FT(b,0)|0)==0;a=c[m>>2]|0;d:do{if(e){D=a}else{e:do{if((c[a+48>>2]|0)==28){if((c[q>>2]|0)==0){E=a;break}do{if((c[a+176>>2]|0)==0){F=a}else{d=Mca(a)|0;t=c[m>>2]|0;v=c[t+176>>2]|0;if((d|0)==(v|0)){E=t;break e}if((v|0)<3){F=t;break}d=c[r>>2]|0;if((v|0)<4){if((d|0)>17){E=t;break e}else{D=t;break d}}else{if((d|0)>19){E=t;break e}else{D=t;break d}}}}while(0);if((c[r>>2]|0)>6){E=F}else{D=F;break d}}else{E=a}}while(0);if((c[o>>2]|0)!=0){break c}if((c[(c[E+12>>2]|0)+16>>2]&1024|0)==0){break c}else{D=E}}}while(0);c[g>>2]=0;a=c[D+8>>2]|0;if((a|0)==0){G=x0a(D,c[h>>2]|0,g,k)|0}else if((a|0)==3){B0a(D,j,g,k)|0;G=c[p>>2]|0}else if((a|0)==1){G=A0a(D,c[h>>2]|0,g,k)|0}else{G=C}if(!((G|0)>-1)){l=G;continue c}a=c[g>>2]|0;if((a|0)!=0){c[r>>2]=(c[r>>2]|0)+1}c[A>>2]=(c[A>>2]|0)+G;e=(c[p>>2]|0)-G|0;c[p>>2]=e;C=a;y=e}}if((c[A>>2]|0)!=0){z=C;break}z=(c[g>>2]|0)==0?-1:C}}while(0);JCb(h);n=z;i=f;return n|0}function HT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[a+1104>>2]|0;if((e|0)==0){f=0;return f|0}g=c[a+1108>>2]|0;a=b;b=0;a:while(1){h=c[g+(b<<2)>>2]|0;b:do{if((h|0)==(a|0)){i=0}else{if((a|0)!=0){i=a;break}j=c[h+16>>2]|0;k=h+12|0;l=0;while(1){if(!(l>>>0<j>>>0)){i=0;break b}if((c[(c[k>>2]|0)+(l<<2)>>2]|0)==(d|0)){f=h;m=9;break a}else{l=l+1|0}}}}while(0);h=b+1|0;if(h>>>0<e>>>0){a=i;b=h}else{f=0;m=9;break}}if((m|0)==9){return f|0}return 0}function IT(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=a+24|0;h=c[g>>2]|0;i=(d|0)<0;a:do{if((e|0)>-1&i){j=c[a+1104>>2]|0;if((j|0)==0){k=h;l=0;break}m=c[a+1108>>2]|0;n=0;while(1){o=c[m+(n<<2)>>2]|0;b:do{if((o|0)!=0){p=c[o+16>>2]|0;q=o+12|0;r=0;while(1){if(!(r>>>0<p>>>0)){break b}s=c[q>>2]|0;if((c[s+(r<<2)>>2]|0)==(e|0)){k=p;l=s;break a}else{r=r+1|0}}}}while(0);o=n+1|0;if(o>>>0<j>>>0){n=o}else{k=h;l=0;break}}}else{k=h;l=0}}while(0);if((k|0)>0){h=a+28|0;e=(b|0)==1;n=(f|0)==0;j=a+1304|0;m=a+1308|0;o=a+1312|0;a=-1;r=-1;p=l;l=0;q=0;s=-1;t=-1381258232;u=k;k=0;while(1){v=(p|0)!=0;if(v){w=c[p+(k<<2)>>2]|0}else{w=k}x=c[(c[h>>2]|0)+(w<<2)>>2]|0;y=c[x+8>>2]|0;c:do{if((c[y+8>>2]|0)==(b|0)){z=(w|0)==(d|0);if(!(i|z)){A=k;B=u;C=t;D=s;E=q;F=l;G=p;H=r;I=a;break}if(!z){if((c[x+72>>2]&384|0)!=0){A=k;B=u;C=t;D=s;E=q;F=l;G=p;H=r;I=a;break}}if(e){if((c[y+416>>2]|0)==0){A=k;B=u;C=t;D=s;E=q;F=l;G=p;H=r;I=a;break}}do{if(n){J=l}else{z=c[y+48>>2]|0;K=c[y+12>>2]|0;if((K|0)!=0){J=K;break}if((b|0)==3){K=c[o>>2]|0;if((K|0)!=0){J=K;break}}else if((b|0)==0){K=c[j>>2]|0;if((K|0)!=0){J=K;break}}else if((b|0)==1){K=c[m>>2]|0;if((K|0)!=0){J=K;break}}K=q0a(z)|0;if((K|0)!=0){J=K;break}A=k;B=u;C=(t|0)<0?-1128613112:t;D=s;E=q;F=0;G=p;H=r;I=a;break c}}while(0);K=c[x+232>>2]|0;z=c[y+72>>2]|0;L=(K|0)<5?K:5;if((a|0)>(L|0)){A=k;B=u;C=t;D=s;E=q;F=J;G=p;H=r;I=a;break}M=(a|0)==(L|0);if(M&(r|0)>(z|0)){A=k;B=u;C=t;D=s;E=q;F=J;G=p;H=r;I=a;break}if(!((s|0)<(K|0)|M&(r|0)==(z|0)^1)){A=k;B=u;C=t;D=s;E=q;F=J;G=p;H=r;I=a;break}if(!v){A=k;B=u;C=w;D=K;E=J;F=J;G=0;H=z;I=L;break}if(!((k|0)==(u-1|0)&(w|0)<0)){A=k;B=u;C=w;D=K;E=J;F=J;G=p;H=z;I=L;break}A=0;B=c[g>>2]|0;C=w;D=K;E=J;F=J;G=0;H=z;I=L}else{A=k;B=u;C=t;D=s;E=q;F=l;G=p;H=r;I=a}}while(0);v=A+1|0;if((v|0)<(B|0)){a=I;r=H;p=G;l=F;q=E;s=D;t=C;u=B;k=v}else{N=E;O=C;break}}}else{N=0;O=-1381258232}if((f|0)==0){return O|0}c[f>>2]=N;return O|0}function JT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=a+24|0;f=c[e>>2]|0;if((f|0)==0){yDb(0,0,2246464,(g=i,i=i+24|0,c[g>>2]=2040552,c[g+8>>2]=2220768,c[g+16>>2]=3510,g)|0);i=g;Cd()}h=a+28|0;if((c[(c[h>>2]|0)+(f-1<<2)>>2]|0)!=(b|0)){yDb(0,0,2246464,(g=i,i=i+24|0,c[g>>2]=2037144,c[g+8>>2]=2220768,c[g+16>>2]=3511,g)|0);i=g;Cd()}g=c[b+240>>2]|0;if((g|0)!=0){VRa(g)}if((c[b+128>>2]|0)!=0){BZ(b+104|0)}DBb(b+88|0);$Db(b+252|0);$Db(b+400|0);g=b+8|0;$Db((c[g>>2]|0)+96|0);$Db((c[g>>2]|0)+860|0);$Db(g);$Db(b+12|0);g=b+184|0;b=c[g>>2]|0;if((b|0)==0){j=g;$Db(j);k=c[e>>2]|0;l=k-1|0;c[e>>2]=l;m=c[h>>2]|0;n=m+(l<<2)|0;o=n;$Db(o);i=d;return}$Db(b+32|0);j=g;$Db(j);k=c[e>>2]|0;l=k-1|0;c[e>>2]=l;m=c[h>>2]|0;n=m+(l<<2)|0;o=n;$Db(o);i=d;return}function KT(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((a|0)==0){i=b;return}g=c[a>>2]|0;if((g|0)==0){i=b;return}h=c[g+16>>2]|0;j=g+4|0;k=c[j>>2]|0;if((k|0)==0){l=5}else{if((c[k+8>>2]&1|0)==0){l=5}else{l=6}}if((l|0)==5){if((c[g+1084>>2]&128|0)==0){m=h}else{l=6}}if((l|0)==6){m=0}l=g+1264|0;h=g+1268|0;k=f;n=c[l>>2]|0;if((n|0)!=0){o=n;do{c[f>>2]=o;c[l>>2]=c[o+80>>2];BZ(o|0);$Db(k);o=c[l>>2]|0;}while((o|0)!=0)}c[h>>2]=0;h=g+1236|0;o=g+1240|0;l=e;k=c[h>>2]|0;if((k|0)!=0){f=k;do{c[e>>2]=f;c[h>>2]=c[f+80>>2];BZ(f|0);$Db(l);f=c[h>>2]|0;}while((f|0)!=0)}c[o>>2]=0;o=g+1256|0;f=g+1260|0;h=d;l=c[o>>2]|0;if((l|0)!=0){e=l;do{c[d>>2]=e;c[o>>2]=c[e+80>>2];BZ(e|0);$Db(h);e=c[o>>2]|0;}while((e|0)!=0)}c[f>>2]=0;c[g+1272>>2]=25e5;f=c[j>>2]|0;do{if((f|0)!=0){j=c[f+48>>2]|0;if((j|0)==0){break}re[j&4095](g)|0}}while(0);bT(g);c[a>>2]=0;Iz(m)|0;i=b;return}function LT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=a+24|0;e=c[d>>2]|0;if(e>>>0>536870910>>>0){f=0;return f|0}g=a+28|0;h=aEb(c[g>>2]|0,e+1|0,4)|0;if((h|0)==0){f=0;return f|0}c[g>>2]=h;h=cEb(656)|0;e=h;if((h|0)==0){f=0;return f|0}i=cEb(104)|0;j=h+184|0;c[j>>2]=i;if((i|0)==0){ZDb(h);f=0;return f|0}k=i;c[k>>2]=0;c[k+4>>2]=-2147483648;k=ARa(b)|0;c[h+8>>2]=k;b=c[a+4>>2]|0;if((b|0)!=0){c[k+72>>2]=0}c[h>>2]=c[d>>2];k=h+48|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+56|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=(b|0)!=0;b=h+208|0;c[b>>2]=k?-1:0;c[b+4>>2]=k?2147418111:0;k=h+200|0;c[k>>2]=0;c[k+4>>2]=-2147483648;c[h+228>>2]=2500;k=h+464|0;c[k>>2]=0;c[k+4>>2]=-2147483648;c[h+472>>2]=0;MT(e,33,1,9e4);k=h+216|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+640|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+264|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+272|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+280|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+288|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+296|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+304|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+312|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+320|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+328|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+336|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+344|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+352|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+360|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+368|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+376|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+384|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+392|0;c[k>>2]=0;c[k+4>>2]=-2147483648;c[h+80>>2]=0;c[h+84>>2]=1;h=c[j>>2]|0;j=h|0;c[j>>2]=0;c[j+4>>2]=-2147483648;j=h+72|0;c[j>>2]=0;c[j+4>>2]=-2147483648;j=h+88|0;c[j>>2]=0;c[j+4>>2]=-2147483648;j=c[d>>2]|0;c[d>>2]=j+1;c[(c[g>>2]|0)+(j<<2)>>2]=e;f=e;return f|0}function MT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+8|0;g=f|0;h=g;j=g;k=h+4|0;do{if((iFb(j,k,d,0,e,0,2147483647,0)|0)==0){yDb(0,24,1943592,(l=i,i=i+8|0,c[l>>2]=c[a>>2],l)|0);i=l;m=5}else{n=c[j>>2]|0;if((n|0)==(d|0)){o=d;break}yDb(0,48,1945032,(l=i,i=i+16|0,c[l>>2]=c[a>>2],c[l+8>>2]=(d>>>0)/(n>>>0)|0,l)|0);i=l;m=5}}while(0);if((m|0)==5){o=c[j>>2]|0}j=c[k>>2]|0;if((o|0)<1|(j|0)<1){k=c[a>>2]|0;yDb(0,16,1936112,(l=i,i=i+24|0,c[l>>2]=o,c[l+8>>2]=j,c[l+16>>2]=k,l)|0);i=l;i=f;return}else{l=a+40|0;k=c[g+4>>2]|0;c[l>>2]=c[g>>2];c[l+4>>2]=k;f0a(c[a+8>>2]|0,h);c[a+188>>2]=b;i=f;return}}function NT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a+1104|0;e=c[d>>2]|0;if((e|0)==0){f=5}else{g=c[a+1108>>2]|0;h=0;i=0;do{j=c[g+(h<<2)>>2]|0;i=(c[j>>2]|0)==(b|0)?j:i;h=h+1|0;}while(h>>>0<e>>>0);if((i|0)==0){f=5}else{k=i}}do{if((f|0)==5){i=cEb(72)|0;if((i|0)==0){l=0;return l|0}else{gEb(a+1108|0,d,i);c[i+8>>2]=-16;k=i;break}}}while(0);c[k>>2]=b;b=k+56|0;c[b>>2]=0;c[b+4>>2]=-2147483648;c[k+64>>2]=0;b=k+48|0;c[b>>2]=0;c[b+4>>2]=-2147483648;b=k+40|0;c[b>>2]=0;c[b+4>>2]=-2147483648;l=k;return l|0}function OT(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=i;l=d;d=i;i=i+8|0;c[d>>2]=c[l>>2];c[d+4>>2]=c[l+4>>2];l=a+1132|0;m=c[l>>2]|0;if((m|0)==0){n=5}else{o=c[a+1136>>2]|0;p=0;q=0;do{r=c[o+(p<<2)>>2]|0;q=(c[r>>2]|0)==(b|0)?r:q;p=p+1|0;}while(p>>>0<m>>>0);if((q|0)==0){n=5}else{s=q}}do{if((n|0)==5){q=cEb(40)|0;if((q|0)==0){t=0;i=k;return t|0}else{gEb(a+1136|0,l,q);s=q;break}}}while(0);CBb(s+32|0,2033528,j,0)|0;c[s>>2]=b;b=d;d=s+4|0;j=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=j;j=s+16|0;c[j>>2]=e;c[j+4>>2]=f;f=s+24|0;c[f>>2]=g;c[f+4>>2]=h;t=s;i=k;return t|0}function PT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;if(!((c[a+24>>2]|0)>>>0>d>>>0)){yDb(a,16,2029368,(f=i,i=i+8|0,c[f>>2]=d,f)|0);i=f;i=e;return}f=c[a+1104>>2]|0;g=a+1108|0;a=0;while(1){if(!(a>>>0<f>>>0)){h=11;break}j=c[(c[g>>2]|0)+(a<<2)>>2]|0;if((c[j>>2]|0)==(b|0)){break}else{a=a+1|0}}if((h|0)==11){i=e;return}a=j+16|0;b=c[a>>2]|0;g=j+12|0;j=c[g>>2]|0;f=0;while(1){if(!(f>>>0<b>>>0)){break}if((c[j+(f<<2)>>2]|0)==(d|0)){h=11;break}else{f=f+1|0}}if((h|0)==11){i=e;return}h=aEb(j,b+1|0,4)|0;if((h|0)==0){i=e;return}b=h;c[g>>2]=b;g=c[a>>2]|0;c[a>>2]=g+1;c[b+(g<<2)>>2]=d;i=e;return}function QT(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;j=b+24|0;k=c[j>>2]|0;do{if((k|0)==0){l=0}else{m=cEb(k)|0;if(!((c[j>>2]|0)!=0&(m|0)==0)){l=m;break}i=g;return}}while(0);k=(f|0)!=0;if(k){n=c[b+8>>2]|0}else{n=c[b+4>>2]|0}m=c[n>>2]|0;yDb(0,32,2025728,(n=i,i=i+40|0,c[n>>2]=k?2022120:2018752,c[n+8>>2]=d,c[n+16>>2]=m,c[n+24>>2]=k?2014472:2011376,c[n+32>>2]=e,n)|0);i=n;RT(c[b+1140>>2]|0,2001384);if(!k){yDb(0,32,1995544,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=b+1064|0;e=c[k>>2]|0;m=c[k+4>>2]|0;if((e|0)==0&(m|0)==(-2147483648|0)){yDb(0,32,1988824,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}else{k=YGb(e,m,5e3,0)|0;m=F;e=eHb(k,m,1e6,0)|0;o=e;e=fHb(k,m,1e6,0)|0;yDb(0,32,1992448,(n=i,i=i+32|0,c[n>>2]=(o|0)/3600|0,c[n+8>>2]=((o|0)/60|0|0)%60|0,c[n+16>>2]=(o|0)%60|0,c[n+24>>2]=(e*100|0|0)/1e6|0,n)|0);i=n}e=b+1056|0;if(!((c[e>>2]|0)==0&(c[e+4>>2]|0)==(-2147483648|0))){yDb(0,32,1985136,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=c[e>>2]|0;m=c[e+4>>2]|0;e=eHb(o,m,1e6,0)|0;k=fHb(o,m,1e6,0)|0;m=k;k=(m|0)>-1?m:-m|0;m=IDb(k,(k|0)<0|0?-1:0,1e6,0,1e6,0)|0;yDb(0,32,1982008,(n=i,i=i+16|0,c[n>>2]=e,c[n+8>>2]=m,n)|0);i=n}yDb(0,32,1978816,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=c[b+1072>>2]|0;if((m|0)==0){yDb(0,32,1988824,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}else{yDb(0,32,1976296,(n=i,i=i+8|0,c[n>>2]=(m|0)/1e3|0,n)|0);i=n}yDb(0,32,1973984,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}m=b+1132|0;if((c[m>>2]|0)!=0){e=b+1136|0;k=0;do{o=c[(c[e>>2]|0)+(k<<2)>>2]|0;yDb(0,32,1972496,(n=i,i=i+16|0,c[n>>2]=d,c[n+8>>2]=k,n)|0);i=n;p=o+16|0;q=o+4|0;r=o+8|0;yDb(0,32,1964272,(n=i,i=i+8|0,h[n>>3]=(+((c[p>>2]|0)>>>0)+ +(c[p+4>>2]|0)*4294967296.0)*(+(c[q>>2]|0)/+(c[r>>2]|0)),n)|0);i=n;p=o+24|0;yDb(0,32,1959944,(n=i,i=i+8|0,h[n>>3]=(+((c[p>>2]|0)>>>0)+ +(c[p+4>>2]|0)*4294967296.0)*(+(c[q>>2]|0)/+(c[r>>2]|0)),n)|0);i=n;RT(c[o+32>>2]|0,1957992);k=k+1|0;}while(k>>>0<(c[m>>2]|0)>>>0)}m=b+1104|0;do{if((c[m>>2]|0)==0){s=28}else{k=b+1108|0;e=0;o=0;r=c[k>>2]|0;while(1){q=BBb(c[(c[r+(e<<2)>>2]|0)+20>>2]|0,1955528,0,0)|0;if((q|0)==0){t=9203216}else{t=c[q+4>>2]|0}yDb(0,32,1953368,(n=i,i=i+16|0,c[n>>2]=c[c[(c[k>>2]|0)+(e<<2)>>2]>>2],c[n+8>>2]=t,n)|0);i=n;RT(c[(c[(c[k>>2]|0)+(e<<2)>>2]|0)+20>>2]|0,1957992);q=c[k>>2]|0;p=c[q+(e<<2)>>2]|0;if((c[p+16>>2]|0)==0){u=0;v=q}else{q=0;w=p;while(1){ST(b,c[(c[w+12>>2]|0)+(q<<2)>>2]|0,d,f);p=c[k>>2]|0;x=p+(e<<2)|0;a[l+(c[(c[(c[x>>2]|0)+12>>2]|0)+(q<<2)>>2]|0)|0]=1;y=q+1|0;z=c[x>>2]|0;x=c[z+16>>2]|0;if(y>>>0<x>>>0){q=y;w=z}else{u=x;v=p;break}}}A=u+o|0;w=e+1|0;if(w>>>0<(c[m>>2]|0)>>>0){e=w;o=A;r=v}else{break}}r=c[j>>2]|0;if(!(A>>>0<r>>>0)){B=r;break}yDb(0,32,1951152,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;s=28}}while(0);if((s|0)==28){B=c[j>>2]|0}if((B|0)!=0){s=0;n=B;while(1){if((a[l+s|0]|0)==0){ST(b,s,d,f);C=c[j>>2]|0}else{C=n}B=s+1|0;if(B>>>0<C>>>0){s=B;n=C}else{break}}}ZDb(l);i=g;return}function RT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+256|0;f=e|0;if((b|0)==0){i=e;return}do{if((ABb(b)|0)==1){if((BBb(b,1900688,0,0)|0)==0){break}i=e;return}}while(0);yDb(0,32,2325344,(g=i,i=i+8|0,c[g>>2]=d,g)|0);i=g;h=BBb(b,9203216,0,2)|0;if((h|0)==0){i=e;return}j=f|0;f=h;do{h=c[f>>2]|0;if((QGb(1900688,h)|0)!=0){k=c[f+4>>2]|0;yDb(0,32,2323480,(g=i,i=i+16|0,c[g>>2]=d,c[g+8>>2]=h,g)|0);i=g;a:do{if((a[k]|0)!=0){h=k;do{l=hc(h|0,2321256)|0;m=l+1|0;sAb(j,h,m>>>0<256>>>0?m:256)|0;yDb(0,32,2319792,(g=i,i=i+8|0,c[g>>2]=j,g)|0);i=g;n=h+l|0;l=a[n]|0;if(l<<24>>24==13){yDb(0,32,1903024,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;o=a[n]|0}else{o=l}if(o<<24>>24==10){yDb(0,32,2318120,(g=i,i=i+16|0,c[g>>2]=d,c[g+8>>2]=9203216,g)|0);i=g;p=a[n]|0}else{p=o}if(p<<24>>24==0){break a}h=h+m|0;}while((a[h]|0)!=0)}}while(0);yDb(0,32,1973984,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}f=BBb(b,9203216,f,2)|0;}while((f|0)!=0);i=e;return}function ST(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;f=i;i=i+264|0;g=f+256|0;if((e|0)==0){j=(c[a+4>>2]|0)+8|0}else{j=(c[a+8>>2]|0)+28|0}k=c[j>>2]|0;j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;a=j+40|0;l=c[a>>2]|0;m=j+44|0;n=c[m>>2]|0;o=GDb(l,(l|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=o;o=j+88|0;l=BBb(c[o>>2]|0,1900688,0,0)|0;p=f|0;q=j+8|0;J0a(p,256,c[q>>2]|0,e);yDb(0,32,1899320,(e=i,i=i+16|0,c[e>>2]=d,c[e+8>>2]=b,e)|0);i=e;if((k&8|0)!=0){yDb(0,32,1898024,(e=i,i=i+8|0,c[e>>2]=c[j+4>>2],e)|0);i=e}if((l|0)!=0){yDb(0,32,1892232,(e=i,i=i+8|0,c[e>>2]=c[l+4>>2],e)|0);i=e}l=(c[a>>2]|0)/(n|0)|0;k=(c[m>>2]|0)/(n|0)|0;yDb(0,48,1889064,(e=i,i=i+24|0,c[e>>2]=c[j+232>>2],c[e+8>>2]=l,c[e+16>>2]=k,e)|0);i=e;yDb(0,32,1887240,(e=i,i=i+8|0,c[e>>2]=p,e)|0);i=e;p=j+80|0;k=c[p>>2]|0;a:do{if((k|0)!=0){l=c[q>>2]|0;n=j+84|0;b=c[n>>2]|0;d=c[l+224>>2]|0;r=c[l+228>>2]|0;s=gHb(r,(r|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;t=F;u=gHb(d,(d|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;do{if((s|0)==(u|0)&(t|0)==(F|0)){if(!((r|0)==0|(b|0)==0)){break a}if((d|0)==0){break}if((k>>31|0)==(d>>31|0)){break a}}}while(0);d=g|0;r=g+4|0;t=ba(k,c[l+120>>2]|0)|0;u=ba(b,c[l+124>>2]|0)|0;iFb(d,r,t,(t|0)<0|0?-1:0,u,(u|0)<0|0?-1:0,1048576,0)|0;u=c[n>>2]|0;t=c[d>>2]|0;d=c[r>>2]|0;yDb(0,32,1885576,(e=i,i=i+32|0,c[e>>2]=c[p>>2],c[e+8>>2]=u,c[e+16>>2]=t,c[e+24>>2]=d,e)|0);i=e}}while(0);do{if((c[(c[q>>2]|0)+8>>2]|0)==0){p=c[j+96>>2]|0;do{if((p|0)!=0){k=c[j+92>>2]|0;if((k|0)==0){break}v=+(k|0)/+(p|0);k=Gc(+(v*100.0))|0;g=k;d=(k|0)<0|0?-1:0;k=iHb(g,d,100,0)|0;if(!((k|0)==0&(F|0)==0)){yDb(0,32,2337296,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=1884216,e)|0);i=e;break}k=iHb(g,d,1e5,0)|0;if((k|0)==0&(F|0)==0){yDb(0,32,2329568,(e=i,i=i+16|0,h[e>>3]=v/1.0e3,c[e+8>>2]=1884216,e)|0);i=e;break}else{yDb(0,32,2335360,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=1884216,e)|0);i=e;break}}}while(0);p=c[j+416>>2]|0;do{if((p|0)!=0){n=c[j+412>>2]|0;if((n|0)==0){break}v=+(n|0)/+(p|0);n=Gc(+(v*100.0))|0;l=n;b=(n|0)<0|0?-1:0;n=iHb(l,b,100,0)|0;if(!((n|0)==0&(F|0)==0)){yDb(0,32,2337296,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=1883088,e)|0);i=e;break}n=iHb(l,b,1e5,0)|0;if((n|0)==0&(F|0)==0){yDb(0,32,2329568,(e=i,i=i+16|0,h[e>>3]=v/1.0e3,c[e+8>>2]=1883088,e)|0);i=e;break}else{yDb(0,32,2335360,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=1883088,e)|0);i=e;break}}}while(0);p=c[m>>2]|0;do{if((p|0)!=0){n=c[a>>2]|0;if((n|0)==0){break}v=1.0/(+(n|0)/+(p|0));n=Gc(+(v*100.0))|0;b=n;l=(n|0)<0|0?-1:0;n=iHb(b,l,100,0)|0;if(!((n|0)==0&(F|0)==0)){yDb(0,32,2337296,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=1881904,e)|0);i=e;break}n=iHb(b,l,1e5,0)|0;if((n|0)==0&(F|0)==0){yDb(0,32,2329568,(e=i,i=i+16|0,h[e>>3]=v/1.0e3,c[e+8>>2]=1881904,e)|0);i=e;break}else{yDb(0,32,2335360,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=1881904,e)|0);i=e;break}}}while(0);p=c[q>>2]|0;n=c[p+108>>2]|0;if((n|0)==0){break}l=c[p+104>>2]|0;if((l|0)==0){break}v=1.0/(+(l|0)/+(n|0));n=Gc(+(v*100.0))|0;l=n;p=(n|0)<0|0?-1:0;n=iHb(l,p,100,0)|0;if(!((n|0)==0&(F|0)==0)){yDb(0,32,2337296,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=1880656,e)|0);i=e;break}n=iHb(l,p,1e5,0)|0;if((n|0)==0&(F|0)==0){yDb(0,32,2329568,(e=i,i=i+16|0,h[e>>3]=v/1.0e3,c[e+8>>2]=1880656,e)|0);i=e;break}else{yDb(0,32,2335360,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=1880656,e)|0);i=e;break}}}while(0);q=j+72|0;j=c[q>>2]|0;if((j&1|0)==0){w=j}else{yDb(0,32,1879056,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;w=c[q>>2]|0}if((w&2|0)==0){x=w}else{yDb(0,32,2355320,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;x=c[q>>2]|0}if((x&4|0)==0){y=x}else{yDb(0,32,2349840,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;y=c[q>>2]|0}if((y&8|0)==0){z=y}else{yDb(0,32,2346560,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;z=c[q>>2]|0}if((z&16|0)==0){A=z}else{yDb(0,32,2345264,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;A=c[q>>2]|0}if((A&32|0)==0){B=A}else{yDb(0,32,2343584,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;B=c[q>>2]|0}if((B&64|0)==0){C=B}else{yDb(0,32,2342288,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;C=c[q>>2]|0}if((C&128|0)==0){D=C}else{yDb(0,32,2341144,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;D=c[q>>2]|0}if((D&256|0)==0){E=D}else{yDb(0,32,2339720,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;E=c[q>>2]|0}if((E&512|0)==0){yDb(0,32,1973984,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;G=c[o>>2]|0;RT(G,1957992);i=f;return}yDb(0,32,2338648,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;yDb(0,32,1973984,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;G=c[o>>2]|0;RT(G,1957992);i=f;return}function TT(){var a=0,b=0,c=0,d=0,e=0;a=WFb()|0;b=F;c=fHb(a,b,1e3,0)|0;d=F;e=YGb(a,b,1220321280,514320)|0;b=ZGb(e,F,c,d)|0;return(F=F,b)|0}function UT(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=i;if((h|0)<=0){i=j;return}k=(e|0)!=0;l=0;do{m=h-l|0;n=(m|0)>16?16:m;if(k){Dd(e|0,1908120,(o=i,i=i+8|0,c[o>>2]=l,o)|0)|0;i=o;p=0}else{yDb(b,f,1908120,(o=i,i=i+8|0,c[o>>2]=l,o)|0);i=o;p=0}do{do{if((p|0)<(n|0)){m=d[g+(p+l)|0]|0;if(k){Dd(e|0,1906344,(o=i,i=i+8|0,c[o>>2]=m,o)|0)|0;i=o;break}else{yDb(b,f,1906344,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;break}}else{if(k){nb(1904832,3,1,e|0)|0;break}else{yDb(b,f,1904832,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);p=p+1|0;}while((p|0)<16);if(k){lb(32,e|0)|0}else{yDb(b,f,1903024,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}if((n|0)>0){m=0;do{q=a[g+(m+l)|0]|0;r=(q-32&255)>>>0>94>>>0?46:q&255;if(k){lb(r|0,e|0)|0}else{yDb(b,f,1901760,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o}m=m+1|0;}while((m|0)<(n|0))}if(k){lb(10,e|0)|0}else{yDb(b,f,1973984,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}l=l+16|0;}while((l|0)<(h|0));i=j;return}function VT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;UT(a,0,b,c,d);return}function WT(a,b,d,e,f,g,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0,r=0;k=i;l=(b|0)!=0;m=c[e+32>>2]|0;if(l){Dd(b|0,1925144,(n=i,i=i+8|0,c[n>>2]=m,n)|0)|0;i=n;Dd(b|0,1923568,(n=i,i=i+8|0,c[n>>2]=c[e+36>>2]&1,n)|0)|0;i=n}else{yDb(a,d,1925144,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;yDb(a,d,1923568,(n=i,i=i+8|0,c[n>>2]=c[e+36>>2]&1,n)|0);i=n}o=+(g|0)/+(j|0);p=+(c[e+48>>2]|0)*o;if(l){Dd(b|0,1922008,(n=i,i=i+8|0,h[n>>3]=p,n)|0)|0;i=n;nb(1920384,6,1,b|0)|0}else{yDb(a,d,1922008,(n=i,i=i+8|0,h[n>>3]=p,n)|0);i=n;yDb(a,d,1920384,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}j=e+16|0;g=c[j>>2]|0;m=c[j+4>>2]|0;do{if((g|0)==0&(m|0)==(-2147483648|0)){if(l){nb(1988824,3,1,b|0)|0;q=15;break}else{yDb(a,d,1988824,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=14;break}}else{p=o*(+(g>>>0)+ +(m|0)*4294967296.0);if(l){Dd(b|0,1918864,(n=i,i=i+8|0,h[n>>3]=p,n)|0)|0;i=n;q=15;break}else{yDb(a,d,1918864,(n=i,i=i+8|0,h[n>>3]=p,n)|0);i=n;q=14;break}}}while(0);if((q|0)==14){yDb(a,d,1912648,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}else if((q|0)==15){nb(1912648,6,1,b|0)|0}m=e+8|0;g=c[m>>2]|0;j=c[m+4>>2]|0;do{if((g|0)==0&(j|0)==(-2147483648|0)){if(l){nb(1988824,3,1,b|0)|0;q=24;break}else{yDb(a,d,1988824,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=23;break}}else{p=o*(+(g>>>0)+ +(j|0)*4294967296.0);if(l){Dd(b|0,1918864,(n=i,i=i+8|0,h[n>>3]=p,n)|0)|0;i=n;q=24;break}else{yDb(a,d,1918864,(n=i,i=i+8|0,h[n>>3]=p,n)|0);i=n;q=23;break}}}while(0);if((q|0)==23){yDb(a,d,1973984,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=e+28|0;yDb(a,d,1909472,(n=i,i=i+8|0,c[n>>2]=c[l>>2],n)|0);i=n;r=l}else if((q|0)==24){lb(10,b|0)|0;q=e+28|0;Dd(b|0,1909472,(n=i,i=i+8|0,c[n>>2]=c[q>>2],n)|0)|0;i=n;r=q}if((f|0)==0){i=k;return}UT(0,b,0,c[e+24>>2]|0,c[r>>2]|0);i=k;return}function XT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;WT(a,0,b,d,e,c[f+40>>2]|0,c[f+44>>2]|0);return}function YT(b,d,e,f,g,h,i,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;m=(i|0)!=0;if(m){c[i>>2]=-1}if((d|0)>0){a[b]=0}if((f|0)>0){a[e]=0}if((h|0)>0){a[g]=0}if((k|0)>0){a[j]=0}n=Vb(l|0,58)|0;if((n|0)==0){sAb(j,l,k)|0;return}o=n+1|0;p=o-l|0;sAb(b,l,(p|0)<(d|0)?p:d)|0;d=(a[o]|0)==47?n+2|0:o;o=(a[d]|0)==47?d+1|0:d;d=Vb(o|0,47)|0;n=Vb(o|0,63)|0;do{if((d|0)==0){q=n;r=16}else{if((n|0)==0){s=d;r=17;break}q=d>>>0>n>>>0?n:d;r=16}}while(0);do{if((r|0)==16){if((q|0)!=0){s=q;r=17;break}t=o+(SGb(o|0)|0)|0}}while(0);if((r|0)==17){sAb(j,s,k)|0;t=s}if((t|0)==(o|0)){return}s=Vb(o|0,64)|0;if((s|0)!=0&s>>>0<t>>>0){k=o;j=s;while(1){s=j+1|0;r=s-k|0;sAb(e,o,(r|0)<(f|0)?r:f)|0;r=Vb(s|0,64)|0;if((r|0)!=0&r>>>0<t>>>0){j=r}else{u=s;break}}}else{u=o}do{if((a[u]|0)==91){o=Vb(u|0,93)|0;if(!((o|0)!=0&o>>>0<t>>>0)){break}j=o-u|0;sAb(g,u+1|0,(j|0)<(h|0)?j:h)|0;if((a[o+1|0]|0)!=58|m^1){return}c[i>>2]=gd(o+2|0)|0;return}}while(0);o=Vb(u|0,58)|0;if(!((o|0)!=0&o>>>0<t>>>0)){j=t+1-u|0;sAb(g,u,(j|0)>(h|0)?h:j)|0;return}j=o+1|0;o=j-u|0;sAb(g,u,(o|0)>(h|0)?h:o)|0;if(!m){return}c[i>>2]=gd(j|0)|0;return}function ZT(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=(f|0)!=0?1234624:1234608;if((e|0)>0){h=0}else{return b|0}do{f=c+h|0;i=h<<1;a[b+i|0]=a[g+((d[f]|0)>>>4)|0]|0;a[b+(i|1)|0]=a[g+(a[f]&15)|0]|0;h=h+1|0;}while((h|0)<(e|0));return b|0}function _T(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(b|0)==0;e=0;f=c;a:while(1){c=1;g=f;do{h=qd(g|0,1947112)|0;i=a[g+h|0]|0;if(i<<24>>24==0){j=11;break a}g=g+(h+1)|0;h=i&255;i=(h-97|0)>>>0<26>>>0?h^32:h;h=i-48|0;if(h>>>0<10>>>0){k=h}else{if(!((i-65|0)>>>0<6>>>0)){j=11;break a}k=i-55|0}c=k|c<<4;}while((c&256|0)==0);if(!d){a[b+e|0]=c}e=e+1|0;f=g}if((j|0)==11){return e|0}return 0}function $T(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+16|0;g=f|0;h=f+8|0;c[g>>2]=0;c[h>>2]=0;j=a[b]|0;if(j<<24>>24==0){i=f;return}else{k=b;l=j}a:while(1){do{if((EAb(l<<24>>24)|0)==0){j=a[k]|0;if((j<<24>>24|0)==0){m=25;break a}else if((j<<24>>24|0)==44){break}j=Vb(k|0,61)|0;if((j|0)==0){m=25;break a}b=j+1|0;le[d&1023](e,k,b-k|0,g,h);n=(c[g>>2]|0)+((c[h>>2]|0)-1)|0;o=a[b]|0;b:do{if((o<<24>>24|0)==0){p=b}else if((o<<24>>24|0)==34){q=j+2|0;while(1){r=a[q]|0;if((r<<24>>24|0)==0|(r<<24>>24|0)==34){break}else if((r<<24>>24|0)!=92){s=c[g>>2]|0;if((s|0)!=0&s>>>0<n>>>0){c[g>>2]=s+1;a[s]=r}q=q+1|0;continue}s=a[q+1|0]|0;if(s<<24>>24==0){break}t=c[g>>2]|0;if((t|0)!=0&t>>>0<n>>>0){c[g>>2]=t+1;a[t]=s}q=q+2|0}p=r<<24>>24==34?q+1|0:q}else{s=b;t=o;while(1){if((EAb(t<<24>>24)|0)!=0){p=s;break b}u=a[s]|0;if(u<<24>>24==44){p=s;break b}v=c[g>>2]|0;if((v|0)!=0&v>>>0<n>>>0){c[g>>2]=v+1;a[v]=u}u=s+1|0;v=a[u]|0;if(v<<24>>24==0){p=u;break}else{s=u;t=v}}}}while(0);n=c[g>>2]|0;if((n|0)!=0){a[n]=0}c[g>>2]=0;c[h>>2]=0;n=a[p]|0;if(n<<24>>24==0){m=25;break a}else{k=p;l=n;continue a}}}while(0);n=k+1|0;o=a[n]|0;if(o<<24>>24==0){m=25;break}else{k=n;l=o}}if((m|0)==25){i=f;return}}function aU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+28|0;e=c[a+24>>2]|0;a=0;while(1){if(!(a>>>0<e>>>0)){f=-1;g=4;break}if((c[(c[(c[d>>2]|0)+(a<<2)>>2]|0)+4>>2]|0)==(b|0)){f=a;g=4;break}else{a=a+1|0}}if((g|0)==4){return f|0}return 0}function bU(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=i;i=i+96|0;c=b|0;d=b+48|0;TGb(c|0,0,44)|0;TGb(d|0,0,44)|0;e=TEb(a,1931992,c)|0;if((TEb(a,1930208,d)|0)!=0&(e|0)==0){f=UEb(d)|0}else{f=UEb(c)|0}i=b;return(F=(f|0)<0|0?-1:0,f)|0}function cU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((a|0)!=0){e=c[a+64>>2]|0;if((e|0)!=0){f=Oe[e&1023](b,d)|0;return f|0}e=c[a+32>>2]|0;if((e|0)==0){if((c[a+20>>2]|0)==(b|0)){f=1;return f|0}if((c[a+16>>2]|0)==(b|0)){f=1;return f|0}if((c[a+24>>2]|0)==(b|0)){f=1}else{break}return f|0}g=c[e>>2]|0;if((g|0)==0){f=0;return f|0}else{h=0;i=g}a:while(1){j=i;while(1){g=c[j>>2]|0;if((g|0)==0){break}if((g|0)==(b|0)){break a}else{j=j+8|0}}g=h+1|0;k=c[e+(g<<2)>>2]|0;if((k|0)==0){f=0;l=15;break}else{h=g;i=k}}if((l|0)==15){return f|0}f=(c[j+4>>2]|0)!=0|0;return f|0}}while(0);f=-1163346256;return f|0}function dU(){return 0}function eU(){return 0}function fU(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((b|0)==0){i=-22;return i|0}j=(c|0)!=0;k=j&1;l=j?8:4;m=(d|0)!=0|(e|0)!=0;if(m){n=l+8|0;o=k|2}else{n=l;o=k}k=(f|0)!=0;if(k){p=n+4|0;q=o|4}else{p=n;q=o}o=(h|g|0)==0;if(o){r=p;s=q}else{r=p+8|0;s=q|8}q=GZ(b,2,r)|0;if((q|0)==0){i=-12;return i|0}r=q;x=s;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;if(j){j=r;x=c;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;t=q+8|0}else{t=r}if(m){m=t;r=m|0;x=d;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+4|0;x=e;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;u=t+8|0}else{u=t}if(k){k=u;x=f;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;v=u+4|0}else{v=u}if(o){i=0;return i|0}o=v;x=g;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=v+4|0;x=h;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;i=0;return i|0}function gU(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+8|0;b=e|0;f=b;g=i;i=i+8|0;h=g;j=i;i=i+8|0;k=d+412|0;l=c[k>>2]|0;m=c[k+4>>2]|0;c[b>>2]=l;c[b+4>>2]=m;k=c[d+8>>2]|0;n=c[k+104>>2]|0;o=c[k+108>>2]|0;p=d+92|0;d=c[p>>2]|0;q=c[p+4>>2]|0;c[g>>2]=d;c[g+4>>2]=q;g=d;p=q;r=l;s=m;do{if((g|0)>0&(p|0)>0&(r|0)>0&(s|0)>0){if(!(+(g|0)/+(p|0)<70.0)){t=r;u=s;v=m;w=l;break}if(!(+(r|0)/+(s|0)>210.0)){t=r;u=s;v=m;w=l;break}c[b>>2]=d;c[b+4>>2]=q;t=g;u=p;v=q;w=d}else{t=r;u=s;v=m;w=l}}while(0);l=c[k+112>>2]|0;do{if((l|0)>1){k=ba(l,n)|0;if(!((o|0)>0&(k|0)>0)){x=v;y=w;break}if(!(+(o|0)/+(k|0)<+(t|0)/+(u|0)*.7)){x=v;y=w;break}kFb(j,h,f);if(+Q(+(1.0- +(c[j>>2]|0)/+(c[j+4>>2]|0)))>.1){m=o|0;s=k|0;c[b>>2]=m;c[b+4>>2]=s;x=s;y=m;break}else{x=c[b+4>>2]|0;y=c[b>>2]|0;break}}else{x=v;y=w}}while(0);w=a;c[w>>2]=y;c[w+4>>2]=x;i=e;return}function hU(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=a[e]|0;if((j-48&255)>>>0<10>>>0){k=kb(e|0,0,0)|0;l=(k|0)==(c[d>>2]|0)|0;i=f;return l|0}a:do{switch(j<<24>>24){case 112:{if((a[e+1|0]|0)!=58){break a}k=kb(e+2|0,g|0,0)|0;m=c[b+1104>>2]|0;if((m|0)==0){l=0;i=f;return l|0}n=b+1108|0;o=c[n>>2]|0;p=d|0;q=0;b:while(1){r=c[o+(q<<2)>>2]|0;c:do{if((c[r>>2]|0)==(k|0)){s=c[g>>2]|0;t=s+1|0;c[g>>2]=t;if((a[s]|0)==58){u=24;break b}s=c[r+16>>2]|0;v=r+12|0;w=0;while(1){if(!(w>>>0<s>>>0)){break c}if((c[p>>2]|0)==(c[(c[v>>2]|0)+(w<<2)>>2]|0)){l=1;u=33;break b}else{w=w+1|0}}}}while(0);r=q+1|0;if(r>>>0<m>>>0){q=r}else{l=0;u=33;break}}if((u|0)==24){m=kb(t|0,0,0)|0;if(!((m|0)>-1)){l=0;i=f;return l|0}k=c[(c[n>>2]|0)+(q<<2)>>2]|0;if(!(m>>>0<(c[k+16>>2]|0)>>>0)){l=0;i=f;return l|0}l=(c[p>>2]|0)==(c[(c[k+12>>2]|0)+(m<<2)>>2]|0)|0;i=f;return l|0}else if((u|0)==33){i=f;return l|0}break};case 118:case 97:case 115:case 100:case 116:{switch(j<<24>>24|0){case 116:{x=4;break};case 97:{x=1;break};case 115:{x=3;break};case 118:{x=0;break};case 100:{x=2;break};default:{yDb(0,0,2246464,(y=i,i=i+24|0,c[y>>2]=1928464,c[y+8>>2]=2220768,c[y+16>>2]=4436,y)|0);i=y;Cd();return 0}}if((x|0)!=(c[(c[d+8>>2]|0)+8>>2]|0)){l=0;i=f;return l|0}if((a[e+1|0]|0)!=58){l=1;i=f;return l|0}m=kb(e+2|0,0,0)|0;k=c[b+24>>2]|0;if((k|0)==0){l=0;i=f;return l|0}o=c[b+28>>2]|0;r=0;w=m;while(1){if((c[(c[(c[o+(r<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==(x|0)){if((w|0)==0){break}else{z=w-1|0}}else{z=w}m=r+1|0;if(m>>>0<k>>>0){r=m;w=z}else{l=0;u=33;break}}if((u|0)==33){i=f;return l|0}l=(r|0)==(c[d>>2]|0)|0;i=f;return l|0};case 0:{l=1;i=f;return l|0};case 35:{w=kb(e+1|0,h|0,0)|0;if((a[c[h>>2]|0]|0)!=0){break a}l=(c[d+4>>2]|0)==(w|0)|0;i=f;return l|0};default:{}}}while(0);yDb(b,16,1926736,(y=i,i=i+8|0,c[y>>2]=e,y)|0);i=y;l=-22;i=f;return l|0}function iU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+8|0;a=c[b>>2]|0;d=c[a+120>>2]|0;do{if((d|0)==1440){e=1214632;f=97}else if((d|0)==1920){g=(c[a+408>>2]|0)==1;e=g?1214832:1214920;f=g?81:97}else{g=(d|0)==1280;if(g){e=g?1214736:0;f=g?89:0;break}else{h=0}return h|0}}while(0);$Db(a+96|0);a=c[b>>2]|0;d=WDb(f+16|0)|0;c[a+96>>2]=d;if((d|0)==0){c[a+100>>2]=0;h=-12;return h|0}else{TGb(d+f|0,0,16)|0;c[a+100>>2]=f;UGb(c[(c[b>>2]|0)+96>>2]|0,e|0,f)|0;h=0;return h|0}return 0}function jU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0.0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=a+24|0;do{if((c[g>>2]|0)!=0){j=a+28|0;k=f|0;l=f+4|0;m=d|0;n=d+4|0;o=a+1104|0;p=a+1108|0;q=e|0;r=e+4|0;s=-2147483648;t=0;u=-2147483648;v=0;w=0;x=2147483647;y=-1;z=2147483647;A=-1;while(1){B=c[(c[j>>2]|0)+(w<<2)>>2]|0;C=B+48|0;D=c[C>>2]|0;E=c[C+4>>2]|0;a:do{if((D|0)==0&(E|0)==(-2147483648|0)){G=z;H=A;I=x;J=y;K=u;L=v}else{C=B+40|0;if((c[B+44>>2]|0)==0){G=z;H=A;I=x;J=y;K=u;L=v;break}c[m>>2]=1;c[n>>2]=1e6;M=KDb(D,E,C,d)|0;N=F;if(((c[(c[B+8>>2]|0)+8>>2]|0)-2|0)>>>0<2>>>0){O=(N|0)<(x|0)|(N|0)==(x|0)&M>>>0<y>>>0;P=z;Q=A;R=O?N:x;S=O?M:y}else{O=(z|0)>(N|0)|(z|0)==(N|0)&A>>>0>M>>>0;P=O?N:z;Q=O?M:A;R=x;S=y}O=B+56|0;T=c[O>>2]|0;U=c[O+4>>2]|0;if((T|0)==0&(U|0)==(-2147483648|0)){V=u;W=v;X=-2147483648;Y=0}else{c[q>>2]=1;c[r>>2]=1e6;O=KDb(T,U,C,e)|0;C=YGb(O,F,M,N)|0;O=F;U=(u|0)>(O|0)|(u|0)==(O|0)&v>>>0>C>>>0;V=U?u:O;W=U?v:C;X=O;Y=C}C=c[o>>2]|0;if((C|0)==0){G=P;H=Q;I=R;J=S;K=V;L=W;break}O=c[p>>2]|0;U=0;T=0;b:while(1){Z=c[O+(T<<2)>>2]|0;c:do{if((Z|0)==(U|0)){_=0}else{if((U|0)!=0){_=U;break}$=c[Z+16>>2]|0;aa=Z+12|0;ba=0;while(1){if(!(ba>>>0<$>>>0)){_=0;break c}if((c[(c[aa>>2]|0)+(ba<<2)>>2]|0)==(w|0)){break}else{ba=ba+1|0}}if((Z|0)==0){G=P;H=Q;I=R;J=S;K=V;L=W;break a}ba=Z+40|0;aa=c[ba>>2]|0;$=c[ba+4>>2]|0;if((aa|0)==0&($|0)==(-2147483648|0)|(($|0)>(N|0)|($|0)==(N|0)&aa>>>0>M>>>0)){c[ba>>2]=M;c[ba+4>>2]=N}ba=Z+48|0;aa=c[ba+4>>2]|0;if(!((aa|0)<(X|0)|(aa|0)==(X|0)&(c[ba>>2]|0)>>>0<Y>>>0)){U=Z;T=0;continue b}c[ba>>2]=Y;c[ba+4>>2]=X;U=Z;T=0;continue b}}while(0);Z=T+1|0;if(Z>>>0<C>>>0){U=_;T=Z}else{G=P;H=Q;I=R;J=S;K=V;L=W;break}}}}while(0);E=B+56|0;D=c[E>>2]|0;T=c[E+4>>2]|0;if((D|0)==0&(T|0)==(-2147483648|0)){ca=s;da=t}else{c[k>>2]=1;c[l>>2]=1e6;E=KDb(D,T,B+40|0,f)|0;T=F;D=(s|0)>(T|0)|(s|0)==(T|0)&t>>>0>E>>>0;ca=D?s:T;da=D?t:E}E=w+1|0;if(E>>>0<(c[g>>2]|0)>>>0){s=ca;t=da;u=K;v=L;w=E;x=I;y=J;z=G;A=H}else{break}}do{if((H|0)==(-1|0)&(G|0)==2147483647){ea=I;fa=J}else{A=(G|0)>(I|0)|(G|0)==(I|0)&H>>>0>J>>>0;z=ZGb(H,G,J,I)|0;y=F;x=0;w=A&((y|0)<(x|0)|(y|0)==(x|0)&z>>>0<1e6>>>0);if(w|A^1){ea=w?I:G;fa=w?J:H;break}yDb(a,40,2312304,(w=i,i=i+8|0,h[w>>3]=(+(J>>>0)+ +(I|0)*4294967296.0)/1.0e6,w)|0);i=w;ea=G;fa=H}}while(0);do{if((fa|0)==(-1|0)&(ea|0)==2147483647){ga=ca;ha=da}else{w=a+1056|0;c[w>>2]=fa;c[w+4>>2]=ea;if((L|0)==0&(K|0)==(-2147483648|0)){ga=ca;ha=da;break}w=c[a+1104>>2]|0;if((w|0)==0){A=ZGb(L,K,fa,ea)|0;z=F;x=(ca|0)>(z|0)|(ca|0)==(z|0)&da>>>0>A>>>0;ga=x?ca:z;ha=x?da:A;break}A=c[a+1108>>2]|0;x=ca;z=da;y=0;while(1){v=c[A+(y<<2)>>2]|0;u=v+40|0;t=c[u>>2]|0;s=c[u+4>>2]|0;do{if((t|0)==0&(s|0)==(-2147483648|0)){ia=x;ja=z}else{u=v+48|0;l=c[u>>2]|0;k=c[u+4>>2]|0;if(!((k|0)>(s|0)|(k|0)==(s|0)&l>>>0>t>>>0)){ia=x;ja=z;break}u=ZGb(l,k,t,s)|0;k=F;l=(x|0)>(k|0)|(x|0)==(k|0)&z>>>0>u>>>0;ia=l?x:k;ja=l?z:u}}while(0);s=y+1|0;if(s>>>0<w>>>0){x=ia;z=ja;y=s}else{ga=ia;ha=ja;break}}}}while(0);y=0;if(!((ga|0)>(y|0)|(ga|0)==(y|0)&ha>>>0>0>>>0)){break}y=a+1064|0;if(!((c[y>>2]|0)==0&(c[y+4>>2]|0)==(-2147483648|0))){break}c[y>>2]=ha;c[y+4>>2]=ga}}while(0);ga=c[a+16>>2]|0;if((ga|0)==0){i=b;return}ha=Wy(ga)|0;ga=F;ja=0;if(!((ga|0)>(ja|0)|(ga|0)==(ja|0)&ha>>>0>0>>>0)){i=b;return}ja=a+1064|0;ia=c[ja>>2]|0;da=c[ja+4>>2]|0;if((ia|0)==0&(da|0)==(-2147483648|0)){i=b;return}ka=(+(ha>>>0)+ +(ga|0)*4294967296.0)*8.0*1.0e6/(+(ia>>>0)+ +(da|0)*4294967296.0);if(!(ka>=0.0&ka<=2147483647.0)){i=b;return}c[a+1072>>2]=~~ka;i=b;return}function kU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;e=i;i=i+168|0;f=e|0;g=e+80|0;h=e+160|0;j=f;TGb(j|0,0,80)|0;TGb(g|0,0,80)|0;k=c[(c[a+28>>2]|0)+(d<<2)>>2]|0;do{if((b|0)==0){vZ(g);l=g;m=1;n=0;o=0}else{d=c[b+24>>2]|0;p=c[b+28>>2]|0;if((p|0)!=0){l=b;m=0;n=p;o=d;break}p=c[k+240>>2]|0;if((c[p+176>>2]&1|0)==0){l=b;m=0;n=0;o=d;break}lU(a,k,p,b);l=b;m=0;n=0;o=d}}while(0);b=k+240|0;d=k+8|0;p=f+24|0;q=f+28|0;r=l+8|0;s=l+16|0;t=l+64|0;u=(l|0)==(g|0);g=l+40|0;v=f+48|0;w=h|0;x=h+4|0;y=k+40|0;z=k|0;A=f+32|0;B=f+8|0;C=f+16|0;D=f+64|0;E=k+236|0;F=l+36|0;G=f+36|0;H=l+24|0;I=l+28|0;J=l|0;K=f|0;L=l+52|0;M=f+52|0;N=a+1264|0;O=a+1268|0;P=f+40|0;Q=l+44|0;R=f+44|0;S=m;m=0;T=n;n=o;a:while(1){if(u){o=S;U=T;V=n;while(1){if((U|0)<1&(o|0)==0){W=38;break a}vZ(f);X=TRa(c[b>>2]|0,c[d>>2]|0,p,q,V,U,c[r>>2]|0,c[r+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0)|0;c[s>>2]=0;c[s+4>>2]=-2147483648;c[r>>2]=0;c[r+4>>2]=-2147483648;c[t>>2]=-1;c[t+4>>2]=-1;Y=V+X|0;Z=U-X|0;X=(c[q>>2]|0)!=0;_=X&1;if(X){$=Y;aa=Z;ba=_;break}else{o=_;U=Z;V=Y}}}else{V=T;U=n;while(1){if((V|0)<=0){W=38;break a}vZ(f);o=TRa(c[b>>2]|0,c[d>>2]|0,p,q,U,V,c[r>>2]|0,c[r+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0)|0;c[s>>2]=0;c[s+4>>2]=-2147483648;c[r>>2]=0;c[r+4>>2]=-2147483648;c[t>>2]=-1;c[t+4>>2]=-1;Y=U+o|0;Z=V-o|0;if((c[q>>2]|0)==0){V=Z;U=Y}else{$=Y;aa=Z;ba=1;break}}}U=c[g>>2]|0;if((U|0)!=0){c[P>>2]=U;c[R>>2]=c[Q>>2];c[g>>2]=0;c[Q>>2]=0}c[v>>2]=0;U=c[d>>2]|0;do{if((c[U+8>>2]|0)==1){V=U+412|0;if((c[V>>2]|0)<=0){break}Z=c[(c[b>>2]|0)+304>>2]|0;c[w>>2]=1;c[x>>2]=c[V>>2];V=JDb(Z,(Z|0)<0|0?-1:0,h,y,2)|0;c[v>>2]=V}else{V=U+104|0;if((c[V>>2]|0)==0){break}if((c[U+108>>2]|0)==0){break}Z=c[(c[b>>2]|0)+304>>2]|0;Y=JDb(Z,(Z|0)<0|0?-1:0,V,y,2)|0;c[v>>2]=Y}}while(0);c[A>>2]=c[z>>2];U=c[b>>2]|0;Y=U+40|0;V=c[Y+4>>2]|0;c[B>>2]=c[Y>>2];c[B+4>>2]=V;V=U+48|0;Y=c[V+4>>2]|0;c[C>>2]=c[V>>2];c[C+4>>2]=Y;Y=U+288|0;V=c[Y+4>>2]|0;c[D>>2]=c[Y>>2];c[D+4>>2]=V;if((c[E>>2]|0)==1463898624){V=U+8|0;Y=c[V+4>>2]|0;c[D>>2]=c[V>>2];c[D+4>>2]=Y}Y=U+224|0;V=c[Y>>2]|0;if((V|0)==(-1|0)){if((c[U+32>>2]|0)==1){W=24}else{W=25}}else if((V|0)==1){W=24}if((W|0)==24){W=0;c[G>>2]=c[G>>2]|1;if((c[Y>>2]|0)==-1){W=25}}do{if((W|0)==25){W=0;if((c[U+32>>2]|0)!=0){break}if((c[F>>2]&1|0)==0){break}c[G>>2]=c[G>>2]|1}}while(0);lU(a,k,U,f);do{if((c[p>>2]|0)==(c[H>>2]|0)){if((c[q>>2]|0)!=(c[I>>2]|0)){break}c[K>>2]=c[J>>2];c[J>>2]=0;c[M>>2]=c[L>>2];c[L>>2]=0}}while(0);U=CZ(f)|0;if((U|0)<0){ca=U;W=40;break}Y=cEb(88)|0;V=Y;if((Y|0)==0){W=37;break}if((c[N>>2]|0)==0){c[N>>2]=V}else{c[(c[O>>2]|0)+80>>2]=V}c[O>>2]=V;UGb(Y|0,j|0,80)|0;S=ba;m=U;T=aa;n=$}if((W|0)==37){BZ(f);ca=-12;BZ(l);i=e;return ca|0}else if((W|0)==38){if(!u){ca=m;BZ(l);i=e;return ca|0}VRa(c[b>>2]|0);c[b>>2]=0;ca=m;BZ(l);i=e;return ca|0}else if((W|0)==40){BZ(l);i=e;return ca|0}return 0}function lU(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;h=i;i=i+152|0;j=h|0;k=h+32|0;l=h+64|0;m=h+96|0;n=h+128|0;o=h+136|0;p=h+144|0;q=p;r=i;i=i+8|0;s=e+8|0;t=c[s>>2]|0;u=c[t+48>>2]|0;v=b+1084|0;if((c[v>>2]&16|0)!=0){i=h;return}do{if((c[t+8>>2]|0)==0){w=g+16|0;x=c[w>>2]|0;y=c[w+4>>2]|0;if((x|0)==0&(y|0)==(-2147483648|0)){break}z=g+8|0;A=e+640|0;do{if((x|0)==(c[z>>2]|0)&(y|0)==(c[z+4>>2]|0)){B=c[A>>2]|0;C=c[A+4>>2]|0;if((B|0)==0&(C|0)==(-2147483648|0)){break}if((C|0)>(y|0)|(C|0)==(y|0)&B>>>0>x>>>0){D=e+649|0;yDb(b,(a[D]|0)!=0?48:24,2277280,(E=i,i=i+32|0,c[E>>2]=x,c[E+8>>2]=y,c[E+16>>2]=B,c[E+24>>2]=C,E)|0);i=E;C=(a[D]|0)+1&255;a[D]=C;G=a[e+648|0]|0;H=C}else{C=e+648|0;D=(a[C]|0)+1&255;a[C]=D;G=D;H=a[e+649|0]|0}D=e+649|0;if(((H&255)+(G&255)|0)<=250){break}a[e+648|0]=(G&255)>>>1;a[D]=(d[D]|0)>>>1}}while(0);y=c[w+4>>2]|0;c[A>>2]=c[w>>2];c[A+4>>2]=y;if(!((d[e+648|0]|0)>>>0<d[e+649|0]<<3>>>0)){break}if(!((c[w>>2]|0)==(c[z>>2]|0)&(c[w+4>>2]|0)==(c[z+4>>2]|0))){break}c[w>>2]=0;c[w+4>>2]=-2147483648}}while(0);do{if((c[v>>2]&8|0)!=0){G=g+8|0;if((c[G>>2]|0)==0&(c[G+4>>2]|0)==(-2147483648|0)){break}G=g+16|0;c[G>>2]=0;c[G+4>>2]=-2147483648}}while(0);v=(f|0)!=0;a:do{if(v){G=f+32|0;H=(c[s>>2]|0)+176|0;t=c[H>>2]|0;y=(t|0)==0;do{if((c[G>>2]|0)==3){if(!y){I=t;break}c[H>>2]=1;I=1}else{if(y){J=0;K=0;L=1;M=0;break a}else{I=t}}}while(0);J=(c[G>>2]|0)!=3|0;K=I;L=0;M=0}else{t=c[(c[s>>2]|0)+176>>2]|0;J=0;K=t;L=(t|0)==0;M=1}}while(0);I=g+8|0;t=c[I>>2]|0;y=c[I+4>>2]|0;do{if((t|0)==0&(y|0)==(-2147483648|0)){N=-2147483648;O=0}else{H=g+16|0;w=c[H>>2]|0;z=c[H+4>>2]|0;if((w|0)==0&(z|0)==(-2147483648|0)){N=y;O=t;break}A=c[e+188>>2]|0;if((A|0)>=63){N=y;O=t;break}x=_Gb(1,0,A-1|0)|0;D=ZGb(w,z,x,F)|0;x=F;if(!((x|0)>(y|0)|(x|0)==(y|0)&D>>>0>t>>>0)){N=y;O=t;break}C=e+208|0;B=c[C>>2]|0;P=c[C+4>>2]|0;C=2147352575;Q=_Gb(1,0,A|0)|0;A=F;if((P|0)>(C|0)|(P|0)==(C|0)&B>>>0>-1>>>0|((x|0)>(P|0)|(x|0)==(P|0)&D>>>0>B>>>0)){B=ZGb(w,z,Q,A)|0;c[H>>2]=B;c[H+4>>2]=F;N=y;O=t;break}else{H=YGb(Q,A,t,y)|0;A=F;c[I>>2]=H;c[I+4>>2]=A;N=A;O=H;break}}}while(0);y=(K|0)==1;do{if(y){t=g+16|0;H=c[t>>2]|0;A=c[t+4>>2]|0;if((H|0)!=(O|0)|(A|0)!=(N|0)|(H|0)==0&(A|0)==(-2147483648|0)|(J|0)==0){break}yDb(b,48,2276184,(E=i,i=i+16|0,c[E>>2]=O,c[E+8>>2]=N,E)|0);i=E;A=c[c[b+4>>2]>>2]|0;if((QGb(A,2275368)|0)==0){break}if((QGb(A,2271304)|0)==0){break}c[t>>2]=0;c[t+4>>2]=-2147483648}}while(0);N=g+48|0;c[r>>2]=c[N>>2];c[r+4>>2]=1;O=e+40|0;jFb(p,r,O);r=c[N>>2]|0;if((r|0)==0){fT(n,o,e,f,g);t=c[o>>2]|0;do{if((t|0)==0){R=40}else{o=c[n>>2]|0;if((o|0)==0){R=40;break}c[p>>2]=o;c[q+4>>2]=t;A=c[e+44>>2]|0;H=gHb(A,(A|0)<0|0?-1:0,o,(o|0)<0|0?-1:0)|0;o=F;A=c[O>>2]|0;Q=gHb(A,(A|0)<0|0?-1:0,t,(t|0)<0|0?-1:0)|0;A=HDb(1,0,H,o,Q,F,2)|0;Q=A;c[N>>2]=Q;S=Q}}while(0);if((R|0)==40){S=c[N>>2]|0}if((S|0)!=0){T=S;R=42}}else{T=r;R=42}b:do{if((R|0)==42){r=c[b+1236>>2]|0;S=(r|0)==0;if(S){if((c[b+1264>>2]|0)==0){break}}t=c[g+32>>2]|0;p=j|0;n=k|0;Q=l|0;A=m|0;if(S){U=c[b+1264>>2]|0}else{U=r}o=e+200|0;H=c[o>>2]|0;B=c[o+4>>2]|0;c:do{if((H|0)==0&(B|0)==(-2147483648|0)){z=e+208|0;if((c[z>>2]|0)==(-1|0)&(c[z+4>>2]|0)==2147418111){V=2147418111;W=-1;X=U}else{break b}}else{z=e+476|0;if((c[z>>2]|0)!=0){break b}c[z>>2]=1;d:do{if((U|0)!=0){z=T;w=(T|0)<0|0?-1:0;D=b+1240|0;P=b+1264|0;x=U;C=B;Y=H;while(1){if((c[x+32>>2]|0)==(t|0)){Z=x+8|0;_=x+16|0;$=c[_>>2]|0;aa=c[_+4>>2]|0;if(!((c[Z>>2]|0)==($|0)&(c[Z+4>>2]|0)==(aa|0)&(($|0)==0&(aa|0)==(-2147483648|0)))){ba=aa;ca=$;break}if((c[x+48>>2]|0)!=0){ba=-2147483648;ca=0;break}$=ZGb(Y,C,z,w)|0;da=F;ea=$}else{da=C;ea=Y}$=c[x+80>>2]|0;if(($|0)!=0){x=$;C=da;Y=ea;continue}if((c[D>>2]|0)!=(x|0)){break d}$=c[P>>2]|0;if(($|0)==0){break d}else{x=$;C=da;Y=ea}}if((ca|0)==(H|0)&(ba|0)==(B|0)){if(S){fa=c[P>>2]|0}else{fa=r}c[o>>2]=Y;c[o+4>>2]=C;V=C;W=Y;X=fa;break c}TGb(p|0,0,32)|0;a[p]=0;Lb(p|0,32,2265168,(E=i,i=i+16|0,c[E>>2]=H,c[E+8>>2]=B,E)|0)|0;i=E;TGb(n|0,0,32)|0;a[n]=0;D=c[_>>2]|0;w=c[_+4>>2]|0;if((D|0)==0&(w|0)==(-2147483648|0)){Lb(n|0,32,2266248,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0)|0;i=E}else{Lb(n|0,32,2265168,(E=i,i=i+16|0,c[E>>2]=D,c[E+8>>2]=w,E)|0)|0;i=E}TGb(Q|0,0,32)|0;a[Q]=0;w=c[Z>>2]|0;D=c[Z+4>>2]|0;if((w|0)==0&(D|0)==(-2147483648|0)){Lb(Q|0,32,2266248,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0)|0;i=E}else{Lb(Q|0,32,2265168,(E=i,i=i+16|0,c[E>>2]=w,c[E+8>>2]=D,E)|0)|0;i=E}D=c[x+48>>2]|0;yDb(b,48,2268784,(E=i,i=i+32|0,c[E>>2]=p,c[E+8>>2]=n,c[E+16>>2]=Q,c[E+24>>2]=D,E)|0);i=E;break b}}while(0);TGb(A|0,0,32)|0;a[A]=0;Lb(A|0,32,2265168,(E=i,i=i+16|0,c[E>>2]=H,c[E+8>>2]=B,E)|0)|0;i=E;yDb(b,48,2267776,(E=i,i=i+8|0,c[E>>2]=A,E)|0);i=E;break b}}while(0);e:do{if((X|0)==0){ga=V;ha=W}else{A=T;B=(T|0)<0|0?-1:0;H=b+1240|0;Q=b+1264|0;n=X;p=V;r=W;while(1){if((c[n+32>>2]|0)==(t|0)){S=n+8|0;G=c[S>>2]|0;D=c[S+4>>2]|0;w=n+16|0;if(!((G|0)==(c[w>>2]|0)&(D|0)==(c[w+4>>2]|0))){break b}if(!((G|0)==0&(D|0)==(-2147483648|0))){if(!((G|0)==(c[o>>2]|0)&(D|0)==(c[o+4>>2]|0))){break b}}D=n+48|0;if((c[D>>2]|0)!=0){break b}c[w>>2]=r;c[w+4>>2]=p;if((c[(c[s>>2]|0)+176>>2]|0)==0){c[S>>2]=r;c[S+4>>2]=p}c[D>>2]=T;D=YGb(r,p,A,B)|0;ia=F;ja=D}else{ia=p;ja=r}D=c[n+80>>2]|0;if((D|0)!=0){n=D;p=ia;r=ja;continue}if((c[H>>2]|0)!=(n|0)){ga=ia;ha=ja;break e}D=c[Q>>2]|0;if((D|0)==0){ga=ia;ha=ja;break}else{n=D;p=ia;r=ja}}}}while(0);o=e+208|0;c[o>>2]=ha;c[o+4>>2]=ga}}while(0);do{if(v){if((c[e+236>>2]|0)!=3){break}ga=c[g+28>>2]|0;if((ga|0)==0){break}ha=f+184|0;ja=c[N>>2]|0;ia=IDb(c[ha>>2]|0,c[ha+4>>2]|0,ja,(ja|0)<0|0?-1:0,ga,(ga|0)<0|0?-1:0)|0;ga=F;ja=c[I>>2]|0;ha=c[I+4>>2]|0;if(!((ja|0)==0&(ha|0)==(-2147483648|0))){T=YGb(ja,ha,ia,ga)|0;c[I>>2]=T;c[I+4>>2]=F}T=g+16|0;ha=c[T>>2]|0;ja=c[T+4>>2]|0;if((ha|0)==0&(ja|0)==(-2147483648|0)){break}W=YGb(ha,ja,ia,ga)|0;c[T>>2]=W;c[T+4>>2]=F}}while(0);T=g+16|0;W=c[T>>2]|0;ga=c[T+4>>2]|0;ia=(W|0)==0&(ga|0)==(-2147483648|0);if(ia){ka=J}else{ja=c[I>>2]|0;ha=c[I+4>>2]|0;ka=((ja|0)!=0|(ha|0)!=(-2147483648|0))&((ha|0)>(ga|0)|(ha|0)==(ga|0)&ja>>>0>W>>>0)?1:J}do{if(L){if(!((u|0)==1211250229|(u|0)==28)){R=97}}else{if(M|y^1){break}if(!((u|0)==1211250229|(u|0)==28)){R=97}}}while(0);do{if((R|0)==97){if((ka|0)==0){y=c[I>>2]|0;M=c[I+4>>2]|0;if((y|0)==0&(M|0)==(-2147483648|0)){if(ia){if((c[N>>2]|0)==0){break}}c[I>>2]=W;c[I+4>>2]=ga;la=ga;ma=W}else{la=M;ma=y}mU(b,c[g+32>>2]|0,ma,la,ma,la);y=c[I>>2]|0;M=c[I+4>>2]|0;if((y|0)==0&(M|0)==(-2147483648|0)){L=e+208|0;J=c[L>>2]|0;ja=c[L+4>>2]|0;c[I>>2]=J;c[I+4>>2]=ja;c[T>>2]=J;c[T+4>>2]=ja;if((J|0)==0&(ja|0)==(-2147483648|0)){break}else{na=ja;oa=J}}else{c[T>>2]=y;c[T+4>>2]=M;na=M;oa=y}y=ODb(O,oa,na,q,1,0)|0;M=e+208|0;c[M>>2]=y;c[M+4>>2]=F;break}if(ia){M=e+216|0;y=c[M>>2]|0;J=c[M+4>>2]|0;c[T>>2]=y;c[T+4>>2]=J;pa=J;qa=y}else{pa=ga;qa=W}mU(b,c[g+32>>2]|0,qa,pa,c[I>>2]|0,c[I+4>>2]|0);y=c[T>>2]|0;J=c[T+4>>2]|0;if((y|0)==0&(J|0)==(-2147483648|0)){M=e+208|0;ja=c[M>>2]|0;L=c[M+4>>2]|0;c[T>>2]=ja;c[T+4>>2]=L;ra=L;sa=ja}else{ra=J;sa=y}y=e+224|0;J=c[y>>2]|0;if((J|0)==0){ja=c[N>>2]|0;c[y>>2]=ja;ta=ja}else{ta=J}if(!((sa|0)==0&(ra|0)==(-2147483648|0))){J=YGb(ta,(ta|0)<0|0?-1:0,sa,ra)|0;ja=e+208|0;c[ja>>2]=J;c[ja+4>>2]=F}c[y>>2]=c[N>>2];y=c[I+4>>2]|0;ja=e+216|0;c[ja>>2]=c[I>>2];c[ja+4>>2]=y}}while(0);f:do{if(((c[I>>2]|0)!=0|(c[I+4>>2]|0)!=(-2147483648|0))&(K|0)<17){N=c[s>>2]|0;g:do{if((c[N+48>>2]|0)==28){if((c[e+184>>2]|0)==0){break}do{if((c[N+176>>2]|0)!=0){ra=Mca(N)|0;sa=c[(c[s>>2]|0)+176>>2]|0;if((ra|0)==(sa|0)){break g}if((sa|0)<3){break}ra=c[e+452>>2]|0;if((sa|0)<4){if((ra|0)>17){break g}else{break f}}else{if((ra|0)>19){break g}else{break f}}}}while(0);if((c[e+452>>2]|0)<=6){break f}}}while(0);N=c[I>>2]|0;ra=c[I+4>>2]|0;sa=e+264|0;c[sa>>2]=N;c[sa+4>>2]=ra;h:do{if((K|0)>0){ta=0;while(1){pa=ta+1|0;qa=e+264+(pa<<3)|0;W=c[qa>>2]|0;ga=c[qa+4>>2]|0;if(!((ra|0)>(ga|0)|(ra|0)==(ga|0)&N>>>0>W>>>0)){break h}ia=e+264+(ta<<3)|0;c[qa>>2]=N;c[qa+4>>2]=ra;c[ia>>2]=W;c[ia+4>>2]=ga;if((pa|0)<(K|0)){ta=pa}else{break}}}}while(0);ra=nU(e,sa,c[T>>2]|0,c[T+4>>2]|0)|0;c[T>>2]=ra;c[T+4>>2]=F}}while(0);if((u|0)==1211250229|(u|0)==28){mU(b,c[g+32>>2]|0,c[T>>2]|0,c[T+4>>2]|0,c[I>>2]|0,c[I+4>>2]|0)}I=c[T>>2]|0;b=c[T+4>>2]|0;T=e+208|0;e=c[T+4>>2]|0;if((b|0)>(e|0)|(b|0)==(e|0)&I>>>0>(c[T>>2]|0)>>>0){c[T>>2]=I;c[T+4>>2]=b}b=c[s>>2]|0;do{if((c[b+8>>2]|0)==0){s=g0a(b)|0;if((s|0)==0){T=g0(c[b+48>>2]|0)|0;h0a(b,T);if((T|0)==0){break}else{ua=T}}else{ua=s}if((c[ua+16>>2]&1|0)!=0){R=137}}else{R=137}}while(0);if((R|0)==137){R=g+36|0;c[R>>2]=c[R>>2]|1}if(!v){i=h;return}v=f+232|0;f=c[v+4>>2]|0;R=g+72|0;c[R>>2]=c[v>>2];c[R+4>>2]=f;i=h;return}function mU(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+136|0;j=h|0;k=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;l=c[a+1236>>2]|0;if((l|0)==0){m=c[a+1264>>2]|0}else{m=l}l=k+200|0;if((c[l>>2]|0)!=0|(c[l+4>>2]|0)!=(-2147483648|0)|(d|0)==0&(e|0)==(-2147483648|0)){i=h;return}n=k+208|0;o=c[n>>2]|0;p=c[n+4>>2]|0;q=2147352575;if((o|0)==0&(p|0)==(-2147483648|0)|((e|0)>(q|0)|(e|0)==(q|0)&d>>>0>-1>>>0)){i=h;return}q=k+8|0;r=c[(c[q>>2]|0)+176>>2]|0;s=YGb(d,e,-1,2147418111)|0;t=ZGb(s,F,o,p)|0;p=F;c[l>>2]=t;c[l+4>>2]=p;c[n>>2]=d;c[n+4>>2]=e;e=j|0;c[e>>2]=0;c[e+4>>2]=-2147483648;n=j+8|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+16|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+24|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+32|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+40|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+48|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+56|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+64|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+72|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+80|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+88|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+96|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+104|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+112|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+120|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+128|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=YGb(t,p,1,-2147418112)|0;p=F;t=2147352576;d=(g|0)<(t|0)|(g|0)==(t|0)&f>>>0<0>>>0;t=YGb(d?0:n,d?0:p,f,g)|0;g=F;f=k+48|0;a:do{if((m|0)!=0){d=(r|0)<17;l=k+184|0;o=k+452|0;s=(r|0)>0;u=a+1240|0;v=a+1264|0;w=m;while(1){b:do{if((c[w+32>>2]|0)==(b|0)){x=w+8|0;y=c[x>>2]|0;z=c[x+4>>2]|0;A=2147352575;if((z|0)>(A|0)|(z|0)==(A|0)&y>>>0>-1>>>0){A=YGb(y,z,n,p)|0;B=F;c[x>>2]=A;c[x+4>>2]=B;C=B;D=A}else{C=z;D=y}y=w+16|0;z=c[y>>2]|0;A=c[y+4>>2]|0;B=2147352575;if((A|0)>(B|0)|(A|0)==(B|0)&z>>>0>-1>>>0){B=YGb(z,A,n,p)|0;c[y>>2]=B;c[y+4>>2]=F}if((c[f>>2]|0)==0&(c[f+4>>2]|0)==(-2147483648|0)){if((D|0)==0&(C|0)==(-2147483648|0)){break}c[f>>2]=D;c[f+4>>2]=C;E=c[x+4>>2]|0;G=c[x>>2]|0}else{E=C;G=D}if(!(((G|0)!=0|(E|0)!=(-2147483648|0))&d)){break}B=c[q>>2]|0;c:do{if((c[B+48>>2]|0)==28){if((c[l>>2]|0)==0){break}do{if((c[B+176>>2]|0)!=0){A=Mca(B)|0;z=c[(c[q>>2]|0)+176>>2]|0;if((A|0)==(z|0)){break c}if((z|0)<3){break}A=c[o>>2]|0;if((z|0)<4){if((A|0)>17){break c}else{break b}}else{if((A|0)>19){break c}else{break b}}}}while(0);if((c[o>>2]|0)<=6){break b}}}while(0);B=c[x>>2]|0;A=c[x+4>>2]|0;c[e>>2]=B;c[e+4>>2]=A;d:do{if(s){z=0;while(1){H=z+1|0;I=j+(H<<3)|0;J=c[I>>2]|0;K=c[I+4>>2]|0;if(!((A|0)>(K|0)|(A|0)==(K|0)&B>>>0>J>>>0)){break d}L=j+(z<<3)|0;c[I>>2]=B;c[I+4>>2]=A;c[L>>2]=J;c[L+4>>2]=K;if((H|0)<(r|0)){z=H}else{break}}}}while(0);A=nU(k,e,c[y>>2]|0,c[y+4>>2]|0)|0;c[y>>2]=A;c[y+4>>2]=F}}while(0);A=c[w+80>>2]|0;if((A|0)!=0){w=A;continue}if((c[u>>2]|0)!=(w|0)){break a}w=c[v>>2]|0;if((w|0)==0){break}}}}while(0);if(!((c[f>>2]|0)==0&(c[f+4>>2]|0)==(-2147483648|0))){i=h;return}c[f>>2]=t;c[f+4>>2]=g;i=h;return}function nU(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;h=c[b+8>>2]|0;i=c[h+48>>2]|0;do{if((i|0)==1211250229|(i|0)==28){j=c[h+176>>2]|0;k=(j|0)>0;if((f|0)==0&(g|0)==(-2147483648|0)){if(k){l=0;m=2147483647;n=-1;o=-2147483648;p=0}else{break}while(1){q=a[b+616+l|0]|0;do{if(q<<24>>24==0){r=o;s=p;t=m;u=n}else{v=b+480+(l<<3)|0;w=eHb(c[v>>2]|0,c[v+4>>2]|0,q&255,0)|0;v=F;if(!((v|0)<(m|0)|(v|0)==(m|0)&w>>>0<n>>>0)){r=o;s=p;t=m;u=n;break}x=e+(l<<3)|0;r=c[x+4>>2]|0;s=c[x>>2]|0;t=v;u=w}}while(0);q=l+1|0;if((q|0)<(j|0)){l=q;m=t;n=u;o=r;p=s}else{y=r;z=s;A=13;break}}}else{if(k){B=0}else{y=g;z=f;A=13;break}while(1){q=e+(B<<3)|0;w=c[q>>2]|0;v=c[q+4>>2]|0;do{if(!((w|0)==0&(v|0)==(-2147483648|0))){q=ZGb(w,v,f,g)|0;x=F;C=-1;D=(x|0)>(C|0)|(x|0)==(C|0)&q>>>0>-1>>>0;C=ZGb(0,0,q,x)|0;E=b+480+(B<<3)|0;G=c[E>>2]|0;H=c[E+4>>2]|0;I=YGb(G,H,D?q:C,D?x:F)|0;x=F;D=(x|0)>(H|0)|(x|0)==(H|0)&I>>>0>G>>>0;c[E>>2]=D?I:G;c[E+4>>2]=D?x:H;H=b+616+B|0;x=(a[H]|0)+1&255;a[H]=x;if(!((x&255)>>>0>250>>>0)){break}x=c[E+4>>2]|0;c[E>>2]=(c[E>>2]|0)>>>1|x<<31;c[E+4>>2]=x>>1|((x|0)<0|0?-1:0)<<31;a[H]=(d[H]|0)>>>1}}while(0);v=B+1|0;if((v|0)<(j|0)){B=v}else{y=g;z=f;A=13;break}}}}else{y=g;z=f;A=13}}while(0);do{if((A|0)==13){if((z|0)==0&(y|0)==(-2147483648|0)){break}else{J=y;K=z}return(F=J,K)|0}}while(0);J=c[e+4>>2]|0;K=c[e>>2]|0;return(F=J,K)|0}function oU(b){b=b|0;var e=0;if((c[b+8>>2]|0)<24){return 0}e=c[b+4>>2]|0;if(!((a[e+3|0]|0)==-59)){return 0}b=e+4|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==4){b=e+20|0;return((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==12?50:0)|0}else{return 0}return 0}function pU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+16>>2]|0;e=qz(d)|0;if((lz(d)|0)!=197){f=-1;i=b;return f|0}if((rz(d)|0)!=4){f=-1;i=b;return f|0}g=LT(a,0)|0;if((g|0)==0){f=-1;i=b;return f|0}h=g+8|0;j=c[h>>2]|0;c[j+8>>2]=0;c[j+48>>2]=72;if((CT(j,d,4)|0)<0){f=-12;i=b;return f|0}j=rz(d)|0;c[(c[h>>2]|0)+124>>2]=j;j=rz(d)|0;c[(c[h>>2]|0)+120>>2]=j;if((rz(d)|0)!=12){f=-1;i=b;return f|0}Vy(d,8,0)|0;j=rz(d)|0;if((j|0)==(-1|0)){MT(g,32,1,1e3);f=0;i=b;return f|0}else if((j|0)==0){yDb(a,16,2122880,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=1}else{k=j}MT(g,24,1,k);k=g+56|0;c[k>>2]=e;c[k+4>>2]=(e|0)<0|0?-1:0;f=0;i=b;return f|0}function qU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+16>>2]|0;if((Xy(d)|0)!=0){e=-5;return e|0}f=qz(d)|0;g=(lz(d)|0)>>>7&1;h=rz(d)|0;if((TS(d,b,f)|0)<0){e=-5;return e|0}if((c[(c[c[a+28>>2]>>2]|0)+44>>2]|0)==1e3){a=b+8|0;c[a>>2]=h;c[a+4>>2]=0}a=b+36|0;c[a>>2]=c[a>>2]|g;g=b+64|0;a=YGb(c[g>>2]|0,c[g+4>>2]|0,-8,-1)|0;c[g>>2]=a;c[g+4>>2]=F;e=c[b+28>>2]|0;return e|0}function rU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+28|0;e=c[(c[c[d>>2]>>2]|0)+8>>2]|0;f=c[a+16>>2]|0;if((c[e+48>>2]|0)!=72){yDb(a,16,2062072,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-1;i=b;return g|0}gz(f,0);Py(f,197);Yy(f,4);Ry(f,c[e+96>>2]|0,4);Yy(f,c[e+124>>2]|0);Yy(f,c[e+120>>2]|0);Yy(f,12);gz(f,0);Py(f,128);Yy(f,0);e=c[c[d>>2]>>2]|0;a=c[e+96>>2]|0;do{if((a|0)==0){h=6}else{if((c[e+92>>2]|0)!=1){h=6;break}Yy(f,a)}}while(0);if((h|0)==6){Yy(f,-1)}MT(c[c[d>>2]>>2]|0,32,1,1e3);g=0;i=b;return g|0}function sU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[a+16>>2]|0;e=b+28|0;f=c[e>>2]|0;if((f|0)==0){return 0}g=c[a+12>>2]|0;Yy(d,c[b+36>>2]<<31|f);Yy(d,c[b+8>>2]|0);Ry(d,c[b+24>>2]|0,c[e>>2]|0);e=g;c[e>>2]=(c[e>>2]|0)+1;return 0}function tU(a){a=a|0;var b=0,d=0;b=c[a+16>>2]|0;if((c[b+88>>2]|0)==0){return 0}d=c[a+12>>2]|0;Ty(b,0,0,0)|0;gz(b,c[d>>2]|0);Sy(b);return 0}function uU(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[b+4>>2]|0;do{if((a[e]|0)==0){b=e+2|0;f=d[e+1|0]|0;g=f&127;if((f&128|0)==0){h=g;i=f;j=b}else{f=d[b]|0;h=f&127|g<<7;i=f;j=e+3|0}if((i&128|0)!=0){break}if((h-21|0)>>>0>1003>>>0){break}if((PGb(j,2179568,15)|0)==0){k=100}else{break}return k|0}}while(0);k=0;return k|0}function vU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[b+12>>2]|0;h=LT(b,0)|0;j=LT(b,0)|0;if((j|0)==0|(h|0)==0){k=-12;i=d;return k|0}l=j+8|0;c[(c[l>>2]|0)+412>>2]=8e3;m=xU(b)|0;if((m|0)<0){k=m;i=d;return k|0}m=g+8|0;n=g+4|0;o=g+12|0;p=b;q=b+16|0;r=g+16|0;s=h+8|0;t=f|0;u=f+4|0;v=b+1140|0;w=1;x=25;y=0;z=0;a:while(1){while(1){if((c[m>>2]|0)!=0){A=39;break a}if((c[n>>2]|0)!=0){A=39;break a}B=c[o>>2]|0;if((B|0)<1025){break}yDb(p,24,1974584,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;D=c[o>>2]|0;Vy(c[q>>2]|0,D,(D|0)<0|0?-1:0)|0;D=xU(b)|0;if((D|0)<0){k=D;A=45;break a}}mz(c[q>>2]|0,r,B)|0;a[g+((c[o>>2]|0)+16)|0]=0;b:do{if((a[r]|0)==0){E=w;G=x;H=y;I=z}else{D=r;J=w;K=x;L=y;M=z;while(1){N=D;while(1){O=yb(N|0,1945984)|0;if((O|0)==0){E=J;G=K;H=L;I=M;break b}a[O]=0;P=O+2|0;if((O|0)!=(N|0)){Q=Vb(N|0,58)|0;if((Q|0)!=0){break}yDb(p,24,1920976,(C=i,i=i+8|0,c[C>>2]=0,C)|0);i=C}if((a[P]|0)==0){E=J;G=K;H=L;I=M;break b}else{N=P}}O=Q+1|0;a[Q]=0;yDb(p,48,1899704,(C=i,i=i+16|0,c[C>>2]=N,c[C+8>>2]=O,C)|0);i=C;R=kb(O|0,e|0,10)|0;do{if((a[c[e>>2]|0]|0)==0){yDb(p,48,1879440,(C=i,i=i+8|0,c[C>>2]=R,C)|0);i=C;if((QGb(N,2337576)|0)==0){S=(R|0)<0|0?-1:0;T=R;U=1;V=K;W=J;break}if((QGb(N,2313200)|0)==0){c[(c[s>>2]|0)+120>>2]=R;S=L;T=M;U=1;V=K;W=J;break}if((QGb(N,2292928)|0)==0){c[(c[s>>2]|0)+124>>2]=R;S=L;T=M;U=1;V=K;W=J;break}if((QGb(N,2276488)|0)==0){S=L;T=M;U=1;V=K;W=(R|0)/1e3|0;break}if((QGb(N,2260784)|0)==0){S=L;T=M;U=1;V=R;W=J;break}if((QGb(N,2246344)|0)==0){c[(c[l>>2]|0)+412>>2]=R;S=L;T=M;U=1;V=K;W=J;break}if((QGb(N,2233672)|0)==0){S=L;T=M;U=1;V=K;W=J;break}S=L;T=M;U=(QGb(N,2220640)|0)==0|0;V=K;W=J}else{S=L;T=M;U=0;V=K;W=J}}while(0);do{if((QGb(N,2211456)|0)==0){R=xd(O|0,2202392,(C=i,i=i+8|0,c[C>>2]=g,C)|0)|0;i=C;if((R|0)==1){X=V;Y=W}else{k=-1094995529;A=45;break a}}else{if((QGb(N,2195304)|0)==0){if((NEb(f,O,1e4,24,p)|0)!=0){X=V;Y=W;break}X=c[t>>2]|0;Y=c[u>>2]|0;break}else{if((U|0)!=0){X=V;Y=W;break}CBb(v,N,O,0)|0;X=V;Y=W;break}}}while(0);if((a[P]|0)==0){E=Y;G=X;H=S;I=T;break}else{D=P;J=Y;K=X;L=S;M=T}}}}while(0);M=xU(b)|0;if((M|0)<0){k=M;A=45;break}else{w=E;x=G;y=H;z=I}}if((A|0)==39){MT(j,64,1,c[(c[l>>2]|0)+412>>2]|0);MT(h,64,w,x);if(!((z|0)==0&(y|0)==0)){x=IDb(z,y,1e3,0,1,0)|0;y=b+1064|0;c[y>>2]=x;c[y+4>>2]=F}y=h+48|0;c[y>>2]=0;c[y+4>>2]=0;y=c[s>>2]|0;c[y+52>>2]=0;c[y+8>>2]=0;if((c[g>>2]|0)==1){c[y+48>>2]=5;y=c[l>>2]|0;c[y+48>>2]=86069;c[y+792>>2]=8;c[y+432>>2]=24;c[y+72>>2]=6400;Z=y}else{Z=c[l>>2]|0}l=j+48|0;c[l>>2]=0;c[l+4>>2]=0;c[Z+52>>2]=0;c[Z+8>>2]=1;c[Z+416>>2]=1;k=0;i=d;return k|0}else if((A|0)==45){i=d;return k|0}return 0}function wU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=e+8|0;h=c[g>>2]|0;j=e+4|0;k=c[j>>2]|0;l=e+12|0;a:while(1){if((Xy(f)|0)!=0){m=-541478725;n=18;break}o=c[j>>2]|0;switch(o|0){case 3:case 4:{p=1;break a;break};case 0:{break};case 1:case 2:{n=6;break a;break};default:{n=5;break a}}e=c[l>>2]|0;Vy(f,e,(e|0)<0|0?-1:0)|0;e=xU(a)|0;if((e|0)<0){m=e;n=18;break}}if((n|0)==5){yDb(a,16,2062048,(e=i,i=i+8|0,c[e>>2]=o,e)|0);i=e;m=-1094995529;i=d;return m|0}else if((n|0)==6){p=0}else if((n|0)==18){i=d;return m|0}e=TS(f,b,c[l>>2]|0)|0;do{if((e|0)<0){q=e}else{o=xU(a)|0;if((o|0)<0){q=o;break}r=(k-1|0)>>>1;s=o;while(1){if((c[g>>2]|0)!=(h|0)){break}if(((c[j>>2]|0)-1>>1|0)!=(r|0)){break}if((Xy(f)|0)!=0){t=-541478725;n=15;break}o=VS(f,b,c[l>>2]|0)|0;if((o|0)<0){t=o;n=15;break}o=xU(a)|0;if((o|0)<0){t=o;n=15;break}else{s=o}}if((n|0)==15){c[b+32>>2]=p;q=t;break}c[b+32>>2]=p;m=s;i=d;return m|0}}while(0);BZ(b);m=q;i=d;return m|0}function xU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((Xy(e)|0)!=0){f=-541478725;i=b;return f|0}g=lz(e)|0;if((g|0)==130){h=1;j=lz(e)|0}else{h=0;j=g}g=j>>>4;c[d+4>>2]=g;c[d+8>>2]=j&15;switch(g|0){case 4:{c[d+12>>2]=24;k=9;break};case 0:case 2:{break};case 1:{c[d+12>>2]=128;k=9;break};case 3:{c[d+12>>2]=40;k=9;break};default:{yDb(a,16,2062048,(l=i,i=i+8|0,c[l>>2]=g,l)|0);i=l;f=-1094995529;i=b;return f|0}}do{if((k|0)==9){if((h|0)==0){f=0}else{break}i=b;return f|0}}while(0);h=lz(e)|0;k=d+12|0;c[k>>2]=h&127;if((h&128|0)==0){f=0;i=b;return f|0}h=lz(e)|0;c[k>>2]=c[k>>2]<<7|h&127;if((h&128|0)==0){f=0;i=b;return f|0}yDb(a,16,2015520,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;f=-1094995529;i=b;return f|0}function yU(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;g=c[d+8>>2]|0;h=a+16|0;j=c[h>>2]|0;k=c[a+12>>2]|0;do{if((c[k>>2]|0)==0&(c[k+4>>2]|0)==0){l=g+412|0;m=g+416|0;n=g+48|0;o=g+792|0;p=e;q=-1;r=0;s=1;a:while(1){t=p;u=r;v=s;b:while(1){w=t;while(1){x=lz(j)|0;if((x|0)==0){y=-541478725;z=32;break a}A=qz(j)|0;B=A;C=0;c[k>>2]=B;c[k+4>>2]=C;if((A|0)==0){if((c[(c[h>>2]|0)+88>>2]|0)==0){y=-5;z=32;break a}A=Wy(j)|0;D=F;E=Ty(j,0,0,1)|0;G=ZGb(A,D,E,F)|0;E=F;c[k>>2]=G;c[k+4>>2]=E;H=E;I=G}else{H=C;I=B}B=w-4|0;if((x|0)==8){break}else if((x|0)==9){z=15;break b}else if((x|0)==1){z=10;break b}else if((x|0)==2){if((I|0)==0&(H|0)==0){w=B;continue}else{J=B;K=q;z=22;break a}}else{Vy(j,I,H)|0;x=ZGb(B,0,c[k>>2]|0,c[k+4>>2]|0)|0;c[k>>2]=0;c[k+4>>2]=0;w=x;continue}}x=pz(j)|0;lz(j)|0;B=(lz(j)|0)+1|0;C=256e6/(ba(B,65536-x|0)|0)|0;c[k>>2]=0;c[k+4>>2]=0;t=w-8|0;u=C;v=B}if((z|0)==10){z=0;if((c[l>>2]|0)==0){t=1e6/(256-(lz(j)|0)|0)|0;B=(u|0)==0?t:u;c[l>>2]=B;MT(d,64,1,B);c[m>>2]=v;c[o>>2]=u0a(c[n>>2]|0)|0}else{Vy(j,1,0)|0;}B=lz(j)|0;t=YGb(c[k>>2]|0,c[k+4>>2]|0,-2,-1)|0;C=F;c[k>>2]=t;c[k+4>>2]=C;L=1;M=B;N=w-6|0;O=C;P=t}else if((z|0)==15){z=0;if((c[l>>2]|0)==0){t=rz(j)|0;c[l>>2]=t;MT(d,64,1,t);c[o>>2]=lz(j)|0;c[m>>2]=lz(j)|0}else{Vy(j,6,0)|0;}t=pz(j)|0;Vy(j,4,0)|0;C=YGb(c[k>>2]|0,c[k+4>>2]|0,-12,-1)|0;B=F;c[k>>2]=C;c[k+4>>2]=B;L=v;M=t;N=w-16|0;O=B;P=C}if((P|0)==0&(O|0)==0){p=N;q=M;r=u;s=L}else{J=N;K=M;z=22;break}}if((z|0)==22){if(!((K|0)>-1)){Q=J;break}s=vT(1089120,K)|0;r=g+48|0;q=c[r>>2]|0;do{if((q|0)==0){c[r>>2]=s;R=s}else{if((q|0)==(s|0)){R=s;break}yDb(a,24,1883392,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;R=c[r>>2]|0}}while(0);if((R|0)!=0){Q=J;break}r=a;if((c[a+1116>>2]|0)!=0){yDb(r,24,2204304,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;Q=J;break}yDb(r,16,2204304,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;y=-22;i=f;return y|0}else if((z|0)==32){i=f;return y|0}}else{Q=e}}while(0);e=ba(c[g+416>>2]|0,c[g+412>>2]|0)|0;c[g+72>>2]=ba(e,c[g+792>>2]|0)|0;g=(Q|0)<1?2048:Q;Q=c[k>>2]|0;e=c[k+4>>2]|0;z=(g|0)<0|0?-1:0;S=(e|0)>(z|0)|(e|0)==(z|0)&Q>>>0>g>>>0?g:Q;g=ZGb(Q,e,S,(S|0)<0|0?-1:0)|0;c[k>>2]=g;c[k+4>>2]=F;y=TS(j,b,S)|0;i=f;return y|0}function zU(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;if((PGb(b,1089016,20)|0)!=0){e=0;return e|0}a=b+22|0;f=b+24|0;e=(4659-((d[a]|d[a+1|0]<<8)<<16>>16&65535)|0)==((d[f]|d[f+1|0]<<8)<<16>>16&65535|0)?100:10;return e|0}function AU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;Vy(e,20,0)|0;f=(pz(e)|0)-22|0;if((f|0)!=4){yDb(a,16,2015384,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-38;i=b;return h|0}Vy(e,4,0)|0;e=LT(a,0)|0;if((e|0)==0){h=-12;i=b;return h|0}c[(c[e+8>>2]|0)+8>>2]=1;e=d;c[e>>2]=0;c[e+4>>2]=0;h=0;i=b;return h|0}function BU(a,b){a=a|0;b=b|0;return yU(a,b,c[c[a+28>>2]>>2]|0,0)|0}function CU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[a+24>>2]|0)!=1){f=-1163346256;i=b;return f|0}if((c[e+8>>2]|0)!=1){f=-1163346256;i=b;return f|0}do{if((c[e+52>>2]|0)==0){if((c[e+48>>2]|0)==65541){break}yDb(a,16,2061864,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;f=-22;i=b;return f|0}}while(0);Ry(d,1089016,20);az(d,26);az(d,276);az(d,4383);f=0;i=b;return f|0}function DU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;e=c[a+16>>2]|0;f=c[a+12>>2]|0;if((c[f>>2]|0)!=0){Py(e,2);a=b+28|0;gz(e,c[a>>2]|0);g=a;h=b+24|0;i=c[h>>2]|0;j=c[g>>2]|0;Ry(e,i,j);return 0}a=d+52|0;if((c[a>>2]|0)>>>0>3>>>0){Py(e,9);gz(e,(c[b+28>>2]|0)+12|0);Yy(e,c[d+412>>2]|0);Py(e,c[d+792>>2]|0);Py(e,c[d+416>>2]|0);az(e,c[a>>2]|0);Yy(e,0)}else{k=d+416|0;if((c[k>>2]|0)>1){Py(e,8);gz(e,4);l=d+412|0;m=ba(c[k>>2]|0,c[l>>2]|0)|0;az(e,65536-((((m|0)/2|0)+256e6|0)/(m|0)|0)|0);Py(e,c[a>>2]|0);Py(e,(c[k>>2]|0)-1|0);n=l}else{n=d+412|0}Py(e,1);gz(e,(c[b+28>>2]|0)+2|0);d=c[n>>2]|0;Py(e,256-((((d|0)/2|0)+1e6|0)/(d|0)|0)|0);Py(e,c[a>>2]|0)}c[f>>2]=1;g=b+28|0;h=b+24|0;i=c[h>>2]|0;j=c[g>>2]|0;Ry(e,i,j);return 0}function EU(a){a=a|0;Py(c[a+16>>2]|0,0);return 0}function FU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=(SGb(b|0)|0)+8|0;c[d>>2]=0;if((a|0)==0){f=e;return f|0}b=BBb(a,9203024,0,2)|0;if((b|0)==0){f=e;return f|0}else{g=e;h=b}while(1){b=SGb(c[h>>2]|0)|0;e=g+5+b+(SGb(c[h+4>>2]|0)|0)|0;c[d>>2]=(c[d>>2]|0)+1;b=BBb(a,9203024,h,2)|0;if((b|0)==0){f=e;break}else{g=e;h=b}}return f|0}function GU(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=SGb(e|0)|0;h=c[b>>2]|0;x=g;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=(c[b>>2]|0)+4|0;c[b>>2]=h;g=SGb(e|0)|0;UGb(h|0,e|0,g)|0;e=(c[b>>2]|0)+g|0;c[b>>2]=e;g=e;if((c[d>>2]|0)==0){x=0;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[b>>2]=(c[b>>2]|0)+4;return 0}x=f;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[b>>2]=(c[b>>2]|0)+4;g=BBb(c[d>>2]|0,9203024,0,2)|0;if((g|0)==0){return 0}else{i=g}do{g=i|0;f=SGb(c[g>>2]|0)|0;e=i+4|0;h=SGb(c[e>>2]|0)|0;j=c[b>>2]|0;x=f+1+h|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=(c[b>>2]|0)+4|0;c[b>>2]=j;UGb(j|0,c[g>>2]|0,f)|0;g=(c[b>>2]|0)+f|0;c[b>>2]=g;a[g]=61;g=(c[b>>2]|0)+1|0;c[b>>2]=g;UGb(g|0,c[e>>2]|0,h)|0;c[b>>2]=(c[b>>2]|0)+h;i=BBb(c[d>>2]|0,9203024,i,2)|0;}while((i|0)!=0);return 0}function HU(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=xd(c[b+4>>2]|0,1974392,(b=i,i=i+8|0,c[b>>2]=e,b)|0)|0;i=b;do{if((f|0)==1){if((Ib(1945744,a[e]|0,4)|0)==0){break}else{g=100}i=d;return g|0}}while(0);g=0;i=d;return g|0}function IU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+4144|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=c[b+12>>2]|0;n=LT(b,0)|0;if((n|0)==0){o=-12;i=d;return o|0}MT(n,64,1,100);p=c[n+8>>2]|0;c[p+8>>2]=3;c[p+48>>2]=1448111218;p=b+16|0;a:do{if((Xy(c[p>>2]|0)|0)==0){b=l|0;n=m;while(1){q=Ty(c[p>>2]|0,0,0,1)|0;r=F;if((wz(c[p>>2]|0,b,4096)|0)==0){s=n;break a}a[l+(hc(b|0,2061784)|0)|0]=0;t=xd(b|0,2015256,(u=i,i=i+48|0,c[u>>2]=f,c[u+8>>2]=g,c[u+16>>2]=h,c[u+24>>2]=j,c[u+32>>2]=e,c[u+40>>2]=k,u)|0)|0;i=u;if((t|0)>4){t=l+(c[k>>2]|0)|0;u=c[f>>2]|0;v=gHb(u,(u|0)<0|0?-1:0,3600,0)|0;u=F;w=c[g>>2]|0;x=gHb(w,(w|0)<0|0?-1:0,60,0)|0;w=YGb(x,F,v,u)|0;u=c[h>>2]|0;v=YGb(w,F,u,(u|0)<0|0?-1:0)|0;u=gHb(v,F,100,0)|0;v=c[j>>2]|0;w=YGb(u,F,v,(v|0)<0|0?-1:0)|0;y=F;z=w;A=t}else{y=-2147483648;z=0;A=b}if(!((z|0)==0&(y|0)==(-2147483648|0))){t=uR(n,A,SGb(A|0)|0,0)|0;if((t|0)==0){o=-12;break}w=t+64|0;c[w>>2]=q;c[w+4>>2]=r;r=t+8|0;c[r>>2]=z;c[r+4>>2]=y;c[t+48>>2]=-1}if((Xy(c[p>>2]|0)|0)!=0){s=n;break a}}i=d;return o|0}else{s=m}}while(0);vR(s);o=0;i=d;return o|0}function JU(a,b){a=a|0;b=b|0;return yR(c[a+12>>2]|0,b)|0}function KU(a){a=a|0;AR(c[a+12>>2]|0);return 0}function LU(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function MU(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1313429332){e=0;return e|0}a=b+4|0;if((PGb(a,2022088,8)|0)==0){e=100;return e|0}if((PGb(a,2018680,8)|0)==0){e=100;return e|0}a=b+12|0;e=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>0>134217728>>>0?25:50;return e|0}function NU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+24|0;h=f|0;j=c[b+12>>2]|0;k=LT(b,0)|0;if((k|0)==0){l=-12;i=d;return l|0}m=b+16|0;Vy(c[m>>2]|0,12,0)|0;n=vz(c[m>>2]|0)|0;o=k+8|0;p=c[o>>2]|0;c[p+8>>2]=1;c[p+48>>2]=86060;p=k+48|0;c[p>>2]=0;c[p+4>>2]=0;p=e|0;q=e;e=b+1140|0;r=f;s=f+4|0;t=f+8|0;f=g;u=-1;v=0;w=n;a:while(1){n=rz(c[m>>2]|0)|0;if((n|0)==1096040772){x=u;y=v;z=17;break}A=vz(c[m>>2]|0)|0;if(A>>>0>1073741823>>>0){z=5;break}B=w-8|0;do{if((n|0)==1296912195){mz(c[m>>2]|0,r,12)|0;C=(fe(c[h>>2]|0)|0)+1|0;c[(c[o>>2]|0)+416>>2]=C;C=fe(c[s>>2]|0)|0;D=c[t>>2]|0;E=A-12|0;Vy(c[m>>2]|0,E,(E|0)<0|0?-1:0)|0;E=c[o>>2]|0;if((c[E+416>>2]|0)<1){z=8;break a}F=fe(D|0)|0;c[E+72>>2]=C*1e3|0;G=F;H=C}else if((n|0)==1380009305|(n|0)==1145261637|(n|0)==1381259333|(n|0)==1213028703|(n|0)==1414811231|(n|0)==860113247){C=(A|0)>(B|0)?B:A;Vy(c[m>>2]|0,C,(C|0)<0|0?-1:0)|0;G=u;H=v}else if((n|0)==1514754884){c[g>>2]=0;c[g+4>>2]=0;C=vz(c[m>>2]|0)|0;Lb(f|0,8,1974376,(I=i,i=i+8|0,c[I>>2]=C,I)|0)|0;i=I;CBb(e,1945688,f,0)|0;G=u;H=v}else{C=A>>>0>B>>>0?B:A;TGb(p|0,0,5)|0;if((C|0)==-1){G=u;H=v;break}F=WDb(C+1|0)|0;if((F|0)==0){G=u;H=v;break}mz(c[m>>2]|0,F,C)|0;a[F+C|0]=0;c[q>>2]=n;CBb(e,p,F,8)|0;G=u;H=v}}while(0);n=B-A|0;if(!((n|0)>-1)){x=G;y=H;z=17;break}if((Xy(c[m>>2]|0)|0)==0){u=G;v=H;w=n}else{x=G;y=H;z=17;break}}if((z|0)==5){yDb(b,16,2061760,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;l=-1;i=d;return l|0}else if((z|0)==8){yDb(b,16,2015216,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;l=-1094995529;i=d;return l|0}else if((z|0)==17){do{if((x|0)==22){z=c[o>>2]|0;c[z+412>>2]=22050;J=z;K=22050}else if((x|0)==44){z=c[o>>2]|0;c[z+412>>2]=44100;J=z;K=44100}else if((x|0)==11){z=c[o>>2]|0;c[z+412>>2]=11025;J=z;K=11025}else if((x|0)==(-1|0)){yDb(b,16,1920800,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;l=-1;i=d;return l|0}else{if(!((x-8|0)>>>0>36>>>0)){z=x*1e3|0;H=c[o>>2]|0;c[H+412>>2]=z;J=H;K=z;break}yDb(b,16,1899576,(I=i,i=i+8|0,c[I>>2]=x,I)|0);i=I;l=-1094995529;i=d;return l|0}}while(0);x=(y|0)/(c[J+416>>2]|0)|0;if((x-8|0)>>>0>40>>>0){yDb(b,16,1879312,(I=i,i=i+8|0,c[I>>2]=x,I)|0);i=I;l=-1094995529;i=d;return l|0}y=J+412|0;z=(((K|0)/1e3|0)<<8)+x|0;if((z|0)==11304|(z|0)==11312){L=2048}else if((z|0)==2824|(z|0)==2056|(z|0)==2826|(z|0)==5664){L=512}else if((z|0)==4112|(z|0)==5652|(z|0)==5656){L=1024}else{z=c[J+72>>2]|0;yDb(b,16,2337512,(I=i,i=i+16|0,c[I>>2]=K,c[I+8>>2]=z,I)|0);i=I;l=-1;i=d;return l|0}c[j>>2]=(ba(c[J+72>>2]|0,L)|0)/(K|0)|0;MT(k,64,L,c[y>>2]|0);if((BT(c[o>>2]|0,12)|0)!=0){l=-12;i=d;return l|0}UGb(c[(c[o>>2]|0)+96>>2]|0,r|0,12)|0;RG(b,0,91920);l=0;i=d;return l|0}return 0}function OU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[b+12>>2]|0;f=e;g=e+8|0;h=(c[f>>2]|0)+7-(c[g>>2]|0)>>3;i=h+2|0;if((wZ(d,i)|0)<0){j=-5;return j|0}k=b+16|0;b=Ty(c[k>>2]|0,0,0,1)|0;l=d+64|0;c[l>>2]=b;c[l+4>>2]=F;c[d+32>>2]=0;c[d+48>>2]=1;l=d+24|0;a[c[l>>2]|0]=8-(c[g>>2]|0);b=e+4|0;a[(c[l>>2]|0)+1|0]=a[b]|0;if((mz(c[k>>2]|0,(c[l>>2]|0)+2|0,h)|0)==(h|0)){a[b]=a[(c[l>>2]|0)+(h+1)|0]|0;c[g>>2]=(h<<3)-(c[f>>2]|0)+(c[g>>2]|0);j=i;return j|0}else{BZ(d);j=-5;return j|0}return 0}function PU(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c[a+12>>2]|0;h=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[(c[h+8>>2]|0)+72>>2]|0;i=b;j=(b|0)<0|0?-1:0;b=gHb(i,j,d,e)|0;e=F;d=c[h+40>>2]|0;k=d;l=(d|0)<0|0?-1:0;d=c[h+44>>2]|0;m=d;n=(d|0)<0|0?-1:0;d=c[g>>2]|0;o=d;p=(d|0)<0|0?-1:0;d=gHb(o,p,m,n)|0;q=HDb(b,e,k,l,d,F,f&1^3)|0;f=gHb(q,F,o,p)|0;p=F;o=gHb(k,l,i,j)|0;j=IDb(f,p,m,n,o,F)|0;o=h+208|0;c[o>>2]=j;c[o+4>>2]=F;o=c[a+16>>2]|0;j=YGb(f,p,-7,-1)|0;p=F;f=a+1248|0;a=YGb(j>>>3|p<<29,p>>3|((p|0)<0|0?-1:0)<<29,c[f>>2]|0,c[f+4>>2]|0)|0;f=Ty(o,a,F,0)|0;a=f;if((a|0)<0){r=a;return r|0}a=ZGb(-7,-1,j&7,p&0)|0;c[g+8>>2]=a;r=0;return r|0}function QU(a){a=a|0;var b=0,d=0;if((c[a+8>>2]|0)<33){b=0;return b|0}d=c[a+4>>2]|0;do{if((PGb(d+8|0,2079176,4)|0)==0){if((PGb(d,2074288,4)|0)==0){b=99;return b|0}if((PGb(d,2069576,4)|0)!=0){break}if((PGb(d+12|0,2065024,4)|0)==0){b=100}else{break}return b|0}}while(0);b=0;return b|0}function RU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;d=i;i=i+400|0;e=d|0;f=d+264|0;g=b+16|0;h=c[g>>2]|0;j=c[b+12>>2]|0;k=Ty(h,0,0,1)|0;l=j+72|0;c[l>>2]=k&1;k=j+24|0;c[k>>2]=-1;c[k+4>>2]=-1;m=rz(h)|0;n=(m|0)==875972178;if(!((m|0)==1179011410|(m|0)==875972178)){o=-1094995529;i=d;return o|0}rz(h)|0;if((rz(h)|0)!=1163280727){o=-1094995529;i=d;return o|0}do{if(n){if((rz(h)|0)!=875983716){o=-1094995529;i=d;return o|0}m=rz(h)|0;if(m>>>0<24>>>0){o=-1094995529;i=d;return o|0}sz(h)|0;p=sz(h)|0;q=F;r=sz(h)|0;s=F;t=s|q;u=0;if(!((t|0)<(u|0)|(t|0)==(u|0)&(r|p)>>>0<0>>>0)){u=YGb(m,0,-24,-1)|0;Vy(h,u,F)|0;v=q;w=p;y=s;z=r;break}yDb(b,16,2246144,(A=i,i=i+32|0,c[A>>2]=p,c[A+8>>2]=q,c[A+16>>2]=r,c[A+24>>2]=s,A)|0);i=A;o=-1094995529;i=d;return o|0}else{v=0;w=0;y=0;z=0}}while(0);s=b;r=j+8|0;q=h+88|0;p=n^1;u=f|0;f=e|0;m=e+256|0;t=e+32|0;B=e+10|0;C=e+8|0;e=b+1140|0;D=-1;E=-1;G=0;H=v;v=w;w=y;y=z;z=0;a:while(1){I=rz(h)|0;J=rz(h)|0;K=J;L=0;M=Ty(h,0,0,1)|0;N=YGb(M,F,K,L)|0;M=F;if((Xy(h)|0)!=0){O=D;P=E;Q=H;R=v;S=w;T=y;U=z;break}do{if((I|0)==810962259){V=57;break a}else if((I|0)==1954047330){W=mz(c[g>>2]|0,f,256)|0;if((W|0)<0){o=W;V=87;break a}a[m]=0;if((a[f]|0)!=0){W=CBb(e,1920752,f,0)|0;if((W|0)<0){o=W;V=87;break a}}W=mz(c[g>>2]|0,f,32)|0;if((W|0)<0){o=W;V=87;break a}a[t]=0;if((a[f]|0)!=0){W=CBb(e,1879296,f,0)|0;if((W|0)<0){o=W;V=87;break a}}W=mz(c[g>>2]|0,f,32)|0;if((W|0)<0){o=W;V=87;break a}a[t]=0;if((a[f]|0)!=0){W=CBb(e,2146248,f,0)|0;if((W|0)<0){o=W;V=87;break a}}W=mz(c[g>>2]|0,f,10)|0;if((W|0)<0){o=W;V=87;break a}a[B]=0;if((a[f]|0)!=0){W=CBb(e,2312776,f,0)|0;if((W|0)<0){o=W;V=87;break a}}W=mz(c[g>>2]|0,f,8)|0;if((W|0)<0){o=W;V=87;break a}a[C]=0;if((a[f]|0)!=0){W=CBb(e,2276360,f,0)|0;if((W|0)<0){o=W;V=87;break a}}W=sz(c[g>>2]|0)|0;X=F;Lb(u|0,131,2140208,(A=i,i=i+16|0,c[A>>2]=W,c[A+8>>2]=X,A)|0)|0;i=A;X=CBb(e,2133696,u,0)|0;if((X|0)<0){o=X;V=87;break a}X=(pz(c[g>>2]|0)|0)==0;W=c[g>>2]|0;if(X){Vy(W,254,0)|0;}else{X=Az(W)|0;W=F;Y=Az(c[g>>2]|0)|0;Z=F;_=Az(c[g>>2]|0)|0;$=F;aa=Az(c[g>>2]|0)|0;ba=F;ca=Az(c[g>>2]|0)|0;da=F;ea=Az(c[g>>2]|0)|0;fa=F;ga=Az(c[g>>2]|0)|0;ha=F;ia=Az(c[g>>2]|0)|0;ja=F;if(!((Y|X|_|aa|ca|ea|ga|ia|0)==0&(Z|W|$|ba|da|fa|ha|ja|0)==0)){do{if((ea|ca|0)==0&(fa|da|0)==0){if(!((ia|ga|0)==0&(ja|ha|0)==0)){ka=0;la=0;V=49;break}Lb(u|0,131,2127464,(A=i,i=i+64|0,c[A>>2]=X,c[A+8>>2]=W,c[A+16>>2]=Y,c[A+24>>2]=Z,c[A+32>>2]=_,c[A+40>>2]=$,c[A+48>>2]=aa,c[A+56>>2]=ba,A)|0)|0;i=A}else{ka=fa;la=ea;V=49}}while(0);if((V|0)==49){V=0;Lb(u|0,131,2121512,(A=i,i=i+128|0,c[A>>2]=X,c[A+8>>2]=W,c[A+16>>2]=Y,c[A+24>>2]=Z,c[A+32>>2]=_,c[A+40>>2]=$,c[A+48>>2]=aa,c[A+56>>2]=ba,c[A+64>>2]=ca,c[A+72>>2]=da,c[A+80>>2]=la,c[A+88>>2]=ka,c[A+96>>2]=ga,c[A+104>>2]=ha,c[A+112>>2]=ia,c[A+120>>2]=ja,A)|0)|0;i=A}ea=CBb(e,2116600,u,0)|0;if((ea|0)<0){o=ea;V=87;break a}}Vy(c[g>>2]|0,190,0)|0;}if(!(J>>>0>602>>>0)){ma=D;na=E;oa=M;pa=N;qa=G;ra=H;sa=v;ta=w;ua=y;va=z;break}ea=WDb(J-601|0)|0;if((ea|0)==0){o=-12;V=87;break a}fa=J-602|0;wa=mz(c[g>>2]|0,ea,fa)|0;if((wa|0)<0){o=wa;V=87;break a}a[ea+fa|0]=0;fa=CBb(e,2102984,ea,8)|0;if((fa|0)<0){o=fa;V=87;break a}else{ma=D;na=E;oa=M;pa=N;qa=G;ra=H;sa=v;ta=w;ua=y;va=z}}else if((I|0)==544501094){if((G|0)!=0){yDb(s,24,2233544,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;ma=D;na=E;oa=M;pa=N;qa=1;ra=H;sa=v;ta=w;ua=y;va=z;break}fa=c[g>>2]|0;ea=LT(b,0)|0;if((ea|0)==0){o=-12;V=87;break a}wa=ea+8|0;xa=AO(fa,c[wa>>2]|0,J)|0;if((xa|0)<0){o=xa;V=87;break a}xa=c[wa>>2]|0;if((c[xa+48>>2]|0)==65536){c[ea+440>>2]=50;wa=ea+228|0;fa=c[wa>>2]|0;c[wa>>2]=(fa|0)>4?4:fa}c[ea+236>>2]=1463898624;MT(ea,64,1,c[xa+412>>2]|0);ma=D;na=E;oa=M;pa=N;qa=1;ra=H;sa=v;ta=w;ua=y;va=ea}else if((I|0)==1635017060){if((G|0)==0){V=20;break a}if(n){ea=Ty(h,0,0,1)|0;xa=YGb(ea,F,v,H)|0;ya=H;za=v;Aa=F;Ba=xa}else{xa=(J|0)!=0;ya=L;za=K;Aa=xa?M:2147483647;Ba=xa?N:-1}c[r>>2]=Ba;c[r+4>>2]=Aa;xa=Ty(h,0,0,1)|0;ea=F;if((c[q>>2]|0)==0){O=ea;P=xa;Q=ya;R=za;S=w;T=y;U=z;break a}if((J|0)==0&p){O=ea;P=xa;Q=ya;R=za;S=w;T=y;U=z;break a}else{ma=ea;na=xa;oa=Aa;pa=Ba;qa=G;ra=ya;sa=za;ta=w;ua=y;va=z}}else if((I|0)==1414744396){if(J>>>0<4>>>0){V=68;break a}if((rz(h)|0)!=1330007625){ma=D;na=E;oa=M;pa=N;qa=G;ra=H;sa=v;ta=w;ua=y;va=z;break}xa=YGb(K,L,-4,-1)|0;DO(b,xa,F)|0;ma=D;na=E;oa=M;pa=N;qa=G;ra=H;sa=v;ta=w;ua=y;va=z}else if((I|0)==1952670054){if(!((y|0)==0&(w|0)==0)){ma=D;na=E;oa=M;pa=N;qa=G;ra=H;sa=v;ta=w;ua=y;va=z;break}ma=D;na=E;oa=M;pa=N;qa=G;ra=H;sa=v;ta=0;ua=rz(h)|0;va=z}else{ma=D;na=E;oa=M;pa=N;qa=G;ra=H;sa=v;ta=w;ua=y;va=z}}while(0);N=Wy(h)|0;M=F;I=0;if((M|0)>(I|0)|(M|0)==(I|0)&N>>>0>0>>>0){N=Wy(h)|0;I=F;if(!((oa|0)<(I|0)|(oa|0)==(I|0)&pa>>>0<N>>>0)){O=ma;P=na;Q=ra;R=sa;S=ta;T=ua;U=va;break}}if((pa|0)==(-1|0)&(oa|0)==2147483647){Ca=0;Da=0}else{N=YGb(c[l>>2]|0,0,pa,oa)|0;Ca=F&0;Da=N&1}N=YGb(Da,Ca,pa,oa)|0;I=Ty(h,N,F,0)|0;N=F;M=0;if((N|0)<(M|0)|(N|0)==(M|0)&I>>>0<0>>>0){O=ma;P=na;Q=ra;R=sa;S=ta;T=ua;U=va;break}else{D=ma;E=na;G=qa;H=ra;v=sa;w=ta;y=ua;z=va}}do{if((V|0)==20){yDb(s,16,2220544,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}else if((V|0)==57){if((G|0)==0){yDb(s,16,2211360,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}if((J|0)!=808464944){yDb(s,16,2202344,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;O=D;P=E;Q=H;R=v;S=w;T=y;U=z;break}yDb(s,48,2195264,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;c[j+68>>2]=0;va=LT(b,0)|0;if((va|0)==0){o=-12;i=d;return o|0}lz(h)|0;c[va+4>>2]=1;ua=va+8|0;ta=c[ua>>2]|0;c[ta+8>>2]=0;c[ta+48>>2]=1397577290;ta=qz(h)|0;c[(c[ua>>2]|0)+120>>2]=ta;ta=qz(h)|0;sa=c[ua>>2]|0;c[sa+124>>2]=ta;if((BT(sa,4)|0)!=0){yDb(s,16,2179208,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-12;i=d;return o|0}sa=qz(h)|0;ta=Ty(h,0,0,1)|0;ra=F;qa=gHb(sa,0,3,0)|0;sa=F;na=YGb(ta,ra,-15,-1)|0;ra=YGb(na,F,qa,sa)|0;c[k>>2]=ra;c[k+4>>2]=F;qz(h)|0;c[j+32>>2]=qz(h)|0;MT(va,32,1,qz(h)|0);ra=va+56|0;c[ra>>2]=qz(h)|0;c[ra+4>>2]=0;qz(h)|0;qz(h)|0;ra=qz(h)|0;c[j+36>>2]=ra;if((ra|0)<=65536){va=c[(c[ua>>2]|0)+96>>2]|0;x=ra;a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;c[j+64>>2]=0;O=D;P=E;Q=H;R=v;S=w;T=y;U=z;break}yDb(s,16,2166832,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}else if((V|0)==68){yDb(s,16,2160080,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}else if((V|0)==87){i=d;return o|0}}while(0);z=0;if((O|0)<(z|0)|(O|0)==(z|0)&P>>>0<0>>>0){yDb(s,16,2153256,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}Ty(h,P,O,0)|0;O=U+8|0;if((T|0)==0&(S|0)==0){V=80}else{if((N0a(c[(c[O>>2]|0)+48>>2]|0)|0)>0){V=80}else{Ea=S;Fa=T}}do{if((V|0)==80){P=c[O>>2]|0;if((c[P+416>>2]|0)==0|(R|0)==0&(Q|0)==0){Ea=S;Fa=T;break}if((u0a(c[P+48>>2]|0)|0)==0){Ea=S;Fa=T;break}P=c[r>>2]|0;A=c[r+4>>2]|0;s=Wy(h)|0;z=F;if((A|0)>(z|0)|(A|0)==(z|0)&P>>>0>s>>>0){Ea=S;Fa=T;break}s=c[O>>2]|0;P=c[s+416>>2]|0;z=u0a(c[s+48>>2]|0)|0;s=gHb(z,(z|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;P=hHb(R<<3|0>>>29,Q<<3|R>>>29,s,F)|0;Ea=F;Fa=P}}while(0);if(!((Fa|0)==0&(Ea|0)==0)){R=U+56|0;c[R>>2]=Fa;c[R+4>>2]=Ea}RG(b,0,58168);RG(b,0,1148752);o=0;i=d;return o|0}function SU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=i;i=i+24|0;e=d|0;f=d+16|0;g=c[a+12>>2]|0;h=g+60|0;j=c[h>>2]|0;do{if((j|0)==1){k=6}else if((j|0)==0){l=a+28|0;if((c[(c[(c[c[l>>2]>>2]|0)+8>>2]|0)+52>>2]|0)!=1){break}m=c[a+16>>2]|0;n=c[m+4>>2]|0;if(($Q(n,(c[m+16>>2]|0)-n|0,f)|0)>50){c[(c[(c[c[l>>2]>>2]|0)+8>>2]|0)+48>>2]=c[f>>2];c[h>>2]=1;k=6;break}else{c[h>>2]=-1;break}}}while(0);if((k|0)==6){o=bR(a,b)|0;i=d;return o|0}h=g+24|0;f=c[h+4>>2]|0;j=0;l=a+28|0;if((f|0)>(j|0)|(f|0)==(j|0)&(c[h>>2]|0)>>>0>0>>>0){p=g+52|0;q=g+48|0;r=a+16|0}else{s=a+16|0;k=24}a:while(1){if((k|0)==24){k=0;t=c[c[l>>2]>>2]|0;u=g+8|0;a=c[u>>2]|0;j=c[u+4>>2]|0;f=Ty(c[s>>2]|0,0,0,1)|0;n=ZGb(a,j,f,F)|0;f=(c[g+56>>2]|0)==0;j=f?n:2147483647;n=f?F:0;f=0;if(!((n|0)<(f|0)|(n|0)==(f|0)&j>>>0<1>>>0)){v=n;w=j;break}j=c[s>>2]|0;b:do{if((c[g+16>>2]|0)==0){if((Xy(j)|0)!=0){break}n=g+72|0;do{f=rz(j)|0;a=rz(j)|0;m=0;if((f|0)==1635017060){x=m;y=a;k=37;break a}f=YGb(c[n>>2]|0,0,a,m)|0;z=YGb(f&1,F&0,a,m)|0;Ty(j,z,F,1)|0;}while((Xy(j)|0)==0)}else{n=e|0;if((Xy(j)|0)!=0){break}while(1){mz(j,n,16)|0;A=sz(j)|0;B=F;z=0;if((B|0)<(z|0)|(B|0)==(z|0)&A>>>0<25>>>0){break b}if((PGb(n,1083624,16)|0)==0){break}z=YGb(A,B,-17,-1)|0;Vy(j,z&-8,F|0)|0;if((Xy(j)|0)!=0){break b}}n=YGb(A,B,-24,-1)|0;z=F;m=0;if(!((z|0)<(m|0)|(z|0)==(m|0)&n>>>0<0>>>0)){x=z;y=n;k=37;break a}}}while(0);j=g+52|0;c[j>>2]=1;n=c[h+4>>2]|0;z=0;if(!((n|0)>(z|0)|(n|0)==(z|0)&(c[h>>2]|0)>>>0>0>>>0)){o=-541478725;k=42;break}z=g+48|0;if((c[z>>2]|0)==0){p=j;q=z;r=s}else{o=-541478725;k=42;break}}z=g+68|0;j=g+44|0;n=g+40|0;m=g+32|0;a=b+64|0;f=g+36|0;C=g+64|0;D=b+8|0;E=b+32|0;while(1){G=c[l>>2]|0;H=c[G>>2]|0;I=c[G+4>>2]|0;if((c[z>>2]|0)==0){J=1}else{G=c[I+208>>2]|0;K=c[H+208>>2]|0;J=(LDb(G,(G|0)<0|0?-1:0,I+40|0,K,(K|0)<0|0?-1:0,H+40|0)|0)<1|0}c[z>>2]=1;c[j>>2]=J;H=J|c[p>>2];c[j>>2]=H;K=(c[q>>2]|0)==0&H;c[j>>2]=K;if((K|0)==0){s=r;k=24;continue a}K=Ty(c[r>>2]|0,0,0,1)|0;H=F;I=ba(c[m>>2]|0,c[n>>2]|0)|0;G=YGb(I,(I|0)<0|0?-1:0,c[h>>2]|0,c[h+4>>2]|0)|0;I=Ty(c[r>>2]|0,G,F,0)|0;G=F;L=0;M=c[r>>2]|0;if((G|0)<(L|0)|(G|0)==(L|0)&I>>>0<0>>>0){Ty(M,K,H,0)|0;}else{I=qz(M)|0;M=TS(c[r>>2]|0,b,I)|0;if((M|0)>=0){I=YGb(c[a>>2]|0,c[a+4>>2]|0,-3,-1)|0;c[a>>2]=I;c[a+4>>2]=F;I=c[n>>2]|0;L=c[f>>2]|0;G=ba(L,I)|0;N=c[C>>2]|0;O=G+N|0;c[D>>2]=O;c[D+4>>2]=(O|0)<0|0?-1:0;O=N+1|0;if((L|0)>0){P=(O|0)%(L|0)|0}else{P=O}c[C>>2]=P;if((P|0)==0){c[n>>2]=I+1}c[E>>2]=1}Ty(c[r>>2]|0,K,H,0)|0;if(!((M|0)==-541478725)){o=M;k=42;break a}}c[q>>2]=1}}if((k|0)==37){q=Ty(c[s>>2]|0,0,0,1)|0;r=YGb(q,F,y,x)|0;c[u>>2]=r;c[u+4>>2]=F;v=x;w=y}else if((k|0)==42){i=d;return o|0}k=c[(c[t+8>>2]|0)+432>>2]|0;if((k|0)>1){t=(k|0)>4096?k:4096;y=t-((t|0)%(k|0)|0)|0;Q=(y|0)<0|0?-1:0;R=y}else{Q=0;R=4096}y=(Q|0)>(v|0)|(Q|0)==(v|0)&R>>>0>w>>>0;y?v:Q;Q=TS(c[s>>2]|0,b,y?w:R)|0;if((Q|0)<0){o=Q;i=d;return o|0}c[b+32>>2]=0;o=Q;i=d;return o|0}function TU(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=c[a+12>>2]|0;c[g+48>>2]=0;c[g+52>>2]=0;h=g+24|0;i=c[h+4>>2]|0;j=0;do{if((i|0)>(j|0)|(i|0)==(j|0)&(c[h>>2]|0)>>>0>0>>>0){k=a+28|0;l=c[k>>2]|0;if((b|0)==0){m=KDb(d,e,(c[l>>2]|0)+40|0,(c[l+4>>2]|0)+40|0)|0;n=F;o=m;p=e;q=d}else{m=KDb(d,e,(c[l+4>>2]|0)+40|0,(c[l>>2]|0)+40|0)|0;n=e;o=d;p=F;q=m}m=c[g+36>>2]|0;if((m|0)<=0){r=p;s=q;t=k;break}l=m;u=(m|0)<0|0?-1:0;m=eHb(o,n,l,u)|0;c[g+40>>2]=m;m=fHb(o,n,l,u)|0;c[g+64>>2]=m;r=p;s=q;t=k}else{r=e;s=d;t=a+28|0}}while(0);d=c[(c[(c[c[t>>2]>>2]|0)+8>>2]|0)+48>>2]|0;if((d|0)==86016|(d|0)==86017|(d|0)==86019|(d|0)==86020){v=-1;return v|0}v=EN(a,b,s,r,f)|0;return v|0}function UU(a){a=a|0;var b=0,d=0;if((c[a+8>>2]|0)<41){b=0;return b|0}d=c[a+4>>2]|0;do{if((PGb(d,1083576,16)|0)==0){if((PGb(d+24|0,1083544,16)|0)==0){b=100}else{break}return b|0}}while(0);b=0;return b|0}function VU(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;e=i;i=i+24|0;f=e|0;g=e+16|0;h=c[b+16>>2]|0;j=c[b+12>>2]|0;k=f|0;mz(h,k,16)|0;if((PGb(k,1083576,16)|0)!=0){l=-1094995529;i=e;return l|0}m=sz(h)|0;n=F;o=0;if(n>>>0<o>>>0|n>>>0==o>>>0&m>>>0<72>>>0){l=-1094995529;i=e;return l|0}mz(h,k,16)|0;if((PGb(k,1083544,16)|0)!=0){yDb(b,16,1974304,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;l=-1094995529;i=e;return l|0}c[j+16>>2]=1;m=LT(b,0)|0;if((m|0)==0){l=-12;i=e;return l|0}if((Xy(h)|0)!=0){l=-541478725;i=e;return l|0}o=m+8|0;n=m+56|0;q=g+4|0;r=g|0;g=b+1140|0;s=b;t=f+1|0;u=f+2|0;v=f+3|0;w=f+4|0;x=f+5|0;y=f+6|0;z=f+7|0;A=f+8|0;B=f+9|0;C=f+10|0;D=f+11|0;E=f+12|0;G=f+13|0;H=f+14|0;I=f+15|0;f=j+8|0;j=h+88|0;J=0;K=0;a:while(1){b:while(1){if((mz(h,k,16)|0)!=16){L=J;M=K;N=31;break a}O=sz(h)|0;P=F;Q=0;if((P|0)<(Q|0)|(P|0)==(Q|0)&O>>>0<25>>>0){l=-1094995529;N=35;break a}Q=ZGb(-1,2147483647,O,P)|0;R=F;S=Ty(h,0,0,1)|0;T=F;if((R|0)<(T|0)|(R|0)==(T|0)&Q>>>0<S>>>0){l=-1094995529;N=35;break a}do{if((PGb(k,1083592,16)|0)==0){S=c[o>>2]|0;Q=YGb(O,P,-24,0)|0;T=AO(h,S,Q)|0;if((T|0)<0){l=T;N=35;break a}T=YGb(O,P,7,0)|0;Q=ZGb(T&-8,F|0,O,P)|0;Vy(h,Q,F)|0;MT(m,64,1,c[(c[o>>2]|0)+412>>2]|0)}else{if((PGb(k,1083608,16)|0)==0){Q=sz(h)|0;T=F;S=0;if(!((T|0)>(S|0)|(T|0)==(S|0)&Q>>>0>0>>>0)){break}c[n>>2]=Q;c[n+4>>2]=T;break}if((PGb(k,1083624,16)|0)==0){break b}if((PGb(k,1083560,16)|0)!=0){T=d[t]|0;Q=d[u]|0;S=d[v]|0;R=d[w]|0;U=d[x]|0;V=d[y]|0;W=d[z]|0;X=d[A]|0;Y=d[B]|0;Z=d[C]|0;_=d[D]|0;$=d[E]|0;aa=d[G]|0;ba=d[H]|0;ca=d[I]|0;yDb(s,48,1945552,(p=i,i=i+128|0,c[p>>2]=d[k]|0,c[p+8>>2]=T,c[p+16>>2]=Q,c[p+24>>2]=S,c[p+32>>2]=R,c[p+40>>2]=U,c[p+48>>2]=V,c[p+56>>2]=W,c[p+64>>2]=X,c[p+72>>2]=Y,c[p+80>>2]=Z,c[p+88>>2]=_,c[p+96>>2]=$,c[p+104>>2]=aa,c[p+112>>2]=ba,c[p+120>>2]=ca,p)|0);i=p;ca=YGb(O,P,-17,-1)|0;Vy(h,ca&-8,F|0)|0;break}ca=Ty(h,0,0,1)|0;ba=F;aa=YGb(O,P,7,0)|0;$=YGb(ca,ba,aa&-8,F|0)|0;aa=F;ba=YGb($,aa,-24,-1)|0;ca=F;_=rz(h)|0;c:do{if((_|0)!=0){Z=YGb($,aa,-32,-1)|0;Y=F;X=0;do{if((Xy(h)|0)!=0){break c}W=Ty(h,0,0,1)|0;V=F;U=0;if((V|0)<(U|0)|(V|0)==(U|0)&W>>>0<0>>>0|((V|0)>(Y|0)|(V|0)==(Y|0)&W>>>0>Z>>>0)){break c}a[q]=0;mz(h,r,4)|0;W=rz(h)|0;V=cEb(W+1|0)|0;if((V|0)==0){l=-12;N=35;break a}Vy(h,W-(yz(h,W,V,W)|0)|0,0)|0;CBb(g,r,V,8)|0;X=X+1|0;}while(X>>>0<_>>>0)}}while(0);_=Ty(h,0,0,1)|0;aa=ZGb(ba,ca,_,F)|0;Vy(h,aa,F)|0;}}while(0);if((Xy(h)|0)!=0){L=J;M=K;N=31;break a}}aa=Ty(h,0,0,1)|0;_=F;$=YGb(O,P,-24,-1)|0;X=F;Z=YGb($,X,aa,_)|0;c[f>>2]=Z;c[f+4>>2]=F;Z=Ty(h,0,0,1)|0;_=F;if((c[j>>2]|0)==0){L=_;M=Z;N=31;break}Vy(h,$,X)|0;if((Xy(h)|0)==0){J=_;K=Z}else{L=_;M=Z;N=31;break}}if((N|0)==31){if((M|0)==0&(L|0)==0){l=-541478725;i=e;return l|0}RG(b,0,58168);RG(b,0,1148752);if((c[(c[m+8>>2]|0)+48>>2]|0)==65536){c[m+440>>2]=50;b=m+228|0;K=c[b>>2]|0;c[b>>2]=(K|0)>4?4:K}c[m+236>>2]=1463898624;Ty(h,M,L,0)|0;l=0;i=e;return l|0}else if((N|0)==35){i=e;return l|0}return 0}function WU(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+24|0;e=b|0;f=c[a+12>>2]|0;g=a+16|0;h=c[g>>2]|0;if((c[a+24>>2]|0)!=1){yDb(a,16,2312584,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=b;return k|0}l=f+56|0;if((c[l>>2]|0)==1){Yy(h,875972178);Yy(h,-1)}else{Yy(h,1179011410);Yy(h,0)}Yy(h,1163280727);m=c[l>>2]|0;if((m|0)!=0){l=(m|0)==1?1879256:2260496;Yy(h,(d[l+1|0]|0)<<8|(d[l]|0)|(d[l+2|0]|0)<<16|(d[l+3|0]|0)<<24);Yy(h,28);l=Ty(h,0,0,1)|0;m=f+24|0;c[m>>2]=l;c[m+4>>2]=F;Qy(h,0,28)}m=EO(h,2246104)|0;l=F;n=a+28|0;if((GO(h,c[(c[c[n>>2]>>2]|0)+8>>2]|0)|0)<0){o=c[(c[(c[c[n>>2]>>2]|0)+8>>2]|0)+12>>2]|0;if((o|0)==0){p=1920648}else{p=c[o>>2]|0}yDb(a,16,2233464,(j=i,i=i+8|0,c[j>>2]=p,j)|0);i=j;k=-1;i=b;return k|0}FO(h,m,l);do{if((c[(c[(c[c[n>>2]>>2]|0)+8>>2]|0)+52>>2]|0)!=1){if((c[(c[g>>2]|0)+88>>2]|0)==0){break}l=EO(h,2220464)|0;m=f+16|0;c[m>>2]=l;c[m+4>>2]=F;Yy(h,0);FO(h,c[m>>2]|0,c[m+4>>2]|0)}}while(0);if((c[f+52>>2]|0)!=0){m=e|0;e=EO(c[g>>2]|0,2202336)|0;l=F;j=a+1140|0;p=BBb(c[j>>2]|0,2195240,0,0)|0;if((p|0)==0){q=0}else{o=c[p+4>>2]|0;p=SGb(o|0)|0;r=(p|0)>256?256:p;Ry(c[g>>2]|0,o,r);q=r}Qy(c[g>>2]|0,0,256-q|0);q=BBb(c[j>>2]|0,2179088,0,0)|0;if((q|0)==0){s=0}else{r=c[q+4>>2]|0;q=SGb(r|0)|0;o=(q|0)>32?32:q;Ry(c[g>>2]|0,r,o);s=o}Qy(c[g>>2]|0,0,32-s|0);s=BBb(c[j>>2]|0,2166792,0,0)|0;if((s|0)==0){t=0}else{o=c[s+4>>2]|0;s=SGb(o|0)|0;r=(s|0)>32?32:s;Ry(c[g>>2]|0,o,r);t=r}Qy(c[g>>2]|0,0,32-t|0);t=BBb(c[j>>2]|0,2160056,0,0)|0;if((t|0)==0){u=0}else{r=c[t+4>>2]|0;t=SGb(r|0)|0;o=(t|0)>10?10:t;Ry(c[g>>2]|0,r,o);u=o}Qy(c[g>>2]|0,0,10-u|0);u=BBb(c[j>>2]|0,2153232,0,0)|0;if((u|0)==0){v=0}else{o=c[u+4>>2]|0;u=SGb(o|0)|0;r=(u|0)>8?8:u;Ry(c[g>>2]|0,o,r);v=r}Qy(c[g>>2]|0,0,8-v|0);v=BBb(c[j>>2]|0,2146232,0,0)|0;if((v|0)==0){w=0;x=0}else{r=Ed(c[v+4>>2]|0,0,10)|0;w=F;x=r}dz(c[g>>2]|0,x,w);az(c[g>>2]|0,1);w=BBb(c[j>>2]|0,2140200,0,0)|0;if((w|0)==0){Qy(c[g>>2]|0,0,64)}else{TGb(m|0,0,17)|0;x=w+4|0;w=(c[x>>2]|0)+2|0;r=SGb(w|0)|0;v=(r|0)/16|0;if((r|0)>15){o=(r|0)>31;UGb(m|0,w|0,16)|0;w=Ed(m|0,0,16)|0;ez(c[g>>2]|0,w,F);if(o){w=1;do{UGb(m|0,(c[x>>2]|0)+(w<<4|2)|0,16)|0;r=Ed(m|0,0,16)|0;ez(c[g>>2]|0,r,F);w=w+1|0;}while((w|0)<(v|0))}y=o?v<<3:8}else{y=0}Qy(c[g>>2]|0,0,64-y|0)}Qy(c[g>>2]|0,0,190);y=BBb(c[j>>2]|0,2133680,0,0)|0;if((y|0)!=0){_y(c[g>>2]|0,c[y+4>>2]|0)|0}FO(c[g>>2]|0,e,l)}l=c[c[n>>2]>>2]|0;MT(l,64,1,c[(c[l+8>>2]|0)+412>>2]|0);c[f+48>>2]=0;l=f+40|0;c[l>>2]=0;c[l+4>>2]=0;l=f+32|0;c[l>>2]=-1;c[l+4>>2]=2147483647;MO(a);a=EO(h,2211352)|0;l=f+8|0;c[l>>2]=a;c[l+4>>2]=F;Sy(h);k=0;i=b;return k|0}function XU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=c[a+12>>2]|0;Ry(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);f=b+8|0;g=c[f>>2]|0;h=c[f+4>>2]|0;if((g|0)==0&(h|0)==(-2147483648|0)){yDb(a,16,2337384,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=d;return 0}else{a=e+32|0;j=c[a>>2]|0;k=c[a+4>>2]|0;l=(k|0)>(h|0)|(k|0)==(h|0)&j>>>0>g>>>0;c[a>>2]=l?g:j;c[a+4>>2]=l?h:k;k=e+40|0;h=c[k>>2]|0;l=c[k+4>>2]|0;a=c[f>>2]|0;j=c[f+4>>2]|0;f=(l|0)>(j|0)|(l|0)==(j|0)&h>>>0>a>>>0;c[k>>2]=f?h:a;c[k+4>>2]=f?l:j;c[e+48>>2]=c[b+48>>2];i=d;return 0}return 0}function YU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a+16|0;d=c[b>>2]|0;e=c[a+12>>2]|0;Sy(d);if((c[(c[b>>2]|0)+88>>2]|0)==0){return 0}b=Ty(d,0,0,1)|0;f=F;g=e+8|0;h=ZGb(b,f,c[g>>2]|0,c[g+4>>2]|0)|0;i=F;j=e+56|0;k=c[j>>2]|0;if((k|0)==(-1|0)){l=YGb(b,f,-8,-1)|0;m=F;n=0;if((m|0)>(n|0)|(m|0)==(n|0)&l>>>0>-1>>>0){o=1}else{p=4}}else if((k|0)==1){o=1}else{p=4}if((p|0)==4){Ty(d,4,0,0)|0;k=YGb(b,f,-8,0)|0;Yy(d,k);Ty(d,b,f,0)|0;FO(d,c[g>>2]|0,c[g+4>>2]|0);Sy(d);o=0}k=e+40|0;l=e+32|0;n=ZGb(c[k>>2]|0,c[k+4>>2]|0,c[l>>2]|0,c[l+4>>2]|0)|0;l=c[e+48>>2]|0;k=YGb(n,F,l,(l|0)<0|0?-1:0)|0;l=F;n=c[c[a+28>>2]>>2]|0;a=c[n+8>>2]|0;m=c[a+412>>2]|0;q=c[n+40>>2]|0;r=gHb(q,(q|0)<0|0?-1:0,m,(m|0)<0|0?-1:0)|0;m=c[n+44>>2]|0;n=IDb(k,l,r,F,m,(m|0)<0|0?-1:0)|0;m=F;a:do{if((c[a+52>>2]|0)==1){p=10}else{r=e+16|0;Ty(d,c[r>>2]|0,c[r+4>>2]|0,0)|0;do{if((o|0)==0){r=0;if((c[j>>2]|0)==-1&((m|0)>(r|0)|(m|0)==(r|0)&n>>>0>-1>>>0)){break}Yy(d,n);Ty(d,b,f,0)|0;Sy(d);p=10;break a}}while(0);Yy(d,-1)}}while(0);do{if((p|0)==10){if((o|0)!=0){break}return 0}}while(0);Ty(d,0,0,0)|0;Yy(d,875972178);Yy(d,-1);o=e+24|0;e=YGb(c[o>>2]|0,c[o+4>>2]|0,-8,-1)|0;Ty(d,e,F,0)|0;Yy(d,875983716);Yy(d,28);e=YGb(b,f,-8,-1)|0;dz(d,e,F);dz(d,h,i);dz(d,n,m);Yy(d,0);m=YGb(c[g>>2]|0,c[g+4>>2]|0,-4,-1)|0;Ty(d,m,F,0)|0;Yy(d,-1);Ty(d,b,f,0)|0;Sy(d);return 0}function ZU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+12>>2]|0;e=a+16|0;f=c[e>>2]|0;Ry(f,1083576,16);dz(f,-1,-1);Ry(f,1083544,16);g=Ty(f,0,0,1)|0;h=F;Ry(f,1083592,16);dz(f,-1,2147483647);j=a+28|0;k=GO(f,c[(c[c[j>>2]>>2]|0)+8>>2]|0)|0;if((k|0)<0){l=c[(c[(c[c[j>>2]>>2]|0)+8>>2]|0)+12>>2]|0;if((l|0)==0){m=1920648}else{m=c[l>>2]|0}yDb(a,16,1945432,(a=i,i=i+8|0,c[a>>2]=m,a)|0);i=a;n=k;i=b;return n|0}k=Ty(f,0,0,1)|0;a=F;m=YGb(k,a,7,0)|0;l=m&-8;m=F|0;o=ZGb(l,m,k,a)|0;Qy(f,0,o);o=YGb(g,h,16,0)|0;Ty(f,o,F,0)|0;o=ZGb(l,m,g,h)|0;dz(f,o,F);Ty(f,l,m,0)|0;do{if((c[(c[(c[c[j>>2]>>2]|0)+8>>2]|0)+52>>2]|0)!=1){if((c[(c[e>>2]|0)+88>>2]|0)==0){break}m=d+16|0;l=Ty(f,0,0,1)|0;c[m>>2]=l;c[m+4>>2]=F;Ry(f,1083608,16);dz(f,-1,2147483647);dz(f,0,0);l=c[m>>2]|0;o=c[m+4>>2]|0;m=Ty(f,0,0,1)|0;h=F;g=YGb(m,h,7,0)|0;a=g&-8;g=F|0;k=ZGb(a,g,m,h)|0;Qy(f,0,k);k=YGb(l,o,16,0)|0;Ty(f,k,F,0)|0;k=ZGb(a,g,l,o)|0;dz(f,k,F);Ty(f,a,g,0)|0;}}while(0);e=d+8|0;d=Ty(f,0,0,1)|0;c[e>>2]=d;c[e+4>>2]=F;Ry(f,1083624,16);dz(f,-1,2147483647);n=0;i=b;return n|0}function _U(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+16>>2]|0;d=c[a+12>>2]|0;if((c[b+88>>2]|0)==0){return 0}e=d+8|0;f=c[e>>2]|0;g=c[e+4>>2]|0;e=Ty(b,0,0,1)|0;h=F;i=YGb(e,h,7,0)|0;j=i&-8;i=F|0;k=ZGb(j,i,e,h)|0;Qy(b,0,k);k=YGb(f,g,16,0)|0;Ty(b,k,F,0)|0;k=ZGb(j,i,f,g)|0;dz(b,k,F);Ty(b,j,i,0)|0;i=Ty(b,0,0,1)|0;j=F;Ty(b,16,0,0)|0;dz(b,i,j);k=c[c[a+28>>2]>>2]|0;a=c[k+8>>2]|0;if((c[a+52>>2]|0)!=1){g=d+40|0;f=d+32|0;h=ZGb(c[g>>2]|0,c[g+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;f=c[d+48>>2]|0;g=YGb(h,F,f,(f|0)<0|0?-1:0)|0;f=F;h=c[a+412>>2]|0;a=c[k+40>>2]|0;e=gHb(a,(a|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=c[k+44>>2]|0;k=IDb(g,f,e,F,h,(h|0)<0|0?-1:0)|0;h=F;e=d+16|0;d=YGb(c[e>>2]|0,c[e+4>>2]|0,24,0)|0;Ty(b,d,F,0)|0;dz(b,k,h)}Ty(b,i,j,0)|0;Sy(b);return 0}function $U(a){a=a|0;var b=0;if((c[a+8>>2]|0)<12){return 0}b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297239878){a=b+8|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1163284301?100:0)|0}else{return 0}return 0}function aV(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=e;c[g>>2]=320;h=e+4|0;c[h>>2]=165;j=e+20|0;k=e+16|0;l=e+24|0;TGb(e+8|0,0,16)|0;vZ(l);c[e+48>>2]=0;c[e+52>>2]=0;Vy(f,12,0)|0;e=rz(f)|0;m=b+1140|0;n=vz(f)|0;o=e;while(1){e=n+1|0;p=e&-2;if((o|0)==1598247007){Vy(f,12,0)|0;}else if((o|0)==1296125506){q=WDb(e|1)|0;if((q|0)==0){r=-12;s=16;break}if((mz(f,q,p)|0)!=(p|0)){r=-5;s=16;break}a[q+p|0]=0;CBb(m,1920624,q,8)|0}else if((o|0)==1145982803|(o|0)==1480871497){Vy(f,p,0)|0;}else if((o|0)==1414283600){Ty(f,-8,-1,1)|0;VS(f,l,776)|0}else if((o|0)==1163544915){c[g>>2]=rz(f)|0;c[h>>2]=rz(f)|0}else{s=10;break}p=rz(f)|0;q=vz(f)|0;if((Xy(f)|0)!=0){r=-5;s=16;break}if((p|0)==1212371522){s=13;break}else{n=q;o=p}}if((s|0)==10){n=o&255;f=o>>>8&255;l=o>>>16&255;m=o>>>24;yDb(b,16,1945280,(o=i,i=i+64|0,c[o>>2]=n,c[o+8>>2]=f,c[o+16>>2]=l,c[o+24>>2]=m,c[o+32>>2]=n,c[o+40>>2]=f,c[o+48>>2]=l,c[o+56>>2]=m,o)|0);i=o;r=-1094995529;i=d;return r|0}else if((s|0)==13){o=LT(b,0)|0;if((o|0)==0){r=-12;i=d;return r|0}MT(o,33,1,15);c[k>>2]=c[o>>2];k=c[o+8>>2]|0;c[k+8>>2]=0;c[k+48>>2]=41;c[k+52>>2]=0;c[k+120>>2]=c[g>>2];c[k+124>>2]=c[h>>2];h=LT(b,0)|0;if((h|0)==0){r=-12;i=d;return r|0}MT(h,33,1,15);c[j>>2]=c[h>>2];j=c[h+8>>2]|0;c[j+8>>2]=1;c[j+48>>2]=65536;c[j+52>>2]=1;c[j+416>>2]=1;h=j+448|0;c[h>>2]=4;c[h+4>>2]=0;c[j+792>>2]=16;c[j+412>>2]=22050;c[j+72>>2]=352800;c[j+432>>2]=16;r=0;i=d;return r|0}else if((s|0)==16){i=d;return r|0}return 0}function bV(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0;f=i;i=i+1024|0;g=f|0;h=c[b+12>>2]|0;j=c[b+16>>2]|0;k=b;b=h+24|0;l=b;m=h+52|0;n=e;o=h+48|0;p=h+16|0;q=e+32|0;r=h+8|0;s=e+8|0;t=g|0;u=g+1|0;v=h+20|0;a:while(1){w=rz(j)|0;x=(vz(j)|0)+1&-2;if((Xy(j)|0)!=0){y=-5;z=23;break}if((w|0)==1229215041){z=21;break}else if((w|0)==1414482003){Ty(j,-8,-1,1)|0;VS(j,l,12)|0;continue}else if((w|0)==1212371522){continue}else if((w|0)==541149014){z=5;break}else if((w|0)!=1415071060){z=22;break}if(x>>>0>1024>>>0){continue}if((mz(j,t,x)|0)!=(x|0)){continue}yDb(k,48,2122056,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;if((x|0)==0){y=-1094995529;z=23;break}h=x-1|0;B=0;do{if(!(B>>>0<h>>>0)){y=-1094995529;z=23;break a}B=B+1|0;}while((a[g+B|0]|0)!=0);yDb(k,48,2061392,(A=i,i=i+8|0,c[A>>2]=u,A)|0);i=A;B=d[t]|0;C=B+1|0;if(!(C>>>0<x>>>0)){y=-1094995529;z=23;break}D=B+2|0;E=g+D|0;G=h+~B|0;B=0;while(1){if(!(B>>>0<G>>>0)){y=-1094995529;z=23;break a}if((a[g+(B+D)|0]|0)==0){break}else{B=B+1|0}}yDb(k,48,2014784,(A=i,i=i+8|0,c[A>>2]=E,A)|0);i=A;B=D+(d[g+C|0]|0)|0;if(!(B>>>0<x>>>0)){y=-1094995529;z=23;break}G=B+1|0;H=g+G|0;I=h-B|0;B=0;while(1){if(!(B>>>0<I>>>0)){y=-1094995529;z=23;break a}if((a[g+(B+G)|0]|0)==0){break}else{B=B+1|0}}yDb(k,48,1974144,(A=i,i=i+8|0,c[A>>2]=H,A)|0);i=A}if((z|0)==5){Ty(j,-8,-1,1)|0;g=VS(j,l,x+8|0)|0;l=(c[m>>2]|0)>0?0:g;UGb(n|0,b|0,80)|0;c[o>>2]=0;c[m>>2]=0;c[q>>2]=c[p>>2];p=c[r+4>>2]|0;c[s>>2]=c[r>>2];c[s+4>>2]=p;y=l;i=f;return y|0}else if((z|0)==21){l=TS(j,e,x)|0;c[q>>2]=c[v>>2];v=c[r+4>>2]|0;c[s>>2]=c[r>>2];c[s+4>>2]=v;v=YGb(c[r>>2]|0,c[r+4>>2]|0,1,0)|0;c[r>>2]=v;c[r+4>>2]=F;y=l;i=f;return y|0}else if((z|0)==22){l=w&255;r=w>>>8&255;v=w>>>16&255;s=w>>>24;yDb(k,16,1945280,(A=i,i=i+64|0,c[A>>2]=l,c[A+8>>2]=r,c[A+16>>2]=v,c[A+24>>2]=s,c[A+32>>2]=l,c[A+40>>2]=r,c[A+48>>2]=v,c[A+56>>2]=s,A)|0);i=A;y=-1094995529;i=f;return y|0}else if((z|0)==23){i=f;return y|0}return 0}function cV(a){a=a|0;var b=0;b=c[a+12>>2]|0;if((c[b+52>>2]|0)<=0){return 0}BZ(b+24|0);return 0}function dV(b){b=b|0;var e=0,f=0;e=c[b+4>>2]|0;b=((d[e+1|0]|0)<<8|(d[e]|0)<<16|(d[e+2|0]|0)|0)==15711167?e+3|0:e;do{if((RGb(b,2014776,6)|0)==0){e=a[b+6|0]|0;if(e<<24>>24==0){f=100;return f|0}if((Ib(2337376,e&255|0,5)|0)==0){break}else{f=100}return f|0}}while(0);f=0;return f|0}function eV(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;d=i;i=i+2048|0;e=d|0;f=d+1024|0;g=c[b+12>>2]|0;h=LT(b,0)|0;if((h|0)==0){j=-12;i=d;return j|0}MT(h,64,1,1e3);k=c[h+8>>2]|0;c[k+8>>2]=3;c[k+48>>2]=1465275476;k=h+72|0;c[k>>2]=c[k>>2]|c[g+24>>2];IAb(e,0,-1);IAb(f,0,-1);k=b+16|0;DR(c[k>>2]|0,f);b=f+4|0;a:do{if((c[b>>2]|0)==0){l=g+4|0;m=31}else{h=f|0;n=g+4|0;while(1){o=c[h>>2]|0;p=Ty(c[k>>2]|0,0,0,1)|0;q=F;do{if((RGb(o,2061376,9)|0)!=0){if((RGb(o,2014776,6)|0)==0){break}else{r=0}while(1){s=o+r|0;t=a[s]|0;if((t<<24>>24|0)==0|(t<<24>>24|0)==10|(t<<24>>24|0)==13){m=9;break}if((RGb(s,1974136,3)|0)==0){u=o;v=0;w=0;break}else{r=r+1|0}}do{if((m|0)==9){m=0;if((o|0)==0){u=0;v=0;w=0;break}s=hc(o|0,1945272)|0;t=o+s|0;x=a[t]|0;if(x<<24>>24==13){y=o+(s+1)|0;z=y;A=a[y]|0}else{z=t;A=x}u=A<<24>>24==10?z+1|0:z;v=s;w=o}}while(0);s=iV(u)|0;x=F;if((s|0)==0&(x|0)==(-2147483648|0)){l=n;m=31;break a}t=yb(u|0,1974136)|0;if((t|0)==0){l=n;m=31;break a}y=t+2|0;while(1){B=y+1|0;t=a[B]|0;if((t<<24>>24|0)==32|(t<<24>>24|0)==9){y=B}else{break}}t=iV(B)|0;C=F;if((t|0)==0&(C|0)==(-2147483648|0)){l=n;m=31;break a}D=y+((hc(B|0,1920616)|0)+1)|0;while(1){E=a[D]|0;if(!((E<<24>>24|0)==32|(E<<24>>24|0)==9)){break}D=D+1|0}y=hc(D|0,1945272)|0;E=D+y|0;G=a[E]|0;if(G<<24>>24==13){H=D+(y+1)|0;I=H;J=a[H]|0}else{I=E;J=G}G=J<<24>>24==10?I+1|0:I;E=uR(n,G,SGb(G|0)|0,0)|0;if((E|0)==0){K=-12;break a}G=E+64|0;c[G>>2]=p;c[G+4>>2]=q;G=E+8|0;c[G>>2]=s;c[G+4>>2]=x;G=ZGb(t,C,s,x)|0;c[E+48>>2]=G;if((v|0)!=0){G=GZ(E,75,v)|0;if((G|0)==0){K=-12;break a}UGb(G|0,w|0,v)|0}if((y|0)==0){break}G=GZ(E,76,y)|0;if((G|0)==0){K=-12;break a}UGb(G|0,D|0,y)|0}}while(0);DR(c[k>>2]|0,f);if((c[b>>2]|0)==0){l=n;m=31;break}}}}while(0);if((m|0)==31){vR(l);K=0}QAb(f,0)|0;QAb(e,0)|0;j=K;i=d;return j|0}function fV(a,b){a=a|0;b=b|0;return yR((c[a+12>>2]|0)+4|0,b)|0}function gV(a){a=a|0;AR((c[a+12>>2]|0)+4|0);return 0}function hV(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return zR((c[a+12>>2]|0)+4|0,a,b,d,e,f,g,h,i,j)|0}function iV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=xd(a|0,1899456,(j=i,i=i+32|0,c[j>>2]=d,c[j+8>>2]=e,c[j+16>>2]=f,c[j+24>>2]=g,j)|0)|0;i=j;if((h|0)==4){h=c[d>>2]|0;d=gHb(h,(h|0)<0|0?-1:0,3600,0)|0;h=F;k=c[e>>2]|0;l=gHb(k,(k|0)<0|0?-1:0,60,0)|0;k=YGb(l,F,d,h)|0;h=c[f>>2]|0;d=YGb(k,F,h,(h|0)<0|0?-1:0)|0;h=gHb(d,F,1e3,0)|0;d=c[g>>2]|0;k=YGb(h,F,d,(d|0)<0|0?-1:0)|0;m=F;n=k;i=b;return(F=m,n)|0}k=xd(a|0,1879232,(j=i,i=i+24|0,c[j>>2]=e,c[j+8>>2]=f,c[j+16>>2]=g,j)|0)|0;i=j;if((k|0)!=3){m=-2147483648;n=0;i=b;return(F=m,n)|0}k=c[e>>2]|0;e=gHb(k,(k|0)<0|0?-1:0,60,0)|0;k=c[f>>2]|0;f=YGb(e,F,k,(k|0)<0|0?-1:0)|0;k=gHb(f,F,1e3,0)|0;f=c[g>>2]|0;g=YGb(k,F,f,(f|0)<0|0?-1:0)|0;m=F;n=g;i=b;return(F=m,n)|0}function jV(a){a=a|0;var b=0,d=0;b=i;d=c[a+16>>2]|0;MT(c[c[a+28>>2]>>2]|0,64,1,1e3);Kz(d,2337368,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;Sy(d);i=b;return 0}function kV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[a+16>>2]|0;Kz(g,2014768,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;h=HZ(b,75,e)|0;do{if((h|0)!=0){j=c[e>>2]|0;if((j|0)<=0){break}Kz(g,1974120,(a=i,i=i+16|0,c[a>>2]=j,c[a+8>>2]=h,a)|0)|0;i=a}}while(0);h=b+8|0;e=c[h>>2]|0;j=c[h+4>>2]|0;k=eHb(e,j,1e3,0)|0;l=F;m=gHb(k,l,-1e3,-1)|0;n=YGb(m,F,e,j)|0;m=F;o=eHb(e,j,6e4,0)|0;p=F;q=gHb(o,p,-60,-1)|0;r=YGb(q,F,k,l)|0;l=F;k=eHb(e,j,36e5,0)|0;q=F;s=gHb(k,q,-60,-1)|0;t=YGb(s,F,o,p)|0;p=F;o=0;if((j|0)>(o|0)|(j|0)==(o|0)&e>>>0>3599999>>>0){Kz(g,1899448,(a=i,i=i+16|0,c[a>>2]=k,c[a+8>>2]=q,a)|0)|0;i=a}Kz(g,1879208,(a=i,i=i+48|0,c[a>>2]=t,c[a+8>>2]=p,c[a+16>>2]=r,c[a+24>>2]=l,c[a+32>>2]=n,c[a+40>>2]=m,a)|0)|0;i=a;Kz(g,1945256,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;m=c[b+48>>2]|0;n=YGb(m,(m|0)<0|0?-1:0,c[h>>2]|0,c[h+4>>2]|0)|0;h=F;m=eHb(n,h,1e3,0)|0;l=F;r=gHb(m,l,-1e3,-1)|0;p=YGb(r,F,n,h)|0;r=F;t=eHb(n,h,6e4,0)|0;q=F;k=gHb(t,q,-60,-1)|0;e=YGb(k,F,m,l)|0;l=F;m=eHb(n,h,36e5,0)|0;k=F;o=gHb(m,k,-60,-1)|0;j=YGb(o,F,t,q)|0;q=F;t=0;if((h|0)>(t|0)|(h|0)==(t|0)&n>>>0>3599999>>>0){Kz(g,1899448,(a=i,i=i+16|0,c[a>>2]=m,c[a+8>>2]=k,a)|0)|0;i=a}Kz(g,1879208,(a=i,i=i+48|0,c[a>>2]=j,c[a+8>>2]=q,c[a+16>>2]=e,c[a+24>>2]=l,c[a+32>>2]=p,c[a+40>>2]=r,a)|0)|0;i=a;r=HZ(b,76,f)|0;do{if((r|0)!=0){p=c[f>>2]|0;if((p|0)<=0){break}Kz(g,1920608,(a=i,i=i+16|0,c[a>>2]=p,c[a+8>>2]=r,a)|0)|0;i=a}}while(0);Kz(g,2014768,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;Ry(g,c[b+24>>2]|0,c[b+28>>2]|0);Kz(g,2014768,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;i=d;return 0}function lV(b){b=b|0;var e=0,f=0;if((c[b+8>>2]|0)<20){e=0;return e|0}f=c[b+4>>2]|0;b=f;if((((d[b]|d[b+1|0]<<8)<<16>>16)-8e3&65535)>>>0>4e4>>>0){e=0;return e|0}if((d[f+10|0]|0)>>>0>3>>>0){e=0;return e|0}b=a[f+11|0]|0;if(!((b<<24>>24|0)==99|(b<<24>>24|0)==1)){e=0;return e|0}b=f+16|0;e=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==57007?50:0;return e|0}function mV(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;if((mz(c[b+16>>2]|0,g,12)|0)!=12){h=-5;i=f;return h|0}j=e[g>>1]|0;k=a[g+10|0]&1;l=k+1|0;m=d[g+11|0]|0;g=LT(b,0)|0;if((g|0)==0){h=-12;i=f;return h|0}do{if((m|0)==1){if((k|0)==0){c[(c[g+8>>2]|0)+48>>2]=86033;break}DDb(b,2121920,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;h=-1163346256;i=f;return h|0}else if((m|0)==99){o=c[g+8>>2]|0;c[o+48>>2]=69636;c[o+792>>2]=4;c[o+72>>2]=ba(j<<2,l)|0}else{DDb(b,2061248,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;h=-1163346256;i=f;return h|0}}while(0);MT(g,64,1,j);n=c[g+8>>2]|0;c[n+8>>2]=1;c[n+416>>2]=l;l=n+448|0;c[l>>2]=4-k;c[l+4>>2]=0;c[n+412>>2]=j;h=0;i=f;return h|0}function nV(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+8|0;h=g|0;j=c[d+16>>2]|0;k=c[c[d+28>>2]>>2]|0;if((mz(j,h,8)|0)!=8){l=-5;i=g;return l|0}d=h+4|0;if((e[d>>1]|e[d+2>>1]<<16|0)!=57007){l=-1094995529;i=g;return l|0}d=b[h>>1]|0;m=d&65535;n=k+8|0;do{if((c[(c[n>>2]|0)+48>>2]|0)==86033){o=b[h+2>>1]|0;p=wZ(f,m+4|0)|0;if((p|0)!=0){l=p;i=g;return l|0}p=f+24|0;q=mz(j,(c[p>>2]|0)+4|0,m)|0;if((q|0)==(m|0)){r=c[p>>2]|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;r=(c[p>>2]|0)+2|0;x=d;a[r]=x;x=x>>8;a[r+1|0]=x;c[f+48>>2]=o&65535;break}l=(q|0)<0?q:-5;i=g;return l|0}else{if((TS(j,f,m)|0)==(m|0)){c[f+48>>2]=(m<<1>>>0)/((c[(c[n>>2]|0)+416>>2]|0)>>>0)|0;break}else{l=-5;i=g;return l|0}}}while(0);c[f+32>>2]=c[k>>2];l=m;i=g;return l|0}function oV(a){a=a|0;var b=0;if((c[a+8>>2]|0)<12){return 0}b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297239878){a=b+8|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1095849559?100:0)|0}else{return 0}return 0}function pV(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+8|0;f=e|0;g=f|0;h=f;j=c[b+12>>2]|0;k=c[b+16>>2]|0;l=LT(b,0)|0;if((l|0)==0){m=-12;i=e;return m|0}n=l+48|0;c[n>>2]=0;c[n+4>>2]=0;c[j+20>>2]=c[l>>2];n=l+8|0;o=c[n>>2]|0;c[o+8>>2]=0;c[o+48>>2]=45;c[o+52>>2]=0;Ty(k,20,0,0)|0;if((CT(c[n>>2]|0,k,42)|0)<0){m=-12;i=e;return m|0}o=c[n>>2]|0;n=c[o+96>>2]|0;p=n+6|0;c[o+120>>2]=(d[p]|d[p+1|0]<<8)<<16>>16&65535;p=n+8|0;c[o+124>>2]=(d[p]|d[p+1|0]<<8)<<16>>16&65535;p=a[n+12|0]|0;o=p&255;q=n+4|0;r=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=0;s=l+56|0;c[s>>2]=r;c[s+4>>2]=q;s=l+64|0;c[s>>2]=r;c[s+4>>2]=q;if(p<<24>>24==0|(p&255)>>>0>30>>>0){yDb(b,16,2061224,(t=i,i=i+8|0,c[t>>2]=o,t)|0);i=t;m=-1094995529;i=e;return m|0}MT(l,64,1,o);o=n;c[j>>2]=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=n+24|0;c[j+12>>2]=(d[o]|d[o+1|0]<<8)<<16>>16&65535;c[j+8>>2]=d[n+26|0]|0;c[j+4>>2]=d[n+27|0]|0;c[j+16>>2]=-1;j=b+20|0;c[j>>2]=c[j>>2]|1;j=f;n=f+4|0;f=b;b=h+1|0;o=h+2|0;l=h+3|0;while(1){if((mz(k,j,8)|0)!=8){m=-5;u=10;break}h=c[g>>2]|0;p=fe(h|0)|0;q=fe(c[n>>2]|0)|0;if(!((p|0)==1128877638|(p|0)==1128877640|(p|0)==1128877636|(p|0)==1346981446|(p|0)==1346981448|(p|0)==1346981444|(p|0)==1179209286|(p|0)==1129137235)){p=d[b]|0;s=d[o]|0;r=d[l]|0;yDb(f,16,2014664,(t=i,i=i+32|0,c[t>>2]=h&255,c[t+8>>2]=p,c[t+16>>2]=s,c[t+24>>2]=r,t)|0);i=t}Vy(k,q,0)|0;if((h|0)==1179535686){m=0;u=10;break}}if((u|0)==10){i=e;return m|0}return 0}function qV(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+8|0;g=f|0;h=g|0;j=c[b+12>>2]|0;k=c[b+16>>2]|0;l=g;if((mz(k,l,8)|0)!=8){m=-1;i=f;return m|0}n=g+4|0;g=b;while(1){o=c[h>>2]|0;p=fe(o|0)|0;q=fe(c[n>>2]|0)|0;r=q&1;if((p-1397638192|0)>>>0<3>>>0|(o|0)==1380340054){break}if((o|0)!=1396985155){yDb(g,32,2121880,(o=i,i=i+8|0,c[o>>2]=p,o)|0);i=o}Vy(k,r+q|0,0)|0;if((mz(k,l,8)|0)!=8){m=-1;s=31;break}}if((s|0)==31){i=f;return m|0}l=TS(k,e,q)|0;if((l|0)<0){m=-5;i=f;return m|0}a:do{if((p|0)==1397638192|(p|0)==1397638193|(p|0)==1397638194){g=j+16|0;do{if((c[g>>2]|0)==-1){n=LT(b,0)|0;if((n|0)==0){m=-12;i=f;return m|0}c[g>>2]=c[n>>2];h=j+12|0;o=c[h>>2]|0;if((o|0)==0){c[h>>2]=22050;t=22050}else{t=o}o=j+8|0;if((c[o>>2]|0)==0){c[o>>2]=1}h=j+4|0;if((c[h>>2]|0)==0){c[h>>2]=8}u=n+8|0;v=c[u>>2]|0;c[v+412>>2]=t;c[v+792>>2]=c[h>>2];c[v+416>>2]=c[o>>2];c[v+8>>2]=1;MT(n,64,1,t);if((p|0)==1397638193){c[(c[u>>2]|0)+48>>2]=86033;c[e+32>>2]=c[g>>2];break}else if((p|0)==1397638192){n=(c[u>>2]|0)+48|0;if((c[h>>2]|0)==16){c[n>>2]=65536;c[e+32>>2]=c[g>>2];break a}else{c[n>>2]=65541;s=21;break}}else if((p|0)==1397638194){n=c[u>>2]|0;c[n+48>>2]=69636;if((BT(n,2)|0)==0){n=c[(c[u>>2]|0)+96>>2]|0;x=c[j>>2]&65535;a[n]=x;x=x>>8;a[n+1|0]=x;s=21;break}else{m=-12;i=f;return m|0}}else{s=21;break}}else{s=21}}while(0);do{if((s|0)==21){c[e+32>>2]=c[g>>2];if((p|0)==1397638193){break}else if((p|0)!=1397638194){break a}c[e+48>>2]=(q<<1>>>0)/((c[j+8>>2]|0)>>>0)|0;break a}}while(0);g=c[e+24>>2]|0;if((g|0)==0){break}n=g;c[e+48>>2]=((d[n]|d[n+1|0]<<8)<<16>>16&65535|0)/(c[j+8>>2]|0)|0}else if((p|0)==1448166994){c[e+32>>2]=c[j+20>>2];c[e+48>>2]=1}}while(0);if((r|0)==0){m=l;i=f;return m|0}Vy(k,1,0)|0;m=l;i=f;return m|0}function rV(a){a=a|0;var b=0;b=(PGb(c[a+4>>2]|0,1079360,16)|0)!=0;return(b?0:100)|0}function sV(b){b=b|0;var f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;f=i;i=i+7232|0;g=f|0;j=f+1024|0;l=f+2048|0;m=f+2056|0;n=f+2064|0;o=f+2072|0;p=f+2080|0;q=f+2096|0;r=c[b+12>>2]|0;s=r+24|0;c[s>>2]=0;c[s+4>>2]=-2147483648;s=r+16|0;c[s>>2]=0;c[s+4>>2]=-2147483648;s=r+8|0;c[s>>2]=0;c[s+4>>2]=-2147483648;s=b+16|0;Vy(c[s>>2]|0,48,0)|0;t=rz(c[s>>2]|0)|0;if(t>>>0>4096>>>0){yDb(b,16,2276224,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1094995529;i=f;return v|0}Vy(c[s>>2]|0,4,0)|0;w=rz(c[s>>2]|0)|0;x=w;Ty(c[s>>2]|0,x<<12|0>>>20,((w|0)<0|0?-1:0)<<12|x>>>20,0)|0;x=f+3136|0;w=mz(c[s>>2]|0,x,t)|0;if((w|0)<0){v=-1094995529;i=f;return v|0}t=zV(b,x,w,1110880,16)|0;y=r;c[y>>2]=t;if((t|0)==0){yDb(b,16,2260432,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1094995529;i=f;return v|0}t=wV(b,0,0,0,0)|0;if((t|0)<0){v=t;i=f;return v|0}Ty(c[y>>2]|0,-32,-1,1)|0;y=Ty(c[s>>2]|0,0,0,1)|0;t=F;z=zV(b,x,w,1126128,58)|0;if((z|0)!=0){A=q|0;B=f+2112|0;a:do{if((Xy(z)|0)==0){C=o;D=p;E=p|0;G=p;H=b+1140|0;I=b;J=p+4|0;K=D+6|0;L=p+8|0;M=G+9|0;N=G+10|0;O=G+11|0;P=p+12|0;Q=G+13|0;R=G+14|0;S=G+15|0;G=g|0;T=j|0;while(1){yO(z,q)|0;U=rz(z)|0;V=rz(z)|0;if((V|0)==0){W=H;break a}if((PGb(A,1190784,16)|0)!=0){break}yz(z,2147483647,B,1024)|0;b:do{if((QGb(B,2233360)|0)==0){Vy(z,V,(V|0)<0|0?-1:0)|0;}else{X=V<<1;Y=(X|0)>34?X|1:35;X=WDb(Y)|0;c[o>>2]=X;if((X|0)==0){break}Z=(V|0)==4;c:do{if((U|0)==0&Z){_=rz(z)|0;Lb(X|0,Y|0,2220440,(u=i,i=i+8|0,c[u>>2]=_,u)|0)|0;i=u}else{d:do{switch(U|0){case 1:{yz(z,V,X,Y)|0;_=c[o>>2]|0;if((a[_]|0)!=0){break c}ZDb(_);break b;break};case 4:{if((V|0)!=8){break d}_=sz(z)|0;$=F;do{if((QGb(B,2195192)|0)!=0){if((QGb(B,2178936)|0)==0){break}do{if((QGb(B,2166744)|0)!=0){if((QGb(B,2160040)|0)==0){break}if((QGb(B,2153208)|0)==0){aa=c[o>>2]|0;c[l>>2]=~~(((c[k>>2]=_,c[k+4>>2]=$,+h[k>>3])+-25569.0)*86400.0);ba=mc(l|0)|0;if((ba|0)==0){ZDb(c[o>>2]|0);break b}else{Ac(aa|0,Y|0,2084456,ba|0)|0;break c}}else{ba=(QGb(B,2146192)|0)==0;aa=c[o>>2]|0;if(ba){ca=(c[k>>2]=_,c[k+4>>2]=$,+h[k>>3]);Lb(aa|0,Y|0,2140176,(u=i,i=i+8|0,h[u>>3]=ca,u)|0)|0;i=u;break c}else{Lb(aa|0,Y|0,2133672,(u=i,i=i+16|0,c[u>>2]=_,c[u+8>>2]=$,u)|0)|0;i=u;break c}}}}while(0);aa=c[o>>2]|0;ba=eHb(_,$,1e7,0)|0;da=YGb(ba,F,-2006054656,0)|0;c[m>>2]=da;if((mc(m|0)|0)==0){ZDb(c[o>>2]|0);break b}else{Ac(aa|0,Y|0,2084456,mc(m|0)|0)|0;break c}}}while(0);aa=c[o>>2]|0;c[n>>2]=YGb(eHb(_,$,1e7,0)|0,F,1240428288,0)|0;if((mc(n|0)|0)==0){ZDb(c[o>>2]|0);break b}else{Ac(aa|0,Y|0,2084456,mc(n|0)|0)|0;break c}break};case 3:{if(!Z){break d}aa=(rz(z)|0)!=0;WGb(X|0,(aa?2211320:2202280)|0)|0;break c;break};case 2:{if((QGb(B,2116560)|0)!=0){break d}aa=Ty(z,0,0,1)|0;da=F;yz(z,2147483647,G,1024)|0;do{if((QGb(G,2094584)|0)==0){lz(z)|0;yz(z,2147483647,T,1024)|0;ba=rz(z)|0;if((ba|0)==0){break}ea=LT(b,0)|0;if((ea|0)==0){break}CBb(ea+88|0,2089264,T,0)|0;fa=c[ea+8>>2]|0;c[fa+8>>2]=0;c[fa+48>>2]=8;c[ea+4>>2]=-1;if((TS(z,ea+104|0,ba)|0)<0){break}c[ea+136>>2]=c[ea>>2];ba=ea+140|0;c[ba>>2]=c[ba>>2]|1;ba=ea+72|0;c[ba>>2]=c[ba>>2]|1024}}while(0);Ty(z,YGb(aa,da,V,(V|0)<0|0?-1:0)|0,F,0)|0;$Db(C);break b;break};case 5:{if((V|0)!=2){break d}$=pz(z)|0;Lb(X|0,Y|0,2127440,(u=i,i=i+8|0,c[u>>2]=$,u)|0)|0;i=u;break c;break};case 6:{if((V|0)!=16){break d}mz(z,D,16)|0;$=e[J>>1]|0;_=e[K>>1]|0;ba=d[L]|0;ea=d[M]|0;fa=d[N]|0;ga=d[O]|0;ha=d[P]|0;ia=d[Q]|0;ja=d[R]|0;ka=d[S]|0;Lb(c[o>>2]|0,Y|0,2121432,(u=i,i=i+88|0,c[u>>2]=c[E>>2],c[u+8>>2]=$,c[u+16>>2]=_,c[u+24>>2]=ba,c[u+32>>2]=ea,c[u+40>>2]=fa,c[u+48>>2]=ga,c[u+56>>2]=ha,c[u+64>>2]=ia,c[u+72>>2]=ja,c[u+80>>2]=ka,u)|0)|0;i=u;break c;break};default:{}}}while(0);$Db(C);yDb(I,24,2102712,(u=i,i=i+24|0,c[u>>2]=B,c[u+8>>2]=U,c[u+16>>2]=V,u)|0);i=u;Vy(z,V,(V|0)<0|0?-1:0)|0;break b}}while(0);CBb(H,B,c[o>>2]|0,0)|0;$Db(C)}}while(0);if((Xy(z)|0)!=0){W=H;break a}}C=d[q+1|0]|0;E=d[q+2|0]|0;S=d[q+3|0]|0;R=d[q+4|0]|0;Q=d[q+5|0]|0;P=d[q+6|0]|0;O=d[q+7|0]|0;N=d[q+8|0]|0;M=d[q+9|0]|0;L=d[q+10|0]|0;K=d[q+11|0]|0;J=d[q+12|0]|0;D=d[q+13|0]|0;T=d[q+14|0]|0;G=d[q+15|0]|0;yDb(I,24,2245896,(u=i,i=i+128|0,c[u>>2]=d[A]|0,c[u+8>>2]=C,c[u+16>>2]=E,c[u+24>>2]=S,c[u+32>>2]=R,c[u+40>>2]=Q,c[u+48>>2]=P,c[u+56>>2]=O,c[u+64>>2]=N,c[u+72>>2]=M,c[u+80>>2]=L,c[u+88>>2]=K,c[u+96>>2]=J,c[u+104>>2]=D,c[u+112>>2]=T,c[u+120>>2]=G,u)|0);i=u;W=H}else{W=b+1140|0}}while(0);QG(W,0,1263112);W=z+20|0;ZDb(c[(c[W>>2]|0)+8>>2]|0);$Db(W);$Db(z+4|0);ZDb(z)}do{if((c[b+24>>2]|0)!=0){z=c[c[b+28>>2]>>2]|0;W=zV(b,x,w,1126088,40)|0;if((W|0)==0){break}u=sz(W)|0;A=F;q=sz(W)|0;if((Xy(W)|0)==0){o=r+32|0;B=r+36|0;n=r+40|0;m=A;A=u;u=q;while(1){mT(o,B,n,0,0,A,m,u,0,1)|0;q=sz(W)|0;l=F;j=sz(W)|0;if((Xy(W)|0)==0){m=l;A=q;u=j}else{la=B;break}}}else{la=r+36|0}B=W+20|0;ZDb(c[(c[B>>2]|0)+8>>2]|0);$Db(B);$Db(W+4|0);ZDb(W);if((c[la>>2]|0)==0){break}B=zV(b,x,w,1110816,62)|0;if((B|0)==0){break}u=sz(B)|0;A=F;m=sz(B)|0;n=F;o=r+32|0;if((Xy(B)|0)==0){H=A;A=u;u=n;n=m;do{m=c[la>>2]|0;e:do{if((m|0)>0){I=c[o>>2]|0;j=m;do{j=j-1|0;q=c[I+(j*24|0)+16>>2]>>2;l=(q|0)<0|0?-1:0;if(H>>>0>l>>>0|H>>>0==l>>>0&A>>>0>q>>>0){break e}q=I+(j*24|0)|0;l=c[q+4>>2]|0;if(u>>>0>l>>>0|u>>>0==l>>>0&n>>>0>(c[q>>2]|0)>>>0){c[q>>2]=n;c[q+4>>2]=u}}while((j|0)>0)}}while(0);A=sz(B)|0;H=F;n=sz(B)|0;u=F;}while((Xy(B)|0)==0)}u=B+20|0;ZDb(c[(c[u>>2]|0)+8>>2]|0);$Db(u);$Db(B+4|0);ZDb(B);u=(c[o>>2]|0)+(((c[la>>2]|0)-1|0)*24|0)+8|0;n=c[u+4>>2]|0;H=z+56|0;c[H>>2]=c[u>>2];c[H+4>>2]=n}}while(0);Ty(c[s>>2]|0,y,t,0)|0;v=0;i=f;return v|0}function tV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=c[f>>2]|0;h=wV(a,0,0,0,e)|0;if((h|0)<0){j=h;i=d;return j|0}a=TS(g,b,(c[e>>2]|0)-32|0)|0;if((a|0)<0){j=a;i=d;return j|0}c[b+32>>2]=h;h=f+16|0;f=c[h+4>>2]|0;a=b+8|0;c[a>>2]=c[h>>2];c[a+4>>2]=f;f=c[e>>2]|0;e=(f+7&-8)-f|0;Vy(g,e,(e|0)<0|0?-1:0)|0;j=0;i=d;return j|0}function uV(a){a=a|0;var b=0;b=c[a+12>>2]|0;$Db(b+32|0);a=c[b>>2]|0;b=a+20|0;ZDb(c[(c[b>>2]|0)+8>>2]|0);$Db(b);$Db(a+4|0);ZDb(a);return 0}function vV(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[a+12>>2]|0;g=c[b>>2]|0;h=c[c[a+28>>2]>>2]|0;if((f&10|0)!=0){i=-38;return i|0}j=b+8|0;k=c[j>>2]|0;l=c[j+4>>2]|0;m=(k|0)==0&(l|0)==(-2147483648|0);n=ZGb(d,e,m?0:k,m?0:l)|0;l=F;m=b+32|0;k=b+36|0;o=nT(c[m>>2]|0,c[k>>2]|0,n,l,f)|0;if((o|0)>=0){f=(c[m>>2]|0)+(o*24|0)|0;p=Ty(g,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=F;q=0;if((f|0)<(q|0)|(f|0)==(q|0)&p>>>0<0>>>0){i=-1;return i|0}p=(c[m>>2]|0)+(o*24|0)+8|0;o=c[p>>2]|0;q=c[p+4>>2]|0;p=b+16|0;c[p>>2]=o;c[p+4>>2]=q;f=c[j>>2]|0;r=c[j+4>>2]|0;if((f|0)==0&(r|0)==(-2147483648|0)){s=q;t=o}else{j=YGb(f,r,o,q)|0;q=F;c[p>>2]=j;c[p+4>>2]=q;s=q;t=j}j=b+24|0;c[j>>2]=t;c[j+4>>2]=s;i=0;return i|0}s=b+24|0;b=c[s>>2]|0;j=c[s+4>>2]|0;do{if((b|0)==0&(j|0)==(-2147483648|0)|((j|0)>(e|0)|(j|0)==(e|0)&b>>>0>d>>>0)){s=Ty(g,0,0,0)|0;t=F;q=0;if((t|0)<(q|0)|(t|0)==(q|0)&s>>>0<0>>>0){i=-1}else{break}return i|0}else{s=h+56|0;q=c[s>>2]|0;t=c[s+4>>2]|0;if(!(((q|0)!=0|(t|0)!=(-2147483648|0))&((l|0)>(t|0)|(l|0)==(t|0)&n>>>0>q>>>0))){break}q=c[k>>2]|0;if((q|0)==0){break}t=(c[m>>2]|0)+((q-1|0)*24|0)|0;q=Ty(g,c[t>>2]|0,c[t+4>>2]|0,0)|0;t=F;s=0;if((t|0)<(s|0)|(t|0)==(s|0)&q>>>0<0>>>0){i=-1}else{break}return i|0}}while(0);i=(wV(a,1,d,e,0)|0)>>31&-34;return i|0}function wV(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0;j=i;i=i+664|0;k=j|0;l=j+16|0;m=j+32|0;n=j+48|0;o=j+64|0;p=j+80|0;q=j+96|0;r=j+112|0;s=j+376|0;t=j+384|0;u=j+392|0;v=j+408|0;w=j+424|0;x=j+440|0;y=j+456|0;z=j+472|0;A=j+488|0;B=j+504|0;C=j+520|0;D=j+536|0;E=j+552|0;G=j+568|0;H=j+584|0;I=j+600|0;J=j+616|0;K=j+632|0;L=j+648|0;M=c[b+12>>2]|0;N=c[M>>2]|0;if((Xy(N)|0)!=0){O=-541478725;i=j;return O|0}P=k|0;Q=l|0;R=m|0;S=n|0;T=b+28|0;U=o|0;V=p|0;W=q|0;X=r|0;Y=b;Z=t|0;_=t+3|0;t=M+16|0;$=M+24|0;aa=M+8|0;M=(e|0)!=1;ba=(e|0)==0;e=u|0;ca=u+1|0;da=u+2|0;ea=u+3|0;fa=u+4|0;ga=u+5|0;ha=u+6|0;ia=u+7|0;ja=u+8|0;ka=u+9|0;la=u+10|0;ma=u+11|0;na=u+12|0;oa=u+13|0;pa=u+14|0;qa=u+15|0;u=v|0;ra=v+1|0;sa=v+2|0;ta=v+3|0;ua=v+4|0;va=v+5|0;wa=v+6|0;xa=v+7|0;ya=v+8|0;za=v+9|0;Aa=v+10|0;Ba=v+11|0;Ca=v+12|0;Da=v+13|0;Ea=v+14|0;Fa=v+15|0;v=w|0;Ga=w+1|0;Ha=w+2|0;Ia=w+3|0;Ja=w+4|0;Ka=w+5|0;La=w+6|0;Ma=w+7|0;Na=w+8|0;Oa=w+9|0;Pa=w+10|0;Qa=w+11|0;Ra=w+12|0;Sa=w+13|0;Ta=w+14|0;Ua=w+15|0;w=x|0;Va=x+1|0;Wa=x+2|0;Xa=x+3|0;Ya=x+4|0;Za=x+5|0;_a=x+6|0;$a=x+7|0;ab=x+8|0;bb=x+9|0;cb=x+10|0;db=x+11|0;eb=x+12|0;fb=x+13|0;gb=x+14|0;hb=x+15|0;x=y|0;ib=y+1|0;jb=y+2|0;kb=y+3|0;lb=y+4|0;mb=y+5|0;nb=y+6|0;ob=y+7|0;pb=y+8|0;qb=y+9|0;rb=y+10|0;sb=y+11|0;tb=y+12|0;ub=y+13|0;vb=y+14|0;wb=y+15|0;y=z|0;xb=z+1|0;yb=z+2|0;zb=z+3|0;Ab=z+4|0;Bb=z+5|0;Cb=z+6|0;Db=z+7|0;Eb=z+8|0;Fb=z+9|0;Gb=z+10|0;Hb=z+11|0;Ib=z+12|0;Jb=z+13|0;Kb=z+14|0;Lb=z+15|0;z=A|0;Mb=A+1|0;Nb=A+2|0;Ob=A+3|0;Pb=A+4|0;Qb=A+5|0;Rb=A+6|0;Sb=A+7|0;Tb=A+8|0;Ub=A+9|0;Vb=A+10|0;Wb=A+11|0;Xb=A+12|0;Yb=A+13|0;Zb=A+14|0;_b=A+15|0;A=B|0;$b=B+1|0;ac=B+2|0;bc=B+3|0;cc=B+4|0;dc=B+5|0;ec=B+6|0;fc=B+7|0;gc=B+8|0;hc=B+9|0;ic=B+10|0;jc=B+11|0;kc=B+12|0;lc=B+13|0;mc=B+14|0;nc=B+15|0;B=C|0;oc=C+1|0;pc=C+2|0;qc=C+3|0;rc=C+4|0;sc=C+5|0;tc=C+6|0;uc=C+7|0;vc=C+8|0;wc=C+9|0;xc=C+10|0;yc=C+11|0;zc=C+12|0;Ac=C+13|0;Bc=C+14|0;Cc=C+15|0;C=D|0;Dc=D+1|0;Ec=D+2|0;Fc=D+3|0;Gc=D+4|0;Hc=D+5|0;Ic=D+6|0;Jc=D+7|0;Kc=D+8|0;Lc=D+9|0;Mc=D+10|0;Nc=D+11|0;Oc=D+12|0;Pc=D+13|0;Qc=D+14|0;Rc=D+15|0;D=E|0;Sc=E+1|0;Tc=E+2|0;Uc=E+3|0;Vc=E+4|0;Wc=E+5|0;Xc=E+6|0;Yc=E+7|0;Zc=E+8|0;_c=E+9|0;$c=E+10|0;ad=E+11|0;bd=E+12|0;cd=E+13|0;dd=E+14|0;ed=E+15|0;E=G|0;fd=G+1|0;gd=G+2|0;hd=G+3|0;id=G+4|0;jd=G+5|0;kd=G+6|0;ld=G+7|0;md=G+8|0;nd=G+9|0;od=G+10|0;pd=G+11|0;qd=G+12|0;rd=G+13|0;sd=G+14|0;td=G+15|0;G=H|0;ud=H+1|0;vd=H+2|0;wd=H+3|0;xd=H+4|0;yd=H+5|0;zd=H+6|0;Ad=H+7|0;Bd=H+8|0;Cd=H+9|0;Dd=H+10|0;Ed=H+11|0;Fd=H+12|0;Gd=H+13|0;Hd=H+14|0;Id=H+15|0;H=I|0;Jd=I+1|0;Kd=I+2|0;Ld=I+3|0;Md=I+4|0;Nd=I+5|0;Od=I+6|0;Pd=I+7|0;Qd=I+8|0;Rd=I+9|0;Sd=I+10|0;Td=I+11|0;Ud=I+12|0;Vd=I+13|0;Wd=I+14|0;Xd=I+15|0;I=J|0;Yd=J+1|0;Zd=J+2|0;_d=J+3|0;$d=J+4|0;ae=J+5|0;be=J+6|0;ce=J+7|0;de=J+8|0;ee=J+9|0;fe=J+10|0;ge=J+11|0;he=J+12|0;ie=J+13|0;je=J+14|0;ke=J+15|0;J=K|0;le=K+1|0;me=K+2|0;ne=K+3|0;oe=K+4|0;pe=K+5|0;qe=K+6|0;re=K+7|0;se=K+8|0;te=K+9|0;ue=K+10|0;ve=K+11|0;we=K+12|0;xe=K+13|0;ye=K+14|0;ze=K+15|0;K=L|0;Ae=L+1|0;Be=L+2|0;Ce=L+3|0;De=L+4|0;Ee=L+5|0;Fe=L+6|0;Ge=L+7|0;He=L+8|0;Ie=L+9|0;Je=L+10|0;Ke=L+11|0;Le=L+12|0;Me=L+13|0;Ne=L+14|0;Oe=L+15|0;L=k+1|0;Pe=k+2|0;Qe=k+3|0;Re=k+4|0;Se=k+5|0;Te=k+6|0;Ue=k+7|0;Ve=k+8|0;We=k+9|0;Xe=k+10|0;Ye=k+11|0;Ze=k+12|0;_e=k+13|0;$e=k+14|0;af=k+15|0;a:while(1){yO(N,k)|0;bf=rz(N)|0;if((bf|0)<32){O=-541478725;cf=76;break}df=(rz(N)|0)&32767;Vy(N,8,0)|0;b:do{if((PGb(P,1286512,16)|0)==0){if((aU(b,df)|0)>=0){ef=32;break}Vy(N,28,0)|0;yO(N,l)|0;yO(N,m)|0;Vy(N,12,0)|0;yO(N,n)|0;ff=rz(N)|0;xV(b,0,df,Q,R,S,ff)|0;ef=ff+124|0}else{if((PGb(P,1134952,16)|0)==0){ff=aU(b,df)|0;if(!((ff|0)>-1)){ef=32;break}gf=c[(c[(c[T>>2]|0)+(ff<<2)>>2]|0)+12>>2]|0;if((gf|0)==0){ef=32;break}if((c[gf>>2]|0)!=0){ef=32;break}Vy(N,12,0)|0;yO(N,o)|0;yO(N,p)|0;Vy(N,12,0)|0;yO(N,q)|0;gf=rz(N)|0;xV(b,c[(c[T>>2]|0)+(ff<<2)>>2]|0,df,U,V,W,gf)|0;ef=gf+108|0;break}do{if((PGb(P,2365656,16)|0)!=0){if((PGb(P,2365608,16)|0)==0){break}if((PGb(P,2365624,16)|0)==0){break}if((PGb(P,2365560,16)|0)==0){break}if((PGb(P,2365544,16)|0)==0){break}if((PGb(P,2365528,16)|0)==0){break}if((PGb(P,2365640,16)|0)==0){gf=aU(b,df)|0;if(!((gf|0)>-1)){ef=32;break b}ff=c[(c[T>>2]|0)+(gf<<2)>>2]|0;Vy(N,8,0)|0;gf=lz(N)|0;if((gf|0)==2){hf=ff+72|0;c[hf>>2]=c[hf>>2]|128;ef=41;break b}else if((gf|0)==3){gf=ff+72|0;c[gf>>2]=c[gf>>2]|256;ef=41;break b}else{ef=41;break b}}if((PGb(P,2365592,16)|0)==0){gf=aU(b,df)|0;if(!((gf|0)>-1)){ef=32;break b}Vy(N,12,0)|0;if((rz(N)|0)==0){ef=48;break b}yDb(Y,24,2121808,(jf=i,i=i+8|0,c[jf>>2]=gf,jf)|0);i=jf;ef=48;break b}if((PGb(P,2365576,16)|0)==0){gf=aU(b,df)|0;if(!((gf|0)>-1)){ef=32;break b}ff=c[(c[T>>2]|0)+(gf<<2)>>2]|0;Vy(N,12,0)|0;mz(N,Z,3)|0;if((a[Z]|0)==0){ef=47;break b}a[_]=0;CBb(ff+88|0,2061208,Z,0)|0;if((QGb(Z,2014592)|0)!=0){if((QGb(Z,1974024)|0)!=0){ef=47;break b}}gf=ff+72|0;c[gf>>2]=c[gf>>2]|256;ef=47;break b}if((PGb(P,1110800,16)|0)==0){if(!((aU(b,df)|0)>-1)){ef=32;break b}Vy(N,8,0)|0;gf=sz(N)|0;ff=F;c[t>>2]=gf;c[t+4>>2]=ff;if((gf|0)==(-1|0)&(ff|0)==(-1|0)){c[t>>2]=0;c[t+4>>2]=-2147483648;ef=48;break b}c[$>>2]=gf;c[$+4>>2]=ff;hf=c[aa>>2]|0;kf=c[aa+4>>2]|0;if((hf|0)==0&(kf|0)==(-2147483648|0)|((ff|0)<(kf|0)|(ff|0)==(kf|0)&gf>>>0<hf>>>0)){c[aa>>2]=gf;c[aa+4>>2]=ff}if(M|((ff|0)<(g|0)|(ff|0)==(g|0)&gf>>>0<f>>>0)){ef=48;break b}else{cf=45;break a}}if((PGb(P,1234728,16)|0)==0){lf=aU(b,df)|0;if(!(ba&(lf|0)>-1&(bf|0)>32)){ef=32;break b}mf=c[(c[(c[T>>2]|0)+(lf<<2)>>2]|0)+12>>2]|0;if((mf|0)==0){ef=32;break b}else{cf=49;break a}}a[e]=-125;a[ca]=-107;a[da]=116;a[ea]=64;a[fa]=-99;a[ga]=107;a[ha]=-20;a[ia]=78;a[ja]=-76;a[ka]=60;a[la]=103;a[ma]=-95;a[na]=-128;a[oa]=30;a[pa]=26;a[qa]=-101;if((PGb(P,e,16)|0)==0){gf=aU(b,df)|0;if(!((gf|0)>-1)){ef=32;break b}yDb(Y,24,1945120,(jf=i,i=i+8|0,c[jf>>2]=gf,jf)|0);i=jf;ef=32;break b}a[u]=20;a[ra]=86;a[sa]=26;a[ta]=12;a[ua]=-51;a[va]=48;a[wa]=64;a[xa]=79;a[ya]=-68;a[za]=-65;a[Aa]=-48;a[Ba]=62;a[Ca]=82;a[Da]=48;a[Ea]=98;a[Fa]=7;if((PGb(P,u,16)|0)==0){ef=32;break b}a[v]=121;a[Ga]=102;a[Ha]=-75;a[Ia]=-32;a[Ja]=-71;a[Ka]=18;a[La]=-52;a[Ma]=67;a[Na]=-73;a[Oa]=-33;a[Pa]=87;a[Qa]=-116;a[Ra]=-86;a[Sa]=90;a[Ta]=123;a[Ua]=99;if((PGb(P,v,16)|0)==0){ef=32;break b}a[w]=2;a[Va]=-82;a[Wa]=91;a[Xa]=47;a[Ya]=-113;a[Za]=123;a[_a]=96;a[$a]=79;a[ab]=-126;a[bb]=-42;a[cb]=-28;a[db]=-22;a[eb]=47;a[fb]=31;a[gb]=76;a[hb]=-103;if((PGb(P,w,16)|0)==0){ef=32;break b}if((PGb(P,1286528,16)|0)==0){ef=32;break b}a[x]=-52;a[ib]=50;a[jb]=100;a[kb]=-35;a[lb]=41;a[mb]=-30;a[nb]=-37;a[ob]=64;a[pb]=-128;a[qb]=-10;a[rb]=-46;a[sb]=99;a[tb]=40;a[ub]=-46;a[vb]=118;a[wb]=31;if((PGb(P,x,16)|0)==0){ef=32;break b}a[y]=-27;a[xb]=-59;a[yb]=103;a[zb]=-112;a[Ab]=92;a[Bb]=76;a[Cb]=5;a[Db]=66;a[Eb]=-122;a[Fb]=-56;a[Gb]=122;a[Hb]=-2;a[Ib]=32;a[Jb]=-2;a[Kb]=30;a[Lb]=-6;if((PGb(P,y,16)|0)==0){ef=32;break b}a[z]=-128;a[Mb]=109;a[Nb]=-13;a[Ob]=65;a[Pb]=50;a[Qb]=65;a[Rb]=-62;a[Sb]=76;a[Tb]=-79;a[Ub]=33;a[Vb]=1;a[Wb]=-92;a[Xb]=50;a[Yb]=25;a[Zb]=-40;a[_b]=27;if((PGb(P,z,16)|0)==0){ef=32;break b}a[A]=81;a[$b]=29;a[ac]=-85;a[bc]=114;a[cc]=-46;a[dc]=-121;a[ec]=-101;a[fc]=72;a[gc]=-70;a[hc]=17;a[ic]=14;a[jc]=8;a[kc]=-36;a[lc]=33;a[mc]=2;a[nc]=67;if((PGb(P,A,16)|0)==0){ef=32;break b}a[B]=101;a[oc]=-113;a[pc]=-4;a[qc]=71;a[rc]=-69;a[sc]=-30;a[tc]=52;a[uc]=70;a[vc]=-100;a[wc]=-17;a[xc]=-3;a[yc]=-65;a[zc]=-26;a[Ac]=38;a[Bc]=29;a[Cc]=92;if((PGb(P,B,16)|0)==0){ef=32;break b}a[C]=-53;a[Dc]=-59;a[Ec]=104;a[Fc]=-128;a[Gc]=4;a[Hc]=60;a[Ic]=43;a[Jc]=73;a[Kc]=-76;a[Lc]=125;a[Mc]=3;a[Nc]=8;a[Oc]=-126;a[Pc]=13;a[Qc]=-50;a[Rc]=81;if((PGb(P,C,16)|0)==0){ef=32;break b}a[D]=-68;a[Sc]=46;a[Tc]=-81;a[Uc]=-126;a[Vc]=-90;a[Wc]=48;a[Xc]=100;a[Yc]=66;a[Zc]=-88;a[_c]=11;a[$c]=-83;a[ad]=46;a[bd]=19;a[cd]=114;a[dd]=-84;a[ed]=96;if((PGb(P,D,16)|0)==0){ef=32;break b}a[E]=30;a[fd]=-66;a[gd]=-61;a[hd]=-59;a[id]=67;a[jd]=-110;a[kd]=-36;a[ld]=17;a[md]=-123;a[nd]=-27;a[od]=0;a[pd]=18;a[qd]=63;a[rd]=111;a[sd]=115;a[td]=-71;if((PGb(P,E,16)|0)==0){ef=32;break b}a[G]=59;a[ud]=-122;a[vd]=-94;a[wd]=-79;a[xd]=-21;a[yd]=30;a[zd]=-61;a[Ad]=68;a[Bd]=-116;a[Cd]=-120;a[Dd]=28;a[Ed]=-93;a[Fd]=-1;a[Gd]=-29;a[Hd]=-25;a[Id]=106;if((PGb(P,G,16)|0)==0){ef=32;break b}a[H]=78;a[Jd]=127;a[Kd]=76;a[Ld]=91;a[Md]=-60;a[Nd]=-48;a[Od]=56;a[Pd]=75;a[Qd]=-88;a[Rd]=62;a[Sd]=33;a[Td]=127;a[Ud]=123;a[Vd]=-65;a[Wd]=82;a[Xd]=-25;if((PGb(P,H,16)|0)==0){ef=32;break b}a[I]=99;a[Yd]=54;a[Zd]=-21;a[_d]=-2;a[$d]=-95;a[ae]=126;a[be]=-39;a[ce]=17;a[de]=-125;a[ee]=8;a[fe]=0;a[ge]=7;a[he]=-23;a[ie]=94;a[je]=-83;a[ke]=-115;if((PGb(P,I,16)|0)==0){ef=32;break b}a[J]=112;a[le]=-23;a[me]=-15;a[ne]=-8;a[oe]=-119;a[pe]=-92;a[qe]=76;a[re]=77;a[se]=-125;a[te]=115;a[ue]=-72;a[ve]=18;a[we]=-32;a[xe]=-43;a[ye]=-8;a[ze]=30;if((PGb(P,J,16)|0)==0){ef=32;break b}if((PGb(P,1202656,16)|0)==0){ef=32;break b}if((PGb(P,1130032,16)|0)==0){ef=32;break b}if((PGb(P,1134968,16)|0)==0){ef=32;break b}a[K]=-9;a[Ae]=16;a[Be]=2;a[Ce]=-71;a[De]=-18;a[Ee]=124;a[Fe]=-19;a[Ge]=78;a[He]=-67;a[Ie]=127;a[Je]=5;a[Ke]=64;a[Le]=53;a[Me]=-122;a[Ne]=24;a[Oe]=-95;if((PGb(P,K,16)|0)==0){ef=32;break b}gf=d[L]|0;ff=d[Pe]|0;hf=d[Qe]|0;kf=d[Re]|0;nf=d[Se]|0;of=d[Te]|0;pf=d[Ue]|0;qf=d[Ve]|0;rf=d[We]|0;sf=d[Xe]|0;tf=d[Ye]|0;uf=d[Ze]|0;vf=d[_e]|0;wf=d[$e]|0;xf=d[af]|0;yDb(Y,24,1920416,(jf=i,i=i+128|0,c[jf>>2]=d[P]|0,c[jf+8>>2]=gf,c[jf+16>>2]=ff,c[jf+24>>2]=hf,c[jf+32>>2]=kf,c[jf+40>>2]=nf,c[jf+48>>2]=of,c[jf+56>>2]=pf,c[jf+64>>2]=qf,c[jf+72>>2]=rf,c[jf+80>>2]=sf,c[jf+88>>2]=tf,c[jf+96>>2]=uf,c[jf+104>>2]=vf,c[jf+112>>2]=wf,c[jf+120>>2]=xf,jf)|0);i=jf;ef=32;break b}}while(0);xf=aU(b,df)|0;if(!((xf|0)>-1)){ef=32;break}wf=c[(c[T>>2]|0)+(xf<<2)>>2]|0;c[s>>2]=X;Vy(N,8,0)|0;if((PGb(P,2365608,16)|0)==0){cf=21}else{if((PGb(P,2365624,16)|0)==0){cf=21}else{yf=40}}if((cf|0)==21){cf=0;Vy(N,6,0)|0;yf=46}xf=bf-yf|0;vf=xf>>>0>258>>>0?258:xf;mz(N,X,vf)|0;LJ(b,wf,0,s,r+vf|0,0,0,0,0)|0;ef=vf+yf|0}}while(0);df=(bf+7&-8)-ef|0;Vy(N,df,(df|0)<0|0?-1:0)|0;if((Xy(N)|0)!=0){O=-541478725;cf=76;break}}if((cf|0)==45){ef=bf-41&-8;Vy(N,ef,(ef|0)<0|0?-1:0)|0;O=0;i=j;return O|0}else if((cf|0)==49){c[mf>>2]=1;if((h|0)==0){O=lf;i=j;return O|0}c[h>>2]=bf;O=lf;i=j;return O|0}else if((cf|0)==76){i=j;return O|0}return 0}function xV(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;l=i;i=i+64|0;m=l|0;n=l+16|0;o=l+32|0;p=l+48|0;q=b+12|0;r=c[c[q>>2]>>2]|0;do{if((PGb(h,1190832,16)|0)==0){if((PGb(j,1218688,16)|0)!=0){break}if((k|0)<32){yDb(b,24,1899344,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;Vy(r,k,(k|0)<0|0?-1:0)|0;t=0;i=l;return t|0}else{u=k-32|0;Vy(r,u,(u|0)<0|0?-1:0)|0;yO(r,m)|0;yO(r,n)|0;v=-k|0;Ty(r,v,(v|0)<0|0?-1:0,1)|0;v=xV(b,e,f,g,m|0,n|0,u)|0;Vy(r,32,0)|0;t=v;i=l;return t|0}}}while(0);if((PGb(g,1190816,16)|0)==0){n=yV(b,e,f,1)|0;if((n|0)==0){t=0;i=l;return t|0}do{if((PGb(j,1218624,16)|0)==0){if((AO(r,c[n+8>>2]|0,k)|0)<0){t=0}else{break}i=l;return t|0}else{if((PGb(j,1218656,16)|0)!=0){m=d[j+1|0]|0;v=d[j+2|0]|0;u=d[j+3|0]|0;w=d[j+4|0]|0;x=d[j+5|0]|0;y=d[j+6|0]|0;z=d[j+7|0]|0;A=d[j+8|0]|0;B=d[j+9|0]|0;C=d[j+10|0]|0;D=d[j+11|0]|0;E=d[j+12|0]|0;F=d[j+13|0]|0;G=d[j+14|0]|0;H=d[j+15|0]|0;yDb(b,24,1879080,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=m,c[s+16>>2]=v,c[s+24>>2]=u,c[s+32>>2]=w,c[s+40>>2]=x,c[s+48>>2]=y,c[s+56>>2]=z,c[s+64>>2]=A,c[s+72>>2]=B,c[s+80>>2]=C,c[s+88>>2]=D,c[s+96>>2]=E,c[s+104>>2]=F,c[s+112>>2]=G,c[s+120>>2]=H,s)|0);i=s}Vy(r,k,(k|0)<0|0?-1:0)|0;}}while(0);H=h+4|0;G=o|0;a[G]=0;a[o+1|0]=0;a[o+2|0]=16;a[o+3|0]=0;a[o+4|0]=-128;a[o+5|0]=0;a[o+6|0]=0;a[o+7|0]=-86;a[o+8|0]=0;a[o+9|0]=56;a[o+10|0]=-101;a[o+11|0]=113;if((PGb(H,G,12)|0)==0){G=h;o=n+8|0;F=BO(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0,c[(c[o>>2]|0)+792>>2]|0)|0;c[(c[o>>2]|0)+48>>2]=F;t=n;i=l;return t|0}if((PGb(h,678936,16)|0)!=0){F=zO(1238560,h)|0;c[(c[n+8>>2]|0)+48>>2]=F;if((F|0)!=0){t=n;i=l;return t|0}F=d[h+1|0]|0;o=d[h+2|0]|0;G=d[h+3|0]|0;E=d[H]|0;H=d[h+5|0]|0;D=d[h+6|0]|0;C=d[h+7|0]|0;B=d[h+8|0]|0;A=d[h+9|0]|0;z=d[h+10|0]|0;y=d[h+11|0]|0;x=d[h+12|0]|0;w=d[h+13|0]|0;u=d[h+14|0]|0;v=d[h+15|0]|0;yDb(b,24,2312360,(s=i,i=i+128|0,c[s>>2]=d[h]|0,c[s+8>>2]=F,c[s+16>>2]=o,c[s+24>>2]=G,c[s+32>>2]=E,c[s+40>>2]=H,c[s+48>>2]=D,c[s+56>>2]=C,c[s+64>>2]=B,c[s+72>>2]=A,c[s+80>>2]=z,c[s+88>>2]=y,c[s+96>>2]=x,c[s+104>>2]=w,c[s+112>>2]=u,c[s+120>>2]=v,s)|0);i=s;t=n;i=l;return t|0}v=c[n+8>>2]|0;u=c[v+96>>2]|0;do{if((u|0)!=0){if((c[v+100>>2]|0)<=21){break}w=u;x=(d[w]|d[w+1|0]<<8)<<16>>16&65535;if((x|0)==4){c[v+48>>2]=86017}else if((x|0)==1){c[v+48>>2]=86059}else if((x|0)==2){c[v+48>>2]=86016}x=u+2|0;c[v+72>>2]=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24;x=u+6|0;w=(d[x]|d[x+1|0]<<8)<<16>>16&65535;if((w|0)==1|(w|0)==2|(w|0)==4){c[v+416>>2]=2;x=v+448|0;c[x>>2]=3;c[x+4>>2]=0;t=n;i=l;return t|0}else if((w|0)==8){c[v+416>>2]=1;w=v+448|0;c[w>>2]=4;c[w+4>>2]=0;t=n;i=l;return t|0}else{t=n;i=l;return t|0}}}while(0);yDb(b,24,2337312,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=n;i=l;return t|0}if((PGb(g,1190800,16)|0)==0){n=yV(b,e,f,0)|0;if((n|0)==0){t=0;i=l;return t|0}do{if((PGb(j,1218640,16)|0)==0){v=c[c[q>>2]>>2]|0;Vy(v,72,0)|0;CO(v,n,0)|0;v=k-112|0;u=(v|0)>0;Vy(r,u?v:0,u?(v|0)<0|0?-1:0:0)|0;}else{if((PGb(j,1218672,16)|0)==0){v=c[c[q>>2]>>2]|0;Vy(v,72,0)|0;CO(v,n,0)|0;v=k-112|0;u=(v|0)>0;Vy(r,u?v:0,u?(v|0)<0|0?-1:0:0)|0;break}if((PGb(j,1218656,16)|0)!=0){v=d[j+1|0]|0;u=d[j+2|0]|0;w=d[j+3|0]|0;x=d[j+4|0]|0;y=d[j+5|0]|0;z=d[j+6|0]|0;A=d[j+7|0]|0;B=d[j+8|0]|0;C=d[j+9|0]|0;D=d[j+10|0]|0;H=d[j+11|0]|0;E=d[j+12|0]|0;G=d[j+13|0]|0;o=d[j+14|0]|0;F=d[j+15|0]|0;yDb(b,24,1879080,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=v,c[s+16>>2]=u,c[s+24>>2]=w,c[s+32>>2]=x,c[s+40>>2]=y,c[s+48>>2]=z,c[s+56>>2]=A,c[s+64>>2]=B,c[s+72>>2]=C,c[s+80>>2]=D,c[s+88>>2]=H,c[s+96>>2]=E,c[s+104>>2]=G,c[s+112>>2]=o,c[s+120>>2]=F,s)|0);i=s}Vy(r,k,(k|0)<0|0?-1:0)|0;}}while(0);q=h+4|0;F=p|0;a[F]=0;a[p+1|0]=0;a[p+2|0]=16;a[p+3|0]=0;a[p+4|0]=-128;a[p+5|0]=0;a[p+6|0]=0;a[p+7|0]=-86;a[p+8|0]=0;a[p+9|0]=56;a[p+10|0]=-101;a[p+11|0]=113;if((PGb(q,F,12)|0)==0){F=h;p=vT(1240808,d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0;c[(c[n+8>>2]|0)+48>>2]=p;I=p}else{p=zO(1089848,h)|0;c[(c[n+8>>2]|0)+48>>2]=p;I=p}if((I|0)!=0){t=n;i=l;return t|0}I=d[h+1|0]|0;p=d[h+2|0]|0;F=d[h+3|0]|0;o=d[q]|0;q=d[h+5|0]|0;G=d[h+6|0]|0;E=d[h+7|0]|0;H=d[h+8|0]|0;D=d[h+9|0]|0;C=d[h+10|0]|0;B=d[h+11|0]|0;A=d[h+12|0]|0;z=d[h+13|0]|0;y=d[h+14|0]|0;x=d[h+15|0]|0;yDb(b,24,2312360,(s=i,i=i+128|0,c[s>>2]=d[h]|0,c[s+8>>2]=I,c[s+16>>2]=p,c[s+24>>2]=F,c[s+32>>2]=o,c[s+40>>2]=q,c[s+48>>2]=G,c[s+56>>2]=E,c[s+64>>2]=H,c[s+72>>2]=D,c[s+80>>2]=C,c[s+88>>2]=B,c[s+96>>2]=A,c[s+104>>2]=z,c[s+112>>2]=y,c[s+120>>2]=x,s)|0);i=s;t=n;i=l;return t|0}do{if((PGb(g,678888,16)|0)==0){if((PGb(h,678952,16)|0)!=0){break}n=yV(b,e,f,3)|0;if((n|0)==0){t=0;i=l;return t|0}if((PGb(j,1218656,16)|0)!=0){x=d[j+1|0]|0;y=d[j+2|0]|0;z=d[j+3|0]|0;A=d[j+4|0]|0;B=d[j+5|0]|0;C=d[j+6|0]|0;D=d[j+7|0]|0;H=d[j+8|0]|0;E=d[j+9|0]|0;G=d[j+10|0]|0;q=d[j+11|0]|0;o=d[j+12|0]|0;F=d[j+13|0]|0;p=d[j+14|0]|0;I=d[j+15|0]|0;yDb(b,24,1879080,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=x,c[s+16>>2]=y,c[s+24>>2]=z,c[s+32>>2]=A,c[s+40>>2]=B,c[s+48>>2]=C,c[s+56>>2]=D,c[s+64>>2]=H,c[s+72>>2]=E,c[s+80>>2]=G,c[s+88>>2]=q,c[s+96>>2]=o,c[s+104>>2]=F,c[s+112>>2]=p,c[s+120>>2]=I,s)|0);i=s}Vy(r,k,(k|0)<0|0?-1:0)|0;c[(c[n+8>>2]|0)+48>>2]=94209;t=n;i=l;return t|0}}while(0);do{if((PGb(g,678856,16)|0)==0){if((PGb(h,678904,16)|0)!=0){if((PGb(h,678968,16)|0)!=0){break}}n=yV(b,e,f,3)|0;if((n|0)==0){t=0;i=l;return t|0}if((PGb(j,1218656,16)|0)!=0){I=d[j+1|0]|0;p=d[j+2|0]|0;F=d[j+3|0]|0;o=d[j+4|0]|0;q=d[j+5|0]|0;G=d[j+6|0]|0;E=d[j+7|0]|0;H=d[j+8|0]|0;D=d[j+9|0]|0;C=d[j+10|0]|0;B=d[j+11|0]|0;A=d[j+12|0]|0;z=d[j+13|0]|0;y=d[j+14|0]|0;x=d[j+15|0]|0;yDb(b,24,1879080,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=I,c[s+16>>2]=p,c[s+24>>2]=F,c[s+32>>2]=o,c[s+40>>2]=q,c[s+48>>2]=G,c[s+56>>2]=E,c[s+64>>2]=H,c[s+72>>2]=D,c[s+80>>2]=C,c[s+88>>2]=B,c[s+96>>2]=A,c[s+104>>2]=z,c[s+112>>2]=y,c[s+120>>2]=x,s)|0);i=s}Vy(r,k,(k|0)<0|0?-1:0)|0;x=(PGb(h,678904,16)|0)==0;c[(c[n+8>>2]|0)+48>>2]=x?94215:1664495672;t=n;i=l;return t|0}}while(0);do{if((PGb(g,678872,16)|0)==0){if((PGb(h,678920,16)|0)!=0){break}if((PGb(j,1218656,16)|0)!=0){f=d[j+1|0]|0;e=d[j+2|0]|0;n=d[j+3|0]|0;x=d[j+4|0]|0;y=d[j+5|0]|0;z=d[j+6|0]|0;A=d[j+7|0]|0;B=d[j+8|0]|0;C=d[j+9|0]|0;D=d[j+10|0]|0;H=d[j+11|0]|0;E=d[j+12|0]|0;G=d[j+13|0]|0;q=d[j+14|0]|0;o=d[j+15|0]|0;yDb(b,24,1879080,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=f,c[s+16>>2]=e,c[s+24>>2]=n,c[s+32>>2]=x,c[s+40>>2]=y,c[s+48>>2]=z,c[s+56>>2]=A,c[s+64>>2]=B,c[s+72>>2]=C,c[s+80>>2]=D,c[s+88>>2]=H,c[s+96>>2]=E,c[s+104>>2]=G,c[s+112>>2]=q,c[s+120>>2]=o,s)|0);i=s}Vy(r,k,(k|0)<0|0?-1:0)|0;t=0;i=l;return t|0}}while(0);o=d[g+1|0]|0;q=d[g+2|0]|0;G=d[g+3|0]|0;E=d[g+4|0]|0;H=d[g+5|0]|0;D=d[g+6|0]|0;C=d[g+7|0]|0;B=d[g+8|0]|0;A=d[g+9|0]|0;z=d[g+10|0]|0;y=d[g+11|0]|0;x=d[g+12|0]|0;n=d[g+13|0]|0;e=d[g+14|0]|0;f=d[g+15|0]|0;F=d[h]|0;p=d[h+1|0]|0;I=d[h+2|0]|0;w=d[h+3|0]|0;u=d[h+4|0]|0;v=d[h+5|0]|0;m=d[h+6|0]|0;J=d[h+7|0]|0;K=d[h+8|0]|0;L=d[h+9|0]|0;M=d[h+10|0]|0;N=d[h+11|0]|0;O=d[h+12|0]|0;P=d[h+13|0]|0;Q=d[h+14|0]|0;R=d[h+15|0]|0;h=d[j]|0;S=d[j+1|0]|0;T=d[j+2|0]|0;U=d[j+3|0]|0;V=d[j+4|0]|0;W=d[j+5|0]|0;X=d[j+6|0]|0;Y=d[j+7|0]|0;Z=d[j+8|0]|0;_=d[j+9|0]|0;$=d[j+10|0]|0;aa=d[j+11|0]|0;ba=d[j+12|0]|0;ca=d[j+13|0]|0;da=d[j+14|0]|0;ea=d[j+15|0]|0;yDb(b,24,2292192,(s=i,i=i+384|0,c[s>>2]=d[g]|0,c[s+8>>2]=o,c[s+16>>2]=q,c[s+24>>2]=G,c[s+32>>2]=E,c[s+40>>2]=H,c[s+48>>2]=D,c[s+56>>2]=C,c[s+64>>2]=B,c[s+72>>2]=A,c[s+80>>2]=z,c[s+88>>2]=y,c[s+96>>2]=x,c[s+104>>2]=n,c[s+112>>2]=e,c[s+120>>2]=f,c[s+128>>2]=F,c[s+136>>2]=p,c[s+144>>2]=I,c[s+152>>2]=w,c[s+160>>2]=u,c[s+168>>2]=v,c[s+176>>2]=m,c[s+184>>2]=J,c[s+192>>2]=K,c[s+200>>2]=L,c[s+208>>2]=M,c[s+216>>2]=N,c[s+224>>2]=O,c[s+232>>2]=P,c[s+240>>2]=Q,c[s+248>>2]=R,c[s+256>>2]=h,c[s+264>>2]=S,c[s+272>>2]=T,c[s+280>>2]=U,c[s+288>>2]=V,c[s+296>>2]=W,c[s+304>>2]=X,c[s+312>>2]=Y,c[s+320>>2]=Z,c[s+328>>2]=_,c[s+336>>2]=$,c[s+344>>2]=aa,c[s+352>>2]=ba,c[s+360>>2]=ca,c[s+368>>2]=da,c[s+376>>2]=ea,s)|0);i=s;Vy(r,k,(k|0)<0|0?-1:0)|0;t=0;i=l;return t|0}function yV(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;do{if((b|0)==0){f=cEb(4)|0;if((f|0)==0){g=0;return g|0}h=LT(a,0)|0;if((h|0)!=0){c[h+4>>2]=d;c[h+12>>2]=f;i=h;j=c[h+8>>2]|0;break}ZDb(f);g=0;return g|0}else{f=b+8|0;h=c[f>>2]|0;k=h+96|0;if((c[k>>2]|0)==0){i=b;j=h;break}$Db(k);k=c[f>>2]|0;c[k+100>>2]=0;i=b;j=k}}while(0);c[j+8>>2]=e;c[i+236>>2]=1;MT(i,64,1,1e7);g=i;return g|0}function zV(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+4096|0;j=h|0;k=b+e|0;if((e|0)<48){l=0;i=h;return l|0}e=k;m=g+2|0;n=g+40|0;o=b;a:while(1){if((PGb(o,1233952,16)|0)!=0){p=4;break}b=o+16|0;q=(d[b]|d[b+1|0]<<8)<<16>>16&65535;b=o+24|0;r=b|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=b+4|0;t=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=o+32|0;b=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24)<<1;if((b|0)<0){p=6;break}r=YGb(b,(b|0)<0|0?-1:0,48,0)|0;u=F;v=e-o|0;w=(v|0)<0|0?-1:0;if((u|0)>(w|0)|(u|0)==(w|0)&r>>>0>v>>>0){p=8;break}v=o+(b+40)|0;x=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=o+(b+44)|0;y=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;do{if((b|0)>=(g|0)){if((PGb(o+40|0,f,g)|0)!=0){break}if((b|0)<(m|0)){p=13;break a}v=o+n|0;if((d[v]|d[v+1|0]<<8)<<16>>16<<16>>16==0){p=13;break a}}}while(0);if((o+(q+48)|0)>>>0>k>>>0){l=0;p=54;break}else{o=o+q|0}}if((p|0)==4){k=d[o+1|0]|0;n=d[o+2|0]|0;m=d[o+3|0]|0;g=d[o+4|0]|0;f=d[o+5|0]|0;e=d[o+6|0]|0;b=d[o+7|0]|0;v=d[o+8|0]|0;r=d[o+9|0]|0;w=d[o+10|0]|0;u=d[o+11|0]|0;z=d[o+12|0]|0;A=d[o+13|0]|0;B=d[o+14|0]|0;C=d[o+15|0]|0;yDb(a,16,2079e3,(D=i,i=i+128|0,c[D>>2]=d[o]|0,c[D+8>>2]=k,c[D+16>>2]=n,c[D+24>>2]=m,c[D+32>>2]=g,c[D+40>>2]=f,c[D+48>>2]=e,c[D+56>>2]=b,c[D+64>>2]=v,c[D+72>>2]=r,c[D+80>>2]=w,c[D+88>>2]=u,c[D+96>>2]=z,c[D+104>>2]=A,c[D+112>>2]=B,c[D+120>>2]=C,D)|0);i=D;l=0;i=h;return l|0}else if((p|0)==6){yDb(a,16,2074152,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;l=0;i=h;return l|0}else if((p|0)==8){yDb(a,16,2069496,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;l=0;i=h;return l|0}else if((p|0)==13){C=a+16|0;B=x;A=Ty(c[C>>2]|0,B<<12|0>>>20,((x|0)<0|0?-1:0)<<12|B>>>20,0)|0;B=F;z=0;if((B|0)<(z|0)|(B|0)==(z|0)&A>>>0<0>>>0){l=0;i=h;return l|0}A=cEb(40)|0;if((A|0)==0){l=0;i=h;return l|0}b:do{if((y|0)==2){z=c[C>>2]|0;B=0;u=0;do{w=rz(z)|0;c[j+(u<<2)>>2]=w;u=((w|0)!=0)+u|0;B=B+1|0;}while((B|0)<1024);do{if(u>>>0>524286>>>0){c[A+8>>2]=0}else{B=WDb(u<<12)|0;z=B;q=A+8|0;c[q>>2]=z;if((B|0)==0){break}B=A+12|0;c[B>>2]=0;if((u|0)>0){E=0}else{w=0;c[A+4>>2]=(t|0)<(w|0)|(t|0)==(w|0)&s>>>0<0>>>0?12:18;G=z;p=41;break b}while(1){z=c[j+(E<<2)>>2]|0;w=Ty(c[C>>2]|0,z<<12|0>>>20,0<<12|z>>>20,0)|0;z=F;r=0;if((z|0)<(r|0)|(z|0)==(r|0)&w>>>0<0>>>0){break}w=c[C>>2]|0;r=c[q>>2]|0;z=(E<<12|0)/4|0;v=0;b=0;do{e=rz(w)|0;c[r+(b+z<<2)>>2]=e;b=((e|0)!=0)+b|0;v=v+1|0;}while((v|0)<1024);v=(c[B>>2]|0)+b|0;c[B>>2]=v;z=E+1|0;if((z|0)<(u|0)){E=z}else{H=v;p=38;break b}}H=c[B>>2]|0;p=38;break b}}while(0);ZDb(A);l=0;i=h;return l|0}else if((y|0)==1){u=WDb(4096)|0;q=u;c[A+8>>2]=q;if((u|0)==0){ZDb(A);l=0;i=h;return l|0}u=c[C>>2]|0;v=0;z=0;do{r=rz(u)|0;c[q+(z<<2)>>2]=r;z=((r|0)!=0)+z|0;v=v+1|0;}while((v|0)<1024);c[A+12>>2]=z;H=z;p=38}else if((y|0)==0){v=WDb(4)|0;q=v;c[A+8>>2]=q;if((v|0)!=0){c[q>>2]=x;q=A+12|0;c[q>>2]=1;v=0;u=A+4|0;c[u>>2]=(t|0)<(v|0)|(t|0)==(v|0)&s>>>0<0>>>0?12:18;I=u;J=q;break}ZDb(A);l=0;i=h;return l|0}else{yDb(a,16,2064920,(D=i,i=i+8|0,c[D>>2]=y,D)|0);i=D;ZDb(A);l=0;i=h;return l|0}}while(0);do{if((p|0)==38){y=0;x=A+4|0;c[x>>2]=(t|0)<(y|0)|(t|0)==(y|0)&s>>>0<0>>>0?12:18;if((H|0)==0){G=c[A+8>>2]|0;p=41;break}else{I=x;J=A+12|0;break}}}while(0);if((p|0)==41){ZDb(G);ZDb(A);l=0;i=h;return l|0}G=Wy(c[C>>2]|0)|0;H=F;x=-1;do{if((H|0)>(x|0)|(H|0)==(x|0)&G>>>0>-1>>>0){y=c[(c[A+8>>2]|0)+((c[J>>2]|0)-1<<2)>>2]|0;E=0<<12|y>>>20;if(!((E|0)>(H|0)|(E|0)==(H|0)&(y<<12|0>>>20)>>>0>G>>>0)){break}yDb(a,24,2060912,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D}}while(0);G=s|0;s=t&65535;t=c[J>>2]|0;H=_Gb(t|0,((t|0)<0|0?-1:0)|0,c[I>>2]|0)|0;t=F;if(s>>>0>t>>>0|s>>>0==t>>>0&G>>>0>H>>>0){yDb(a,24,2057592,(D=i,i=i+32|0,c[D>>2]=G,c[D+8>>2]=s,c[D+16>>2]=H,c[D+24>>2]=t,D)|0);i=D;D=c[J>>2]|0;J=_Gb(D|0,((D|0)<0|0?-1:0)|0,c[I>>2]|0)|0;K=F;L=J}else{K=s;L=G}G=A+32|0;c[G>>2]=L;c[G+4>>2]=K;K=A+24|0;c[K>>2]=0;c[K+4>>2]=0;K=A+8|0;G=c[c[K>>2]>>2]|0;L=Ty(c[C>>2]|0,G<<12|0>>>20,0<<12|G>>>20,0)|0;G=F;s=0;if((G|0)<(s|0)|(G|0)==(s|0)&L>>>0<0>>>0){ZDb(c[K>>2]|0);ZDb(A);l=0;i=h;return l|0}c[A>>2]=c[C>>2];C=WDb(1<<c[I>>2])|0;if((C|0)==0){ZDb(c[K>>2]|0);ZDb(A);l=0;i=h;return l|0}L=Oy(C,1<<c[I>>2],0,A,16,0,292)|0;if((L|0)!=0){l=L;i=h;return l|0}ZDb(C);ZDb(c[K>>2]|0);ZDb(A);l=0;i=h;return l|0}else if((p|0)==54){i=h;return l|0}return 0}function AV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=c[a>>2]|0;f=a+16|0;if((c[f>>2]|0)!=0){g=-1;return g|0}if((c[e+76>>2]|0)!=0){g=-1;return g|0}h=a+24|0;i=c[h+4>>2]|0;j=a+32|0;k=c[j+4>>2]|0;if(!((i|0)<(k|0)|(i|0)==(k|0)&(c[h>>2]|0)>>>0<(c[j>>2]|0)>>>0)){g=0;return g|0}if((Xy(e)|0)!=0){g=0;return g|0}k=(d|0)<0|0?-1:0;i=c[h>>2]|0;l=c[h+4>>2]|0;m=ZGb(c[j>>2]|0,c[j+4>>2]|0,i,l)|0;j=F;n=(k|0)>(j|0)|(k|0)==(j|0)&d>>>0>m>>>0?m:d;if((n|0)<=0){g=0;return g|0}d=a+4|0;m=a+12|0;j=a+8|0;a=0;k=b;b=l;l=i;a:while(1){i=1<<c[d>>2];o=ZGb(i,0,i-1&l,0&b)|0;i=o;o=n-a|0;p=mz(e,k,(o|0)>(i|0)?i:o)|0;if((p|0)<1){g=a;q=15;break}r=p+a|0;o=k+p|0;s=YGb(c[h>>2]|0,c[h+4>>2]|0,p,(p|0)<0|0?-1:0)|0;t=F;c[h>>2]=s;c[h+4>>2]=t;do{if((p|0)==(i|0)){u=c[d>>2]|0;v=aHb(s|0,t|0,u|0)|0;w=v;if((w|0)>=(c[m>>2]|0)){q=14;break a}v=c[j>>2]|0;x=c[v+(w<<2)>>2]|0;if((x|0)==((c[v+(w-1<<2)>>2]|0)+(1<<u-12)|0)){break}u=x;x=Ty(e,u<<12|0>>>20,0<<12|u>>>20,0)|0;u=F;w=0;if((u|0)<(w|0)|(u|0)==(w|0)&x>>>0<0>>>0){q=14;break a}}}while(0);if((r|0)>=(n|0)){g=r;q=15;break}a=r;k=o;b=c[h+4>>2]|0;l=c[h>>2]|0}if((q|0)==14){c[f>>2]=1;g=r;return g|0}else if((q|0)==15){return g|0}return 0}function BV(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=c[a>>2]|0;if((e|0)==2){g=a+32|0;h=c[g+4>>2]|0;i=c[g>>2]|0}else if((e|0)==1){g=a+24|0;j=YGb(c[g>>2]|0,c[g+4>>2]|0,b,d)|0;h=F;i=j}else if((e|0)==65536){e=a+32|0;k=c[e+4>>2]|0;l=c[e>>2]|0;return(F=k,l)|0}else{h=d;i=b}b=0;do{if((h|0)<(b|0)|(h|0)==(b|0)&i>>>0<0>>>0){m=1}else{d=a+32|0;e=c[d+4>>2]|0;if(!((h|0)<(e|0)|(h|0)==(e|0)&i>>>0<(c[d>>2]|0)>>>0)){m=1;break}d=c[a+4>>2]|0;e=aHb(i|0,h|0,d|0)|0;j=c[(c[a+8>>2]|0)+(e<<2)>>2]|0;e=(1<<d)-1|0;d=YGb(j<<12|0>>>20,0<<12|j>>>20,e&i,((e|0)<0|0?-1:0)&h)|0;Ty(f,d,F,0)|0;m=F>>>31|0<<1}}while(0);c[a+16>>2]=m;m=a+24|0;c[m>>2]=i;c[m+4>>2]=h;k=h;l=i;return(F=k,l)|0}function CV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;d=a+16|0;e=c[d>>2]|0;f=a+12|0;g=c[f>>2]|0;h=g+208|0;j=h;TGb(h|0,-1|0,16)|0;HO(e,1079360);HO(e,429768);Yy(e,1);Yy(e,2);Yy(e,4096);Yy(e,262144);Yy(e,0);Qy(e,0,4);Yy(e,0);Qy(e,0,32);Yy(e,0);h=Ty(e,0,0,1)|0;k=ZGb(4096,0,h,F)|0;Qy(e,0,k);k=Ty(e,0,0,1)|0;e=g;c[e>>2]=k;c[e+4>>2]=F;e=g+200|0;c[e>>2]=1;c[e+4>>2]=0;c[j>>2]=-1;c[j+4>>2]=-1;c[g+476>>2]=1;j=a+24|0;a:do{if((c[j>>2]|0)!=0){e=a+28|0;k=0;b:do{h=c[(c[e>>2]|0)+(k<<2)>>2]|0;l=h+8|0;do{if((c[(c[l>>2]|0)+48>>2]|0)!=8){m=c[d>>2]|0;n=c[f>>2]|0;o=n+208|0;p=c[o>>2]|0;q=c[o+4>>2]|0;KV(n,m,1134968,0,-2147483647);dz(m,p,q);Yy(m,1);Qy(m,0,4);Qy(m,0,4);if((NV(a,h)|0)<0){r=7;break b}LV(a);if((k|0)!=0){break}JV(a)}}while(0);k=k+1|0;s=c[j>>2]|0;}while(k>>>0<s>>>0);if((r|0)==7){k=a;yDb(k,16,2260344,(t=i,i=i+8|0,c[t>>2]=c[(c[l>>2]|0)+8>>2],t)|0);i=t;yDb(k,16,2292112,(t=i,i=i+8|0,c[t>>2]=c[(c[l>>2]|0)+8>>2],t)|0);i=t;u=-1;i=b;return u|0}if((s|0)==0){break}k=a+28|0;e=0;h=s;while(1){m=c[(c[k>>2]|0)+(e<<2)>>2]|0;v=m+8|0;if((c[(c[v>>2]|0)+48>>2]|0)==8){w=h}else{q=c[d>>2]|0;p=m|0;n=c[f>>2]|0;o=n+208|0;x=c[o>>2]|0;y=c[o+4>>2]|0;KV(n,q,1286512,0,(c[p>>2]|0)+2|-2147483648);dz(q,x,y);Yy(q,1);Yy(q,(c[p>>2]|0)+2|0);Yy(q,1);Qy(q,0,8);if((NV(a,m)|0)<0){break}LV(a);MT(m,64,1,1e7);w=c[j>>2]|0}m=e+1|0;if(m>>>0<w>>>0){e=m;h=w}else{break a}}h=a;yDb(h,16,2260344,(t=i,i=i+8|0,c[t>>2]=c[(c[v>>2]|0)+8>>2],t)|0);i=t;yDb(h,16,2276136,(t=i,i=i+8|0,c[t>>2]=c[(c[v>>2]|0)+8>>2],t)|0);i=t;u=-1;i=b;return u|0}}while(0);if((c[g+472>>2]|0)==0){u=0;i=b;return u|0}MV(a);u=0;i=b;return u|0}function DV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=a+16|0;e=c[d>>2]|0;f=a+12|0;g=c[f>>2]|0;h=b+32|0;i=a+28|0;do{if((c[(c[(c[(c[i>>2]|0)+(c[h>>2]<<2)>>2]|0)+8>>2]|0)+48>>2]|0)==8){if((c[g+540>>2]|0)!=0){break}EZ(g+512|0,b)|0;return 0}}while(0);j=g+200|0;k=c[g+492>>2]|0;if((k|0)==0){l=0;m=0}else{n=(c[g+488>>2]|0)+(k-1<<4)|0;l=c[n+4>>2]|0;m=c[n>>2]|0}n=ZGb(c[j>>2]|0,c[j+4>>2]|0,m,l)|0;l=F;m=0;if((l|0)>(m|0)|(l|0)==(m|0)&n>>>0>49>>>0){JV(a)}a=b+8|0;n=c[a>>2]|0;m=c[a+4>>2]|0;do{if(!((n|0)==0&(m|0)==(-2147483648|0))){l=g+484|0;k=c[l>>2]|0;if((k|0)==0){o=0;p=0}else{q=(c[g+480>>2]|0)+(k-1<<4)+8|0;o=c[q+4>>2]|0;p=c[q>>2]|0}q=ZGb(n,m,p,o)|0;r=F;s=0;do{if((r|0)>(s|0)|(r|0)==(s|0)&q>>>0>4999999>>>0){t=g+480|0;u=c[j>>2]|0;v=c[j+4>>2]|0;w=k+1|0;x=XDb(c[t>>2]|0,w<<4)|0;y=x;if((x|0)==0){break}x=c[l>>2]|0;z=y+(x<<4)|0;c[z>>2]=u;c[z+4>>2]=v;v=y+(x<<4)+8|0;c[v>>2]=n;c[v+4>>2]=m;c[t>>2]=y;c[l>>2]=w}}while(0);l=c[a>>2]|0;k=c[a+4>>2]|0;if((l|0)==0&(k|0)==(-2147483648|0)){break}q=g+496|0;s=c[q+4>>2]|0;if(!((k|0)>(s|0)|(k|0)==(s|0)&l>>>0>(c[q>>2]|0)>>>0)){break}c[q>>2]=l;c[q+4>>2]=k;k=c[j+4>>2]|0;q=g+504|0;c[q>>2]=c[j>>2];c[q+4>>2]=k}}while(0);g=c[f>>2]|0;m=c[d>>2]|0;n=c[h>>2]|0;o=c[(c[(c[i>>2]|0)+(n<<2)>>2]|0)+8>>2]|0;KV(g,m,1110800,56,n+2|1073741824);Qy(m,0,8);n=c[a>>2]|0;i=c[a+4>>2]|0;p=(n|0)==0&(i|0)==(-2147483648|0);dz(m,p?-1:n,p?-1:i);i=c[a>>2]|0;p=c[a+4>>2]|0;n=(i|0)==0&(p|0)==(-2147483648|0);dz(m,n?-1:i,n?-1:p);p=c[a>>2]|0;n=c[a+4>>2]|0;a=(p|0)==0&(n|0)==(-2147483648|0);dz(m,a?-1:p,a?-1:n);dz(m,0,0);if((c[o+8>>2]|0)==0){A=0;B=c[b+36>>2]&1}else{A=0;B=0}dz(m,B,A);dz(m,0,0);m=g+208|0;A=c[m+4>>2]|0;B=g+216|0;c[B>>2]=c[m>>2];c[B+4>>2]=A;A=b+28|0;KV(c[f>>2]|0,c[d>>2]|0,1234728,c[A>>2]|0,(c[h>>2]|0)+2|0);Ry(e,c[b+24>>2]|0,c[A>>2]|0);b=c[A>>2]|0;Qy(e,0,(b+7&-8)-b|0);b=YGb(c[j>>2]|0,c[j+4>>2]|0,1,0)|0;c[j>>2]=b;c[j+4>>2]=F;return 0}function EV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;g=d;if((FV(a,2,c[g>>2]|0,c[g+4>>2]|0)|0)<0){h=-1;return h|0}g=Ty(f,0,0,1)|0;i=F;j=c[b>>2]|0;k=c[e>>2]|0;l=j+492|0;if((c[l>>2]|0)>0){m=j+488|0;j=0;do{n=(c[m>>2]|0)+(j<<4)|0;dz(k,c[n>>2]|0,c[n+4>>2]|0);n=(c[m>>2]|0)+(j<<4)+8|0;dz(k,c[n>>2]|0,c[n+4>>2]|0);j=j+1|0;}while((j|0)<(c[l>>2]|0))}if((FV(a,1,g,i)|0)<0){h=-1;return h|0}i=Ty(f,0,0,1)|0;g=F;l=c[b>>2]|0;j=c[e>>2]|0;k=a+1140|0;QG(k,1263112,0);m=BBb(c[k>>2]|0,9203320,0,2)|0;if((m|0)!=0){n=m;do{m=c[n>>2]|0;o=c[n+4>>2]|0;p=((SGb(o|0)|0)<<1)+2|0;HO(j,1190784);Yy(j,1);Yy(j,p);$y(j,m)|0;$y(j,o)|0;n=BBb(c[k>>2]|0,9203320,n,2)|0;}while((n|0)!=0)}n=l+540|0;if((c[n>>2]|0)!=0){o=BBb(c[(c[(c[a+28>>2]|0)+(c[l+544>>2]<<2)>>2]|0)+88>>2]|0,2014464,0,0)|0;if((o|0)==0){m=(c[n>>2]|0)+29|0;HO(j,1190784);Yy(j,2);Yy(j,m);$y(j,2061032)|0;$y(j,1945016)|0;Py(j,16);q=9203320}else{m=o+4|0;o=((SGb(c[m>>2]|0)|0)<<1)+29|0;p=o+(c[n>>2]|0)|0;HO(j,1190784);Yy(j,2);Yy(j,p);$y(j,2061032)|0;$y(j,1945016)|0;Py(j,16);q=c[m>>2]|0}$y(j,q)|0;Yy(j,c[n>>2]|0);Ry(j,c[l+536>>2]|0,c[n>>2]|0);HO(j,1190784);Yy(j,0);Yy(j,4);$y(j,1973952)|0;Yy(j,2)}if((FV(a,4,i,g)|0)<0){h=-1;return h|0}g=Ty(f,0,0,1)|0;i=F;j=c[b>>2]|0;n=c[e>>2]|0;l=BBb(c[k>>2]|0,9203320,0,2)|0;if((l|0)==0){r=0;s=0}else{q=0;m=0;p=l;while(1){dz(n,m,q);l=SGb(c[p>>2]|0)|0;o=YGb(((SGb(c[p+4>>2]|0)|0)+l<<1)+28|0,0,m,q)|0;l=F;t=BBb(c[k>>2]|0,9203320,p,2)|0;if((t|0)==0){r=l;s=o;break}else{q=l;m=o;p=t}}}p=j+540|0;if((c[p>>2]|0)!=0){m=c[(c[a+28>>2]|0)+(c[j+544>>2]<<2)>>2]|0;dz(n,s,r);j=BBb(c[m+88>>2]|0,2014464,0,0)|0;if((j|0)==0){u=75}else{u=((SGb(c[j+4>>2]|0)|0)<<1)+75|0}j=(c[p>>2]|0)+u|0;u=YGb(j,(j|0)<0|0?-1:0,s,r)|0;dz(n,u,F)}if((FV(a,5,g,i)|0)<0){h=-1;return h|0}i=Ty(f,0,0,1)|0;g=F;u=c[b>>2]|0;n=c[e>>2]|0;r=u+484|0;if((c[r>>2]|0)>0){s=u+480|0;j=0;do{p=(c[s>>2]|0)+(j<<4)+8|0;dz(n,c[p>>2]|0,c[p+4>>2]|0);p=(c[s>>2]|0)+(j<<4)|0;dz(n,c[p>>2]|0,c[p+4>>2]|0);j=j+1|0;}while((j|0)<(c[r>>2]|0))}r=u+496|0;dz(n,c[r>>2]|0,c[r+4>>2]|0);r=u+504|0;dz(n,c[r>>2]|0,c[r+4>>2]|0);if((FV(a,7,i,g)|0)<0){h=-1;return h|0}g=Ty(f,0,0,1)|0;i=F;a=c[e>>2]|0;e=(c[b>>2]|0)+8|0;b=15656;r=0;while(1){n=b+4|0;u=c[n>>2]|0;j=(u+7&-8)-u|0;u=c[b+8>>2]|0;HO(a,1233952);s=Ty(a,0,0,1)|0;p=F;az(a,j+48+(c[n>>2]|0)|0);Qy(a,0,6);m=(u|0)!=0;if(m){v=0;w=0}else{q=e+(r*24|0)|0;v=c[q+4>>2]|0;w=c[q>>2]|0}dz(a,w,v);Yy(a,(c[n>>2]|0)+j>>1);Qy(a,0,4);Ry(a,c[b>>2]|0,c[n>>2]|0);Qy(a,0,j);if(m){m=re[u&4095](a)|0;Ty(a,s,p,0)|0;p=j+40+m+(c[n>>2]|0)|0;dz(a,p,(p|0)<0|0?-1:0);dz(a,m|0,((m|0)<0|0?-1:0)|1342177280);p=j+8+m+(c[n>>2]|0)|0;Ty(a,p,(p|0)<0|0?-1:0,1)|0;}else{Yy(a,c[e+(r*24|0)+16>>2]|0);Yy(a,c[e+(r*24|0)+12>>2]|0)}p=r+1|0;if(p>>>0<8>>>0){b=b+12|0;r=p}else{break}}r=Ty(a,0,0,1)|0;b=ZGb(r,F,g,i)|0;r=b;Qy(a,0,4096-r|0);a=Ty(f,0,0,1)|0;b=F;Ty(f,48,0,0)|0;Yy(f,r);Ty(f,4,0,1)|0;Yy(f,g>>>12|i<<20);Ty(f,92,0,0)|0;Yy(f,a>>>12|b<<20);Sy(f);ZDb(c[d+488>>2]|0);ZDb(c[d+480>>2]|0);BZ(d+512|0);h=0;return h|0}function FV(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;g=a+16|0;h=c[g>>2]|0;j=(c[a+12>>2]|0)+8|0;k=Ty(h,0,0,1)|0;l=F;if(!(b>>>0<8>>>0)){yDb(0,0,1920352,(m=i,i=i+24|0,c[m>>2]=1899288,c[m+8>>2]=1879032,c[m+16>>2]=725,m)|0);i=m;Cd();return 0}n=ZGb(k,l,d,e)|0;l=F;k=j+(b*24|0)|0;c[k>>2]=n;c[k+4>>2]=l;o=0;do{if((l|0)<(o|0)|(l|0)==(o|0)&n>>>0<4097>>>0){c[j+(b*24|0)+12>>2]=0;p=12;q=0}else{r=0;if((l|0)<(r|0)|(l|0)==(r|0)&n>>>0<4194305>>>0){c[j+(b*24|0)+12>>2]=1;p=12;q=1;break}r=0;if((l|0)<(r|0)|(l|0)==(r|0)&n>>>0<268435457>>>0){c[j+(b*24|0)+12>>2]=1;p=18;q=1;break}r=1;if((l|0)<(r|0)|(l|0)==(r|0)&n>>>0<1>>>0){c[j+(b*24|0)+12>>2]=2;p=12;q=2;break}r=64;if((l|0)<(r|0)|(l|0)==(r|0)&n>>>0<1>>>0){c[j+(b*24|0)+12>>2]=2;p=18;q=2;break}yDb(a,16,2337240,(m=i,i=i+16|0,c[m>>2]=n,c[m+8>>2]=l,m)|0);i=m;s=-1;i=f;return s|0}}while(0);m=aHb(n|0,l|0,p|0)|0;a=m;m=1<<p;o=m;r=(m|0)<0|0?-1:0;m=fHb(n,l,o,r)|0;l=ZGb(o,r,m,F)|0;m=l;if((m|0)==0){t=a;u=q}else{Qy(h,0,m);t=a+1|0;u=c[j+(b*24|0)+12>>2]|0}a=d>>>12|e<<20;if((u|0)>0){e=p-12|0;d=Ty(c[g>>2]|0,0,0,1)|0;m=F;h=c[g>>2]|0;q=a;if((t|0)>0){l=0;do{Yy(h,(l<<e)+q|0);l=l+1|0;}while((l|0)<(t|0))}l=t<<2;Qy(h,0,4096-((l|0)%4096|0)|0);h=d>>>12|m<<20;if((u|0)==2){u=(l+4095|0)/4096|0;m=Ty(c[g>>2]|0,0,0,1)|0;d=F;t=c[g>>2]|0;if((l|0)>0){l=0;do{Yy(t,l+h|0);l=l+1|0;}while((l|0)<(u|0))}Qy(t,0,4096-((u<<2|0)%4096|0)|0);v=m>>>12|d<<20}else{v=h}c[j+(b*24|0)+16>>2]=v}else{c[j+(b*24|0)+16>>2]=a}a=(p|0)==12;p=c[k+4>>2]|(a?-1879048192:268435456);c[k>>2]=c[k>>2]|(a?0:0);c[k+4>>2]=p;s=0;i=f;return s|0}function GV(a){a=a|0;Yy(a,16);Qy(a,0,84);dz(a,50,0);return 96}function HV(a){a=a|0;Yy(a,-1);Qy(a,0,12);Ry(a,857880,26);Qy(a,0,6);Qy(a,0,32);return 80}function IV(a){a=a|0;Yy(a,16);Qy(a,0,76);dz(a,64,0);return 88}function JV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[a+16>>2]|0;d=c[a+12>>2]|0;e=d+208|0;f=c[e>>2]|0;g=c[e+4>>2]|0;h=Ty(b,0,0,1)|0;i=d;j=ZGb(h,F,c[i>>2]|0,c[i+4>>2]|0)|0;c[e>>2]=j;c[e+4>>2]=F;HO(b,1130032);Yy(b,56);Yy(b,0);j=d+200|0;dz(b,c[j>>2]|0,c[j+4>>2]|0);i=d+224|0;dz(b,c[i>>2]|0,c[i+4>>2]|0);i=d+216|0;dz(b,c[i>>2]|0,c[i+4>>2]|0);dz(b,0,0);LV(a);a=d+488|0;b=d+492|0;d=c[j>>2]|0;i=c[j+4>>2]|0;j=c[e>>2]|0;h=c[e+4>>2]|0;k=(c[b>>2]|0)+1|0;l=XDb(c[a>>2]|0,k<<4)|0;m=l;if((l|0)==0){n=e|0;c[n>>2]=f;o=e+4|0;c[o>>2]=g;return}l=c[b>>2]|0;p=m+(l<<4)|0;c[p>>2]=d;c[p+4>>2]=i;i=m+(l<<4)+8|0;c[i>>2]=j;c[i+4>>2]=h;c[a>>2]=m;c[b>>2]=k;n=e|0;c[n>>2]=f;o=e+4|0;c[o>>2]=g;return}function KV(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=Ty(b,0,0,1)|0;j=a;k=ZGb(h,F,c[j>>2]|0,c[j+4>>2]|0)|0;j=a+208|0;c[j>>2]=k;c[j+4>>2]=F;HO(b,d);Yy(b,e+32|0);Yy(b,f);e=a+200|0;dz(b,c[e>>2]|0,c[e+4>>2]|0);if((f|0)>-1|(d|0)==1202656){i=g;return}b=a+232|0;k=a+472|0;a=c[k>>2]|0;if((a|0)>=10){yDb(0,0,1920352,(h=i,i=i+24|0,c[h>>2]=2312280,c[h+8>>2]=1879032,c[h+16>>2]=148,h)|0);i=h;Cd()}h=c[j+4>>2]|0;l=b+(a*24|0)|0;c[l>>2]=c[j>>2];c[l+4>>2]=h;h=c[e+4>>2]|0;l=b+(a*24|0)+8|0;c[l>>2]=c[e>>2];c[l+4>>2]=h;c[b+(a*24|0)+16>>2]=d;c[b+(a*24|0)+20>>2]=f&1073741823;c[k>>2]=(c[k>>2]|0)+1;i=g;return}function LV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=Ty(d,0,0,1)|0;f=b+208|0;g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;g=ZGb(e,F,c[f>>2]|0,c[f+4>>2]|0)|0;f=ZGb(g,F,h,i)|0;i=F;h=ZGb(16,0,f,i)|0;Ty(d,h,F,1)|0;Yy(d,f);h=YGb(f,i,-20,-1)|0;Ty(d,h,F,1)|0;h=YGb(f,i,7,0)|0;g=ZGb(h&-8,F&0,f,i)|0;Qy(d,0,g);g=b+200|0;d=YGb(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=d;c[g+4>>2]=F;if((c[b+472>>2]|0)!=10){return}MV(a);return}function MV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+16|0;d=c[b>>2]|0;e=a+12|0;a=c[e>>2]|0;f=a+208|0;g=c[f>>2]|0;h=c[f+4>>2]|0;i=Ty(d,0,0,1)|0;j=a;k=ZGb(i,F,c[j>>2]|0,c[j+4>>2]|0)|0;c[f>>2]=k;c[f+4>>2]=F;HO(d,1202656);Yy(d,32);Yy(d,-2147483648);k=a+200|0;dz(d,c[k>>2]|0,c[k+4>>2]|0);dz(d,g,h);Yy(d,0);Yy(d,0);h=a+472|0;if((c[h>>2]|0)>0){g=a+232|0;k=0;do{HO(d,c[g+(k*24|0)+16>>2]|0);j=g+(k*24|0)|0;dz(d,c[j>>2]|0,c[j+4>>2]|0);Yy(d,c[g+(k*24|0)+20>>2]|0);Yy(d,0);j=g+(k*24|0)+8|0;dz(d,c[j>>2]|0,c[j+4>>2]|0);k=k+1|0;}while((k|0)<(c[h>>2]|0))}c[h>>2]=0;h=c[e>>2]|0;e=c[b>>2]|0;b=Ty(e,0,0,1)|0;k=h+208|0;d=h;g=c[d>>2]|0;j=c[d+4>>2]|0;d=ZGb(b,F,c[k>>2]|0,c[k+4>>2]|0)|0;k=ZGb(d,F,g,j)|0;j=F;g=ZGb(16,0,k,j)|0;Ty(e,g,F,1)|0;Yy(e,k);g=YGb(k,j,-20,-1)|0;Ty(e,g,F,1)|0;g=YGb(k,j,7,0)|0;d=ZGb(g&-8,F&0,k,j)|0;Qy(e,0,d);d=h+200|0;h=YGb(c[d>>2]|0,c[d+4>>2]|0,1,0)|0;c[d>>2]=h;c[d+4>>2]=F;d=a+224|0;if(!((c[d>>2]|0)==0&(c[d+4>>2]|0)==0)){return}a=c[f+4>>2]|0;c[d>>2]=c[f>>2];c[d+4>>2]=a;return}function NV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0;e=i;i=i+48|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=c[b+16>>2]|0;m=d+8|0;n=c[m>>2]|0;o=c[n+8>>2]|0;if((o|0)==1){p=IO(c[n+48>>2]|0,1238560)|0;q=1190816;r=1238064;s=1218624}else if((o|0)==0){t=IO(c[n+48>>2]|0,1089848)|0;p=t;q=1190800;r=1240808;s=(c[(c[m>>2]|0)+48>>2]|0)==2?1218672:1218640}else{yDb(b,16,2245840,(u=i,i=i+8|0,c[u>>2]=o,u)|0);i=u;v=-1;i=e;return v|0}HO(l,q);HO(l,1190832);Qy(l,0,12);HO(l,1218688);Yy(l,0);q=Ty(l,0,0,1)|0;o=F;t=c[m>>2]|0;do{if((c[t+8>>2]|0)==0){c[g>>2]=c[t+120>>2];c[g+4>>2]=c[t+124>>2];jFb(f,d+80|0,g);n=c[f>>2]|0;w=c[f+4>>2]|0;iFb(h,j,n,(n|0)<0|0?-1:0,w,(w|0)<0|0?-1:0,-1,0)|0;Yy(l,0);Yy(l,0);Yy(l,c[(c[m>>2]|0)+120>>2]|0);Yy(l,c[(c[m>>2]|0)+124>>2]|0);Yy(l,0);Yy(l,0);Yy(l,0);Yy(l,0);Yy(l,c[(c[m>>2]|0)+72>>2]|0);Yy(l,0);w=c[d+92>>2]|0;do{if((w|0)==0){x=0;y=0}else{n=c[d+96>>2]|0;if((n|0)==0){x=0;y=0;break}z=1.0e7/(+(w|0)/+(n|0));x=(E=+z,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);y=~~+z>>>0}}while(0);dz(l,y,x);Yy(l,0);Yy(l,0);Yy(l,c[h>>2]|0);Yy(l,c[j>>2]|0);Yy(l,0);Yy(l,0);JO(l,c[m>>2]|0,1240808,0,1);if((c[(c[m>>2]|0)+48>>2]|0)!=2){A=s;break}Yy(l,0);Yy(l,c[(c[m>>2]|0)+100>>2]|0);Yy(l,-1);Yy(l,-1);Yy(l,0);w=c[m>>2]|0;Ry(l,c[w+96>>2]|0,c[w+100>>2]|0);dz(l,0,0);A=s}else{w=(GO(l,t)|0)<0;A=w?1218656:s}}while(0);s=Ty(l,0,0,1)|0;t=ZGb(s,F,q,o)|0;o=t;t=-4-o|0;Ty(l,t,(t|0)<0|0?-1:0,1)|0;Yy(l,o+32|0);Ty(l,o,(o|0)<0|0?-1:0,1)|0;do{if((p|0)==0){o=uT(r,c[(c[m>>2]|0)+48>>2]|0)|0;if((o|0)!=0){Yy(l,o);o=k|0;a[o]=0;a[k+1|0]=0;a[k+2|0]=16;a[k+3|0]=0;a[k+4|0]=-128;a[k+5|0]=0;a[k+6|0]=0;a[k+7|0]=-86;a[k+8|0]=0;a[k+9|0]=56;a[k+10|0]=-101;a[k+11|0]=113;Ry(l,o,12);break}yDb(b,16,2233328,(u=i,i=i+8|0,c[u>>2]=c[(c[m>>2]|0)+48>>2],u)|0);i=u;v=-1;i=e;return v|0}else{HO(l,p)}}while(0);HO(l,A);v=0;i=e;return v|0}function OV(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0;TGb(a|0,0,36)|0;f=e;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=1802532471){g=-1094995529;return g|0}f=e+4|0;h=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a|0;c[f>>2]=h;i=h-24|0;if(i>>>0>1048552>>>0){g=-1094995529;return g|0}c[f>>2]=i;i=e+8|0;b[a+4>>1]=(d[i]|d[i+1|0]<<8)<<16>>16;i=e+12|0;c[a+8>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=e+16|0;c[a+12>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=e+20|0;c[a+16>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=e+24|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+20>>2]=f;i=e+28|0;c[a+24>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[a+28>>2]=f>>>11&1;c[a+32>>2]=f>>>12&1;g=0;return g|0}function PV(a){a=a|0;var b=0,e=0,f=0;if((c[a+8>>2]|0)<33){b=0;return b|0}e=c[a+4>>2]|0;a=e;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1802532471){f=e+4|0;if(!(((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24)-24|0)>>>0<1048553>>>0)){break}f=e+8|0;if((((d[f]|d[f+1|0]<<8)<<16>>16)-1026&65535)>>>0<15>>>0){b=100}else{break}return b|0}}while(0);b=0;return b|0}function QV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+16|0;d=c[b>>2]|0;e=c[a+12>>2]|0;c[e+88>>2]=0;f=TV(a,d)|0;if((f|0)<0){g=f;return g|0}f=e+48|0;h=e+32|0;while(1){if((c[f>>2]|0)!=0){break}Vy(d,c[h>>2]|0,0)|0;i=TV(a,d)|0;if((i|0)<0){g=i;j=12;break}}if((j|0)==12){return g|0}j=LT(a,0)|0;if((j|0)==0){g=-12;return g|0}d=c[j+8>>2]|0;c[d+8>>2]=1;c[d+48>>2]=86041;c[d+416>>2]=c[e+72>>2];h=d+448|0;c[h>>2]=c[e+80>>2];c[h+4>>2]=0;h=e+68|0;c[d+412>>2]=c[h>>2];c[d+792>>2]=c[e+76>>2];MT(j,64,1,c[h>>2]|0);h=j+48|0;c[h>>2]=0;c[h+4>>2]=0;h=c[e+40>>2]|0;if(!((h|0)==-1)){d=j+56|0;c[d>>2]=h;c[d+4>>2]=0}d=c[b>>2]|0;if((c[d+88>>2]|0)==0){g=0;return g|0}h=Ty(d,0,0,1)|0;d=F;j=tx(a)|0;f=e+104|0;c[f>>2]=j;c[f+4>>2]=F;if((BBb(c[a+1140>>2]|0,9203576,0,2)|0)==0){mX(a)}Ty(c[b>>2]|0,h,d,0)|0;g=0;return g|0}function RV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=c[a+12>>2]|0;f=a+16|0;if((Xy(c[f>>2]|0)|0)!=0){g=-541478725;i=d;return g|0}h=e+88|0;do{if((c[h>>2]|0)!=0){j=TV(a,c[f>>2]|0)|0;if((j|0)<0){g=j}else{break}i=d;return g|0}}while(0);j=e+96|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=e+32|0;if((wZ(b,(c[j>>2]|0)+32|0)|0)<0){g=-12;i=d;return g|0}m=b+24|0;UGb(c[m>>2]|0,e|0,32)|0;n=mz(c[f>>2]|0,(c[m>>2]|0)+32|0,c[j>>2]|0)|0;if((n|0)!=(c[j>>2]|0)){BZ(b);g=-5;i=d;return g|0}n=e+52|0;o=b+28|0;while(1){if((c[n>>2]&4096|0)!=0){p=15;break}q=TV(a,c[f>>2]|0)|0;if((q|0)<0){p=10;break}r=c[o>>2]|0;s=zZ(b,(c[j>>2]|0)+32|0)|0;if((s|0)<0){p=12;break}UGb((c[m>>2]|0)+r|0,e|0,32)|0;t=mz(c[f>>2]|0,(c[m>>2]|0)+(r+32)|0,c[j>>2]|0)|0;if((t|0)!=(c[j>>2]|0)){p=14;break}}if((p|0)==10){BZ(b);g=q;i=d;return g|0}else if((p|0)==12){BZ(b);g=s;i=d;return g|0}else if((p|0)==14){BZ(b);g=(t|0)<0?t:-541478725;i=d;return g|0}else if((p|0)==15){c[b+32>>2]=0;c[h>>2]=1;h=c[e+44>>2]|0;p=0;t=b+8|0;c[t>>2]=h;c[t+4>>2]=p;s=c[e+48>>2]|0;if((s|0)<0){yDb(a,24,2121584,(e=i,i=i+8|0,c[e>>2]=s,e)|0);i=e;u=c[t+4>>2]|0;v=c[t>>2]|0}else{c[b+48>>2]=s;u=p;v=h}jT(c[c[a+28>>2]>>2]|0,k,l,v,u,0,0,1)|0;g=0;i=d;return g|0}return 0}function SV(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+80|0;h=g|0;j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[a+12>>2]|0;k=oT(j,d,e,f)|0;do{if((k|0)>-1){f=c[j+400>>2]|0;l=f+(((c[j+404>>2]|0)-1|0)*24|0)+8|0;m=c[l+4>>2]|0;if((m|0)<(e|0)|(m|0)==(e|0)&(c[l>>2]|0)>>>0<d>>>0){break}c[b+88>>2]=1;l=f+(k*24|0)|0;Ty(c[a+16>>2]|0,c[l>>2]|0,c[l+4>>2]|0,0)|0;n=0;i=g;return n|0}}while(0);k=0;if((e|0)<(k|0)|(e|0)==(k|0)&d>>>0<0>>>0){n=-22;i=g;return n|0}k=a+1064|0;b=c[k+4>>2]|0;if(!((b|0)>(e|0)|(b|0)==(e|0)&(c[k>>2]|0)>>>0>d>>>0)){n=-22;i=g;return n|0}k=a+16|0;b=Ty(c[k>>2]|0,0,0,1)|0;j=F;l=h+8|0;while(1){o=gT(a,h)|0;if((o|0)<0){break}f=c[l>>2]|0;m=c[l+4>>2]|0;BZ(h);if(!((m|0)<(e|0)|(m|0)==(e|0)&f>>>0<d>>>0)){n=0;p=10;break}}if((p|0)==10){i=g;return n|0}Ty(c[k>>2]|0,b,j,0)|0;n=o;i=g;return n|0}function TV(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;f=c[a+12>>2]|0;g=Ty(d,0,0,1)|0;h=F;j=f+96|0;c[j>>2]=g;c[j+4>>2]=h;j=f+104|0;k=c[j>>2]|0;l=c[j+4>>2]|0;if(!((k|0)==0&(l|0)==0|((h|0)<(l|0)|(h|0)==(l|0)&g>>>0<k>>>0))){m=-541478725;i=e;return m|0}k=mz(d,f,32)|0;if((k|0)!=32){m=(k|0)<0?k:-541478725;i=e;return m|0}k=f+32|0;g=OV(k,f)|0;if((g|0)<0){yDb(a,16,2060984,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=g;i=e;return m|0}g=b[f+36>>1]|0;if((g-1026&65535)>>>0>14>>>0){yDb(a,16,2014432,(n=i,i=i+8|0,c[n>>2]=g&65535,n)|0);i=n;m=-1163346256;i=e;return m|0}if((c[f+48>>2]|0)==0){m=0;i=e;return m|0}g=c[f+52>>2]|0;l=(g<<3&24)+8|0;h=g>>>2&1;j=g>>>23&15;o=c[15576+(j<<2)>>2]|0;if((c[f+60>>2]|0)==0){p=f+84|0;c[p>>2]=1;q=p;r=12}else{p=(c[f+64>>2]|0)==0;s=f+84|0;c[s>>2]=p&1;if(p){q=s;r=12}else{t=h+3|0;u=2-h|0;v=s}}if((r|0)==12){t=c[f+80>>2]|0;u=c[f+72>>2]|0;v=q}do{if((j|0)==15|(u|0)==0){if((c[f+88>>2]|0)!=0){w=o;x=t;y=u;break}q=Ty(d,0,0,1)|0;s=k;h=YGb(c[s>>2]|0,0,q,F)|0;q=F;if((c[d+88>>2]|0)==0){yDb(a,16,1973912,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=e;return m|0}p=Ty(d,0,0,1)|0;z=F;a:do{if((z|0)<(q|0)|(z|0)==(q|0)&p>>>0<h>>>0){A=u;B=t;C=o;b:while(1){D=lz(d)|0;if((D&128|0)==0){E=lz(d)|0}else{E=qz(d)|0}G=(D&64|0)!=0;H=(E<<1)+(G<<31>>31)|0;I=D&63;c:do{if((I|0)==39){J=qz(d)|0;K=B;L=A}else if((I|0)==13){if((H|0)<2){r=23;break b}D=lz(d)|0;switch(H|0){case 4:{J=C;K=qz(d)|0;L=D;break c;break};case 2:{J=C;K=lz(d)|0;L=D;break c;break};case 5:{J=C;K=rz(d)|0;L=D;break c;break};case 3:{J=C;K=pz(d)|0;L=D;break c;break};case 7:{Vy(d,1,0)|0;M=(lz(d)|0)<<8&3840|D;J=C;K=qz(d)|0;L=M;break c;break};default:{r=30;break b}}}else{Vy(d,H,(H|0)<0|0?-1:0)|0;J=C;K=B;L=A}}while(0);if(G){Vy(d,1,0)|0;}I=Ty(d,0,0,1)|0;M=F;if((M|0)<(q|0)|(M|0)==(q|0)&I>>>0<h>>>0){A=L;B=K;C=J}else{N=L;O=K;P=J;break a}}if((r|0)==23){yDb(a,16,1944976,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=e;return m|0}else if((r|0)==30){yDb(a,16,1920320,(n=i,i=i+8|0,c[n>>2]=H,n)|0);i=n;m=-1094995529;i=e;return m|0}}else{N=u;O=t;P=o}}while(0);if(!((P|0)==-1)){p=ZGb(h,q,c[s>>2]|0,0)|0;Ty(d,p,F,0)|0;w=P;x=O;y=N;break}yDb(a,16,1899248,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=e;return m|0}else{w=o;x=t;y=u}}while(0);u=f+76|0;t=c[u>>2]|0;if((t|0)==0){c[u>>2]=l;Q=l}else{Q=t}t=f+72|0;u=c[t>>2]|0;if((u|0)==0){c[t>>2]=y;R=y}else{R=u}u=f+80|0;if((c[u>>2]|0)==0){c[u>>2]=x}x=f+68|0;f=c[x>>2]|0;if((f|0)==0){c[x>>2]=w;S=w}else{S=f}if((g|0)==0){m=0;i=e;return m|0}if((l|0)!=(Q|0)){yDb(a,16,1878936,(n=i,i=i+16|0,c[n>>2]=l,c[n+8>>2]=Q,n)|0);i=n;m=-1094995529;i=e;return m|0}if(!((c[v>>2]|0)!=0|(y|0)==(R|0))){yDb(a,16,2337176,(n=i,i=i+16|0,c[n>>2]=y,c[n+8>>2]=R,n)|0);i=n;m=-1094995529;i=e;return m|0}if((w|0)==-1|(w|0)==(S|0)){m=0;i=e;return m|0}yDb(a,16,2312192,(n=i,i=i+16|0,c[n>>2]=w,c[n+8>>2]=S,n)|0);i=n;m=-1094995529;i=e;return m|0}function UV(a){a=a|0;var b=0,d=0;b=i;do{if(!((c[a+24>>2]|0)>>>0>1>>>0)){if((c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+48>>2]|0)==86041){d=0}else{break}i=b;return d|0}}while(0);yDb(a,16,2014376,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;d=-22;i=b;return d|0}function VV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+40|0;e=d|0;f=c[a+12>>2]|0;g=b+28|0;do{if((c[g>>2]|0)>=32){h=b+24|0;if((OV(e,c[h>>2]|0)|0)<0){break}j=f;k=YGb(c[j>>2]|0,c[j+4>>2]|0,c[e+16>>2]|0,0)|0;c[j>>2]=k;c[j+4>>2]=F;Ry(c[a+16>>2]|0,c[h>>2]|0,c[g>>2]|0);l=0;i=d;return l|0}}while(0);yDb(a,16,2060928,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;l=-22;i=d;return l|0}function WV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a+16|0;d=c[b>>2]|0;if((c[d+88>>2]|0)==0){e=ux(a)|0;return 0}f=c[a+12>>2]|0;g=c[f>>2]|0;h=c[f+4>>2]|0;i=0;if(!(((g|0)!=0|(h|0)!=0)&((h|0)<(i|0)|(h|0)==(i|0)&g>>>0<-1>>>0))){e=ux(a)|0;return 0}g=Ty(d,0,0,1)|0;d=F;Ty(c[b>>2]|0,12,0,0)|0;Yy(c[b>>2]|0,c[f>>2]|0);Ty(c[b>>2]|0,g,d,0)|0;e=ux(a)|0;return 0}function XV(a){a=a|0;var b=0,e=0,f=0;if((c[a+8>>2]|0)<24){return 0}b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((e|0)==16728|(e|0)==4800856|(e|0)==4866392)){return 0}e=b+10|0;a=(d[e]|d[e+1|0]<<8)<<16>>16;e=b+12|0;f=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+22|0;if(a<<16>>16==0|(a&65535)>>>0>8>>>0){return 0}if((f|0)==0|(f|0)>192e3){return 0}else{return((((d[e]|d[e+1|0]<<8)<<16>>16)-4&65535)>>>0>28>>>0?0:50)|0}return 0}function YV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=LT(a,0)|0;if((e|0)==0){f=-12;return f|0}a=e+8|0;g=c[a>>2]|0;c[g+8>>2]=1;c[g+48>>2]=69658;Vy(d,4,0)|0;c[b>>2]=rz(d)|0;Vy(d,2,0)|0;b=pz(d)|0;c[(c[a>>2]|0)+416>>2]=b;b=rz(d)|0;c[(c[a>>2]|0)+412>>2]=b;Vy(d,4,0)|0;Vy(d,2,0)|0;Vy(d,2,0)|0;d=c[a>>2]|0;a=c[d+416>>2]|0;if((a|0)==0){f=-1094995529;return f|0}b=c[d+412>>2]|0;if((b|0)==0){f=-1094995529;return f|0}g=gHb(a,(a|0)<0|0?-1:0,120,0)|0;a=gHb(g,F,b,(b|0)<0|0?-1:0)|0;g=eHb(a,F,28,0)|0;a=g;c[d+72>>2]=(a|0)<0?0:a;MT(e,64,1,b);b=e+48|0;c[b>>2]=0;c[b+4>>2]=0;f=0;return f|0}function ZV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=c[c[a+28>>2]>>2]|0;f=d+4|0;if(!((c[f>>2]|0)>>>0<(c[d>>2]|0)>>>0)){g=-541478725;return g|0}d=(c[(c[e+8>>2]|0)+416>>2]|0)*15|0;h=TS(c[a+16>>2]|0,b,d)|0;if((h|0)<0){g=h;return g|0}c[b+32>>2]=c[e>>2];c[f>>2]=(c[f>>2]|0)+d;c[b+48>>2]=28;g=h;return g|0}function _V(a){a=a|0;var b=0,e=0,f=0;if((c[a+8>>2]|0)<36){b=0;return b|0}e=c[a+4>>2]|0;a=e+16|0;f=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((f|0)==0|f>>>0>4>>>0){b=0;return b|0}f=(PGb(e+12|0,1918816,4)|0)==0;b=f?100:0;return b|0}function $V(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;d=i;f=a+12|0;g=c[f>>2]|0;h=c[a+16>>2]|0;Vy(h,4,0)|0;j=rz(h)|0;Vy(h,4,0)|0;Vy(h,4,0)|0;k=rz(h)|0;if(!((k|0)==4|(k|0)==2)){DDb(a,2011328,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l}k=LT(a,0)|0;if((k|0)==0){m=-12;i=d;return m|0}MT(k,32,1,1e3);n=k+8|0;o=c[n>>2]|0;c[o+8>>2]=0;c[o+48>>2]=19;c[o+52>>2]=1464686130;o=rz(h)|0;c[(c[n>>2]|0)+120>>2]=o;o=rz(h)|0;c[(c[n>>2]|0)+124>>2]=o;o=k+56|0;c[o>>2]=rz(h)|0;c[o+4>>2]=0;c[g+40>>2]=c[k>>2];k=g;b[k>>1]=pz(h)|0;Vy(h,2,0)|0;n=WDb(e[k>>1]<<6)|0;p=n;q=g+88|0;c[q>>2]=p;a:do{if((n|0)==0){r=-12}else{b:do{if((b[k>>1]|0)!=0){s=a;t=1;u=0;v=p;while(1){w=v+(u<<6)+4|0;b[w>>1]=pz(h)|0;x=v+(u<<6)+6|0;b[x>>1]=pz(h)|0;y=v+(u<<6)+8|0;c[y>>2]=rz(h)|0;z=v+(u<<6)+12|0;b[z>>1]=pz(h)|0;A=v+(u<<6)+20|0;b[A>>1]=pz(h)|0;B=e[z>>1]|0;C=ba(B,c[y>>2]|0)|0;D=e[x>>1]|0;E=v+(u<<6)+16|0;c[E>>2]=ba(C,D)|0;c[v+(u<<6)+24>>2]=D*36|0;D=v+(u<<6)+28|0;b[D>>1]=64;C=v+(u<<6)+32|0;c[C>>2]=BO(e[w>>1]|0,B)|0;B=v+(u<<6)|0;c[B>>2]=-1;c[v+(u<<6)+48>>2]=0;G=v+(u<<6)+56|0;c[G>>2]=0;c[G+4>>2]=0;G=e[A>>1]|0;if((G&7|0)!=0){yDb(s,24,1972424,(l=i,i=i+8|0,c[l>>2]=G,l)|0);i=l}G=b[x>>1]|0;if(G<<16>>16==0){break}if((c[y>>2]|0)==0|(G&65535)>>>0>1819>>>0){break}G=LT(a,0)|0;if((G|0)==0){r=-12;break a}A=c[G+8>>2]|0;c[A+8>>2]=1;c[A+48>>2]=c[C>>2];c[A+52>>2]=e[w>>1]|0;w=e[x>>1]|0;c[A+416>>2]=w;c[A+412>>2]=c[y>>2];c[A+792>>2]=e[z>>1]|0;c[A+72>>2]=c[E>>2];c[A+432>>2]=w*36|0;MT(G,32,e[D>>1]|0,c[y>>2]|0);c[B>>2]=c[G>>2];B=c[o+4>>2]|0;y=G+56|0;c[y>>2]=c[o>>2];c[y+4>>2]=B;if(!((t&65535)>>>0<(e[k>>1]|0)>>>0)){break b}B=t&65535;t=t+1&65535;u=B;v=c[q>>2]|0}yDb(s,16,1943536,(l=i,i=i+8|0,c[l>>2]=u,l)|0);i=l;r=-1094995529;break a}}while(0);v=Ty(h,0,0,1)|0;t=F;B=g+24|0;c[B>>2]=v;c[B+4>>2]=t;B=ZGb(j,0,v,t)|0;c[g+8>>2]=B;b[g+34>>1]=(b[k>>1]|0)+1;m=0;i=d;return m|0}}while(0);$Db((c[f>>2]|0)+88|0);m=r;i=d;return m|0}function aW(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+8|0;j=h|0;k=f+12|0;l=c[k>>2]|0;m=l+56|0;if((c[m>>2]|0)==(c[l+60>>2]|0)){n=l+16|0;o=l+24|0;p=c[o>>2]|0;q=c[o+4>>2]|0;if((c[n>>2]|0)==(p|0)&(c[n+4>>2]|0)==(q|0)){r=-541478725;i=h;return r|0}s=f+16|0;t=c[s>>2]|0;c[n>>2]=p;c[n+4>>2]=q;u=Ty(t,p,q,0)|0;if(!((u|0)==(c[n>>2]|0)&(F|0)==(c[n+4>>2]|0))){r=-5;i=h;return r|0}u=c[l+8>>2]|0;q=l+4|0;c[q>>2]=u;if(u>>>0<(((e[l>>1]|0)<<2)+12|0)>>>0){r=-5;i=h;return r|0}u=j;p=j|0;t=c[k>>2]|0;v=c[s>>2]|0;c[t+8>>2]=rz(v)|0;if((mz(v,u,8)|0)!=8){r=-5;i=h;return r|0}s=c[p>>2]&8388607;w=t+40|0;y=t+44|0;c[y>>2]=s;c[t+56>>2]=0;z=(c[p>>2]|0)>>>23&255;A=t+60|0;c[A>>2]=z;B=t+64|0;c[B>>2]=(d[j+3|0]|0)>>>7&255;j=t;C=b[j>>1]|0;c[y>>2]=s-((C&65535)<<2);s=t+32|0;b[s>>1]=0;if((z|0)==0){c[A>>2]=1;b[s>>1]=(e[t+34>>1]|0)>>>0>1>>>0|0}a:do{if(!(C<<16>>16==0)){s=t+88|0;z=0;D=0;while(1){E=c[s>>2]|0;if((mz(v,u,4)|0)!=4){r=-5;break}G=c[p>>2]&8388607;H=E+(D<<6)+36|0;c[H>>2]=G;if((G|0)!=0|z<<16>>16==0){I=G}else{G=c[(c[s>>2]|0)+(D-1<<6)+36>>2]|0;c[H>>2]=G;I=G}G=(I>>>0)/((c[A>>2]|0)>>>0)|0;c[E+(D<<6)+48>>2]=G-((G>>>0)%((c[E+(D<<6)+24>>2]|0)>>>0)|0);E=z+1&65535;if(!((E&65535)>>>0<(e[j>>1]|0)>>>0)){break a}z=E;D=E&65535}i=h;return r|0}}while(0);A=Ty(v,0,0,1)|0;I=F;p=t+48|0;c[p>>2]=A;c[p+4>>2]=I;u=b[j>>1]|0;j=c[y>>2]|0;if(!(u<<16>>16==0)){C=YGb(j,0,A,I)|0;I=c[t+88>>2]|0;A=F;D=C;C=0;z=0;while(1){s=I+(z<<6)+40|0;c[s>>2]=D;c[s+4>>2]=A;s=YGb(c[I+(z<<6)+36>>2]|0,0,D,A)|0;E=C+1&65535;if((E&65535)>>>0<(u&65535)>>>0){A=F;D=s;C=E;z=E&65535}else{break}}}do{if((j|0)!=0){if((c[B>>2]|0)==0){break}z=rz(v)|0;C=fe(z>>>1<<14&16384|z<<15&32768|z>>>2<<13&8192|z>>>3<<12&4096|z>>>4<<11&2048|z>>>5<<10&1024|z>>>6<<7&896|0)|0;z=t+68|0;x=C;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[y>>2]=(c[y>>2]|0)-4;D=YGb(c[p>>2]|0,c[p+4>>2]|0,4,0)|0;c[p>>2]=D;c[p+4>>2]=F;D=c[w>>2]|0;if(!((D|0)>-1)){break}if(!(D>>>0<(c[f+24>>2]|0)>>>0)){yDb(0,0,2121400,(A=i,i=i+24|0,c[A>>2]=2060872,c[A+8>>2]=2057464,c[A+16>>2]=381,A)|0);i=A;Cd();return 0}A=(c[(c[f+28>>2]|0)+(D<<2)>>2]|0)+8|0;D=c[A>>2]|0;if((c[D+100>>2]|0)<4){ZDb(c[D+96>>2]|0);BT(c[A>>2]|0,4)|0;J=c[A>>2]|0;K=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0}else{J=D;K=C}C=c[J+96>>2]|0;x=K;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x}}while(0);K=YGb(c[q>>2]|0,0,c[n>>2]|0,c[n+4>>2]|0)|0;c[o>>2]=K;c[o+4>>2]=F}o=l+32|0;K=b[o>>1]|0;do{if(K<<16>>16==0){n=c[k>>2]|0;q=c[f+16>>2]|0;J=n+40|0;w=n+48|0;p=Ty(q,c[w>>2]|0,c[w+4>>2]|0,0)|0;if(!((p|0)==(c[w>>2]|0)&(F|0)==(c[w+4>>2]|0))){r=-5;i=h;return r|0}p=rz(q)|0;y=p<<2&524284;t=y+4|0;v=p>>>17;p=y+8|0;y=n+44|0;if(p>>>0>(c[y>>2]|0)>>>0){r=-5;i=h;return r|0}B=TS(q,g,t)|0;if((B|0)!=(t|0)){if((B|0)==0){break}else{r=B}i=h;return r|0}B=g+24|0;q=c[B>>2]|0;j=q+t|0;t=q;do{q=t;x=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;t=t+4|0;}while(t>>>0<j>>>0);j=c[B>>2]|0;c[g+32>>2]=c[J>>2];t=v;q=0;C=n+80|0;D=YGb(c[C>>2]|0,c[C+4>>2]|0,t,q)|0;z=F;A=n+72|0;c[A>>2]=D;c[A+4>>2]=z;c[g+48>>2]=0;A=g+8|0;c[A>>2]=D;c[A+4>>2]=z;z=g+16|0;c[z>>2]=0;c[z+4>>2]=-2147483648;z=YGb(c[C>>2]|0,c[C+4>>2]|0,t,q)|0;c[C>>2]=z;c[C+4>>2]=F;c[g+36>>2]=(d[j]|0)>>>7&255^1;c[y>>2]=(c[y>>2]|0)-p;j=YGb(c[w>>2]|0,c[w+4>>2]|0,p,0)|0;c[w>>2]=j;c[w+4>>2]=F}else{j=(K&65535)-1|0;C=c[k>>2]|0;z=c[f+16>>2]|0;q=c[C+88>>2]|0;t=q+(j<<6)+40|0;A=Ty(z,c[t>>2]|0,c[t+4>>2]|0,0)|0;if(!((A|0)==(c[t>>2]|0)&(F|0)==(c[t+4>>2]|0))){r=-5;i=h;return r|0}if(((c[C+56>>2]|0)+1|0)>>>0<(c[C+60>>2]|0)>>>0){C=c[q+(j<<6)+48>>2]|0;A=c[q+(j<<6)+36>>2]|0;L=C>>>0>A>>>0?A:C}else{L=c[q+(j<<6)+36>>2]|0}C=TS(z,g,L)|0;if((C|0)>=1){c[g+32>>2]=c[q+(j<<6)>>2];z=(L>>>0)/((c[q+(j<<6)+24>>2]|0)>>>0)|0;c[g+48>>2]=z;A=q+(j<<6)+56|0;D=c[A+4>>2]|0;u=g+8|0;c[u>>2]=c[A>>2];c[u+4>>2]=D;D=g+16|0;c[D>>2]=0;c[D+4>>2]=-2147483648;D=YGb(c[A>>2]|0,c[A+4>>2]|0,z,0)|0;c[A>>2]=D;c[A+4>>2]=F;A=q+(j<<6)+36|0;c[A>>2]=(c[A>>2]|0)-L;A=YGb(c[t>>2]|0,c[t+4>>2]|0,L,0)|0;c[t>>2]=A;c[t+4>>2]=F;break}if((C|0)==0){break}else{r=C}i=h;return r|0}}while(0);L=(b[o>>1]|0)+1&65535;b[o>>1]=L;if((L&65535)>>>0<(e[l+34>>1]|0)>>>0){r=0;i=h;return r|0}b[o>>1]=0;c[m>>2]=(c[m>>2]|0)+1;r=0;i=h;return r|0}function bW(a){a=a|0;$Db((c[a+12>>2]|0)+88|0);return 0}function cW(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;do{if((PGb(b,2355264,4)|0)==0){if((PGb(b+8|0,2335248,4)|0)==0){d=100}else{break}return d|0}}while(0);d=0;return d|0}function dW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;e=c[b+16>>2]|0;f=c[b+12>>2]|0;if((rz(e)|0)!=1179011410){g=-1;i=d;return g|0}rz(e)|0;if((rz(e)|0)!=1095587672){g=-1;i=d;return g|0}if((rz(e)|0)!=544501094){g=-1;i=d;return g|0}h=rz(e)|0;j=LT(b,0)|0;if((j|0)==0){g=-12;i=d;return g|0}k=j+8|0;l=AO(e,c[k>>2]|0,h)|0;if((l|0)<0){g=l;i=d;return g|0}c[j+236>>2]=0;l=c[k>>2]|0;h=c[l+48>>2]|0;do{if((h|0)==86024){m=l+100|0;n=c[m>>2]|0;if((n|0)!=0){DDb(b,2116496,(o=i,i=i+8|0,c[o>>2]=n,o)|0);i=o;break}c[m>>2]=6;m=cEb(22)|0;c[(c[k>>2]|0)+96>>2]=m;m=c[(c[k>>2]|0)+96>>2]|0;if((m|0)==0){g=-12;i=d;return g|0}else{a[m+4|0]=31;break}}else{DDb(b,2195136,(o=i,i=i+16|0,c[o>>2]=c[l+52>>2],c[o+8>>2]=h,o)|0);i=o}}while(0);h=c[k>>2]|0;if((c[h+416>>2]|0)==0){yDb(b,24,2057432,(o=i,i=i+8|0,c[o>>2]=0,o)|0);i=o;g=-1094995529;i=d;return g|0}if((c[h+792>>2]|0)==0){yDb(b,24,2011288,(o=i,i=i+8|0,c[o>>2]=0,o)|0);i=o;g=-1094995529;i=d;return g|0}MT(j,64,1,c[h+412>>2]|0);h=e+52|0;if((c[h>>2]|0)!=0){g=-1;i=d;return g|0}l=b;b=0;m=0;while(1){n=rz(e)|0;p=rz(e)|0;q=p;r=0;if((n|0)==1935962212){if((b|0)!=0){s=20;break}if(!((q&3|0)==0&(r&0|0)==0)){yDb(l,24,1943488,(o=i,i=i+16|0,c[o>>2]=q,c[o+8>>2]=r,o)|0);i=o}t=p>>>2;if((t|0)==0|p>>>0>2147483643>>>0){s=24;break}u=WDb(t<<2)|0;v=u;if((u|0)==0){g=-12;s=41;break}u=t-1|0;w=u<<2|0>>>30;x=0<<2|u>>>30;u=0;do{c[v+(u<<2)>>2]=rz(e)|0;u=u+1|0;}while(u>>>0<t>>>0);u=YGb(q,r,-4,-1)|0;y=ZGb(u,F,w,x)|0;z=F;A=y;B=t;C=v}else if((n|0)==1635017060){s=30;break}else{z=r;A=q;B=m;C=b}Vy(e,A,z)|0;if((c[h>>2]|0)==0){b=C;m=B}else{g=-1;s=41;break}}if((s|0)==20){yDb(l,16,1972392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;g=-1;i=d;return g|0}else if((s|0)==24){yDb(l,16,1918784,(o=i,i=i+16|0,c[o>>2]=q,c[o+8>>2]=r,o)|0);i=o;g=-1;i=d;return g|0}else if((s|0)==30){if((p|0)==0){p=f;c[p>>2]=-1;c[p+4>>2]=2147483647}else{p=Ty(e,0,0,1)|0;B=YGb(p,F,q,r)|0;p=f;c[p>>2]=B;c[p+4>>2]=F}p=c[k>>2]|0;do{if((b|0)==0|(m|0)==0){B=c[p+72>>2]|0;if((B|0)==0){break}f=c[p+412>>2]|0;C=gHb(q<<3|0>>>29,r<<3|q>>>29,f,(f|0)<0|0?-1:0)|0;f=eHb(C,F,B,(B|0)<0|0?-1:0)|0;B=j+56|0;c[B>>2]=f;c[B+4>>2]=F}else{B=c[p+416>>2]|0;f=c[p+792>>2]|0;C=(ba(f,B)|0)>>3;if((C|0)==0){yDb(l,16,1897928,(o=i,i=i+16|0,c[o>>2]=f,c[o+8>>2]=B,o)|0);i=o;g=-1094995529;i=d;return g|0}else{B=j+56|0;c[B>>2]=((c[b+(m-1<<2)>>2]|0)>>>0)/(C>>>0)|0;c[B+4>>2]=0;B=Ty(e,0,0,1)|0;f=F;h=0;while(1){z=h+1|0;A=c[(c[k>>2]|0)+432>>2]|0;y=ba(A,z)|0;u=YGb(y,(y|0)<0|0?-1:0,B,f)|0;jT(j,u,F,((c[b+(h<<2)>>2]|0)>>>0)/(C>>>0)|0,0,A,0,1)|0;if(z>>>0<m>>>0){h=z}else{break}}}}}while(0);ZDb(b);g=0;i=d;return g|0}else if((s|0)==41){i=d;return g|0}return 0}function eW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[c[a+28>>2]>>2]|0;e=c[a+12>>2]|0;f=c[e>>2]|0;g=c[e+4>>2]|0;e=a+16|0;a=Ty(c[e>>2]|0,0,0,1)|0;h=ZGb(f,g,a,F)|0;a=F;g=0;if((a|0)<(g|0)|(a|0)==(g|0)&h>>>0<1>>>0){i=-541478725;return i|0}g=c[(c[d+8>>2]|0)+432>>2]|0;d=(g|0)>1;f=d?g:2230;j=d?(g|0)<0|0?-1:0:0;g=(j|0)>(a|0)|(j|0)==(a|0)&f>>>0>h>>>0;g?a:j;j=TS(c[e>>2]|0,b,g?h:f)|0;if((j|0)<0){i=j;return i|0}c[b+32>>2]=0;i=j;return i|0}function fW(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[b+4>>2]|0;b=e;do{if((d[b]|d[b+1|0]<<8)<<16>>16<<16>>16==20313){if(!((d[e+2|0]|0)>>>0<10>>>0)){break}if(!((d[e+3|0]|0)>>>0<10>>>0)){break}if((a[e+6|0]|0)==0){break}f=a[e+7|0]|0;if(f<<24>>24==0){break}if(!((a[e+8|0]&1)==0)){break}if(!((a[e+10|0]&1)==0)){break}g=e+18|0;h=(d[g]|d[g+1|0]<<8)<<16>>16;if(!((h&65535)>>>0>919>>>0)){break}if((h&65535|0)<(((f&255)<<11|4)+((d[e+12|0]|0)*3|0)|0)){i=75}else{break}return i|0}}while(0);i=0;return i|0}function gW(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=LT(a,0)|0;h=LT(a,0)|0;if((g|0)==0|(h|0)==0){j=-12;i=b;return j|0}k=h+8|0;if((BT(c[k>>2]|0,8)|0)!=0){j=-12;i=b;return j|0}l=c[g+8>>2]|0;c[l+8>>2]=1;c[l+48>>2]=69661;c[l+416>>2]=1;g=l+448|0;c[g>>2]=4;c[g+4>>2]=0;c[l+412>>2]=22050;l=c[k>>2]|0;c[l+8>>2]=0;c[l+48>>2]=140;Vy(f,6,0)|0;k=lz(f)|0;g=e+84|0;c[g>>2]=(lz(f)|0)<<11;c[l+120>>2]=pz(f)|0;c[l+124>>2]=pz(f)|0;c[h+80>>2]=1;c[h+84>>2]=2;m=l+96|0;n=mz(f,c[m>>2]|0,8)|0;if((n|0)<8){j=(n|0)<0?n:-541478725;i=b;return j|0}n=c[m>>2]|0;m=e+92|0;c[m>>2]=((d[n]|0)*3|0)+4;o=n+6|0;n=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=e+88|0;c[o>>2]=n;c[l+72>>2]=ba(k<<3,(c[g>>2]|0)-n|0)|0;n=c[o>>2]|0;do{if((n|0)>=920){if(((c[m>>2]|0)+n|0)>=(c[g>>2]|0)){break}Ty(f,2048,0,0)|0;MT(h,32,1,k);j=0;i=b;return j|0}}while(0);yDb(a,16,2195112,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-1094995529;i=b;return j|0}function hW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;b=e+88|0;g=(c[e+84>>2]|0)-(c[b>>2]|0)|0;h=e+92|0;i=g-(c[h>>2]|0)|0;j=e;c[e+32>>2]=1;k=e+24|0;if((c[k>>2]|0)!=0){UGb(d|0,e|0,80)|0;c[k>>2]=0;c[e>>2]=0;c[e+52>>2]=0;c[e+28>>2]=0;l=e+80|0;a[c[d+24>>2]|0]=c[l>>2];m=d+36|0;c[m>>2]=c[m>>2]|1;c[l>>2]=c[l>>2]^1;n=c[d+28>>2]|0;return n|0}l=wZ(j,g)|0;if((l|0)<0){n=l;return n|0}l=Ty(f,0,0,1)|0;g=e+64|0;c[g>>2]=l;c[g+4>>2]=F;l=mz(f,c[k>>2]|0,c[h>>2]|0)|0;do{if((l|0)<0){o=l}else{if((l|0)<(c[h>>2]|0)){o=-541478725;break}e=TS(f,d,920)|0;if((e|0)<0){o=e;break}m=c[g+4>>2]|0;p=d+64|0;c[p>>2]=c[g>>2];c[p+4>>2]=m;m=(c[b>>2]|0)-e|0;Vy(f,m,(m|0)<0|0?-1:0)|0;m=mz(f,(c[k>>2]|0)+(c[h>>2]|0)|0,i)|0;if((m|0)<0){o=m;break}if((m|0)<(i|0)){yZ(j,(c[h>>2]|0)+m|0)}n=c[b>>2]|0;return n|0}}while(0);BZ(j);n=o;return n|0}function iW(a){a=a|0;BZ(c[a+12>>2]|0);return 0}function jW(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[a+12>>2]|0;if((b|0)==0){g=-1;return g|0}b=a+1248|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a+16|0;a=Wy(c[b>>2]|0)|0;j=c[f+84>>2]|0;k=j;l=(j|0)<0|0?-1:0;j=ZGb(a,F,h,i)|0;a=ZGb(j,F,k,l)|0;j=eHb(a,F,k,l)|0;a=j;j=a;m=(a|0)<0|0?-1:0;a=(m|0)>(e|0)|(m|0)==(e|0)&j>>>0>d>>>0;n=a?d:j;j=a?e:m;m=0;e=(j|0)<(m|0)|(j|0)==(m|0)&n>>>0<0>>>0;m=e?0:n;n=gHb(m,e?0:j,k,l)|0;l=YGb(n,F,h,i)|0;i=Ty(c[b>>2]|0,l,F,0)|0;l=F;b=0;if((l|0)<(b|0)|(l|0)==(b|0)&i>>>0<0>>>0){g=-1;return g|0}BZ(f);c[f+80>>2]=m&1;g=0;return g|0}function kW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+12>>2]|0;if((c[a+24>>2]|0)!=1){e=-5;i=b;return e|0}f=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[f+48>>2]|0)!=14){yDb(a,16,1911560,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;e=-1094995529;i=b;return e|0}h=c[f+140>>2]|0;a:do{switch(h|0){case 8:case 32:case 0:case 4:case 5:{break};case 7:{yDb(a,24,1909288,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;break};case 70:case 80:case 76:case 72:case 74:case 78:case 302:case 306:case 310:case 304:case 308:case 312:case 54:case 56:case 58:{j=a;if(!((c[f+680>>2]|0)>-1)){yDb(j,24,1906120,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;break a}k=ZEb(h)|0;yDb(j,16,1907768,(g=i,i=i+8|0,c[g>>2]=k,g)|0);i=g;e=-22;i=b;return e|0};default:{yDb(a,16,1904344,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;e=-5;i=b;return e|0}}}while(0);c[d>>2]=1;e=0;i=b;return e|0}function lW(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+320|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+296|0;l=c[a+28>>2]|0;m=c[l+(c[b+32>>2]<<2)>>2]|0;n=c[a+16>>2]|0;o=c[a+12>>2]|0;p=c[b+24>>2]|0;b=p;q=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;r=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+8|0;s=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+32|0;t=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+36|0;u=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+40|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;do{if((c[o>>2]|0)!=0){c[o>>2]=0;b=e+32|0;v=c[l>>2]|0;w=v+8|0;x=c[w>>2]|0;y=c[x+120>>2]|0;z=c[x+124>>2]|0;A=c[x+108>>2]|0;B=c[x+104>>2]|0;iFb(f,g,A,(A|0)<0|0?-1:0,B,(B|0)<0|0?-1:0,2147483647,0)|0;B=c[v+80>>2]|0;A=c[v+84>>2]|0;v=(B|0)==0&(A|0)==1?0:A;A=c[w>>2]|0;w=c[A+804>>2]|0;do{if((w|0)==0){C=112}else{if((c[w+296>>2]|0)==0){C=112;break}C=(c[w+300>>2]|0)!=0?116:98}}while(0);w=c[A+408>>2]|0;if((w|0)==4|(w|0)==2){D=116}else if((w|0)==5){E=8}else if((w|0)==1){D=112}else{if((w|0)==3){E=8}else{D=C}}if((E|0)==8){D=98}a:do{switch(c[A+140>>2]|0){case 80:{F=1950816;break};case 4:{F=1957680;break};case 56:{F=1921728;break};case 8:{F=1978600;break};case 58:{F=1919760;break};case 0:{w=c[A+400>>2]|0;if((w|0)==1){F=1962824;break a}else if((w|0)==3){F=1971600;break a}else{F=1959816;break a}break};case 78:{F=1942912;break};case 304:{F=1928272;break};case 5:{F=1955248;break};case 74:{F=1944832;break};case 72:{F=1946928;break};case 302:{F=1934632;break};case 306:{F=1931840;break};case 7:{F=1973792;break};case 70:{F=1953152;break};case 310:{F=1930024;break};case 32:{F=1975960;break};case 308:{F=1926544;break};case 312:{F=1924984;break};case 54:{F=1923400;break};case 76:{F=1948936;break};default:{F=9203168}}}while(0);A=c[f>>2]|0;w=c[g>>2]|0;x=Lb(b|0,256,1918336,(G=i,i=i+72|0,c[G>>2]=2057416,c[G+8>>2]=y,c[G+16>>2]=z,c[G+24>>2]=A,c[G+32>>2]=w,c[G+40>>2]=D<<24>>24,c[G+48>>2]=B,c[G+56>>2]=v,c[G+64>>2]=F,G)|0)|0;i=G;if((x|0)>=0){Ry(n,b,SGb(b|0)|0);break}yDb(a,16,1991984,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-5;i=e;return H|0}}while(0);F=k|0;Lb(F|0,20,1988496,(G=i,i=i+8|0,c[G>>2]=2116488,G)|0)|0;i=G;Ry(n,F,SGb(F|0)|0);F=m+8|0;m=c[F>>2]|0;k=c[m+120>>2]|0;D=c[m+124>>2]|0;g=c[m+140>>2]|0;switch(g|0){case 32:case 70:case 80:case 76:case 72:case 74:case 78:case 302:case 306:case 310:case 304:case 308:case 312:case 54:case 56:case 58:{I=k<<1;break};case 8:case 7:case 0:case 4:case 5:{I=k;break};default:{k=ZEb(g)|0;yDb(a,16,1984120,(G=i,i=i+8|0,c[G>>2]=k,G)|0);i=G;H=-22;i=e;return H|0}}if((D|0)>0){G=0;k=q;while(1){Ry(n,k,I);q=G+1|0;if((q|0)<(D|0)){G=q;k=k+t|0}else{break}}J=c[(c[F>>2]|0)+140>>2]|0}else{J=g}if((J|0)==8|(J|0)==32){H=0;i=e;return H|0}eFb(J,h,j)|0;J=-(-I>>c[h>>2])|0;h=-D>>c[j>>2];j=-h|0;D=(h|0)<0;if(D){K=0;L=r}else{H=0;i=e;return H|0}while(1){Ry(n,L,J);r=K+1|0;if((r|0)<(j|0)){K=r;L=L+u|0}else{break}}if(D){M=0;N=s}else{H=0;i=e;return H|0}while(1){Ry(n,N,J);s=M+1|0;if((s|0)<(j|0)){M=s;N=N+p|0}else{H=0;break}}i=e;return H|0}function mW(a){a=a|0;var b=0;b=(RGb(c[a+4>>2]|0,2057416,9)|0)==0;return(b?100:0)|0}function nW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;d=i;i=i+136|0;e=d|0;f=d+96|0;g=d+104|0;h=d+112|0;j=d+120|0;k=d+128|0;l=c[b+16>>2]|0;c[g>>2]=0;c[h>>2]=0;c[j>>2]=0;c[k>>2]=0;m=0;while(1){if((m|0)>=80){n=5;break}o=(lz(l)|0)&255;a[e+m|0]=o;p=m+1|0;if(o<<24>>24==10){n=4;break}else{m=p}}do{if((n|0)==4){a[e+p|0]=32;a[e+(m+2)|0]=0}else if((n|0)==5){if((m|0)==80){q=-1}else{break}i=d;return q|0}}while(0);if((RGb(e|0,2057416,9)|0)!=0){q=-1;i=d;return q|0}p=m+1|0;m=e+p|0;do{if((p|0)>10){l=-1;o=-1;r=-1;s=-1;t=0;u=63;v=e+10|0;a:while(1){w=a[v]|0;b:do{if(w<<24>>24==32){x=v;y=u;z=t;A=s;B=r;C=o;D=l}else{E=v+1|0;switch(w<<24>>24|0){case 88:{do{if((RGb(2094264,E,6)|0)==0){F=v+7|0;if((RGb(2088992,F,7)|0)==0){G=F;H=0;break}if((RGb(2084112,F,8)|0)==0){G=F;H=0;break}if((RGb(2078736,F,8)|0)==0){G=F;H=0;break}if((RGb(2073856,F,5)|0)==0){G=F;H=70;break}if((RGb(2069280,F,5)|0)==0){G=F;H=80;break}if((RGb(2064648,F,5)|0)==0){G=F;H=76;break}if((RGb(2060696,F,6)|0)==0){G=F;H=72;break}if((RGb(2056504,F,6)|0)==0){G=F;H=74;break}if((RGb(2045312,F,6)|0)==0){G=F;H=78;break}if((RGb(2040336,F,6)|0)==0){G=F;H=302;break}if((RGb(2036872,F,6)|0)==0){G=F;H=306;break}if((RGb(2033240,F,6)|0)==0){G=F;H=310;break}if((RGb(2029072,F,6)|0)==0){G=F;H=304;break}if((RGb(2025408,F,6)|0)==0){G=F;H=308;break}if((RGb(2021920,F,6)|0)==0){G=F;H=312;break}if((RGb(2018208,F,6)|0)==0){G=F;H=54;break}if((RGb(2014144,F,6)|0)==0){G=F;H=56;break}if((RGb(2010448,F,6)|0)==0){G=F;H=58;break}if((RGb(2159784,F,3)|0)==0){G=F;H=7;break}if((RGb(2152800,F,3)|0)==0){G=F;H=4;break}I=(RGb(2133488,F,3)|0)==0;G=F;H=I?5:s}else{G=E;H=s}}while(0);I=G;while(1){if(!(I>>>0<m>>>0)){x=I;y=u;z=t;A=H;B=r;C=o;D=l;break b}if((a[I]|0)==32){x=I;y=u;z=t;A=H;B=r;C=o;D=l;break}else{I=I+1|0}}break};case 67:{do{if((RGb(2011280,E,7)|0)==0){J=2;K=0}else{if((RGb(1972376,E,8)|0)==0){J=1;K=0;break}if((RGb(1943472,E,8)|0)==0){J=3;K=0;break}if((RGb(1918776,E,6)|0)==0){J=t;K=54;break}if((RGb(1897920,E,6)|0)==0){J=t;K=56;break}if((RGb(2355256,E,6)|0)==0){J=t;K=58;break}if((RGb(2335240,E,6)|0)==0){J=t;K=304;break}if((RGb(2310136,E,6)|0)==0){J=t;K=308;break}if((RGb(2291216,E,6)|0)==0){J=t;K=312;break}if((RGb(2275320,E,6)|0)==0){J=t;K=302;break}if((RGb(2259552,E,6)|0)==0){J=t;K=306;break}if((RGb(2244944,E,6)|0)==0){J=t;K=310;break}if((RGb(2232568,E,6)|0)==0){J=t;K=72;break}if((RGb(2220096,E,6)|0)==0){J=t;K=74;break}if((RGb(2210872,E,6)|0)==0){J=t;K=78;break}if((RGb(2201992,E,5)|0)==0){J=t;K=70;break}if((RGb(2194024,E,5)|0)==0){J=t;K=80;break}if((RGb(2177360,E,5)|0)==0){J=t;K=76;break}if((RGb(2166352,E,3)|0)==0){J=2;K=0;break}if((RGb(2159784,E,3)|0)==0){J=t;K=7;break}if((RGb(2152800,E,3)|0)==0){J=t;K=4;break}if((RGb(2145896,E,8)|0)==0){n=35;break a}if((RGb(2133488,E,3)|0)==0){J=t;K=5;break}if((RGb(2127112,E,6)|0)==0){J=t;K=32;break}if((RGb(2121192,E,4)|0)==0){J=t;K=8}else{n=40;break a}}}while(0);I=E;while(1){if(!(I>>>0<m>>>0)){x=I;y=u;z=J;A=s;B=K;C=o;D=l;break b}if((a[I]|0)==32){x=I;y=u;z=J;A=s;B=K;C=o;D=l;break}else{I=I+1|0}}break};case 87:{I=kb(E|0,f|0,10)|0;x=c[f>>2]|0;y=u;z=t;A=s;B=r;C=o;D=I;break b;break};case 73:{x=v+2|0;y=a[E]|0;z=t;A=s;B=r;C=o;D=l;break b;break};case 70:{xd(E|0,2101192,(L=i,i=i+16|0,c[L>>2]=g,c[L+8>>2]=h,L)|0)|0;i=L;I=E;while(1){if(!(I>>>0<m>>>0)){x=I;y=u;z=t;A=s;B=r;C=o;D=l;break b}if((a[I]|0)==32){x=I;y=u;z=t;A=s;B=r;C=o;D=l;break}else{I=I+1|0}}break};case 65:{xd(E|0,2101192,(L=i,i=i+16|0,c[L>>2]=j,c[L+8>>2]=k,L)|0)|0;i=L;I=E;while(1){if(!(I>>>0<m>>>0)){x=I;y=u;z=t;A=s;B=r;C=o;D=l;break b}if((a[I]|0)==32){x=I;y=u;z=t;A=s;B=r;C=o;D=l;break}else{I=I+1|0}}break};case 72:{I=kb(E|0,f|0,10)|0;x=c[f>>2]|0;y=u;z=t;A=s;B=r;C=I;D=l;break b;break};default:{x=E;y=u;z=t;A=s;B=r;C=o;D=l;break b}}}}while(0);w=x+1|0;if(w>>>0<m>>>0){l=D;o=C;r=B;s=A;t=z;u=y;v=w}else{n=76;break}}if((n|0)==35){yDb(b,16,2139848,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-1;i=d;return q|0}else if((n|0)==40){yDb(b,16,2115776,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-1;i=d;return q|0}else if((n|0)==76){if((D|0)==-1|(C|0)==-1){break}if((B|0)==-1){M=(A|0)==-1?0:A}else{M=B}if((c[g>>2]|0)<1){n=82}else{if((c[h>>2]|0)<1){n=82}}if((n|0)==82){c[g>>2]=25;c[h>>2]=1}do{if((c[j>>2]|0)==0){if((c[k>>2]|0)!=0){break}c[k>>2]=1}}while(0);v=LT(b,0)|0;if((v|0)==0){q=-12;i=d;return q|0}u=v+8|0;t=c[u>>2]|0;c[t+120>>2]=D;c[t+124>>2]=C;t=c[g>>2]|0;s=c[h>>2]|0;iFb(g,h,t,(t|0)<0|0?-1:0,s,(s|0)<0|0?-1:0,2147483647,0)|0;MT(v,64,c[h>>2]|0,c[g>>2]|0);s=v+92|0;t=c[v+40>>2]|0;c[s>>2]=c[v+44>>2];c[s+4>>2]=t;t=c[u>>2]|0;c[t+140>>2]=M;c[t+8>>2]=0;c[t+48>>2]=14;s=c[k>>2]|0;c[v+80>>2]=c[j>>2];c[v+84>>2]=s;c[t+400>>2]=z;switch(y<<24>>24|0){case 63:{N=t;break};case 116:{c[t+408>>2]=4;q=0;i=d;return q|0};case 98:{c[t+408>>2]=5;q=0;i=d;return q|0};case 109:{yDb(b,16,1995248,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;N=c[u>>2]|0;break};case 112:{c[t+408>>2]=1;q=0;i=d;return q|0};default:{yDb(b,16,1999704,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-22;i=d;return q|0}}c[N+408>>2]=0;q=0;i=d;return q|0}}}while(0);yDb(b,16,1999704,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-1;i=d;return q|0}function oW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+88|0;f=e|0;g=c[c[b+28>>2]>>2]|0;h=b+16|0;b=0;while(1){if((b|0)>=80){break}j=(lz(c[h>>2]|0)|0)&255;a[f+b|0]=j;k=b+1|0;if(j<<24>>24==10){l=4;break}else{b=k}}if((l|0)==4){a[f+k|0]=0}k=c[h>>2]|0;l=c[k+76>>2]|0;if((l|0)!=0){m=l;i=e;return m|0}if((c[k+52>>2]|0)!=0){m=-541478725;i=e;return m|0}if((b|0)==80){m=-1094995529;i=e;return m|0}if((RGb(f|0,2116488,5)|0)!=0){m=-1094995529;i=e;return m|0}f=c[g+8>>2]|0;g=QZ(c[f+140>>2]|0,c[f+120>>2]|0,c[f+124>>2]|0)|0;if((g|0)<0){m=g;i=e;return m|0}f=TS(c[h>>2]|0,d,g)|0;if((f|0)<0){m=f;i=e;return m|0}if((f|0)==(g|0)){c[d+32>>2]=0;m=0;i=e;return m|0}else{m=(c[(c[h>>2]|0)+52>>2]|0)!=0?-541478725:-5;i=e;return m|0}return 0}function pW(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1179011410){a=b+8|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1447909428?100:0)|0}else{return 0}return 0}function qW(b){b=b|0;var e=0,f=0,h=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;f=c[b+16>>2]|0;h=c[b+12>>2]|0;j=h+4|0;c[j>>2]=0;l=h+8|0;m=l;c[m>>2]=0;n=h+24|0;g[n>>2]=1.0;Vy(f,12,0)|0;o=rz(f)|0;p=rz(f)|0;if((o|0)!=1414744396){q=-1094995529;i=e;return q|0}o=p-4|0;if((rz(f)|0)!=1145128264|(o|0)<0){q=-1094995529;i=e;return q|0}r=WDb(o)|0;if((r|0)==0){q=-12;i=e;return q|0}if((mz(f,r,o)|0)!=(o|0)){ZDb(r);q=-5;i=e;return q|0}s=p-12|0;a:do{if((s|0)>0){p=h;t=0;b:while(1){u=r+t|0;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=r+(t+4)|0;w=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=o-t|0;y=u-8|0;do{if(w>>>0>y>>>0){if((v|0)==1600418931){z=12}else if((v|0)==1802663030|(v|0)==1802663027){z=10;break b}else{A=t}}else{if((v|0)==1600418931){z=12;break}else if((v|0)==1802663030){if((w|0)!=68|(w+8|0)>(u|0)){B=-1094995529;break a}C=LT(b,0)|0;if((C|0)==0){B=-12;break a}MT(C,60,1,~~+g[n>>2]);c[p>>2]=c[C>>2];D=C+8|0;C=c[D>>2]|0;c[C+8>>2]=0;c[C+48>>2]=35;c[C+100>>2]=4;C=WDb(4)|0;c[(c[D>>2]|0)+96>>2]=C;C=r+(t+16)|0;E=c[(c[D>>2]|0)+96>>2]|0;x=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;E=r+(t+36)|0;C=c[D>>2]|0;c[C+120>>2]=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24;E=r+(t+40)|0;c[C+124>>2]=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24;A=t+76|0;break}else if((v|0)!=1802663027){A=t;break}if((w|0)!=40|(w+8|0)>(u|0)){B=-1094995529;break a}E=r+(t+8)|0;C=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;if(C>>>0>134217725>>>0){z=20;break b}E=C+1|0;if((E|0)>(c[j>>2]|0)){if((bEb(l,E,32)|0)!=0){B=-12;break a}D=c[j>>2]|0;TGb((c[m>>2]|0)+(D<<5)|0,0,E-D<<5|0)|0;c[j>>2]=E}E=r+(t+12)|0;D=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=c[m>>2]|0;c[E+(C<<5)+16>>2]=D;F=r+(t+36)|0;G=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;c[E+(C<<5)+8>>2]=G;F=r+(t+40)|0;H=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;c[E+(C<<5)>>2]=H;F=r+(t+44)|0;I=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;c[E+(C<<5)+4>>2]=I;F=E+(C<<5)+24|0;c[F>>2]=0;c[F+4>>2]=0;if((G|0)<1|(H|0)<1|(I|0)<1){z=25;break b}if((D|0)==0&(I|0)<8){z=27;break b}I=LT(b,0)|0;if((I|0)==0){B=-12;break a}c[I+4>>2]=C;MT(I,60,1,c[(c[m>>2]|0)+(C<<5)>>2]|0);D=c[m>>2]|0;c[D+(C<<5)+12>>2]=c[I>>2];H=c[I+8>>2]|0;c[H+8>>2]=1;c[H+52>>2]=0;I=c[D+(C<<5)+8>>2]|0;c[H+416>>2]=I;G=c[D+(C<<5)>>2]|0;c[H+412>>2]=G;F=c[D+(C<<5)+4>>2]|0;c[H+792>>2]=F;c[H+72>>2]=ba(ba(G,I)|0,F)|0;c[H+432>>2]=ba(F,I)|0;do{if((c[D+(C<<5)+16>>2]|0)==0){I=H+48|0;if((F|0)==8){c[I>>2]=65541;break}else{c[I>>2]=65536;break}}else{c[H+48>>2]=69639}}while(0);A=t+48|0}}while(0);if((z|0)==12){z=0;if((u|0)<16){z=13;break}v=r+(t+12)|0;g[n>>2]=(c[k>>2]=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24,+g[k>>2]);A=t}v=A+1|0;if((v|0)<(s|0)){t=v}else{z=36;break a}}if((z|0)==10){yDb(b,16,2195056,(J=i,i=i+16|0,c[J>>2]=w,c[J+8>>2]=y,J)|0);i=J;q=-1094995529;i=e;return q|0}else if((z|0)==13){yDb(b,16,2116440,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;B=-1094995529;break}else if((z|0)==20){yDb(b,16,2057368,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;B=-1094995529;break}else if((z|0)==25){yDb(b,16,2011240,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;B=-1094995529;break}else if((z|0)==27){yDb(b,16,1972344,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;B=-1094995529;break}}else{z=36}}while(0);do{if((z|0)==36){J=rz(f)|0;rz(f)|0;if((J|0)!=1414744396){q=-1094995529;i=e;return q|0}if((rz(f)|0)!=1230393165){B=-1094995529;break}ZDb(r);J=h+16|0;c[J>>2]=-1;c[J+4>>2]=-1;q=0;i=e;return q|0}}while(0);$Db(l);ZDb(r);q=B;i=e;return q|0}function rW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+8|0;f=e|0;g=f;h=c[b+12>>2]|0;j=b+16|0;b=c[j>>2]|0;k=f;l=f+4|0;m=h+16|0;n=h;o=d+32|0;p=d+8|0;q=d+64|0;r=d+24|0;s=h+4|0;t=h+8|0;h=b;while(1){u=mz(h,k,8)|0;if((u|0)<0){v=u;w=21;break}u=c[g>>2]|0;y=c[l>>2]|0;if((Xy(b)|0)!=0){v=-5;w=21;break}if((u|0)==1600417395){z=rz(b)|0;Vy(b,4,0)|0;A=y-8|0;if(z>>>0<(c[s>>2]|0)>>>0){if((c[(c[t>>2]|0)+(z<<5)+8>>2]|0)>0){w=16;break}}Vy(b,A,0)|0;}else if((u|0)==1414744396){B=YGb(c[m>>2]|0,c[m+4>>2]|0,1,0)|0;c[m>>2]=B;c[m+4>>2]=F;rz(b)|0}else if((u|0)==1836213865|(u|0)==1836213872|(u|0)==1836213859|(u|0)==846358121|(u|0)==846358128|(u|0)==846358115){u=lc(y|0,8)|0;if(F){v=-5;w=21;break}if((wZ(d,u)|0)!=0){v=-5;w=21;break}c[o>>2]=c[n>>2];u=c[m+4>>2]|0;c[p>>2]=c[m>>2];c[p+4>>2]=u;u=Ty(c[j>>2]|0,0,0,1)|0;c[q>>2]=u;c[q+4>>2]=F;u=c[r>>2]|0;B=c[f+4>>2]|0;C=u|0;x=c[f>>2]|0;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=u+4|0;x=B;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;D=mz(c[j>>2]|0,(c[r>>2]|0)+8|0,y)|0;if((D|0)>=0){w=15;break}BZ(d)}else{Vy(b,y,0)|0;}h=c[j>>2]|0}if((w|0)==15){yZ(d,D+8|0);v=D;i=e;return v|0}else if((w|0)==16){D=TS(c[j>>2]|0,d,A)|0;if((D|0)<0){v=-5;i=e;return v|0}d=c[t>>2]|0;c[o>>2]=c[d+(z<<5)+12>>2];o=d+(z<<5)+24|0;t=c[o+4>>2]|0;c[p>>2]=c[o>>2];c[p+4>>2]=t;t=c[d+(z<<5)+8>>2]|0;if((c[d+(z<<5)+16>>2]|0)==0){E=((A|0)/(t|0)|0|0)/((c[d+(z<<5)+4>>2]|0)/8|0|0)|0}else{E=((A-(t<<1)|0)/(t|0)|0)<<1}t=YGb(c[o>>2]|0,c[o+4>>2]|0,E,(E|0)<0|0?-1:0)|0;c[o>>2]=t;c[o+4>>2]=F;v=D;i=e;return v|0}else if((w|0)==21){i=e;return v|0}return 0}function sW(a){a=a|0;$Db((c[a+12>>2]|0)+8|0);return 0}function tW(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;h=f|0;a[h]=a[1878872]|0;a[h+1|0]=a[1878873]|0;a[h+2|0]=a[1878874]|0;a[h+3|0]=a[1878875]|0;a[h+4|0]=a[1878876]|0;j=c[(c[g+12>>2]|0)+12>>2]|0;if((j|0)==145){a[f+2|0]=1;k=c[g+96>>2]|0;a[f+3|0]=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>24;a[f+4|0]=3}else if((j|0)==144){a[f+2|0]=0;j=c[g+96>>2]|0;a[f+3|0]=(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)>>>24;a[f+4|0]=2}else{l=-22;i=e;return l|0}Ry(c[b+16>>2]|0,h,2);l=0;i=e;return l|0}function uW(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+4>>2]|0;e=(c[a+8>>2]|0)-7|0;a=b+e|0;do{if((e|0)>0){f=a;g=0;h=b;i=0;do{a:do{if(h>>>0<a>>>0){j=0;k=h;while(1){l=k;if(!(((de((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&-10)<<16>>16==-16)){m=j;n=k;break a}l=k+3|0;o=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)>>>13&8191;if(o>>>0<7>>>0){m=j;n=k;break a}l=f-k|0;p=k+((o|0)>(l|0)?l:o)|0;o=j+1|0;if(p>>>0<a>>>0){j=o;k=p}else{m=o;n=p;break}}}else{m=0;n=h}}while(0);i=(i|0)>(m|0)?i:m;g=(h|0)==(b|0)?m:g;h=n+1|0;}while(h>>>0<a>>>0);if((g|0)>2){q=51;return q|0}if((i|0)>500){q=50;return q|0}if((i|0)>2){q=25}else{r=i;break}return q|0}else{r=0}}while(0);q=(r|0)>0|0;return q|0}function vW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[b+236>>2]=1463898624;mX(a);e=a+16|0;do{if((c[(c[e>>2]|0)+88>>2]|0)!=0){if((BBb(c[a+1140>>2]|0,9203432,0,2)|0)!=0){break}f=Ty(c[e>>2]|0,0,0,1)|0;g=F;tx(a)|0;Ty(c[e>>2]|0,f,g,0)|0;}}while(0);MT(b,64,1,28224e3);d=0;return d|0}function wW(a){a=a|0;return yW(a,86019)|0}function xW(a){a=a|0;return yW(a,86057)|0}function yW(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;i=i+4128|0;j=h|0;k=h+8|0;l=h+32|0;c[j>>2]=0;m=f+4|0;n=c[m>>2]|0;o=c[f+8>>2]|0;f=n+o|0;a:do{if((o|0)>0){p=l|0;q=k|0;r=k+12|0;s=k+16|0;t=l+7|0;u=k+4|0;v=k+8|0;w=0;x=0;y=n;z=86019;A=n;b:while(1){do{if(y>>>0>A>>>0){B=a[y]|0;if((B<<24>>24|0)==11){if((a[y+1|0]|0)==119){C=7;break}else{D=z;E=x;F=w;G=A;break}}else if((B<<24>>24|0)==119){if((a[y+1|0]|0)==11){C=7;break}else{D=z;E=x;F=w;G=A;break}}else{D=z;E=x;F=w;G=A;break}}else{C=7}}while(0);if((C|0)==7){C=0;c:do{if(y>>>0<f>>>0){B=y+1|0;H=0;I=y;J=z;while(1){K=(PGb(I,2057352,8)|0)==0;L=K?I+16|0:I;do{if((a[y]|0)==119){if((a[B]|0)!=11){C=12;break}a[p]=11;a[l+1|0]=a[y]|0;a[l+2|0]=a[y+3|0]|0;a[l+3|0]=a[y+2|0]|0;a[l+4|0]=a[y+5|0]|0;a[l+5|0]=a[y+4|0]|0;a[l+6|0]=a[y+7|0]|0;a[t]=a[y+6|0]|0;c[q>>2]=p;c[r>>2]=54;c[s>>2]=62;M=t}else{C=12}}while(0);if((C|0)==12){C=0;K=(L|0)==0?0:54;c[q>>2]=L;c[r>>2]=K;c[s>>2]=K|8;M=L+((K+7|0)>>>3)|0}c[u>>2]=M;c[v>>2]=0;if((GX(k,j)|0)<0){N=H;O=J;break c}K=(c[j>>2]|0)+42|0;P=b[K>>1]|0;if((L+(P&65535)|0)>>>0>f>>>0){N=H;O=J;break c}do{if((a[y]|0)==119){if((a[B]|0)!=11){break}if(!((P&65535)>>>0<4097>>>0)){break b}if((P&65535)>>>0>8>>>0){Q=8}else{break}do{R=Q|1;a[l+Q|0]=a[y+R|0]|0;a[l+R|0]=a[y+Q|0]|0;Q=Q+2|0;}while((Q|0)<(e[K>>1]|0))}}while(0);K=tBb(1)|0;P=c[j>>2]|0;R=e[P+42>>1]|0;if((uBb(K,0,(c[q>>2]|0)+2|0,R-2|0)|0)!=0){N=H;O=J;break c}K=(d[P+5|0]|0)>>>0>10>>>0?86057:J;P=L+R|0;R=H+1|0;if(P>>>0<f>>>0){H=R;I=P;J=K}else{N=R;O=K;break}}}else{N=0;O=z}}while(0);J=c[m>>2]|0;D=O;E=(y|0)==(J|0)?N:x;F=(w|0)>(N|0)?w:N;G=J}J=y+1|0;if(J>>>0<f>>>0){w=F;x=E;y=J;z=D;A=G}else{S=F;T=E;U=D;break a}}yDb(0,0,2011208,(A=i,i=i+24|0,c[A>>2]=1972304,c[A+8>>2]=1943448,c[A+16>>2]=63,A)|0);i=A;Cd();return 0}else{S=0;T=0;U=86019}}while(0);$Db(j);if((U|0)!=(g|0)){V=0;i=h;return V|0}if((T|0)>3){V=51;i=h;return V|0}if((S|0)>200){V=50;i=h;return V|0}if((S|0)>3){V=25;i=h;return V|0}V=(S|0)>0|0;i=h;return V|0}function zW(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[b+4>>2]|0;f=e;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=1179011410){g=0;return g|0}f=e+8|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=1163280727){g=0;return g|0}f=e+16|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=16){g=0;return g|0}if((c[b+8>>2]|0)<512){g=0;return g|0}else{h=44}while(1){if((h|0)>=256){break}if((a[e+h|0]|0)==0){h=h+1|0}else{g=0;i=10;break}}if((i|0)==10){return g|0}if((a[e+256|0]|0)==-124){j=264}else{g=0;return g|0}while(1){if((j|0)>=512){g=100;i=10;break}if((a[e+j|0]|0)==0){j=j+1|0}else{g=0;i=10;break}}if((i|0)==10){return g|0}return 0}function AW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=LT(a,0)|0;if((f|0)==0){g=-12;i=b;return g|0}Vy(e,16,0)|0;h=rz(e)|0;j=f+8|0;AO(e,c[j>>2]|0,h)|0;h=c[j>>2]|0;k=c[h+412>>2]|0;if((k|0)==8e3){c[h+424>>2]=80;c[h+416>>2]=1;MT(f,64,1,100);c[(c[j>>2]|0)+48>>2]=86070;Ty(e,257,0,0)|0;h=pz(e)|0;l=lz(e)|0;m=((((rz(e)|0)*60|0)+l|0)*1e3|0)+h|0;h=c[j>>2]|0;j=c[h+412>>2]|0;l=(c[h+424>>2]|0)*1e3|0;h=IDb(m,(m|0)<0|0?-1:0,j,(j|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=f+56|0;c[l>>2]=h;c[l+4>>2]=F;c[d>>2]=512;Ty(e,512,0,0)|0;g=0;i=b;return g|0}else{yDb(a,16,2194888,(a=i,i=i+8|0,c[a>>2]=k,a)|0);i=a;g=-1094995529;i=b;return g|0}return 0}function BW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=b+28|0;b=(c[(c[(c[c[g>>2]>>2]|0)+8>>2]|0)+412>>2]|0)==8e3;h=b?10:22;if(b){i=wZ(d,10)|0}else{i=wZ(d,11)|0}if((i|0)!=0){j=i;return j|0}do{if((c[(c[(c[c[g>>2]>>2]|0)+8>>2]|0)+412>>2]|0)==4400){i=e+26|0;if((a[i]|0)!=0){b=e+26|0;if((a[b]|0)==0){k=12;break}l=d+24|0;a[c[l>>2]|0]=a[e+9|0]|0;a[(c[l>>2]|0)+1|0]=a[e+21|0]|0;a[(c[l>>2]|0)+2|0]=a[e+10|0]|0;a[(c[l>>2]|0)+3|0]=a[e+22|0]|0;a[(c[l>>2]|0)+4|0]=a[e+11|0]|0;a[(c[l>>2]|0)+5|0]=a[e+23|0]|0;a[(c[l>>2]|0)+6|0]=a[e+12|0]|0;a[(c[l>>2]|0)+7|0]=a[e+24|0]|0;a[(c[l>>2]|0)+8|0]=a[e+13|0]|0;a[(c[l>>2]|0)+9|0]=a[e+25|0]|0;a[(c[l>>2]|0)+10|0]=a[e+14|0]|0;a[b]=0;m=0;break}b=e+4|0;l=mz(f,b,h)|0;if((l|0)<0){j=l;return j|0}if((l|0)==(h|0)){l=d+24|0;a[c[l>>2]|0]=a[e+15|0]|0;a[(c[l>>2]|0)+1|0]=a[b]|0;a[(c[l>>2]|0)+2|0]=a[e+16|0]|0;a[(c[l>>2]|0)+3|0]=a[e+5|0]|0;a[(c[l>>2]|0)+4|0]=a[e+17|0]|0;a[(c[l>>2]|0)+5|0]=a[e+6|0]|0;a[(c[l>>2]|0)+6|0]=a[e+18|0]|0;a[(c[l>>2]|0)+7|0]=a[e+7|0]|0;a[(c[l>>2]|0)+8|0]=a[e+19|0]|0;a[(c[l>>2]|0)+9|0]=a[e+8|0]|0;a[(c[l>>2]|0)+10|0]=a[e+20|0]|0;a[i]=1;m=h;break}else{j=-5;return j|0}}else{k=12}}while(0);do{if((k|0)==12){g=e+4|0;i=mz(f,g,h)|0;if((i|0)<0){j=i;return j|0}if((i|0)==(h|0)){i=d+24|0;a[c[i>>2]|0]=a[e+9|0]|0;a[(c[i>>2]|0)+1|0]=a[g]|0;a[(c[i>>2]|0)+2|0]=a[e+10|0]|0;a[(c[i>>2]|0)+3|0]=a[e+5|0]|0;a[(c[i>>2]|0)+4|0]=a[e+11|0]|0;a[(c[i>>2]|0)+5|0]=a[e+6|0]|0;a[(c[i>>2]|0)+6|0]=a[e+12|0]|0;a[(c[i>>2]|0)+7|0]=a[e+7|0]|0;a[(c[i>>2]|0)+8|0]=a[e+13|0]|0;a[(c[i>>2]|0)+9|0]=a[e+8|0]|0;m=h;break}else{j=-5;return j|0}}}while(0);k=e;e=(c[k>>2]|0)-h|0;c[k>>2]=e;if((e|0)<(h|0)){Vy(f,e,(e|0)<0|0?-1:0)|0;c[k>>2]=512}c[d+48>>2]=1;j=m;return j|0}function CW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[b+8>>2]|0;if((d|0)<32){e=0;return e|0}f=d-3|0;if((f|0)<=0){e=0;return e|0}g=c[b+4>>2]|0;b=0;h=0;i=0;while(1){j=a[g+b|0]|0;if(!(j<<24>>24==(a[g+(b|2)|0]|0))){e=0;k=9;break}if((a[g+(b|1)|0]|0)!=(a[g+(b|3)|0]|0)){e=0;k=9;break}l=((j&255|0)!=(i|0))+h|0;m=b+32|0;if((m|0)<(f|0)){b=m;h=l;i=j<<24>>24}else{k=7;break}}if((k|0)==7){if((l|0)<2){e=0;return e|0}e=(d|0)<260?1:25;return e|0}else if((k|0)==9){return e|0}return 0}function DW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=LT(a,0)|0;if((b|0)==0){d=-12;return d|0}e=b+8|0;f=c[e>>2]|0;c[f+8>>2]=1;c[f+48>>2]=1146374944;g=f+448|0;c[g>>2]=3;c[g+4>>2]=0;c[f+416>>2]=2;c[f+412>>2]=48e3;g=b+48|0;c[g>>2]=0;c[g+4>>2]=0;g=c[a+16>>2]|0;if((c[g+88>>2]|0)==0){h=48e3}else{a=Wy(g)|0;g=O0a(f,a)|0;a=b+56|0;c[a>>2]=g;c[a+4>>2]=(g|0)<0|0?-1:0;h=c[(c[e>>2]|0)+412>>2]|0}MT(b,64,1,h);d=0;return d|0}function EW(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+16|0;if((Xy(c[d>>2]|0)|0)!=0){e=-541478725;return e|0}a=TS(c[d>>2]|0,b,1024)|0;do{if((a|0)!=1024){if((a|0)>=0){yZ(b,a);break}BZ(b);e=a;return e|0}}while(0);c[b+32>>2]=0;e=a;return e|0}function FW(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+96|0;f=e|0;g=e+24|0;h=e+48|0;j=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;k=c[j+100>>2]|0;do{if((k|0)>0){l=c[b+12>>2]|0;m=c[j+96>>2]|0;n=k<<3;o=n>>>0>2147483639>>>0|(m|0)==0;p=o?0:m;q=o?0:n;c[f>>2]=p;c[f+12>>2]=q;o=q+8|0;c[f+16>>2]=o;c[f+4>>2]=p+(q>>3);q=f+8|0;c[q>>2]=0;r=QMa(h,m,n,1)|0;do{if((r|0)<0){s=r}else{n=(o|0)<(r|0)?o:r;c[q>>2]=n;m=c[h>>2]|0;t=m-1|0;c[l+8>>2]=t;u=c[h+4>>2]|0;c[l+12>>2]=u;v=c[h+12>>2]|0;c[l+16>>2]=v;if(t>>>0>3>>>0){yDb(b,16,2011168,(w=i,i=i+8|0,c[w>>2]=m,w)|0);i=w;s=-1;break}if((u|0)==15){yDb(b,16,1972256,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1;break}u=p+(n>>>3)|0;m=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=n+1|0;t=o>>>0>u>>>0?u:o;c[q>>2]=t;if((m&-2147483648>>>((n&7)>>>0)|0)!=0){yDb(b,16,1943400,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1;break}n=p+(t>>>3)|0;m=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=t+1|0;u=o>>>0>n>>>0?n:o;c[q>>2]=u;if((m&-2147483648>>>((t&7)>>>0)|0)!=0){yDb(b,16,1918720,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1;break}t=p+(u>>>3)|0;m=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=u+1|0;c[q>>2]=o>>>0>t>>>0?t:o;if((m&-2147483648>>>((u&7)>>>0)|0)!=0){yDb(b,16,1897880,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1;break}if((v|0)==0){v=l+28|0;c[g+20>>2]=2432;c[g+8>>2]=v;c[g+16>>2]=l+332;u=g+12|0;c[u>>2]=v;v=g+4|0;m=g|0;c[m>>2]=5;c[v>>2]=29;c[l+20>>2]=((RMa(g,f)|0)+3|0)/8|0;t=c[v>>2]|0;if((t|0)<32){n=c[m>>2]<<t;c[m>>2]=n;t=n>>>24&255;while(1){n=c[u>>2]|0;c[u>>2]=n+1;a[n]=t;n=c[m>>2]|0;c[m>>2]=n<<8;x=(c[v>>2]|0)+8|0;c[v>>2]=x;if((x|0)<32){t=n>>>16&255}else{break}}}c[v>>2]=32;c[m>>2]=0}c[l+4>>2]=1;s=0}}while(0);if((s|0)<0){y=-1}else{break}i=e;return y|0}}while(0);y=0;i=e;return y|0}function GW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+8|0;f=e|0;g=c[b+12>>2]|0;h=c[b+16>>2]|0;b=d+28|0;j=c[b>>2]|0;if((j|0)==0){k=0;i=e;return k|0}do{if((c[g+4>>2]|0)!=0){l=g+20|0;m=j+7+(c[l>>2]|0)|0;if(m>>>0>8191>>>0){yDb(0,16,2057240,(n=i,i=i+16|0,c[n>>2]=m,c[n+8>>2]=8191,n)|0);i=n;k=-1094995529;i=e;return k|0}else{c[f>>2]=fe((c[g+16>>2]|(c[g+8>>2]<<4|c[g+12>>2])<<4)<<6|m>>>11|-983040|0)|0;a[f+4|0]=m>>>3;a[f+5|0]=m<<5|31;a[f+6|0]=-4;Ry(h,f|0,7);m=c[l>>2]|0;if((m|0)==0){break}Ry(h,g+28|0,m);c[l>>2]=0;break}}}while(0);Ry(h,c[d+24>>2]|0,c[b>>2]|0);k=0;i=e;return k|0}function HW(a){a=a|0;if((c[(c[a+12>>2]|0)+24>>2]|0)==0){return 0}ux(a)|0;return 0}function IW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+12>>2]|0;d=LT(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;g=a+16|0;if((tz(c[g>>2]|0)|0)!=32768){e=-1094995529;return e|0}h=b;c[h>>2]=(tz(c[g>>2]|0)|0)+4;Ty(c[g>>2]|0,-4,-1,1)|0;if((CT(f,c[g>>2]|0,c[h>>2]|0)|0)<0){e=-12;return e|0}g=KX(f,c[f+96>>2]|0,c[f+100>>2]|0,h,0)|0;if((g|0)!=0){e=g;return e|0}g=c[d+8>>2]|0;c[g+8>>2]=1;c[g+48>>2]=c[(c[a+4>>2]|0)+28>>2];MT(d,64,32,c[f+412>>2]|0);e=0;return e|0}function JW(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[a+12>>2]|0;f=(c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+416>>2]|0)*18|0;g=a+16|0;a=Ty(c[g>>2]|0,0,0,1)|0;h=b+64|0;c[h>>2]=a;c[h+4>>2]=F;c[b+32>>2]=0;a=TS(c[g>>2]|0,b,f)|0;if((a|0)!=(f|0)){BZ(b);i=(a|0)<0?a:-5;return i|0}a=c[b+24>>2]|0;if(((d[a]|d[a+1|0]<<8)<<16>>16&128)==0){c[b+28>>2]=f;c[b+48>>2]=1;a=c[e>>2]|0;e=ZGb(c[h>>2]|0,c[h+4>>2]|0,a,(a|0)<0|0?-1:0)|0;a=eHb(e,F,f,(f|0)<0|0?-1:0)|0;f=b+8|0;c[f>>2]=a;c[f+4>>2]=F;i=0;return i|0}else{BZ(b);i=-541478725;return i|0}return 0}function KW(b){b=b|0;var e=0,f=0;if((c[b+8>>2]|0)<2261){e=0;return e|0}f=c[b+4>>2]|0;b=f;do{if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==2048){if(((a[f+264|0]|0)-1&255)>>>0>1>>>0){e=0;return e|0}if((a[f+2048|0]|0)==(a[f+2259|0]|0)&(a[f+2049|0]|0)==(a[f+2258|0]|0)){e=26}else{break}return e|0}}while(0);e=0;return e|0}function LW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=LT(a,0)|0;if((d|0)==0){e=-12;i=b;return e|0}f=a+16|0;Vy(c[f>>2]|0,264,0)|0;g=lz(c[f>>2]|0)|0;h=d+8|0;c[(c[h>>2]|0)+416>>2]=g;Vy(c[f>>2]|0,1783,0)|0;f=c[h>>2]|0;c[f+8>>2]=1;c[f+48>>2]=86063;c[f+412>>2]=44100;c[f+72>>2]=292e3;h=c[f+416>>2]|0;if((h-1|0)>>>0<2>>>0){g=(h|0)==1;d=f+448|0;c[d>>2]=g?4:3;c[d+4>>2]=g?0:0;c[f+432>>2]=h*212|0;e=0;i=b;return e|0}else{yDb(a,16,2194768,(a=i,i=i+8|0,c[a>>2]=h,a)|0);i=a;e=-1;i=b;return e|0}return 0}function MW(a,b){a=a|0;b=b|0;var d=0;d=TS(c[a+16>>2]|0,b,c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+432>>2]|0)|0;c[b+32>>2]=0;return((d|0)<1?-5:d)|0}function NW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[b+12>>2]|0;e=LT(b,0)|0;if((e|0)==0){f=-12;return f|0}g=e+8|0;h=c[g>>2]|0;c[h+8>>2]=1;c[h+48>>2]=1095123744;c[h+416>>2]=2;i=h+448|0;c[i>>2]=3;c[i+4>>2]=0;if((BT(h,1)|0)!=0){f=-12;return f|0}h=c[g>>2]|0;a[c[h+96>>2]|0]=c[h+416>>2]<<3;h=b+16|0;b=YGb(vz(c[h>>2]|0)|0,0,32,0)|0;i=d;c[i>>2]=b;c[i+4>>2]=F;i=e+56|0;c[i>>2]=vz(c[h>>2]|0)|0;c[i+4>>2]=0;i=tz(c[h>>2]|0)|0;c[(c[g>>2]|0)+412>>2]=i;Vy(c[h>>2]|0,22,0)|0;MT(e,64,1,c[(c[g>>2]|0)+412>>2]|0);f=0;return f|0}function OW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[a+12>>2]|0;e=c[d>>2]|0;f=c[d+4>>2]|0;g=a+16|0;a=Ty(c[g>>2]|0,0,0,1)|0;h=ZGb(e,f,a,F)|0;a=F;f=0;do{if((a|0)>(f|0)|(a|0)==(f|0)&h>>>0>2304>>>0){i=2304}else{e=c[d>>2]|0;j=c[d+4>>2]|0;k=Ty(c[g>>2]|0,0,0,1)|0;l=ZGb(e,j,k,F)|0;k=F;j=0;if((k|0)<(j|0)|(k|0)==(j|0)&l>>>0<1>>>0){m=-541478725}else{i=l;break}return m|0}}while(0);d=TS(c[g>>2]|0,b,i)|0;c[b+32>>2]=0;m=d;return m|0}function PW(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==70){if((a[d+1|0]|0)!=79){break}if((a[d+2|0]|0)!=82){break}if((a[d+3|0]|0)!=77){break}if((a[d+8|0]|0)!=65){break}if((a[d+9|0]|0)!=73){break}if((a[d+10|0]|0)!=70){break}b=a[d+11|0]|0;if((b<<24>>24|0)==70|(b<<24>>24|0)==67){e=100}else{break}return e|0}}while(0);e=0;return e|0}function QW(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;e=i;i=i+8|0;f=e|0;g=b+16|0;h=c[g>>2]|0;j=b+12|0;k=c[j>>2]|0;c[f>>2]=0;if((Xy(h)|0)!=0){l=-1094995529;i=e;return l|0}m=rz(h)|0;n=vz(h)|0;o=(n|0)<0?2147483647:n;if(!((o|0)>-1&(m|0)==1297239878)){l=-1094995529;i=e;return l|0}m=rz(h)|0;do{if((m|0)==1179011393){p=0}else{if((m|0)==1128679745){p=-1568648896;break}else{l=-1094995529}i=e;return l|0}}while(0);m=o-4|0;o=LT(b,0)|0;if((o|0)==0){l=-12;i=e;return l|0}a:do{if((m|0)>0){n=b+28|0;q=o+64|0;r=k;s=o+8|0;t=h+88|0;u=k+8|0;v=0;w=0;x=p;y=m;b:while(1){if((Xy(h)|0)!=0){l=-5;z=64;break}A=rz(h)|0;B=vz(h)|0;C=(B|0)<0?2147483647:B;B=y-8-C|0;c:do{if((A|0)==539583272){SW(b,2011080,C);D=x;E=v;G=w}else if((A|0)==1330531905){SW(b,1972120,C);D=x;E=v;G=w}else if((A|0)==1145983827){H=Ty(h,0,0,1)|0;I=YGb(H,F,C,(C|0)<0|0?-1:0)|0;c[r>>2]=I;c[r+4>>2]=F;I=vz(h)|0;vz(h)|0;H=Ty(h,0,0,1)|0;J=YGb(H,F,I,0)|0;I=F;H=(c[t>>2]|0)==0;if((c[(c[s>>2]|0)+432>>2]|0)==0){if(H){z=47;break b}}else{if(H){K=I;L=J;M=s;break a}}H=C-8|0;Vy(h,H,(H|0)<0|0?-1:0)|0;D=x;E=I;G=J}else if((A|0)==1296912195){J=c[j>>2]|0;I=c[g>>2]|0;H=c[(c[c[n>>2]>>2]|0)+8>>2]|0;N=(C&1)+C|0;c[H+8>>2]=1;O=H+416|0;c[O>>2]=tz(I)|0;P=vz(I)|0;Q=H+792|0;c[Q>>2]=tz(I)|0;R=tz(I)|0;S=Az(I)|0;T=H+412|0;c[T>>2]=~~+sGb(+(S>>>0)+ +(F>>>0)*4294967296.0,R-16446|0);R=N-18|0;do{if((x|0)==-1568648896){S=rz(I)|0;c[H+52>>2]=S;U=vT(1243448,S)|0;c[H+48>>2]=U;S=N-22|0;if((U|0)==86025){c[H+432>>2]=c[O>>2]<<1}else if((U|0)==909260615){c[Q>>2]=5;z=22}else if((U|0)==69660|(U|0)==86026){z=22}else if((U|0)==65537){V=S;z=13;break}else if((U|0)==65556|(U|0)==65558|(U|0)==65536|(U|0)==65543|(U|0)==65542){c[J+8>>2]=1}else if((U|0)==86034){c[H+432>>2]=33}else if((U|0)==69632){c[H+432>>2]=(c[O>>2]|0)*34|0}else{c[J+8>>2]=1}if((z|0)==22){z=0;c[H+432>>2]=c[O>>2]}U=H+432|0;W=c[U>>2]|0;if((W|0)<=0){X=S;Y=U;break}c[J+8>>2]=O0a(H,W)|0;X=S;Y=U}else{V=R;z=13}}while(0);if((z|0)==13){z=0;R=c[Q>>2]|0;do{if((R|0)<9){Z=65540}else{if((R|0)<17){Z=65537;break}if((R|0)<25){Z=65549;break}Z=(R|0)<33?65545:0}}while(0);c[H+48>>2]=Z;c[Q>>2]=u0a(Z)|0;c[J+8>>2]=1;X=V;Y=H+432|0}R=c[Y>>2]|0;if((R|0)==0){N=u0a(c[H+48>>2]|0)|0;U=(ba(c[O>>2]|0,N)|0)>>3;c[Y>>2]=U;_=U}else{_=R}R=c[J+8>>2]|0;if((R|0)!=0){c[H+72>>2]=(ba(_<<3,c[T>>2]|0)|0)/(R|0)|0}if((X|0)!=0){Vy(I,X,(X|0)<0|0?-1:0)|0;}c[q>>2]=P;c[q+4>>2]=0;R=0;if((v|0)>(R|0)|(v|0)==(R|0)&w>>>0>0>>>0){K=v;L=w;M=s;break a}else{D=x;E=v;G=w}}else if((A|0)==1162690894){SW(b,2116360,C);D=x;E=v;G=w}else if((A|0)==1213486401){SW(b,2057112,C);D=x;E=v;G=w}else if((A|0)==1380275782){D=vz(h)|0;E=v;G=w}else if((A|0)==540230729){R=Ty(h,0,0,1)|0;U=F;yE(b,2194736,f);if((c[f>>2]|0)!=0){$=BE(b,f)|0;if(($|0)<0){z=36;break b}}zE(f);N=YGb(R,U,C,(C|0)<0|0?-1:0)|0;U=F;R=Ty(h,0,0,1)|0;S=F;if(!((U|0)>(S|0)|(U|0)==(S|0)&N>>>0>R>>>0)){D=x;E=v;G=w;break}R=Ty(h,0,0,1)|0;S=ZGb(N,U,R,F)|0;Vy(h,S,F)|0;D=x;E=v;G=w}else if((A|0)==1702257015){if(C>>>0>1073741824>>>0){l=-1;z=64;break b}if((CT(c[s>>2]|0,h,C)|0)<0){l=-12;z=64;break b}S=c[s>>2]|0;R=c[S+48>>2]|0;do{if((R|0)==86035&(C|0)>47){U=S+432|0;if((c[U>>2]|0)!=0){break}N=c[S+96>>2]|0;W=N+44|0;c[U>>2]=fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0;W=N+36|0;c[u>>2]=fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0;D=x;E=v;G=w;break c}}while(0);if((R|0)!=86040){D=x;E=v;G=w;break}if((C|0)>24){aa=(a[(c[S+96>>2]|0)+24|0]|0)==72?17:35}else{aa=35}c[S+432>>2]=aa;c[u>>2]=160;P=c[s>>2]|0;c[P+72>>2]=(ba(c[P+412>>2]<<3,c[P+432>>2]|0)|0)/160|0;D=x;E=v;G=w}else if((A|0)==1312901187){if((xI(b,h,o,C,(C|0)<0|0?-1:0)|0)<0){l=-1094995529;z=64;break b}else{D=x;E=v;G=w}}else{P=(C&1)+C|0;Vy(h,P,(P|0)<0|0?-1:0)|0;D=x;E=v;G=w}}while(0);if((B|0)>0){v=E;w=G;x=D;y=B}else{K=E;L=G;M=s;break a}}if((z|0)==36){zE(f);l=$;i=e;return l|0}else if((z|0)==47){yDb(b,16,1943304,(ca=i,i=i+1|0,i=i+7&-8,c[ca>>2]=0,ca)|0);i=ca;l=-1;i=e;return l|0}else if((z|0)==64){i=e;return l|0}}else{K=0;L=0;M=o+8|0}}while(0);z=c[M>>2]|0;if((c[z+432>>2]|0)==0){yDb(b,16,1918664,(ca=i,i=i+1|0,i=i+7&-8,c[ca>>2]=0,ca)|0);i=ca;l=-1;i=e;return l|0}else{MT(o,64,1,c[z+412>>2]|0);z=o+48|0;c[z>>2]=0;c[z+4>>2]=0;z=o+64|0;ca=c[k+8>>2]|0;k=gHb(ca,(ca|0)<0|0?-1:0,c[z>>2]|0,c[z+4>>2]|0)|0;z=o+56|0;c[z>>2]=k;c[z+4>>2]=F;Ty(h,L,K,0)|0;l=0;i=e;return l|0}return 0}function RW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[c[a+28>>2]>>2]|0;e=c[a+12>>2]|0;f=e;g=c[f>>2]|0;h=c[f+4>>2]|0;f=a+16|0;a=Ty(c[f>>2]|0,0,0,1)|0;i=ZGb(g,h,a,F)|0;a=F;h=0;if((a|0)<(h|0)|(a|0)==(h|0)&i>>>0<1>>>0){j=-541478725;return j|0}h=d+8|0;d=c[(c[h>>2]|0)+432>>2]|0;if((d|0)>16){k=d}else{k=4096-(4096%(d|0)|0)|0}d=(k|0)<0|0?-1:0;g=(a|0)>(d|0)|(a|0)==(d|0)&i>>>0>k>>>0?k:i;i=TS(c[f>>2]|0,b,g)|0;if((i|0)<0){j=i;return j|0}f=(c[h>>2]|0)+432|0;if((g|0)>=(c[f>>2]|0)){g=b+36|0;c[g>>2]=c[g>>2]&-3}c[b+32>>2]=0;c[b+48>>2]=ba(c[e+8>>2]|0,(i|0)/(c[f>>2]|0)|0)|0;j=0;return j|0}function SW(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=WDb(e+1|0)|0;do{if((f|0)==0){g=e&1;h=b+16|0}else{i=b+16|0;j=mz(c[i>>2]|0,f,e)|0;if((j|0)>=0){a[f+j|0]=0;CBb(b+1140|0,d,f,8)|0;g=(e&1)-j|0;h=i;break}ZDb(f);return}}while(0);f=g+e|0;Vy(c[h>>2]|0,f,(f|0)<0|0?-1:0)|0;return}function TW(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=i;e=c[a+12>>2]|0;f=a+16|0;g=c[f>>2]|0;j=e+32|0;c[j>>2]=-1;l=a+24|0;m=c[l>>2]|0;do{if((m|0)!=0){n=c[a+28>>2]|0;o=0;p=-1;q=m;while(1){r=c[(c[(c[n+(o<<2)>>2]|0)+8>>2]|0)+8>>2]|0;if((p|0)<0&(r|0)==1){c[j>>2]=o;s=o;t=c[l>>2]|0}else{if((r|0)==0){s=p;t=q}else{u=6;break}}r=o+1|0;if(r>>>0<t>>>0){o=r;p=s;q=t}else{break}}if((u|0)==6){yDb(a,16,1972064,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=b;return w|0}if((s|0)<0){break}q=a+28|0;p=c[(c[(c[q>>2]|0)+(s<<2)>>2]|0)+8>>2]|0;o=p+52|0;n=c[o>>2]|0;if((n|0)==0){w=-1;i=b;return w|0}else if((n|0)==1162760014){x=0}else{x=1}Yy(g,1297239878);n=Ty(g,0,0,1)|0;r=e+8|0;c[r>>2]=n;c[r+4>>2]=F;Zy(g,0);r=x?1897832:2355232;Yy(g,(d[r+1|0]|0)<<8|(d[r]|0)|(d[r+2|0]|0)<<16|(d[r+3|0]|0)<<24);do{if(x){if((c[p+432>>2]|0)!=0){Yy(g,1380275782);Zy(g,4);Zy(g,-1568648896);break}yDb(a,16,2335184,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=b;return w|0}}while(0);r=p+416|0;do{if((c[r>>2]|0)>2){n=p+448|0;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){break}Yy(g,1312901187);Zy(g,12);wF(g,c[n>>2]|0,c[n+4>>2]|0)}}while(0);n=a+1140|0;WW(c[f>>2]|0,c[n>>2]|0,2275312,1162690894);WW(c[f>>2]|0,c[n>>2]|0,2259544,1213486401);WW(c[f>>2]|0,c[n>>2]|0,2244928,539583272);WW(c[f>>2]|0,c[n>>2]|0,2232560,1330531905);Yy(g,1296912195);Zy(g,x?24:18);fz(g,c[r>>2]|0);n=Ty(g,0,0,1)|0;y=e+16|0;c[y>>2]=n;c[y+4>>2]=F;Zy(g,0);y=p+792|0;n=c[y>>2]|0;do{if((n|0)==0){z=u0a(c[p+48>>2]|0)|0;c[y>>2]=z;if((z|0)!=0){A=z;break}yDb(a,16,2210808,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=b;return w|0}else{A=n}}while(0);n=p+432|0;if((c[n>>2]|0)==0){c[n>>2]=(ba(c[r>>2]|0,A)|0)>>3}fz(g,A);h[k>>3]=+(c[p+412>>2]|0);n=c[k>>2]|0;y=c[k+4>>2]|0;z=YGb(y>>>20|0<<12,0>>>20|0<<12,15360,0)|0;fz(g,z);ez(g,n<<11|0>>>21|0,y<<11|n>>>21|-2147483648);if(x){Yy(g,c[o>>2]|0);fz(g,0)}do{if((c[o>>2]|0)==843924561){n=p+100|0;if((c[n>>2]|0)==0){break}Yy(g,1702257015);Zy(g,c[n>>2]|0);Ry(g,c[p+96>>2]|0,c[n>>2]|0)}}while(0);Yy(g,1145983827);p=Ty(g,0,0,1)|0;o=e+24|0;c[o>>2]=p;c[o+4>>2]=F;Zy(g,0);Zy(g,0);Zy(g,0);o=c[(c[q>>2]|0)+(c[j>>2]<<2)>>2]|0;MT(o,64,1,c[(c[o+8>>2]|0)+412>>2]|0);Sy(g);w=0;i=b;return w|0}}while(0);yDb(a,16,1943272,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=b;return w|0}function UW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=b+32|0;h=c[g>>2]|0;if((h|0)==(c[f+32>>2]|0)){Ry(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);j=0;i=d;return j|0}k=a+28|0;l=c[(c[k>>2]|0)+(h<<2)>>2]|0;if((c[(c[l+8>>2]|0)+8>>2]|0)!=0){j=0;i=d;return j|0}m=l+64|0;l=c[m>>2]|0;n=c[m+4>>2]|0;if((l|0)==1&(n|0)==0){yDb(a,24,2011024,(a=i,i=i+8|0,c[a>>2]=h,a)|0);i=a;a=(c[(c[k>>2]|0)+(c[g>>2]<<2)>>2]|0)+64|0;o=c[a+4>>2]|0;p=c[a>>2]|0}else{o=n;p=l}l=0;if((o|0)>(l|0)|(o|0)==(l|0)&p>>>0>0>>>0){j=0;i=d;return j|0}p=cEb(88)|0;l=p;c[e>>2]=l;if((p|0)==0){j=-12;i=d;return j|0}o=EZ(p,b)|0;if((o|0)<0){$Db(e);j=o;i=d;return j|0}o=f+36|0;f=c[o>>2]|0;if((f|0)==0){c[o>>2]=l;j=0;i=d;return j|0}else{q=f}do{r=q+80|0;q=c[r>>2]|0;}while((q|0)!=0);c[r>>2]=l;j=0;i=d;return j|0}function VW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+32|0;d=b|0;e=b+24|0;f=a+16|0;g=c[f>>2]|0;h=c[a+12>>2]|0;j=h+36|0;c[e>>2]=c[j>>2];k=c[(c[(c[a+28>>2]|0)+(c[h+32>>2]<<2)>>2]|0)+8>>2]|0;l=Ty(g,0,0,1)|0;m=F;if((l&1|0)==0&(m&0|0)==0){n=m;o=l}else{Py(g,0);p=YGb(l,m,1,0)|0;n=F;o=p}if((c[(c[f>>2]|0)+88>>2]|0)!=0){p=h+16|0;Ty(g,c[p>>2]|0,c[p+4>>2]|0,0)|0;p=h+24|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=YGb(l,m,-12,-1)|0;t=ZGb(s,F,q,r)|0;r=c[k+432>>2]|0;k=eHb(t,F,r,(r|0)<0|0?-1:0)|0;Zy(g,k);Ty(g,c[p>>2]|0,c[p+4>>2]|0,0)|0;k=c[p>>2]|0;r=c[p+4>>2]|0;p=YGb(l,m,-4,0)|0;m=ZGb(p,F,k,r)|0;Zy(g,m);Ty(g,o,n,0)|0;do{if((c[h+40>>2]|0)!=0){n=d;c[n>>2]=c[139916];c[n+4>>2]=c[139917];c[n+8>>2]=c[139918];c[n+12>>2]=c[139919];c[n+16>>2]=c[139920];c[n+20>>2]=c[139921];n=c[f>>2]|0;o=c[j>>2]|0;if((c[n+88>>2]|0)==0){break}m=(o|0)==0;if((c[a+1140>>2]|0)==0&m){break}Yy(n,540230729);Zy(n,0);r=Ty(n,0,0,1)|0;k=F;nX(d,n,c[h+44>>2]|0,2057104);oX(a,d)|0;a:do{if(!m){p=o;while(1){l=qX(a,d,p|0)|0;if((l|0)<0){u=l;break}p=c[p+80>>2]|0;if((p|0)==0){break a}}i=b;return u|0}}while(0);rX(d,n,c[a+1316>>2]|0);o=Ty(n,0,0,1)|0;m=F;p=ZGb(o,m,r,k)|0;l=F;t=YGb(r,k,-4,-1)|0;Ty(n,t,F,0)|0;Zy(n,p);Ty(n,o,m,0)|0;if((p&1|0)==0&(l&0|0)==0){break}Py(n,0)}}while(0);a=Ty(g,0,0,1)|0;d=F;j=h+8|0;Ty(g,c[j>>2]|0,c[j+4>>2]|0,0)|0;h=c[j>>2]|0;f=c[j+4>>2]|0;j=YGb(a,d,-4,0)|0;d=ZGb(j,F,h,f)|0;Zy(g,d);Sy(g)}g=c[e>>2]|0;if((g|0)==0){u=0;i=b;return u|0}d=e;f=g;while(1){g=c[f+80>>2]|0;BZ(f|0);$Db(d);c[e>>2]=g;if((g|0)==0){u=0;break}else{f=g}}i=b;return u|0}function WW(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=BBb(b,d,0,0)|0;if((f|0)==0){return}d=f+4|0;f=SGb(c[d>>2]|0)|0;Yy(a,e);Zy(a,f+1&-2);Ry(a,c[d>>2]|0,f);if((f&1|0)==0){return}Py(a,0);return}function XW(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;g=i;i=i+728|0;h=g|0;j=g+392|0;k=g+656|0;l=g+720|0;m=f>>3;n=k;TGb(n|0,0,64)|0;if((f|0)<16){if((f|0)>0){o=0}else{i=g;return}do{p=e+o|0;a[p]=a[p]^a[b+o|0];o=o+1|0;}while((o|0)<(f|0));i=g;return}oFb(j,b,96,1)|0;pFb(j,n,0,64,0,1);o=c[k>>2]|1;p=c[n+4>>2]|1;q=c[k+8>>2]|1;r=c[n+12>>2]|1;s=c[k+16>>2]|1;t=c[n+20>>2]|1;u=c[k+24>>2]|1;v=c[n+28>>2]|1;w=c[k+32>>2]|1;y=c[n+36>>2]|1;z=c[k+40>>2]|1;A=c[n+44>>2]|1;n=e+((m<<3)-8)|0;B=n|0;C=n+4|0;n=k+56|0;D=c[n+4>>2]^(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24);c[l>>2]=c[n>>2]^(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24);c[l+4>>2]=D;vBb(h,b+12|0,64,1)|0;b=l;wBb(h,b,b,1,0,1);h=k+48|0;k=c[l+4>>2]^c[h+4>>2];c[l>>2]=c[l>>2]^c[h>>2];c[l+4>>2]=k;oFb(j,b,64,1)|0;pFb(j,e,e,f,0,1);f=m-1|0;if((f|0)>0){j=(m<<3)-8|0;m=e;b=0;k=0;h=0;while(1){D=m;B=D|0;n=D+4|0;D=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=YGb(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0,D,k,b)|0;B=ba(n,o)|0;n=ba(B>>>16|B<<16,p)|0;B=ba(n>>>16|n<<16,q)|0;n=ba(B>>>16|B<<16,r)|0;B=(ba(n>>>16|n<<16,s)|0)+t|0;n=YGb(B,0,b,0)|0;C=ba(B+D|0,u)|0;D=ba(C>>>16|C<<16,v)|0;C=ba(D>>>16|D<<16,w)|0;D=ba(C>>>16|C<<16,y)|0;C=(ba(D>>>16|D<<16,z)|0)+A|0;E=C|0;G=C+n|0;n=h+1|0;if((n|0)<(f|0)){m=m+8|0;b=G;k=E;h=n}else{break}}H=e+j|0;I=G;J=E}else{H=e;I=0;J=0}e=ba(ba(o,o)|0,o)|0;E=ba(2-(ba(e,o)|0)|0,e)|0;e=ba(2-(ba(E,o)|0)|0,E)|0;E=ba(2-(ba(e,o)|0)|0,e)|0;e=ba(ba(p,p)|0,p)|0;o=ba(2-(ba(e,p)|0)|0,e)|0;e=ba(2-(ba(o,p)|0)|0,o)|0;o=ba(2-(ba(e,p)|0)|0,e)|0;e=ba(ba(q,q)|0,q)|0;p=ba(2-(ba(e,q)|0)|0,e)|0;e=ba(2-(ba(p,q)|0)|0,p)|0;p=ba(2-(ba(e,q)|0)|0,e)|0;e=ba(ba(r,r)|0,r)|0;q=ba(2-(ba(e,r)|0)|0,e)|0;e=ba(2-(ba(q,r)|0)|0,q)|0;q=ba(2-(ba(e,r)|0)|0,e)|0;e=ba(ba(s,s)|0,s)|0;r=ba(2-(ba(e,s)|0)|0,e)|0;e=ba(2-(ba(r,s)|0)|0,r)|0;r=ba(2-(ba(e,s)|0)|0,e)|0;e=ba(ba(u,u)|0,u)|0;s=ba(2-(ba(e,u)|0)|0,e)|0;e=ba(2-(ba(s,u)|0)|0,s)|0;s=ba(2-(ba(e,u)|0)|0,e)|0;e=ba(ba(v,v)|0,v)|0;u=ba(2-(ba(e,v)|0)|0,e)|0;e=ba(2-(ba(u,v)|0)|0,u)|0;u=ba(2-(ba(e,v)|0)|0,e)|0;e=ba(ba(w,w)|0,w)|0;v=ba(2-(ba(e,w)|0)|0,e)|0;e=ba(2-(ba(v,w)|0)|0,v)|0;v=ba(2-(ba(e,w)|0)|0,e)|0;e=ba(ba(y,y)|0,y)|0;w=ba(2-(ba(e,y)|0)|0,e)|0;e=ba(2-(ba(w,y)|0)|0,w)|0;w=ba(2-(ba(e,y)|0)|0,e)|0;e=ba(ba(z,z)|0,z)|0;y=ba(2-(ba(e,z)|0)|0,e)|0;e=ba(2-(ba(y,z)|0)|0,y)|0;y=ba(2-(ba(e,z)|0)|0,e)|0;e=c[l+4>>2]|0;z=ba(y,e-A|0)|0;A=ba(w,z>>>16|z<<16)|0;z=ba(v,A>>>16|A<<16)|0;A=ba(u,z>>>16|z<<16)|0;z=ba(s,A>>>16|A<<16)|0;A=ZGb((c[l>>2]|0)-e|0,0,I,0)|0;e=A;A=ba(r,e-t|0)|0;t=ba(q,A>>>16|A<<16)|0;A=ba(p,t>>>16|t<<16)|0;t=ba(o,A>>>16|A<<16)|0;A=ZGb(ba(E,t>>>16|t<<16)|0,0,J,I)|0;I=A|0|0;A=F&0|z-e;c[l>>2]=I;c[l+4>>2]=A;l=H;H=l|0;x=I;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=l+4|0;x=A;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;i=g;return}function YW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+24|0;d=c[b>>2]|0;if((d|0)==0){return}e=a+28|0;a=0;f=d;while(1){d=c[(c[e>>2]|0)+(a<<2)>>2]|0;if((c[(c[d+8>>2]|0)+8>>2]|0)==1){VBb(c[c[d+12>>2]>>2]|0);g=c[b>>2]|0}else{g=f}d=a+1|0;if(d>>>0<g>>>0){a=d;f=g}else{break}}return}function ZW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=d;d=i;i=i+8|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];if((b|0)==0){g=-1;i=e;return g|0}if((c[d>>2]|0)==0){yDb(a,16,2346048,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1;i=e;return g|0}f=a+24|0;j=c[f>>2]|0;if((j|0)==0){g=0;i=e;return g|0}k=a+28|0;l=d;d=0;m=j;while(1){j=c[(c[k>>2]|0)+(d<<2)>>2]|0;n=c[j+12>>2]|0;o=c[j+8>>2]|0;if((c[o+8>>2]|0)==1){j=c[o+416>>2]|0;p=ba(u0a(c[o+48>>2]|0)|0,j)|0;c[n+16>>2]=(p|0)/8|0;if(!((p+7|0)>>>0>14>>>0)){break}c[n+20>>2]=b;c[n+24>>2]=b;p=n+28|0;j=c[l+4>>2]|0;c[p>>2]=c[l>>2];c[p+4>>2]=j;c[n+4>>2]=(c[b>>2]|0)*100|0;c[n>>2]=UBb((c[b>>2]|0)*100|0)|0;q=c[f>>2]|0}else{q=m}n=d+1|0;if(n>>>0<q>>>0){d=n;m=q}else{g=0;r=11;break}}if((r|0)==11){i=e;return g|0}yDb(a,16,2336360,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1;i=e;return g|0}function _W(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;i=i+80|0;j=h|0;do{if((d|0)!=0){k=c[(c[a+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0;l=c[k+12>>2]|0;if((c[(c[k+8>>2]|0)+8>>2]|0)!=1){k=l+8|0;m=c[k>>2]|0;n=c[k+4>>2]|0;o=d+16|0;c[o>>2]=m;c[o+4>>2]=n;o=d+8|0;c[o>>2]=m;c[o+4>>2]=n;n=c[d+48>>2]|0;o=YGb(c[k>>2]|0,c[k+4>>2]|0,n,(n|0)<0|0?-1:0)|0;c[k>>2]=o;c[k+4>>2]=F;k=JK(a,d,g)|0;if((k|0)<0){p=k}else{break}i=h;return p|0}k=l;o=WBb(c[k>>2]|0)|0;n=d+28|0;m=c[n>>2]|0;q=m+o|0;o=l+4|0;do{if(q>>>0>(c[o>>2]|0)>>>0){if((YBb(c[k>>2]|0,q)|0)<0){p=-1;i=h;return p|0}else{c[o>>2]=q;r=c[n>>2]|0;break}}else{r=m}}while(0);_Bb(c[k>>2]|0,c[d+24>>2]|0,r,0)|0}}while(0);r=a+24|0;a:do{if((c[r>>2]|0)!=0){d=a+28|0;m=(e|0)==0;n=j+24|0;q=j+8|0;o=j+16|0;l=j+48|0;s=j+32|0;t=0;b:while(1){u=c[(c[d>>2]|0)+(t<<2)>>2]|0;c:do{if((c[(c[u+8>>2]|0)+8>>2]|0)==1){d:do{if(m){v=u;while(1){w=c[v+12>>2]|0;x=w;y=WBb(c[x>>2]|0)|0;z=w+24|0;A=ba(c[w+16>>2]|0,c[c[z>>2]>>2]|0)|0;if((y|0)>(A|0)){B=A}else{B=WBb(c[x>>2]|0)|0}if((B|0)==0){break c}if((B|0)==(WBb(c[x>>2]|0)|0)){break c}if((wZ(j,B)|0)<0){p=-12;C=34;break b}ZBb(c[x>>2]|0,c[n>>2]|0,B,0)|0;x=w+8|0;A=c[x>>2]|0;y=c[x+4>>2]|0;c[q>>2]=A;c[q+4>>2]=y;c[o>>2]=A;c[o+4>>2]=y;y=c[c[z>>2]>>2]|0;A=KDb(y,(y|0)<0|0?-1:0,v+40|0,w+28|0)|0;y=A;c[l>>2]=y;c[s>>2]=t;A=YGb(y,(y|0)<0|0?-1:0,c[x>>2]|0,c[x+4>>2]|0)|0;c[x>>2]=A;c[x+4>>2]=F;x=(c[z>>2]|0)+4|0;c[z>>2]=x;if((c[x>>2]|0)==0){c[z>>2]=c[w+20>>2]}if((B|0)<=0){D=B;break d}w=JK(a,j,g)|0;if((w|0)<0){p=w;C=34;break b}v=c[(c[d>>2]|0)+(t<<2)>>2]|0}}else{v=u;while(1){w=c[v+12>>2]|0;z=w;x=WBb(c[z>>2]|0)|0;A=w+24|0;y=ba(c[w+16>>2]|0,c[c[A>>2]>>2]|0)|0;if((x|0)>(y|0)){E=y}else{E=WBb(c[z>>2]|0)|0}if((E|0)==0){break c}if((wZ(j,E)|0)<0){p=-12;C=34;break b}ZBb(c[z>>2]|0,c[n>>2]|0,E,0)|0;z=w+8|0;y=c[z>>2]|0;x=c[z+4>>2]|0;c[q>>2]=y;c[q+4>>2]=x;c[o>>2]=y;c[o+4>>2]=x;x=c[c[A>>2]>>2]|0;y=KDb(x,(x|0)<0|0?-1:0,v+40|0,w+28|0)|0;x=y;c[l>>2]=x;c[s>>2]=t;y=YGb(x,(x|0)<0|0?-1:0,c[z>>2]|0,c[z+4>>2]|0)|0;c[z>>2]=y;c[z+4>>2]=F;z=(c[A>>2]|0)+4|0;c[A>>2]=z;if((c[z>>2]|0)==0){c[A>>2]=c[w+20>>2]}if((E|0)<=0){D=E;break d}w=JK(a,j,g)|0;if((w|0)<0){p=w;C=34;break b}v=c[(c[d>>2]|0)+(t<<2)>>2]|0}}}while(0);if((D|0)<0){p=D;C=34;break b}}}while(0);t=t+1|0;if(!(t>>>0<(c[r>>2]|0)>>>0)){break a}}if((C|0)==34){i=h;return p|0}}}while(0);p=_e[f&1023](a,b,0,e)|0;i=h;return p|0}function $W(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+(4-(b&3))|0;f=d-3|0;a:do{if(f>>>0>b>>>0){g=b;while(1){h=g+1|0;do{if((a[g]|0)==0){if((a[h]|0)!=0){break}if((a[g+2|0]|0)==1){i=g;break a}}}while(0);if(h>>>0<e>>>0&h>>>0<f>>>0){g=h}else{j=h;k=6;break}}}else{j=b;k=6}}while(0);b:do{if((k|0)==6){e=d-6|0;if(j>>>0<e>>>0){g=j;while(1){l=c[g>>2]|0;m=l&255;do{if(((l&-2139062144^-2139062144)&l-16843009|0)!=0){n=g+1|0;do{if((a[n]|0)==0){o=a[g+2|0]|0;if(m<<24>>24==0&o<<24>>24==1){i=g;break b}if(!(o<<24>>24==0)){break}if((a[g+3|0]|0)==1){i=n;break b}}}while(0);n=g+3|0;if((a[n]|0)!=0){break}o=g+2|0;p=a[g+4|0]|0;if((a[o]|0)==0&p<<24>>24==1){i=o;break b}if(!(p<<24>>24==0)){break}if((a[g+5|0]|0)==1){i=n;break b}}}while(0);m=g+4|0;if(m>>>0<e>>>0){g=m}else{q=m;break}}}else{q=j}if(q>>>0<f>>>0){r=q}else{s=d;return s|0}while(1){g=r+1|0;do{if((a[r]|0)==0){if((a[g]|0)!=0){break}if((a[r+2|0]|0)==1){i=r;break b}}}while(0);if(g>>>0<f>>>0){r=g}else{s=d;break}}return s|0}}while(0);if(i>>>0>b>>>0&i>>>0<d>>>0){d=i-1|0;return((a[d]|0)==0?d:i)|0}else{s=i;return s|0}return 0}function aX(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c+d|0;d=0;f=$W(c,e)|0;while(1){c=f;while(1){if(!(c>>>0<e>>>0)){g=c;break}h=c+1|0;if((a[c]|0)==0){c=h}else{g=h;break}}if((g|0)==(e|0)){break}c=$W(g,e)|0;h=g;i=c-h|0;Zy(b,i);Ry(b,g,i);d=d-h+(c+4)|0;f=c}return d|0}function bX(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+8|0;g=f|0;h=Mz(g)|0;if((h|0)<0){j=h;i=f;return j|0}h=c[g>>2]|0;k=b+(c[e>>2]|0)|0;l=$W(b,k)|0;while(1){if(l>>>0<k>>>0){b=l+1|0;if((a[l]|0)==0){l=b;continue}else{m=b}}else{m=l}if((m|0)==(k|0)){break}b=$W(m,k)|0;n=b-m|0;Zy(h,n);Ry(h,m,n);l=b}$Db(d);c[e>>2]=Oz(c[g>>2]|0,d)|0;j=0;i=f;return j|0}function cX(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+16|0;h=g|0;j=g+8|0;c[h>>2]=f;if((f|0)<=6){k=0;i=g;return k|0}l=e;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;do{if((m|0)!=16777216){if(((d[e+1|0]|0)<<8|m<<16&16711680|(d[e+2|0]|0)|0)==1){break}Ry(b,e,f);k=0;i=g;return k|0}}while(0);c[j>>2]=0;f=bX(e,j,h)|0;if((f|0)<0){k=f;i=g;return k|0}f=c[j>>2]|0;e=c[h>>2]|0;h=f+e|0;if((e|0)>4){n=0;o=0;p=0;q=0;r=f;s=e}else{k=-1094995529;i=g;return k|0}while(1){e=r;m=fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;e=s-4|0;l=m>>>0>e>>>0?e:m;m=r+4|0;c[j>>2]=m;e=a[m]&31;if(e<<24>>24==7){t=l;u=p;v=o;w=m}else{x=e<<24>>24==8;t=q;u=x?l:p;v=x?m:o;w=n}m=r+(l+4)|0;c[j>>2]=m;l=h-m|0;if((l|0)>4){n=w;o=v;p=u;q=t;r=m;s=l}else{break}}if((w|0)==0|(v|0)==0){k=-1094995529;i=g;return k|0}if((t-4|0)>>>0>65531>>>0|u>>>0>65535>>>0){k=-1094995529;i=g;return k|0}Py(b,1);Py(b,d[w+1|0]|0);Py(b,d[w+2|0]|0);Py(b,d[w+3|0]|0);Py(b,255);Py(b,225);fz(b,t);Ry(b,w,t);Py(b,1);fz(b,u);Ry(b,v,u);ZDb(f);k=0;i=g;return k|0}function dX(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[e>>2]=0;g=c[f>>2]|0;if((g|0)<=3){h=-1094995529;return h|0}i=b;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;if((j|0)==16777216){h=0;return h|0}if(((d[b+1|0]|0)<<8|j<<16&16711680|(d[b+2|0]|0)|0)==1){h=0;return h|0}if(!((g|0)>10&(j&255)<<24>>24==1)){h=-1094995529;return h|0}j=b+6|0;i=(de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535;j=i+11|0;if((j|0)>(g|0)){h=-1094995529;return h|0}k=b+(i+9)|0;l=(de((d[k]|d[k+1|0]<<8)<<16>>16|0)|0)&65535;if((l+j|0)>(g|0)){h=-1094995529;return h|0}g=i+8|0;k=g+l|0;m=cEb(k)|0;if((m|0)==0){h=-12;return h|0}n=m;x=16777216;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;UGb(m+4|0,b+8|0,i)|0;n=m+(i+4)|0;x=16777216;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;UGb(m+g|0,b+j|0,l)|0;c[e>>2]=m;c[f>>2]=k;h=0;return h|0}function eX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+48|0;e=d|0;UGb(e|0,1256136,48)|0;f=(a|0)/86400|0;g=(a|0)%86400|0;c[b+8>>2]=(g|0)/3600|0;c[b+4>>2]=((g|0)%3600|0|0)/60|0;c[b>>2]=(g|0)%60|0;if((a|0)>31622399){a=1970;g=f;while(1){h=(g|0)/366|0;j=h+a|0;k=j-1|0;l=a-1|0;m=((k|0)/-4|0)+g+(h*-365|0)+((k|0)/100|0)+((k|0)/-400|0)+((l|0)/4|0)+((l|0)/-100|0)+((l|0)/400|0)|0;if((m|0)>365){a=j;g=m}else{n=j;o=m;break}}}else{n=1970;o=f}do{if((o|0)==365){if((n&3|0)==0){if(((n|0)%100|0|0)!=0|((n|0)%400|0|0)==0){p=365;q=n;break}}p=0;q=n+1|0}else{p=o;q=n}}while(0);do{if((q&3|0)==0){if(((q|0)%100|0|0)!=0){r=29;break}r=((q|0)%400|0|0)==0?29:28}else{r=28}}while(0);c[e+4>>2]=r;if((p|0)<31){s=p;t=1;u=b+20|0;c[u>>2]=q;v=b+16|0;c[v>>2]=t;w=s+1|0;x=b+12|0;c[x>>2]=w;i=d;return b|0}else{y=p;z=0;A=31}while(1){B=y-A|0;p=z+1|0;r=c[e+(p<<2)>>2]|0;if((B|0)<(r|0)){break}else{y=B;z=p;A=r}}s=B;t=z+2|0;u=b+20|0;c[u>>2]=q;v=b+16|0;c[v>>2]=t;w=s+1|0;x=b+12|0;c[x>>2]=w;i=d;return b|0}function fX(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+88|0;g=f|0;h=f+8|0;j=f+72|0;k=f+80|0;c[g>>2]=0;c[j>>2]=0;l=Oy(d,e,0,0,0,0,0)|0;c[k>>2]=l;if((l|0)==0){m=-12;i=f;return m|0}e=vz(l)|0;do{if(e>>>0>20>>>0|(e|0)<0){yDb(b,16,2345776,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;if((c[b+1156>>2]&8|0)!=0){o=-1094995529;break}p=0;q=c[k>>2]|0;r=5}else{p=e;q=l;r=5}}while(0);a:do{if((r|0)==5){l=vz(q)|0;do{if((l|0)>=1){e=h|0;if((mz(c[k>>2]|0,e,l>>>0>63>>>0?63:l)|0)!=(l|0)){break}if(!(l>>>0<64>>>0)){yDb(0,0,2194648,(n=i,i=i+24|0,c[n>>2]=2116304,c[n+8>>2]=2057064,c[n+16>>2]=63,n)|0);i=n;Cd();return 0}a[h+l|0]=0;d=1204600;while(1){s=c[d+32>>2]|0;if((s|0)==0){r=13;break}if((RGb(d|0,e,64)|0)==0){break}else{d=d+36|0}}if((r|0)==13){yDb(b,16,2010976,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-1094995529;break a}d=vz(c[k>>2]|0)|0;do{if((d|0)>0){t=WDb(d+1|0)|0;c[j>>2]=t;if((t|0)==0){o=-12;break a}if((mz(c[k>>2]|0,t,d)|0)==(d|0)){a[(c[j>>2]|0)+d|0]=0;break}else{yDb(b,16,1972e3,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-5;break a}}}while(0);d=vz(c[k>>2]|0)|0;e=vz(c[k>>2]|0)|0;Vy(c[k>>2]|0,8,0)|0;t=vz(c[k>>2]|0)|0;if((t|0)<1){yDb(b,16,1943224,(n=i,i=i+8|0,c[n>>2]=t,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-1094995529;break a}u=UAb(t+16|0)|0;c[g>>2]=u;if((u|0)==0){o=-12;break a}v=u+4|0;TGb((c[v>>2]|0)+t|0,0,16)|0;if((mz(c[k>>2]|0,c[v>>2]|0,t)|0)!=(t|0)){yDb(b,16,1918536,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-5;break a}v=LT(b,0)|0;if((v|0)==0){o=-12;break a}u=v+104|0;vZ(u);c[u>>2]=c[g>>2];c[v+128>>2]=c[(c[g>>2]|0)+4>>2];c[v+132>>2]=t;c[v+136>>2]=c[v>>2];t=v+140|0;c[t>>2]=c[t>>2]|1;t=v+72|0;c[t>>2]=c[t>>2]|1024;t=c[v+8>>2]|0;c[t+8>>2]=0;c[t+48>>2]=s;c[t+120>>2]=d;c[t+124>>2]=e;e=v+88|0;CBb(e,1897808,c[1204512+(p<<2)>>2]|0,0)|0;v=c[j>>2]|0;if((v|0)!=0){CBb(e,2355176,v,8)|0}$Db(k);m=0;i=f;return m|0}}while(0);yDb(b,16,2336304,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-1094995529}}while(0);XAb(g);$Db(j);$Db(k);m=o;i=f;return m|0}function gX(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;i=i+16|0;j=h|0;k=h+8|0;c[j>>2]=e;c[k>>2]=0;do{if((f|0)==0){l=0;m=aX(a,b,e)|0}else{n=bX(b,k,j)|0;if((n|0)<0){l=0;m=n;break}n=c[k>>2]|0;o=c[j>>2]|0;p=n+o|0;if((o|0)>4){q=n;r=0;s=0;t=o}else{l=0;m=0;break}while(1){o=q;n=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=t-4|0;u=n>>>0>o>>>0?o:n;n=q+4|0;if((((d[n]|0)>>>1&63)-32|0)>>>0<3>>>0){v=s+1|0;w=r}else{Zy(a,u);Ry(a,n,u);v=s;w=r+4+u|0}n=q+(u+4)|0;u=p-n|0;if((u|0)>4){q=n;r=w;s=v;t=u}else{l=v;m=w;break}}}}while(0);ZDb(c[k>>2]|0);if((g|0)==0){i=h;return m|0}c[g>>2]=l;i=h;return m|0}function hX(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+8|0;h=g|0;j=Mz(h)|0;if((j|0)<0){k=j;i=g;return k|0}j=gX(c[h>>2]|0,a,c[d>>2]|0,e,f)|0;c[d>>2]=Oz(c[h>>2]|0,b)|0;k=j;i=g;return k|0}function iX(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0;k=i;i=i+336|0;l=k|0;m=k+256|0;n=k+280|0;o=k+288|0;p=k+296|0;c[n>>2]=h;c[o>>2]=0;q=p|0;TGb(q|0,0,40)|0;a[q]=1;r=p+29|0;a[r]=3;s=p+4|0;c[s>>2]=-1;t=p+8|0;c[t>>2]=-1;c[t+4>>2]=65535;u=p+18|0;b[u>>1]=4097;a:do{if((h|0)<6){v=-1094995529}else{w=a[g]|0;if(w<<24>>24==1){Ry(f,g,h);v=0;break}if((d[g+1|0]<<8|(w&255)<<16|d[g+2|0]|0)!=1){w=g;if((d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)!=16777216){v=-1094995529;break}}w=bX(g,o,n)|0;if((w|0)<0){v=w;break}w=c[o>>2]|0;x=c[n>>2]|0;y=w+x|0;b:do{if((x|0)>4){z=m|0;A=m+12|0;B=m+16|0;C=m+4|0;D=m+8|0;E=p+32|0;F=p+30|0;G=j&255;H=p+27|0;I=p+28|0;J=p+21|0;K=p+22|0;L=p+23|0;M=p+20|0;N=E;O=w;P=x;while(1){Q=O;R=fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Q=P-4|0;S=R>>>0>Q>>>0?Q:R;R=O+4|0;switch((d[R]|0)>>>1&63|0){case 32:case 33:case 34:case 39:case 40:{Q=WDb(S)|0;c:do{if((Q|0)==0){T=-12;U=0}else{if((S|0)==0){V=0}else{W=(S|0)==1?1:2;UGb(Q|0,R|0,W)|0;V=W}W=V+2|0;if(W>>>0<S>>>0){X=V;Y=V;Z=W;while(1){W=a[O+(X+4)|0]|0;_=X+1|0;do{if(W<<24>>24==0){if((a[O+(X+5)|0]|0)!=0){$=20;break}if((a[O+(Z+4)|0]|0)!=3){$=20;break}a[Q+Y|0]=0;a[Q+(Y+1)|0]=0;aa=Y+2|0;ba=X+3|0}else{$=20}}while(0);if(($|0)==20){$=0;a[Q+Y|0]=W;aa=Y+1|0;ba=_}ca=ba+2|0;if(ca>>>0<S>>>0){X=ba;Y=aa;Z=ca}else{da=ba;ea=aa;break}}}else{da=V;ea=V}if(da>>>0<S>>>0){UGb(Q+ea|0,O+(da+4)|0,S-da|0)|0;fa=ea+S-da|0}else{fa=ea}Z=fa>>>0>268435455>>>0?-8:fa<<3;Y=Z>>>0>2147483639>>>0;X=Y?0:Q;ca=Y?0:Z;c[z>>2]=X;c[A>>2]=ca;Z=ca+8|0;c[B>>2]=Z;c[C>>2]=X+(ca>>3);c[D>>2]=0;if(Y){T=Y?-1094995529:0;U=Q;break}Y=Z>>>0>1>>>0?1:Z;ca=X+(Y>>>3)|0;X=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(Y&1)>>>26;ca=Y|6;Y=X&255;ga=(Z>>>0>ca>>>0?ca:Z)+9|0;c[D>>2]=Z>>>0>ga>>>0?ga:Z;switch(X|0){case 32:case 33:case 34:case 39:case 40:{break};default:{T=-1094995529;U=Q;break c}}X=a[F]|0;Z=c[E>>2]|0;ga=0;while(1){ha=ga&255;if(!((ga&255)>>>0<(X&255)>>>0)){$=27;break}if((a[Z+(ha*12|0)+1|0]|0)==Y<<24>>24){ia=Z;break}else{ga=ga+1&255}}if(($|0)==27){$=0;Z=ha+1|0;X=bEb(N,Z,12)|0;if((X|0)<0){T=X;U=Q;break}X=a[F]|0;if(!((X&255)>>>0>(ga&255)>>>0)){ca=X;do{TGb((c[E>>2]|0)+((ca&255)*12|0)|0,0,12)|0;ca=ca+1&255;}while(!((ca&255)>>>0>(ga&255)>>>0))}a[F]=Z;ia=c[E>>2]|0}ga=ia+(ha*12|0)+2|0;ca=ia+(ha*12|0)+8|0;X=e[ga>>1]|0;ja=X+1|0;ka=bEb(ca,ja,4)|0;if((ka|0)<0){T=ka;U=Q;break}ka=ia+(ha*12|0)+4|0;la=bEb(ka,ja,2)|0;if((la|0)<0){T=la;U=Q;break}c[(c[ca>>2]|0)+(X<<2)>>2]=R;b[(c[ka>>2]|0)+(X<<1)>>1]=S;a[ia+(ha*12|0)+1|0]=Y;b[ga>>1]=(b[ga>>1]|0)+1;if((Y-32&255)>>>0<3>>>0){a[ia+(ha*12|0)|0]=G}if((Y<<24>>24|0)==33){ga=c[B>>2]|0;X=(c[D>>2]|0)+4|0;ka=ga>>>0>X>>>0?X:ga;c[D>>2]=ka;X=c[z>>2]|0;ca=X+(ka>>>3)|0;la=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(ka&7)>>>29;ca=ka+3|0;ka=ga>>>0>ca>>>0?ca:ga;c[D>>2]=ka;ca=a[H]|0;ja=la+1|0;a[H]=(ca&255)>>>0>ja>>>0?ca:ja&255;ja=d[X+(ka>>>3)|0]<<(ka&7)>>>7;c[D>>2]=((ka|0)<(ga|0))+ka;a[I]=ja&1;kX(m,p,la);jX(m)|0;ja=jX(m)|0;a[J]=ja;if((ja&255|0)==3){ja=c[B>>2]|0;ka=(c[D>>2]|0)+1|0;c[D>>2]=ja>>>0>ka>>>0?ka:ja}jX(m)|0;jX(m)|0;ja=c[D>>2]|0;ka=d[(c[z>>2]|0)+(ja>>>3)|0]|0;c[D>>2]=((ja|0)<(c[B>>2]|0))+ja;if((ka&128>>>((ja&7)>>>0)|0)!=0){jX(m)|0;jX(m)|0;jX(m)|0;jX(m)|0}a[K]=jX(m)|0;a[L]=jX(m)|0;ja=jX(m)|0;ka=c[D>>2]|0;ga=d[(c[z>>2]|0)+(ka>>>3)|0]|0;c[D>>2]=((ka|0)<(c[B>>2]|0))+ka;X=(ga&128>>>((ka&7)>>>0)|0)!=0?0:la;do{jX(m)|0;jX(m)|0;jX(m)|0;X=X+1|0;}while(!(X>>>0>la>>>0));jX(m)|0;jX(m)|0;jX(m)|0;jX(m)|0;jX(m)|0;jX(m)|0;X=c[D>>2]|0;Z=c[z>>2]|0;ka=d[Z+(X>>>3)|0]|0;ga=c[B>>2]|0;ca=((X|0)<(ga|0))+X|0;c[D>>2]=ca;do{if((ka&128>>>((X&7)>>>0)|0)==0){ma=ca;na=ga;oa=Z}else{pa=d[Z+(ca>>>3)|0]|0;qa=((ca|0)<(ga|0))+ca|0;c[D>>2]=qa;if((pa&128>>>((ca&7)>>>0)|0)==0){ma=qa;na=ga;oa=Z;break}else{ra=0}do{qa=(ra|0)==3?2:6;pa=1<<(ra<<1)+4;sa=(pa|0)<64?pa:64;pa=(sa|0)>0;d:do{if((ra|0)>1){ta=pa^1;ua=1;while(1){va=c[D>>2]|0;wa=d[(c[z>>2]|0)+(va>>>3)|0]|0;c[D>>2]=((va|0)<(c[B>>2]|0))+va;jX(m)|0;if(!((wa&128>>>((va&7)>>>0)|0)==0|ta)){va=0;do{jX(m)|0;va=va+1|0;}while((va|0)<(sa|0))}if((ua|0)>=(qa|0)){break d}ua=ua+1|0}}else{if(pa){xa=1}else{ua=1;while(1){ta=c[D>>2]|0;va=d[(c[z>>2]|0)+(ta>>>3)|0]|0;c[D>>2]=((ta|0)<(c[B>>2]|0))+ta;if((va&128>>>((ta&7)>>>0)|0)==0){jX(m)|0}if((ua|0)>=(qa|0)){break d}ua=ua+1|0}}while(1){ua=c[D>>2]|0;ta=d[(c[z>>2]|0)+(ua>>>3)|0]|0;c[D>>2]=((ua|0)<(c[B>>2]|0))+ua;if((ta&128>>>((ua&7)>>>0)|0)==0){jX(m)|0}else{ua=0;do{jX(m)|0;ua=ua+1|0;}while((ua|0)<(sa|0))}if((xa|0)>=(qa|0)){break d}xa=xa+1|0}}}while(0);ra=ra+1|0;}while((ra|0)<4);ma=c[D>>2]|0;na=c[B>>2]|0;oa=c[z>>2]|0}}while(0);Z=ma+1|0;ga=(na>>>0>Z>>>0?Z:na)+1|0;Z=na>>>0>ga>>>0?ga:na;c[D>>2]=Z;ga=d[oa+(Z>>>3)|0]|0;ca=((Z|0)<(na|0))+Z|0;c[D>>2]=ca;if((128>>>((Z&7)>>>0)&ga|0)!=0){ga=ca+4|0;ca=(na>>>0>ga>>>0?ga:na)+4|0;c[D>>2]=na>>>0>ca>>>0?ca:na;jX(m)|0;jX(m)|0;ca=c[B>>2]|0;ga=(c[D>>2]|0)+1|0;c[D>>2]=ca>>>0>ga>>>0?ga:ca}ca=jX(m)|0;if(ca>>>0>64>>>0){T=-1094995529;U=Q;break}if((ca|0)!=0){ga=0;do{do{if((ga|0)==0){$=75}else{Z=c[D>>2]|0;X=d[(c[z>>2]|0)+(Z>>>3)|0]|0;ka=c[B>>2]|0;_=((Z|0)<(ka|0))+Z|0;c[D>>2]=_;if((X&128>>>((Z&7)>>>0)|0)==0){$=75;break}Z=_+1|0;c[D>>2]=ka>>>0>Z>>>0?Z:ka;jX(m)|0;ka=l+(ga<<2)|0;c[ka>>2]=0;Z=c[l+(ga-1<<2)>>2]|0;if((Z|0)==0){break}_=c[z>>2]|0;X=c[B>>2]|0;W=1;qa=c[D>>2]|0;sa=0;while(1){pa=d[_+(qa>>>3)|0]|0;ua=((qa|0)<(X|0))+qa|0;c[D>>2]=ua;if((pa&128>>>((qa&7)>>>0)|0)==0){pa=d[_+(ua>>>3)|0]|0;ta=((ua|0)<(X|0))+ua|0;c[D>>2]=ta;if((pa&128>>>((ua&7)>>>0)|0)==0){ya=ta;za=sa}else{Aa=ta;$=73}}else{Aa=ua;$=73}if(($|0)==73){$=0;ua=sa+1|0;c[ka>>2]=ua;ya=Aa;za=ua}if(W>>>0<Z>>>0){W=W+1|0;qa=ya;sa=za}else{break}}}}while(0);do{if(($|0)==75){$=0;sa=jX(m)|0;qa=jX(m)|0;c[l+(ga<<2)>>2]=qa+sa;if((sa|0)!=0){W=0;do{jX(m)|0;Z=c[B>>2]|0;ka=(c[D>>2]|0)+1|0;c[D>>2]=Z>>>0>ka>>>0?ka:Z;W=W+1|0;}while(W>>>0<sa>>>0)}if((qa|0)==0){break}else{Ba=0}do{jX(m)|0;sa=c[B>>2]|0;W=(c[D>>2]|0)+1|0;c[D>>2]=sa>>>0>W>>>0?W:sa;Ba=Ba+1|0;}while(Ba>>>0<qa>>>0)}}while(0);ga=ga+1|0;}while(ga>>>0<ca>>>0)}ca=c[D>>2]|0;ga=c[z>>2]|0;qa=d[ga+(ca>>>3)|0]|0;sa=c[B>>2]|0;W=((ca|0)<(sa|0))+ca|0;c[D>>2]=W;if((qa&128>>>((ca&7)>>>0)|0)==0){Ca=W;Da=sa;Ea=ga}else{if((jX(m)|0)!=0){ga=ja+4|0;sa=ga>>>0>16>>>0?16:ga;ga=0;do{W=c[B>>2]|0;ca=(c[D>>2]|0)+sa|0;qa=(W>>>0>ca>>>0?ca:W)+1|0;c[D>>2]=W>>>0>qa>>>0?qa:W;ga=ga+1|0;}while(ga>>>0<(jX(m)|0)>>>0)}Ca=c[D>>2]|0;Da=c[B>>2]|0;Ea=c[z>>2]|0}ga=Ca+1|0;sa=(Da>>>0>ga>>>0?ga:Da)+1|0;ga=Da>>>0>sa>>>0?sa:Da;c[D>>2]=ga;sa=d[Ea+(ga>>>3)|0]|0;ja=((ga|0)<(Da|0))+ga|0;c[D>>2]=ja;if((128>>>((ga&7)>>>0)&sa|0)==0){T=0;U=Q;break}sa=d[Ea+(ja>>>3)|0]|0;ga=((ja|0)<(Da|0))+ja|0;c[D>>2]=ga;do{if((sa&128>>>((ja&7)>>>0)|0)==0){Fa=ga}else{W=Ea+(ga>>>3)|0;qa=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(ga&7);W=ga+8|0;ca=Da>>>0>W>>>0?W:Da;c[D>>2]=ca;if(!((qa&-16777216|0)==-16777216)){Fa=ca;break}qa=-ca|0;W=Da-ca|0;if((qa|0)>32){Ga=qa}else{Ga=(W|0)<32?W:32}W=Ga+ca|0;c[D>>2]=W;Fa=W}}while(0);ga=((Fa|0)<(Da|0))+Fa|0;if((d[Ea+(Fa>>>3)|0]&128>>>((Fa&7)>>>0)|0)==0){Ha=ga}else{ja=ga+1|0;Ha=Da>>>0>ja>>>0?ja:Da}c[D>>2]=Ha;ja=d[Ea+(Ha>>>3)|0]|0;ga=((Ha|0)<(Da|0))+Ha|0;c[D>>2]=ga;do{if((ja&128>>>((Ha&7)>>>0)|0)==0){Ia=ga}else{sa=ga+4|0;W=Da>>>0>sa>>>0?sa:Da;c[D>>2]=W;sa=d[Ea+(W>>>3)|0]|0;ca=((W|0)<(Da|0))+W|0;c[D>>2]=ca;if((sa&128>>>((W&7)>>>0)|0)==0){Ia=ca;break}W=ca+24|0;ca=Da>>>0>W>>>0?W:Da;c[D>>2]=ca;Ia=ca}}while(0);ga=d[Ea+(Ia>>>3)|0]|0;ja=((Ia|0)<(Da|0))+Ia|0;c[D>>2]=ja;if((ga&128>>>((Ia&7)>>>0)|0)==0){Ja=ja;Ka=Da;La=Ea}else{jX(m)|0;jX(m)|0;Ja=c[D>>2]|0;Ka=c[B>>2]|0;La=c[z>>2]|0}ja=Ja+3|0;ga=Ka>>>0>ja>>>0?ja:Ka;c[D>>2]=ga;ja=d[La+(ga>>>3)|0]|0;ca=((ga|0)<(Ka|0))+ga|0;c[D>>2]=ca;if((128>>>((ga&7)>>>0)&ja|0)==0){Ma=ca;Na=La;Oa=Ka}else{jX(m)|0;jX(m)|0;jX(m)|0;jX(m)|0;Ma=c[D>>2]|0;Na=c[z>>2]|0;Oa=c[B>>2]|0}ca=d[Na+(Ma>>>3)|0]|0;ja=((Ma|0)<(Oa|0))+Ma|0;c[D>>2]=ja;do{if((ca&128>>>((Ma&7)>>>0)|0)==0){Pa=ja;Qa=Na;Ra=Oa}else{ga=-ja|0;W=Oa-ja|0;if((ga|0)>32){Sa=ga}else{Sa=(W|0)<32?W:32}W=Sa+ja|0;c[D>>2]=W;ga=-W|0;sa=Oa-W|0;if((ga|0)>32){Ta=ga}else{Ta=(sa|0)<32?sa:32}sa=Ta+W|0;c[D>>2]=sa;W=d[Na+(sa>>>3)|0]|0;ga=((sa|0)<(Oa|0))+sa|0;c[D>>2]=ga;if((128>>>((sa&7)>>>0)&W|0)==0){Ua=ga;Va=Na;Wa=Oa}else{jX(m)|0;Ua=c[D>>2]|0;Va=c[z>>2]|0;Wa=c[B>>2]|0}ga=d[Va+(Ua>>>3)|0]|0;W=((Ua|0)<(Wa|0))+Ua|0;c[D>>2]=W;if((ga&128>>>((Ua&7)>>>0)|0)==0){Pa=W;Qa=Va;Ra=Wa;break}ga=d[Va+(W>>>3)|0]<<(W&7)>>>7;sa=((W|0)<(Wa|0))+W|0;c[D>>2]=sa;W=ga&1;qa=d[Va+(sa>>>3)|0]<<(sa&7)>>>7;Z=((sa|0)<(Wa|0))+sa|0;c[D>>2]=Z;sa=qa&1;if(((qa|ga)&1|0)==0){Xa=0;Ya=Z}else{ga=d[Va+(Z>>>3)|0]<<(Z&7)>>>7;qa=((Z|0)<(Wa|0))+Z|0;c[D>>2]=qa;Z=ga&1;if(Z<<24>>24==0){ga=qa+8|0;Za=Wa>>>0>ga>>>0?ga:Wa}else{ga=qa+19|0;qa=(Wa>>>0>ga>>>0?ga:Wa)+8|0;ga=Wa>>>0>qa>>>0?qa:Wa;c[D>>2]=ga;qa=ga+4|0;Za=Wa>>>0>qa>>>0?qa:Wa}qa=Za+15|0;ga=Wa>>>0>qa>>>0?qa:Wa;c[D>>2]=ga;Xa=Z;Ya=ga}ga=(W|0)==0;W=(sa|0)==0;sa=1;Z=Ya;qa=Va;ka=Wa;while(1){X=d[qa+(Z>>>3)|0]|0;_=((Z|0)<(ka|0))+Z|0;c[D>>2]=_;do{if((X&128>>>((Z&7)>>>0)|0)==0){ua=d[qa+(_>>>3)|0]|0;ta=((_|0)<(ka|0))+_|0;c[D>>2]=ta;if((ua&128>>>((_&7)>>>0)|0)==0){_a=ta;$=117;break}jX(m)|0;$=118}else{_a=_;$=117}}while(0);if(($|0)==117){$=0;_=d[qa+(_a>>>3)|0]|0;c[D>>2]=((_a|0)<(ka|0))+_a;if((_&128>>>((_a&7)>>>0)|0)==0){$=118}else{$a=0}}if(($|0)==118){$=0;$a=jX(m)|0}if(!ga){lX(m,$a,Xa)}if(!W){lX(m,$a,Xa)}_=c[D>>2]|0;X=c[z>>2]|0;ta=c[B>>2]|0;if(sa>>>0>la>>>0){Pa=_;Qa=X;Ra=ta;break}else{sa=sa+1|0;Z=_;qa=X;ka=ta}}}}while(0);la=d[Qa+(Pa>>>3)|0]|0;ja=((Pa|0)<(Ra|0))+Pa|0;c[D>>2]=ja;if((la&128>>>((Pa&7)>>>0)|0)==0){T=0;U=Q;break}la=ja+3|0;c[D>>2]=Ra>>>0>la>>>0?la:Ra;la=jX(m)|0;ja=b[u>>1]|0;b[u>>1]=(ja&65535)>>>0>la>>>0?la&65535:ja;jX(m)|0;jX(m)|0;jX(m)|0;jX(m)|0;T=0;U=Q;break}else if((Y<<24>>24|0)==34){jX(m)|0;jX(m)|0;ja=c[B>>2]|0;la=(c[D>>2]|0)+7|0;c[D>>2]=ja>>>0>la>>>0?la:ja;jX(m)|0;jX(m)|0;jX(m)|0;ja=c[B>>2]|0;la=(c[D>>2]|0)+2|0;ca=ja>>>0>la>>>0?la:ja;c[D>>2]=ca;la=d[(c[z>>2]|0)+(ca>>>3)|0]|0;c[D>>2]=((ca|0)<(ja|0))+ca;if((128>>>((ca&7)>>>0)&la|0)!=0){jX(m)|0}jX(m)|0;jX(m)|0;la=c[B>>2]|0;ca=(c[D>>2]|0)+3|0;ja=la>>>0>ca>>>0?ca:la;c[D>>2]=ja;ca=c[z>>2]|0;ka=d[ca+(ja>>>3)|0]<<(ja&7)>>>7;qa=((ja|0)<(la|0))+ja|0;c[D>>2]=qa;ja=ka&1;ka=d[ca+(qa>>>3)|0]<<(qa&7)>>>7;c[D>>2]=((qa|0)<(la|0))+qa;if((ka&ja|0)!=0){a[M]=0;T=0;U=Q;break}if((ka&1|0)!=0){a[M]=3;T=0;U=Q;break}if((ja|0)==0){a[M]=1;T=0;U=Q;break}else{a[M]=2;T=0;U=Q;break}}else if((Y<<24>>24|0)==32){ja=c[B>>2]|0;ka=(c[D>>2]|0)+12|0;qa=ja>>>0>ka>>>0?ka:ja;c[D>>2]=qa;ka=(c[z>>2]|0)+(qa>>>3)|0;la=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(qa&7)>>>29;ka=qa+3|0;qa=a[H]|0;ca=la+1|0;a[H]=(qa&255)>>>0>ca>>>0?qa:ca&255;ca=(ja>>>0>ka>>>0?ka:ja)+17|0;c[D>>2]=ja>>>0>ca>>>0?ca:ja;kX(m,p,la);T=0;U=Q;break}else{T=0;U=Q;break}}}while(0);ZDb(U);if((T|0)<0){v=T;break a}break};default:{}}O=O+(S+4)|0;P=y-O|0;if((P|0)<=4){break b}}}}while(0);a[q]=1;y=b[u>>1]|0;if((y&65535)>>>0>4096>>>0){b[u>>1]=0;$=140}else{if(y<<16>>16==0){$=140}}if(($|0)==140){a[p+20|0]=0}y=p+24|0;b[y>>1]=0;x=p+26|0;a[x]=0;w=p+30|0;P=a[w]|0;if(P<<24>>24==0){ab=0;bb=0;cb=0}else{O=c[p+32>>2]|0;D=0;H=0;z=0;B=0;while(1){M=D&255;L=d[O+(M*12|0)+1|0]|0;if((L|0)==32){db=B;eb=z;fb=(b[O+(M*12|0)+2>>1]|0)+H&65535}else if((L|0)==33){db=B;eb=(b[O+(M*12|0)+2>>1]|0)+z&65535;fb=H}else if((L|0)==34){db=(b[O+(M*12|0)+2>>1]|0)+B&65535;eb=z;fb=H}else{db=B;eb=z;fb=H}M=D+1&255;if((M&255)>>>0<(P&255)>>>0){D=M;H=fb;z=eb;B=db}else{ab=fb;bb=eb;cb=db;break}}}if(ab<<16>>16==0|(ab&65535)>>>0>16>>>0|bb<<16>>16==0|(bb&65535)>>>0>32>>>0|cb<<16>>16==0|(cb&65535)>>>0>256>>>0){v=-1094995529;break}Py(f,1);Py(f,d[p+2|0]<<5|d[p+1|0]<<6|d[p+3|0]);Zy(f,c[s>>2]|0);Zy(f,(c[t>>2]|0)>>>16|c[t+4>>2]<<16);fz(f,c[t>>2]|0);Py(f,d[p+16|0]|0);fz(f,e[u>>1]|61440);Py(f,d[p+20|0]|252);Py(f,d[p+21|0]|252);Py(f,d[p+22|0]|248);Py(f,d[p+23|0]|248);fz(f,e[y>>1]|0);Py(f,d[p+27|0]<<3|d[x]<<6|d[p+28|0]<<2|d[r]);Py(f,d[w]|0);if((a[w]|0)==0){v=0;break}B=p+32|0;z=0;H=0;D=c[B>>2]|0;while(1){Py(f,a[D+(H*12|0)+1|0]&63|d[D+(H*12|0)|0]<<7);fz(f,e[(c[B>>2]|0)+(H*12|0)+2>>1]|0);P=c[B>>2]|0;if((b[P+(H*12|0)+2>>1]|0)==0){gb=P}else{O=0;M=0;L=P;while(1){fz(f,e[(c[L+(H*12|0)+4>>2]|0)+(M<<1)>>1]|0);P=c[B>>2]|0;Ry(f,c[(c[P+(H*12|0)+8>>2]|0)+(M<<2)>>2]|0,e[(c[P+(H*12|0)+4>>2]|0)+(M<<1)>>1]|0);P=O+1&65535;K=c[B>>2]|0;if((P&65535)>>>0<(e[K+(H*12|0)+2>>1]|0)>>>0){O=P;M=P&65535;L=K}else{gb=K;break}}}L=z+1&255;if((L&255)>>>0<(d[w]|0)>>>0){z=L;H=L&255;D=gb}else{v=0;break}}}}while(0);gb=p+30|0;f=p+32|0;if((a[gb]|0)==0){a[gb]=0;hb=f;$Db(hb);ib=c[o>>2]|0;ZDb(ib);i=k;return v|0}else{jb=1;kb=0}while(1){p=c[f>>2]|0;b[p+(kb*12|0)+2>>1]=0;$Db(p+(kb*12|0)+8|0);$Db((c[f>>2]|0)+(kb*12|0)+4|0);if(!((jb&255)>>>0<(d[gb]|0)>>>0)){break}p=jb&255;jb=jb+1&255;kb=p}a[gb]=0;hb=f;$Db(hb);ib=c[o>>2]|0;ZDb(ib);i=k;return v|0}function jX(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a>>2]|0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;a=b+(f>>>3)|0;h=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7);a=f+16|0;i=g>>>0>a>>>0?a:g;a=b+(i>>>3)|0;j=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>16|h&-65536;i=j>>>0>65535>>>0;a=i?h>>>16:j;j=i?16:0;if((a&65280|0)==0){k=j;l=a}else{k=j|8;l=a>>>8}a=(d[1191992+l|0]|0)+k|0;k=31-a|0;l=-f|0;j=g-f|0;if((k|0)<(l|0)){m=l}else{m=(j|0)<(k|0)?j:k}j=m+f|0;c[e>>2]=j;f=k+1|0;if((f|0)==0){n=0;o=n-1|0;return o|0}m=b+(j>>>3)|0;l=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7);if((f|0)<26){m=j+f|0;c[e>>2]=g>>>0>m>>>0?m:g;n=l>>>(a>>>0);o=n-1|0;return o|0}else{a=j+16|0;j=g>>>0>a>>>0?a:g;c[e>>2]=j;a=k-15|0;m=b+(j>>>3)|0;b=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>((47-k|0)>>>0);k=j+a|0;c[e>>2]=g>>>0>k>>>0?k:g;n=b|l>>>16<<a;o=n-1|0;return o|0}return 0}function kX(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=b+8|0;l=c[k>>2]|0;m=b+16|0;n=c[m>>2]|0;o=b|0;b=c[o>>2]|0;p=b+(l>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(l&7)>>>30;p=l+2|0;l=n>>>0>p>>>0?p:n;c[k>>2]=l;p=d[b+(l>>>3)|0]<<(l&7)>>>7;r=((l|0)<(n|0))+l|0;c[k>>2]=r;l=p&1;p=b+(r>>>3)|0;s=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>27;p=r+5|0;r=n>>>0>p>>>0?p:n;c[k>>2]=r;p=s&255;s=b+(r>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)&-65536;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;u=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>16;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;v=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>16;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;w=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)&-65536;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;x=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>16;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;b=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>24;s=r+8|0;c[k>>2]=n>>>0>s>>>0?s:n;n=b&255;a[e+1|0]=q;q=e+2|0;b=a[q]|0;s=e+16|0;if((b&255)>>>0<(l&255)>>>0){y=n}else{r=a[s]|0;y=(r&255)>>>0>(n&255)>>>0?r:n}a[s]=y;a[q]=(b&255)>>>0>(l&255)>>>0?b:l;l=e+3|0;b=a[l]|0;a[l]=(b&255)>>>0>(p&255)>>>0?b:p;p=e+4|0;c[p>>2]=c[p>>2]&(u|t);t=e+8|0;e=c[t+4>>2]&v;c[t>>2]=c[t>>2]&(x|w);c[t+4>>2]=e;e=(f|0)==0;if(e){i=g;return}t=c[o>>2]|0;o=c[m>>2]|0;w=0;x=c[k>>2]|0;do{v=d[t+(x>>>3)|0]<<(x&7)>>>7;u=((x|0)<(o|0))+x|0;c[k>>2]=u;a[h+w|0]=v&1;v=d[t+(u>>>3)|0]<<(u&7)>>>7;x=((u|0)<(o|0))+u|0;c[k>>2]=x;a[j+w|0]=v&1;w=w+1|0;}while(w>>>0<f>>>0);if(e){i=g;return}do{if(f>>>0<8>>>0){w=c[m>>2]|0;x=f;o=c[k>>2]|0;do{t=o+2|0;o=w>>>0>t>>>0?t:w;x=x+1|0;}while(x>>>0<8>>>0);c[k>>2]=o;if(!e){z=0;break}i=g;return}else{z=0}}while(0);do{if((a[h+z|0]|0)!=0){e=c[k>>2]|0;x=-e|0;w=c[m>>2]|0;t=w-e|0;if((x|0)>32){A=x}else{A=(t|0)<32?t:32}t=A+e|0;c[k>>2]=t;e=-t|0;x=w-t|0;if((e|0)>32){B=e}else{B=(x|0)<32?x:32}x=B+t+24|0;c[k>>2]=w>>>0>x>>>0?x:w}if((a[j+z|0]|0)!=0){w=c[m>>2]|0;x=(c[k>>2]|0)+8|0;c[k>>2]=w>>>0>x>>>0?x:w}z=z+1|0;}while(z>>>0<f>>>0);i=g;return}function lX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+8|0;f=a+16|0;if(d<<24>>24==0){d=0;do{jX(a)|0;jX(a)|0;g=c[f>>2]|0;h=(c[e>>2]|0)+1|0;c[e>>2]=g>>>0>h>>>0?h:g;d=d+1|0;}while(!(d>>>0>b>>>0));return}else{d=0;do{jX(a)|0;jX(a)|0;jX(a)|0;jX(a)|0;g=c[f>>2]|0;h=(c[e>>2]|0)+1|0;c[e>>2]=g>>>0>h>>>0?h:g;d=d+1|0;}while(!(d>>>0>b>>>0));return}}function mX(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+648|0;e=d|0;f=d+520|0;g=b+16|0;h=Ty(c[g>>2]|0,0,0,1)|0;j=F;k=c[g>>2]|0;if((c[k+88>>2]|0)==0){i=d;return}l=Wy(k)|0;k=F;m=0;if(!((k|0)>(m|0)|(k|0)==(m|0)&l>>>0>128>>>0)){i=d;return}m=c[g>>2]|0;n=YGb(l,k,-128,-1)|0;Ty(m,n,F,0)|0;n=f|0;do{if((mz(c[g>>2]|0,n,128)|0)==128){m=d+512|0;if((a[n]|0)!=84){break}if((a[f+1|0]|0)!=65){break}if((a[f+2|0]|0)!=71){break}k=e|0;l=e;o=0;p=k;while(1){q=a[f+(o+3)|0]|0;if(q<<24>>24==0){r=p;break}if((p-l|0)>>>0>510>>>0){r=p;break}s=p+1|0;a[p]=q;q=o+1|0;if((q|0)<30){o=q;p=s}else{r=s;break}}a[r]=0;if((a[k]|0)==0){t=0;u=k}else{CBb(b+1140|0,2262528,k,0)|0;t=0;u=k}while(1){p=a[f+(t+33)|0]|0;if(p<<24>>24==0){v=u;break}if((u-l|0)>>>0>510>>>0){v=u;break}o=u+1|0;a[u]=p;p=t+1|0;if((p|0)<30){t=p;u=o}else{v=o;break}}a[v]=0;if((a[k]|0)==0){w=0;x=k}else{CBb(b+1140|0,2261448,k,0)|0;w=0;x=k}while(1){o=a[f+(w+63)|0]|0;if(o<<24>>24==0){y=x;break}if((x-l|0)>>>0>510>>>0){y=x;break}p=x+1|0;a[x]=o;o=w+1|0;if((o|0)<30){w=o;x=p}else{y=p;break}}a[y]=0;if((a[k]|0)!=0){CBb(b+1140|0,2260232,k,0)|0}p=a[f+93|0]|0;do{if(p<<24>>24==0){z=k}else{o=e+1|0;a[k]=p;s=a[f+94|0]|0;if(s<<24>>24==0){z=o;break}q=e+2|0;a[o]=s;s=a[f+95|0]|0;if(s<<24>>24==0){z=q;break}o=e+3|0;a[q]=s;s=a[f+96|0]|0;if(s<<24>>24==0){z=o;break}a[o]=s;z=e+4|0}}while(0);a[z]=0;if((a[k]|0)==0){A=0;B=k}else{CBb(b+1140|0,2259304,k,0)|0;A=0;B=k}while(1){p=a[f+(A+97)|0]|0;if(p<<24>>24==0){C=B;break}if((B-l|0)>>>0>510>>>0){C=B;break}s=B+1|0;a[B]=p;p=A+1|0;if((p|0)<30){A=p;B=s}else{C=s;break}}a[C]=0;if((a[k]|0)!=0){CBb(b+1140|0,2254928,k,0)|0}do{if((a[f+125|0]|0)==0){l=a[f+126|0]|0;if(l<<24>>24==0){break}Lb(m|0,5,2253184,(s=i,i=i+8|0,c[s>>2]=l&255,s)|0)|0;i=s;CBb(b+1140|0,2252064,m,0)|0}}while(0);m=a[f+127|0]|0;if(!((m&255)>>>0<148>>>0)){break}CBb(b+1140|0,2251016,c[1205192+((m&255)<<2)>>2]|0,0)|0}}while(0);Ty(c[g>>2]|0,h,j,0)|0;i=d;return}function nX(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;c[b>>2]=f;Zy(e,a[g+2|0]<<8|f|a[g+1|0]<<16|d[g]<<24);Py(e,0);Py(e,0);g=Ty(e,0,0,1)|0;f=b+8|0;c[f>>2]=g;c[f+4>>2]=F;Zy(e,0);return}function oX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+144|0;e=d|0;f=d+8|0;g=(c[b>>2]|0)==3?1:3;h=a+16|0;j=pX(c[h>>2]|0,a+1140|0,b,g)|0;if((j|0)<0){k=j;i=d;return k|0}j=a+1132|0;l=e;m=d+16|0;n=a+1136|0;a=b+16|0;o=0;while(1){if(!(o>>>0<(c[j>>2]|0)>>>0)){k=0;p=11;break}q=c[(c[n>>2]|0)+(o<<2)>>2]|0;c[e>>2]=0;c[f>>2]=0;r=Mz(f)|0;do{if((r|0)<0){s=r}else{t=q+16|0;u=q+4|0;v=KDb(c[t>>2]|0,c[t+4>>2]|0,u,15872)|0;t=q+24|0;w=KDb(c[t>>2]|0,c[t+4>>2]|0,u,15872)|0;Lb(m|0,122,2057048,(u=i,i=i+8|0,c[u>>2]=o,u)|0)|0;i=u;u=_y(c[f>>2]|0,m)|0;c[a>>2]=(c[a>>2]|0)+u;Zy(c[f>>2]|0,v);Zy(c[f>>2]|0,w);Zy(c[f>>2]|0,-1);Zy(c[f>>2]|0,-1);w=pX(c[f>>2]|0,q+32|0,b,g)|0;if((w|0)<0){s=w;break}v=Oz(c[f>>2]|0,e)|0;c[a>>2]=(c[a>>2]|0)+26;Zy(c[h>>2]|0,1128808784);Zy(c[h>>2]|0,v);fz(c[h>>2]|0,0);Ry(c[h>>2]|0,c[e>>2]|0,v);s=w}}while(0);q=c[f>>2]|0;do{if((q|0)!=0){if((c[e>>2]|0)!=0){break}Oz(q,e)|0}}while(0);$Db(l);if((s|0)<0){k=s;p=11;break}else{o=o+1|0}}if((p|0)==11){i=d;return k|0}return 0}function pX(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=i;i=i+24|0;j=h|0;QG(e,1205072,0);k=f|0;l=c[k>>2]|0;if((l|0)==3){m=h+8|0;n=h+16|0;c[j>>2]=0;TGb(m|0,0,5)|0;TGb(n|0,0,5)|0;o=BBb(c[e>>2]|0,9203640,0,2)|0;if((o|0)!=0){p=o;do{o=c[p>>2]|0;q=(yAb(o,2010960)|0)==0;r=c[p+4>>2]|0;do{if(q){s=0;while(1){t=r+s|0;u=a[t]|0;v=s+1|0;if((u-48&255)>>>0<10>>>0){s=v}else{break}}if(!((u<<24>>24|0)==0|(u<<24>>24|0)==45)){CBb(j,o,r,0)|0;break}sAb(m,r,5)|0;CBb(j,1971984,m,0)|0;if((a[t]|0)!=45){break}w=r+v|0;if(!(((a[w]|0)-48&255)>>>0<2>>>0)){break}if(!(((a[r+(s+2)|0]|0)-48&255)>>>0<10>>>0)){break}if((a[r+(s+3)|0]|0)!=45){break}x=r+(s+4)|0;if(!(((a[x]|0)-48&255)>>>0<4>>>0)){break}if(!(((a[r+(s+5)|0]|0)-48&255)>>>0<10>>>0)){break}y=a[r+(s+6)|0]|0;if(!((y<<24>>24|0)==0|(y<<24>>24|0)==32)){break}Lb(n|0,5,1943200,(y=i,i=i+16|0,c[y>>2]=x,c[y+8>>2]=w,y)|0)|0;i=y;CBb(j,1918520,n,0)|0}else{CBb(j,o,r,0)|0}}while(0);p=BBb(c[e>>2]|0,9203640,p,2)|0;}while((p|0)!=0)}DBb(e);c[e>>2]=c[j>>2]}else if((l|0)==4){QG(e,1204984,0)}l=BBb(c[e>>2]|0,9203640,0,2)|0;if((l|0)==0){z=0;i=h;return z|0}j=f+16|0;p=l;while(1){l=p|0;n=c[l>>2]|0;a:do{if((a[n]|0)==84){if((SGb(n|0)|0)==4){v=n;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=fe(t|0)|0;m=t&255;t=0;while(1){u=1204376+(t<<2)|0;if((a[u]|0)==0){A=n;B=m;break}r=u;if((v|0)==(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)){C=27;break}else{t=t+1|0}}do{if((C|0)==27){C=0;t=tX(f,b,c[p+4>>2]|0,0,v,g)|0;if((t|0)>0){c[j>>2]=(c[j>>2]|0)+t;break a}else{t=c[l>>2]|0;A=t;B=a[t]|0;break}}}while(0);if(B<<24>>24==84){D=A;E=(c[k>>2]|0)==3?1205040:1204928}else{F=A;C=39;break}}else{D=n;E=(c[k>>2]|0)==3?1205040:1204928}if((SGb(D|0)|0)!=4){F=D;C=39;break}v=D;t=fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;v=0;while(1){m=E+(v<<2)|0;if((a[m]|0)==0){F=D;C=39;break a}s=m;if((t|0)==(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)){break}else{v=v+1|0}}v=tX(f,b,c[p+4>>2]|0,0,t,g)|0;if((v|0)>0){c[j>>2]=(c[j>>2]|0)+v;break}else{F=c[l>>2]|0;C=39;break}}else{F=n;C=39}}while(0);if((C|0)==39){C=0;n=tX(f,b,F,c[p+4>>2]|0,1415075928,g)|0;if((n|0)<0){z=n;C=41;break}c[j>>2]=(c[j>>2]|0)+n}n=BBb(c[e>>2]|0,9203640,p,2)|0;if((n|0)==0){z=0;C=41;break}else{p=n}}if((C|0)==41){i=h;return z|0}return 0}function qX(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=c[(c[b+28>>2]|0)+(c[e+32>>2]<<2)>>2]|0;k=d|0;l=(c[k>>2]|0)==3;m=l?1:3;n=j+8|0;o=1204600;while(1){p=c[o+32>>2]|0;if((p|0)==0){break}if((p|0)==(c[(c[n>>2]|0)+48>>2]|0)){q=4;break}else{o=o+36|0}}do{if((q|0)==4){n=o|0;if((o|0)==0){break}p=j+88|0;r=BBb(c[p>>2]|0,2194616,0,0)|0;s=r+4|0;a:do{if((r|0)==0){t=0}else{u=0;while(1){if(!(u>>>0<21>>>0)){t=0;break a}v=c[1204512+(u<<2)>>2]|0;w=c[s>>2]|0;if((RGb(v,w,SGb(w|0)|0)|0)==0){t=u;break}else{u=u+1|0}}}}while(0);s=BBb(c[p>>2]|0,2116288,0,0)|0;if((s|0)==0){x=9203640}else{x=c[s+4>>2]|0}if(l){s=x;while(1){r=a[s]|0;y=r<<24>>24==0;if(r<<24>>24>-1&(y^1)){s=s+1|0}else{break}}z=y?0:m}else{z=m}if((Mz(g)|0)<0){A=-12;i=f;return A|0}Py(c[g>>2]|0,z);_y(c[g>>2]|0,n)|0;Py(c[g>>2]|0,t);s=c[g>>2]|0;if((z|0)==1){az(s,65279);B=410}else{B=62}Oe[B&1023](s,x)|0;Ry(c[g>>2]|0,c[e+24>>2]|0,c[e+28>>2]|0);s=Oz(c[g>>2]|0,h)|0;p=b+16|0;Zy(c[p>>2]|0,1095780675);r=c[p>>2]|0;if((c[k>>2]|0)==3){Zy(r,s)}else{Py(r,s>>>21&127);Py(r,s>>>14&127);Py(r,s>>>7&127);Py(r,s&127)}fz(c[p>>2]|0,0);Ry(c[p>>2]|0,c[h>>2]|0,s);$Db(h);p=d+16|0;c[p>>2]=s+10+(c[p>>2]|0);A=0;i=f;return A|0}}while(0);yDb(b,16,2336144,(b=i,i=i+8|0,c[b>>2]=c[j>>2],b)|0);i=b;A=-22;i=f;return A|0}function rX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=(d|0)<0?10:d;d=a+16|0;f=268435455-(c[d>>2]|0)|0;if((e|0)<10){g=10}else{g=(e|0)>(f|0)?f:e}Qy(b,0,g);c[d>>2]=(c[d>>2]|0)+g;g=Ty(b,0,0,1)|0;e=F;f=a+8|0;Ty(b,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=c[d>>2]|0;Py(b,f>>>21&127);Py(b,f>>>14&127);Py(b,f>>>7&127);Py(b,f&127);Ty(b,g,e,0)|0;return}function sX(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+24|0;h=g|0;j=h;c[j>>2]=c[301088];c[j+4>>2]=c[301089];c[j+8>>2]=c[301090];c[j+12>>2]=c[301091];c[j+16>>2]=c[301092];c[j+20>>2]=c[301093];j=b+16|0;k=c[j>>2]|0;c[h>>2]=e;Zy(k,a[f+2|0]<<8|e|a[f+1|0]<<16|d[f]<<24);Py(k,0);Py(k,0);f=Ty(k,0,0,1)|0;e=h+8|0;c[e>>2]=f;c[e+4>>2]=F;Zy(k,0);k=oX(b,h)|0;if((k|0)<0){l=k;i=g;return l|0}rX(h,c[j>>2]|0,c[b+1316>>2]|0);l=0;i=g;return l|0}function tX(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=j|0;l=j+8|0;if((Mz(l)|0)<0){m=-12;i=j;return m|0}do{if((h|0)==1){n=e;while(1){o=a[n]|0;p=o<<24>>24==0;if(o<<24>>24>-1&(p^1)){n=n+1|0}else{break}}if(!p){q=1;break}if((f|0)!=0){n=f;while(1){o=a[n]|0;r=o<<24>>24==0;if(o<<24>>24>-1&(r^1)){n=n+1|0}else{break}}if(!r){q=1;break}}q=0}else{q=h}}while(0);Py(c[l>>2]|0,q);h=c[l>>2]|0;r=(q|0)==1;if(r){az(h,65279);s=410}else{s=62}Oe[s&1023](h,e)|0;if((f|0)!=0){e=c[l>>2]|0;if(r){az(e,65279);t=410}else{t=62}Oe[t&1023](e,f)|0}f=Oz(c[l>>2]|0,k)|0;Zy(d,g);if((c[b>>2]|0)==3){Zy(d,f)}else{Py(d,f>>>21&127);Py(d,f>>>14&127);Py(d,f>>>7&127);Py(d,f&127)}fz(d,0);Ry(d,c[k>>2]|0,f);$Db(k);m=f+10|0;i=j;return m|0}function uX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=0;while(1){if((d|0)>=13){e=-1;f=5;break}if((PGb(a,1170996+(d*20|0)|0,16)|0)==0){break}else{d=d+1|0}}if((f|0)==5){return e|0}c[b>>2]=c[1170992+(d*20|0)>>2];e=0;return e|0}function vX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0;d=i;e=b;b=i;i=i+8|0;c[b>>2]=c[e>>2];c[b+4>>2]=c[e+4>>2];e=c[b>>2]|0;f=c[b+4>>2]|0;b=f;g=(f|0)<0|0?-1:0;h=e;j=(e|0)<0|0?-1:0;k=(e|0)==0;l=e>>31;do{if((f|0)==0){if(k){break}m=gHb(b,g,1001,0)|0;n=F;o=gHb(h,j,24e3,0)|0;if((m|0)==(o|0)&(n|0)==(F|0)&(l|0)==0){p=638120;i=d;return p|0}o=gHb(h,j,24,0)|0;if((b|0)==(o|0)&(g|0)==(F|0)&(l|0)==0){p=638152;i=d;return p|0}o=gHb(h,j,3e4,0)|0;if((m|0)==(o|0)&(n|0)==(F|0)&(l|0)==0){p=638184;i=d;return p|0}o=gHb(h,j,6e4,0)|0;if((m|0)==(o|0)&(n|0)==(F|0)&(l|0)==0){p=638216;i=d;return p|0}n=gHb(h,j,25,0)|0;if((b|0)==(n|0)&(g|0)==(F|0)&(l|0)==0){p=638248;i=d;return p|0}n=gHb(h,j,50,0)|0;if((b|0)==(n|0)&(g|0)==(F|0)&(l|0)==0){p=638280}else{break}i=d;return p|0}else{n=gHb(b,g,1001,0)|0;o=F;m=gHb(h,j,24e3,0)|0;q=(n|0)==(m|0)&(o|0)==(F|0);if(k){if(q){p=638120;i=d;return p|0}m=gHb(h,j,24,0)|0;if((b|0)==(m|0)&(g|0)==(F|0)){p=638152;i=d;return p|0}m=gHb(h,j,3e4,0)|0;if((n|0)==(m|0)&(o|0)==(F|0)){p=638184;i=d;return p|0}m=gHb(h,j,6e4,0)|0;if((n|0)==(m|0)&(o|0)==(F|0)){p=638216;i=d;return p|0}m=gHb(h,j,25,0)|0;if((b|0)==(m|0)&(g|0)==(F|0)){p=638248;i=d;return p|0}m=gHb(h,j,50,0)|0;if((b|0)==(m|0)&(g|0)==(F|0)){p=638280}else{break}i=d;return p|0}else{if(q){p=638120;i=d;return p|0}q=gHb(h,j,24,0)|0;if((b|0)==(q|0)&(g|0)==(F|0)){p=638152;i=d;return p|0}q=gHb(h,j,3e4,0)|0;if((n|0)==(q|0)&(o|0)==(F|0)){p=638184;i=d;return p|0}q=gHb(h,j,6e4,0)|0;if((n|0)==(q|0)&(o|0)==(F|0)){p=638216;i=d;return p|0}o=gHb(h,j,25,0)|0;if((b|0)==(o|0)&(g|0)==(F|0)){p=638248;i=d;return p|0}o=gHb(h,j,50,0)|0;if((b|0)==(o|0)&(g|0)==(F|0)){p=638280}else{break}i=d;return p|0}}}while(0);r=+(e|0)/+(f|0);g=0;while(1){if(!(g>>>0<6>>>0)){p=0;s=14;break}t=638120+(g<<5)|0;u=c[t>>2]|0;v=c[638124+(g<<5)>>2]|0;if(+Q(+(+(u|0)/+(v|0)-r))<1.0e-4){break}else{g=g+1|0}}if((s|0)==14){i=d;return p|0}yDb(a,24,2342480,(a=i,i=i+32|0,c[a>>2]=e,c[a+8>>2]=f,c[a+16>>2]=u,c[a+24>>2]=v,a)|0);i=a;p=t;i=d;return p|0}function wX(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b;b=i;i=i+8|0;c[b>>2]=c[g>>2];c[b+4>>2]=c[g+4>>2];g=c[(c[a>>2]|0)+24>>2]|0;if((g|0)==0){i=f;return}h=c[b>>2]|0;j=h;k=(h|0)<0|0?-1:0;h=c[a+3728>>2]|0;a=c[b+4>>2]|0;b=a;l=(a|0)<0|0?-1:0;a=0;do{m=c[h+(a*40|0)+20>>2]|0;n=c[m+4>>2]|0;o=gHb(n,(n|0)<0|0?-1:0,j,k)|0;n=F;p=c[m>>2]|0;m=gHb(p,(p|0)<0|0?-1:0,b,l)|0;p=HDb(d,e,o,n,m,F,2)|0;m=h+(a*40|0)+8|0;c[m>>2]=p;c[m+4>>2]=F;a=a+1|0;}while(a>>>0<g>>>0);i=f;return}function xX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=_Gb(1,0,c[a+24>>2]|0)|0;f=YGb(e,F,-1,-1)|0;e=F;g=a+8|0;a=c[g>>2]|0;h=c[g+4>>2]|0;g=eHb(f,e,2,0)|0;i=ZGb(a,h,g,F)|0;g=F;h=ZGb(b,d,i,g)|0;d=YGb(h&f,F&e,i,g)|0;return(F=F,d)|0}function yX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a|0;a=c[d>>2]|0;e=c[d+4>>2]|0;d=b|0;b=c[d>>2]|0;f=c[d+4>>2]|0;ZGb(a,e,b,f)|0;d=F;ZGb(b,f,a,e)|0;e=ZGb(d,0,F,0)|0;return e|0}function zX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+16|0;a=c[d>>2]|0;e=c[d+4>>2]|0;d=b+16|0;b=c[d>>2]|0;f=c[d+4>>2]|0;ZGb(a,e,b,f)|0;d=F;ZGb(b,f,a,e)|0;e=ZGb(d,0,F,0)|0;return e|0}function AX(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=cEb(24)|0;c[k>>2]=m;n=eGb()|0;c[l>>2]=n;if((m|0)==0|(n|0)==0){$Db(k);$Db(l);o=-12;i=j;return o|0}n=a+3764|0;c[n>>2]=(c[n>>2]|0)+1;n=m;c[n>>2]=b;c[n+4>>2]=d;d=m+8|0;c[d>>2]=e;c[d+4>>2]=f;f=m+16|0;c[f>>2]=g;c[f+4>>2]=h;gGb(a+3760|0,m,618,l)|0;if((c[l>>2]|0)==0){o=0;i=j;return o|0}ZDb(c[k>>2]|0);ZDb(c[l>>2]|0);o=0;i=j;return o|0}function BX(a){a=a|0;var b=0;b=a+3760|0;iGb(c[b>>2]|0,0,0,816);hGb(c[b>>2]|0);return}function CX(a,b){a=a|0;b=b|0;ZDb(b);return 0}function DX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=i;i=i+8|0;f=e|0;g=(a|0)!=0;a:do{if(g){h=a+8|0;j=c[h>>2]|0;if((j|0)==0){k=b+48|0;l=b+412|0;m=b+416|0;n=b+8|0}else{do{if((c[j+36>>2]|0)!=0){o=c[a+12>>2]|0;if((o|0)==0){break}p=(zEb(o,2341464,0,f)|0)>-1;o=c[f>>2]|0;q=c[f+4>>2]|0;r=-1;if(!(p&((q|0)>(r|0)|(q|0)==(r|0)&o>>>0>-1>>>0))){break}s=o;i=e;return s|0}}while(0);j=b+48|0;o=b+412|0;r=b+416|0;q=b+8|0;if(g){k=j;l=o;m=r;n=q}else{t=j;u=o;v=r;w=q;x=4;break}}q=a+12|0;r=0;o=545824;while(1){j=c[545840+(r*28|0)>>2]|0;do{if((j|0)==(c[k>>2]|0)){if((r|0)==25){p=c[h>>2]|0;if((p|0)==0){y=n;x=42;break a}if((c[p+36>>2]|0)==0){y=n;x=42;break a}p=c[q>>2]|0;if((p|0)==0){y=n;x=42;break a}if((AEb(p,2336e3,2194552)|0)==0){y=n;x=42;break a}z=c[k>>2]|0}else{z=j}do{if((z|0)==69660){if((c[l>>2]|0)!=16e3){break}if((c[m>>2]|0)==1){A=o;x=34;break a}}}while(0);if((c[n>>2]|0)!=1){B=o;x=40;break a}if((67096575>>>(r>>>0)&1|0)!=0){if((c[l>>2]|0)!=(c[545844+(r*28|0)>>2]|0)){break}}if((249855>>>(r>>>0)&1|0)==0){B=o;x=40;break a}if((c[m>>2]|0)==(c[545848+(r*28|0)>>2]|0)){B=o;x=40;break a}}}while(0);j=r+1|0;if((j|0)==26){y=n;x=42;break a}r=j;o=545824+(j*28|0)|0}}else{t=b+48|0;u=b+412|0;v=b+416|0;w=b+8|0;x=4}}while(0);b:do{if((x|0)==4){b=c[t>>2]|0;n=0;m=545824;l=b;while(1){do{if((c[545840+(n*28|0)>>2]|0)==(l|0)){if((l|0)==5){C=5;break}do{if((b|0)==69660){if((c[u>>2]|0)!=16e3){break}if((c[v>>2]|0)==1){A=m;x=34;break b}}}while(0);if((c[w>>2]|0)!=1){B=m;x=40;break b}if((67096575>>>(n>>>0)&1|0)!=0){if((c[u>>2]|0)!=(c[545844+(n*28|0)>>2]|0)){C=b;break}}if((249855>>>(n>>>0)&1|0)==0){B=m;x=40;break b}if((c[v>>2]|0)==(c[545848+(n*28|0)>>2]|0)){B=m;x=40;break b}else{C=b}}else{C=l}}while(0);z=n+1|0;if((z|0)==26){y=w;x=42;break}else{n=z;m=545824+(z*28|0)|0;l=C}}}}while(0);if((x|0)==34){s=c[A>>2]|0;i=e;return s|0}else if((x|0)==40){s=c[B>>2]|0;i=e;return s|0}else if((x|0)==42){if((d|0)<0){D=(c[y>>2]|0)==1|0}else{D=d}s=D+96|0;i=e;return s|0}return 0}function EX(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)<8){e=0}else{f=0;g=8;while(1){b[a+(f<<1)>>1]=de(b[c+(f<<1)>>1]|0)|0;h=f|1;b[a+(h<<1)>>1]=de(b[c+(h<<1)>>1]|0)|0;h=f|2;b[a+(h<<1)>>1]=de(b[c+(h<<1)>>1]|0)|0;h=f|3;b[a+(h<<1)>>1]=de(b[c+(h<<1)>>1]|0)|0;h=f|4;b[a+(h<<1)>>1]=de(b[c+(h<<1)>>1]|0)|0;h=f|5;b[a+(h<<1)>>1]=de(b[c+(h<<1)>>1]|0)|0;h=f|6;b[a+(h<<1)>>1]=de(b[c+(h<<1)>>1]|0)|0;h=f|7;b[a+(h<<1)>>1]=de(b[c+(h<<1)>>1]|0)|0;h=g+8|0;if((h|0)>(d|0)){e=g;break}else{f=g;g=h}}}if((e|0)<(d|0)){i=e}else{return}do{b[a+(i<<1)>>1]=de(b[c+(i<<1)>>1]|0)|0;i=i+1|0;}while((i|0)<(d|0));return}function FX(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=b+8|0;g=c[f>>2]|0;h=c[b+16>>2]|0;i=c[b>>2]|0;b=i+(g>>>3)|0;j=(fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(g&7);b=g+12|0;g=h>>>0>b>>>0?b:h;c[f>>2]=g;if(!((j&-1048576|0)==-1048576)){k=-16976906;return k|0}j=g+1|0;g=(h>>>0>j>>>0?j:h)+2|0;j=h>>>0>g>>>0?g:h;c[f>>2]=j;g=(d[i+(j>>>3)|0]|0)<<(j&7)>>>7;b=((j|0)<(h|0))+j|0;c[f>>2]=b;j=i+(b>>>3)|0;l=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(b&7)>>>30;j=b+2|0;b=h>>>0>j>>>0?j:h;c[f>>2]=b;j=i+(b>>>3)|0;m=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(b&7)>>>28;j=b+4|0;b=h>>>0>j>>>0?j:h;c[f>>2]=b;j=c[1743568+(m<<2)>>2]|0;if((j|0)==0){k=-50531338;return k|0}n=b+1|0;b=h>>>0>n>>>0?n:h;c[f>>2]=b;n=i+(b>>>3)|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+3|0;p=(h>>>0>n>>>0?n:h)+1|0;n=(h>>>0>p>>>0?p:h)+1|0;p=(h>>>0>n>>>0?n:h)+1|0;n=(h>>>0>p>>>0?p:h)+1|0;p=h>>>0>n>>>0?n:h;c[f>>2]=p;n=i+(p>>>3)|0;q=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(p&7);n=q>>>19;r=p+13|0;p=h>>>0>r>>>0?r:h;c[f>>2]=p;if(q>>>0<3670016>>>0){k=-67308554;return k|0}q=(fe(o|0)|0)<<(b&7)>>>29;b=p+11|0;p=h>>>0>b>>>0?b:h;c[f>>2]=p;b=i+(p>>>3)|0;i=(fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(p&7)>>>30;b=p+2|0;c[f>>2]=h>>>0>b>>>0?b:h;a[e+13|0]=l+1;a[e+15|0]=q;a[e+12|0]=g&1;g=i+1|0;a[e+16|0]=g;a[e+14|0]=m;c[e>>2]=j;m=g<<10;c[e+4>>2]=m;c[e+8>>2]=((ba(n<<3,j)|0)>>>0)/(m>>>0)|0;k=n;return k|0}function GX(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[g>>2]|0;do{if((h|0)==0){i=cEb(64)|0;j=i;c[g>>2]=j;if((i|0)==0){k=-12}else{l=j;break}return k|0}else{l=h}}while(0);TGb(l|0,0,64)|0;h=f+8|0;g=c[h>>2]|0;j=f+16|0;i=c[j>>2]|0;m=f|0;f=(c[m>>2]|0)+(g>>>3)|0;n=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(g&7)>>>16;f=g+16|0;c[h>>2]=i>>>0>f>>>0?f:i;b[l>>1]=n;if((n|0)!=2935){k=-16976906;return k|0}n=c[j>>2]|0;i=(c[h>>2]|0)+16|0;f=n>>>0>i>>>0?i:n;n=(c[m>>2]|0)+(f>>>3)|0;i=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(f&7)>>>19&31;f=l+5|0;a[f]=i;if((i&255)>>>0>16>>>0){k=-33754122;return k|0}n=l+28|0;c[n>>2]=6;g=l+16|0;c[g>>2]=5;o=l+20|0;c[o>>2]=6;p=l+56|0;c[p>>2]=0;if((i&255)>>>0<11>>>0){i=c[h>>2]|0;q=c[j>>2]|0;r=c[m>>2]|0;s=r+(i>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(i&7)>>>16;s=i+16|0;i=q>>>0>s>>>0?s:q;c[h>>2]=i;b[l+2>>1]=t;t=r+(i>>>3)|0;r=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(i&7)>>>30;t=i+2|0;c[h>>2]=q>>>0>t>>>0?t:q;q=l+4|0;a[q]=r;if((r|0)==3){k=-50531338;return k|0}r=c[h>>2]|0;t=c[j>>2]|0;i=c[m>>2]|0;s=i+(r>>>3)|0;u=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7);s=u>>>26;v=r+6|0;r=t>>>0>v>>>0?v:t;c[h>>2]=r;if(u>>>0>2550136831>>>0){k=-67308554;return k|0}v=r+5|0;r=t>>>0>v>>>0?v:t;c[h>>2]=r;v=i+(r>>>3)|0;i=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(r&7)>>>29;v=r+3|0;c[h>>2]=t>>>0>v>>>0?v:t;a[l+6|0]=i;i=c[h>>2]|0;t=c[j>>2]|0;v=(c[m>>2]|0)+(i>>>3)|0;r=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(i&7)>>>29;v=i+3|0;c[h>>2]=t>>>0>v>>>0?v:t;t=r&255;v=l+7|0;a[v]=t;do{if((r|0)==2){i=c[h>>2]|0;w=c[j>>2]|0;x=(c[m>>2]|0)+(i>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(i&7)>>>30;x=i+2|0;c[h>>2]=w>>>0>x>>>0?x:w;c[p>>2]=y}else{if((r&1|0)==0|(r|0)==1){z=t}else{y=c[h>>2]|0;w=c[j>>2]|0;x=(c[m>>2]|0)+(y>>>3)|0;i=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7)>>>30;x=y+2|0;c[h>>2]=w>>>0>x>>>0?x:w;c[g>>2]=d[1500312+i|0]|0;z=a[v]|0}if((z&4)==0){break}i=c[h>>2]|0;w=c[j>>2]|0;x=(c[m>>2]|0)+(i>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(i&7)>>>30;x=i+2|0;c[h>>2]=w>>>0>x>>>0?x:w;c[o>>2]=d[429256+y|0]|0}}while(0);o=c[h>>2]|0;z=(d[(c[m>>2]|0)+(o>>>3)|0]|0)<<(o&7)>>>7;c[h>>2]=((o|0)<(c[j>>2]|0))+o;o=z&1;a[l+8|0]=o;z=a[f]|0;f=(z&255)>>>0>8>>>0?z-8&255:0;a[l+32|0]=f;z=d[q]|0;q=f&255;b[l+34>>1]=(e[1274880+(z<<1)>>1]|0)>>>(q>>>0);c[l+36>>2]=((e[1276624+(u>>>27<<1)>>1]|0)*1e3|0)>>>(q>>>0);q=a[v]|0;a[l+40|0]=o+(a[1276464+(q&255)|0]|0);b[l+42>>1]=b[1275600+(s*6|0)+(z<<1)>>1]<<1;a[l+9|0]=2;c[l+12>>2]=0;A=q;B=o}else{b[l+2>>1]=0;o=c[h>>2]|0;q=c[j>>2]|0;z=(c[m>>2]|0)+(o>>>3)|0;s=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(o&7)>>>30;z=o+2|0;c[h>>2]=q>>>0>z>>>0?z:q;a[l+9|0]=s;if((s|0)==3){k=-84085770;return k|0}s=c[h>>2]|0;q=c[j>>2]|0;z=c[m>>2]|0;o=z+(s>>>3)|0;v=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(s&7)>>>29;o=s+3|0;c[h>>2]=q>>>0>o>>>0?o:q;c[l+12>>2]=v;v=c[h>>2]|0;q=c[j>>2]|0;o=z+(v>>>3)|0;z=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(v&7)>>>21;o=v+11|0;c[h>>2]=q>>>0>o>>>0?o:q;q=(z<<1)+2|0;b[l+42>>1]=q;if((q&65534)>>>0<7>>>0){k=-67308554;return k|0}z=c[h>>2]|0;o=c[j>>2]|0;v=(c[m>>2]|0)+(z>>>3)|0;s=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(z&7)>>>30;v=z+2|0;c[h>>2]=o>>>0>v>>>0?v:o;o=l+4|0;a[o]=s;v=c[h>>2]|0;z=c[j>>2]|0;u=(c[m>>2]|0)+(v>>>3)|0;f=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(v&7)>>>30;u=v+2|0;c[h>>2]=z>>>0>u>>>0?u:z;do{if((s|0)==3){if((f|0)==3){k=-50531338;return k|0}else{z=(e[1274880+(f<<1)>>1]|0)>>>1;b[l+34>>1]=z;a[l+32|0]=1;C=z;break}}else{c[n>>2]=d[1344848+f|0]|0;z=b[1274880+((d[o]|0)<<1)>>1]|0;b[l+34>>1]=z;a[l+32|0]=0;C=z}}while(0);o=c[h>>2]|0;f=c[j>>2]|0;s=(c[m>>2]|0)+(o>>>3)|0;z=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(o&7)>>>29;s=o+3|0;c[h>>2]=f>>>0>s>>>0?s:f;f=l+7|0;a[f]=z;z=c[h>>2]|0;s=(d[(c[m>>2]|0)+(z>>>3)|0]|0)<<(z&7)>>>7;c[h>>2]=((z|0)<(c[j>>2]|0))+z;z=s&1;a[l+8|0]=z;c[l+36>>2]=~~(+(q&65534|0)*8.0*+(C&65535|0)/(+(c[n>>2]|0)*256.0));n=a[f]|0;a[l+40|0]=z+(a[1276464+(n&255)|0]|0);A=n;B=z}z=e[1746384+((A&255)<<1)>>1]|0;A=0;n=l+48|0;c[n>>2]=z;c[n+4>>2]=A;if(B<<24>>24==0){k=0;return k|0}c[n>>2]=z|8;c[n+4>>2]=A;k=0;return k|0}function HX(a){a=a|0;var b=0;b=c[a>>2]|0;c[b+44>>2]=7;c[b+48>>2]=138;return 0}function IX(b,f,g,h,j){b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;i=i+104|0;l=k|0;m=k+8|0;n=k+72|0;o=k+80|0;p=l|0;q=fe(b|0)|0;c[p>>2]=fe(f|0)|0;c[p+4>>2]=q;c[n>>2]=m;q=l+8|0;c[o>>2]=q-7;c[o+12>>2]=54;c[o+16>>2]=62;c[o+4>>2]=q;c[o+8>>2]=0;if((GX(o,n)|0)<0){r=0;i=k;return r|0}c[g+56>>2]=e[m+34>>1]|0;c[g+60>>2]=c[m+36>>2];n=a[m+40|0]|0;c[g+52>>2]=n&255;o=m+48|0;q=c[o+4>>2]|0;l=g+72|0;c[l>>2]=c[o>>2];c[l+4>>2]=q;c[g+64>>2]=c[m+28>>2]<<8;q=a[m+6|0]|0;if(q<<24>>24==7&(n&255)>>>0>1>>>0){s=8}else{s=q&255}c[g+80>>2]=s;s=g+100|0;do{if((d[m+5|0]|0)>>>0>10>>>0){c[s>>2]=86057}else{if((c[s>>2]|0)!=0){break}c[s>>2]=86019}}while(0);s=a[m+9|0]|0;c[h>>2]=s<<24>>24!=2;c[j>>2]=s<<24>>24!=1;r=e[m+42>>1]|0;i=k;return r|0}function JX(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0.0,g=0.0;f=1.4142135623730951- +T(+(a|0)*6.283185307179586/+(b|0));g=(f- +R((f+.41421356237309515)*(f+-.41421356237309515)))/.41421356237309515;f=+(1<<d|0);c[e>>2]=Gc(+(f*g*2.0))|0;c[e+4>>2]=Gc(+(f*(-0.0-g*g)))|0;return}function KX(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0;j=i;if((f|0)<24){k=-1094995529;i=j;return k|0}l=e;if(!((d[l]|d[l+1|0]<<8)<<16>>16<<16>>16==128)){k=-1094995529;i=j;return k|0}l=e+2|0;m=(de((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&65535;l=m+4|0;do{if((l|0)<=(f|0)&l>>>0>5>>>0){if((PGb(e+(m-2)|0,2340280,6)|0)==0){break}else{k=-1094995529}i=j;return k|0}}while(0);do{if((a[e+4|0]|0)==3){if((a[e+5|0]|0)!=18){break}if((a[e+6|0]|0)!=4){break}m=a[e+7|0]|0;f=m&255;c[b+416>>2]=f;if(m<<24>>24==0|(m&255)>>>0>2>>>0){k=-1094995529;i=j;return k|0}m=e+8|0;n=fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;c[b+412>>2]=n;if((n|0)<1){k=-1094995529;i=j;return k|0}if((n|0)>(2147483647/((f*144|0)>>>0)|0|0)){k=-1094995529;i=j;return k|0}c[b+72>>2]=(ba(n*144|0,f)|0)/32|0;if((h|0)!=0){f=e+16|0;o=1.4142135623730951- +T(+((de((d[f]|d[f+1|0]<<8)<<16>>16|0)|0)&65535|0)*6.283185307179586/+(n|0));p=(o- +R((o+.41421356237309515)*(o+-.41421356237309515)))/.41421356237309515;c[h>>2]=Gc(+(p*2.0*4096.0))|0;c[h+4>>2]=Gc(+(p*p*-4096.0))|0}c[g>>2]=l;k=0;i=j;return k|0}}while(0);DDb(b,2335840,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;k=-1163346256;i=j;return k|0}function LX(){if(a[1759360]|0){return}a[1759360]=1;T$a(1286216);T$a(1286320);T$a(1276784);T$a(1265784);T$a(1264296);T$a(1264400);T$a(1264192);T$a(1264008);T$a(1261680);T$a(1261784);T$a(1261472);T$a(1261576);T$a(1259808);T$a(1259912);T$a(1258936);T$a(1259040);T$a(1259144);T$a(1258832);T$a(1258432);T$a(1258536);T$a(1258224);T$a(1258328);T$a(1257872);T$a(1257688);T$a(1257504);T$a(1256656);T$a(1256760);T$a(1256368);T$a(1256184);T$a(1255952);T$a(1255600);T$a(1244432);T$a(1244328);T$a(1243936);T$a(1244040);T$a(1243728);T$a(1243832);T$a(1243624);T$a(1237856);T$a(1237960);T$a(1237424);T$a(1234928);T$a(1234824);T$a(1234048);T$a(1233808);T$a(1230848);T$a(1231032);T$a(1230552);T$a(1230656);T$a(1230264);T$a(1225520);T$a(1225624);T$a(1225408);T$a(1225224);T$a(1223712);T$a(1223608);T$a(1223504);T$a(1223400);T$a(1223296);T$a(1222936);T$a(1222832);T$a(1222728);T$a(1222480);T$a(1222376);T$a(1222168);T$a(1221440);T$a(1221544);T$a(1221232);T$a(1221336);T$a(1221024);T$a(1219264);T$a(1219368);T$a(1219472);T$a(1220088);T$a(1219160);T$a(1218792);T$a(1218976);T$a(1218520);T$a(1218160);T$a(1217976);T$a(1217872);T$a(1214344);T$a(1214528);T$a(1211688);T$a(1211872);T$a(1210856);T$a(1211048);T$a(1210032);T$a(1209824);T$a(1209928);T$a(1207680);T$a(1207272);T$a(1206344);T$a(1206056);T$a(1206160);T$a(1204248);T$a(1203880);T$a(1203696);T$a(1202984);T$a(1202880);T$a(1202776);T$a(1202672);T$a(1200712);T$a(1193536);T$a(1193640);T$a(1193328);T$a(1193432);T$a(1193224);T$a(1193040);T$a(1192936);T$a(1192832);T$a(1192560);T$a(1192296);T$a(1190848);T$a(1188304);T$a(1188016);T$a(1188200);T$a(1187824);T$a(1184352);T$a(1184184);T$a(1178656);T$a(1178760);T$a(1177536);T$a(1177640);T$a(1176760);T$a(1177152);T$a(1175352);T$a(1174336);T$a(1173968);T$a(1173760);T$a(1173864);T$a(1173552);T$a(1173656);T$a(1173368);T$a(1173264);T$a(1173160);T$a(1172952);T$a(1173056);T$a(1172848);T$a(1172744);T$a(1172392);T$a(1172288);T$a(1170808);T$a(1167776);T$a(1166488);T$a(1166280);T$a(1166384);T$a(1166072);T$a(1166176);T$a(1156680);T$a(1156784);T$a(1156472);T$a(1156576);T$a(1156264);T$a(1156368);T$a(1156056);T$a(1155576);T$a(1155680);T$a(1155160);T$a(1155264);T$a(1154832);T$a(1154936);T$a(1155048);T$a(1154664);T$a(1154544);T$a(1154272);T$a(1153720);T$a(1153616);T$a(1152576);T$a(1152680);T$a(1152112);T$a(1152216);T$a(1151904);T$a(1152008);T$a(1149568);T$a(1149752);T$a(1148648);T$a(1146040);T$a(1146432);T$a(1145768);T$a(1145224);T$a(1145328);T$a(1145016);T$a(1145120);T$a(1144912);T$a(1144808);T$a(1144216);T$a(1144320);T$a(1143928);T$a(1138720);T$a(1138824);T$a(1138616);T$a(1137864);T$a(1137680);T$a(1137240);T$a(1137032);T$a(1137136);T$a(1136264);T$a(1134080);T$a(1134184);T$a(1133864);T$a(1133968);T$a(1130416);T$a(1124616);T$a(1124720);T$a(1124512);T$a(1123920);T$a(1123816);T$a(1123552);T$a(1123032);T$a(1123280);T$a(1110696);T$a(1110192);T$a(1110088);T$a(1109776);T$a(1109880);T$a(1108984);T$a(1108288);T$a(1107952);T$a(1108056);T$a(1107744);T$a(1107848);T$a(1107640);T$a(1107408);T$a(1107512);T$a(1107200);T$a(1107304);T$a(1106992);T$a(1107096);T$a(1106888);T$a(1106784);T$a(1098880);T$a(1094304);T$a(1094032);T$a(1089376);T$a(1089272);T$a(1087344);T$a(1085448);T$a(1085344);T$a(1085240);T$a(1085136);T$a(1084976);T$a(1084872);T$a(1084584);T$a(1082808);T$a(1080752);T$a(1080856);T$a(1080208);T$a(1080312);T$a(1079928);T$a(1079824);T$a(1079720);T$a(1078816);T$a(1078712);T$a(1078320);T$a(1078424);T$a(1078112);T$a(1078216);T$a(1077784);T$a(1077288);T$a(1077392);T$a(1077e3);T$a(1077104);T$a(1076896);T$a(1076480);T$a(1076584);T$a(1076208);T$a(1076104);T$a(1075768);T$a(1075872);T$a(1075560);T$a(1075664);T$a(1278040);T$a(1285904);T$a(1277936);T$a(1275976);T$a(1276256);T$a(1275848);T$a(1265112);T$a(1265216);T$a(1265008);T$a(1264608);T$a(1264504);T$a(1263824);T$a(1261072);T$a(1260968);T$a(1260864);T$a(1257320);T$a(1257216);T$a(1256552);T$a(1237672);T$a(1234232);T$a(1234336);T$a(1230368);T$a(1224680);T$a(1224912);T$a(1222272);T$a(1221128);T$a(1220392);T$a(1220576);T$a(1217248);T$a(1217432);T$a(1217056);T$a(1213496);T$a(1212280);T$a(1205952);T$a(1203088);T$a(1191512);T$a(1191408);T$a(1190680);T$a(1185288);T$a(1183672);T$a(1183568);T$a(1183360);T$a(1183464);T$a(1183064);T$a(1183168);T$a(1182960);T$a(1182480);T$a(1182688);T$a(1182584);T$a(1182376);T$a(1182272);T$a(1180600);T$a(1180496);T$a(1169792);T$a(1169896);T$a(1166672);T$a(1154008);T$a(1153824);T$a(1151616);T$a(1151720);T$a(1151512);T$a(1151408);T$a(1138512);T$a(1138120);T$a(1137968);T$a(1136640);T$a(1136744);T$a(1136536);T$a(1124952);T$a(1110464);T$a(1109984);T$a(1109488);T$a(1109672);T$a(1109128);T$a(1089480);T$a(1088544);T$a(1088648);T$a(1083080);T$a(1083184);T$a(1081616);T$a(1081512);T$a(1081304);T$a(1081408);T$a(1081096);T$a(1081200);T$a(1080992);T$a(1079616);T$a(1165784);T$a(1165968);T$a(1165592);T$a(1165488);T$a(1165200);T$a(1165384);T$a(1164824);T$a(1165008);T$a(1164448);T$a(1164632);T$a(1164072);T$a(1164256);T$a(1163880);T$a(1163592);T$a(1163776);T$a(1159920);T$a(1160104);T$a(1159624);T$a(1159728);T$a(1163216);T$a(1163400);T$a(1162920);T$a(1163024);T$a(1162632);T$a(1162816);T$a(1162336);T$a(1162440);T$a(1162048);T$a(1162232);T$a(1161752);T$a(1161856);T$a(1161464);T$a(1161648);T$a(1161168);T$a(1161272);T$a(1160880);T$a(1161064);T$a(1160504);T$a(1160688);T$a(1160208);T$a(1160312);T$a(1157080);T$a(1157264);T$a(1159336);T$a(1159520);T$a(1158960);T$a(1159144);T$a(1158584);T$a(1158768);T$a(1158208);T$a(1158392);T$a(1157832);T$a(1158016);T$a(1157456);T$a(1157640);T$a(1156888);T$a(1200816);T$a(1146144);T$a(1146248);T$a(1136848);T$a(1078920);T$a(1273776);T$a(1273520);T$a(1273624);T$a(1273352);T$a(1273248);T$a(1273144);T$a(1273040);T$a(1272936);T$a(1272832);T$a(1272728);T$a(1272624);T$a(1272520);T$a(1272312);T$a(1272416);T$a(1272104);T$a(1272208);T$a(1272e3);T$a(1271896);T$a(1271792);T$a(1271672);T$a(1271568);T$a(1271464);T$a(1271360);T$a(1271256);T$a(1271152);T$a(1270944);T$a(1271048);T$a(1270840);T$a(1270736);T$a(1270528);T$a(1270632);T$a(1270424);T$a(1270184);T$a(1270288);T$a(1269976);T$a(1269872);T$a(1269768);T$a(1269376);T$a(1269480);T$a(1269272);T$a(1269168);T$a(1268944);T$a(1269064);T$a(1089744);T$a(1135064);T$a(1135168);T$a(1262144);T$a(1262328);T$a(1225936);T$a(1226040);T$a(1225728);T$a(1225832);T$a(1193912);T$a(1188576);T$a(1183776);T$a(1183880);T$a(1175080);T$a(1156160);T$a(1155944);T$a(1149280);T$a(1144112);T$a(1135360);T$a(1135544);T$a(1134656);T$a(1134760);T$a(1134368);T$a(1134552);T$a(1124240);T$a(1084768);T$a(1082704);T$a(1077496);T$a(1077600);T$a(1257112);T$a(1078608);T$a(1204064);QRa(1277792);QRa(1277888);QRa(1274896);QRa(1234184);QRa(1233568);QRa(1220256);QRa(1210520);QRa(1184704);QRa(1175840);QRa(1175784);QRa(1124824);return}function MX(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;b=i;i=i+48|0;e=b|0;f=c[a+60>>2]|0;g=f;c[g>>2]=a;h=c[a+96>>2]|0;if((h|0)==0){yDb(a,16,2275208,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}l=c[a+100>>2]|0;m=l<<3;n=l>>>0>268435455>>>0?-8:m;l=n>>>0>2147483639>>>0;o=l?0:h;p=l?0:n;n=p+8|0;a:do{if(l){q=-1094995529;r=33}else{s=QMa(e,h,m,1)|0;if((s|0)<0){q=-1094995529;r=33;break}t=(n|0)<(s|0)?n:s;if((p-t|0)<240){q=-1094995529;r=33;break}s=o+(t>>>3)|0;u=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(t&7)&-65536;s=t+16|0;t=n>>>0>s>>>0?s:n;s=o+(t>>>3)|0;v=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(t&7)>>>16;s=t+16|0;t=n>>>0>s>>>0?s:n;s=a+412|0;c[s>>2]=c[e+8>>2];w=-t|0;x=n-t|0;if((w|0)>32){y=w}else{y=(x|0)<32?x:32}x=y+t|0;t=o+(x>>>3)|0;w=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(x&7)&-65536;t=x+16|0;x=n>>>0>t>>>0?t:n;t=o+(x>>>3)|0;z=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(x&7)>>>16;t=x+16|0;c[f+4>>2]=z|w;w=a+416|0;c[w>>2]=c[e+36>>2];z=(n>>>0>t>>>0?t:n)+16|0;t=(n>>>0>z>>>0?z:n)+3|0;z=n>>>0>t>>>0?t:n;t=o+(z>>>3)|0;x=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(z&7)>>>29;t=z+3|0;z=n>>>0>t>>>0?t:n;t=f+8|0;c[t>>2]=x;x=((z|0)<(n|0))+z|0;A=f+12|0;c[A>>2]=(d[o+(z>>>3)|0]|0)<<(z&7)>>>7&1;z=((x|0)<(n|0))+x|0;B=f+16|0;c[B>>2]=(d[o+(x>>>3)|0]|0)<<(x&7)>>>7&1;x=o+(z>>>3)|0;C=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7)>>>16;x=z+16|0;z=n>>>0>x>>>0?x:n;x=C+1|0;C=f+20|0;c[C>>2]=x;D=o+(z>>>3)|0;E=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(z&7)>>>24;D=z+8|0;z=n>>>0>D>>>0?D:n;c[f+24>>2]=E;E=o+(z>>>3)|0;D=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(z&7)>>>30;E=z+2|0;z=n>>>0>E>>>0?E:n;c[f+28>>2]=D;D=((z|0)<(n|0))+z|0;c[f+32>>2]=(d[o+(z>>>3)|0]|0)<<(z&7)>>>7&1;z=o+(D>>>3)|0;E=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(D&7)>>>30;z=D+2|0;D=n>>>0>z>>>0?z:n;c[f+36>>2]=E;E=((D|0)<(n|0))+D|0;c[f+40>>2]=(d[o+(D>>>3)|0]|0)<<(D&7)>>>7&1;D=o+(E>>>3)|0;z=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7)>>>22;D=E+10|0;E=n>>>0>D>>>0?D:n;D=f+44|0;c[D>>2]=z;z=o+(E>>>3)|0;G=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(E&7)>>>30;z=E+2|0;E=n>>>0>z>>>0?z:n;c[f+48>>2]=G;G=((E|0)<(n|0))+E|0;z=f+52|0;c[z>>2]=(d[o+(E>>>3)|0]|0)<<(E&7)>>>7&1;E=((G|0)<(n|0))+G|0;c[f+56>>2]=(d[o+(G>>>3)|0]|0)<<(G&7)>>>7&1;G=((E|0)<(n|0))+E|0;c[f+60>>2]=(d[o+(E>>>3)|0]|0)<<(E&7)>>>7&1;E=((G|0)<(n|0))+G|0;H=f+64|0;c[H>>2]=(d[o+(G>>>3)|0]|0)<<(G&7)>>>7&1;G=((E|0)<(n|0))+E|0;I=(d[o+(E>>>3)|0]|0)<<(E&7)>>>7&1;c[f+68>>2]=I;E=((G|0)<(n|0))+G|0;J=(d[o+(G>>>3)|0]|0)<<(G&7)>>>7&1;c[f+72>>2]=J;G=((E|0)<(n|0))+E|0;K=f+88|0;c[K>>2]=(d[o+(E>>>3)|0]|0)<<(E&7)>>>7&1;E=f+76|0;c[E>>2]=(d[o+(G>>>3)|0]|0)<<(G&7)>>>7&1;L=G+5+((G|0)<(n|0))|0;G=(n>>>0>L>>>0?L:n)+1|0;L=n>>>0>G>>>0?G:n;if((v|u|0)!=1095521024){q=-1094995529;r=33;break}u=f+1368|0;c[u>>2]=x;if((I|0)==0){M=L}else{I=o+(L>>>3)|0;x=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>16;I=L+16|0;c[f+80>>2]=x;M=n>>>0>I>>>0?I:n}do{if((J|0)==0){N=M}else{I=c[w>>2]|0;if((I|0)<=1){N=M;break}x=(I<<1)-2|0;L=x>>>0>65535>>>0;v=L?x>>>16:x;x=L?16:0;if((v&65280|0)==0){O=x;P=v}else{O=x|8;P=v>>>8}v=(d[1191992+P|0]|0)+O|0;if((p-M|0)<((ba(v,I)|0)+7|0)){q=-1094995529;r=33;break a}x=WDb(I<<2)|0;I=x;c[f+84>>2]=I;if((x|0)==0){q=-12;r=33;break a}x=f+1380|0;c[x>>2]=1;L=c[w>>2]|0;b:do{if((L|0)>0){G=32-v|0;Q=M;R=0;while(1){S=o+(Q>>>3)|0;T=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Q&7)>>>(G>>>0);S=Q+v|0;U=n>>>0>S>>>0?S:n;if((T|0)>=(L|0)){break}c[I+(T<<2)>>2]=R;T=R+1|0;if((T|0)<(L|0)){Q=U;R=T}else{V=U;break b}}yDb(a,24,2210664,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;c[x>>2]=0;V=U}else{V=M}}while(0);x=-V&7;if((x|0)==0){N=V;break}L=x+V|0;N=n>>>0>L>>>0?L:n}}while(0);if((p-N|0)<64){q=-1094995529;r=33;break}J=o+(N>>>3)|0;L=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(N&7)&-65536;J=N+16|0;x=n>>>0>J>>>0?J:n;J=o+(x>>>3)|0;I=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(x&7)>>>16;J=x+16|0;x=n>>>0>J>>>0?J:n;J=I|L;L=o+(x>>>3)|0;I=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(x&7)&-65536;L=x+16|0;x=n>>>0>L>>>0?L:n;L=o+(x>>>3)|0;v=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(x&7)>>>16;L=x+16|0;x=n>>>0>L>>>0?L:n;L=v|I;I=(J|0)==-1;v=(L|0)==-1;R=YGb(v?0:L,v?0:0,I?0:J,I?0:0)|0;I=R<<3|0>>>29;J=F<<3|R>>>29;R=p-x|0;v=(R|0)<0|0?-1:0;if(v>>>0<J>>>0|v>>>0==J>>>0&R>>>0<I>>>0){q=-1094995529;r=33;break}R=0;if(J>>>0>R>>>0|J>>>0==R>>>0&I>>>0>2147483647>>>0){q=-1163346256;r=33;break}R=I;I=-x|0;J=n-x|0;if((R|0)<(I|0)){W=I}else{W=(J|0)<(R|0)?J:R}R=W+x|0;do{if((c[K>>2]|0)!=0){if((p-R|0)<32){q=-1094995529;r=33;break a}if((c[a+696>>2]&65537|0)==0){break}c[f+1356>>2]=tBb(4)|0;c[f+1364>>2]=-1;x=o+(R>>>3)|0;J=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(R&7)&-65536;x=R+16|0;I=n>>>0>x>>>0?x:n;x=o+(I>>>3)|0;c[f+1360>>2]=~((fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(I&7)>>>16|J)}}while(0);if((c[A>>2]|0)==0){X=0}else{EDb(c[g>>2]|0,2232464,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;X=-1163346256}if((c[E>>2]|0)!=0){EDb(c[g>>2]|0,2219904,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-1163346256;break}if((X|0)<0){Y=X;break}if((c[z>>2]|0)!=0){R=j_(a,f+1392|0,f+1396|0)|0;if((R|0)<0){Y=R;break}}if((c[A>>2]|0)==0){R=c[t>>2]|0;c[a+420>>2]=(R|0)>1?2:1;c[a+796>>2]=(R<<3)+8}else{c[a+420>>2]=3;c[a+796>>2]=32}c[f+1388>>2]=(c[t>>2]|0)>1?31:15;R=c[s>>2]|0;c[f+1400>>2]=((R|0)>95999|8)+((R|0)>191999);if((c[H>>2]|0)==0){Z=1}else{Z=c[w>>2]|0}R=Z<<2;J=f+1436|0;c[J>>2]=WDb(R)|0;I=f+1444|0;c[I>>2]=WDb(R)|0;x=f+1440|0;c[x>>2]=WDb(ba(c[D>>2]|0,R)|0)|0;v=f+1448|0;c[v>>2]=WDb(ba(c[D>>2]|0,R)|0)|0;L=WDb(c[D>>2]<<2)|0;c[f+1452>>2]=L;Q=c[J>>2]|0;do{if((Q|0)!=0){if((c[I>>2]|0)==0){break}G=c[x>>2]|0;if((G|0)==0){break}if((c[v>>2]|0)==0|(L|0)==0){break}T=(Z|0)==0;c:do{if(!T){S=c[D>>2]|0;_=0;$=G;aa=Q;while(1){ca=ba(S,_)|0;c[aa+(_<<2)>>2]=$+(ca<<2);c[(c[I>>2]|0)+(_<<2)>>2]=(c[v>>2]|0)+(ca<<2);ca=_+1|0;if(!(ca>>>0<Z>>>0)){break c}_=ca;$=c[x>>2]|0;aa=c[J>>2]|0}}}while(0);G=f+1404|0;c[G>>2]=WDb(R)|0;aa=f+1408|0;c[aa>>2]=WDb(R)|0;$=f+1412|0;c[$>>2]=WDb(R)|0;_=f+1416|0;c[_>>2]=WDb(R)|0;S=f+1420|0;c[S>>2]=cEb(R)|0;ca=f+1424|0;c[ca>>2]=WDb(R)|0;da=f+1428|0;c[da>>2]=WDb(R)|0;ea=WDb(Z*20|0)|0;fa=ea;ga=f+1432|0;c[ga>>2]=fa;do{if((c[G>>2]|0)!=0){if((c[aa>>2]|0)==0){break}if((c[$>>2]|0)==0){break}if((c[_>>2]|0)==0){break}if((c[S>>2]|0)==0){break}if((c[ca>>2]|0)==0){break}ha=c[da>>2]|0;if((ha|0)==0|(ea|0)==0){break}d:do{if(!T){ia=0;ja=fa;ka=ha;while(1){c[ka+(ia<<2)>>2]=ja+((ia*5|0)<<2);la=ia+1|0;if(!(la>>>0<Z>>>0)){break d}ia=la;ja=c[ga>>2]|0;ka=c[da>>2]|0}}}while(0);e:do{if((c[H>>2]|0)==0){c[f+1456>>2]=0;c[f+1460>>2]=0;c[f+1464>>2]=0}else{ha=f+1460|0;c[ha>>2]=WDb(ba(Z*44|0,Z)|0)|0;ka=f+1456|0;c[ka>>2]=WDb(R)|0;ja=WDb(R)|0;c[f+1464>>2]=ja;ia=c[ha>>2]|0;do{if((ia|0)!=0){la=c[ka>>2]|0;if((la|0)==0|(ja|0)==0){break}if(T){break e}else{ma=0;na=ia;oa=la}while(1){c[oa+(ma<<2)>>2]=na+((ba(ma,Z)|0)*44|0);la=ma+1|0;if(!(la>>>0<Z>>>0)){break e}ma=la;na=c[ha>>2]|0;oa=c[ka>>2]|0}}}while(0);yDb(a,16,2244824,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12;break a}}while(0);ka=c[D>>2]|0;ha=ka+(c[C>>2]|0)|0;ia=f+1468|0;c[ia>>2]=WDb(ka<<2)|0;ka=f+1476|0;c[ka>>2]=cEb(ba(ha<<2,c[w>>2]|0)|0)|0;ja=WDb(c[w>>2]<<2)|0;la=ja;pa=f+1472|0;c[pa>>2]=la;do{if((c[ia>>2]|0)!=0){qa=c[ka>>2]|0;if((qa|0)==0|(ja|0)==0){break}c[la>>2]=qa+(c[D>>2]<<2);qa=c[w>>2]|0;if(qa>>>0>1>>>0){ra=1;do{sa=c[pa>>2]|0;c[sa+(ra<<2)>>2]=(c[sa+(ra-1<<2)>>2]|0)+(ha<<2);ra=ra+1|0;}while(ra>>>0<qa>>>0)}do{if((c[B>>2]|0)!=0){if((c[K>>2]|0)==0){break}if((c[a+696>>2]&65537|0)==0){break}ra=ba(c[u>>2]|0,qa)|0;sa=WDb(ba(ra,BFb(c[a+420>>2]|0)|0)|0)|0;c[f+1480>>2]=sa;if((sa|0)!=0){break}yDb(a,16,2244824,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12;break a}}while(0);Z3(f+112|0,a);k=0;i=b;return k|0}}while(0);yDb(a,16,2244824,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12;break a}}while(0);yDb(a,16,2244824,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12;break a}}while(0);yDb(a,16,2244824,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12}}while(0);if((r|0)==33){yDb(a,16,2259440,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=q}OX(a)|0;k=Y;i=b;return k|0}function NX(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0;h=i;i=i+392|0;j=h|0;k=h+120|0;l=h+184|0;m=h+312|0;n=h+320|0;o=h+384|0;p=c[a+60>>2]|0;q=p;r=e;s=c[g+24>>2]|0;t=c[g+28>>2]|0;g=t<<3;u=g>>>0>2147483639>>>0|(s|0)==0;v=u?0:s;s=u?0:g;g=p+92|0;c[g>>2]=v;u=p+104|0;c[u>>2]=s;w=s+8|0;x=p+108|0;c[x>>2]=w;c[p+96>>2]=v+(s>>3);s=p+100|0;c[s>>2]=0;y=c[p+24>>2]|0;if((y|0)==0){z=0}else{z=(((c[p+1372>>2]|0)>>>0)%(y>>>0)|0|0)==0|0}y=c[p+4>>2]|0;if((y|0)==-1){c[p+1368>>2]=c[p+20>>2]}else{A=c[p+20>>2]|0;B=A;C=(A|0)<0|0?-1:0;D=gHb(B,C,c[p+1372>>2]|0,0)|0;E=ZGb(y,0,D,F)|0;D=F;c[p+1368>>2]=D>>>0>C>>>0|D>>>0==C>>>0&E>>>0>B>>>0?A:E}E=n;A=p;B=c[A>>2]|0;c[m>>2]=0;if((c[p+28>>2]|0)!=1|(z|0)==0){G=0}else{C=(w|0)<32?w:32;c[s>>2]=C;G=C}C=p+60|0;a:do{if((c[p+64>>2]|0)==0){H=14}else{do{if((c[C>>2]|0)==0){I=c[p+1376>>2]|0}else{D=d[v+(G>>>3)|0]<<(G&7)>>>7;y=((G|0)<(w|0))+G|0;c[s>>2]=y;J=D&1;c[p+1376>>2]=J;D=-y&7;if((D|0)==0){I=J;break}K=D+y|0;c[s>>2]=w>>>0>K>>>0?K:w;I=J}}while(0);if((I|0)!=0){H=14;break}TGb(E|0,0,60)|0;J=c[p+1464>>2]|0;K=B+416|0;y=c[K>>2]|0;D=p+1456|0;L=p+1460|0;M=0;while(1){if(!(M>>>0<y>>>0)){break}if((c[(c[D>>2]|0)+(M<<2)>>2]|0)>>>0<(c[L>>2]|0)>>>0){H=56;break}else{M=M+1|0}}if((H|0)==56){yDb(B,16,2057e3,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;O=-1094995529;break}M=J;TGb(M|0,0,y<<2|0)|0;L=n+4|0;c[L>>2]=z;c[n+52>>2]=c[p+1468>>2];QX(q,l|0,m);P=p+1384|0;b:do{if((c[P>>2]|0)!=0){Q=n|0;R=p+1404|0;S=n+8|0;T=p+1408|0;U=n+16|0;V=p+1412|0;W=n+20|0;X=p+1416|0;Y=n+24|0;Z=p+1420|0;_=n+28|0;$=p+1424|0;aa=n+32|0;ca=p+1428|0;da=n+36|0;ea=p+1444|0;fa=n+44|0;ga=p+1436|0;ha=n+40|0;ia=p+1472|0;ja=n+48|0;ka=n+56|0;la=p+1400|0;ma=0;na=0;c:while(1){oa=l+(ma<<2)|0;pa=c[oa>>2]|0;c[Q>>2]=pa;if((pa|0)==0){yDb(c[A>>2]|0,24,2010872,(N=i,i=i+8|0,c[N>>2]=0,N)|0);i=N;qa=na}else{do{if((c[K>>2]|0)==0){ra=0}else{pa=0;do{c[S>>2]=(c[R>>2]|0)+(pa<<2);c[U>>2]=(c[T>>2]|0)+(pa<<2);c[W>>2]=(c[V>>2]|0)+(pa<<2);c[Y>>2]=(c[X>>2]|0)+(pa<<2);c[_>>2]=(c[Z>>2]|0)+(pa<<2);c[aa>>2]=(c[$>>2]|0)+(pa<<2);c[da>>2]=c[(c[ca>>2]|0)+(pa<<2)>>2];c[fa>>2]=c[(c[ea>>2]|0)+(pa<<2)>>2];c[ha>>2]=c[(c[ga>>2]|0)+(pa<<2)>>2];c[ja>>2]=(c[(c[ia>>2]|0)+(pa<<2)>>2]|0)+(na<<2);c[ka>>2]=0;sa=RX(q,n)|0;if((sa|0)<0){O=sa;break a}ta=c[A>>2]|0;sa=c[ta+416>>2]|0;d:do{if((sa|0)==0){ua=0}else{va=(sa<<1)-2|0;wa=va>>>0>65535>>>0;xa=wa?va>>>16:va;va=wa?16:0;wa=(xa&65280|0)==0;ya=c[g>>2]|0;za=wa?va:va|8;va=1191992+(wa?xa:xa>>>8)|0;xa=c[(c[D>>2]|0)+(pa<<2)>>2]|0;wa=0;while(1){Aa=c[s>>2]|0;Ba=d[ya+(Aa>>>3)|0]<<(Aa&7)>>>7;c[s>>2]=((Aa|0)<(c[x>>2]|0))+Aa;Aa=Ba&1;c[xa>>2]=Aa;if((Aa|0)!=0){ua=wa;break d}Aa=(d[va]|0)+za|0;do{if((Aa|0)==0){Ca=0}else{Ba=c[s>>2]|0;Da=c[x>>2]|0;Ea=ya+(Ba>>>3)|0;Fa=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ba&7);if((Aa|0)<26){Ea=Ba+Aa|0;c[s>>2]=Da>>>0>Ea>>>0?Ea:Da;Ca=Fa>>>((32-Aa|0)>>>0);break}else{Ea=Ba+16|0;Ba=Da>>>0>Ea>>>0?Ea:Da;c[s>>2]=Ba;Ea=Aa-16|0;Ga=ya+(Ba>>>3)|0;Ha=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ba&7)>>>((48-Aa|0)>>>0);Ga=Ba+Ea|0;c[s>>2]=Da>>>0>Ga>>>0?Ga:Da;Ca=Ha|Fa>>>16<<Ea;break}}}while(0);c[xa+4>>2]=Ca;if(!(Ca>>>0<sa>>>0)){H=73;break c}do{if((Ca|0)!=(pa|0)){Aa=c[s>>2]|0;Ea=d[ya+(Aa>>>3)|0]<<(Aa&7)>>>7;c[s>>2]=((Aa|0)<(c[x>>2]|0))+Aa;Aa=xa+8|0;c[Aa>>2]=Ea&1;Ea=c[s>>2]|0;Fa=(c[u>>2]|0)+~Ea|0;Ha=0;Da=Ea;while(1){if((Ha|0)>=(Fa|0)){H=77;break}Ea=d[ya+(Da>>>3)|0]|0;Ga=c[x>>2]|0;Ba=((Da|0)<(Ga|0))+Da|0;c[s>>2]=Ba;if((Ea&128>>>((Da&7)>>>0)|0)==0){Ia=Ba;Ja=Ga;break}else{Ha=Ha+1|0;Da=Ba}}if((H|0)==77){H=0;Ia=Da;Ja=c[x>>2]|0}Fa=d[ya+(Ia>>>3)|0]<<(Ia&7);c[s>>2]=((Ia|0)<(Ja|0))+Ia;Ba=((Fa>>>7&1)-1^Ha)+16|0;if((Ba|0)<0){Ka=0}else{Ka=(Ba|0)>31?31:Ba}c[xa+20>>2]=b[679144+(Ka<<1)>>1]|0;Ba=c[s>>2]|0;Fa=-2-Ba+(c[u>>2]|0)|0;Ga=0;Ea=Ba;while(1){if((Ga|0)>=(Fa|0)){H=83;break}Ba=d[ya+(Ea>>>3)|0]|0;La=c[x>>2]|0;Ma=((Ea|0)<(La|0))+Ea|0;c[s>>2]=Ma;if((Ba&128>>>((Ea&7)>>>0)|0)==0){Na=Ma;Oa=La;break}else{Ga=Ga+1|0;Ea=Ma}}if((H|0)==83){H=0;Na=Ea;Oa=c[x>>2]|0}Fa=d[ya+(Na>>>3)|0]<<(Na&7);Ha=((Na|0)<(Oa|0))+Na|0;c[s>>2]=Ha;Da=ya+(Ha>>>3)|0;Ma=(fe(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Ha&7)>>>31;Da=Ha+1|0;c[s>>2]=Oa>>>0>Da>>>0?Da:Oa;Da=((Ma|Ga<<1)^(Fa>>>7&1)-1)+14|0;if((Da|0)<0){Pa=0}else{Pa=(Da|0)>31?31:Da}c[xa+24>>2]=b[679144+(Pa<<1)>>1]|0;Da=c[s>>2]|0;Fa=(c[u>>2]|0)+~Da|0;Ma=0;Ha=Da;while(1){if((Ma|0)>=(Fa|0)){H=89;break}Da=d[ya+(Ha>>>3)|0]|0;La=c[x>>2]|0;Ba=((Ha|0)<(La|0))+Ha|0;c[s>>2]=Ba;if((Da&128>>>((Ha&7)>>>0)|0)==0){Qa=Ba;Ra=La;break}else{Ma=Ma+1|0;Ha=Ba}}if((H|0)==89){H=0;Qa=Ha;Ra=c[x>>2]|0}Fa=d[ya+(Qa>>>3)|0]<<(Qa&7);c[s>>2]=((Qa|0)<(Ra|0))+Qa;Ga=((Fa>>>7&1)-1^Ma)+16|0;if((Ga|0)<0){Sa=0}else{Sa=(Ga|0)>31?31:Ga}c[xa+28>>2]=b[679144+(Sa<<1)>>1]|0;if((c[Aa>>2]|0)==0){break}Ga=c[s>>2]|0;Fa=(c[u>>2]|0)+~Ga|0;Ea=0;Ba=Ga;while(1){if((Ea|0)>=(Fa|0)){H=96;break}Ga=d[ya+(Ba>>>3)|0]|0;La=c[x>>2]|0;Da=((Ba|0)<(La|0))+Ba|0;c[s>>2]=Da;if((Ga&128>>>((Ba&7)>>>0)|0)==0){Ta=Da;Ua=La;break}else{Ea=Ea+1|0;Ba=Da}}if((H|0)==96){H=0;Ta=Ba;Ua=c[x>>2]|0}Fa=d[ya+(Ta>>>3)|0]<<(Ta&7);c[s>>2]=((Ta|0)<(Ua|0))+Ta;Aa=((Fa>>>7&1)-1^Ea)+16|0;if((Aa|0)<0){Va=0}else{Va=(Aa|0)>31?31:Aa}c[xa+32>>2]=b[679144+(Va<<1)>>1]|0;Aa=c[s>>2]|0;Fa=(c[u>>2]|0)+~Aa|0;Ma=0;Ha=Aa;while(1){if((Ma|0)>=(Fa|0)){H=102;break}Aa=d[ya+(Ha>>>3)|0]|0;Da=c[x>>2]|0;La=((Ha|0)<(Da|0))+Ha|0;c[s>>2]=La;if((Aa&128>>>((Ha&7)>>>0)|0)==0){Wa=La;Xa=Da;break}else{Ma=Ma+1|0;Ha=La}}if((H|0)==102){H=0;Wa=Ha;Xa=c[x>>2]|0}Fa=d[ya+(Wa>>>3)|0]<<(Wa&7);c[s>>2]=((Wa|0)<(Xa|0))+Wa;Ea=((Fa>>>7&1)-1^Ma)+16|0;if((Ea|0)<0){Ya=0}else{Ya=(Ea|0)>31?31:Ea}c[xa+36>>2]=b[679144+(Ya<<1)>>1]|0;Ea=c[s>>2]|0;Fa=(c[u>>2]|0)+~Ea|0;Ba=0;La=Ea;while(1){if((Ba|0)>=(Fa|0)){H=108;break}Ea=d[ya+(La>>>3)|0]|0;Da=c[x>>2]|0;Aa=((La|0)<(Da|0))+La|0;c[s>>2]=Aa;if((Ea&128>>>((La&7)>>>0)|0)==0){Za=Aa;_a=Da;break}else{Ba=Ba+1|0;La=Aa}}if((H|0)==108){H=0;Za=La;_a=c[x>>2]|0}Fa=d[ya+(Za>>>3)|0]<<(Za&7);c[s>>2]=((Za|0)<(_a|0))+Za;Ma=((Fa>>>7&1)-1^Ba)+16|0;if((Ma|0)<0){$a=0}else{$a=(Ma|0)>31?31:Ma}c[xa+40>>2]=b[679144+($a<<1)>>1]|0;Ma=c[s>>2]|0;Fa=d[ya+(Ma>>>3)|0]<<(Ma&7)>>>7;c[s>>2]=((Ma|0)<(c[x>>2]|0))+Ma;c[xa+12>>2]=Fa&1;Fa=c[la>>2]|0;Ma=c[s>>2]|0;Ha=c[x>>2]|0;Aa=ya+(Ma>>>3)|0;Da=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Ma&7)>>>((35-Fa|0)>>>0);Aa=Fa-3+Ma|0;c[s>>2]=Ha>>>0>Aa>>>0?Aa:Ha;c[xa+16>>2]=Da+3}}while(0);Da=wa+1|0;if(Da>>>0<sa>>>0){xa=xa+44|0;wa=Da}else{ua=Da;break}}}}while(0);if((ua|0)==(sa|0)){H=115;break c}wa=c[s>>2]|0;xa=-wa&7;if((xa|0)!=0){ya=c[x>>2]|0;za=xa+wa|0;c[s>>2]=ya>>>0>za>>>0?za:ya}pa=pa+1|0;ab=c[K>>2]|0;}while(pa>>>0<ab>>>0);if((ab|0)==0){ra=0;break}else{bb=0}do{pa=SX(q,n,c[D>>2]|0,J,na,bb)|0;if((pa|0)<0){O=pa;break a}bb=bb+1|0;cb=c[K>>2]|0;}while(bb>>>0<cb>>>0);if((cb|0)==0){ra=0;break}else{db=0}do{c[S>>2]=(c[R>>2]|0)+(db<<2);c[U>>2]=(c[T>>2]|0)+(db<<2);c[W>>2]=(c[V>>2]|0)+(db<<2);c[Y>>2]=(c[X>>2]|0)+(db<<2);c[_>>2]=(c[Z>>2]|0)+(db<<2);c[aa>>2]=(c[$>>2]|0)+(db<<2);c[da>>2]=c[(c[ca>>2]|0)+(db<<2)>>2];c[fa>>2]=c[(c[ea>>2]|0)+(db<<2)>>2];c[ha>>2]=c[(c[ga>>2]|0)+(db<<2)>>2];c[ja>>2]=(c[(c[ia>>2]|0)+(db<<2)>>2]|0)+(na<<2);TX(q,n);db=db+1|0;eb=c[K>>2]|0;}while(db>>>0<eb>>>0);ra=eb<<2}}while(0);TGb(M|0,0,ra|0)|0;pa=(c[oa>>2]|0)+na|0;c[L>>2]=0;qa=pa}pa=ma+1|0;if(pa>>>0<(c[P>>2]|0)>>>0){ma=pa;na=qa}else{break b}}if((H|0)==73){yDb(ta,16,1943136,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;O=-1094995529;break a}else if((H|0)==115){yDb(ta,16,1918464,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;O=-1094995529;break a}}}while(0);if((c[K>>2]|0)==0){O=0;break}P=p+1472|0;L=p+44|0;M=p+20|0;J=0;while(1){D=c[(c[P>>2]|0)+(J<<2)>>2]|0;y=c[L>>2]|0;VGb(D+(-y<<2)|0,D+((c[M>>2]|0)-y<<2)|0,y<<2|0)|0;y=J+1|0;if(y>>>0<(c[K>>2]|0)>>>0){J=y}else{O=0;break}}}}while(0);e:do{if((H|0)==14){ta=B+416|0;if((c[ta>>2]|0)==0){O=0;break}qa=l|0;ra=j;eb=j|0;db=j+4|0;n=p+1404|0;cb=j+8|0;bb=p+1408|0;ab=j+16|0;x=p+1412|0;ua=j+20|0;$a=p+1416|0;Za=j+24|0;_a=p+1420|0;u=j+28|0;Ya=p+1424|0;Wa=j+32|0;Xa=p+1428|0;Va=j+36|0;Ta=p+1436|0;Ua=j+40|0;Sa=p+1444|0;Qa=j+44|0;Ra=p+1468|0;Pa=j+52|0;Oa=j+12|0;Na=j+60|0;Ka=j+64|0;Ia=j+68|0;Ja=j+76|0;Ca=j+80|0;g=j+84|0;E=j+88|0;I=j+92|0;w=j+96|0;G=j+100|0;v=j+104|0;J=j+112|0;K=j+72|0;M=p+1384|0;L=p+1472|0;P=p+44|0;y=p+20|0;D=j|0;na=Na|0;ma=j+48|0;ia=j+108|0;ja=j+56|0;ga=j+116|0;ha=k;ea=k+4|0;fa=k+8|0;ca=k+16|0;da=k+20|0;$=k+24|0;aa=k+28|0;Z=k+32|0;_=k+36|0;X=k+40|0;Y=k+44|0;V=k+52|0;W=k+48|0;T=k|0;U=p+48|0;R=0;S=(c[C>>2]|0)==0|0;f:while(1){QX(q,qa,m);do{if((c[C>>2]|0)==0){fb=S}else{if((c[U>>2]|0)==0){fb=S;break}fb=(c[m>>2]|0)<0?2:S}}while(0);la=(R|0)==((c[ta>>2]|0)-1|0)?1:fb;g:do{if((la|0)==0){TGb(ra|0,0,120)|0;c[db>>2]=z;ka=c[n>>2]|0;c[cb>>2]=ka;Q=c[bb>>2]|0;c[ab>>2]=Q;pa=c[x>>2]|0;c[ua>>2]=pa;ya=c[$a>>2]|0;c[Za>>2]=ya;za=c[_a>>2]|0;c[u>>2]=za;wa=c[Ya>>2]|0;c[Wa>>2]=wa;xa=c[Xa>>2]|0;c[Va>>2]=c[xa>>2];va=c[Ta>>2]|0;c[Ua>>2]=c[va>>2];Da=c[Sa>>2]|0;c[Qa>>2]=c[Da>>2];Ha=c[Ra>>2]|0;c[Pa>>2]=Ha;c[Oa>>2]=0;c[Ka>>2]=z;c[Ia>>2]=ka;c[Ja>>2]=Q;c[Ca>>2]=pa;c[g>>2]=ya;c[E>>2]=za;c[I>>2]=wa;c[w>>2]=c[xa>>2];c[G>>2]=c[va>>2];c[v>>2]=c[Da>>2];c[J>>2]=Ha;c[K>>2]=0;Ha=R+1|0;h:do{if((c[M>>2]|0)!=0){Da=0;va=0;while(1){xa=l+(va<<2)|0;wa=c[xa>>2]|0;c[D>>2]=wa;c[na>>2]=wa;wa=c[L>>2]|0;za=(c[wa+(R<<2)>>2]|0)+(Da<<2)|0;c[ma>>2]=za;ya=(c[wa+(Ha<<2)>>2]|0)+(Da<<2)|0;c[ia>>2]=ya;c[ja>>2]=ya;c[ga>>2]=za;za=RX(q,eb)|0;if((za|0)<0){gb=za;break}TX(q,eb);za=RX(q,Na)|0;if((za|0)<0){gb=za;break}TX(q,Na);za=(c[K>>2]|0)!=0;do{if((c[Oa>>2]|0)==0){ya=c[xa>>2]|0;if(!za){hb=ya;break}if((ya|0)==0){hb=0;break}ya=c[ia>>2]|0;wa=c[ma>>2]|0;pa=0;while(1){Q=ya+(pa<<2)|0;c[Q>>2]=(c[wa+(pa<<2)>>2]|0)+(c[Q>>2]|0);Q=pa+1|0;ka=c[xa>>2]|0;if(Q>>>0<ka>>>0){pa=Q}else{hb=ka;break}}}else{if(za){yDb(c[A>>2]|0,24,2291056,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N}if((c[xa>>2]|0)==0){hb=0;break}pa=c[ia>>2]|0;wa=c[ma>>2]|0;ya=0;while(1){ka=wa+(ya<<2)|0;c[ka>>2]=(c[pa+(ya<<2)>>2]|0)-(c[ka>>2]|0);ka=ya+1|0;Q=c[xa>>2]|0;if(ka>>>0<Q>>>0){ya=ka}else{hb=Q;break}}}}while(0);c[db>>2]=0;c[Ka>>2]=0;xa=va+1|0;if(xa>>>0<(c[M>>2]|0)>>>0){Da=hb+Da|0;va=xa}else{break h}}Da=c[M>>2]|0;xa=c[ma>>2]|0;do{if(va>>>0<Da>>>0){za=va;sa=0;while(1){ya=za+1|0;ib=(c[l+(za<<2)>>2]|0)+sa|0;if(ya>>>0<Da>>>0){za=ya;sa=ib}else{break}}if((ib|0)==0){jb=Da;break}TGb(xa|0,0,ib<<2|0)|0;jb=c[M>>2]|0}else{jb=Da}}while(0);Da=c[ia>>2]|0;do{if(va>>>0<jb>>>0){xa=va;sa=0;while(1){za=xa+1|0;kb=(c[l+(xa<<2)>>2]|0)+sa|0;if(za>>>0<jb>>>0){xa=za;sa=kb}else{break}}if((kb|0)==0){break}TGb(Da|0,0,kb<<2|0)|0}}while(0);if((gb|0)<0){O=gb;break e}else{lb=0;mb=Ha;break g}}}while(0);oa=c[(c[L>>2]|0)+(R<<2)>>2]|0;Da=c[P>>2]|0;VGb(oa+(-Da<<2)|0,oa+((c[y>>2]|0)-Da<<2)|0,Da<<2|0)|0;lb=0;mb=Ha}else{TGb(ha|0,0,60)|0;c[ea>>2]=z;c[fa>>2]=c[n>>2];c[ca>>2]=c[bb>>2];c[da>>2]=c[x>>2];c[$>>2]=c[$a>>2];c[aa>>2]=c[_a>>2];c[Z>>2]=c[Ya>>2];c[_>>2]=c[c[Xa>>2]>>2];c[X>>2]=c[c[Ta>>2]>>2];c[Y>>2]=c[c[Sa>>2]>>2];c[V>>2]=c[Ra>>2];c[W>>2]=c[(c[L>>2]|0)+(R<<2)>>2];if((c[M>>2]|0)!=0){nb=0;while(1){Da=l+(nb<<2)|0;c[T>>2]=c[Da>>2];ob=RX(q,k)|0;if((ob|0)<0){break f}TX(q,k);c[W>>2]=(c[W>>2]|0)+(c[Da>>2]<<2);c[ea>>2]=0;Da=nb+1|0;if(Da>>>0<(c[M>>2]|0)>>>0){nb=Da}else{break}}}lb=la-1|0;mb=R}}while(0);la=c[(c[L>>2]|0)+(mb<<2)>>2]|0;Ha=c[P>>2]|0;VGb(la+(-Ha<<2)|0,la+((c[y>>2]|0)-Ha<<2)|0,Ha<<2|0)|0;Ha=mb+1|0;if(Ha>>>0<(c[ta>>2]|0)>>>0){R=Ha;S=lb}else{O=0;break e}}S=c[M>>2]|0;R=c[W>>2]|0;if(nb>>>0<S>>>0){pb=nb;qb=0}else{O=ob;break}while(1){ta=pb+1|0;rb=(c[l+(pb<<2)>>2]|0)+qb|0;if(ta>>>0<S>>>0){pb=ta;qb=rb}else{break}}if((rb|0)==0){O=ob;break}TGb(R|0,0,rb<<2|0)|0;O=ob}}while(0);if((O|0)<0){yDb(c[A>>2]|0,24,2194480,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N}ob=p+1372|0;c[ob>>2]=(c[ob>>2]|0)+1;ob=p+1368|0;c[e+76>>2]=c[ob>>2];rb=_$a(a,r,0)|0;if((rb|0)<0){sb=rb;i=h;return sb|0}rb=(c[A>>2]|0)+796|0;A=c[rb>>2]|0;r=e;e=c[r>>2]|0;i:do{if((A|0)<17){qb=e;pb=16-A|0;l=c[ob>>2]|0;nb=(l|0)==0;if((c[p+1380>>2]|0)==0){if(nb){tb=0;break}lb=c[a+416>>2]|0;mb=p+1472|0;if((lb|0)==0){tb=l;break}else{ub=qb;vb=0}while(1){k=c[mb>>2]|0;q=lb>>>0>1>>>0?lb:1;z=ub;gb=0;while(1){b[z>>1]=c[(c[k+(gb<<2)>>2]|0)+(vb<<2)>>2]<<pb;kb=gb+1|0;if(kb>>>0<lb>>>0){z=z+2|0;gb=kb}else{break}}gb=vb+1|0;if(gb>>>0<l>>>0){ub=ub+(q<<1)|0;vb=gb}else{tb=l;break i}}}if(nb){tb=0;break}lb=c[a+416>>2]|0;mb=(lb|0)==0;R=p+84|0;gb=p+1472|0;z=qb;k=0;while(1){if(mb){wb=z}else{kb=c[R>>2]|0;jb=c[gb>>2]|0;ib=lb>>>0>1>>>0?lb:1;hb=z;fb=0;while(1){b[hb>>1]=c[(c[jb+(c[kb+(fb<<2)>>2]<<2)>>2]|0)+(k<<2)>>2]<<pb;m=fb+1|0;if(m>>>0<lb>>>0){hb=hb+2|0;fb=m}else{break}}wb=z+(ib<<1)|0}fb=k+1|0;if(fb>>>0<l>>>0){z=wb;k=fb}else{tb=l;break}}}else{l=e;k=32-A|0;z=c[ob>>2]|0;lb=(z|0)==0;if((c[p+1380>>2]|0)==0){if(lb){tb=0;break}pb=a+416|0;gb=p+1472|0;R=l;mb=0;qb=c[pb>>2]|0;nb=z;while(1){if((qb|0)==0){xb=R;yb=0;zb=nb}else{fb=c[gb>>2]|0;hb=R;kb=0;while(1){Ab=hb+4|0;c[hb>>2]=c[(c[fb+(kb<<2)>>2]|0)+(mb<<2)>>2]<<k;jb=kb+1|0;Bb=c[pb>>2]|0;if(jb>>>0<Bb>>>0){hb=Ab;kb=jb}else{break}}xb=Ab;yb=Bb;zb=c[ob>>2]|0}kb=mb+1|0;if(kb>>>0<zb>>>0){R=xb;mb=kb;qb=yb;nb=zb}else{tb=zb;break}}}else{if(lb){tb=0;break}nb=a+416|0;qb=p+84|0;mb=p+1472|0;R=l;pb=0;gb=c[nb>>2]|0;kb=z;while(1){if((gb|0)==0){Cb=R;Db=0;Eb=kb}else{hb=c[qb>>2]|0;fb=c[mb>>2]|0;ib=R;jb=0;while(1){Fb=ib+4|0;c[ib>>2]=c[(c[fb+(c[hb+(jb<<2)>>2]<<2)>>2]|0)+(pb<<2)>>2]<<k;q=jb+1|0;Gb=c[nb>>2]|0;if(q>>>0<Gb>>>0){ib=Fb;jb=q}else{break}}Cb=Fb;Db=Gb;Eb=c[ob>>2]|0}jb=pb+1|0;if(jb>>>0<Eb>>>0){R=Cb;pb=jb;gb=Db;kb=Eb}else{tb=Eb;break}}}}}while(0);do{if((c[p+88>>2]|0)!=0){Eb=a+696|0;if((c[Eb>>2]&65537|0)==0){break}Db=(c[p+16>>2]|0)!=0;Cb=c[rb>>2]|0;do{if((Cb|0)==24){Gb=e;Fb=a+416|0;if((ba(c[Fb>>2]|0,tb)|0)==0){Hb=tb;break}zb=p+1356|0;yb=p+1364|0;xb=o;if(Db){Bb=0;while(1){c[o>>2]=(fe(c[Gb+(Bb<<2)>>2]|0)|0)>>8;c[yb>>2]=uBb(c[zb>>2]|0,c[yb>>2]|0,xb,3)|0;Ab=Bb+1|0;A=c[ob>>2]|0;if(Ab>>>0<(ba(c[Fb>>2]|0,A)|0)>>>0){Bb=Ab}else{Hb=A;break}}}else{Bb=0;while(1){c[o>>2]=c[Gb+(Bb<<2)>>2]>>8;c[yb>>2]=uBb(c[zb>>2]|0,c[yb>>2]|0,xb,3)|0;A=Bb+1|0;Ab=c[ob>>2]|0;if(A>>>0<(ba(c[Fb>>2]|0,Ab)|0)>>>0){Bb=A}else{Hb=Ab;break}}}}else{do{if(Db){if((Cb|0)>=17){Bb=p+1480|0;Fb=ba(c[a+416>>2]|0,tb)|0;Xe[c[p+1208>>2]&4095](c[Bb>>2]|0,e,Fb);Ib=Bb;Jb=c[ob>>2]|0;break}Bb=e;Fb=ba(c[a+416>>2]|0,tb)|0;xb=p+1480|0;if((Fb|0)==0){Ib=xb;Jb=tb;break}yb=0;zb=c[xb>>2]|0;while(1){b[zb>>1]=de(b[Bb+(yb<<1)>>1]|0)|0;Gb=yb+1|0;if(Gb>>>0<Fb>>>0){yb=Gb;zb=zb+2|0}else{Ib=xb;Jb=tb;break}}}else{Ib=r;Jb=tb}}while(0);xb=c[Ib>>2]|0;zb=c[p+1356>>2]|0;yb=p+1364|0;Fb=c[yb>>2]|0;Bb=ba(c[a+416>>2]|0,Jb)|0;c[yb>>2]=uBb(zb,Fb,xb,ba(Bb,BFb(c[a+420>>2]|0)|0)|0)|0;Hb=c[ob>>2]|0}}while(0);if((Hb|0)==(c[p+20>>2]|0)){break}if((c[p+1360>>2]|0)==(c[p+1364>>2]|0)){break}yDb(a,16,2116224,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;if((c[Eb>>2]&8|0)==0){break}else{sb=-1094995529}i=h;return sb|0}}while(0);c[f>>2]=1;if((O|0)!=0){sb=t;i=h;return sb|0}sb=(c[s>>2]|0)+7>>3;i=h;return sb|0}function OX(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+84|0);k_(b+1392|0,b+1396|0);$Db(b+1404|0);$Db(b+1408|0);$Db(b+1412|0);$Db(b+1416|0);$Db(b+1420|0);$Db(b+1424|0);$Db(b+1428|0);$Db(b+1432|0);$Db(b+1436|0);$Db(b+1444|0);$Db(b+1440|0);$Db(b+1448|0);$Db(b+1452|0);$Db(b+1468|0);$Db(b+1472|0);$Db(b+1476|0);$Db(b+1456|0);$Db(b+1460|0);$Db(b+1464|0);$Db(b+1480|0);return 0}function PX(a){a=a|0;c[(c[a+60>>2]|0)+1372>>2]=0;return}function QX(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+8|0;g=f|0;c[g>>2]=b;h=c[a+48>>2]|0;if((h|0)!=0){j=1<<h+2;h=a+100|0;k=c[h>>2]|0;l=c[a+108>>2]|0;m=c[a+92>>2]|0;n=m+(k>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7);if((j|0)<26){n=32-j|0;p=k+j|0;c[h>>2]=l>>>0>p>>>0?p:l;q=o>>>(n>>>0);r=n}else{n=k+16|0;k=l>>>0>n>>>0?n:l;c[h>>2]=k;n=j-16|0;p=m+(k>>>3)|0;m=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(k&7)>>>((48-j|0)>>>0);p=k+n|0;c[h>>2]=l>>>0>p>>>0?p:l;q=m|o>>>16<<n;r=32-j|0}c[e>>2]=q<<r}r=a+1384|0;c[r>>2]=0;UX(c[e>>2]|0,0,0,g,r);g=a+20|0;if((c[r>>2]|0)==0){s=0}else{e=0;while(1){q=b+(e<<2)|0;c[q>>2]=c[g>>2]>>c[q>>2];q=e+1|0;j=c[r>>2]|0;if(q>>>0<j>>>0){e=q}else{s=j;break}}}e=c[a+1368>>2]|0;if((e|0)==(c[g>>2]|0)|(s|0)==0){i=f;return}else{t=0;u=e}while(1){v=b+(t<<2)|0;e=c[v>>2]|0;if(!(u>>>0>e>>>0)){break}g=t+1|0;if(g>>>0<s>>>0){t=g;u=u-e|0}else{w=12;break}}if((w|0)==12){i=f;return}c[v>>2]=u;c[r>>2]=t+1;i=f;return}function RX(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0;g=i;i=i+152|0;h=g|0;j=g+32|0;k=g+64|0;l=g+96|0;m=g+128|0;n=g+136|0;o=g+144|0;p=e+92|0;q=c[f+16>>2]|0;c[q>>2]=0;r=e+100|0;s=c[r>>2]|0;t=p|0;u=c[t>>2]|0;v=d[u+(s>>>3)|0]|0;w=e+108|0;c[r>>2]=((s|0)<(c[w>>2]|0))+s;if((v&128>>>((s&7)>>>0)|0)==0){s=c[e>>2]|0;if((c[f>>2]|0)==0){x=-1094995529;i=g;return x|0}v=c[f+48>>2]|0;c[v>>2]=0;y=c[r>>2]|0;z=d[u+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[w>>2]|0))+y;y=c[f+8>>2]|0;c[y>>2]=z&1;z=c[r>>2]|0;A=d[u+(z>>>3)|0]<<(z&7)>>>7;c[r>>2]=((z|0)<(c[w>>2]|0))+z;c[f+12>>2]=A&1;A=c[w>>2]|0;z=(c[r>>2]|0)+5|0;B=A>>>0>z>>>0?z:A;c[r>>2]=B;if((c[y>>2]|0)!=0){if((c[e+12>>2]|0)==0){z=c[s+796>>2]|0;if((z|0)==0){C=0;D=0}else{E=z;F=209}}else{E=24;F=209}do{if((F|0)==209){z=u+(B>>>3)|0;s=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7);if((E|0)<26){z=E+B|0;c[r>>2]=A>>>0>z>>>0?z:A;C=s>>>((32-E|0)>>>0);D=E;break}else{z=B+16|0;G=A>>>0>z>>>0?z:A;c[r>>2]=G;z=E-16|0;H=u+(G>>>3)|0;I=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(G&7)>>>((48-E|0)>>>0);H=z+G|0;c[r>>2]=A>>>0>H>>>0?H:A;C=I|s>>>16<<z;D=E;break}}}while(0);E=32-D|0;c[v>>2]=C<<E>>E}c[y>>2]=1;x=0;i=g;return x|0}y=c[e>>2]|0;E=c[f+40>>2]|0;c[c[f+8>>2]>>2]=0;C=c[f+20>>2]|0;c[C>>2]=1;v=c[r>>2]|0;D=d[u+(v>>>3)|0]<<(v&7)>>>7;c[r>>2]=((v|0)<(c[w>>2]|0))+v;v=f+12|0;c[v>>2]=D&1;D=c[C>>2]|0;A=e+52|0;B=(c[A>>2]|0)==0;z=(c[e+56>>2]|0)==0;do{if(B){if(z){J=0}else{F=6}}else{if(z){F=6;break}s=c[r>>2]|0;I=c[w>>2]|0;H=u+(s>>>3)|0;G=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(s&7)>>>30;H=s+2|0;c[r>>2]=I>>>0>H>>>0?H:I;J=G}}while(0);if((F|0)==6){z=c[r>>2]|0;G=d[u+(z>>>3)|0]<<(z&7)>>>7;c[r>>2]=((z|0)<(c[w>>2]|0))+z;J=G<<1&2}G=1<<J;z=f|0;I=c[z>>2]|0;if((G-1&I|0)!=0){yDb(y,24,1897696,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;x=-1094995529;i=g;return x|0}H=I>>>(J>>>0);J=(c[e+8>>2]|0)>1|0;do{if(B){I=J|4;s=c[r>>2]|0;L=c[w>>2]|0;M=u+(s>>>3)|0;N=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(s&7)>>>((32-I|0)>>>0);M=s+I|0;I=L>>>0>M>>>0?M:L;c[r>>2]=I;c[h>>2]=N;if(!(G>>>0>1>>>0)){O=I;P=L;break}M=c[e+104>>2]|0;s=1;Q=N;N=I;while(1){I=M-N|0;R=0;S=N;while(1){if((R|0)>=(I|0)){T=S;break}U=d[u+(S>>>3)|0]|0;V=((S|0)<(L|0))+S|0;c[r>>2]=V;if((U&128>>>((S&7)>>>0)|0)==0){T=V;break}else{R=R+1|0;S=V}}S=(R<<31>>31^R>>1)+Q|0;c[h+(s<<2)>>2]=S;I=s+1|0;if(I>>>0<G>>>0){s=I;Q=S;N=T}else{O=T;P=L;break}}}else{L=J|8;N=c[r>>2]|0;Q=c[w>>2]|0;s=u+(N>>>3)|0;M=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(N&7)>>>((32-L|0)>>>0);s=N+L|0;L=Q>>>0>s>>>0?s:Q;c[r>>2]=L;c[h>>2]=M;if(G>>>0>1>>>0){s=(c[e+104>>2]|0)-2|0;N=1;S=M;M=L;while(1){I=s-M|0;V=0;U=M;while(1){if((V|0)>=(I|0)){W=U;break}X=d[u+(U>>>3)|0]|0;Y=((U|0)<(Q|0))+U|0;c[r>>2]=Y;if((X&128>>>((U&7)>>>0)|0)==0){W=Y;break}else{V=V+1|0;U=Y}}U=d[u+(W>>>3)|0]<<(W&7);I=((W|0)<(Q|0))+W|0;c[r>>2]=I;R=u+(I>>>3)|0;Y=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(I&7)>>>31;R=I+1|0;I=Q>>>0>R>>>0?R:Q;c[r>>2]=I;R=((Y|V<<1)^(U>>>7&1)-1)+S|0;c[h+(N<<2)>>2]=R;U=N+1|0;if(U>>>0<G>>>0){N=U;S=R;M=I}else{Z=I;break}}}else{Z=L}M=0;while(1){S=h+(M<<2)|0;N=c[S>>2]|0;c[j+(M<<2)>>2]=N&15;c[S>>2]=N>>>4;N=M+1|0;if(N>>>0<G>>>0){M=N}else{O=Z;P=Q;break}}}}while(0);Z=1;while(1){if(!(Z>>>0<G>>>0)){break}if((c[h+(Z<<2)>>2]|0)>>>0>32>>>0){F=27;break}else{Z=Z+1|0}}if((F|0)==27){yDb(y,16,2355096,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;x=-1094995529;i=g;return x|0}Z=d[u+(O>>>3)|0]|0;W=((O|0)<(P|0))+O|0;c[r>>2]=W;if((Z&128>>>((O&7)>>>0)|0)!=0){O=u+(W>>>3)|0;Z=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(W&7)>>>28;O=W+4|0;c[r>>2]=P>>>0>O>>>0?O:P;c[q>>2]=Z+1}if((c[v>>2]|0)==0){F=32}else{if((c[f+56>>2]|0)==0){F=32}else{_=1}}if((F|0)==32){_=(c[q>>2]|0)!=0|0}c[c[f+24>>2]>>2]=_;do{if((c[e+76>>2]|0)==0){do{if((c[e+32>>2]|0)==0){_=c[e+44>>2]|0;c[C>>2]=_;$=_}else{_=((c[z>>2]|0)>>>3)-1|0;q=e+44|0;v=(c[q>>2]|0)+1|0;if((_|0)<2){aa=2}else{aa=(((_|0)>(v|0)?v:_)<<1)-2|0}_=aa>>>0>65535>>>0;v=_?aa>>>16:aa;Z=_?16:0;if((v&65280|0)==0){ba=Z;ca=v}else{ba=Z|8;ca=v>>>8}v=(d[1191992+ca|0]|0)+ba|0;Z=c[r>>2]|0;_=c[w>>2]|0;P=u+(Z>>>3)|0;O=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Z&7)>>>((32-v|0)>>>0);P=v+Z|0;c[r>>2]=_>>>0>P>>>0?P:_;c[C>>2]=O;_=c[q>>2]|0;if(!(O>>>0>_>>>0)){$=O;break}c[C>>2]=_;yDb(y,16,2334888,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;x=-1094995529;i=g;return x|0}}while(0);_=c[z>>2]|0;if($>>>0>_>>>0){c[C>>2]=_;yDb(y,16,2334888,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;x=-1094995529;i=g;return x|0}if(($|0)==0){da=0;break}_=e+36|0;if((c[_>>2]|0)==3){O=c[r>>2]|0;q=c[w>>2]|0;P=u+(O>>>3)|0;Z=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(O&7)>>>25;P=O+7|0;c[r>>2]=q>>>0>P>>>0?P:q;c[E>>2]=b[592704+(Z<<1)>>1]<<5;if(!($>>>0>1>>>0)){da=$;break}Z=c[r>>2]|0;q=c[w>>2]|0;P=u+(Z>>>3)|0;O=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Z&7)>>>25;P=Z+7|0;c[r>>2]=q>>>0>P>>>0?P:q;c[E+4>>2]=(b[592704+(O<<1)>>1]|0)*-32|0;if($>>>0>2>>>0){ea=2}else{da=2;break}while(1){O=c[r>>2]|0;q=c[w>>2]|0;P=u+(O>>>3)|0;Z=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(O&7)>>>25;P=O+7|0;c[r>>2]=q>>>0>P>>>0?P:q;c[E+(ea<<2)>>2]=Z;Z=ea+1|0;if(Z>>>0<$>>>0){ea=Z}else{fa=1040384;break}}}else{Z=$>>>0>20>>>0?20:$;q=e+104|0;P=0;while(1){if(!(P>>>0<Z>>>0)){break}O=c[_>>2]|0;v=a[592960+(O*40|0)+(P<<1)+1|0]|0;W=v<<24>>24;J=a[592960+(O*40|0)+(P<<1)|0]|0;O=c[r>>2]|0;T=(c[q>>2]|0)-(O+W)|0;B=0;Q=O;while(1){if((B|0)>=(T|0)){ga=Q;break}O=d[u+(Q>>>3)|0]|0;M=((Q|0)<(c[w>>2]|0))+Q|0;c[r>>2]=M;if((O&128>>>((Q&7)>>>0)|0)==0){ga=M;break}else{B=B+1|0;Q=M}}Q=v<<24>>24!=0;do{if(Q){T=d[u+(ga>>>3)|0]<<(ga&7)>>>7;V=c[w>>2]|0;M=((ga|0)<(V|0))+ga|0;c[r>>2]=M;O=T&1;if(!((v&255)>>>0>1>>>0)){ha=O;F=62;break}T=W-1|0;L=B<<T;do{if((T|0)==0){ia=0}else{N=u+(M>>>3)|0;S=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(M&7);if((T|0)<26){N=M+T|0;c[r>>2]=V>>>0>N>>>0?N:V;ia=S>>>((33-W|0)>>>0);break}else{N=M+16|0;s=V>>>0>N>>>0?N:V;c[r>>2]=s;N=W-17|0;I=u+(s>>>3)|0;R=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(s&7)>>>((49-W|0)>>>0);I=s+N|0;c[r>>2]=V>>>0>I>>>0?I:V;ia=R|S>>>16<<N;break}}}while(0);ja=ia+L|0;ka=O}else{ha=B&1^1;F=62}}while(0);if((F|0)==62){F=0;ja=B>>(Q&1^1);ka=ha}la=(((ka|0)==0)<<31>>31^ja)+J|0;c[E+(P<<2)>>2]=la;if((la+64|0)>>>0>127>>>0){F=64;break}else{P=P+1|0}}if((F|0)==64){yDb(y,16,2309872,(K=i,i=i+8|0,c[K>>2]=la,K)|0);i=K;x=-1094995529;i=g;return x|0}_=$>>>0>127>>>0?127:$;if(P>>>0<_>>>0){Z=P;do{W=c[r>>2]|0;v=-2-W+(c[q>>2]|0)|0;V=0;M=W;while(1){if((V|0)>=(v|0)){F=70;break}W=d[u+(M>>>3)|0]|0;T=c[w>>2]|0;N=((M|0)<(T|0))+M|0;c[r>>2]=N;if((W&128>>>((M&7)>>>0)|0)==0){ma=N;na=T;break}else{V=V+1|0;M=N}}if((F|0)==70){F=0;ma=M;na=c[w>>2]|0}v=d[u+(ma>>>3)|0]<<(ma&7);J=((ma|0)<(na|0))+ma|0;c[r>>2]=J;Q=u+(J>>>3)|0;B=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(J&7)>>>31;Q=J+1|0;c[r>>2]=na>>>0>Q>>>0?Q:na;c[E+(Z<<2)>>2]=((B|V<<1)^(v>>>7&1)-1)+(Z&1);Z=Z+1|0;}while(Z>>>0<_>>>0);oa=$>>>0<127>>>0?$:127}else{oa=P}if(oa>>>0<$>>>0){_=oa;do{Z=c[r>>2]|0;v=(c[q>>2]|0)+~Z|0;B=0;Q=Z;while(1){if((B|0)>=(v|0)){F=75;break}Z=d[u+(Q>>>3)|0]|0;J=c[w>>2]|0;N=((Q|0)<(J|0))+Q|0;c[r>>2]=N;if((Z&128>>>((Q&7)>>>0)|0)==0){pa=N;qa=J;break}else{B=B+1|0;Q=N}}if((F|0)==75){F=0;pa=Q;qa=c[w>>2]|0}v=d[u+(pa>>>3)|0]<<(pa&7);c[r>>2]=((pa|0)<(qa|0))+pa;c[E+(_<<2)>>2]=(v>>>7&1)-1^B;_=_+1|0;}while(_>>>0<$>>>0)}c[E>>2]=b[592704+((c[E>>2]|0)+64<<1)>>1]<<5;if(!($>>>0>1>>>0)){da=$;break}_=E+4|0;c[_>>2]=(b[592704+((c[_>>2]|0)+64<<1)>>1]|0)*-32|0;fa=8192}if($>>>0>2>>>0){ra=2}else{da=$;break}while(1){_=E+(ra<<2)|0;c[_>>2]=(c[_>>2]<<14)+fa;_=ra+1|0;if(_>>>0<$>>>0){ra=_}else{da=$;break}}}else{da=D}}while(0);do{if((c[e+40>>2]|0)!=0){D=c[r>>2]|0;$=d[u+(D>>>3)|0]<<(D&7)>>>7;c[r>>2]=((D|0)<(c[w>>2]|0))+D;D=$&1;c[c[f+28>>2]>>2]=D;if((D|0)==0){break}D=c[r>>2]|0;$=e+104|0;ra=(c[$>>2]|0)+~D|0;fa=0;E=D;while(1){if((fa|0)>=(ra|0)){F=86;break}D=d[u+(E>>>3)|0]|0;pa=c[w>>2]|0;qa=((E|0)<(pa|0))+E|0;c[r>>2]=qa;if((D&128>>>((E&7)>>>0)|0)==0){sa=qa;ta=pa;break}else{fa=fa+1|0;E=qa}}if((F|0)==86){sa=E;ta=c[w>>2]|0}ra=d[u+(sa>>>3)|0]<<(sa&7);c[r>>2]=((sa|0)<(ta|0))+sa;qa=c[f+36>>2]|0;c[qa>>2]=((ra>>>7&1)+536870911^fa)<<3;ra=c[r>>2]|0;pa=-2-ra+(c[$>>2]|0)|0;D=0;oa=ra;while(1){if((D|0)>=(pa|0)){F=90;break}ra=d[u+(oa>>>3)|0]|0;na=c[w>>2]|0;ma=((oa|0)<(na|0))+oa|0;c[r>>2]=ma;if((ra&128>>>((oa&7)>>>0)|0)==0){ua=ma;va=na;break}else{D=D+1|0;oa=ma}}if((F|0)==90){ua=oa;va=c[w>>2]|0}pa=d[u+(ua>>>3)|0]<<(ua&7);fa=((ua|0)<(va|0))+ua|0;c[r>>2]=fa;E=u+(fa>>>3)|0;ma=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(fa&7)>>>31;E=fa+1|0;c[r>>2]=va>>>0>E>>>0?E:va;c[qa+4>>2]=((ma|D<<1)^(pa>>>7&1)+536870911)<<3;pa=0;ma=c[r>>2]|0;while(1){if((pa|0)>=3){F=94;break}E=d[u+(ma>>>3)|0]|0;fa=c[w>>2]|0;na=((ma|0)<(fa|0))+ma|0;c[r>>2]=na;if((E&128>>>((ma&7)>>>0)|0)==0){wa=na;xa=fa;break}else{pa=pa+1|0;ma=na}}if((F|0)==94){wa=ma;xa=c[w>>2]|0}D=u+(wa>>>3)|0;oa=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(wa&7)>>>30;D=wa+2|0;c[r>>2]=xa>>>0>D>>>0?D:xa;c[qa+8>>2]=d[688352+(pa<<2)+oa|0]|0;oa=c[r>>2]|0;D=-2-oa+(c[$>>2]|0)|0;na=0;fa=oa;while(1){if((na|0)>=(D|0)){F=98;break}oa=d[u+(fa>>>3)|0]|0;E=c[w>>2]|0;ra=((fa|0)<(E|0))+fa|0;c[r>>2]=ra;if((oa&128>>>((fa&7)>>>0)|0)==0){ya=ra;za=E;break}else{na=na+1|0;fa=ra}}if((F|0)==98){ya=fa;za=c[w>>2]|0}D=d[u+(ya>>>3)|0]<<(ya&7);pa=((ya|0)<(za|0))+ya|0;c[r>>2]=pa;ma=u+(pa>>>3)|0;ra=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(pa&7)>>>31;ma=pa+1|0;c[r>>2]=za>>>0>ma>>>0?ma:za;c[qa+12>>2]=((ra|na<<1)^(D>>>7&1)+536870911)<<3;D=c[r>>2]|0;ra=(c[$>>2]|0)+~D|0;ma=0;pa=D;while(1){if((ma|0)>=(ra|0)){F=102;break}D=d[u+(pa>>>3)|0]|0;E=c[w>>2]|0;oa=((pa|0)<(E|0))+pa|0;c[r>>2]=oa;if((D&128>>>((pa&7)>>>0)|0)==0){Aa=oa;Ba=E;break}else{ma=ma+1|0;pa=oa}}if((F|0)==102){Aa=pa;Ba=c[w>>2]|0}ra=d[u+(Aa>>>3)|0]<<(Aa&7);c[r>>2]=((Aa|0)<(Ba|0))+Aa;c[qa+16>>2]=((ra>>>7&1)+536870911^ma)<<3;ra=c[e+1400>>2]|0;$=c[r>>2]|0;na=c[w>>2]|0;fa=u+($>>>3)|0;oa=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<($&7)>>>((32-ra|0)>>>0);fa=$+ra|0;c[r>>2]=na>>>0>fa>>>0?fa:na;na=da+1|0;c[c[f+32>>2]>>2]=oa+(na>>>0<4>>>0?4:na)}}while(0);if((c[f+4>>2]|0)==0){Ca=0}else{do{if((da|0)!=0){Aa=c[y+796>>2]|0;Ba=Aa-4|0;za=c[r>>2]|0;ya=e+104|0;xa=4-Aa-za+(c[ya>>2]|0)|0;wa=0;va=za;while(1){if((wa|0)>=(xa|0)){Da=va;break}za=d[u+(va>>>3)|0]|0;ua=((va|0)<(c[w>>2]|0))+va|0;c[r>>2]=ua;if((za&128>>>((va&7)>>>0)|0)==0){Da=ua;break}else{wa=wa+1|0;va=ua}}va=(Ba|0)!=0;do{if(va){xa=d[u+(Da>>>3)|0]<<(Da&7)>>>7;ma=c[w>>2]|0;qa=((Da|0)<(ma|0))+Da|0;c[r>>2]=qa;pa=xa&1;if(!(Ba>>>0>1>>>0)){Ea=pa;F=118;break}xa=Aa-5|0;ua=wa<<xa;do{if((xa|0)==0){Fa=0}else{za=u+(qa>>>3)|0;sa=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(qa&7);if((xa|0)<26){za=qa+xa|0;c[r>>2]=ma>>>0>za>>>0?za:ma;Fa=sa>>>((37-Aa|0)>>>0);break}else{za=qa+16|0;ta=ma>>>0>za>>>0?za:ma;c[r>>2]=ta;za=Aa-21|0;na=u+(ta>>>3)|0;oa=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ta&7)>>>((53-Aa|0)>>>0);na=ta+za|0;c[r>>2]=ma>>>0>na>>>0?na:ma;Fa=oa|sa>>>16<<za;break}}}while(0);Ga=Fa+ua|0;Ha=pa}else{Ea=wa&1^1;F=118}}while(0);if((F|0)==118){Ga=wa>>(va&1^1);Ha=Ea}Aa=c[f+48>>2]|0;c[Aa>>2]=((Ha|0)==0)<<31>>31^Ga;if(!(da>>>0>1>>>0)){break}Ba=c[h>>2]|0;ma=Ba+3|0;qa=e+1388|0;xa=c[qa>>2]|0;B=ma>>>0>xa>>>0?xa:ma;ma=c[r>>2]|0;xa=(c[ya>>2]|0)-(B+ma)|0;Q=0;za=ma;while(1){if((Q|0)>=(xa|0)){Ia=za;break}ma=d[u+(za>>>3)|0]|0;sa=((za|0)<(c[w>>2]|0))+za|0;c[r>>2]=sa;if((ma&128>>>((za&7)>>>0)|0)==0){Ia=sa;break}else{Q=Q+1|0;za=sa}}za=(B|0)!=0;do{if(za){xa=d[u+(Ia>>>3)|0]<<(Ia&7)>>>7;va=c[w>>2]|0;wa=((Ia|0)<(va|0))+Ia|0;c[r>>2]=wa;sa=xa&1;if(!(B>>>0>1>>>0)){Ja=sa;F=131;break}xa=B-1|0;ma=Q<<xa;do{if((xa|0)==0){Ka=0}else{oa=u+(wa>>>3)|0;na=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(wa&7);if((xa|0)<26){oa=wa+xa|0;c[r>>2]=va>>>0>oa>>>0?oa:va;Ka=na>>>((33-B|0)>>>0);break}else{oa=wa+16|0;ta=va>>>0>oa>>>0?oa:va;c[r>>2]=ta;oa=B-17|0;fa=u+(ta>>>3)|0;ra=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ta&7)>>>((49-B|0)>>>0);fa=ta+oa|0;c[r>>2]=va>>>0>fa>>>0?fa:va;Ka=ra|na>>>16<<oa;break}}}while(0);La=Ka+ma|0;Ma=sa}else{Ja=Q&1^1;F=131}}while(0);if((F|0)==131){La=Q>>(za&1^1);Ma=Ja}c[Aa+4>>2]=((Ma|0)==0)<<31>>31^La;if(!(da>>>0>2>>>0)){break}B=Ba+1|0;va=c[qa>>2]|0;wa=B>>>0>va>>>0?va:B;B=c[r>>2]|0;va=(c[ya>>2]|0)-(wa+B)|0;xa=0;pa=B;while(1){if((xa|0)>=(va|0)){Na=pa;break}B=d[u+(pa>>>3)|0]|0;ua=((pa|0)<(c[w>>2]|0))+pa|0;c[r>>2]=ua;if((B&128>>>((pa&7)>>>0)|0)==0){Na=ua;break}else{xa=xa+1|0;pa=ua}}pa=(wa|0)!=0;do{if(pa){va=d[u+(Na>>>3)|0]<<(Na&7)>>>7;ya=c[w>>2]|0;qa=((Na|0)<(ya|0))+Na|0;c[r>>2]=qa;Ba=va&1;if(!(wa>>>0>1>>>0)){Oa=Ba;F=144;break}va=wa-1|0;za=xa<<va;do{if((va|0)==0){Pa=0}else{Q=u+(qa>>>3)|0;ua=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(qa&7);if((va|0)<26){Q=qa+va|0;c[r>>2]=ya>>>0>Q>>>0?Q:ya;Pa=ua>>>((33-wa|0)>>>0);break}else{Q=qa+16|0;B=ya>>>0>Q>>>0?Q:ya;c[r>>2]=B;Q=wa-17|0;oa=u+(B>>>3)|0;na=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(B&7)>>>((49-wa|0)>>>0);oa=B+Q|0;c[r>>2]=ya>>>0>oa>>>0?oa:ya;Pa=na|ua>>>16<<Q;break}}}while(0);Qa=Pa+za|0;Ra=Ba}else{Oa=xa&1^1;F=144}}while(0);if((F|0)==144){Qa=xa>>(pa&1^1);Ra=Oa}c[Aa+8>>2]=((Ra|0)==0)<<31>>31^Qa}}while(0);Ca=da>>>0>3>>>0?3:da}if((c[A>>2]|0)==0){A=e+104|0;da=(c[f+48>>2]|0)+(Ca<<2)|0;Qa=0;Ra=Ca;while(1){if(Ra>>>0<H>>>0){Oa=h+(Qa<<2)|0;Pa=da;Na=Ra;while(1){La=c[Oa>>2]|0;Ma=c[r>>2]|0;Ja=(c[A>>2]|0)-(Ma+La)|0;Ka=0;Ia=Ma;while(1){if((Ka|0)>=(Ja|0)){Sa=Ia;break}Ma=d[u+(Ia>>>3)|0]|0;Ga=((Ia|0)<(c[w>>2]|0))+Ia|0;c[r>>2]=Ga;if((Ma&128>>>((Ia&7)>>>0)|0)==0){Sa=Ga;break}else{Ka=Ka+1|0;Ia=Ga}}Ia=(La|0)!=0;do{if(Ia){Ja=d[u+(Sa>>>3)|0]<<(Sa&7)>>>7;Ba=c[w>>2]|0;za=((Sa|0)<(Ba|0))+Sa|0;c[r>>2]=za;Ga=Ja&1;if(!(La>>>0>1>>>0)){Ta=Ga;F=196;break}Ja=La-1|0;Ma=Ka<<Ja;do{if((Ja|0)==0){Ua=0}else{Ha=u+(za>>>3)|0;Ea=(fe(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(za&7);if((Ja|0)<26){Ha=za+Ja|0;c[r>>2]=Ba>>>0>Ha>>>0?Ha:Ba;Ua=Ea>>>((33-La|0)>>>0);break}else{Ha=za+16|0;Fa=Ba>>>0>Ha>>>0?Ha:Ba;c[r>>2]=Fa;Ha=La-17|0;Da=u+(Fa>>>3)|0;y=(fe(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Fa&7)>>>((49-La|0)>>>0);Da=Fa+Ha|0;c[r>>2]=Ba>>>0>Da>>>0?Da:Ba;Ua=y|Ea>>>16<<Ha;break}}}while(0);Va=Ua+Ma|0;Wa=Ga}else{Ta=Ka&1^1;F=196}}while(0);if((F|0)==196){F=0;Va=Ka>>(Ia&1^1);Wa=Ta}c[Pa>>2]=((Wa|0)==0)<<31>>31^Va;La=Na+1|0;if(!(La>>>0<H>>>0)){break}Pa=Pa+4|0;Na=La}Xa=da+(H-Ra<<2)|0}else{Xa=da}Na=Qa+1|0;if(Na>>>0<G>>>0){da=Xa;Qa=Na;Ra=0}else{break}}}else{Ra=(c[z>>2]<<1)-2|0;z=Ra>>>0>65535>>>0;Qa=z?Ra>>>16:Ra;Ra=z?16:0;if((Qa&65280|0)==0){Ya=Ra;Za=Qa}else{Ya=Ra|8;Za=Qa>>>8}Qa=Ya-3+(d[1191992+Za|0]|0)>>1;if((Qa|0)<0){_a=0}else{_a=(Qa|0)>5?5:Qa}l_(p,m,n,o);Qa=f+48|0;f=e+1392|0;Za=e+1396|0;Ya=(c[Qa>>2]|0)+(Ca<<2)|0;Ra=0;while(1){z=H-((Ra|0)!=0?0:Ca)|0;Xa=c[h+(Ra<<2)>>2]|0;da=Xa>>>0>_a>>>0?Xa-_a|0:0;c[l+(Ra<<2)>>2]=da;Va=da+(5-Xa)|0;c[k+(Ra<<2)>>2]=Va;n_(p,z,Ya,Va,c[j+(Ra<<2)>>2]|0,m,n,o,c[f>>2]|0,c[Za>>2]|0);Va=Ra+1|0;if(!(Va>>>0<G>>>0)){break}Ya=Ya+(z<<2)|0;Ra=Va}m_(p);p=e+104|0;Ra=(c[Qa>>2]|0)+(Ca<<2)|0;Qa=0;Ya=Ca;while(1){Ca=k+(Qa<<2)|0;Za=j+(Qa<<2)|0;f=d[(c[Ca>>2]|0)+(189976+((c[Za>>2]|0)*6|0))|0]|0;o=c[l+(Qa<<2)>>2]|0;n=c[h+(Qa<<2)>>2]|0;if(Ya>>>0<H>>>0){m=(n|0)!=0;_a=n>>>0>1>>>0;Va=n-1|0;z=(Va|0)==0;Xa=(Va|0)<26;da=33-n|0;Wa=n-17|0;Ta=49-n|0;Ua=m&1^1;u=(o|0)==0;Sa=(o|0)<26;A=32-o|0;Na=o-16|0;Pa=48-o|0;Oa=Ra;Aa=Ya;while(1){pa=c[Oa>>2]|0;do{if((pa|0)==(f|0)){xa=c[Za>>2]|0;La=(xa>>>0>2>>>0|2)+(xa>>>0>10>>>0)<<5-(c[Ca>>2]|0);xa=c[r>>2]|0;Ba=(c[p>>2]|0)-(xa+n)|0;za=0;Ja=xa;while(1){if((za|0)>=(Ba|0)){$a=Ja;break}xa=d[(c[t>>2]|0)+(Ja>>>3)|0]|0;O=((Ja|0)<(c[w>>2]|0))+Ja|0;c[r>>2]=O;if((xa&128>>>((Ja&7)>>>0)|0)==0){$a=O;break}else{za=za+1|0;Ja=O}}do{if(m){Ja=c[t>>2]|0;Ba=d[Ja+($a>>>3)|0]<<($a&7)>>>7;Ga=c[w>>2]|0;Ma=(($a|0)<(Ga|0))+$a|0;c[r>>2]=Ma;O=Ba&1;if(!_a){ab=O;F=170;break}Ba=za<<Va;do{if(z){bb=0}else{xa=Ja+(Ma>>>3)|0;L=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ma&7);if(Xa){xa=Ma+Va|0;c[r>>2]=Ga>>>0>xa>>>0?xa:Ga;bb=L>>>(da>>>0);break}else{xa=Ma+16|0;Ha=Ga>>>0>xa>>>0?xa:Ga;c[r>>2]=Ha;xa=Ja+(Ha>>>3)|0;Ea=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ha&7)>>>(Ta>>>0);xa=Ha+Wa|0;c[r>>2]=Ga>>>0>xa>>>0?xa:Ga;bb=Ea|L>>>16<<Wa;break}}}while(0);cb=bb+Ba|0;db=O}else{ab=za&1^1;F=170}}while(0);if((F|0)==170){F=0;cb=za>>Ua;db=ab}Ga=((db|0)==0)<<31>>31^cb;if((Ga|0)>-1){eb=Ga+(La<<o)|0;break}else{eb=Ga-(La-1<<o)|0;break}}else{Ga=((pa>>>0>f>>>0)<<31>>31)+pa|0;Ja=((Ga&1|0)==0?Ga:-Ga|0)>>1;if(u){eb=Ja;break}Ga=c[r>>2]|0;Ma=c[w>>2]|0;L=c[t>>2]|0;Ea=L+(Ga>>>3)|0;xa=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ga&7);if(Sa){Ea=Ga+o|0;c[r>>2]=Ma>>>0>Ea>>>0?Ea:Ma;fb=xa>>>(A>>>0)}else{Ea=Ga+16|0;Ga=Ma>>>0>Ea>>>0?Ea:Ma;c[r>>2]=Ga;Ea=L+(Ga>>>3)|0;L=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ga&7)>>>(Pa>>>0);Ea=Ga+Na|0;c[r>>2]=Ma>>>0>Ea>>>0?Ea:Ma;fb=L|xa>>>16<<Na}eb=fb|Ja<<o}}while(0);c[Oa>>2]=eb;pa=Aa+1|0;if(pa>>>0<H>>>0){Oa=Oa+4|0;Aa=pa}else{break}}gb=Ra+(H-Ya<<2)|0}else{gb=Ra}Aa=Qa+1|0;if(Aa>>>0<G>>>0){Ra=gb;Qa=Aa;Ya=0}else{break}}}do{if((c[e+64>>2]|0)!=0){if((c[e+1376>>2]|0)==0){x=0}else{break}i=g;return x|0}}while(0);e=c[r>>2]|0;Ya=-e&7;if((Ya|0)==0){x=0;i=g;return x|0}Qa=c[w>>2]|0;w=Ya+e|0;c[r>>2]=Qa>>>0>w>>>0?w:Qa;x=0;i=g;return x|0}function SX(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;h=i;j=c[d+(g<<2)>>2]|0;k=a|0;l=c[(c[k>>2]|0)+416>>2]|0;m=e+(g<<2)|0;if((c[m>>2]|0)!=0){n=0;i=h;return n|0}c[m>>2]=1;a:do{if((l|0)==0){o=0}else{m=0;while(1){if((c[j+(m*44|0)>>2]|0)!=0){o=m;break a}SX(a,b,d,e,f,c[j+(m*44|0)+4>>2]|0)|0;p=m+1|0;if(p>>>0<l>>>0){m=p}else{o=p;break}}}}while(0);if((o|0)==(l|0)){yDb(c[k>>2]|0,24,1971920,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;n=-1094995529;i=h;return n|0}c[b+8>>2]=(c[a+1404>>2]|0)+(g<<2);c[b+16>>2]=(c[a+1408>>2]|0)+(g<<2);c[b+20>>2]=(c[a+1412>>2]|0)+(g<<2);c[b+24>>2]=(c[a+1416>>2]|0)+(g<<2);c[b+28>>2]=(c[a+1420>>2]|0)+(g<<2);c[b+32>>2]=(c[a+1424>>2]|0)+(g<<2);c[b+36>>2]=c[(c[a+1428>>2]|0)+(g<<2)>>2];c[b+44>>2]=c[(c[a+1444>>2]|0)+(g<<2)>>2];c[b+40>>2]=c[(c[a+1436>>2]|0)+(g<<2)>>2];k=a+1472|0;a=c[(c[k>>2]|0)+(g<<2)>>2]|0;c[b+48>>2]=a+(f<<2);if((c[j>>2]|0)!=0){n=0;i=h;return n|0}l=b|0;b=c[k>>2]|0;k=f-1|0;o=0;while(1){e=(c[l>>2]|0)-1|0;d=c[j+(o*44|0)+4>>2]|0;m=c[b+(d<<2)>>2]|0;b:do{if((d|0)!=(g|0)){if((c[j+(o*44|0)+8>>2]|0)==0){if(!(e>>>0>1>>>0)){break}p=j+(o*44|0)+20|0;q=j+(o*44|0)+24|0;r=j+(o*44|0)+28|0;s=1;while(1){t=c[p>>2]|0;u=c[m+(k+s<<2)>>2]|0;v=gHb(u,(u|0)<0|0?-1:0,t,(t|0)<0|0?-1:0)|0;t=YGb(v,F,64,0)|0;v=F;u=c[q>>2]|0;w=c[m+(s+f<<2)>>2]|0;x=gHb(w,(w|0)<0|0?-1:0,u,(u|0)<0|0?-1:0)|0;u=YGb(t,v,x,F)|0;x=F;v=c[r>>2]|0;t=s+1|0;w=c[m+(t+f<<2)>>2]|0;y=gHb(w,(w|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=YGb(u,x,y,F)|0;y=F;x=a+(s+f<<2)|0;u=YGb(v>>>7|y<<25,y>>>7|0<<25,c[x>>2]|0,0)|0;c[x>>2]=u;if(t>>>0<e>>>0){s=t}else{break b}}}s=c[j+(o*44|0)+16>>2]|0;if((c[j+(o*44|0)+12>>2]|0)==0){z=s;A=e-s|0;B=1}else{z=-s|0;A=e;B=s+1|0}if(!(B>>>0<A>>>0)){break}s=j+(o*44|0)+20|0;r=j+(o*44|0)+24|0;q=j+(o*44|0)+28|0;p=j+(o*44|0)+32|0;t=z+f|0;u=j+(o*44|0)+36|0;x=j+(o*44|0)+40|0;y=B;while(1){v=c[s>>2]|0;w=y-1|0;C=c[m+(w+f<<2)>>2]|0;D=gHb(C,(C|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=YGb(D,F,64,0)|0;D=F;C=c[r>>2]|0;E=c[m+(y+f<<2)>>2]|0;G=gHb(E,(E|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;C=YGb(v,D,G,F)|0;G=F;D=c[q>>2]|0;v=y+1|0;E=c[m+(v+f<<2)>>2]|0;H=gHb(E,(E|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;D=YGb(C,G,H,F)|0;H=F;G=c[p>>2]|0;C=c[m+(t+w<<2)>>2]|0;w=gHb(C,(C|0)<0|0?-1:0,G,(G|0)<0|0?-1:0)|0;G=YGb(D,H,w,F)|0;w=F;H=c[u>>2]|0;D=c[m+(t+y<<2)>>2]|0;C=gHb(D,(D|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;H=YGb(G,w,C,F)|0;C=F;w=c[x>>2]|0;G=c[m+(t+v<<2)>>2]|0;D=gHb(G,(G|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=YGb(H,C,D,F)|0;D=F;C=a+(y+f<<2)|0;H=YGb(w>>>7|D<<25,D>>>7|0<<25,c[C>>2]|0,0)|0;c[C>>2]=H;if(v>>>0<A>>>0){y=v}else{break}}}}while(0);m=o+1|0;if((c[j+(m*44|0)>>2]|0)==0){o=m}else{n=0;break}}i=h;return n|0}function TX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=b|0;e=c[d>>2]|0;do{if((c[c[b+8>>2]>>2]|0)==0){f=c[c[b+20>>2]>>2]|0;g=c[b+40>>2]|0;h=c[b+44>>2]|0;i=b+48|0;j=c[i>>2]|0;k=j+(e<<2)|0;l=c[a+1452>>2]|0;a:do{if((c[c[b+28>>2]>>2]|0)!=0){m=c[b+32>>2]|0;n=c[m>>2]|0;o=n-2|0;p=(o|0)>0?o:0;if(!(p>>>0<e>>>0)){break}o=b+36|0;q=p;p=n;while(1){n=q-p|0;r=n-2|0;s=(r|0)<0?0:r;r=n+3|0;if((s|0)<(r|0)){t=c[o>>2]|0;u=0;v=64;w=2-n+s|0;n=s;while(1){s=c[t+(w<<2)>>2]|0;x=c[j+(n<<2)>>2]|0;y=gHb(x,(x|0)<0|0?-1:0,s,(s|0)<0|0?-1:0)|0;z=YGb(y,F,v,u)|0;A=F;y=n+1|0;if((y|0)<(r|0)){u=A;v=z;w=w+1|0;n=y}else{break}}B=A>>>7|0<<25;C=z>>>7|A<<25}else{B=0;C=0}n=j+(q<<2)|0;w=YGb(c[n>>2]|0,0,C,B)|0;c[n>>2]=w;w=q+1|0;if(!(w>>>0<e>>>0)){break a}q=w;p=c[m>>2]|0}}}while(0);m=(f|0)==0;do{if((c[b+4>>2]|0)==0){if(!m){p=0;do{q=p-1|0;o=g+(p<<2)|0;if((q|0)>0){w=0;n=q;while(1){v=c[o>>2]|0;u=v;r=(v|0)<0|0?-1:0;v=h+(n<<2)|0;t=c[v>>2]|0;y=t;s=(t|0)<0|0?-1:0;t=gHb(y,s,u,r)|0;x=YGb(t,F,524288,0)|0;t=x>>>20|F<<12;x=h+(w<<2)|0;D=c[x>>2]|0;E=gHb(D,(D|0)<0|0?-1:0,u,r)|0;r=YGb(E,F,524288,0)|0;E=F;u=YGb(r>>>20|E<<12,E>>>20|0<<12,y,s)|0;c[v>>2]=u;c[x>>2]=t+(c[x>>2]|0);x=w+1|0;t=n-1|0;if((x|0)<(t|0)){w=x;n=t}else{G=x;H=t;break}}}else{G=0;H=q}if((G|0)==(H|0)){n=c[o>>2]|0;w=h+(H<<2)|0;t=c[w>>2]|0;x=gHb(t,(t|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=YGb(x,F,524288,0)|0;x=F;u=YGb(n>>>20|x<<12,x>>>20|0<<12,t,0)|0;c[w>>2]=u}c[h+(p<<2)>>2]=c[o>>2];p=p+1|0;}while(p>>>0<f>>>0)}if((c[c[b+24>>2]>>2]|0)!=0){p=c[a+44>>2]|0;UGb(c[b+52>>2]|0,j+(-p<<2)|0,p<<2)|0}do{if((c[b+12>>2]|0)!=0){p=c[b+56>>2]|0;if((p|0)==0){break}u=p>>>0>j>>>0;w=u?j:p;t=u?p:j;p=a+44|0;if((-(c[p>>2]|0)|0)>-1){break}else{I=-1}do{c[j+(I<<2)>>2]=(c[t+(I<<2)>>2]|0)-(c[w+(I<<2)>>2]|0);I=I-1|0;}while((I|0)>=(-(c[p>>2]|0)|0))}}while(0);p=c[b+16>>2]|0;w=c[p>>2]|0;if((w|0)==0){J=0;K=39;break}t=a+44|0;if((-(c[t>>2]|0)|0)>-1){J=0;K=39;break}o=j-4|0;c[o>>2]=c[o>>2]>>w;if((-(c[t>>2]|0)|0)>-2){J=0;K=39;break}else{L=-2}while(1){w=j+(L<<2)|0;c[w>>2]=c[w>>2]>>c[p>>2];w=L-1|0;if((w|0)<(-(c[t>>2]|0)|0)){J=0;K=39;break}else{L=w}}}else{if(m){M=0;N=0;break}else{O=j;P=0}while(1){if((P|0)==0){Q=0;R=0}else{t=0;p=524288;w=0;while(1){o=c[h+(w<<2)>>2]|0;q=w+1|0;u=c[O+(~w<<2)>>2]|0;x=gHb(u,(u|0)<0|0?-1:0,o,(o|0)<0|0?-1:0)|0;S=YGb(x,F,p,t)|0;T=F;if(q>>>0<P>>>0){t=T;p=S;w=q}else{break}}Q=T>>>20|0<<12;R=S>>>20|T<<12}w=O+4|0;p=ZGb(c[O>>2]|0,0,R,Q)|0;c[O>>2]=p;p=P-1|0;t=g+(P<<2)|0;if((p|0)>0){q=0;x=p;while(1){o=c[t>>2]|0;u=o;n=(o|0)<0|0?-1:0;o=h+(x<<2)|0;v=c[o>>2]|0;s=v;y=(v|0)<0|0?-1:0;v=gHb(s,y,u,n)|0;E=YGb(v,F,524288,0)|0;v=E>>>20|F<<12;E=h+(q<<2)|0;r=c[E>>2]|0;D=gHb(r,(r|0)<0|0?-1:0,u,n)|0;n=YGb(D,F,524288,0)|0;D=F;u=YGb(n>>>20|D<<12,D>>>20|0<<12,s,y)|0;c[o>>2]=u;c[E>>2]=v+(c[E>>2]|0);E=q+1|0;v=x-1|0;if((E|0)<(v|0)){q=E;x=v}else{U=E;V=v;break}}}else{U=0;V=p}if((U|0)==(V|0)){x=c[t>>2]|0;q=h+(V<<2)|0;v=c[q>>2]|0;E=gHb(v,(v|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=YGb(E,F,524288,0)|0;E=F;u=YGb(x>>>20|E<<12,E>>>20|0<<12,v,0)|0;c[q>>2]=u}c[h+(P<<2)>>2]=c[t>>2];u=P+1|0;if(u>>>0<f>>>0){O=w;P=u}else{J=f;K=39;break}}}}while(0);do{if((K|0)==39){if((f|0)>0){W=0}else{M=J;N=0;break}while(1){g=W+1|0;c[l+(W<<2)>>2]=c[h+(f+~W<<2)>>2];if((g|0)<(f|0)){W=g}else{M=J;N=1;break}}}}while(0);h=c[i>>2]|0;g=h+(M<<2)|0;b:do{if(g>>>0<k>>>0){j=-f|0;if(N){X=g}else{m=g;while(1){m=m+4|0;if(!(m>>>0<k>>>0)){break b}}}do{m=0;u=524288;q=j;do{v=c[l+(q+f<<2)>>2]|0;E=c[X+(q<<2)>>2]|0;x=gHb(E,(E|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;u=YGb(x,F,u,m)|0;m=F;q=q+1|0;}while((q|0)<0);q=ZGb(c[X>>2]|0,0,u>>>20|m<<12,m>>>20|0<<12)|0;c[X>>2]=q;X=X+4|0;}while(X>>>0<k>>>0)}}while(0);if((c[c[b+24>>2]>>2]|0)==0){break}k=c[a+44>>2]|0;UGb(h+(-k<<2)|0,c[b+52>>2]|0,k<<2)|0}else{k=c[b+48>>2]|0;f=c[k>>2]|0;l=e-1|0;if((l|0)==0){break}else{Y=k;Z=l}do{Y=Y+4|0;c[Y>>2]=f;Z=Z-1|0;}while((Z|0)!=0)}}while(0);Z=c[b+16>>2]|0;Y=c[Z>>2]|0;if((Y|0)==0){return}if((c[d>>2]|0)==0){return}e=c[b+48>>2]|0;b=0;a=Y;while(1){Y=e+(b<<2)|0;c[Y>>2]=c[Y>>2]<<a;Y=b+1|0;if(!(Y>>>0<(c[d>>2]|0)>>>0)){break}b=Y;a=c[Z>>2]|0}return}function UX(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a:do{if(b>>>0<31>>>0){g=b;h=d;while(1){if((1073741824>>>(g>>>0)&a|0)==0){i=h;break a}j=g<<1;k=h+1|0;UX(a,j|1,k,e,f);l=j+2|0;if(l>>>0<31>>>0){g=l;h=k}else{i=k;break}}}else{i=d}}while(0);d=c[e>>2]|0;c[d>>2]=i;c[e>>2]=d+4;c[f>>2]=(c[f>>2]|0)+1;return}function VX(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0.0;e=i;f=c[d+60>>2]|0;j=d+416|0;if((c[j>>2]|0)>1){EDb(d,1971896,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=e;return l|0}c[j>>2]=1;j=d+448|0;c[j>>2]=4;c[j+4>>2]=0;j=d+412|0;if((c[j>>2]|0)==0){c[j>>2]=8e3}c[d+420>>2]=3;c[f+1684>>2]=f+1524;d=f+464|0;j=f+664|0;k=f+704|0;m=0;do{h[d+(m<<3)>>3]=+((a[688400+m|0]|0)*1e3|0|0)*30517578125.0e-15;n=+(b[693560+(m<<1)>>1]|0)*30517578125.0e-15;g[j+(m<<2)>>2]=n;g[k+(m<<2)>>2]=n;m=m+1|0;}while((m|0)<10);g[f+2008>>2]=-14.0;g[f+2012>>2]=-14.0;g[f+2016>>2]=-14.0;g[f+2020>>2]=-14.0;Bgb(f+2336|0);Rgb(f+2344|0);A$(f+2348|0);E$(f+2356|0);l=0;i=e;return l|0}function WX(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0.0,$=0.0,aa=0.0,ba=0.0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0.0,gc=0.0,hc=0.0,ic=0.0,jc=0,kc=0.0,lc=0.0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0.0,tc=0,uc=0.0,vc=0.0,wc=0,xc=0,yc=0,zc=0,Ac=0.0,Bc=0,Cc=0.0;m=i;i=i+1048|0;n=m|0;o=m+128|0;p=m+328|0;q=m+368|0;r=m+528|0;s=m+688|0;t=m+696|0;u=m+704|0;v=m+728|0;w=m+768|0;y=m+792|0;z=m+888|0;A=c[f+60>>2]|0;B=A;C=c[l+24>>2]|0;D=c[l+28>>2]|0;TGb(y|0,0,96)|0;c[j+76>>2]=160;l=_$a(f,j,0)|0;if((l|0)<0){E=l;i=m;return E|0}l=c[j>>2]|0;j=a[C]|0;F=(j&255)>>>3&15;a[A+114|0]=(j&255)>>>2&1^1;do{if(F>>>0>8>>>0){G=11}else{if(((d[1046616+F|0]|0)+1|0)>(D|0)){G=11;break}do{if(F>>>0<8>>>0){j=c[1795880+(F<<2)>>2]|0;TGb(A|0,0,114)|0;H=a[j]|0;if(H<<24>>24==0){break}else{I=j;J=H}while(1){H=I+2|0;j=d[I+1|0]|0;if(J<<24>>24==0){K=0;L=H}else{M=J&255;N=0;O=M;P=H;while(1){H=O-1|0;R=d[P]|0;S=(d[C+((R>>>3)+1)|0]|0)>>>((R&7)>>>0)&1|N<<1;if((H|0)==0){break}else{N=S;O=H;P=P+1|0}}K=S&65535;L=I+(M+2)|0}b[B+(j>>>1<<1)>>1]=K;P=a[L]|0;if(P<<24>>24==0){break}else{I=L;J=P}}}}while(0);P=A+116|0;c[P>>2]=F;if((F|0)==15){break}else if((F|0)==8){O=f;EDb(O,2116208,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;yDb(O,32,2056960,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;E=-1163346256;i=m;return E|0}else if((F|0)==7){O=w|0;c[O>>2]=751216+(e[A>>1]<<3);c[w+4>>2]=749168+(e[A+2>>1]<<3);N=A+4|0;H=e[N>>1]|0;c[w+8>>2]=747120+(H>>>1<<3);c[w+12>>2]=745072+(e[A+6>>1]<<3);c[w+16>>2]=744560+(e[A+8>>1]<<3);R=v|0;g[R>>2]=+(b[A+120>>1]|0)*.244140625*.65+337.8909912109375;g[v+4>>2]=+(b[A+122>>1]|0)*.244140625*.65+507.0799865722656;g[v+8>>2]=+(b[A+124>>1]|0)*.244140625*.65+834.9609985351562;g[v+12>>2]=+(b[A+126>>1]|0)*.244140625*.65+1247.0699462890625;g[v+16>>2]=+(b[A+128>>1]|0)*.244140625*.65+1646.0;g[v+20>>2]=+(b[A+130>>1]|0)*.244140625*.65+1982.9100341796875;g[v+24>>2]=+(b[A+132>>1]|0)*.244140625*.65+2407.9599609375;g[v+28>>2]=+(b[A+134>>1]|0)*.244140625*.65+2708.010009765625;g[v+32>>2]=+(b[A+136>>1]|0)*.244140625*.65+3104.0;g[v+36>>2]=+(b[A+138>>1]|0)*.244140625*.65+3344.969970703125;U=A+224|0;XX(B,U,R,O,0,H&1,0);H=A+384|0;XX(B,H,R,O,2,b[N>>1]&1,1);N=A+144|0;V=+h[U>>3]*.5;h[N>>3]=+h[A+464>>3]*.5+V;W=+h[A+232>>3]*.5;h[A+152>>3]=+h[A+472>>3]*.5+W;X=+h[A+240>>3]*.5;h[A+160>>3]=+h[A+480>>3]*.5+X;Y=+h[A+248>>3]*.5;h[A+168>>3]=+h[A+488>>3]*.5+Y;Z=+h[A+256>>3]*.5;h[A+176>>3]=+h[A+496>>3]*.5+Z;_=+h[A+264>>3]*.5;h[A+184>>3]=+h[A+504>>3]*.5+_;$=+h[A+272>>3]*.5;h[A+192>>3]=+h[A+512>>3]*.5+$;aa=+h[A+280>>3]*.5;h[A+200>>3]=+h[A+520>>3]*.5+aa;ba=+h[A+288>>3]*.5;h[A+208>>3]=+h[A+528>>3]*.5+ba;ca=+h[A+296>>3]*.5;h[A+216>>3]=+h[A+536>>3]*.5+ca;h[A+304>>3]=V+ +h[H>>3]*.5;h[A+312>>3]=W+ +h[A+392>>3]*.5;h[A+320>>3]=X+ +h[A+400>>3]*.5;h[A+328>>3]=Y+ +h[A+408>>3]*.5;h[A+336>>3]=Z+ +h[A+416>>3]*.5;h[A+344>>3]=_+ +h[A+424>>3]*.5;h[A+352>>3]=$+ +h[A+432>>3]*.5;h[A+360>>3]=aa+ +h[A+440>>3]*.5;h[A+368>>3]=ba+ +h[A+448>>3]*.5;h[A+376>>3]=ca+ +h[A+456>>3]*.5;da=N;ea=A+544|0;fa=A+2344|0}else{N=u;H=((F|0)==5?760472:763544)+((e[A>>1]|0)*6|0)|0;b[N>>1]=b[H>>1]|0;b[N+2>>1]=b[H+2>>1]|0;b[N+4>>1]=b[H+4>>1]|0;H=F>>>0<2>>>0;U=u+6|0;O=757400+((e[A+2>>1]<<(H&1))*6|0)|0;b[U>>1]=b[O>>1]|0;b[U+2>>1]=b[O+2>>1]|0;b[U+4>>1]=b[O+4>>1]|0;O=(H?752280:753304)+(e[A+4>>1]<<3)|0;H=u+12|0;U=O|0;R=O+4|0;O=e[R>>1]|e[R+2>>1]<<16;R=H|0;x=e[U>>1]|e[U+2>>1]<<16;b[R>>1]=x;b[R+2>>1]=x>>16;R=H+4|0;x=O;b[R>>1]=x;b[R+2>>1]=x>>16;R=0;do{g[v+(R<<2)>>2]=+g[752240+(R<<2)>>2]*125.0e-6+(+(b[u+(R<<1)>>1]|0)+ +(b[B+120+(R<<1)>>1]|0)*+g[562296+(R<<2)>>2])*30517578125.0e-15;R=R+1|0;}while((R|0)<10);R=v|0;KKa(R,.0062561,10);O=A+2344|0;H=A+664|0;U=A+544|0;Ge[c[O>>2]&3](U,H,R,.75,.25,10);Ge[c[O>>2]&3](A+584|0,H,R,.5,.5,10);Ge[c[O>>2]&3](A+624|0,H,R,.25,.75,10);Ge[c[O>>2]&3](H,H,R,0.0,1.0,10);UGb(A+120|0,N|0,20)|0;H=A+384|0;MKa(H,R,10);R=A+464|0;ga=A+472|0;ha=A+392|0;ia=A+480|0;ja=A+400|0;ka=A+488|0;la=A+408|0;ma=A+496|0;na=A+416|0;oa=A+504|0;pa=A+424|0;qa=A+512|0;ra=A+432|0;sa=A+520|0;ta=A+440|0;ua=A+528|0;va=A+448|0;wa=A+536|0;xa=A+456|0;ya=1;do{ca=+(ya|0);za=ya-1|0;ba=+h[R>>3];h[B+144+(za*80|0)>>3]=ba+ca*(+h[H>>3]-ba)*.25;ba=+h[ga>>3];h[B+144+(za*80|0)+8>>3]=ba+ca*(+h[ha>>3]-ba)*.25;ba=+h[ia>>3];h[B+144+(za*80|0)+16>>3]=ba+ca*(+h[ja>>3]-ba)*.25;ba=+h[ka>>3];h[B+144+(za*80|0)+24>>3]=ba+ca*(+h[la>>3]-ba)*.25;ba=+h[ma>>3];h[B+144+(za*80|0)+32>>3]=ba+ca*(+h[na>>3]-ba)*.25;ba=+h[oa>>3];h[B+144+(za*80|0)+40>>3]=ba+ca*(+h[pa>>3]-ba)*.25;ba=+h[qa>>3];h[B+144+(za*80|0)+48>>3]=ba+ca*(+h[ra>>3]-ba)*.25;ba=+h[sa>>3];h[B+144+(za*80|0)+56>>3]=ba+ca*(+h[ta>>3]-ba)*.25;ba=+h[ua>>3];h[B+144+(za*80|0)+64>>3]=ba+ca*(+h[va>>3]-ba)*.25;ba=+h[wa>>3];h[B+144+(za*80|0)+72>>3]=ba+ca*(+h[xa>>3]-ba)*.25;ya=ya+1|0;}while((ya|0)<4);da=A+144|0;ea=U;fa=O}ya=A+744|0;xa=ya;QKa(da,ya,5);QKa(da+80|0,A+784|0,5);QKa(da+160|0,A+824|0,5);QKa(da+240|0,A+864|0,5);ya=A+10|0;wa=A+904|0;va=A+2336|0;ua=A+1684|0;ta=A+1688|0;sa=y+4|0;ra=y+8|0;qa=y|0;pa=y+12|0;oa=y+16|0;na=A+2040|0;ma=A+2064|0;la=y+88|0;ka=y+92|0;ja=A+1848|0;ia=A+2356|0;ha=A+2008|0;ga=A+2060|0;H=ea;R=A+704|0;N=A+708|0;za=A+712|0;Aa=A+716|0;Ba=A+720|0;Ca=A+724|0;Da=A+728|0;Ea=A+732|0;Fa=A+736|0;Ga=A+740|0;Ha=A+2068|0;Ia=A+2069|0;Ja=z|0;Ka=A+2072|0;La=A+2077|0;Ma=q|0;Na=r|0;Oa=z;Pa=A+2076|0;Qa=A+2176|0;Ra=ta;Sa=A+2348|0;Ta=o;Ua=v;Va=A+2080|0;Wa=o+40|0;Xa=p|0;Ya=o+160|0;Za=A+2352|0;_a=v|0;$a=A+2120|0;ab=n;bb=n+40|0;cb=n+44|0;db=cb;eb=A+2124|0;fb=A+464|0;gb=A+384|0;hb=A+908|0;ib=A+1068|0;jb=A+2024|0;kb=A+2028|0;lb=A+2044|0;mb=A+2048|0;nb=A+2136|0;ob=A+2296|0;pb=jb;qb=kb;rb=A+2032|0;sb=A+2036|0;tb=lb;ub=mb;vb=A+2052|0;wb=A+2056|0;xb=y+20|0;yb=y+44|0;zb=y+60|0;Ab=y+24|0;Bb=y+48|0;Cb=y+64|0;Db=y+28|0;Eb=y+52|0;Fb=y+68|0;Gb=y+32|0;Hb=y+56|0;Ib=y+72|0;Jb=0;while(1){Kb=b[ya+(Jb*26|0)>>1]|0;Lb=c[P>>2]|0;Mb=Kb&65535;Nb=d[wa]|0;do{if((Lb|0)==7){if((Jb|0)==2|(Jb|0)==0){if((Kb&65535)>>>0<463>>>0){Ob=((Mb*10923|0)+1168761|0)>>>16;c[s>>2]=Ob;Pb=Mb+105+(Ob*-6|0)|0;c[t>>2]=Pb;Qb=Ob;Rb=0;Sb=Pb;break}else{Pb=Mb-368|0;c[s>>2]=Pb;c[t>>2]=0;Qb=Pb;Rb=0;Sb=0;break}}else{Pb=(((Mb*10923|0)+54615|0)>>>16)-1|0;c[s>>2]=Pb;Ob=Mb-3+(Pb*-6|0)|0;c[t>>2]=Ob;Tb=Nb-5|0;if((Tb|0)<18){Ub=18}else{Ub=(Tb|0)>134?134:Tb}Tb=Ub+Pb|0;c[s>>2]=Tb;Qb=Tb;Rb=0;Sb=Ob;break}}else if((Lb|0)==0){Vb=4;Wb=0;G=32}else{Ob=(Lb|0)!=1|0;if(Lb>>>0<4>>>0){Vb=4;Wb=Ob;G=32;break}Vb=(Lb|0)==5?5:6;Wb=Ob;G=32}}while(0);if((G|0)==32){G=0;Igb(s,t,Mb,Nb,Jb,Wb,Vb);Qb=c[s>>2]|0;Rb=(c[P>>2]|0)!=7|0;Sb=c[t>>2]|0}a[wa]=Qb;Lb=Sb<<Rb;c[t>>2]=Lb;Kb=(Lb|0)>0|0;Ob=Kb+Qb|0;c[s>>2]=Ob;Tb=c[ua>>2]|0;Ke[c[va>>2]&1023](Tb,Tb+(1-Ob<<2)|0,1257976,6,Lb+6-(-Kb&6)|0,10,40);UGb(ta|0,c[ua>>2]|0,160)|0;Kb=ya+(Jb*26|0)+6|0;Lb=c[P>>2]|0;if((Lb|0)==7){Kgb(Kb,y,986144,5,3);Xb=c[P>>2]|0;G=53}else if((Lb|0)==6){Ob=b[ya+(Jb*26|0)+14>>1]|0;Tb=Ob>>3;Pb=d[1734802+(Tb*3|0)|0]<<1|Ob&1;Yb=d[1734801+(Tb*3|0)|0]<<1|Ob>>>1&1;Zb=d[1734800+(Tb*3|0)|0]<<3;Tb=b[ya+(Jb*26|0)+16>>1]|0;_b=Tb>>3;$b=d[1734802+(_b*3|0)|0]<<1|Tb&1;ac=d[1734801+(_b*3|0)|0]<<1|Tb>>>1&1;bc=d[1734800+(_b*3|0)|0]<<3;_b=b[ya+(Jb*26|0)+18>>1]|0;cc=((_b<<16>>16>>2)*25|0)+12>>5;dc=(cc|0)%5|0;ec=(cc|0)/5|0;cc=_b&65535;c[qa>>2]=8;_b=Pb<<2;Pb=Yb<<2;ba=(b[Kb>>1]|0)!=0?-1.0:1.0;c[sa>>2]=_b;c[xb>>2]=Pb;g[yb>>2]=ba;if(Pb>>>0<_b>>>0){fc=-0.0-ba}else{fc=ba}g[zb>>2]=fc;_b=Ob&4|Zb|1;Zb=Tb&4|bc|1;ba=(b[ya+(Jb*26|0)+8>>1]|0)!=0?-1.0:1.0;c[ra>>2]=_b;c[Ab>>2]=Zb;g[Bb>>2]=ba;if(Zb>>>0<_b>>>0){gc=-0.0-ba}else{gc=ba}g[Cb>>2]=gc;_b=$b<<2|2;$b=ac<<2|2;ba=(b[ya+(Jb*26|0)+10>>1]|0)!=0?-1.0:1.0;c[pa>>2]=_b;c[Db>>2]=$b;g[Eb>>2]=ba;if($b>>>0<_b>>>0){hc=-0.0-ba}else{hc=ba}g[Fb>>2]=hc;_b=(((ec&1|0)==0?dc:4-dc|0)<<1|cc&1)<<2|3;dc=(cc>>>1&1|ec<<1)<<2|3;ba=(b[ya+(Jb*26|0)+12>>1]|0)!=0?-1.0:1.0;c[oa>>2]=_b;c[Gb>>2]=dc;g[Hb>>2]=ba;if((dc|0)<(_b|0)){ic=-0.0-ba}else{ic=ba}g[Ib>>2]=ic;jc=6;G=56}else{_b=e[Kb>>1]|0;do{if(Lb>>>0<2>>>0){Kb=_b>>>3;dc=(Kb&8)+(Jb<<1)|0;c[sa>>2]=(d[185520+dc|0]|0)+((_b&7)*5|0);c[ra>>2]=(d[185520+(dc|1)|0]|0)+((Kb&7)*5|0);c[qa>>2]=2}else{if((Lb|0)==2){Kb=((_b>>>1&7)*5|0)+(_b<<1&2|1)|0;c[sa>>2]=Kb;dc=_b>>>4&3;ec=((_b>>>6&7)*5|0)+dc+((dc|0)==3)|0;c[ra>>2]=ec;c[qa>>2]=(Kb|0)==(ec|0)?1:2;break}ec=_b&7;if((Lb|0)==3){c[sa>>2]=ec*5|0;c[ra>>2]=(_b>>>2&2|1)+((_b>>>4&7)*5|0);c[pa>>2]=(_b>>>6&2)+2+((_b>>>8&7)*5|0);c[qa>>2]=3;break}else{c[sa>>2]=d[986144+ec|0]|0;c[ra>>2]=(d[986144+(_b>>>3&7)|0]|0)+1;c[pa>>2]=(d[986144+(_b>>>6&7)|0]|0)+2;c[oa>>2]=(_b>>>9&1)+3+(d[986144+(_b>>>10&7)|0]|0);c[qa>>2]=4;break}}}while(0);_b=e[ya+(Jb*26|0)+8>>1]|0;Nb=0;while(1){g[y+44+(Nb<<2)>>2]=(1<<Nb&_b|0)!=0?1.0:-1.0;Mb=Nb+1|0;if((Mb|0)<(c[qa>>2]|0)){Nb=Mb}else{Xb=Lb;G=53;break}}}do{if((G|0)==53){G=0;if((Xb|0)==7|(Xb|0)==5){ba=+(e[554448+(e[ya+(Jb*26|0)+2>>1]<<1)>>1]|0)*6103515625.0e-14;g[na>>2]=ba;kc=+(e[554480+(e[ya+(Jb*26|0)+4>>1]<<1)>>1]|0)*.00048828125;lc=ba;mc=Xb;break}if(Xb>>>0>2>>>0){jc=Xb;G=56;break}if((Xb|0)==0){nc=1035976+((e[B+10+((Jb&2)*26|0)+2>>1]<<1|Jb&1)<<2)|0;oc=0;G=60;break}else{nc=1035208+(e[ya+(Jb*26|0)+2>>1]<<2)|0;oc=Xb;G=60;break}}}while(0);if((G|0)==56){G=0;nc=1035464+(e[ya+(Jb*26|0)+2>>1]<<2)|0;oc=jc;G=60}if((G|0)==60){G=0;ba=+(e[nc>>1]|0)*6103515625.0e-14;g[na>>2]=ba;kc=+(e[nc+2>>1]|0)*.000244140625;lc=ba;mc=oc}ba=kc;do{if((mc|0)==7){ca=lc>1.0?1.0:lc;g[ma>>2]=ca;Lb=a[wa]|0;c[la>>2]=Lb&255;g[ka>>2]=ca;pc=Lb;G=65}else{ca=+g[ma>>2];Lb=a[wa]|0;c[la>>2]=Lb&255;g[ka>>2]=ca;if((mc|0)!=0){pc=Lb;G=65;break}if((Jb&1|0)==0){qc=Lb}else{pc=Lb;G=65}}}while(0);if((G|0)==65){G=0;ca=+g[na>>2];if(ca<0.0){rc=0.0}else{rc=ca>.79449462890625?.79449462890625:ca}g[ma>>2]=rc;qc=pc}if(qc<<24>>24==0){G=69;break}Pgb(ja,y,1.0,40);ca=+we[c[ia>>2]&7](ja,ja,40)/40.0;g[ga>>2]=+Hgb(ba,ca,ha,+g[1342848+(c[P>>2]<<2)>>2],1342832);Lb=c[ua>>2]|0;Nb=0;do{_b=Lb+(Nb<<2)|0;g[_b>>2]=+g[na>>2]*+g[_b>>2];Nb=Nb+1|0;}while((Nb|0)<40);Pgb(Lb,y,+g[ga>>2],40);Nb=c[ua>>2]|0;_b=0;do{Mb=Nb+(_b<<2)|0;g[Mb>>2]=+sc(+(+g[Mb>>2]));_b=_b+1|0;}while((_b|0)<40);_b=c[P>>2]|0;ba=+g[R>>2];ca=+Q(+(ba- +g[H+(Jb*40|0)>>2]))/ba+0.0;ba=+g[N>>2];aa=ca+ +Q(+(ba- +g[H+(Jb*40|0)+4>>2]))/ba;ba=+g[za>>2];ca=aa+ +Q(+(ba- +g[H+(Jb*40|0)+8>>2]))/ba;ba=+g[Aa>>2];aa=ca+ +Q(+(ba- +g[H+(Jb*40|0)+12>>2]))/ba;ba=+g[Ba>>2];ca=aa+ +Q(+(ba- +g[H+(Jb*40|0)+16>>2]))/ba;ba=+g[Ca>>2];aa=ca+ +Q(+(ba- +g[H+(Jb*40|0)+20>>2]))/ba;ba=+g[Da>>2];ca=aa+ +Q(+(ba- +g[H+(Jb*40|0)+24>>2]))/ba;ba=+g[Ea>>2];aa=ca+ +Q(+(ba- +g[H+(Jb*40|0)+28>>2]))/ba;ba=+g[Fa>>2];ca=aa+ +Q(+(ba- +g[H+(Jb*40|0)+32>>2]))/ba;ba=+g[Ga>>2];aa=ca+ +Q(+(ba- +g[H+(Jb*40|0)+36>>2]))/ba;Nb=aa>.65?(a[Ha]|0)+1&255:0;a[Ha]=Nb;a:do{if((Nb&255)>>>0>10>>>0){a[Ia]=0;a[Ha]=Nb-1;tc=0;G=77}else{Lb=a[Ia]|0;if((Lb&255)>>>0<40>>>0){tc=Lb;G=77;break}switch(_b|0){case 6:case 3:case 2:case 1:case 0:{break};default:{G=82;break a}}ba=aa*4.0+ -1.6;if(ba<0.0){uc=0.0}else{uc=ba>1.0?1.0:ba}ba=+g[ga>>2];vc=uc*ba+(1.0-uc)*(+g[tb>>2]+ +g[ub>>2]+ +g[vb>>2]+ +g[wb>>2]+ba)*.2}}while(0);if((G|0)==77){G=0;a[Ia]=tc+1;G=82}if((G|0)==82){G=0;vc=+g[ga>>2]}aa=+g[na>>2];Nb=aa<.6;if(Nb){wc=0}else{wc=aa<.9?1:2}do{if(vc>+g[Ka>>2]*2.0){a[La]=2;G=91}else{Lb=a[La]|0;if(!(Lb<<24>>24==0)){Mb=Lb-1&255;a[La]=Mb;if(!(Mb<<24>>24==0)){G=91;break}}Mb=((+g[pb>>2]<.6)+(Nb&1)+(+g[qb>>2]<.6)+(+g[rb>>2]<.6)+(+g[sb>>2]<.6)|0)>2?0:wc;if(!(Mb>>>0>((d[Pa]|0)+1|0)>>>0)){xc=Mb;break}xc=Mb-1|0}}while(0);if((G|0)==91){G=0;xc=(wc>>>0<2>>>0)+wc|0}Nb=vc<5.0?2:xc;do{if((_b|0)!=4&_b>>>0<6>>>0&(Nb|0)<2){Mb=c[((_b|0)==5?901176:901192)+(Nb<<2)>>2]|0;Lb=c[la>>2]|0;aa=+g[ka>>2];do{if((Lb|0)<40){w$(Ma,Mb,Mb,Lb,aa,40);if((Lb|0)>=20){break}w$(Na,Mb,Ma,Lb,aa,40)}}while(0);TGb(Oa|0,0,160)|0;if((c[qa>>2]|0)<=0){yc=Ja;break}j=40-Lb|0;M=40-(Lb<<1)|0;ec=0;while(1){Kb=c[y+4+(ec<<2)>>2]|0;if((Kb|0)<(j|0)){zc=(Kb|0)<(M|0)?Na:Ma}else{zc=Mb}w$(Ja,Ja,zc,Kb,+g[y+44+(ec<<2)>>2],40);Kb=ec+1|0;if((Kb|0)<(c[qa>>2]|0)){ec=Kb}else{yc=Ja;break}}}else{yc=ja}}while(0);a[Pa]=Nb;g[Ka>>2]=vc;_b=xa+(Jb*40|0)|0;Ge[c[fa>>2]&3](Ma,Ra,yc,+g[na>>2],vc,40);if(!(+g[na>>2]<=.5)){aa=+we[c[ia>>2]&7](Ma,Ma,40);ba=+g[na>>2];ca=ba;do{if((c[P>>2]|0)==7){if(ba>1.0){Ac=.25;break}Ac=ca*.25}else{if(ba>.79449462890625){Ac=.397247314453125;break}Ac=ca*.5}}while(0);ba=ca*Ac;Nb=0;do{ec=q+(Nb<<2)|0;g[ec>>2]=+g[ec>>2]+ba*+g[B+1688+(Nb<<2)>>2];Nb=Nb+1|0;}while((Nb|0)<40);Ogb(Ma,Ma,aa,40)}le[c[Sa>>2]&1023](Qa,_b,Ma,40,10);Nb=0;while(1){if((Nb|0)>=40){break}if(+Q(+(+g[Qa+(Nb<<2)>>2]))>32768.0){Bc=0;G=113;break}else{Nb=Nb+1|0}}if((G|0)==113){while(1){G=0;Nb=B+1688+(Bc<<2)|0;g[Nb>>2]=+g[Nb>>2]*.25;Nb=Bc+1|0;if((Nb|0)<40){Bc=Nb;G=113}else{break}}Ge[c[fa>>2]&3](Ma,Ra,yc,+g[na>>2],vc,40);le[c[Sa>>2]&1023](Qa,_b,Ma,40,10)}aa=+we[c[ia>>2]&7](Qa,Qa,40);Nb=((c[P>>2]|0)-6|0)>>>0<2>>>0;ec=Nb?1155408:1155448;Mb=Nb?1155368:1155408;ba=+g[_b>>2];g[_a>>2]=ba*+g[ec>>2];g[Xa>>2]=ba*+g[Mb>>2];ba=+g[xa+(Jb*40|0)+4>>2];g[v+4>>2]=ba*+g[ec+4>>2];g[p+4>>2]=ba*+g[Mb+4>>2];ba=+g[xa+(Jb*40|0)+8>>2];g[v+8>>2]=ba*+g[ec+8>>2];g[p+8>>2]=ba*+g[Mb+8>>2];ba=+g[xa+(Jb*40|0)+12>>2];g[v+12>>2]=ba*+g[ec+12>>2];g[p+12>>2]=ba*+g[Mb+12>>2];ba=+g[xa+(Jb*40|0)+16>>2];g[v+16>>2]=ba*+g[ec+16>>2];g[p+16>>2]=ba*+g[Mb+16>>2];ba=+g[xa+(Jb*40|0)+20>>2];g[v+20>>2]=ba*+g[ec+20>>2];g[p+20>>2]=ba*+g[Mb+20>>2];ba=+g[xa+(Jb*40|0)+24>>2];g[v+24>>2]=ba*+g[ec+24>>2];g[p+24>>2]=ba*+g[Mb+24>>2];ba=+g[xa+(Jb*40|0)+28>>2];g[v+28>>2]=ba*+g[ec+28>>2];g[p+28>>2]=ba*+g[Mb+28>>2];ba=+g[xa+(Jb*40|0)+32>>2];g[v+32>>2]=ba*+g[ec+32>>2];g[p+32>>2]=ba*+g[Mb+32>>2];ba=+g[xa+(Jb*40|0)+36>>2];g[v+36>>2]=ba*+g[ec+36>>2];g[p+36>>2]=ba*+g[Mb+36>>2];Mb=l+((Jb*40|0)<<2)|0;UGb(Ta|0,Va|0,40)|0;le[c[Sa>>2]&1023](Wa,Xa,Qa,40,10);UGb(Va|0,Ya|0,40)|0;le[c[Za>>2]&1023](Mb,_a,Wa,40,10);TGb(ab|0,0,128)|0;g[bb>>2]=1.0;UGb(db|0,Ua|0,40)|0;le[c[Sa>>2]&1023](bb,Xa,bb,22,10);ba=+we[c[ia>>2]&7](bb,bb,22);ca=+we[c[ia>>2]&7](bb,cb,21);if(ca<0.0){Cc=0.0}else{Cc=ca/ba*.8}Agb($a,Cc,Mb,40);Ngb(Mb,Mb,aa,40,.8999999761581421,eb);Qgb(ja,y,40);UGb(fb|0,gb|0,80)|0;VGb(hb|0,ib|0,616)|0;VGb(jb|0,kb|0,16)|0;VGb(lb|0,mb|0,16)|0;UGb(nb|0,ob|0,40)|0;Mb=Jb+1|0;if((Mb|0)<4){Jb=Mb}else{G=118;break}}if((G|0)==69){yDb(f,16,2010816,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;E=-1094995529;i=m;return E|0}else if((G|0)==118){We[c[A+2340>>2]&7](l,l,943056,943064,5736202001571655.0e-20,A+2128|0,160);Ge[c[fa>>2]&3](R,R,A+664|0,.8399999737739563,.1599999964237213,10);c[k>>2]=1;E=(d[1046616+(c[P>>2]|0)|0]|0)+1|0;i=m;return E|0}}}while(0);if((G|0)==11){c[A+116>>2]=15}yDb(f,16,2194456,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;E=-1094995529;i=m;return E|0}function XX(a,d,f,h,j,k,l){a=a|0;d=d|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;m=i;i=i+24|0;n=m|0;o=i;i=i+40|0;p=(c[h>>2]|0)+(j<<1)|0;q=e[p>>1]|e[p+2>>1]<<16;c[n>>2]=q;p=(c[h+4>>2]|0)+(j<<1)|0;r=e[p>>1]|e[p+2>>1]<<16;c[n+4>>2]=r;p=n+8|0;s=(c[h+8>>2]|0)+(j<<1)|0;t=e[s>>1]|e[s+2>>1]<<16;c[p>>2]=t;s=(c[h+12>>2]|0)+(j<<1)|0;u=e[s>>1]|e[s+2>>1]<<16;c[n+12>>2]=u;s=(c[h+16>>2]|0)+(j<<1)|0;j=e[s>>1]|e[s+2>>1]<<16;c[n+16>>2]=j;s=t&65535;h=t>>>16&65535;if((k|0)==0){v=s;w=h}else{k=-s&65535;b[p>>1]=k;p=-h&65535;b[n+10>>1]=p;v=k;w=p}p=(l|0)!=0;if(p){UGb(a+120|0,n|0,20)|0}n=o|0;g[n>>2]=+((q&65535)<<16>>16|0)*30517578125.0e-15+ +g[f>>2]*125.0e-6;g[o+4>>2]=+((q>>>16&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+4>>2]*125.0e-6;g[o+8>>2]=+((r&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+8>>2]*125.0e-6;g[o+12>>2]=+((r>>>16&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+12>>2]*125.0e-6;g[o+16>>2]=+(v<<16>>16|0)*30517578125.0e-15+ +g[f+16>>2]*125.0e-6;g[o+20>>2]=+(w<<16>>16|0)*30517578125.0e-15+ +g[f+20>>2]*125.0e-6;g[o+24>>2]=+((u&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+24>>2]*125.0e-6;g[o+28>>2]=+((u>>>16&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+28>>2]*125.0e-6;g[o+32>>2]=+((j&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+32>>2]*125.0e-6;g[o+36>>2]=+((j>>>16&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+36>>2]*125.0e-6;KKa(n,.0062561,10);if(!p){MKa(d,n,10);i=m;return}p=a+2344|0;f=a+664|0;Ge[c[p>>2]&3](a+544|0,f,n,.75,.25,10);Ge[c[p>>2]&3](a+584|0,f,n,.5,.5,10);Ge[c[p>>2]&3](a+624|0,f,n,.25,.75,10);Ge[c[p>>2]&3](f,f,n,0.0,1.0,10);MKa(d,n,10);i=m;return}function YX(b){b=b|0;var d=0,e=0,f=0,h=0,j=0;d=i;e=c[b+60>>2]|0;f=b+416|0;if((c[f>>2]|0)>1){EDb(b,1971872,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=d;return j|0}c[f>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;f=b+412|0;if((c[f>>2]|0)==0){c[f>>2]=16e3}c[b+420>>2]=3;oDb(e+4376|0,1);c[e+2464>>2]=e+2204;a[e+4636|0]=1;g[e+248>>2]=.03125;g[e+252>>2]=.0625;g[e+256>>2]=.09375;g[e+260>>2]=.125;g[e+264>>2]=.15625;g[e+268>>2]=.1875;g[e+272>>2]=.21875;g[e+276>>2]=.25;g[e+280>>2]=.28125;g[e+284>>2]=.3125;g[e+288>>2]=.34375;g[e+292>>2]=.375;g[e+296>>2]=.40625;g[e+300>>2]=.4375;g[e+304>>2]=.46875;g[e+308>>2]=.1171875;g[e+2980>>2]=-14.0;g[e+2984>>2]=-14.0;g[e+2988>>2]=-14.0;g[e+2992>>2]=-14.0;Bgb(e+4640|0);Rgb(e+4648|0);A$(e+4652|0);E$(e+4660|0);j=0;i=d;return j|0}function ZX(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0.0,$=0.0,aa=0.0,ca=0.0,da=0.0,ea=0.0,fa=0,ga=0.0,ha=0,ia=0.0,ja=0,ka=0.0,la=0,ma=0.0,na=0.0,oa=0,pa=0.0,qa=0.0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0.0,Wc=0,Xc=0,Yc=0,Zc=0.0,_c=0.0,$c=0.0,ad=0.0,bd=0.0,cd=0.0,dd=0.0,ed=0.0,fd=0.0,gd=0.0,hd=0.0,id=0.0,jd=0.0,kd=0.0,ld=0;m=i;i=i+2080|0;n=m|0;o=m+96|0;p=m+152|0;q=m+168|0;r=m+248|0;s=m+328|0;t=m+488|0;u=m+928|0;v=m+1184|0;w=m+1440|0;x=m+1760|0;y=x;z=c[f+60>>2]|0;A=z;B=c[l+24>>2]|0;C=c[l+28>>2]|0;c[j+76>>2]=320;l=_$a(f,j,0)|0;if((l|0)<0){D=l;i=m;return D|0}l=c[j>>2]|0;j=(d[B]|0)>>>3&15;E=z+112|0;c[E>>2]=j;F=(d[B]|0)>>>2&1;a[z+116|0]=F;if(j>>>0>9>>>0){yDb(f,16,2194432,(G=i,i=i+8|0,c[G>>2]=j,G)|0);i=G;D=-1094995529;i=m;return D|0}H=(((e[1500288+(j<<1)>>1]|0)+7|0)>>>3)+1|0;if((C|0)<(H|0)){yDb(f,16,2116160,(G=i,i=i+8|0,c[G>>2]=C,G)|0);i=G;c[k>>2]=0;D=-1094995529;i=m;return D|0}if(F<<24>>24==0){yDb(f,16,2056920,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;I=c[E>>2]|0}else{I=j}if((I|0)==9){DDb(f,2010800,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;D=-1163346256;i=m;return D|0}G=z;f=c[1795952+(I<<2)>>2]|0;TGb(z|0,0,112)|0;j=b[f>>1]|0;if(j<<16>>16==0){J=I;K=0;L=0;M=0}else{I=f;f=j;while(1){j=I+4|0;F=e[I+2>>1]|0;if(f<<16>>16==0){N=0;O=j}else{C=f&65535;P=0;Q=C;R=j;while(1){j=Q-1|0;S=e[R>>1]|0;T=(d[B+((S>>>3)+1)|0]|0)>>>((S&7)>>>0)&1|P<<1;if((j|0)==0){break}else{P=T;Q=j;R=R+2|0}}N=T&65535;O=I+(C+2<<1)|0}b[G+(F>>>1<<1)>>1]=N;R=b[O>>1]|0;if(R<<16>>16==0){break}else{I=O;f=R}}J=c[E>>2]|0;K=e[z+2>>1]|0;L=e[z+4>>1]|0;M=e[z+6>>1]|0}f=z+120|0;O=f;U=+(b[1371576+(K*18|0)>>1]|0)*30517578125.0e-15;V=+(b[1371578+(K*18|0)>>1]|0)*30517578125.0e-15;I=z+124|0;W=+(b[1371580+(K*18|0)>>1]|0)*30517578125.0e-15;N=z+128|0;X=+(b[1371582+(K*18|0)>>1]|0)*30517578125.0e-15;T=z+132|0;Y=+(b[1371584+(K*18|0)>>1]|0)*30517578125.0e-15;B=z+136|0;Z=+(b[1371586+(K*18|0)>>1]|0)*30517578125.0e-15;R=z+140|0;_=+(b[1371588+(K*18|0)>>1]|0)*30517578125.0e-15;Q=z+144|0;$=+(b[1371590+(K*18|0)>>1]|0)*30517578125.0e-15;P=z+148|0;aa=+(b[1371592+(K*18|0)>>1]|0)*30517578125.0e-15;K=z+152|0;ca=+(b[1362424+(L*14|0)>>1]|0)*30517578125.0e-15;j=z+156|0;da=+(b[1362426+(L*14|0)>>1]|0)*30517578125.0e-15;S=z+160|0;ea=+(b[1362428+(L*14|0)>>1]|0)*30517578125.0e-15;fa=z+164|0;ga=+(b[1362430+(L*14|0)>>1]|0)*30517578125.0e-15;ha=z+168|0;ia=+(b[1362432+(L*14|0)>>1]|0)*30517578125.0e-15;ja=z+172|0;ka=+(b[1362434+(L*14|0)>>1]|0)*30517578125.0e-15;la=z+176|0;ma=+(b[1362436+(L*14|0)>>1]|0)*30517578125.0e-15;L=z+180|0;if((J|0)==0){na=U+ +(b[1369912+(M*10|0)>>1]|0)*30517578125.0e-15;g[O>>2]=na;g[I>>2]=V+ +(b[1369914+(M*10|0)>>1]|0)*30517578125.0e-15;g[N>>2]=W+ +(b[1369916+(M*10|0)>>1]|0)*30517578125.0e-15;g[T>>2]=X+ +(b[1369918+(M*10|0)>>1]|0)*30517578125.0e-15;g[B>>2]=Y+ +(b[1369920+(M*10|0)>>1]|0)*30517578125.0e-15;J=e[z+8>>1]|0;g[R>>2]=Z+ +(b[1368120+(J<<3)>>1]|0)*30517578125.0e-15;g[Q>>2]=_+ +(b[1368122+(J<<3)>>1]|0)*30517578125.0e-15;g[P>>2]=$+ +(b[1368124+(J<<3)>>1]|0)*30517578125.0e-15;g[K>>2]=aa+ +(b[1368126+(J<<3)>>1]|0)*30517578125.0e-15;J=e[z+10>>1]|0;g[j>>2]=ca+ +(b[1366456+(J*14|0)>>1]|0)*30517578125.0e-15;g[S>>2]=da+ +(b[1366458+(J*14|0)>>1]|0)*30517578125.0e-15;g[fa>>2]=ea+ +(b[1366460+(J*14|0)>>1]|0)*30517578125.0e-15;g[ha>>2]=ga+ +(b[1366462+(J*14|0)>>1]|0)*30517578125.0e-15;g[ja>>2]=ia+ +(b[1366464+(J*14|0)>>1]|0)*30517578125.0e-15;g[la>>2]=ka+ +(b[1366466+(J*14|0)>>1]|0)*30517578125.0e-15;oa=1366468+(J*14|0)|0;pa=na}else{na=U+ +(b[1371192+(M*6|0)>>1]|0)*30517578125.0e-15;g[O>>2]=na;g[I>>2]=V+ +(b[1371194+(M*6|0)>>1]|0)*30517578125.0e-15;g[N>>2]=W+ +(b[1371196+(M*6|0)>>1]|0)*30517578125.0e-15;M=e[z+8>>1]|0;g[T>>2]=X+ +(b[1369144+(M*6|0)>>1]|0)*30517578125.0e-15;g[B>>2]=Y+ +(b[1369146+(M*6|0)>>1]|0)*30517578125.0e-15;g[R>>2]=Z+ +(b[1369148+(M*6|0)>>1]|0)*30517578125.0e-15;M=e[z+10>>1]|0;g[Q>>2]=_+ +(b[1367352+(M*6|0)>>1]|0)*30517578125.0e-15;g[P>>2]=$+ +(b[1367354+(M*6|0)>>1]|0)*30517578125.0e-15;g[K>>2]=aa+ +(b[1367356+(M*6|0)>>1]|0)*30517578125.0e-15;M=e[z+12>>1]|0;g[j>>2]=ca+ +(b[1366264+(M*6|0)>>1]|0)*30517578125.0e-15;g[S>>2]=da+ +(b[1366266+(M*6|0)>>1]|0)*30517578125.0e-15;g[fa>>2]=ea+ +(b[1366268+(M*6|0)>>1]|0)*30517578125.0e-15;M=e[z+14>>1]|0;g[ha>>2]=ga+ +(b[1366008+(M<<3)>>1]|0)*30517578125.0e-15;g[ja>>2]=ia+ +(b[1366010+(M<<3)>>1]|0)*30517578125.0e-15;g[la>>2]=ka+ +(b[1366012+(M<<3)>>1]|0)*30517578125.0e-15;oa=1366014+(M<<3)|0;pa=na}g[L>>2]=ma+ +(b[oa>>1]|0)*30517578125.0e-15;oa=z+184|0;M=0;ma=pa;while(1){J=oa+(M<<2)|0;g[O+(M<<2)>>2]=+g[J>>2]*.3333333333333333+(ma+ +(b[901144+(M<<1)>>1]|0)*30517578125.0e-15);g[J>>2]=ma;J=M+1|0;if((J|0)>=16){break}M=J;ma=+g[O+(J<<2)>>2]}KKa(O,.00390625,15);M=z+248|0;oa=M;ma=+g[O>>2]- +g[oa>>2];pa=+g[I>>2]- +g[z+252>>2];na=+g[N>>2]- +g[z+256>>2];ka=+g[T>>2]- +g[z+260>>2];ia=+g[B>>2]- +g[z+264>>2];ga=+g[R>>2]- +g[z+268>>2];ea=+g[Q>>2]- +g[z+272>>2];da=+g[P>>2]- +g[z+276>>2];ca=+g[K>>2]- +g[z+280>>2];aa=+g[j>>2]- +g[z+284>>2];$=+g[S>>2]- +g[z+288>>2];_=+g[fa>>2]- +g[z+292>>2];Z=+g[ha>>2]- +g[z+296>>2];Y=+g[ja>>2]- +g[z+300>>2];X=+g[la>>2]- +g[z+304>>2];W=1.25-(ma*ma+0.0+pa*pa+na*na+ka*ka+ia*ia+ga*ga+ea*ea+da*da+ca*ca+aa*aa+$*$+_*_+Z*Z+Y*Y+X*X)*.8*512.0;if(W<0.0){qa=0.0}else{qa=W}g[L>>2]=+g[L>>2]*2.0;L=z+312|0;la=z+696|0;MKa(la,O,16);ja=z+4636|0;if((a[ja]|0)==0){ra=z+824|0}else{a[ja]=0;ja=z+824|0;UGb(ja|0,la|0,128)|0;ra=ja}ja=L;ha=ra;fa=0;while(1){h[ja+(fa<<3)>>3]=+h[ha+(fa<<3)>>3]*.550000011920929+ +h[ja+384+(fa<<3)>>3]*.44999998807907104;S=fa+1|0;if((S|0)<16){fa=S}else{sa=0;break}}while(1){h[ja+128+(sa<<3)>>3]=+h[ha+(sa<<3)>>3]*.19999998807907104+ +h[ja+384+(sa<<3)>>3]*.800000011920929;fa=sa+1|0;if((fa|0)<16){sa=fa}else{ta=0;break}}do{h[ja+256+(ta<<3)>>3]=+h[ha+(ta<<3)>>3]*.04000002145767212+ +h[ja+384+(ta<<3)>>3]*.9599999785423279;ta=ta+1|0;}while((ta|0)<16);ta=z+952|0;ja=ta;OKa(L,ta,16);OKa(z+440|0,z+1016|0,16);OKa(z+568|0,z+1080|0,16);OKa(z+696|0,z+1144|0,16);ta=z+16|0;L=z+2464|0;ha=z+1208|0;sa=z+1209|0;fa=z+4640|0;S=z+2724|0;j=S;K=S;P=z+3028|0;Q=z+2976|0;R=z+2996|0;B=R;T=z+4660|0;N=z+2980|0;I=z+3020|0;J=z+2468|0;ua=J;va=z+3040|0;wa=u|0;xa=v|0;ya=z+3108|0;za=z+4648|0;Aa=z+4652|0;Ba=z+3460|0;Ca=z+4132|0;Da=z+3712|0;Ea=z+4644|0;Fa=z+4116|0;Ga=z+3412|0;Ha=x|0;Ia=z+4124|0;Ja=w|0;Ka=z+4632|0;La=z+3796|0;Ma=La;Na=r|0;Oa=r+60|0;Pa=r+76|0;Qa=r+4|0;Ra=o|0;Sa=r+8|0;Ta=o+4|0;Ua=r+12|0;Va=o+8|0;Wa=r+16|0;Xa=o+12|0;Ya=r+20|0;Za=o+16|0;_a=r+24|0;$a=o+20|0;ab=r+28|0;bb=o+24|0;cb=r+32|0;db=o+28|0;eb=r+36|0;fb=o+32|0;gb=r+40|0;hb=o+36|0;ib=r+44|0;jb=o+40|0;kb=r+48|0;lb=o+44|0;mb=r+52|0;nb=o+48|0;ob=r+56|0;pb=o+52|0;qb=r+64|0;rb=r+68|0;sb=r+72|0;tb=s|0;s=q|0;ub=z+4136|0;vb=t;wb=t+120|0;xb=t+320|0;yb=z+4256|0;zb=z+1212|0;Ab=z+1468|0;Bb=z+3e3|0;Cb=z+3024|0;Db=z+3044|0;Eb=z+3300|0;Fb=z+3364|0;Gb=z+3620|0;Hb=z+3716|0;Ib=z+4036|0;Jb=q+4|0;Kb=q+8|0;Lb=q+12|0;Mb=q+16|0;Nb=q+20|0;Ob=q+24|0;Pb=q+28|0;Qb=q+32|0;Rb=q+36|0;Sb=q+40|0;Tb=q+44|0;Ub=q+48|0;Vb=q+52|0;Wb=q+56|0;Xb=q+60|0;Yb=x+4|0;Zb=z+3036|0;_b=u;u=Bb;$b=z+3004|0;ac=z+3008|0;bc=z+3012|0;cc=z+3016|0;z=n|0;dc=n+24|0;ec=n+48|0;fc=n+72|0;gc=n+4|0;hc=n+28|0;ic=n+52|0;jc=n+76|0;kc=n+8|0;lc=n+32|0;mc=n+12|0;nc=n+16|0;oc=n+36|0;pc=n+40|0;qc=0;do{rc=qc*80|0;tc=c[L>>2]|0;uc=c[E>>2]|0;vc=b[ta+(qc*24|0)>>1]|0;wc=vc&65535;do{if(uc>>>0<2>>>0){if((qc|0)==2){if((uc|0)==0){xc=42}}else if((qc|0)!=0){xc=42}if((xc|0)==42){xc=0;yc=(wc+1|0)>>>1;zc=wc-(yc<<1)<<1;Ac=(d[ha]|0)+yc|0;break}if((vc&65535)>>>0<116>>>0){yc=(wc+69|0)>>>1;Bc=(wc-(yc<<1)<<1)+136|0;Cc=yc}else{Bc=0;Cc=wc-24|0}yc=Cc-8+(Bc>>31)|0;if((yc|0)<34){Dc=34}else{Dc=(yc|0)>216?-40:yc&255}a[ha]=Dc;zc=Bc;Ac=Cc}else{if(!((qc|0)==2|(qc|0)==0)){yc=(wc+1|0)>>>2;zc=wc-(yc<<2)|0;Ac=(d[ha]|0)+yc|0;break}do{if((vc&65535)>>>0<376>>>0){yc=(wc+137|0)>>>2;Ec=wc+136-(yc<<2)|0;Fc=yc}else{if((vc&65535)>>>0<440>>>0){yc=wc-119>>1;Ec=(wc-(yc<<1)<<1)-240|0;Fc=yc;break}else{Ec=0;Fc=wc-280|0;break}}}while(0);yc=Fc-8+(Ec>>31)|0;if((yc|0)<34){Gc=34}else{Gc=(yc|0)>216?-40:yc&255}a[ha]=Gc;zc=Ec;Ac=Fc}}while(0);a[sa]=Ac;wc=(zc|0)>0;Ke[c[fa>>2]&1023](tc,tc+(1-Ac-(wc&1)<<2)|0,1862192,4,(wc?0:4)+zc|0,16,65);if((b[ta+(qc*24|0)+2>>1]|0)==0){wc=0;while(1){vc=wc+1|0;g[A+2468+(wc<<2)>>2]=+g[tc+(wc-1<<2)>>2]*.18+ +g[tc+(wc<<2)>>2]*.64+ +g[tc+(vc<<2)>>2]*.18;if((vc|0)<64){wc=vc}else{break}}UGb(tc|0,J|0,256)|0}else{UGb(J|0,tc|0,256)|0}wc=ta+(qc*24|0)+8|0;vc=ta+(qc*24|0)+16|0;uc=c[E>>2]|0;F=(uc|0)==0;C=F?2:4;switch(uc|0){case 7:case 8:{yc=0;do{Hc=n+(yc*24|0)|0;Ic=(e[ta+(qc*24|0)+8+(yc<<1)>>1]<<11)+(e[ta+(qc*24|0)+16+(yc<<1)>>1]|0)|0;Jc=Ic>>>19<<3&8;Kc=8-Jc|0;Lc=Ic>>>20&3;if((Lc|0)==0){Mc=Jc|1;Nc=Mc+(Ic&7)|0;c[Hc>>2]=(Ic&8|0)!=0?-Nc|0:Nc;Nc=Ic>>>4;Oc=Ic>>>11;Pc=Mc|Ic>>>18<<2&4;Qc=Pc|Ic>>>14<<1&2;Rc=Qc+(Ic>>>12&1)|0;Sc=Qc+(Oc&1)|0;Qc=(Oc&4|0)!=0;c[n+(yc*24|0)+4>>2]=Qc?-Rc|0:Rc;Oc=Qc?-Sc|0:Sc;c[n+(yc*24|0)+8>>2]=(Rc|0)>(Sc|0)?-Oc|0:Oc;Oc=Ic>>>15;Sc=Pc+(Oc&3)|0;c[n+(yc*24|0)+12>>2]=(Oc&4|0)!=0?-Sc|0:Sc;Sc=Mc+(Ic>>>7&7)|0;Oc=Mc+(Nc&7)|0;Mc=(Nc&64|0)!=0;c[n+(yc*24|0)+16>>2]=Mc?-Sc|0:Sc;Nc=Mc?-Oc|0:Oc;c[n+(yc*24|0)+20>>2]=(Sc|0)>(Oc|0)?-Nc|0:Nc}else if((Lc|0)==2){Nc=Kc|1;Oc=Nc+(Ic>>>3&7)|0;Sc=Nc+(Ic&7)|0;Nc=(Ic&64|0)!=0;c[Hc>>2]=Nc?-Oc|0:Oc;Mc=Nc?-Sc|0:Sc;c[n+(yc*24|0)+4>>2]=(Oc|0)>(Sc|0)?-Mc|0:Mc;_X(n+(yc*24|0)+8|0,Ic>>>7&4095,3,Jc|1)}else if((Lc|0)==3){Mc=Ic>>>10;Sc=Ic>>>15<<2&4|1;Oc=Sc+(Ic>>>12&3)|0;Nc=Sc+(Mc&3)|0;Sc=(Mc&16|0)!=0;c[Hc>>2]=Sc?-Oc|0:Oc;Mc=Sc?-Nc|0:Nc;c[n+(yc*24|0)+4>>2]=(Oc|0)>(Nc|0)?-Mc|0:Mc;Mc=Ic>>>16;c[n+(yc*24|0)+8>>2]=(Mc&8|0)!=0?(Mc|-8)^7:(Mc&7)+1|0;Mc=Ic>>>5<<2&4|9;Nc=Mc+(Ic>>>2&3)|0;Oc=Mc+(Ic&3)|0;Mc=(Ic&16|0)!=0;c[n+(yc*24|0)+12>>2]=Mc?-Nc|0:Nc;Sc=Mc?-Oc|0:Oc;c[n+(yc*24|0)+16>>2]=(Nc|0)>(Oc|0)?-Sc|0:Sc;Sc=Ic>>>6;Oc=Sc&7;c[n+(yc*24|0)+20>>2]=(Sc&8|0)!=0?-9-Oc|0:Oc+9|0}else if((Lc|0)==1){Lc=(Kc|1)+(Ic&7)|0;c[Hc>>2]=(Ic&8|0)!=0?-Lc|0:Lc;Lc=Ic>>>4;Hc=Jc|1;Jc=Ic>>>11;Kc=Hc|Ic>>>18<<2&4;Oc=Kc|Ic>>>14<<1&2;Sc=Oc+(Ic>>>12&1)|0;Nc=Oc+(Jc&1)|0;Oc=(Jc&4|0)!=0;c[n+(yc*24|0)+4>>2]=Oc?-Sc|0:Sc;Jc=Oc?-Nc|0:Nc;c[n+(yc*24|0)+8>>2]=(Sc|0)>(Nc|0)?-Jc|0:Jc;Jc=Ic>>>15;Nc=Kc+(Jc&3)|0;c[n+(yc*24|0)+12>>2]=(Jc&4|0)!=0?-Nc|0:Nc;Nc=Hc+(Ic>>>7&7)|0;Ic=Hc+(Lc&7)|0;Hc=(Lc&64|0)!=0;c[n+(yc*24|0)+16>>2]=Hc?-Nc|0:Nc;Lc=Hc?-Ic|0:Ic;c[n+(yc*24|0)+20>>2]=(Nc|0)>(Ic|0)?-Lc|0:Lc}yc=yc+1|0;}while((yc|0)<4);break};case 3:{yc=e[vc>>1]|0;tc=yc>>>7<<3&8|1;Lc=tc+(yc>>>3&7)|0;Ic=tc+(yc&7)|0;tc=(yc&64|0)!=0;c[z>>2]=tc?-Lc|0:Lc;Nc=tc?-Ic|0:Ic;c[gc>>2]=(Lc|0)>(Ic|0)?-Nc|0:Nc;Nc=yc>>>8;c[kc>>2]=(Nc&16|0)!=0?(Nc|-16)^15:(Nc&15)+1|0;Nc=e[ta+(qc*24|0)+18>>1]|0;yc=Nc>>>7<<3&8|1;Ic=yc+(Nc>>>3&7)|0;Lc=yc+(Nc&7)|0;yc=(Nc&64|0)!=0;c[dc>>2]=yc?-Ic|0:Ic;tc=yc?-Lc|0:Lc;c[hc>>2]=(Ic|0)>(Lc|0)?-tc|0:tc;tc=Nc>>>8;c[lc>>2]=(tc&16|0)!=0?(tc|-16)^15:(tc&15)+1|0;tc=e[ta+(qc*24|0)+20>>1]|0;Nc=tc>>>4;Lc=(Nc&15)+1|0;Ic=(tc&15)+1|0;yc=(tc&256|0)!=0;c[ec>>2]=yc?(Nc|-16)^15:Lc;Nc=yc?(tc|-16)^15:Ic;c[ic>>2]=Lc>>>0>Ic>>>0?-Nc|0:Nc;Nc=e[ta+(qc*24|0)+22>>1]|0;Ic=Nc>>>4;Lc=(Ic&15)+1|0;tc=(Nc&15)+1|0;yc=(Nc&256|0)!=0;c[fc>>2]=yc?(Ic|-16)^15:Lc;Ic=yc?(Nc|-16)^15:tc;c[jc>>2]=Lc>>>0>tc>>>0?-Ic|0:Ic;break};case 2:{Ic=e[vc>>1]|0;tc=Ic>>>4;Lc=(tc&15)+1|0;Nc=(Ic&15)+1|0;yc=(Ic&256|0)!=0;c[z>>2]=yc?(tc|-16)^15:Lc;tc=yc?(Ic|-16)^15:Nc;c[gc>>2]=Lc>>>0>Nc>>>0?-tc|0:tc;tc=e[ta+(qc*24|0)+18>>1]|0;Nc=tc>>>4;Lc=(Nc&15)+1|0;Ic=(tc&15)+1|0;yc=(tc&256|0)!=0;c[dc>>2]=yc?(Nc|-16)^15:Lc;Nc=yc?(tc|-16)^15:Ic;c[hc>>2]=Lc>>>0>Ic>>>0?-Nc|0:Nc;Nc=e[ta+(qc*24|0)+20>>1]|0;Ic=Nc>>>4;Lc=(Ic&15)+1|0;tc=(Nc&15)+1|0;yc=(Nc&256|0)!=0;c[ec>>2]=yc?(Ic|-16)^15:Lc;Ic=yc?(Nc|-16)^15:tc;c[ic>>2]=Lc>>>0>tc>>>0?-Ic|0:Ic;Ic=e[ta+(qc*24|0)+22>>1]|0;tc=Ic>>>4;Lc=(tc&15)+1|0;Nc=(Ic&15)+1|0;yc=(Ic&256|0)!=0;c[fc>>2]=yc?(tc|-16)^15:Lc;tc=yc?(Ic|-16)^15:Nc;c[jc>>2]=Lc>>>0>Nc>>>0?-tc|0:tc;break};case 1:{tc=e[vc>>1]|0;c[z>>2]=(tc&16|0)!=0?(tc|-16)^15:(tc&15)+1|0;tc=e[ta+(qc*24|0)+18>>1]|0;c[dc>>2]=(tc&16|0)!=0?(tc|-16)^15:(tc&15)+1|0;tc=e[ta+(qc*24|0)+20>>1]|0;c[ec>>2]=(tc&16|0)!=0?(tc|-16)^15:(tc&15)+1|0;tc=e[ta+(qc*24|0)+22>>1]|0;c[fc>>2]=(tc&16|0)!=0?(tc|-16)^15:(tc&15)+1|0;break};case 0:{tc=e[vc>>1]|0;c[z>>2]=(tc&32|0)!=0?(tc|-32)^31:(tc&31)+1|0;tc=e[ta+(qc*24|0)+18>>1]|0;c[dc>>2]=(tc&32|0)!=0?(tc|-32)^31:(tc&31)+1|0;break};case 4:{tc=0;do{Nc=e[ta+(qc*24|0)+16+(tc<<1)>>1]|0;Lc=Nc>>>7<<3&8|1;Ic=Lc+(Nc>>>3&7)|0;yc=Lc+(Nc&7)|0;Lc=(Nc&64|0)!=0;c[n+(tc*24|0)>>2]=Lc?-Ic|0:Ic;Hc=Lc?-yc|0:yc;c[n+(tc*24|0)+4>>2]=(Ic|0)>(yc|0)?-Hc|0:Hc;Hc=Nc>>>8;c[n+(tc*24|0)+8>>2]=(Hc&16|0)!=0?(Hc|-16)^15:(Hc&15)+1|0;tc=tc+1|0;}while((tc|0)<4);break};case 6:{tc=(e[wc>>1]<<10)+(e[vc>>1]|0)|0;Hc=tc>>>9;Nc=tc>>>19<<3&8|1;yc=Nc|tc>>>14<<2&4;Ic=yc+(tc>>>11&3)|0;Lc=yc+(Hc&3)|0;yc=(Hc&16|0)!=0;c[z>>2]=yc?-Ic|0:Ic;Hc=yc?-Lc|0:Lc;c[gc>>2]=(Ic|0)>(Lc|0)?-Hc|0:Hc;Hc=tc>>>15;Lc=Nc+(Hc&7)|0;c[kc>>2]=(Hc&8|0)!=0?-Lc|0:Lc;Lc=tc>>>4;Hc=(Lc&15)+1|0;Nc=(tc&15)+1|0;Ic=(tc&256|0)!=0;c[mc>>2]=Ic?(Lc|-16)^15:Hc;Lc=Ic?(tc|-16)^15:Nc;c[nc>>2]=Hc>>>0>Nc>>>0?-Lc|0:Lc;Lc=(e[ta+(qc*24|0)+10>>1]<<10)+(e[ta+(qc*24|0)+18>>1]|0)|0;Nc=Lc>>>9;Hc=Lc>>>19<<3&8|1;tc=Hc|Lc>>>14<<2&4;Ic=tc+(Lc>>>11&3)|0;yc=tc+(Nc&3)|0;tc=(Nc&16|0)!=0;c[dc>>2]=tc?-Ic|0:Ic;Nc=tc?-yc|0:yc;c[hc>>2]=(Ic|0)>(yc|0)?-Nc|0:Nc;Nc=Lc>>>15;yc=Hc+(Nc&7)|0;c[lc>>2]=(Nc&8|0)!=0?-yc|0:yc;yc=Lc>>>4;Nc=(yc&15)+1|0;Hc=(Lc&15)+1|0;Ic=(Lc&256|0)!=0;c[oc>>2]=Ic?(yc|-16)^15:Nc;yc=Ic?(Lc|-16)^15:Hc;c[pc>>2]=Nc>>>0>Hc>>>0?-yc|0:yc;_X(ec,(e[ta+(qc*24|0)+12>>1]<<14)+(e[ta+(qc*24|0)+20>>1]|0)|0,4,1);_X(fc,(e[ta+(qc*24|0)+14>>1]<<14)+(e[ta+(qc*24|0)+22>>1]|0)|0,4,1);break};case 5:{_X(z,(e[wc>>1]<<14)+(e[vc>>1]|0)|0,4,1);_X(dc,(e[ta+(qc*24|0)+10>>1]<<14)+(e[ta+(qc*24|0)+18>>1]|0)|0,4,1);_X(ec,(e[ta+(qc*24|0)+12>>1]<<14)+(e[ta+(qc*24|0)+20>>1]|0)|0,4,1);_X(fc,(e[ta+(qc*24|0)+14>>1]<<14)+(e[ta+(qc*24|0)+22>>1]|0)|0,4,1);break};default:{}}TGb(S|0,0,256)|0;yc=d[559688+(uc<<2)|0]|0;Hc=0;do{Nc=c[n+(Hc<<2)>>2]|0;Lc=ba(((Nc|0)>-1?Nc:-Nc|0)-1|0,C)|0;Ic=K+(Lc<<2)|0;g[Ic>>2]=+g[Ic>>2]+((Nc|0)<0?-1.0:1.0);Hc=Hc+1|0;}while((Hc|0)<(yc|0));yc=d[559689+(uc<<2)|0]|0;Hc=0;do{vc=c[n+24+(Hc<<2)>>2]|0;wc=ba(((vc|0)>-1?vc:-vc|0)-1|0,C)|0|1;Nc=K+(wc<<2)|0;g[Nc>>2]=+g[Nc>>2]+((vc|0)<0?-1.0:1.0);Hc=Hc+1|0;}while((Hc|0)<(yc|0));if(!F){yc=d[559690+(uc<<2)|0]|0;Hc=0;do{vc=c[n+48+(Hc<<2)>>2]|0;Nc=(ba(((vc|0)>-1?vc:-vc|0)-1|0,C)|0)+2|0;wc=K+(Nc<<2)|0;g[wc>>2]=+g[wc>>2]+((vc|0)<0?-1.0:1.0);Hc=Hc+1|0;}while((Hc|0)<(yc|0));yc=d[559691+(uc<<2)|0]|0;Hc=0;do{F=c[n+72+(Hc<<2)>>2]|0;vc=(ba(((F|0)>-1?F:-F|0)-1|0,C)|0)+3|0;wc=K+(vc<<2)|0;g[wc>>2]=+g[wc>>2]+((F|0)<0?-1.0:1.0);Hc=Hc+1|0;}while((Hc|0)<(yc|0))}yc=63;W=+g[Q>>2];while(1){Hc=yc-1|0;X=+g[K+(Hc<<2)>>2];g[K+(yc<<2)>>2]=W-X*+g[P>>2];if((Hc|0)==0){break}else{yc=Hc;W=X}}yc=a[sa]|0;do{if((yc&255)>>>0<64>>>0){Hc=yc&255;C=K+(Hc<<2)|0;g[C>>2]=+g[C>>2]+ +g[K>>2]*.85;C=Hc+1|0;if(C>>>0<64>>>0){Tc=C}else{break}do{C=K+(Tc<<2)|0;g[C>>2]=+g[C>>2]+ +g[K+(Tc-(d[sa]|0)<<2)>>2]*.85;Tc=Tc+1|0;}while((Tc|0)<64)}}while(0);yc=b[ta+(qc*24|0)+4>>1]&255;if((c[E>>2]|0)>>>0<2>>>0){Uc=555056+(yc<<2)|0}else{Uc=554544+(yc<<2)|0}g[B>>2]=+(b[Uc>>1]|0)*6103515625.0e-14;W=+(b[Uc+2>>1]|0)*.00048828125;X=+Hgb(W,+we[c[T>>2]&7](K,K,64)*.015625,N,30.0,1342816);g[I>>2]=X;W=+g[B>>2];Y=W;W=Y*Y*+we[c[T>>2]&7](ua,ua,64);Y=X;X=Y*Y*+we[c[T>>2]&7](K,K,64);Y=(W-X)/(W+X);g[P>>2]=Y*.25+.25;yc=c[L>>2]|0;C=0;do{Hc=yc+(C<<2)|0;X=+g[B>>2]*+g[Hc>>2];g[Hc>>2]=X;g[Hc>>2]=+sc(+(+g[I>>2]*+g[j+(C<<2)>>2]+X));C=C+1|0;}while((C|0)<64);X=+g[I>>2];W=qa*(1.0-Y)*.5;Z=+g[va>>2];if(Z>X){_=X+X*.19000244140625;Vc=Z>_?_:Z}else{_=X*.84033203125;Vc=Z>_?Z:_}g[va>>2]=Vc;_=(1.0-W)*X+W*Vc;C=c[E>>2]|0;do{if(C>>>0>1>>>0){Wc=K}else{W=+g[B>>2];yc=W<.6;if(yc){Xc=0}else{Xc=W<.9?1:2}do{if(X>+g[Cb>>2]*3.0){Yc=(Xc>>>0<2>>>0)+Xc|0}else{Hc=((+g[u>>2]<.6)+(yc&1)+(+g[$b>>2]<.6)+(+g[ac>>2]<.6)+(+g[bc>>2]<.6)+(+g[cc>>2]<.6)|0)>2?0:Xc;if(!(Hc>>>0>((d[Zb]|0)+1|0)>>>0)){Yc=Hc;break}Yc=Hc-1|0}}while(0);a[Zb]=Yc;yc=Yc+((C|0)==1)|0;if((yc|0)>=2){Wc=K;break}Hc=c[901184+(yc<<2)>>2]|0;TGb(_b|0,0,256)|0;yc=0;while(1){W=+g[K+(yc<<2)>>2];if(W!=0.0){w$(wa,wa,Hc,yc,W,64)}uc=yc+1|0;if((uc|0)<64){yc=uc}else{Wc=wa;break}}}}while(0);X=(Y+1.0)*.125;W=+g[Wc>>2];Z=+g[Wc+4>>2];g[Wc>>2]=W-X*Z;$=W;C=1;W=Z;while(1){yc=C+1|0;Z=+g[Wc+(yc<<2)>>2];g[Wc+(C<<2)>>2]=W-X*($+Z);if((yc|0)<63){$=W;C=yc;W=Z}else{break}}C=Wc+252|0;g[C>>2]=+g[C>>2]-X*W;C=ja+(qc<<6)|0;Ge[c[za>>2]&3](xa,ua,Wc,+g[B>>2],_,64);do{if(+g[B>>2]>.5){if(!((c[E>>2]|0)>>>0<2>>>0)){break}$=+we[c[T>>2]&7](xa,xa,64);Y=+g[B>>2];Z=Y*Y*.25;yc=0;do{Hc=v+(yc<<2)|0;g[Hc>>2]=+g[Hc>>2]+Z*+g[A+2468+(yc<<2)>>2];yc=yc+1|0;}while((yc|0)<64);Ogb(xa,xa,$,64)}}while(0);le[c[Aa>>2]&1023](ya,C,xa,64,16);_=+g[ya>>2]+ +g[Ca>>2]*.6800000071525574;g[Ba>>2]=_;yc=1;W=_;do{W=W*.6800000071525574+ +g[ya+(yc<<2)>>2];g[Ba+(yc<<2)>>2]=W;yc=yc+1|0;}while((yc|0)<64);g[Ca>>2]=+g[Da>>2];We[c[Ea>>2]&7](Ba,Ba,931504,931520,.989501953125,Fa,64);yc=rc|1;C=rc|2;Hc=rc|3;uc=rc|4;F=0;wc=0;vc=0;while(1){g[l+(F+rc<<2)>>2]=+g[Ga+(vc<<2)>>2];g[l+(yc+F<<2)>>2]=+we[c[T>>2]&7](Ga+(vc-11<<2)|0,160992,24);Nc=vc|1;g[l+(C+F<<2)>>2]=+we[c[T>>2]&7](Ga+(Nc-11<<2)|0,161088,24);g[l+(Hc+F<<2)>>2]=+we[c[T>>2]&7](Ga+(Nc-10<<2)|0,161184,24);g[l+(uc+F<<2)>>2]=+we[c[T>>2]&7](Ga+((vc|3)-11<<2)|0,161280,24);Nc=wc+1|0;if((Nc|0)<16){F=F+5|0;wc=Nc;vc=vc+4|0}else{break}}We[c[Ea>>2]&7](Ha,Ba,931504,931512,.8935546875,Ia,64);vc=(b[G>>1]&255)<<24>>24!=0|0;do{if((c[E>>2]|0)==8){Zc=+(e[554416+(e[ta+(qc*24|0)+6>>1]<<1)>>1]|0)*6103515625.0e-14}else{W=+we[c[T>>2]&7](Ha,Yb,63);_=W/+we[c[T>>2]&7](Ha,Ha,64);if(_<0.0){_c=0.0}else{_c=_}_=(1.25- +(vc|0)*.25)*(1.0-_c);if(_<.10000000149011612){Zc=.10000000149011612;break}Zc=_>1.0?1.0:_}}while(0);_=+we[c[T>>2]&7](xa,xa,64);vc=0;wc=c[Ka>>2]|0;do{c[A+4376+((wc&63)<<2)>>2]=(c[A+4376+((wc+9&63)<<2)>>2]|0)+(c[A+4376+((wc+40&63)<<2)>>2]|0);F=c[Ka>>2]|0;wc=F+1|0;c[Ka>>2]=wc;g[w+(vc<<2)>>2]=32768.0- +(c[A+4376+((F&63)<<2)>>2]&65535|0);vc=vc+1|0;}while((vc|0)<80);Ogb(Ja,Ja,Zc*Zc*_,80);vc=(c[E>>2]|0)==0;if(vc){W=+g[901128+(qc<<2)>>2];Ge[c[za>>2]&3](Na,oa,O,W,1.0-W,16);g[Pa>>2]=+g[Oa>>2];W=+g[Qa>>2];X=+g[Na>>2];g[Ra>>2]=W-X;Z=+g[Sa>>2];g[Ta>>2]=Z-W;Y=+g[Ua>>2];aa=Y-Z;g[Va>>2]=aa;ca=+g[Wa>>2];da=ca-Y;g[Xa>>2]=da;ea=+g[Ya>>2];ga=ea-ca;g[Za>>2]=ga;ia=+g[_a>>2];ka=ia-ea;g[$a>>2]=ka;ea=+g[ab>>2];na=ea-ia;g[bb>>2]=na;ia=+g[cb>>2];pa=ia-ea;g[db>>2]=pa;ea=+g[eb>>2];ma=ea-ia;g[fb>>2]=ma;ia=+g[gb>>2];V=ia-ea;g[hb>>2]=V;ea=+g[ib>>2];U=ea-ia;g[jb>>2]=U;ia=+g[kb>>2];$c=ia-ea;g[lb>>2]=$c;ea=+g[mb>>2];ad=ea-ia;g[nb>>2]=ad;ia=+g[ob>>2];bd=ia-ea;g[pb>>2]=bd;ea=aa*.0833333358168602+0.0+da*.0833333358168602+ga*.0833333358168602+ka*.0833333358168602+na*.0833333358168602+pa*.0833333358168602+ma*.0833333358168602+V*.0833333358168602+U*.0833333358168602+$c*.0833333358168602+ad*.0833333358168602+bd*.0833333358168602;na=pa-ea;pa=ma-ea;ma=V-ea;V=U-ea;U=$c-ea;$c=ad-ea;ad=bd-ea;wc=0;F=0;do{bd=na*(+g[o+(5-wc<<2)>>2]-ea);ka=pa*(+g[o+(6-wc<<2)>>2]-ea);ga=ma*(+g[o+(7-wc<<2)>>2]-ea);da=V*(+g[o+(8-wc<<2)>>2]-ea);aa=U*(+g[o+(9-wc<<2)>>2]-ea);cd=$c*(+g[o+(10-wc<<2)>>2]-ea);dd=ad*(+g[o+(11-wc<<2)>>2]-ea);ed=bd*bd+0.0+ka*ka+ga*ga+da*da+aa*aa+cd*cd+dd*dd;g[p+(wc<<2)>>2]=ed;F=ed>+g[p+(F<<2)>>2]?wc:F;wc=wc+1|0;}while((wc|0)<3);wc=-3-F|0;ea=ia+ +g[r+(13-F<<2)>>2]- +g[r+(wc+15<<2)>>2];g[Oa>>2]=ea;ad=ea+ +g[r+(14-F<<2)>>2]- +g[r+(wc+16<<2)>>2];g[qb>>2]=ad;$c=ad+ +g[r+(15-F<<2)>>2]- +g[r+(wc+17<<2)>>2];g[rb>>2]=$c;U=$c+ +g[r+(16-F<<2)>>2]- +g[r+(wc+18<<2)>>2];g[sb>>2]=U;V=(Z-Y-ca)/6.0+7965.0;ma=((V>7600.0?7600.0:V)-ia)*.5/(U-ia);V=(ea-ia)*ma;g[Ra>>2]=V;pa=(ad-ea)*ma;g[Ta>>2]=pa;ea=($c-ad)*ma;g[Va>>2]=ea;ad=(U-$c)*ma;g[Xa>>2]=ad;do{if(pa+V<5.0){if(pa>V){ma=5.0-pa;g[Ra>>2]=ma;fd=pa;gd=ma;break}else{ma=5.0-V;g[Ta>>2]=ma;fd=ma;gd=V;break}}else{fd=pa;gd=V}}while(0);do{if(ea+fd<5.0){if(ea>fd){V=5.0-ea;g[Ta>>2]=V;hd=ea;id=V;break}else{V=5.0-fd;g[Va>>2]=V;hd=V;id=fd;break}}else{hd=ea;id=fd}}while(0);do{if(ad+hd<5.0){if(ad>hd){ea=5.0-ad;g[Va>>2]=ea;jd=ea;kd=ad;break}else{ea=5.0-hd;g[Xa>>2]=ea;jd=hd;kd=ea;break}}else{jd=hd;kd=ad}}while(0);ad=ia+gd*30517578125.0e-15;g[Oa>>2]=ad;ea=ad+id*30517578125.0e-15;g[qb>>2]=ea;ad=ea+jd*30517578125.0e-15;g[rb>>2]=ad;g[sb>>2]=kd*30517578125.0e-15+ad;g[Na>>2]=X*.8;g[Qa>>2]=W*.8;F=2;ad=Z;while(1){g[r+(F<<2)>>2]=ad*.8;wc=F+1|0;if((wc|0)>=19){break}F=wc;ad=+g[r+(wc<<2)>>2]}g[Pa>>2]=+g[Pa>>2]*2.0;MKa(tb,Na,20);OKa(tb,s,20);F=0;ad=.8999999761581421;while(1){wc=q+(F<<2)|0;g[wc>>2]=ad*+g[wc>>2];wc=F+1|0;if((wc|0)<20){F=wc;ad=ad*.8999999761581421}else{break}}}else{g[s>>2]=+g[A+952+(qc<<6)>>2]*.6000000238418579;g[Jb>>2]=+g[A+952+(qc<<6)+4>>2]*.36000001430511475;g[Kb>>2]=+g[A+952+(qc<<6)+8>>2]*.2160000205039978;g[Lb>>2]=+g[A+952+(qc<<6)+12>>2]*.12960001826286316;g[Mb>>2]=+g[A+952+(qc<<6)+16>>2]*.0777600109577179;g[Nb>>2]=+g[A+952+(qc<<6)+20>>2]*.046656008809804916;g[Ob>>2]=+g[A+952+(qc<<6)+24>>2]*.02799360640347004;g[Pb>>2]=+g[A+952+(qc<<6)+28>>2]*.016796164214611053;g[Qb>>2]=+g[A+952+(qc<<6)+32>>2]*.010077699087560177;g[Rb>>2]=+g[A+952+(qc<<6)+36>>2]*.0060466197319328785;g[Sb>>2]=+g[A+952+(qc<<6)+40>>2]*.0036279719788581133;g[Tb>>2]=+g[A+952+(qc<<6)+44>>2]*.0021767832804471254;g[Ub>>2]=+g[A+952+(qc<<6)+48>>2]*.001306070014834404;g[Vb>>2]=+g[A+952+(qc<<6)+52>>2]*.0007836420554667711;g[Wb>>2]=+g[A+952+(qc<<6)+56>>2]*.00047018524492159486;g[Xb>>2]=+g[A+952+(qc<<6)+60>>2]*.0002821111702360213}le[c[Aa>>2]&1023](Ma,s,Ja,80,vc?20:16);UGb(vb|0,ub|0,120)|0;UGb(wb|0,La|0,320)|0;F=0;do{wc=x+(F<<2)|0;g[wc>>2]=0.0;uc=0;ad=0.0;do{ad=ad+ +g[t+(uc+F<<2)>>2]*+g[1679968+(uc<<2)>>2];uc=uc+1|0;}while((uc|0)<31);g[wc>>2]=ad;F=F+1|0;}while((F|0)<80);UGb(ub|0,xb|0,120)|0;if((c[E>>2]|0)==8){UGb(vb|0,yb|0,120)|0;UGb(wb|0,y|0,320)|0;F=0;do{vc=x+(F<<2)|0;g[vc>>2]=0.0;uc=0;$=0.0;do{$=$+ +g[t+(uc+F<<2)>>2]*+g[765400+(uc<<2)>>2];uc=uc+1|0;}while((uc|0)<31);g[vc>>2]=$;F=F+1|0;}while((F|0)<80);UGb(yb|0,xb|0,120)|0;ld=0}else{ld=0}do{F=l+(ld+rc<<2)|0;g[F>>2]=(+g[F>>2]+ +g[x+(ld<<2)>>2])*30517578125.0e-15;ld=ld+1|0;}while((ld|0)<80);VGb(zb|0,Ab|0,992)|0;VGb(Bb|0,R|0,20)|0;g[Cb>>2]=+g[I>>2];UGb(Db|0,Eb|0,64)|0;UGb(Fb|0,Gb|0,96)|0;UGb(Hb|0,Ib|0,80)|0;qc=qc+1|0;}while((qc|0)<4);UGb(ra|0,la|0,128)|0;UGb(M|0,f|0,64)|0;c[k>>2]=1;D=H;i=m;return D|0}function _X(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d-1|0;g=1<<f;h=d<<2;i=b>>h-2&3;if((i|0)==3){j=(1<<(d*3|0)-2)-1&b>>d;k=f<<1;l=k-1|0;m=d-2|0;n=(1<<l)-1&j;o=((j>>>(l>>>0)&1)<<m)+e|0;l=(1<<m)-1|0;p=o+(n>>m&l)|0;q=o+(n&l)|0;l=(n&1<<(m<<1)|0)!=0;c[a>>2]=l?-p|0:p;m=l?-q|0:q;c[a+4>>2]=(p|0)>(q|0)?-m|0:m;m=(1<<d)-1|0;q=j>>k&m;k=g-1|0;j=(q&k)+e|0;c[a+8>>2]=(q&g|0)!=0?-j|0:j;j=m&b;m=g+e+(k&j)|0;c[a+12>>2]=(j&g|0)!=0?-m|0:m;return}else if((i|0)==0){m=d<<1;j=m-3|0;k=d-2|0;q=(1<<j)-1&b;p=((b>>>((h-3|0)>>>0)&1)<<f)+e|0;h=p+((b>>>(j>>>0)&1)<<k)|0;j=(1<<k)-1|0;l=(q>>k&j)+h|0;n=h+(q&j)|0;j=(q&1<<(k<<1)|0)!=0;c[a>>2]=j?-l|0:l;k=j?-n|0:n;c[a+4>>2]=(l|0)>(n|0)?-k|0:k;k=(1<<m-1)-1&b>>m-2;m=g-1|0;n=(k>>f&m)+p|0;l=(k&m)+p|0;p=(k&1<<(f<<1)|0)!=0;c[a+8>>2]=p?-n|0:n;k=p?-l|0:l;c[a+12>>2]=(n|0)>(l|0)?-k|0:k;return}else if((i|0)==1){k=(d*3|0)-2|0;l=(1<<d)-1|0;n=b>>k&l;p=g-1|0;m=(n&p)+e|0;c[a>>2]=(n&g|0)!=0?-m|0:m;m=(1<<k)-1&b;k=g+e|0;n=f<<1;j=n-1|0;q=d-2|0;h=(1<<j)-1&m;o=((m>>>(j>>>0)&1)<<q)+k|0;j=(1<<q)-1|0;r=o+(h>>q&j)|0;s=o+(h&j)|0;j=(h&1<<(q<<1)|0)!=0;c[a+4>>2]=j?-r|0:r;q=j?-s|0:s;c[a+8>>2]=(r|0)>(s|0)?-q|0:q;q=m>>n&l;l=(q&p)+k|0;c[a+12>>2]=(q&g|0)!=0?-l|0:l;return}else if((i|0)==2){i=(d<<1)-1|0;d=(1<<i)-1|0;l=d&b>>i;i=g-1|0;q=(l>>f&i)+e|0;k=(l&i)+e|0;p=1<<(f<<1);n=(l&p|0)!=0;c[a>>2]=n?-q|0:q;l=n?-k|0:k;c[a+4>>2]=(q|0)>(k|0)?-l|0:l;l=d&b;b=g+e|0;e=(l>>f&i)+b|0;f=(l&i)+b|0;b=(l&p|0)!=0;c[a+8>>2]=b?-e|0:e;p=b?-f|0:f;c[a+12>>2]=(e|0)>(f|0)?-p|0:p;return}else{return}}function $X(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0;b=i;e=c[a+60>>2]|0;c[a+140>>2]=11;f=ICb()|0;c[e>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}f=c[a+96>>2]|0;h=c[a+100>>2]|0;if(!((h|0)>-1)){yDb(0,0,2010768,(a=i,i=i+24|0,c[a>>2]=1971856,c[a+8>>2]=1943112,c[a+16>>2]=135,a)|0);i=a;Cd();return 0}a=e+1028|0;c[a>>2]=f;c[e+1036>>2]=f;c[e+1032>>2]=f+h;if(h>>>0<1152>>>0){g=-1094995529;i=b;return g|0}h=f+128|0;c[a>>2]=h;f=e+4|0;e=0;j=h;while(1){c[a>>2]=j+4;h=j;c[f+(e<<2)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=e+1|0;if((h|0)>=256){g=0;break}e=h;j=c[a>>2]|0}i=b;return g|0}function aY(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;h=i;j=c[b+60>>2]|0;k=c[g+28>>2]|0;l=j;m=$$a(b,c[l>>2]|0)|0;if((m|0)<0){n=m;i=h;return n|0}m=c[l>>2]|0;o=c[m>>2]|0;p=o+(ba(c[b+124>>2]|0,c[m+32>>2]|0)|0)|0;m=j+1028|0;q=m;r=c[g+24>>2]|0;if(!((k|0)>-1)){yDb(0,0,2010768,(s=i,i=i+24|0,c[s>>2]=1971856,c[s+8>>2]=1943112,c[s+16>>2]=135,s)|0);i=s;Cd();return 0}g=m;c[g>>2]=r;c[j+1036>>2]=r;m=r+k|0;t=j+1032|0;c[t>>2]=m;u=m;do{if((k|0)>=1){v=r+1|0;c[g>>2]=v;if((a[r]|0)!=66){break}do{if((u-v|0)<1){w=v}else{x=r+2|0;c[g>>2]=x;if((a[v]|0)==0){w=x;break}DDb(b,2116144,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-1163346256;i=h;return n|0}}while(0);v=u-w|0;x=w+(v>>>0>2>>>0?2:v)|0;c[g>>2]=x;v=j+1040|0;c[v>>2]=0;y=b+120|0;z=o;A=m;B=x;x=0;a:while(1){C=A;do{if((C-B|0)<1){D=B;E=28}else{F=B+1|0;c[g>>2]=F;G=d[B]|0;H=G&127;I=(G&128|0)==0;if((H|0)!=0){G=I?q:0;J=c[y>>2]|0;K=c[(c[l>>2]|0)+32>>2]|0;L=J-x|0;M=G|0;N=K-J|0;O=(K|0)>0;K=G+4|0;if((G|0)==0){G=H;P=L;Q=z;while(1){R=(G|0)>(P|0)?P:G;S=P-R|0;T=G-R|0;U=(S|0)<1;V=U?J:S;S=Q+((U?N:0)+R)|0;if(O){if(!(S>>>0<p>>>0)){W=V;E=25;break a}}else{if(!(S>>>0>p>>>0)){W=V;E=25;break a}}if((T|0)>0){G=T;P=V;Q=S}else{X=V;Y=S;break}}}else{Q=c[M>>2]|0;if(O){P=H;G=L;S=z;V=Q;while(1){T=(P|0)>(G|0)?G:P;if(((c[K>>2]|0)-V|0)>>>0<T>>>0){W=G;E=25;break a}UGb(S|0,V|0,T)|0;R=(c[M>>2]|0)+T|0;c[M>>2]=R;U=G-T|0;Z=P-T|0;_=(U|0)<1;$=_?J:U;U=S+((_?N:0)+T)|0;if(!(U>>>0<p>>>0)){W=$;E=25;break a}if((Z|0)>0){P=Z;G=$;S=U;V=R}else{X=$;Y=U;break}}}else{V=H;S=L;G=z;P=Q;while(1){O=(V|0)>(S|0)?S:V;if(((c[K>>2]|0)-P|0)>>>0<O>>>0){W=S;E=25;break a}UGb(G|0,P|0,O)|0;U=(c[M>>2]|0)+O|0;c[M>>2]=U;$=S-O|0;R=V-O|0;Z=($|0)<1;T=Z?J:$;$=G+((Z?N:0)+O)|0;if(!($>>>0>p>>>0)){W=T;E=25;break a}if((R|0)>0){V=R;S=T;G=$;P=U}else{X=T;Y=$;break}}}}P=J-X|0;c[v>>2]=P;aa=Y;ca=P;break}if(I){D=F;E=28;break}if((C-F|0)<2){break a}P=B+3|0;c[g>>2]=P;G=F;S=(d[G]|d[G+1|0]<<8)<<16>>16&65535;G=S&16383;V=S>>>14;if((G|0)==0){if((V|0)==2){E=43;break a}else if((V|0)==0){break a}else{aa=z;ca=x;break}}do{if((V|0)==3){if((C-P|0)<1){da=0;break}c[g>>2]=B+4;da=d[P]|0}else{da=-1}}while(0);P=(V|0)==1?G|16384:G;F=(V|0)==2?q:0;ea=c[y>>2]|0;I=c[(c[l>>2]|0)+32>>2]|0;S=ea-x|0;N=F|0;b:do{if((P|0)==0){fa=S;ga=z}else{M=(da|0)>-1;K=da&255;Q=I-ea|0;L=(I|0)>0;H=F+4|0;if((F|0)==0){$=P;T=S;U=z;while(1){R=($|0)>(T|0)?T:$;if(M){TGb(U|0,K|0,R|0)|0}O=T-R|0;Z=$-R|0;_=(O|0)<1;ha=_?ea:O;O=U+((_?Q:0)+R)|0;if(L){if(!(O>>>0<p>>>0)){ia=ha;E=66;break a}}else{if(!(O>>>0>p>>>0)){ia=ha;E=66;break a}}if((Z|0)>0){$=Z;T=ha;U=O}else{fa=ha;ga=O;break b}}}U=c[N>>2]|0;if(M){T=P;$=S;K=z;O=U;while(1){ha=(T|0)>($|0)?$:T;if(((c[H>>2]|0)-O|0)>>>0<ha>>>0){ia=$;E=66;break a}UGb(K|0,O|0,ha)|0;Z=(c[N>>2]|0)+ha|0;c[N>>2]=Z;R=$-ha|0;_=T-ha|0;ja=(R|0)<1;ka=ja?ea:R;R=K+((ja?Q:0)+ha)|0;if(L){if(!(R>>>0<p>>>0)){ia=ka;E=66;break a}}else{if(!(R>>>0>p>>>0)){ia=ka;E=66;break a}}if((_|0)>0){T=_;$=ka;K=R;O=Z}else{fa=ka;ga=R;break}}}else{O=P;K=S;$=z;T=U;while(1){M=(O|0)>(K|0)?K:O;if(((c[H>>2]|0)-T|0)>>>0<M>>>0){ia=K;E=66;break a}UGb($|0,T|0,M)|0;R=(c[N>>2]|0)+M|0;c[N>>2]=R;ka=K-M|0;Z=O-M|0;_=(ka|0)<1;ha=_?ea:ka;ka=$+((_?Q:0)+M)|0;if(L){if(!(ka>>>0<p>>>0)){ia=ha;E=66;break a}}else{if(!(ka>>>0>p>>>0)){ia=ha;E=66;break a}}if((Z|0)>0){O=Z;K=ha;$=ka;T=R}else{fa=ha;ga=ka;break}}}}}while(0);N=ea-fa|0;c[v>>2]=N;aa=ga;ca=N}}while(0);if((E|0)==28){E=0;if((C-D|0)<1){la=0;ma=D}else{N=D+1|0;c[g>>2]=N;la=d[D]|0;ma=N}if((C-ma|0)<1){na=0}else{c[g>>2]=ma+1;na=a[ma]|0}oa=c[y>>2]|0;N=c[(c[l>>2]|0)+32>>2]|0;S=oa-x|0;if((la|0)==0){pa=S;qa=z}else{P=N-oa|0;F=(N|0)>0;N=la;I=S;S=z;while(1){V=(N|0)>(I|0)?I:N;TGb(S|0,na|0,V|0)|0;G=I-V|0;T=N-V|0;$=(G|0)<1;ra=$?oa:G;G=S+(($?P:0)+V)|0;if(F){if(!(G>>>0<p>>>0)){E=39;break a}}else{if(!(G>>>0>p>>>0)){E=39;break a}}if((T|0)>0){N=T;I=ra;S=G}else{pa=ra;qa=G;break}}}S=oa-pa|0;c[v>>2]=S;aa=qa;ca=S}S=c[g>>2]|0;I=c[t>>2]|0;if((I|0)==(S|0)){break}else{z=aa;A=I;B=S;x=ca}}if((E|0)==25){c[v>>2]=J-W}else if((E|0)==39){c[v>>2]=oa-ra}else if((E|0)==43){DDb(b,2056904,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-1163346256;i=h;return n|0}else if((E|0)==66){c[v>>2]=ea-ia}UGb(c[(c[l>>2]|0)+4>>2]|0,j+4|0,1024)|0;c[f>>2]=1;x=MCb(e,c[l>>2]|0)|0;n=(x|0)<0?x:k;i=h;return n|0}}while(0);DDb(b,2194408,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-1094995529;i=h;return n|0}function bY(a){a=a|0;JCb(c[a+60>>2]|0);return 0}function cY(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[a+140>>2]=11;d=ICb()|0;c[b>>2]=d;if((d|0)==0){e=-12;return e|0}c[b+20>>2]=1739472;c[b+24>>2]=16;c[b+32>>2]=7;c[b+36>>2]=0;do{if((c[a+120>>2]|0)!=0){if((c[a+124>>2]|0)==0){break}else{e=0}return e|0}}while(0);V$a(a,640,400)|0;e=0;return e|0}function dY(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;h=i;j=b+60|0;k=c[j>>2]|0;l=c[g+24>>2]|0;m=c[g+28>>2]|0;g=l+m|0;n=k;o=$$a(b,c[n>>2]|0)|0;if((o|0)<0){p=o;i=h;return p|0}if((c[b+428>>2]|0)==0){o=b+124|0;q=c[n>>2]|0;if((c[o>>2]|0)>0){r=b+120|0;s=0;t=q;while(1){u=(c[t>>2]|0)+(ba(c[t+32>>2]|0,s)|0)|0;TGb(u|0,0,c[r>>2]|0)|0;u=s+1|0;v=c[n>>2]|0;if((u|0)<(c[o>>2]|0)){s=u;t=v}else{w=v;break}}}else{w=q}TGb(c[w+4>>2]|0,0,1024)|0}w=c[n>>2]|0;c[w+88>>2]=1;c[w+304>>2]=1;fY(c[w+4>>2]|0);w=k+40|0;if((c[w>>2]|0)==0){q=c[j>>2]|0;t=b+124|0;if((c[t>>2]|0)>0){s=q;o=b+120|0;r=0;do{v=c[s>>2]|0;u=(c[v>>2]|0)+(ba(c[v+32>>2]|0,r)|0)|0;TGb(u|0,0,c[o>>2]|0)|0;r=r+1|0;}while((r|0)<(c[t>>2]|0))}c[q+8>>2]=0;c[q+4>>2]=0;c[w>>2]=1}a:do{if((m|0)>0){w=k+44|0;q=k+4|0;t=b+124|0;r=b+120|0;o=k+64|0;s=k+48|0;u=s;v=b;x=s;s=l;b:while(1){while(1){y=c[w>>2]|0;if((y|0)==0){z=18;break}else if((y|0)==2){z=38;break}else if((y|0)==3){z=187;break}else if((y|0)!=1){break}if((a[s]|0)==91){z=37;break}c[w>>2]=0;gY(b,27)}c:do{if((z|0)==18){z=0;y=d[s]|0;d:do{switch(y|0){case 8:{A=(c[q>>2]|0)-1|0;c[q>>2]=(A|0)>0?A:0;break c;break};case 9:{A=(c[q>>2]|0)/8|0;B=(A+8&-8)-A|0;if((B|0)>0){C=0}else{break c}while(1){gY(b,32);C=C+1|0;if((C|0)>=(B|0)){break c}}break};case 10:{B=c[j>>2]|0;A=B+8|0;D=c[A>>2]|0;E=c[t>>2]|0;F=B+24|0;G=c[F>>2]|0;if((D|0)<=(E-(G<<1)|0)){c[A>>2]=G+D;break d}if((E-G|0)>0){D=B;A=0;H=G;while(1){G=c[D>>2]|0;I=c[G>>2]|0;J=c[G+32>>2]|0;G=I+(ba(J,A)|0)|0;K=I+(ba(J,A+H|0)|0)|0;UGb(G|0,K|0,c[r>>2]|0)|0;K=A+1|0;G=c[t>>2]|0;J=c[F>>2]|0;if((K|0)<(G-J|0)){A=K;H=J}else{L=K;M=G;break}}}else{L=0;M=E}if((L|0)>=(M|0)){break d}H=B;A=L;do{F=c[H>>2]|0;D=(c[F>>2]|0)+(ba(c[F+32>>2]|0,A)|0)|0;TGb(D|0,0,c[r>>2]|0)|0;A=A+1|0;}while((A|0)<(c[t>>2]|0));break};case 13:{break};case 12:{A=c[j>>2]|0;if((c[t>>2]|0)>0){H=A;B=0;do{E=c[H>>2]|0;D=(c[E>>2]|0)+(ba(c[E+32>>2]|0,B)|0)|0;TGb(D|0,0,c[r>>2]|0)|0;B=B+1|0;}while((B|0)<(c[t>>2]|0))}c[A+8>>2]=0;c[A+4>>2]=0;break c;break};case 27:{c[w>>2]=1;break c;break};case 0:case 7:case 26:{break c;break};default:{gY(b,y);break c}}}while(0);c[q>>2]=0}else if((z|0)==37){z=0;c[w>>2]=2;c[o>>2]=0;c[u>>2]=-1}else if((z|0)==38){z=0;y=d[s]|0;switch(y|0){case 77:{c[w>>2]=3;break c;break};case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:{B=c[o>>2]|0;if((B|0)>=4){break c}H=x+(B<<2)|0;B=c[H>>2]|0;if((B|0)>=6553){break c}if((B|0)>0){N=(B*10|0)-48|0}else{N=-48}c[H>>2]=N+y;break c;break};case 59:{y=(c[o>>2]|0)+1|0;c[o>>2]=y;if((y|0)>=4){break c}c[x+(y<<2)>>2]=0;break c;break};case 61:case 63:{break c;break};default:{y=c[o>>2]|0;if((y|0)>4){yDb(v,24,2194384,(O=i,i=i+8|0,c[O>>2]=y,O)|0);i=O;P=c[o>>2]|0}else{P=y}do{if((P|0)<4){if(!((c[x+(P<<2)>>2]|0)>-1)){break}c[o>>2]=P+1}}while(0);y=a[s]|0;H=c[j>>2]|0;B=c[r>>2]|0;D=c[t>>2]|0;e:do{switch(y&255|0){case 65:{E=H+8|0;F=c[E>>2]|0;G=(c[H+64>>2]|0)>0;if(G){K=c[H+24>>2]|0;Q=ba(K,c[H+48>>2]|0)|0;R=K}else{K=c[H+24>>2]|0;Q=K;R=K}if((F-Q|0)>0){if(G){S=ba(c[H+48>>2]|0,R)|0}else{S=R}T=F-S|0}else{T=0}c[E>>2]=T;break};case 67:{E=H+4|0;F=c[E>>2]|0;G=(c[H+64>>2]|0)>0;if(G){U=c[H+48>>2]<<3}else{U=8}K=B-8|0;if((U+F|0)>(K|0)){V=K}else{if(G){W=c[H+48>>2]<<3}else{W=8}V=W+F|0}c[E>>2]=V;break};case 104:case 108:{E=H+48|0;f:do{if((c[H+64>>2]|0)<2){c[E>>2]=3;z=95}else{switch(c[E>>2]|0){case 0:case 1:case 4:case 5:case 13:case 19:{c[H+20>>2]=1744336;c[H+24>>2]=8;X=200;Y=320;break f;break};case 2:case 3:{z=95;break f;break};case 6:case 14:{c[H+20>>2]=1744336;c[H+24>>2]=8;X=200;Y=640;break f;break};case 15:case 16:{c[H+20>>2]=1744336;c[H+24>>2]=8;X=344;Y=640;break f;break};case 17:case 18:{c[H+20>>2]=1744336;c[H+24>>2]=8;X=960;Y=640;break f;break};case 7:{X=D;Y=B;break f;break};default:{DDb(v,2116120,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;X=D;Y=B;break f}}}}while(0);if((z|0)==95){z=0;c[H+20>>2]=1739472;c[H+24>>2]=16;X=400;Y=640}E=H+4|0;A=c[E>>2]|0;F=Y-8|0;if((A|0)<0){Z=0}else{Z=(A|0)>(F|0)?F:A}c[E>>2]=Z;E=H+8|0;A=c[E>>2]|0;F=X-(c[H+24>>2]|0)|0;if((A|0)<0){_=0}else{_=(A|0)>(F|0)?F:A}c[E>>2]=_;do{if((Y|0)==(c[r>>2]|0)){if((X|0)!=(c[t>>2]|0)){break}if(!(y<<24>>24==108)){break e}E=c[j>>2]|0;do{if((X|0)>0){A=E;TGb(c[c[A>>2]>>2]|0,0,Y|0)|0;if((c[t>>2]|0)>1){$=1}else{break}do{F=c[A>>2]|0;TGb((c[F>>2]|0)+(ba(c[F+32>>2]|0,$)|0)|0,0,c[r>>2]|0)|0;$=$+1|0;}while(($|0)<(c[t>>2]|0))}}while(0);c[E+8>>2]=0;c[E+4>>2]=0;break e}}while(0);A=H;KCb(c[A>>2]|0);F=V$a(b,Y,X)|0;if((F|0)<0){p=F;z=191;break b}F=_$a(b,c[A>>2]|0,1)|0;if((F|0)<0){p=F;z=191;break b}F=c[A>>2]|0;c[F+88>>2]=1;c[F+304>>2]=1;fY(c[F+4>>2]|0);F=c[j>>2]|0;if((c[t>>2]|0)>0){A=F;G=0;do{K=c[A>>2]|0;J=(c[K>>2]|0)+(ba(c[K+32>>2]|0,G)|0)|0;TGb(J|0,0,c[r>>2]|0)|0;G=G+1|0;}while((G|0)<(c[t>>2]|0))}c[F+8>>2]=0;c[F+4>>2]=0;break};case 74:{G=c[H+48>>2]|0;if((G|0)==0){A=c[H+4>>2]|0;J=B-A|0;K=H+24|0;I=c[K>>2]|0;if((I|0)>0){aa=H;ca=H+8|0;da=0;do{ea=c[aa>>2]|0;TGb((c[ea>>2]|0)+((ba((c[ca>>2]|0)+da|0,c[ea+32>>2]|0)|0)+A)|0,0,J|0)|0;da=da+1|0;fa=c[K>>2]|0;}while((da|0)<(fa|0));ga=c[t>>2]|0;ha=fa;ia=ca}else{ga=D;ha=I;ia=H+8|0}da=c[ia>>2]|0;K=ga-ha|0;if((da|0)>=(K|0)){break e}J=c[H>>2]|0;A=c[J+32>>2]|0;TGb((c[J>>2]|0)+(ba(A,da+ha|0)|0)|0,0,ba(A,K-da|0)|0)|0;break e}else if((G|0)==1){da=c[H+4>>2]|0;K=H+24|0;if((c[K>>2]|0)>0){A=H;J=H+8|0;aa=0;while(1){F=c[A>>2]|0;TGb((c[F>>2]|0)+(ba((c[J>>2]|0)+aa|0,c[F+32>>2]|0)|0)|0,0,da|0)|0;F=aa+1|0;if((F|0)<(c[K>>2]|0)){aa=F}else{ja=J;break}}}else{ja=H+8|0}J=c[ja>>2]|0;if((J|0)<=0){break e}aa=c[H>>2]|0;TGb(c[aa>>2]|0,0,ba(c[aa+32>>2]|0,J)|0)|0;break e}else if((G|0)==2){do{if((D|0)>0){J=H;TGb(c[c[J>>2]>>2]|0,0,B|0)|0;if((c[t>>2]|0)>1){ka=1}else{break}do{aa=c[J>>2]|0;TGb((c[aa>>2]|0)+(ba(c[aa+32>>2]|0,ka)|0)|0,0,c[r>>2]|0)|0;ka=ka+1|0;}while((ka|0)<(c[t>>2]|0))}}while(0);c[H+8>>2]=0;c[H+4>>2]=0;break e}else{break e}break};case 75:{G=c[H+48>>2]|0;if((G|0)==0){J=c[H+4>>2]|0;E=B-J|0;aa=H+24|0;if((c[aa>>2]|0)<=0){break e}K=H;da=H+8|0;A=0;do{I=c[K>>2]|0;TGb((c[I>>2]|0)+((ba((c[da>>2]|0)+A|0,c[I+32>>2]|0)|0)+J)|0,0,E|0)|0;A=A+1|0;}while((A|0)<(c[aa>>2]|0))}else if((G|0)==1){aa=c[H+4>>2]|0;A=H+24|0;if((c[A>>2]|0)<=0){break e}E=H;J=H+8|0;da=0;do{K=c[E>>2]|0;TGb((c[K>>2]|0)+(ba((c[J>>2]|0)+da|0,c[K+32>>2]|0)|0)|0,0,aa|0)|0;da=da+1|0;}while((da|0)<(c[A>>2]|0))}else if((G|0)==2){A=H+24|0;if((c[A>>2]|0)<=0){break e}da=H;aa=H+8|0;J=0;do{E=c[da>>2]|0;TGb((c[E>>2]|0)+(ba((c[aa>>2]|0)+J|0,c[E+32>>2]|0)|0)|0,0,B|0)|0;J=J+1|0;}while((J|0)<(c[A>>2]|0))}else{break e}break};case 109:{A=H+64|0;J=c[A>>2]|0;if((J|0)==0){c[A>>2]=1;c[H+48>>2]=0;la=1}else{la=J}J=(la|0)>4?4:la;if((J|0)<=0){break e}aa=H+48|0;da=H+28|0;G=H+32|0;E=H+36|0;K=0;I=J;J=la;while(1){ca=c[aa+(K<<2)>>2]|0;g:do{if((ca|0)==0){c[da>>2]=0;c[G>>2]=7;c[E>>2]=0;ma=K;na=J}else{F=ca-1|0;if(F>>>0<2>>>0|(ca|0)==4|(ca|0)==5|(ca|0)==7|(ca|0)==8){c[da>>2]=c[da>>2]|1<<F;ma=K;na=J;break}F=ca-30|0;if(F>>>0<8>>>0){c[G>>2]=d[1795848+F|0]|0;ma=K;na=J;break}if((ca|0)==38){z=156}else if((ca|0)==39){c[G>>2]=7;ma=K;na=J;break}else{z=163}do{if((z|0)==156){z=0;F=K+2|0;if((F|0)>=(I|0)){break}if((c[aa+(K+1<<2)>>2]|0)!=5){z=163;break}ea=c[aa+(F<<2)>>2]|0;if((ea|0)>=256){z=163;break}if((ea|0)<16){oa=d[1795848+ea|0]|0}else{oa=ea}c[G>>2]=oa;ma=F;na=J;break g}}while(0);do{if((z|0)==163){z=0;F=ca-40|0;if(F>>>0<8>>>0){c[E>>2]=d[1795848+F|0]|0;ma=K;na=J;break g}if((ca|0)==49){c[G>>2]=0;ma=K;na=J;break g}else if((ca|0)!=48){break}F=K+2|0;if((F|0)>=(((J|0)>4?4:J)|0)){break}if((c[aa+(K+1<<2)>>2]|0)!=5){break}ea=c[aa+(F<<2)>>2]|0;if((ea|0)>=256){break}if((ea|0)<16){pa=d[1795848+ea|0]|0}else{pa=ea}c[E>>2]=pa;ma=F;na=J;break g}}while(0);DDb(v,2056872,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;ma=K;na=c[A>>2]|0}}while(0);ca=ma+1|0;F=(na|0)>4?4:na;if((ca|0)<(F|0)){K=ca;I=F;J=na}else{break}}break};case 115:{c[H+12>>2]=c[H+4>>2];c[H+16>>2]=c[H+8>>2];break};case 117:{J=c[H+12>>2]|0;I=B-8|0;if((J|0)<0){qa=0}else{qa=(J|0)>(I|0)?I:J}c[H+4>>2]=qa;J=c[H+16>>2]|0;I=(c[t>>2]|0)-(c[H+24>>2]|0)|0;if((J|0)<0){ra=0}else{ra=(J|0)>(I|0)?I:J}c[H+8>>2]=ra;break};case 72:case 102:{J=c[H+64>>2]|0;do{if((J|0)>0){I=c[H+24>>2]|0;K=ba((c[H+48>>2]|0)-1|0,I)|0;A=D-I|0;if((K|0)<0){sa=0}else{sa=(K|0)>(A|0)?A:K}c[H+8>>2]=sa;if((J|0)<=1){ta=0;break}K=(c[H+52>>2]<<3)-8|0;A=(c[r>>2]|0)-8|0;if((K|0)<0){ta=0;break}ta=(K|0)>(A|0)?A:K}else{c[H+8>>2]=0;ta=0}}while(0);c[H+4>>2]=ta;break};case 68:{J=H+4|0;K=c[J>>2]|0;A=(c[H+64>>2]|0)>0;if(A){ua=c[H+48>>2]<<3}else{ua=8}if((K-ua|0)>0){if(A){va=c[H+48>>2]<<3}else{va=8}wa=K-va|0}else{wa=0}c[J>>2]=wa;break};case 66:{J=H+8|0;K=c[J>>2]|0;A=(c[H+64>>2]|0)>0;if(A){I=c[H+24>>2]|0;xa=ba(I,c[H+48>>2]|0)|0;ya=I}else{I=c[H+24>>2]|0;xa=I;ya=I}I=D-ya|0;if((xa+K|0)>(I|0)){za=I}else{if(A){Aa=ba(c[H+48>>2]|0,ya)|0}else{Aa=ya}za=Aa+K|0}c[J>>2]=za;break};case 110:case 82:{break};default:{DDb(v,2010744,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O}}}while(0);D=H+4|0;B=c[D>>2]|0;y=(c[r>>2]|0)-8|0;if((B|0)<0){Ba=0}else{Ba=(B|0)>(y|0)?y:B}c[D>>2]=Ba;D=H+8|0;B=c[D>>2]|0;y=(c[t>>2]|0)-(c[H+24>>2]|0)|0;if((B|0)<0){Ca=0}else{Ca=(B|0)>(y|0)?y:B}c[D>>2]=Ca;c[w>>2]=0;break c}}}else if((z|0)==187){z=0;D=a[s]|0;if(!((D<<24>>24|0)==14|(D<<24>>24|0)==27)){break}c[w>>2]=0}}while(0);s=s+1|0;if(!(s>>>0<g>>>0)){break a}}if((z|0)==191){i=h;return p|0}}}while(0);c[f>>2]=1;f=MCb(e,c[n>>2]|0)|0;p=(f|0)<0?f:m;i=h;return p|0}function eY(a){a=a|0;JCb(c[a+60>>2]|0);return 0}function fY(a){a=a|0;var b=0,d=0,e=0;UGb(a|0,1244144,64)|0;b=a+64|0;d=0;while(1){e=(ba(d,2621440)|0)+3604480|0;c[b>>2]=e|-16763081;c[b+4>>2]=e|-16763041;c[b+8>>2]=e|-16763001;c[b+12>>2]=e|-16762961;c[b+16>>2]=e|-16762921;c[b+20>>2]=e|-16762881;c[b+24>>2]=e|-16752841;c[b+28>>2]=e|-16752801;c[b+32>>2]=e|-16752761;c[b+36>>2]=e|-16752721;c[b+40>>2]=e|-16752681;c[b+44>>2]=e|-16752641;c[b+48>>2]=e|-16742601;c[b+52>>2]=e|-16742561;c[b+56>>2]=e|-16742521;c[b+60>>2]=e|-16742481;c[b+64>>2]=e|-16742441;c[b+68>>2]=e|-16742401;c[b+72>>2]=e|-16732361;c[b+76>>2]=e|-16732321;c[b+80>>2]=e|-16732281;c[b+84>>2]=e|-16732241;c[b+88>>2]=e|-16732201;c[b+92>>2]=e|-16732161;c[b+96>>2]=e|-16722121;c[b+100>>2]=e|-16722081;c[b+104>>2]=e|-16722041;c[b+108>>2]=e|-16722001;c[b+112>>2]=e|-16721961;c[b+116>>2]=e|-16721921;c[b+120>>2]=e|-16711881;c[b+124>>2]=e|-16711841;c[b+128>>2]=e|-16711801;c[b+132>>2]=e|-16711761;c[b+136>>2]=e|-16711721;c[b+140>>2]=e|-16711681;e=d+1|0;if((e|0)<6){b=b+144|0;d=e}else{break}}d=a+928|0;a=0;while(1){b=(a*10|0)+8|0;c[d>>2]=b|b<<8|b<<16|-16777216;b=a+1|0;if((b|0)<24){d=d+4|0;a=b}else{break}}return}function gY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a+60|0;e=c[d>>2]|0;f=c[e+32>>2]|0;g=c[e+36>>2]|0;h=c[e+28>>2]|0;i=(h&1|0)==0?f:f+8|0;f=(h&16|0)==0?g:g+8|0;g=(h&64|0)==0;j=g?f:i;k=c[e>>2]|0;l=c[k+32>>2]|0;m=ba(l,c[e+8>>2]|0)|0;n=e+4|0;F$((c[k>>2]|0)+(m+(c[n>>2]|0))|0,l,c[e+20>>2]|0,c[e+24>>2]|0,b,(h&128|0)==0?g?i:f:j,j);j=(c[n>>2]|0)+8|0;c[n>>2]=j;f=a+120|0;if((j|0)<=((c[f>>2]|0)-8|0)){return}c[n>>2]=0;n=c[d>>2]|0;d=n+8|0;j=c[d>>2]|0;i=a+124|0;a=c[i>>2]|0;g=n+24|0;h=c[g>>2]|0;if((j|0)<=(a-(h<<1)|0)){c[d>>2]=h+j;return}if((a-h|0)>0){j=n;d=0;b=h;while(1){h=c[j>>2]|0;e=c[h>>2]|0;l=c[h+32>>2]|0;h=e+(ba(l,d)|0)|0;m=e+(ba(l,d+b|0)|0)|0;UGb(h|0,m|0,c[f>>2]|0)|0;m=d+1|0;h=c[i>>2]|0;l=c[g>>2]|0;if((m|0)<(h-l|0)){d=m;b=l}else{o=m;p=h;break}}}else{o=0;p=a}if((o|0)>=(p|0)){return}p=n;n=o;do{o=c[p>>2]|0;a=(c[o>>2]|0)+(ba(c[o+32>>2]|0,n)|0)|0;TGb(a|0,0,c[f>>2]|0)|0;n=n+1|0;}while((n|0)<(c[i>>2]|0));return}function hY(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;f=a+60|0;g=c[f>>2]|0;if((c[a+100>>2]|0)!=6){yDb(a,16,2291032,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=e;return j|0}k=a+416|0;if((c[k>>2]|0)>2){yDb(a,16,2275168,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=e;return j|0}l=c[a+792>>2]|0;c[g+1260>>2]=l;if((l|0)==16){c[a+420>>2]=6}else if((l|0)==8){c[a+420>>2]=5}else if((l|0)==24){c[a+420>>2]=7}else{DDb(a,2259384,(h=i,i=i+8|0,c[h>>2]=l,h)|0);i=h;j=-1163346256;i=e;return j|0}c[g+4>>2]=a;c[g+1252>>2]=c[k>>2];l=c[a+96>>2]|0;m=l;n=g+1264|0;c[n>>2]=(d[m]|d[m+1|0]<<8)<<16>>16&65535;m=l+2|0;o=(d[m]|d[m+1|0]<<8)<<16>>16&65535;m=g+1268|0;c[m>>2]=o;p=l+4|0;l=(d[p]|d[p+1|0]<<8)<<16>>16&65535;c[g+1276>>2]=l;p=a;yDb(p,48,2244784,(h=i,i=i+16|0,c[h>>2]=o,c[h+8>>2]=l,h)|0);i=h;l=c[m>>2]|0;do{if(!(((l|0)%1e3|0|0)!=0|(l|0)>5e3|(l|0)==0)){if((c[n>>2]|0)<3930&(l|0)==5e3){break}m=g+1272|0;c[m>>2]=((l|0)/1e3|0)-1;o=g+3660|0;q=0;while(1){if((q|0)>=3){break}r=b[1794312+((c[m>>2]|0)*6|0)+(q<<1)>>1]|0;if(r<<16>>16==0){break}s=WDb(((r&65535)*12|0)+2048|0)|0;c[o+(q<<2)>>2]=s;if((s|0)==0){t=17;break}else{q=q+1|0}}if((t|0)==17){yDb(p,16,2219872,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;q=c[f>>2]|0;$Db(q+3660|0);$Db(q+3664|0);$Db(q+3668|0);$Db(q+3640|0);$Db(q+3844|0);c[q+3852>>2]=0;c[q+3644>>2]=0;j=-12;i=e;return j|0}q=c[n>>2]|0;a:do{if((q|0)<3860){c[g+3864>>2]=22;c[g+3868>>2]=130;t=26}else{if((q|0)<3900){c[g+3864>>2]=114;c[g+3868>>2]=410;t=26;break}if((q|0)<3930){c[g+3864>>2]=6;c[g+3868>>2]=528;t=26;break}o=g+3864|0;do{if((q|0)<3990){c[o>>2]=6;c[g+3868>>2]=256;m=g+3872|0;if((q|0)>=3950){u=m;break}c[m>>2]=502;c[g+3876>>2]=274;break a}else{c[o>>2]=220;c[g+3868>>2]=152;u=g+3872|0}}while(0);c[u>>2]=506;c[g+3876>>2]=208}}while(0);if((t|0)==26){c[g+3872>>2]=412;c[g+3876>>2]=72}Z3(g+8|0,a);q=(c[k>>2]|0)==2;o=a+448|0;c[o>>2]=q?3:4;c[o+4>>2]=q?0:0;j=0;i=e;return j|0}}while(0);yDb(p,16,2232432,(h=i,i=i+8|0,c[h>>2]=l,h)|0);i=h;j=-1094995529;i=e;return j|0}function iY(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;j=i;k=f;l=c[h+24>>2]|0;m=c[e+60>>2]|0;n=m;o=m+1256|0;p=c[o>>2]|0;if(!((p|0)>-1)){yDb(0,0,2194352,(q=i,i=i+24|0,c[q>>2]=2116104,c[q+8>>2]=2056848,c[q+16>>2]=1420,q)|0);i=q;Cd();return 0}a:do{if((p|0)==0){r=c[h+28>>2]|0;if((r|0)==0){c[g>>2]=0;s=0;i=j;return s|0}if((r|0)<8){yDb(e,16,2010720,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=-1094995529;i=j;return s|0}t=r&-4;if((t|0)!=(r|0)){yDb(e,24,1971776,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}r=m+1264|0;u=(c[r>>2]|0)<3950?t|2:t;v=m+3844|0;w=v;O$a(v,m+3852|0,u);v=c[w>>2]|0;if((v|0)==0){s=-12;i=j;return s|0}Xe[c[m+1104>>2]&4095](v,l,u>>2);TGb((c[w>>2]|0)+t|0,0,u&2|0)|0;t=c[w>>2]|0;v=m+3856|0;x=t+u|0;c[m+3848>>2]=x;u=t+4|0;c[v>>2]=u;y=t;z=fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=t+8|0;c[v>>2]=y;A=u;u=fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0;A=c[r>>2]|0;r=(A|0)>3899;do{if(r){if(u>>>0>3>>>0){yDb(e,16,1943080,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[w>>2]=0;s=-1094995529;i=j;return s|0}if(!((x-y|0)>>>0<u>>>0)){B=t+(u+8)|0;c[v>>2]=B;C=B;break}yDb(e,16,2010720,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=-1094995529;i=j;return s|0}else{B=x-y|0;D=B>>>0>268435455>>>0?-8:B<<3;B=D>>>0>2147483639>>>0|(y|0)==0;E=B?0:y;F=B?0:D;c[m+3824>>2]=E;c[m+3836>>2]=F;D=F+8|0;c[m+3840>>2]=D;c[m+3828>>2]=E+(F>>3);F=m+3832|0;c[F>>2]=0;if(B){s=B?-1094995529:0;i=j;return s|0}if((A|0)>3800){B=u<<3;if((B|0)<0){G=0}else{G=(D|0)<(B|0)?D:B}c[F>>2]=G;C=y;break}else{if((u|0)<0){H=0}else{H=(D|0)<(u|0)?D:u}c[F>>2]=H;C=y;break}}}while(0);if((z|0)<1){yDb(e,16,1918432,(q=i,i=i+8|0,c[q>>2]=z,q)|0);i=q;s=-1094995529;i=j;return s|0}c[o>>2]=z;do{if(r){if((x-C|0)<6){break}y=C+4|0;c[v>>2]=y;u=C;t=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;c[m+1280>>2]=t;I=t;J=y;K=32}else{y=m+3832|0;t=c[y>>2]|0;u=c[m+3840>>2]|0;F=c[m+3824>>2]|0;D=F+(t>>>3)|0;B=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(t&7)&-65536;D=t+16|0;t=u>>>0>D>>>0?D:u;c[y>>2]=t;D=F+(t>>>3)|0;F=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(t&7)>>>16;D=t+16|0;c[y>>2]=u>>>0>D>>>0?D:u;u=F|B;c[m+1280>>2]=u;I=u;J=C;K=32}}while(0);do{if((K|0)==32){z=m+1284|0;c[z>>2]=0;if((A|0)>3820&(I|0)<0){c[m+1280>>2]=I&2147483647;if((x-J|0)<6){break}u=J+4|0;c[v>>2]=u;B=J;c[z>>2]=fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0;L=u}else{L=J}c[m+3688>>2]=10;c[m+3692>>2]=16384;c[m+3696>>2]=10;c[m+3700>>2]=16384;do{if(r){c[v>>2]=L+2;u=d[L+1|0]|0;c[m+3684>>2]=u;c[m+3672>>2]=u>>>1;c[m+3676>>2]=128;u=m+1388|0;TGb(u|0,0,200)|0;c[m+1288>>2]=u;if((A|0)<3930){K=38;break}u=m+1316|0;c[u>>2]=c[228184];c[u+4>>2]=c[228185];c[u+8>>2]=c[228186];c[u+12>>2]=c[228187];u=m+1332|0;c[u>>2]=c[228184];c[u+4>>2]=c[228185];c[u+8>>2]=c[228186];c[u+12>>2]=c[228187];TGb(m+1348|0,0,40)|0}else{u=m+1388|0;TGb(u|0,0,200)|0;c[m+1288>>2]=u;K=38}}while(0);if((K|0)==38){u=m+1316|0;if((c[m+1268>>2]|0)==1e3){c[u>>2]=375;c[m+1332>>2]=375;B=m+1348|0;TGb(B|0,0,40)|0;M=B}else{c[u>>2]=c[228180];c[u+4>>2]=c[228181];c[u+8>>2]=c[228182];u=m+1332|0;c[u>>2]=c[228180];c[u+4>>2]=c[228181];c[u+8>>2]=c[228182];u=m+1348|0;TGb(u|0,0,40)|0;M=u}u=M;c[u>>2]=740;c[u+4>>2]=0;u=m+1368|0;c[u>>2]=740;c[u+4>>2]=0}c[m+3636>>2]=0;TGb(m+1292|0,0,24)|0;u=m+1272|0;B=0;while(1){z=b[1794312+((c[u>>2]|0)*6|0)+(B<<1)>>1]|0;if(z<<16>>16==0){N=w;break a}F=c[n+3660+(B<<2)>>2]|0;D=z&65535;z=n+3704+(B*40|0)|0;c[z>>2]=F;y=F+(D<<1)|0;c[n+3704+(B*40|0)+8>>2]=y;t=D*3|0;c[n+3704+(B*40|0)+12>>2]=F+(t<<1);E=D<<1;c[n+3704+(B*40|0)+4>>2]=F+(E<<1);O=D<<2;TGb(y|0,0,O|0)|0;TGb(c[z>>2]|0,0,E|0)|0;c[n+3704+(B*40|0)+16>>2]=0;z=t+512|0;y=n+3704+(B*40|0)+20|0;c[y>>2]=F+(z<<1);P=F+(z+D<<1)|0;c[n+3704+(B*40|0)+28>>2]=P;c[n+3704+(B*40|0)+32>>2]=F+(z+t<<1);c[n+3704+(B*40|0)+24>>2]=F+(z+E<<1);TGb(P|0,0,O|0)|0;TGb(c[y>>2]|0,0,E|0)|0;c[n+3704+(B*40|0)+36>>2]=0;E=B+1|0;if((E|0)<3){B=E}else{N=w;break a}}}}while(0);yDb(e,16,1897664,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=-1094995529;i=j;return s|0}else{N=m+3844|0}}while(0);if((c[N>>2]|0)==0){c[g>>2]=0;s=c[h+28>>2]|0;i=j;return s|0}N=c[m+3656>>2]|0;M=c[o>>2]|0;L=(c[m+1264>>2]|0)<3930?M:(N|0)>(M|0)?M:N;N=m+3640|0;M=N;J=m+3644|0;I=L+7&-8;kEb(N,J,I<<3);N=c[M>>2]|0;if((N|0)==0){s=-12;i=j;return s|0}TGb(N|0,0,c[J>>2]|0)|0;J=c[M>>2]|0;M=m+3648|0;N=M;C=M;c[C>>2]=J;M=m+3652|0;c[M>>2]=J+(I<<2);c[f+76>>2]=L;I=_$a(e,k,0)|0;if((I|0)<0){s=I;i=j;return s|0}I=m+3860|0;c[I>>2]=0;k=m+1252|0;J=c[m+1284>>2]|0;do{if((c[k>>2]|0)==1){K=53}else{if((J&4|0)!=0){K=53;break}if((J&3|0)!=0){yDb(c[m+4>>2]|0,48,2334864,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break}H=c[M>>2]|0;G=c[C>>2]|0;ne[c[m+3868>>2]&1023](n,L);ne[c[m+3876>>2]&1023](n,L);if((L|0)==0){break}else{Q=L;R=G;S=H}while(1){H=Q-1|0;G=c[R>>2]|0;l=(c[S>>2]|0)-((G|0)/2|0)|0;c[R>>2]=l;c[S>>2]=l+G;if((H|0)==0){break}else{Q=H;R=R+4|0;S=S+4|0}}}}while(0);do{if((K|0)==53){if((J&3|0)!=0){yDb(c[m+4>>2]|0,48,2309848,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break}ne[c[m+3864>>2]&1023](n,L);ne[c[m+3872>>2]&1023](n,L);if((c[k>>2]|0)!=2){break}UGb(c[M>>2]|0,c[C>>2]|0,L<<2)|0}}while(0);if((c[I>>2]|0)!=0){c[o>>2]=0;yDb(e,16,2355072,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=-1094995529;i=j;return s|0}q=c[m+1260>>2]|0;b:do{if((q|0)==16){m=c[k>>2]|0;if((m|0)<=0){break}e=f;if((L|0)>0){T=0}else{break}do{I=c[N+(T<<2)>>2]|0;C=c[e+(T<<2)>>2]|0;M=0;while(1){b[C>>1]=c[I+(M<<2)>>2];n=M+1|0;if((n|0)<(L|0)){C=C+2|0;M=n}else{break}}T=T+1|0;}while((T|0)<(m|0))}else if((q|0)==24){m=c[k>>2]|0;if((m|0)<=0){break}e=f;if((L|0)>0){U=0}else{M=0;while(1){M=M+1|0;if((M|0)>=(m|0)){break b}}}do{m=c[N+(U<<2)>>2]|0;M=c[e+(U<<2)>>2]|0;C=0;while(1){c[M>>2]=c[m+(C<<2)>>2]<<8;I=C+1|0;if((I|0)<(L|0)){M=M+4|0;C=I}else{break}}U=U+1|0;}while((U|0)<(c[k>>2]|0))}else if((q|0)==8){e=c[k>>2]|0;if((e|0)<=0){break}C=f;if((L|0)>0){V=0}else{M=0;while(1){M=M+1|0;if((M|0)>=(e|0)){break b}}}do{e=N+(V<<2)|0;M=0;m=c[C+(V<<2)>>2]|0;while(1){a[m]=(c[(c[e>>2]|0)+(M<<2)>>2]|0)+128;I=M+1|0;if((I|0)<(L|0)){M=I;m=m+1|0}else{break}}V=V+1|0;}while((V|0)<(c[k>>2]|0))}}while(0);c[o>>2]=(c[o>>2]|0)-L;c[g>>2]=1;if((c[o>>2]|0)!=0){s=0;i=j;return s|0}s=c[h+28>>2]|0;i=j;return s|0}function jY(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+3660|0);$Db(b+3664|0);$Db(b+3668|0);$Db(b+3640|0);$Db(b+3844|0);c[b+3852>>2]=0;c[b+3644>>2]=0;return 0}function kY(a){a=a|0;c[(c[a+60>>2]|0)+1256>>2]=0;return}function lY(a,b){a=a|0;b=b|0;HY(a,c[a+3648>>2]|0,a+3696|0,b);return}function mY(a,b){a=a|0;b=b|0;HY(a,c[a+3648>>2]|0,a+3696|0,b);HY(a,c[a+3652>>2]|0,a+3688|0,b);return}function nY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((b|0)==0){return}d=a+3824|0;e=a+3696|0;f=b;b=c[a+3648>>2]|0;while(1){g=f-1|0;c[b>>2]=GY(a,d,e)|0;if((g|0)==0){break}else{f=g;b=b+4|0}}return}function oY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[a+3652>>2]|0;e=(b|0)==0;if(e){return}f=a+3824|0;g=a+3696|0;h=b;i=c[a+3648>>2]|0;while(1){j=h-1|0;c[i>>2]=GY(a,f,g)|0;if((j|0)==0){break}else{h=j;i=i+4|0}}if(e){return}e=a+3824|0;i=a+3688|0;h=d;d=b;while(1){b=d-1|0;c[h>>2]=GY(a,e,i)|0;if((b|0)==0){break}else{h=h+4|0;d=b}}return}function pY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((b|0)==0){return}d=a+3696|0;e=b;b=c[a+3648>>2]|0;while(1){f=e-1|0;c[b>>2]=FY(a,d)|0;if((f|0)==0){break}else{e=f;b=b+4|0}}return}function qY(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[a+3652>>2]|0;f=(b|0)==0;if(!f){g=a+3696|0;h=b;i=c[a+3648>>2]|0;while(1){j=h-1|0;c[i>>2]=FY(a,g)|0;if((j|0)==0){break}else{h=j;i=i+4|0}}}i=a+3676|0;h=c[i>>2]|0;if(h>>>0<8388609>>>0){g=a+3684|0;j=a+3856|0;k=a+3672|0;l=a+3860|0;m=c[a+3848>>2]|0;n=c[g>>2]|0;o=c[j>>2]|0;p=h;while(1){h=n<<8;c[g>>2]=h;if(o>>>0<m>>>0){q=d[o]|0|h;c[g>>2]=q;r=o+1|0;c[j>>2]=r;s=r;t=q}else{c[l>>2]=1;s=o;t=h}c[k>>2]=c[k>>2]<<8|t>>>1&255;h=p<<8;c[i>>2]=h;if(h>>>0<8388609>>>0){n=t;o=s;p=h}else{u=s;v=g;w=k;break}}}else{u=c[a+3856>>2]|0;v=a+3684|0;w=a+3672|0}k=d[u-1|0]|0;c[v>>2]=k;c[w>>2]=k>>>1;c[i>>2]=128;if(f){return}f=a+3688|0;i=e;e=b;while(1){b=e-1|0;c[i>>2]=FY(a,f)|0;if((b|0)==0){break}else{i=i+4|0;e=b}}return}function rY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;if((b|0)==0){return}d=a+3696|0;e=a+3688|0;f=b;b=c[a+3648>>2]|0;g=c[a+3652>>2]|0;while(1){h=f-1|0;c[b>>2]=FY(a,d)|0;c[g>>2]=FY(a,e)|0;if((h|0)==0){break}else{f=h;b=b+4|0;g=g+4|0}}return}function sY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((b|0)==0){return}d=a+3696|0;e=b;b=c[a+3648>>2]|0;while(1){f=e-1|0;c[b>>2]=EY(a,d)|0;if((f|0)==0){break}else{e=f;b=b+4|0}}return}function tY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;if((b|0)==0){return}d=a+3696|0;e=a+3688|0;f=b;b=c[a+3648>>2]|0;g=c[a+3652>>2]|0;while(1){h=f-1|0;c[b>>2]=EY(a,d)|0;c[g>>2]=EY(a,e)|0;if((h|0)==0){break}else{f=h;b=b+4|0;g=g+4|0}}return}function uY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=i;i=i+2048|0;e=d|0;f=d+1024|0;g=c[a+3648>>2]|0;h=a+1268|0;j=c[h>>2]|0;do{if((j|0)==3e3){TGb(e|0,0,64)|0;k=c[g>>2]|0;l=f|0;c[l>>2]=k;m=f+4|0;c[m>>2]=c[g+4>>2];n=f+8|0;c[n>>2]=c[g+8>>2];o=f+12|0;c[o>>2]=c[g+12>>2];p=f+16|0;c[p>>2]=c[g+16>>2];q=f+20|0;c[q>>2]=c[g+20>>2];r=f+24|0;c[r>>2]=c[g+24>>2];s=f+28|0;c[s>>2]=c[g+28>>2];t=f+32|0;c[t>>2]=c[g+32>>2];u=f+36|0;c[u>>2]=c[g+36>>2];v=f+40|0;c[v>>2]=c[g+40>>2];w=f+44|0;c[w>>2]=c[g+44>>2];x=f+48|0;c[x>>2]=c[g+48>>2];y=f+52|0;c[y>>2]=c[g+52>>2];z=f+56|0;c[z>>2]=c[g+56>>2];A=c[g+60>>2]|0;B=f+60|0;c[B>>2]=A;if((b|0)>16){C=16;D=A;E=k}else{F=10;G=16;break}while(1){k=g+(C<<2)|0;A=c[k>>2]|0;H=(A>>>31)-((A|0)>0)|0;I=0;J=0;K=E;while(1){L=e+(I<<2)|0;M=c[L>>2]|0;N=(ba(M,K)|0)+J|0;c[L>>2]=M-(ba((K>>>30&2)-1|0,H)|0);M=I+1|0;if((M|0)>=16){break}I=M;J=N;K=c[f+(M<<2)>>2]|0}K=A-(N>>9)|0;c[k>>2]=K;J=c[m>>2]|0;c[l>>2]=J;c[m>>2]=c[n>>2];c[n>>2]=c[o>>2];c[o>>2]=c[p>>2];c[p>>2]=c[q>>2];c[q>>2]=c[r>>2];c[r>>2]=c[s>>2];c[s>>2]=c[t>>2];c[t>>2]=c[u>>2];c[u>>2]=c[v>>2];c[v>>2]=c[w>>2];c[w>>2]=c[x>>2];c[x>>2]=c[y>>2];c[y>>2]=c[z>>2];c[z>>2]=D;c[B>>2]=K;I=C+1|0;if((I|0)<(b|0)){C=I;D=K;E=J}else{F=10;G=16;break}}}else if((j|0)==4e3){if((c[a+1264>>2]|0)>3829){DY(g+1024|0,b-256|0);O=12;P=256;Q=11}else{O=11;P=128;Q=10}CY(g,P,O,e|0,f|0,b);F=Q;G=P}else{F=10;G=4}}while(0);if((b|0)==0){i=d;return}P=a+1292|0;Q=a+1288|0;f=a+3636|0;e=a+1300|0;O=a+1316|0;j=a+1388|0;E=a+3436|0;D=j|0;C=j;j=a+1308|0;N=a+1320|0;B=a+1324|0;z=a+1348|0;y=a+1352|0;a=g;g=b;b=c[Q>>2]|0;while(1){x=g-1|0;w=(c[h>>2]|0)==1e3;v=c[a>>2]|0;u=c[P>>2]|0;c[b+200>>2]=u;do{if(w){if((c[f>>2]|0)>>>0<3>>>0){c[P>>2]=v;c[e>>2]=v;R=v;break}else{t=(u<<1)-(c[b+196>>2]|0)|0;s=c[O>>2]|0;r=((ba(t,s)|0)>>9)+v|0;c[P>>2]=r;c[O>>2]=((t^v|0)>0?1:-1)+s;s=(c[e>>2]|0)+r|0;c[e>>2]=s;R=s;break}}else{s=c[j>>2]|0;c[b+168>>2]=s;if((c[f>>2]|0)>>>0<G>>>0){r=(c[e>>2]|0)+v|0;c[P>>2]=v;c[j>>2]=v;c[e>>2]=r;R=r;break}else{r=c[b+196>>2]|0;t=u-r|0;q=((c[b+192>>2]|0)-r<<3)+u|0;r=(s<<1)-(c[b+164>>2]|0)|0;p=c[O>>2]|0;o=ba(q,p)|0;n=c[N>>2]|0;m=(ba(t<<1,n)|0)+o|0;o=c[B>>2]|0;l=m+(ba(o,u)|0)|0;m=(v>>>31)-((v|0)>0)|0;c[O>>2]=(ba((q>>>30&2)-1|0,m)|0)+p;c[N>>2]=(ba((t>>>27&8)-4|0,m)|0)+n;c[B>>2]=o+(ba((u>>>28&8)-4|0,m)|0);m=c[z>>2]|0;o=ba(m,r)|0;n=c[y>>2]|0;t=o-(ba(n,s)|0)|0;o=(l>>11)+v|0;c[P>>2]=o;l=(o>>>31)-((o|0)>0)|0;c[z>>2]=(ba(l,(r>>>29&4)-2|0)|0)+m;c[y>>2]=n-(ba(l,(s>>>30&2)-1|0)|0);s=(t>>F)+o|0;c[j>>2]=s;o=s+(((c[e>>2]|0)*31|0)>>5)|0;c[e>>2]=o;R=o;break}}}while(0);c[a>>2]=R;v=(c[Q>>2]|0)+4|0;c[Q>>2]=v;c[f>>2]=(c[f>>2]|0)+1;if((v|0)==(E|0)){UGb(C|0,E|0,200)|0;c[Q>>2]=D;S=D}else{S=v}if((x|0)==0){break}else{a=a+4|0;g=x;b=S}}i=d;return}function vY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;i=i+2048|0;e=d|0;f=d+1024|0;g=c[a+3648>>2]|0;h=c[a+3652>>2]|0;j=a+1268|0;k=c[j>>2]|0;do{if((k|0)==3e3){l=e;TGb(l|0,0,64)|0;m=c[g>>2]|0;n=f|0;c[n>>2]=m;o=f+4|0;c[o>>2]=c[g+4>>2];p=f+8|0;c[p>>2]=c[g+8>>2];q=f+12|0;c[q>>2]=c[g+12>>2];r=f+16|0;c[r>>2]=c[g+16>>2];s=f+20|0;c[s>>2]=c[g+20>>2];t=f+24|0;c[t>>2]=c[g+24>>2];u=f+28|0;c[u>>2]=c[g+28>>2];v=f+32|0;c[v>>2]=c[g+32>>2];w=f+36|0;c[w>>2]=c[g+36>>2];x=f+40|0;c[x>>2]=c[g+40>>2];y=f+44|0;c[y>>2]=c[g+44>>2];z=f+48|0;c[z>>2]=c[g+48>>2];A=f+52|0;c[A>>2]=c[g+52>>2];B=f+56|0;c[B>>2]=c[g+56>>2];C=f+60|0;c[C>>2]=c[g+60>>2];D=(b|0)>16;if(D){E=16;F=m;do{m=g+(E<<2)|0;G=c[m>>2]|0;H=(G>>>31)-((G|0)>0)|0;I=0;J=0;K=F;while(1){L=e+(I<<2)|0;M=c[L>>2]|0;N=(ba(M,K)|0)+J|0;c[L>>2]=M-(ba((K>>>30&2)-1|0,H)|0);M=I+1|0;if((M|0)>=16){break}I=M;J=N;K=c[f+(M<<2)>>2]|0}c[m>>2]=G-(N>>9);F=c[o>>2]|0;c[n>>2]=F;c[o>>2]=c[p>>2];c[p>>2]=c[q>>2];c[q>>2]=c[r>>2];c[r>>2]=c[s>>2];c[s>>2]=c[t>>2];c[t>>2]=c[u>>2];c[u>>2]=c[v>>2];c[v>>2]=c[w>>2];c[w>>2]=c[x>>2];c[x>>2]=c[y>>2];c[y>>2]=c[z>>2];c[z>>2]=c[A>>2];c[A>>2]=c[B>>2];c[B>>2]=c[C>>2];c[C>>2]=c[m>>2];E=E+1|0;}while((E|0)<(b|0))}TGb(l|0,0,64)|0;E=c[h>>2]|0;c[n>>2]=E;c[o>>2]=c[h+4>>2];c[p>>2]=c[h+8>>2];c[q>>2]=c[h+12>>2];c[r>>2]=c[h+16>>2];c[s>>2]=c[h+20>>2];c[t>>2]=c[h+24>>2];c[u>>2]=c[h+28>>2];c[v>>2]=c[h+32>>2];c[w>>2]=c[h+36>>2];c[x>>2]=c[h+40>>2];c[y>>2]=c[h+44>>2];c[z>>2]=c[h+48>>2];c[A>>2]=c[h+52>>2];c[B>>2]=c[h+56>>2];F=c[h+60>>2]|0;c[C>>2]=F;if(D){O=16;P=F;Q=E}else{R=10;S=16;break}while(1){E=h+(O<<2)|0;F=c[E>>2]|0;K=(F>>>31)-((F|0)>0)|0;J=0;I=0;H=Q;while(1){M=e+(J<<2)|0;L=c[M>>2]|0;T=(ba(L,H)|0)+I|0;c[M>>2]=L-(ba((H>>>30&2)-1|0,K)|0);L=J+1|0;if((L|0)>=16){break}J=L;I=T;H=c[f+(L<<2)>>2]|0}H=F-(T>>9)|0;c[E>>2]=H;I=c[o>>2]|0;c[n>>2]=I;c[o>>2]=c[p>>2];c[p>>2]=c[q>>2];c[q>>2]=c[r>>2];c[r>>2]=c[s>>2];c[s>>2]=c[t>>2];c[t>>2]=c[u>>2];c[u>>2]=c[v>>2];c[v>>2]=c[w>>2];c[w>>2]=c[x>>2];c[x>>2]=c[y>>2];c[y>>2]=c[z>>2];c[z>>2]=c[A>>2];c[A>>2]=c[B>>2];c[B>>2]=P;c[C>>2]=H;J=O+1|0;if((J|0)<(b|0)){O=J;P=H;Q=I}else{R=10;S=16;break}}}else if((k|0)==4e3){if((c[a+1264>>2]|0)>3829){C=b-256|0;DY(g+1024|0,C);DY(h+1024|0,C);U=12;V=256;W=11}else{U=11;V=128;W=10}C=e|0;B=f|0;CY(g,V,U,C,B,b);CY(h,V,U,C,B,b);R=W;S=V}else{R=10;S=4}}while(0);if((b|0)==0){i=d;return}V=a+1292|0;W=a+1288|0;U=a+3636|0;f=a+1300|0;e=a+1296|0;k=a+1304|0;Q=a+1332|0;P=a+1316|0;O=a+1388|0;T=a+3436|0;N=O|0;B=O;O=a+1308|0;C=a+1312|0;A=a+1336|0;z=a+1340|0;y=a+1368|0;x=a+1372|0;w=a+1320|0;v=a+1324|0;u=a+1348|0;t=a+1352|0;a=h;h=g;g=b;b=c[W>>2]|0;while(1){s=g-1|0;r=c[h>>2]|0;q=c[a>>2]|0;p=(c[j>>2]|0)==1e3;o=c[V>>2]|0;c[b+200>>2]=o;do{if(p){if((c[U>>2]|0)>>>0<3>>>0){c[V>>2]=q;X=q}else{n=(o<<1)-(c[b+196>>2]|0)|0;D=c[P>>2]|0;l=((ba(n,D)|0)>>9)+q|0;c[V>>2]=l;c[P>>2]=((n^q|0)>0?1:-1)+D;X=(c[f>>2]|0)+l|0}c[f>>2]=X;c[h>>2]=X;l=c[e>>2]|0;c[b+136>>2]=l;if((c[U>>2]|0)>>>0<3>>>0){c[e>>2]=r;c[k>>2]=r;Y=r;break}else{D=(l<<1)-(c[b+132>>2]|0)|0;l=c[Q>>2]|0;n=((ba(D,l)|0)>>9)+r|0;c[e>>2]=n;c[Q>>2]=((D^r|0)>0?1:-1)+l;l=(c[k>>2]|0)+n|0;c[k>>2]=l;Y=l;break}}else{l=c[O>>2]|0;c[b+168>>2]=l;if((c[U>>2]|0)>>>0<S>>>0){n=(c[f>>2]|0)+q|0;c[V>>2]=q;c[O>>2]=q;Z=n}else{n=c[b+196>>2]|0;D=o-n|0;I=((c[b+192>>2]|0)-n<<3)+o|0;n=(l<<1)-(c[b+164>>2]|0)|0;H=c[P>>2]|0;J=ba(I,H)|0;K=c[w>>2]|0;m=(ba(D<<1,K)|0)+J|0;J=c[v>>2]|0;G=m+(ba(J,o)|0)|0;m=(q>>>31)-((q|0)>0)|0;c[P>>2]=(ba((I>>>30&2)-1|0,m)|0)+H;c[w>>2]=(ba((D>>>27&8)-4|0,m)|0)+K;c[v>>2]=J+(ba((o>>>28&8)-4|0,m)|0);m=c[u>>2]|0;J=ba(m,n)|0;K=c[t>>2]|0;D=J-(ba(K,l)|0)|0;J=(G>>11)+q|0;c[V>>2]=J;G=(J>>>31)-((J|0)>0)|0;c[u>>2]=(ba(G,(n>>>29&4)-2|0)|0)+m;c[t>>2]=K-(ba(G,(l>>>30&2)-1|0)|0);l=(D>>R)+J|0;c[O>>2]=l;Z=l+(((c[f>>2]|0)*31|0)>>5)|0}c[f>>2]=Z;c[h>>2]=Z;l=c[e>>2]|0;c[b+136>>2]=l;J=c[C>>2]|0;c[b+104>>2]=J;if((c[U>>2]|0)>>>0<S>>>0){D=(c[k>>2]|0)+r|0;c[e>>2]=r;c[C>>2]=r;c[k>>2]=D;Y=D;break}else{D=c[b+132>>2]|0;G=l-D|0;K=((c[b+128>>2]|0)-D<<3)+l|0;D=(J<<1)-(c[b+100>>2]|0)|0;m=c[Q>>2]|0;n=ba(K,m)|0;H=c[A>>2]|0;I=(ba(G<<1,H)|0)+n|0;n=c[z>>2]|0;L=I+(ba(n,l)|0)|0;I=(r>>>31)-((r|0)>0)|0;c[Q>>2]=(ba((K>>>30&2)-1|0,I)|0)+m;c[A>>2]=(ba((G>>>27&8)-4|0,I)|0)+H;c[z>>2]=n+(ba((l>>>28&8)-4|0,I)|0);I=c[y>>2]|0;l=ba(I,D)|0;n=c[x>>2]|0;H=l-(ba(n,J)|0)|0;l=(L>>11)+r|0;c[e>>2]=l;L=(l>>>31)-((l|0)>0)|0;c[y>>2]=(ba(L,(D>>>29&4)-2|0)|0)+I;c[x>>2]=n-(ba(L,(J>>>30&2)-1|0)|0);J=(H>>R)+l|0;c[C>>2]=J;l=J+(((c[k>>2]|0)*31|0)>>5)|0;c[k>>2]=l;Y=l;break}}}while(0);c[a>>2]=Y;r=(c[W>>2]|0)+4|0;c[W>>2]=r;c[U>>2]=(c[U>>2]|0)+1;if((r|0)==(T|0)){UGb(B|0,T|0,200)|0;c[W>>2]=N;_=N}else{_=r}if((s|0)==0){break}else{a=a+4|0;h=h+4|0;g=s;b=_}}i=d;return}function wY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[a+3648>>2]|0;AY(a,d,0,b);if((b|0)==0){return}e=a+1292|0;f=a+1288|0;g=a+1316|0;h=a+1320|0;i=a+1324|0;j=a+1328|0;k=a+1300|0;l=a+1388|0;m=a+3436|0;a=l|0;n=l;l=d;d=b;b=c[f>>2]|0;while(1){o=d-1|0;p=c[l>>2]|0;q=c[e>>2]|0;c[b+200>>2]=q;r=c[b+196>>2]|0;s=q-r|0;t=c[b+192>>2]|0;u=r-t|0;r=t-(c[b+188>>2]|0)|0;t=c[g>>2]|0;v=ba(t,q)|0;w=c[h>>2]|0;x=(ba(w,s)|0)+v|0;v=c[i>>2]|0;y=x+(ba(v,u)|0)|0;x=c[j>>2]|0;z=(y+(ba(x,r)|0)>>9)+p|0;c[e>>2]=z;y=z+(((c[k>>2]|0)*31|0)>>5)|0;c[k>>2]=y;z=(p>>>31)-((p|0)>0)|0;c[g>>2]=t+(ba((q>>>31<<1)-1|0,z)|0);c[h>>2]=w+(ba((s>>>31<<1)-1|0,z)|0);c[i>>2]=v+(ba((u>>>31<<1)-1|0,z)|0);c[j>>2]=x+(ba((r>>>31<<1)-1|0,z)|0);c[l>>2]=y;y=b+4|0;c[f>>2]=y;if((y|0)==(m|0)){UGb(n|0,m|0,200)|0;c[f>>2]=a;A=a}else{A=y}if((o|0)==0){break}else{l=l+4|0;d=o;b=A}}return}function xY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=c[a+3648>>2]|0;e=c[a+3652>>2]|0;AY(a,d,e,b);if((b|0)==0){return}f=a+1292|0;g=a+1288|0;h=a+1316|0;i=a+1320|0;j=a+1324|0;k=a+1328|0;l=a+1300|0;m=a+1296|0;n=a+1332|0;o=a+1336|0;p=a+1340|0;q=a+1344|0;r=a+1304|0;s=a+1388|0;t=a+3436|0;a=s|0;u=s;s=e;e=d;d=b;b=c[g>>2]|0;while(1){v=d-1|0;w=c[s>>2]|0;x=c[e>>2]|0;y=c[f>>2]|0;c[b+200>>2]=y;z=c[b+196>>2]|0;A=y-z|0;B=c[b+192>>2]|0;C=z-B|0;z=B-(c[b+188>>2]|0)|0;B=c[h>>2]|0;D=ba(B,y)|0;E=c[i>>2]|0;F=(ba(E,A)|0)+D|0;D=c[j>>2]|0;G=F+(ba(D,C)|0)|0;F=c[k>>2]|0;H=(G+(ba(F,z)|0)>>9)+w|0;c[f>>2]=H;G=H+(((c[l>>2]|0)*31|0)>>5)|0;c[l>>2]=G;H=(w>>>31)-((w|0)>0)|0;c[h>>2]=B+(ba((y>>>31<<1)-1|0,H)|0);c[i>>2]=E+(ba((A>>>31<<1)-1|0,H)|0);c[j>>2]=D+(ba((C>>>31<<1)-1|0,H)|0);c[k>>2]=F+(ba((z>>>31<<1)-1|0,H)|0);c[e>>2]=G;G=c[m>>2]|0;c[b+136>>2]=G;H=c[b+132>>2]|0;z=G-H|0;F=c[b+128>>2]|0;C=H-F|0;H=F-(c[b+124>>2]|0)|0;F=c[n>>2]|0;D=ba(F,G)|0;A=c[o>>2]|0;E=(ba(A,z)|0)+D|0;D=c[p>>2]|0;y=E+(ba(D,C)|0)|0;E=c[q>>2]|0;B=(y+(ba(E,H)|0)>>9)+x|0;c[m>>2]=B;y=B+(((c[r>>2]|0)*31|0)>>5)|0;c[r>>2]=y;B=(x>>>31)-((x|0)>0)|0;c[n>>2]=F+(ba((G>>>31<<1)-1|0,B)|0);c[o>>2]=A+(ba((z>>>31<<1)-1|0,B)|0);c[p>>2]=D+(ba((C>>>31<<1)-1|0,B)|0);c[q>>2]=E+(ba((H>>>31<<1)-1|0,B)|0);c[s>>2]=y;y=b+4|0;c[g>>2]=y;if((y|0)==(t|0)){UGb(u|0,t|0,200)|0;c[g>>2]=a;I=a}else{I=y}if((v|0)==0){break}else{s=s+4|0;e=e+4|0;d=v;b=I}}return}function yY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[a+3648>>2]|0;AY(a,d,0,b);e=a+1292|0;f=c[e>>2]|0;if((b|0)==0){g=f;c[e>>2]=g;return}h=a+1288|0;i=a+1316|0;j=a+1320|0;k=a+1324|0;l=a+1328|0;m=a+1388|0;n=a+3436|0;o=m|0;p=m;m=a+1300|0;a=f;f=d;d=b;b=c[h>>2]|0;while(1){q=d-1|0;r=c[f>>2]|0;c[b+200>>2]=a;s=b+196|0;t=a-(c[s>>2]|0)|0;c[s>>2]=t;s=ba(c[i>>2]|0,a)|0;u=(ba(c[j>>2]|0,t)|0)+s|0;s=u+(ba(c[k>>2]|0,c[b+192>>2]|0)|0)|0;u=(s+(ba(c[l>>2]|0,c[b+188>>2]|0)|0)>>10)+r|0;s=(a>>>31)-((a|0)>0)|0;c[b+72>>2]=s;v=b+68|0;c[v>>2]=(t>>>31)-((t|0)>0);t=(r>>>31)-((r|0)>0)|0;r=ba(s,t)|0;c[i>>2]=(c[i>>2]|0)+r;r=ba(c[v>>2]|0,t)|0;c[j>>2]=(c[j>>2]|0)+r;r=ba(c[b+64>>2]|0,t)|0;c[k>>2]=(c[k>>2]|0)+r;r=ba(c[b+60>>2]|0,t)|0;c[l>>2]=(c[l>>2]|0)+r;r=b+4|0;c[h>>2]=r;if((r|0)==(n|0)){UGb(p|0,n|0,200)|0;c[h>>2]=o;w=o}else{w=r}r=(((c[m>>2]|0)*31|0)>>5)+u|0;c[m>>2]=r;c[f>>2]=r;if((q|0)==0){g=u;break}else{a=u;f=f+4|0;d=q;b=w}}c[e>>2]=g;return}function zY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=c[a+3648>>2]|0;e=c[a+3652>>2]|0;AY(a,d,e,b);if((b|0)==0){return}f=a+1292|0;g=a+1288|0;h=a+1316|0;i=a+1320|0;j=a+1324|0;k=a+1328|0;l=a+1304|0;m=a+1308|0;n=a+1348|0;o=a+1352|0;p=a+1356|0;q=a+1360|0;r=a+1364|0;s=a+1300|0;t=a+1296|0;u=a+1332|0;v=a+1336|0;w=a+1340|0;x=a+1344|0;y=a+1312|0;z=a+1368|0;A=a+1372|0;B=a+1376|0;C=a+1380|0;D=a+1384|0;E=a+1388|0;F=a+3436|0;a=E|0;G=E;E=d;d=e;e=b;b=c[g>>2]|0;while(1){H=e-1|0;I=c[E>>2]|0;J=c[f>>2]|0;c[b+200>>2]=J;K=b+72|0;c[K>>2]=(J>>>31)-((J|0)>0);L=b+196|0;M=J-(c[L>>2]|0)|0;c[L>>2]=M;L=b+68|0;c[L>>2]=(M>>>31)-((M|0)>0);N=ba(c[h>>2]|0,J)|0;J=(ba(c[i>>2]|0,M)|0)+N|0;N=J+(ba(c[j>>2]|0,c[b+192>>2]|0)|0)|0;J=N+(ba(c[k>>2]|0,c[b+188>>2]|0)|0)|0;N=(c[l>>2]|0)-(((c[m>>2]|0)*31|0)>>5)|0;M=b+168|0;c[M>>2]=N;O=b+40|0;c[O>>2]=(N>>>31)-((N|0)>0);P=b+164|0;Q=N-(c[P>>2]|0)|0;c[P>>2]=Q;N=b+36|0;c[N>>2]=(Q>>>31)-((Q|0)>0);c[m>>2]=c[l>>2];Q=c[n>>2]|0;R=ba(Q,c[M>>2]|0)|0;M=c[o>>2]|0;S=(ba(M,c[P>>2]|0)|0)+R|0;R=c[p>>2]|0;P=S+(ba(R,c[b+160>>2]|0)|0)|0;S=c[q>>2]|0;T=P+(ba(S,c[b+156>>2]|0)|0)|0;P=c[r>>2]|0;U=(J+(T+(ba(P,c[b+152>>2]|0)|0)>>1)>>10)+I|0;c[f>>2]=U;T=U+(((c[s>>2]|0)*31|0)>>5)|0;c[s>>2]=T;U=(I>>>31)-((I|0)>0)|0;I=ba(c[K>>2]|0,U)|0;c[h>>2]=(c[h>>2]|0)+I;I=ba(c[L>>2]|0,U)|0;c[i>>2]=(c[i>>2]|0)+I;I=ba(c[b+64>>2]|0,U)|0;c[j>>2]=(c[j>>2]|0)+I;I=ba(c[b+60>>2]|0,U)|0;c[k>>2]=(c[k>>2]|0)+I;c[n>>2]=Q+(ba(c[O>>2]|0,U)|0);c[o>>2]=M+(ba(c[N>>2]|0,U)|0);c[p>>2]=R+(ba(c[b+32>>2]|0,U)|0);c[q>>2]=S+(ba(c[b+28>>2]|0,U)|0);c[r>>2]=P+(ba(c[b+24>>2]|0,U)|0);c[E>>2]=T;T=c[d>>2]|0;U=c[t>>2]|0;c[b+136>>2]=U;P=b+56|0;c[P>>2]=(U>>>31)-((U|0)>0);S=b+132|0;R=U-(c[S>>2]|0)|0;c[S>>2]=R;S=b+52|0;c[S>>2]=(R>>>31)-((R|0)>0);N=ba(c[u>>2]|0,U)|0;U=(ba(c[v>>2]|0,R)|0)+N|0;N=U+(ba(c[w>>2]|0,c[b+128>>2]|0)|0)|0;U=N+(ba(c[x>>2]|0,c[b+124>>2]|0)|0)|0;N=(c[s>>2]|0)-(((c[y>>2]|0)*31|0)>>5)|0;R=b+104|0;c[R>>2]=N;M=b+20|0;c[M>>2]=(N>>>31)-((N|0)>0);O=b+100|0;Q=N-(c[O>>2]|0)|0;c[O>>2]=Q;N=b+16|0;c[N>>2]=(Q>>>31)-((Q|0)>0);c[y>>2]=c[s>>2];Q=c[z>>2]|0;I=ba(Q,c[R>>2]|0)|0;R=c[A>>2]|0;L=(ba(R,c[O>>2]|0)|0)+I|0;I=c[B>>2]|0;O=L+(ba(I,c[b+96>>2]|0)|0)|0;L=c[C>>2]|0;K=O+(ba(L,c[b+92>>2]|0)|0)|0;O=c[D>>2]|0;J=(U+(K+(ba(O,c[b+88>>2]|0)|0)>>1)>>10)+T|0;c[t>>2]=J;K=J+(((c[l>>2]|0)*31|0)>>5)|0;c[l>>2]=K;J=(T>>>31)-((T|0)>0)|0;T=ba(c[P>>2]|0,J)|0;c[u>>2]=(c[u>>2]|0)+T;T=ba(c[S>>2]|0,J)|0;c[v>>2]=(c[v>>2]|0)+T;T=ba(c[b+48>>2]|0,J)|0;c[w>>2]=(c[w>>2]|0)+T;T=ba(c[b+44>>2]|0,J)|0;c[x>>2]=(c[x>>2]|0)+T;c[z>>2]=Q+(ba(c[M>>2]|0,J)|0);c[A>>2]=R+(ba(c[N>>2]|0,J)|0);c[B>>2]=I+(ba(c[b+12>>2]|0,J)|0);c[C>>2]=L+(ba(c[b+8>>2]|0,J)|0);L=b+4|0;c[D>>2]=O+(ba(c[L>>2]|0,J)|0);c[d>>2]=K;c[g>>2]=L;if((L|0)==(F|0)){UGb(G|0,F|0,200)|0;c[g>>2]=a;V=a}else{V=L}if((H|0)==0){break}else{E=E+4|0;d=d+4|0;e=H;b=V}}return}function AY(a,b,f,g){a=a|0;b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;h=a+1272|0;i=a+1264|0;j=(f|0)==0;k=c[h>>2]|0;if((k|0)==0){return}l=e[1794312+(k*6|0)>>1]|0;m=d[1794344+(k*3|0)|0]|0;BY(a,c[i>>2]|0,a+3704|0,b,g,l,m);if(!j){BY(a,c[i>>2]|0,a+3724|0,f,g,l,m)}m=c[h>>2]|0;if((m-3|0)>>>0>1>>>0){return}l=e[1794314+(m*6|0)>>1]|0;k=d[1794345+(m*3|0)|0]|0;BY(a,c[i>>2]|0,a+3744|0,b,g,l,k);if(!j){BY(a,c[i>>2]|0,a+3764|0,f,g,l,k)}k=c[h>>2]|0;if((k|0)!=4){return}h=e[1794316+(k*6|0)>>1]|0;l=d[1794346+(k*3|0)|0]|0;BY(a,c[i>>2]|0,a+3784|0,b,g,h,l);if(j){return}BY(a,c[i>>2]|0,a+3804|0,f,g,h,l);return}function BY(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((g|0)==0){return}j=a+1236|0;a=e|0;k=e+12|0;l=-h|0;m=e+4|0;n=1<<i-1;o=(d|0)<3980;d=e+8|0;p=h<<1;q=p+512|0;r=-p|0;s=h<<2;t=e+16|0;e=f;f=g;g=c[k>>2]|0;u=c[m>>2]|0;while(1){v=f-1|0;w=c[e>>2]|0;x=(Pe[c[j>>2]&255](c[a>>2]|0,g+(l<<1)|0,u+(l<<1)|0,h,(w>>>31)-((w|0)>0)|0)|0)+n>>i;w=x+(c[e>>2]|0)|0;x=e+4|0;c[e>>2]=w;if((w+32768|0)>>>0>65535>>>0){y=(w>>31^32767)&65535}else{y=w&65535}z=c[k>>2]|0;A=z+2|0;c[k>>2]=A;b[z>>1]=y;if(o){if((w|0)==0){B=0}else{B=(w>>>28&8)+65532&65535}C=c[m>>2]|0;b[C>>1]=B;D=C-8|0;b[D>>1]=(b[D>>1]|0)>>>1;D=C-16|0;b[D>>1]=(b[D>>1]|0)>>>1;E=C}else{C=(w|0)>-1?w:-w|0;if((w|0)==0){D=c[m>>2]|0;b[D>>1]=0;F=c[t>>2]|0;G=D}else{D=c[t>>2]|0;H=c[m>>2]|0;b[H>>1]=(w&-2147483648^-1073741824)>>((C|0)<=(D*3|0|0)?26:25)+((C|0)<=((D<<2|0)/3|0|0));F=D;G=H}c[t>>2]=((C-F|0)/16|0)+F;C=G-2|0;b[C>>1]=(b[C>>1]|0)>>>1;C=G-4|0;b[C>>1]=(b[C>>1]|0)>>>1;C=G-16|0;b[C>>1]=(b[C>>1]|0)>>>1;E=G}C=E+2|0;c[m>>2]=C;H=c[d>>2]|0;if((A|0)==(H+(q<<1)|0)){VGb(H|0,z+((r|1)<<1)|0,s|0)|0;z=c[d>>2]|0;H=z+(p<<1)|0;c[k>>2]=H;D=z+(h<<1)|0;c[m>>2]=D;I=H;J=D}else{I=A;J=C}if((v|0)==0){break}else{e=x;f=v;g=I;u=J}}return}function CY(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;TGb(e|0,0,b<<2|0)|0;h=(b|0)>0;if(h){i=0;do{c[f+(i<<2)>>2]=c[a+(i<<2)>>2];i=i+1|0;}while((i|0)<(b|0))}if((b|0)>=(g|0)){return}i=b-1|0;j=(i|0)>0;if(h){k=b}else{h=b;do{l=a+(h<<2)|0;if(j){m=0;while(1){n=m+1|0;c[f+(m<<2)>>2]=c[f+(n<<2)>>2];if((n|0)<(i|0)){m=n}else{break}}}c[f+(i<<2)>>2]=c[l>>2];h=h+1|0;}while((h|0)<(g|0));return}do{h=a+(k<<2)|0;m=c[h>>2]|0;n=(m>>>31)-((m|0)>0)|0;m=0;o=0;do{p=c[f+(m<<2)>>2]|0;q=e+(m<<2)|0;r=c[q>>2]|0;o=(ba(r,p)|0)+o|0;c[q>>2]=r-(ba((p>>>30&2)-1|0,n)|0);m=m+1|0;}while((m|0)<(b|0));m=(c[h>>2]|0)-(o>>d)|0;c[h>>2]=m;if(j){n=0;while(1){l=n+1|0;c[f+(n<<2)>>2]=c[f+(l<<2)>>2];if((l|0)<(i|0)){n=l}else{break}}s=c[h>>2]|0}else{s=m}c[f+(i<<2)>>2]=s;k=k+1|0;}while((k|0)<(g|0));return}function DY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((b|0)>0){d=0;e=0;f=0;g=0;h=0;i=0;j=0;k=0;l=0;m=0;n=0;o=0;p=0;q=0;r=0;s=0;t=0}else{return}while(1){u=a+(d<<2)|0;v=c[u>>2]|0;w=(v>>>31)-((v|0)>0)|0;x=f-(ba((e>>>30&2)-1|0,w)|0)|0;y=h-(ba((g>>>30&2)-1|0,w)|0)|0;z=j-(ba((i>>>30&2)-1|0,w)|0)|0;A=l-(ba((k>>>30&2)-1|0,w)|0)|0;B=n-(ba((m>>>30&2)-1|0,w)|0)|0;C=p-(ba((o>>>30&2)-1|0,w)|0)|0;D=r-(ba((q>>>30&2)-1|0,w)|0)|0;E=t-(ba((s>>>30&2)-1|0,w)|0)|0;c[u>>2]=v-((ba(t,s)|0)+((ba(r,q)|0)+((ba(p,o)|0)+((ba(n,m)|0)+((ba(l,k)|0)+((ba(j,i)|0)+((ba(h,g)|0)+(ba(f,e)|0)))))))>>9);u=d+1|0;if((u|0)<(b|0)){d=u;e=g;f=x;g=i;h=y;i=k;j=z;k=m;l=A;m=o;n=B;o=q;p=C;q=s;r=D;s=v;t=E}else{break}}return}function EY(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;f=b+4|0;g=(c[f>>2]|0)>>>5;h=(g|0)==0?1:g;g=a+3676|0;i=c[g>>2]|0;if(i>>>0<8388609>>>0){j=a+3684|0;k=a+3856|0;l=a+3672|0;m=a+3860|0;n=c[a+3848>>2]|0;o=c[j>>2]|0;p=c[k>>2]|0;q=i;while(1){r=o<<8;c[j>>2]=r;if(p>>>0<n>>>0){s=d[p]|0|r;c[j>>2]=s;t=p+1|0;c[k>>2]=t;u=t;v=s}else{c[m>>2]=1;u=p;v=r}r=c[l>>2]<<8|v>>>1&255;c[l>>2]=r;s=q<<8;c[g>>2]=s;if(s>>>0<8388609>>>0){o=v;p=u;q=s}else{w=s;x=r;break}}}else{w=i;x=c[a+3672>>2]|0}i=w>>>16;w=a+3680|0;c[w>>2]=i;q=(x>>>0)/(i>>>0)|0;do{if((q|0)>65492){u=q-65472|0;p=x-(ba(i,q)|0)|0;c[a+3672>>2]=p;c[g>>2]=i;if((q|0)<=65535){y=u;z=i;A=p;break}c[a+3860>>2]=1;y=u;z=i;A=p}else{p=0;while(1){u=p+1|0;if((e[1418936+(u<<1)>>1]|0|0)>(q|0)){break}else{p=u}}u=e[1418840+(p<<1)>>1]|0;v=x-(ba(e[1418936+(p<<1)>>1]|0,i)|0)|0;c[a+3672>>2]=v;o=ba(u,i)|0;c[g>>2]=o;y=p;z=o;A=v}}while(0);if((y|0)==63){i=a+3684|0;if(z>>>0<8388609>>>0){x=a+3856|0;q=a+3672|0;v=a+3860|0;o=c[a+3848>>2]|0;u=c[i>>2]|0;l=c[x>>2]|0;m=z;k=A;while(1){j=u<<8;c[i>>2]=j;if(l>>>0<o>>>0){n=d[l]|0|j;c[i>>2]=n;r=l+1|0;c[x>>2]=r;B=r;C=n}else{c[v>>2]=1;B=l;C=j}j=k<<8|C>>>1&255;c[q>>2]=j;n=m<<8;c[g>>2]=n;if(n>>>0<8388609>>>0){u=C;l=B;m=n;k=j}else{D=n;E=j;F=C;G=B;H=o;I=v;break}}}else{D=z;E=A;F=c[i>>2]|0;G=c[a+3856>>2]|0;H=c[a+3848>>2]|0;I=a+3860|0}i=D>>>16;c[w>>2]=i;D=(E>>>0)/(i>>>0)|0;v=a+3672|0;o=E-(ba(i,D)|0)|0;c[v>>2]=o;c[g>>2]=i;E=a+3684|0;B=a+3856|0;C=F;F=G;G=i;i=o;while(1){o=C<<8;c[E>>2]=o;if(F>>>0<H>>>0){k=d[F]|0|o;c[E>>2]=k;m=F+1|0;c[B>>2]=m;J=m;K=k}else{c[I>>2]=1;J=F;K=o}L=i<<8|K>>>1&255;c[v>>2]=L;o=G<<8;c[g>>2]=o;if(o>>>0<8388609>>>0){C=K;F=J;G=o;i=L}else{break}}i=G>>>8&65535;c[w>>2]=i;G=(L>>>0)/(i>>>0)|0;J=L-(ba(G,i)|0)|0;c[v>>2]=J;c[g>>2]=i;M=G|D<<16;N=i;O=J}else{M=y;N=z;O=A}if(h>>>0<65536>>>0){if(N>>>0<8388609>>>0){A=a+3684|0;z=a+3856|0;y=a+3672|0;J=a+3860|0;i=c[a+3848>>2]|0;D=c[A>>2]|0;G=c[z>>2]|0;v=N;L=O;while(1){F=D<<8;c[A>>2]=F;if(G>>>0<i>>>0){K=d[G]|0|F;c[A>>2]=K;C=G+1|0;c[z>>2]=C;P=C;Q=K}else{c[J>>2]=1;P=G;Q=F}F=L<<8|Q>>>1&255;c[y>>2]=F;K=v<<8;c[g>>2]=K;if(K>>>0<8388609>>>0){D=Q;G=P;v=K;L=F}else{R=K;S=F;break}}}else{R=N;S=O}L=(R>>>0)/(h>>>0)|0;c[w>>2]=L;R=(S>>>0)/(L>>>0)|0;c[a+3672>>2]=S-(ba(R,L)|0);c[g>>2]=L;T=R}else{R=h;L=0;do{R=R>>1;L=L+1|0;}while(R>>>0>65535>>>0);S=R+1|0;if(N>>>0<8388609>>>0){R=a+3684|0;v=a+3856|0;P=a+3672|0;G=a+3860|0;Q=c[a+3848>>2]|0;D=c[R>>2]|0;y=c[v>>2]|0;J=N;z=O;while(1){A=D<<8;c[R>>2]=A;if(y>>>0<Q>>>0){i=d[y]|0|A;c[R>>2]=i;F=y+1|0;c[v>>2]=F;U=F;V=i}else{c[G>>2]=1;U=y;V=A}A=z<<8|V>>>1&255;c[P>>2]=A;i=J<<8;c[g>>2]=i;if(i>>>0<8388609>>>0){D=V;y=U;J=i;z=A}else{W=i;X=A;break}}}else{W=N;X=O}O=(W>>>0)/(S>>>0)|0;c[w>>2]=O;S=(X>>>0)/(O>>>0)|0;W=a+3672|0;N=X-(ba(S,O)|0)|0;c[W>>2]=N;c[g>>2]=O;if(O>>>0<8388609>>>0){X=a+3684|0;z=a+3856|0;J=a+3860|0;U=c[a+3848>>2]|0;a=c[X>>2]|0;y=c[z>>2]|0;V=O;D=N;while(1){P=a<<8;c[X>>2]=P;if(y>>>0<U>>>0){G=d[y]|0|P;c[X>>2]=G;v=y+1|0;c[z>>2]=v;Y=v;Z=G}else{c[J>>2]=1;Y=y;Z=P}P=D<<8|Z>>>1&255;c[W>>2]=P;G=V<<8;c[g>>2]=G;if(G>>>0<8388609>>>0){a=Z;y=Y;V=G;D=P}else{_=G;$=P;break}}}else{_=O;$=N}N=_>>>(L>>>0);c[w>>2]=N;w=($>>>0)/(N>>>0)|0;c[W>>2]=$-(ba(N,w)|0);c[g>>2]=N;T=w+(S<<L)|0}L=T+(ba(M,h)|0)|0;h=b|0;b=c[h>>2]|0;if((b|0)==0){aa=0}else{aa=1<<b+4}M=c[f>>2]|0;T=((L+1|0)>>>1)-((M+16|0)>>>5)+M|0;c[f>>2]=T;if(T>>>0<aa>>>0){c[h>>2]=b-1;ca=L&1;da=(ca|0)==0;ea=L>>>1;fa=ea+1|0;ga=-ea|0;ha=da?ga:fa;return ha|0}if(T>>>0<1<<b+5>>>0){ca=L&1;da=(ca|0)==0;ea=L>>>1;fa=ea+1|0;ga=-ea|0;ha=da?ga:fa;return ha|0}c[h>>2]=b+1;ca=L&1;da=(ca|0)==0;ea=L>>>1;fa=ea+1|0;ga=-ea|0;ha=da?ga:fa;return ha|0}function FY(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;f=i;g=a+3676|0;h=c[g>>2]|0;if(h>>>0<8388609>>>0){j=a+3684|0;k=a+3856|0;l=a+3672|0;m=a+3860|0;n=c[a+3848>>2]|0;o=c[j>>2]|0;p=c[k>>2]|0;q=h;while(1){r=o<<8;c[j>>2]=r;if(p>>>0<n>>>0){s=d[p]|0|r;c[j>>2]=s;t=p+1|0;c[k>>2]=t;u=t;v=s}else{c[m>>2]=1;u=p;v=r}r=c[l>>2]<<8|v>>>1&255;c[l>>2]=r;s=q<<8;c[g>>2]=s;if(s>>>0<8388609>>>0){o=v;p=u;q=s}else{w=s;x=r;break}}}else{w=h;x=c[a+3672>>2]|0}h=w>>>16;w=a+3680|0;c[w>>2]=h;q=(x>>>0)/(h>>>0)|0;do{if((q|0)>65492){u=q-65472|0;p=x-(ba(h,q)|0)|0;c[a+3672>>2]=p;c[g>>2]=h;if((q|0)<=65535){y=u;z=h;A=p;break}c[a+3860>>2]=1;y=u;z=h;A=p}else{p=0;while(1){u=p+1|0;if((e[1418984+(u<<1)>>1]|0|0)>(q|0)){break}else{p=u}}u=e[1418888+(p<<1)>>1]|0;v=x-(ba(e[1418984+(p<<1)>>1]|0,h)|0)|0;c[a+3672>>2]=v;o=ba(u,h)|0;c[g>>2]=o;y=p;z=o;A=v}}while(0);if((y|0)==63){if(z>>>0<8388609>>>0){h=a+3684|0;x=a+3856|0;q=a+3672|0;v=a+3860|0;o=c[a+3848>>2]|0;u=c[h>>2]|0;l=c[x>>2]|0;m=z;k=A;while(1){j=u<<8;c[h>>2]=j;if(l>>>0<o>>>0){n=d[l]|0|j;c[h>>2]=n;r=l+1|0;c[x>>2]=r;B=r;C=n}else{c[v>>2]=1;B=l;C=j}j=k<<8|C>>>1&255;c[q>>2]=j;n=m<<8;c[g>>2]=n;if(n>>>0<8388609>>>0){u=C;l=B;m=n;k=j}else{D=n;E=j;break}}}else{D=z;E=A}k=D>>>5;c[w>>2]=k;D=(E>>>0)/(k>>>0)|0;m=E-(ba(k,D)|0)|0;c[a+3672>>2]=m;c[g>>2]=k;F=D;G=0;H=k;I=m}else{m=c[b>>2]|0;F=(m|0)==0?0:m-1|0;G=y;H=z;I=A}do{if((F|0)<17){J=26}else{if((c[a+1264>>2]|0)<3910){if((F|0)<=23){J=26;break}yDb(c[a+4>>2]|0,16,2210640,(K=i,i=i+8|0,c[K>>2]=F,K)|0);i=K;L=-1094995529;i=f;return L|0}if((F|0)>=33){yDb(c[a+4>>2]|0,16,2210640,(K=i,i=i+8|0,c[K>>2]=F,K)|0);i=K;L=-1094995529;i=f;return L|0}A=a+3684|0;if(H>>>0<8388609>>>0){z=a+3856|0;y=a+3672|0;m=a+3860|0;k=c[a+3848>>2]|0;D=c[A>>2]|0;E=c[z>>2]|0;B=H;l=I;while(1){C=D<<8;c[A>>2]=C;if(E>>>0<k>>>0){u=d[E]|0|C;c[A>>2]=u;q=E+1|0;c[z>>2]=q;M=q;N=u}else{c[m>>2]=1;M=E;N=C}C=l<<8|N>>>1&255;c[y>>2]=C;u=B<<8;c[g>>2]=u;if(u>>>0<8388609>>>0){D=N;E=M;B=u;l=C}else{O=u;P=C;Q=N;R=M;S=k;T=m;break}}}else{O=H;P=I;Q=c[A>>2]|0;R=c[a+3856>>2]|0;S=c[a+3848>>2]|0;T=a+3860|0}m=O>>>16;c[w>>2]=m;k=(P>>>0)/(m>>>0)|0;l=a+3672|0;B=P-(ba(m,k)|0)|0;c[l>>2]=B;c[g>>2]=m;E=a+3684|0;D=a+3856|0;y=Q;z=R;p=m;m=B;while(1){B=y<<8;c[E>>2]=B;if(z>>>0<S>>>0){C=d[z]|0|B;c[E>>2]=C;u=z+1|0;c[D>>2]=u;U=u;V=C}else{c[T>>2]=1;U=z;V=B}W=m<<8|V>>>1&255;c[l>>2]=W;X=p<<8;c[g>>2]=X;if(X>>>0<8388609>>>0){y=V;z=U;p=X;m=W}else{break}}m=X>>>((F-16|0)>>>0);c[w>>2]=m;p=(W>>>0)/(m>>>0)|0;c[l>>2]=W-(ba(p,m)|0);c[g>>2]=m;Y=p<<16|k}}while(0);if((J|0)==26){if(H>>>0<8388609>>>0){J=a+3684|0;W=a+3856|0;X=a+3672|0;U=a+3860|0;V=c[a+3848>>2]|0;T=c[J>>2]|0;S=c[W>>2]|0;R=H;Q=I;while(1){P=T<<8;c[J>>2]=P;if(S>>>0<V>>>0){O=d[S]|0|P;c[J>>2]=O;M=S+1|0;c[W>>2]=M;Z=M;_=O}else{c[U>>2]=1;Z=S;_=P}P=Q<<8|_>>>1&255;c[X>>2]=P;O=R<<8;c[g>>2]=O;if(O>>>0<8388609>>>0){T=_;S=Z;R=O;Q=P}else{$=O;aa=P;break}}}else{$=H;aa=I}I=$>>>(F>>>0);c[w>>2]=I;w=(aa>>>0)/(I>>>0)|0;c[a+3672>>2]=aa-(ba(I,w)|0);c[g>>2]=I;Y=w}w=Y+(G<<F)|0;F=b|0;G=c[F>>2]|0;if((G|0)==0){ca=0}else{ca=1<<G+4}Y=b+4|0;b=c[Y>>2]|0;I=((w+1|0)>>>1)-((b+16|0)>>>5)+b|0;c[Y>>2]=I;do{if(I>>>0<ca>>>0){c[F>>2]=G-1}else{if(I>>>0<1<<G+5>>>0){break}c[F>>2]=G+1}}while(0);G=w>>>1;if((w&1|0)==0){L=-G|0;i=f;return L|0}else{L=G+1|0;i=f;return L|0}return 0}function GY(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=b+8|0;h=c[g>>2]|0;j=(c[b+12>>2]|0)-h|0;k=b|0;l=b+16|0;b=0;m=h;while(1){if((b|0)>=(j|0)){break}h=d[(c[k>>2]|0)+(m>>>3)|0]|0;n=((m|0)<(c[l>>2]|0))+m|0;c[g>>2]=n;if((h&128>>>((m&7)>>>0)|0)==0){b=b+1|0;m=n}else{break}}if((c[a+1264>>2]|0)>3880&b>>>0>15>>>0){m=e|0;j=b;n=c[m>>2]|0;do{j=j-16|0;n=n+4|0;}while(j>>>0>15>>>0);c[m>>2]=n;o=j}else{o=b}b=e|0;j=c[b>>2]|0;do{if((j|0)==0){p=o;q=0}else{if(j>>>0<26>>>0){n=c[g>>2]|0;m=c[l>>2]|0;h=(c[k>>2]|0)+(n>>>3)|0;r=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(n&7)>>>((32-j|0)>>>0);h=n+j|0;c[g>>2]=m>>>0>h>>>0?h:m;p=r+(o<<j)|0;q=c[b>>2]|0;break}yDb(c[a+4>>2]|0,16,2210640,(r=i,i=i+8|0,c[r>>2]=j,r)|0);i=r;s=-1094995529;i=f;return s|0}}while(0);j=e+4|0;e=c[j>>2]|0;a=p-((e+8|0)>>>4)+e|0;c[j>>2]=a;if((q|0)==0){t=0}else{t=1<<q+4}do{if(a>>>0<t>>>0){c[b>>2]=q-1}else{if(!(a>>>0>=1<<q+5>>>0&q>>>0<24>>>0)){break}c[b>>2]=q+1}}while(0);q=p>>>1;if((p&1|0)==0){s=-q|0;i=f;return s|0}else{s=q+1|0;i=f;return s|0}return 0}function HY(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=e+4|0;c[g>>2]=0;h=a+3832|0;i=a+3836|0;j=a+3824|0;k=a+3840|0;a=0;do{l=c[h>>2]|0;m=(c[i>>2]|0)-l|0;n=0;o=l;while(1){if((n|0)>=(m|0)){p=4;break}l=c[j>>2]|0;q=d[l+(o>>>3)|0]|0;r=c[k>>2]|0;s=((o|0)<(r|0))+o|0;c[h>>2]=s;if((q&128>>>((o&7)>>>0)|0)==0){n=n+1|0;o=s}else{t=s;u=r;v=l;break}}if((p|0)==4){p=0;t=o;u=c[k>>2]|0;v=c[j>>2]|0}m=v+(t>>>3)|0;l=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(t&7)>>>22;m=t+10|0;c[h>>2]=u>>>0>m>>>0?m:u;m=l|n<<10;c[b+(a<<2)>>2]=m;w=m+(c[g>>2]|0)|0;c[g>>2]=w;a=a+1|0;}while((a|0)<5);a=(w>>>0)/10|0;u=w>>>0>655359>>>0;w=u?a>>>16:a;a=u?16:0;if((w&65280|0)==0){x=a;y=w}else{x=a|8;y=w>>>8}w=x+1+(d[1191992+y|0]|0)|0;y=e|0;c[y>>2]=w;if(w>>>0>23>>>0){return}else{z=5;A=w;B=v}while(1){if((z|0)>=64){break}w=c[h>>2]|0;e=(c[i>>2]|0)-w|0;x=0;a=w;while(1){if((x|0)>=(e|0)){C=a;break}w=d[B+(a>>>3)|0]|0;u=((a|0)<(c[k>>2]|0))+a|0;c[h>>2]=u;if((w&128>>>((a&7)>>>0)|0)==0){x=x+1|0;a=u}else{C=u;break}}if((A|0)==0){D=x;E=B}else{a=c[k>>2]|0;e=v+(C>>>3)|0;n=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(C&7)>>>((32-A|0)>>>0);e=C+A|0;c[h>>2]=a>>>0>e>>>0?e:a;D=n|x<<A;E=v}c[b+(z<<2)>>2]=D;n=(c[g>>2]|0)+D|0;c[g>>2]=n;a=z+1|0;e=(n>>>0)/(a<<1>>>0)|0;n=e>>>0>65535>>>0;o=n?e>>>16:e;e=n?16:0;if((o&65280|0)==0){F=e;G=o}else{F=e|8;G=o>>>8}o=F+1+(d[1191992+G|0]|0)|0;c[y>>2]=o;if(o>>>0>23>>>0){p=41;break}else{z=a;A=o;B=E}}if((p|0)==41){return}if((A|0)==0){H=0}else{H=1<<A+6}a:do{if((z|0)<(f|0)){p=z;E=1<<A+7;B=H;G=A;b:while(1){F=c[h>>2]|0;D=(c[i>>2]|0)-F|0;v=0;C=F;while(1){if((v|0)>=(D|0)){I=C;break}F=d[(c[j>>2]|0)+(C>>>3)|0]|0;o=((C|0)<(c[k>>2]|0))+C|0;c[h>>2]=o;if((F&128>>>((C&7)>>>0)|0)==0){v=v+1|0;C=o}else{I=o;break}}if((G|0)==0){J=v}else{C=c[k>>2]|0;D=(c[j>>2]|0)+(I>>>3)|0;o=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(I&7)>>>((32-G|0)>>>0);D=I+G|0;c[h>>2]=C>>>0>D>>>0?D:C;J=o|v<<G}c[b+(p<<2)>>2]=J;o=J-(c[b+(p-64<<2)>>2]|0)+(c[g>>2]|0)|0;c[g>>2]=o;if(o>>>0<B>>>0){C=E;D=B;F=c[y>>2]|0;do{F=F-1|0;D=(F|0)==0?0:D>>1;C=C>>1;}while(o>>>0<D>>>0);c[y>>2]=F;K=C;L=D}else{K=E;L=B}if(o>>>0<K>>>0){M=K;N=L}else{v=K;a=L;O=c[y>>2]|0;do{O=O+1|0;if(O>>>0>24>>>0){break b}v=v<<1;a=(a|0)==0?128:a<<1;}while(!(o>>>0<v>>>0));c[y>>2]=O;M=v;N=a}o=p+1|0;if((o|0)>=(f|0)){break a}p=o;E=M;B=N;G=c[y>>2]|0}c[y>>2]=O;return}}while(0);if((f|0)>0){P=0}else{return}do{O=b+(P<<2)|0;y=c[O>>2]|0;N=y>>1;c[O>>2]=(y&1|0)==0?-N|0:N+1|0;P=P+1|0;}while((P|0)<(f|0));return}function IY(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+100|0;e=WDb((c[d>>2]|0)+1|0)|0;c[b+860>>2]=e;if((e|0)==0){f=-12;return f|0}g=c[b+96>>2]|0;h=c[d>>2]|0;UGb(e|0,g|0,h)|0;a[e+h|0]=0;c[b+864>>2]=h;h=uhb(g)|0;c[b+60>>2]=h;f=((h|0)==0)<<31>>31;return f|0}function JY(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=e+28|0;g=c[f>>2]|0;do{if((g|0)>0){h=a+60|0;i=b;j=g;k=c[e+24>>2]|0;while(1){l=xhb(c[h>>2]|0,k,0,0)|0;if((l|0)==0){m=-1094995529;n=8;break}o=shb(i,k,0,(c[l+8>>2]|0)-(c[l+4>>2]|0)|0,1)|0;if((o|0)<0){m=o;n=8;break}l=j-o|0;if((l|0)>0){j=l;k=k+o|0}else{n=6;break}}if((n|0)==6){p=c[f>>2]|0;break}else if((n|0)==8){return m|0}}else{p=g}}while(0);c[d>>2]=(p|0)>0;m=c[f>>2]|0;return m|0}function KY(a){a=a|0;var b=0;b=a+60|0;whb(c[b>>2]|0);c[b>>2]=0;return 0}function LY(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=c[e+24>>2]|0;h=e+8|0;j=a+104|0;k=KDb(c[h>>2]|0,c[h+4>>2]|0,j,1790464)|0;h=c[e+48>>2]|0;l=KDb(h,(h|0)<0|0?-1:0,j,1790464)|0;j=e+28|0;e=c[j>>2]|0;if((e|0)<1){m=e;i=f;return m|0}e=shb(b,g,k,l,2)|0;if((e|0)>=0){c[d>>2]=(c[j>>2]|0)>0;m=c[j>>2]|0;i=f;return m|0}if(!((e|0)==-1094995529)){m=e;i=f;return m|0}yDb(a,16,2056824,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;m=-1094995529;i=f;return m|0}function MY(b){b=b|0;var d=0,e=0,f=0,g=0;d=b+864|0;e=WDb((c[d>>2]|0)+1|0)|0;c[b+96>>2]=e;if((e|0)==0){f=-12;return f|0}g=c[d>>2]|0;UGb(e|0,c[b+860>>2]|0,g)|0;c[b+100>>2]=g;a[e+g|0]=0;f=0;return f|0}function NY(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;i=i+2056|0;h=g|0;j=g+2048|0;k=f+12|0;if((c[k>>2]|0)==0){l=0;i=g;return l|0}m=f+16|0;f=b+12|0;n=h|0;o=c[b+60>>2]|0;p=0;q=0;while(1){r=c[(c[m>>2]|0)+(q<<2)>>2]|0;s=c[r+92>>2]|0;if((c[r+84>>2]|0)!=3){t=4;break}if((RGb(s,2010704,10)|0)!=0){t=6;break}if((c[(c[f>>2]|0)+12>>2]|0)==1095979808){if((q|0)>0){t=9;break}r=kb(s+10|0,j|0,10)|0;u=c[j>>2]|0;v=Vb(u|0,44)|0;if((v|0)==0){w=u}else{u=v+1|0;c[j>>2]=u;w=u}u=Vb(w|0,44)|0;if((u|0)==0){x=w}else{v=u+1|0;c[j>>2]=v;x=v}v=Vb(x|0,44)|0;if((v|0)==0){y=x}else{u=v+1|0;c[j>>2]=u;y=u}u=(c[o>>2]|0)+1|0;c[o>>2]=u;Lb(n|0,2048,1918416,(z=i,i=i+24|0,c[z>>2]=u,c[z+8>>2]=r,c[z+16>>2]=y,z)|0)|0;i=z;a[h+(hc(n|0,1897656)|0)|0]=0;A=n}else{A=s}r=e-p|0;u=sAb(d+p|0,A,r)|0;if((u|0)>(r-1|0)){t=18;break}r=u+p|0;u=q+1|0;if(u>>>0<(c[k>>2]|0)>>>0){p=r;q=u}else{l=r;t=20;break}}if((t|0)==4){yDb(b,16,2056784,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;l=-1;i=g;return l|0}else if((t|0)==6){yDb(b,16,1971712,(z=i,i=i+8|0,c[z>>2]=s,z)|0);i=z;l=-1094995529;i=g;return l|0}else if((t|0)==9){yDb(b,16,1943024,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;l=-1094995529;i=g;return l|0}else if((t|0)==18){yDb(b,16,2355032,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;l=-1;i=g;return l|0}else if((t|0)==20){i=g;return l|0}return 0}function OY(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;h=c[f+60>>2]|0;j=f+48|0;k=(c[j>>2]|0)==32?64:128;l=f+100|0;if((c[l>>2]|0)<1){yDb(f,24,2010680,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}Ihb(f);if(!(a[912752]|0)){a[912752]=1;c[2202845]=5092656;c[2202847]=64;N_(8811376,6,17,1261273,2,1,1261272,2,1,0,0,0,4)|0;c[2187435]=5087280;c[2187437]=64;N_(8749736,6,8,1261257,2,1,1261256,2,1,0,0,0,4)|0;c[2296437]=5087024;c[2296439]=64;N_(9185744,6,16,1261313,2,1,1261312,2,1,0,0,0,4)|0;c[1253529]=5086768;c[1253531]=64;N_(5014112,6,7,1261241,2,1,1261240,2,1,0,0,0,4)|0;c[2295811]=5088560;c[2295813]=1024;N_(9183240,10,63,1261345,2,1,1261344,2,1,0,0,0,4)|0}x2(h+1132|0,h+1292|0,1261176);c[f+140>>2]=0;if((c[l>>2]|0)<1){n=h+1424|0;o=8}else{l=a[c[f+96>>2]|0]|0;p=l&255;q=h+1424|0;c[q>>2]=p;if(l<<24>>24==0){n=q;o=8}else{r=p}}do{if((o|0)==8){yDb(f,16,1971688,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;if((c[j>>2]|0)==32){c[n>>2]=6;r=6;break}else{c[n>>2]=10;r=10;break}}}while(0);n=h+1424|0;j=h+2224|0;h=0;m=r;while(1){b[j+(h<<1)>>1]=(ba(e[1179176+((d[1261176+h|0]|0)<<1)>>1]|0,k)|0)/(m|0)|0;r=h+1|0;if((r|0)>=64){break}h=r;m=c[n>>2]|0}i=g;return 0}function PY(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=c[b+60>>2]|0;i=h;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=_$a(b,e,0)|0;if((g|0)<0){l=g;return l|0}c[e+88>>2]=1;c[e+84>>2]=1;g=h+2608|0;m=g;O$a(g,h+2612|0,k);g=c[m>>2]|0;if((g|0)==0){l=-12;return l|0}a:do{if((c[b+48>>2]|0)==32){Xe[c[h+1100>>2]&4095](g,j,(k|0)/4|0)}else{if((k|0)>0){n=0;o=g}else{break}while(1){a[o+n|0]=a[1148864+(d[j+n|0]|0)|0]|0;p=n+1|0;if((p|0)>=(k|0)){break a}n=p;o=c[m>>2]|0}}}while(0);o=c[m>>2]|0;m=k<<3;k=m>>>0>2147483639>>>0|(o|0)==0;n=k?0:o;o=k?0:m;c[h+1272>>2]=n;c[h+1284>>2]=o;c[h+1288>>2]=o+8;c[h+1276>>2]=n+(o>>3);o=h+1280|0;c[o>>2]=0;n=h+1440|0;m=c[n>>2]|0;k=h+1436|0;b:do{if((m|0)>0){j=h+1456|0;g=j;b=e+32|0;p=e;q=e+4|0;r=e+36|0;s=e+8|0;t=e+40|0;u=h+1124|0;v=j;j=h+1584|0;w=h+1712|0;x=h+1840|0;y=h;z=h+1968|0;A=h+2096|0;B=0;C=c[k>>2]|0;D=m;c:while(1){if((C|0)>0){E=B<<4;F=B<<3;G=0;do{H=RY(i,g)|0;if((H|0)<0){l=H;break c}H=c[b>>2]|0;I=c[p>>2]|0;J=(ba(E,H)|0)+(G<<4)|0;K=c[q>>2]|0;L=c[r>>2]|0;M=G<<3;N=c[s>>2]|0;O=c[t>>2]|0;Xe[c[u>>2]&4095](I+J|0,H,v);Xe[c[u>>2]&4095](I+(J|8)|0,H,j);P=J+(H<<3)|0;Xe[c[u>>2]&4095](I+P|0,H,w);Xe[c[u>>2]&4095](I+(P+8)|0,H,x);if((c[(c[y>>2]|0)+88>>2]&8192|0)==0){H=N+((ba(O,F)|0)+M)|0;O=K+((ba(L,F)|0)+M)|0;Xe[c[u>>2]&4095](O,c[r>>2]|0,z);Xe[c[u>>2]&4095](H,c[t>>2]|0,A)}G=G+1|0;Q=c[k>>2]|0;}while((G|0)<(Q|0));R=Q;S=c[n>>2]|0}else{R=C;S=D}G=B+1|0;if((G|0)<(S|0)){B=G;C=R;D=S}else{T=S;U=R;break b}}return l|0}else{T=m;U=c[k>>2]|0}}while(0);k=h+1428|0;d:do{if((U|0)!=(c[k>>2]|0)&(T|0)>0){m=h+1456|0;R=m;S=e+32|0;Q=e;D=U<<4;C=e+4|0;B=e+36|0;A=U<<3;t=e+8|0;u=e+40|0;z=h+1124|0;r=m;m=h+1584|0;y=h+1712|0;x=h+1840|0;w=h;j=h+1968|0;v=h+2096|0;s=0;while(1){q=RY(i,R)|0;if((q|0)<0){l=q;break}q=c[S>>2]|0;p=c[Q>>2]|0;b=(ba(s<<4,q)|0)+D|0;g=c[C>>2]|0;G=s<<3;F=c[B>>2]|0;E=c[t>>2]|0;H=c[u>>2]|0;Xe[c[z>>2]&4095](p+b|0,q,r);Xe[c[z>>2]&4095](p+(b|8)|0,q,m);O=b+(q<<3)|0;Xe[c[z>>2]&4095](p+O|0,q,y);Xe[c[z>>2]&4095](p+(O+8)|0,q,x);if((c[(c[w>>2]|0)+88>>2]&8192|0)==0){q=E+((ba(H,G)|0)+A)|0;H=g+((ba(F,G)|0)+A)|0;Xe[c[z>>2]&4095](H,c[B>>2]|0,j);Xe[c[z>>2]&4095](q,c[u>>2]|0,v)}q=s+1|0;H=c[n>>2]|0;if((q|0)<(H|0)){s=q}else{V=H;break d}}return l|0}else{V=T}}while(0);e:do{if((V|0)!=(c[h+1432>>2]|0)){if((c[k>>2]|0)<=0){break}T=h+1456|0;n=T;U=e+32|0;s=e;v=V<<4;u=e+4|0;z=V<<3;j=e+36|0;B=e+8|0;A=e+40|0;w=h+1124|0;x=T;T=h+1584|0;y=h+1712|0;m=h+1840|0;r=h;t=h+1968|0;C=h+2096|0;D=0;while(1){Q=RY(i,n)|0;if((Q|0)<0){l=Q;break}Q=c[U>>2]|0;S=c[s>>2]|0;R=(ba(v,Q)|0)+(D<<4)|0;H=c[u>>2]|0;q=c[j>>2]|0;G=D<<3;F=c[B>>2]|0;g=c[A>>2]|0;Xe[c[w>>2]&4095](S+R|0,Q,x);Xe[c[w>>2]&4095](S+(R|8)|0,Q,T);E=R+(Q<<3)|0;Xe[c[w>>2]&4095](S+E|0,Q,y);Xe[c[w>>2]&4095](S+(E+8)|0,Q,m);if((c[(c[r>>2]|0)+88>>2]&8192|0)==0){Q=F+((ba(g,z)|0)+G)|0;g=H+((ba(q,z)|0)+G)|0;Xe[c[w>>2]&4095](g,c[j>>2]|0,t);Xe[c[w>>2]&4095](Q,c[A>>2]|0,C)}D=D+1|0;if((D|0)>=(c[k>>2]|0)){break e}}return l|0}}while(0);c[f>>2]=1;l=(((c[o>>2]|0)+31|0)/32|0)<<2;return l|0}function QY(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+2608|0);c[b+2612>>2]=0;return 0}function RY(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;h=i;me[c[f+44>>2]&511](g|0);j=c[f>>2]|0;k=f+1280|0;l=f+1288|0;m=f+1272|0;if((c[j+48>>2]|0)==32){n=c[l>>2]|0;o=c[m>>2]|0;p=c[2202845]|0;q=0;r=c[k>>2]|0;a:while(1){s=o+(r>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>24;s=r+8|0;u=n>>>0>s>>>0?s:n;c[k>>2]=u;b[g+(q<<7)>>1]=t<<3;t=0;s=u;b:while(1){u=o+(s>>>3)|0;v=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(s&7)>>>26;u=b[p+(v<<2)>>1]|0;w=u<<16>>16;x=(b[p+(v<<2)+2>>1]|0)+s|0;v=n>>>0>x>>>0?x:n;c[k>>2]=v;do{if((w|0)==16){y=v;break b}else if((w|0)==0){z=v}else{if(u<<16>>16<0|(t|0)>9){break a}if((w&8|0)==0){A=v}else{x=c[1253529]|0;B=o+(v>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7)>>>26;B=b[x+(C<<2)>>1]|0;D=(b[x+(C<<2)+2>>1]|0)+v|0;C=n>>>0>D>>>0?D:n;c[k>>2]=C;if(B<<16>>16==3){D=o+(C>>>3)|0;x=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>24;D=C+8|0;E=n>>>0>D>>>0?D:n;c[k>>2]=E;F=x;G=E}else{F=(B<<16>>16)-3|0;G=C}C=t<<2;B=(ba(e[f+2224+(C<<1)>>1]|0,F)|0)>>>4&65535;b[g+(q<<7)+(d[f+1296+C|0]<<1)>>1]=B;A=G}if((w&4|0)==0){H=A}else{B=c[1253529]|0;C=o+(A>>>3)|0;E=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(A&7)>>>26;C=b[B+(E<<2)>>1]|0;x=(b[B+(E<<2)+2>>1]|0)+A|0;E=n>>>0>x>>>0?x:n;c[k>>2]=E;if(C<<16>>16==3){x=o+(E>>>3)|0;B=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(E&7)>>24;x=E+8|0;D=n>>>0>x>>>0?x:n;c[k>>2]=D;I=B;J=D}else{I=(C<<16>>16)-3|0;J=E}E=t<<2|1;C=(ba(e[f+2224+(E<<1)>>1]|0,I)|0)>>>4&65535;b[g+(q<<7)+(d[f+1296+E|0]<<1)>>1]=C;H=J}if((w&2|0)==0){K=H}else{C=c[1253529]|0;E=o+(H>>>3)|0;D=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(H&7)>>>26;E=b[C+(D<<2)>>1]|0;B=(b[C+(D<<2)+2>>1]|0)+H|0;D=n>>>0>B>>>0?B:n;c[k>>2]=D;if(E<<16>>16==3){B=o+(D>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(D&7)>>24;B=D+8|0;x=n>>>0>B>>>0?B:n;c[k>>2]=x;L=C;M=x}else{L=(E<<16>>16)-3|0;M=D}D=t<<2|2;E=(ba(e[f+2224+(D<<1)>>1]|0,L)|0)>>>4&65535;b[g+(q<<7)+(d[f+1296+D|0]<<1)>>1]=E;K=M}if((w&1|0)==0){z=K;break}E=c[1253529]|0;D=o+(K>>>3)|0;x=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(K&7)>>>26;D=b[E+(x<<2)>>1]|0;C=(b[E+(x<<2)+2>>1]|0)+K|0;x=n>>>0>C>>>0?C:n;c[k>>2]=x;if(D<<16>>16==3){C=o+(x>>>3)|0;E=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(x&7)>>24;C=x+8|0;B=n>>>0>C>>>0?C:n;c[k>>2]=B;N=E;O=B}else{N=(D<<16>>16)-3|0;O=x}x=t<<2|3;D=(ba(e[f+2224+(x<<1)>>1]|0,N)|0)>>>4&65535;b[g+(q<<7)+(d[f+1296+x|0]<<1)>>1]=D;z=O}}while(0);w=t+1|0;if((w|0)<11){t=w;s=z}else{y=z;break}}s=q+1|0;if((s|0)<6){q=s;r=y}else{P=0;Q=71;break}}if((Q|0)==71){i=h;return P|0}yDb(j,16,2056752,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;P=-1;i=h;return P|0}j=f+2230|0;Q=f+1299|0;y=f+2228|0;r=f+1298|0;q=f+2226|0;z=f+1297|0;O=c[l>>2]|0;l=c[m>>2]|0;m=c[2187435]|0;N=0;n=c[k>>2]|0;while(1){o=l+(n>>>3)|0;K=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(n&7)>>>28;o=n+4|0;M=O>>>0>o>>>0?o:O;c[k>>2]=M;o=d[1148864+(K<<4)|0]|0;K=l+(M>>>3)|0;L=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(M&7)>>>24;K=M+8|0;M=O>>>0>K>>>0?K:O;c[k>>2]=M;b[g+(N<<7)>>1]=d[1148864+L|0]<<3;L=l+(M>>>3)|0;K=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>26;L=b[m+(K<<2)>>1]|0;H=L<<16>>16;J=(b[m+(K<<2)+2>>1]|0)+M|0;M=O>>>0>J>>>0?J:O;c[k>>2]=M;do{if(L<<16>>16==0){R=M}else{if((H&4|0)==0){S=M}else{J=c[2295811]|0;K=l+(M>>>3)|0;I=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(M&7)>>>22;K=b[J+(I<<2)>>1]|0;A=(b[J+(I<<2)+2>>1]|0)+M|0;I=O>>>0>A>>>0?A:O;c[k>>2]=I;if(K<<16>>16==31){A=l+(I>>>3)|0;J=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(I&7)>>>24;A=I+8|0;G=O>>>0>A>>>0?A:O;c[k>>2]=G;T=a[1148864+J|0]|0;U=G}else{T=(K<<16>>16)-31|0;U=I}I=(ba(e[q>>1]|0,T)|0)>>>4&65535;b[g+(N<<7)+(d[z]<<1)>>1]=I;S=U}if((H&2|0)==0){V=S}else{I=c[2295811]|0;K=l+(S>>>3)|0;G=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(S&7)>>>22;K=b[I+(G<<2)>>1]|0;J=(b[I+(G<<2)+2>>1]|0)+S|0;G=O>>>0>J>>>0?J:O;c[k>>2]=G;if(K<<16>>16==31){J=l+(G>>>3)|0;I=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(G&7)>>>24;J=G+8|0;A=O>>>0>J>>>0?J:O;c[k>>2]=A;W=a[1148864+I|0]|0;X=A}else{W=(K<<16>>16)-31|0;X=G}G=(ba(e[y>>1]|0,W)|0)>>>4&65535;b[g+(N<<7)+(d[r]<<1)>>1]=G;V=X}if((H&1|0)==0){R=V;break}G=c[2295811]|0;K=l+(V>>>3)|0;A=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(V&7)>>>22;K=b[G+(A<<2)>>1]|0;I=(b[G+(A<<2)+2>>1]|0)+V|0;A=O>>>0>I>>>0?I:O;c[k>>2]=A;if(K<<16>>16==31){I=l+(A>>>3)|0;G=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(A&7)>>>24;I=A+8|0;J=O>>>0>I>>>0?I:O;c[k>>2]=J;Y=a[1148864+G|0]|0;Z=J}else{Y=(K<<16>>16)-31|0;Z=A}A=(ba(e[j>>1]|0,Y)|0)>>>4&65535;b[g+(N<<7)+(d[Q]<<1)>>1]=A;R=Z}}while(0);H=o+1|0;if(H>>>0>1>>>0){M=c[2296437]|0;L=1;A=R;while(1){K=l+(A>>>3)|0;J=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(A&7)>>>26;K=b[M+(J<<2)>>1]|0;G=K<<16>>16;I=(b[M+(J<<2)+2>>1]|0)+A|0;J=O>>>0>I>>>0?I:O;c[k>>2]=J;do{if(K<<16>>16==0){_=J}else{if((G&8|0)==0){$=J}else{I=c[2295811]|0;F=l+(J>>>3)|0;p=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(J&7)>>>22;F=b[I+(p<<2)>>1]|0;s=(b[I+(p<<2)+2>>1]|0)+J|0;p=O>>>0>s>>>0?s:O;c[k>>2]=p;if(F<<16>>16==31){s=l+(p>>>3)|0;I=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(p&7)>>>24;s=p+8|0;t=O>>>0>s>>>0?s:O;c[k>>2]=t;aa=a[1148864+I|0]|0;ca=t}else{aa=(F<<16>>16)-31|0;ca=p}p=L<<2;F=(ba(e[f+2224+(p<<1)>>1]|0,aa)|0)>>>4&65535;b[g+(N<<7)+(d[f+1296+p|0]<<1)>>1]=F;$=ca}if((G&4|0)==0){da=$}else{F=c[2295811]|0;p=l+($>>>3)|0;t=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<($&7)>>>22;p=b[F+(t<<2)>>1]|0;I=(b[F+(t<<2)+2>>1]|0)+$|0;t=O>>>0>I>>>0?I:O;c[k>>2]=t;if(p<<16>>16==31){I=l+(t>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(t&7)>>>24;I=t+8|0;s=O>>>0>I>>>0?I:O;c[k>>2]=s;ea=a[1148864+F|0]|0;fa=s}else{ea=(p<<16>>16)-31|0;fa=t}t=L<<2|1;p=(ba(e[f+2224+(t<<1)>>1]|0,ea)|0)>>>4&65535;b[g+(N<<7)+(d[f+1296+t|0]<<1)>>1]=p;da=fa}if((G&2|0)==0){ga=da}else{p=c[2295811]|0;t=l+(da>>>3)|0;s=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(da&7)>>>22;t=b[p+(s<<2)>>1]|0;F=(b[p+(s<<2)+2>>1]|0)+da|0;s=O>>>0>F>>>0?F:O;c[k>>2]=s;if(t<<16>>16==31){F=l+(s>>>3)|0;p=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(s&7)>>>24;F=s+8|0;I=O>>>0>F>>>0?F:O;c[k>>2]=I;ha=a[1148864+p|0]|0;ia=I}else{ha=(t<<16>>16)-31|0;ia=s}s=L<<2|2;t=(ba(e[f+2224+(s<<1)>>1]|0,ha)|0)>>>4&65535;b[g+(N<<7)+(d[f+1296+s|0]<<1)>>1]=t;ga=ia}if((G&1|0)==0){_=ga;break}t=c[2295811]|0;s=l+(ga>>>3)|0;I=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(ga&7)>>>22;s=b[t+(I<<2)>>1]|0;p=(b[t+(I<<2)+2>>1]|0)+ga|0;I=O>>>0>p>>>0?p:O;c[k>>2]=I;if(s<<16>>16==31){p=l+(I>>>3)|0;t=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(I&7)>>>24;p=I+8|0;F=O>>>0>p>>>0?p:O;c[k>>2]=F;ja=a[1148864+t|0]|0;ka=F}else{ja=(s<<16>>16)-31|0;ka=I}I=L<<2|3;s=(ba(e[f+2224+(I<<1)>>1]|0,ja)|0)>>>4&65535;b[g+(N<<7)+(d[f+1296+I|0]<<1)>>1]=s;_=ka}}while(0);G=L+1|0;if((G|0)<(H|0)){L=G;A=_}else{la=_;break}}}else{la=R}A=N+1|0;if((A|0)<6){N=A;n=la}else{P=0;break}}i=h;return P|0}function SY(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=c[a+60>>2]|0;d=(c[a+48>>2]|0)==32?32:64;Ihb(a);f=a+80|0;g=c[f>>2]|0;if((g|0)==0){c[f>>2]=512;h=512}else{h=g}g=b+1424|0;c[g>>2]=(((h|0)/2|0)+(d<<7)|0)/(h|0)|0;h=cEb(8)|0;c[a+96>>2]=h;c[a+100>>2]=8;c[h>>2]=c[g>>2];c[h+4>>2]=1398100801;h=b+2352|0;b=0;do{a=ba(e[1179176+(b<<1)>>1]|0,d)|0;c[h+(b<<2)>>2]=((a>>>1)+(c[g>>2]<<16)|0)/(a|0)|0;b=b+1|0;}while((b|0)<64);return 0}function TY(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=c[b+60>>2]|0;i=h;j=h+1432|0;k=h+1428|0;l=(ba((c[j>>2]|0)*1440|0,c[k>>2]|0)|0)+16384|0;m=r0a(b,e,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){n=m;return n|0}m=h+1248|0;l=m;o=e+24|0;p=e+28|0;q=c[p>>2]|0;r=(q|0)<0;s=r?0:c[o>>2]|0;t=r?0:q;c[h+1268>>2]=t<<3;q=h+1256|0;c[q>>2]=s;c[h+1264>>2]=s+t;t=h+1260|0;c[t>>2]=s;s=h+1252|0;c[s>>2]=32;r=m;c[r>>2]=0;m=h+1440|0;u=c[m>>2]|0;v=h+1436|0;if((u|0)>0){w=h+1456|0;y=0;z=c[v>>2]|0;A=u;while(1){if((z|0)>0){B=0;do{UY(i,f,B,y);VY(i,w);B=B+1|0;C=c[v>>2]|0;}while((B|0)<(C|0));D=C;E=c[m>>2]|0}else{D=z;E=A}B=y+1|0;if((B|0)<(E|0)){y=B;z=D;A=E}else{F=E;G=D;break}}}else{F=u;G=c[v>>2]|0}if((G|0)!=(c[k>>2]|0)&(F|0)>0){v=h+1456|0;u=0;while(1){UY(i,f,G,u);VY(i,v);D=u+1|0;E=c[m>>2]|0;if((D|0)<(E|0)){u=D}else{H=E;break}}}else{H=F}do{if((H|0)!=(c[j>>2]|0)){if((c[k>>2]|0)<=0){break}F=h+1456|0;u=0;do{UY(i,f,u,H);VY(i,F);u=u+1|0;}while((u|0)<(c[k>>2]|0))}}while(0);K_(l);l=c[s>>2]|0;k=c[q>>2]|0;i=c[t>>2]|0;H=(i-k<<3)+(32-l)|0;if((H&31|0)==0){I=H}else{H=c[r>>2]|0;f=l;l=k;k=i;while(1){if((f|0)>8){J=f-8|0;K=H<<8;L=l;M=k}else{i=k;x=fe(H<<f|0)|0;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;i=(c[t>>2]|0)+4|0;c[t>>2]=i;J=f+24|0;K=0;L=c[q>>2]|0;M=i}c[r>>2]=K;c[s>>2]=J;i=(M-L<<3)+(32-J)|0;if((i&31|0)==0){I=i;break}else{H=K;f=J;l=L;k=M}}}M=(I|0)/32|0;do{if((c[b+48>>2]|0)==32){I=c[o>>2]|0;Xe[c[h+1100>>2]&4095](I,I,M);N=M<<2}else{I=M<<2;if((I|0)>0){O=0}else{N=I;break}while(1){k=(c[o>>2]|0)+O|0;a[k]=a[1148864+(d[k]|0)|0]|0;k=O+1|0;if((k|0)<(I|0)){O=k}else{N=I;break}}}}while(0);c[p>>2]=N;N=e+36|0;c[N>>2]=c[N>>2]|1;c[g>>2]=1;n=0;return n|0}function UY(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[b+32>>2]|0;g=c[b>>2]|0;h=(ba(e<<4,f)|0)+(d<<4)|0;i=c[b+4>>2]|0;j=e<<3;e=b+36|0;k=c[e>>2]|0;l=d<<3;d=c[b+8>>2]|0;m=b+40|0;b=c[m>>2]|0;n=a+4|0;o=a+1456|0;Xe[c[n>>2]&4095](o,g+h|0,f);p=a+1584|0;Xe[c[n>>2]&4095](p,g+(h|8)|0,f);q=a+1712|0;r=h+(f<<3)|0;Xe[c[n>>2]&4095](q,g+r|0,f);h=a+1840|0;Xe[c[n>>2]&4095](h,g+(r+8)|0,f);f=a+1112|0;me[c[f>>2]&511](o);me[c[f>>2]&511](p);me[c[f>>2]&511](q);me[c[f>>2]&511](h);if((c[(c[a>>2]|0)+88>>2]&8192|0)!=0){return}h=d+((ba(b,j)|0)+l)|0;b=i+((ba(k,j)|0)+l)|0;l=a+1968|0;Xe[c[n>>2]&4095](l,b,c[e>>2]|0);e=a+2096|0;Xe[c[n>>2]&4095](e,h,c[m>>2]|0);me[c[f>>2]&511](l);me[c[f>>2]&511](e);return}function VY(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;g=i;h=e+1248|0;j=c[e+1256>>2]|0;k=e+1252|0;l=c[k>>2]|0;m=e+1260|0;n=c[m>>2]|0;o=c[e>>2]|0;if(((c[e+1264>>2]|0)-j-(32-l+(n-j<<3)>>3)|0)<1440){yDb(o,16,2010648,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;i=g;return}if((c[o+48>>2]|0)==32){o=h|0;j=d[1261273]|0;p=d[1261272]|0;q=32-j|0;r=d[1261305]|0;s=d[1261304]|0;t=32-r|0;u=0;v=c[o>>2]|0;w=l;while(1){y=f+(u<<7)|0;z=(b[y>>1]|0)+32>>6;if((w|0)>8){A=w-8|0;B=z|v<<8}else{C=fe(z>>>((8-w|0)>>>0)|v<<w|0)|0;D=c[m>>2]|0;x=C;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;A=w+24|0;B=z}c[o>>2]=B;c[k>>2]=A;b[y>>1]=0;y=0;z=0;while(1){D=d[1261176+(z<<2)|0]|0;C=f+(u<<7)+(D<<1)|0;E=((ba(b[C>>1]|0,c[e+2352+(D<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[C>>1]=E;F=E<<16>>16==0?0:8;E=D+8|0;G=f+(u<<7)+(E<<1)|0;H=((ba(b[G>>1]|0,c[e+2352+(E<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[G>>1]=H;E=H<<16>>16==0?F:F|4;F=D+1|0;H=f+(u<<7)+(F<<1)|0;I=((ba(b[H>>1]|0,c[e+2352+(F<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[H>>1]=I;F=I<<16>>16==0?E:E|2;E=D+9|0;D=f+(u<<7)+(E<<1)|0;I=((ba(b[D>>1]|0,c[e+2352+(E<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[D>>1]=I;E=I<<16>>16!=0|F;do{if((E|0)==0){J=y+1|0}else{I=c[o>>2]|0;K=c[k>>2]|0;if((y|0)==0){L=I;M=K}else{N=y;O=I;I=K;while(1){if((I|0)>(j|0)){P=I-j|0;Q=O<<j|p}else{K=fe(p>>>((j-I|0)>>>0)|O<<I|0)|0;R=c[m>>2]|0;x=K;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;P=q+I|0;Q=p}c[o>>2]=Q;c[k>>2]=P;R=N-1|0;if((R|0)==0){L=Q;M=P;break}else{N=R;O=Q;I=P}}}I=d[1261273+(E<<1)|0]|0;O=d[1261272+(E<<1)|0]|0;if((M|0)>(I|0)){S=M;T=L<<I|O}else{N=fe(O>>>((I-M|0)>>>0)|L<<M|0)|0;R=c[m>>2]|0;x=N;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;S=M+32|0;T=O}c[o>>2]=T;c[k>>2]=S-I;if((F&8|0)!=0){WY(h,b[C>>1]|0)}if((F&4|0)!=0){WY(h,b[G>>1]|0)}if((F&2|0)!=0){WY(h,b[H>>1]|0)}if((E&1|0)==0){J=0;break}WY(h,b[D>>1]|0);J=0}}while(0);D=z+1|0;if((D|0)<10){y=J;z=D}else{break}}z=c[o>>2]|0;y=c[k>>2]|0;if((y|0)>(r|0)){U=y-r|0;V=z<<r|s}else{D=fe(s>>>((r-y|0)>>>0)|z<<y|0)|0;z=c[m>>2]|0;x=D;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;U=t+y|0;V=s}c[o>>2]=V;c[k>>2]=U;y=u+1|0;if((y|0)<6){u=y;v=V;w=U}else{break}}i=g;return}U=e+1248|0;w=d[1261407]|0;V=d[1261406]|0;v=32-w|0;u=0;o=l;l=n;while(1){n=f+(u<<7)|0;s=63;while(1){if((s|0)<=3){break}t=d[1261176+s|0]|0;if(((ba(b[f+(u<<7)+(t<<1)>>1]|0,c[e+2352+(t<<2)>>2]|0)|0)+32768|0)>>>0>65535>>>0){break}else{s=s-1|0}}t=s>>2;r=d[1148864+(t<<4)|0]|0;J=c[U>>2]|0;if((o|0)>4){W=o-4|0;X=J<<4|r;Y=l}else{h=l;x=fe(r>>>((4-o|0)>>>0)|J<<o|0)|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=(c[m>>2]|0)+4|0;c[m>>2]=h;W=o+28|0;X=r;Y=h}c[U>>2]=X;c[k>>2]=W;h=d[1148864+((b[n>>1]|0)+32>>6)|0]|0;if((W|0)>8){Z=W-8|0;_=h|X<<8;$=Y}else{r=Y;x=fe(h>>>((8-W|0)>>>0)|X<<W|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[m>>2]|0)+4|0;c[m>>2]=r;Z=W+24|0;_=h;$=r}c[U>>2]=_;c[k>>2]=Z;b[n>>1]=0;if((t|0)<0){aa=Z;ca=$}else{r=0;h=_;J=Z;S=$;while(1){T=d[1261176+(r<<2)|0]|0;M=f+(u<<7)+(T<<1)|0;L=((ba(b[M>>1]|0,c[e+2352+(T<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[M>>1]=L;P=L<<16>>16==0?0:8;L=T+8|0;Q=f+(u<<7)+(L<<1)|0;p=((ba(b[Q>>1]|0,c[e+2352+(L<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[Q>>1]=p;L=p<<16>>16==0?P:P|4;P=T+1|0;p=f+(u<<7)+(P<<1)|0;q=((ba(b[p>>1]|0,c[e+2352+(P<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[p>>1]=q;P=q<<16>>16==0?L:L|2;L=T+9|0;T=f+(u<<7)+(L<<1)|0;q=((ba(b[T>>1]|0,c[e+2352+(L<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[T>>1]=q;L=q<<16>>16!=0|P;do{if((r|0)==0){q=d[1261257+(L<<1)|0]|0;j=d[1261256+(L<<1)|0]|0;if((J|0)>(q|0)){da=J-q|0;ea=h<<q|j;fa=S;break}else{A=S;x=fe(j>>>((q-J|0)>>>0)|h<<J|0)|0;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;A=(c[m>>2]|0)+4|0;c[m>>2]=A;da=J+32-q|0;ea=j;fa=A;break}}else{A=d[1261313+(L<<1)|0]|0;j=d[1261312+(L<<1)|0]|0;if((J|0)>(A|0)){da=J-A|0;ea=h<<A|j;fa=S;break}else{q=S;x=fe(j>>>((A-J|0)>>>0)|h<<J|0)|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=(c[m>>2]|0)+4|0;c[m>>2]=q;da=J+32-A|0;ea=j;fa=q;break}}}while(0);c[U>>2]=ea;c[k>>2]=da;do{if((L|0)==0){ga=ea;ha=da;ia=fa}else{do{if((P&8|0)==0){ja=ea;ka=da;la=fa}else{q=b[M>>1]|0;j=q+31|0;if(j>>>0<63>>>0){A=d[1261345+(j<<1)|0]|0;B=d[1261344+(j<<1)|0]|0;if((da|0)>(A|0)){ma=da;na=ea<<A|B;oa=fa}else{j=fa;x=fe(B>>>((A-da|0)>>>0)|ea<<da|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=(c[m>>2]|0)+4|0;c[m>>2]=j;ma=da+32|0;na=B;oa=j}j=ma-A|0;c[U>>2]=na;c[k>>2]=j;ja=na;ka=j;la=oa;break}if((da|0)>(w|0)){pa=da-w|0;qa=ea<<w|V;ra=fa}else{j=fa;x=fe(V>>>((w-da|0)>>>0)|ea<<da|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=(c[m>>2]|0)+4|0;c[m>>2]=j;pa=da+v|0;qa=V;ra=j}c[U>>2]=qa;c[k>>2]=pa;j=d[1148864+(q&255)|0]|0;if((pa|0)>8){sa=pa-8|0;ta=j|qa<<8;ua=ra}else{q=ra;x=fe(j>>>((8-pa|0)>>>0)|qa<<pa|0)|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=(c[m>>2]|0)+4|0;c[m>>2]=q;sa=pa+24|0;ta=j;ua=q}c[U>>2]=ta;c[k>>2]=sa;ja=ta;ka=sa;la=ua}}while(0);do{if((P&4|0)==0){va=ja;wa=ka;xa=la}else{q=b[Q>>1]|0;j=q+31|0;if(j>>>0<63>>>0){A=d[1261345+(j<<1)|0]|0;B=d[1261344+(j<<1)|0]|0;if((ka|0)>(A|0)){ya=ka;za=ja<<A|B;Aa=la}else{j=la;x=fe(B>>>((A-ka|0)>>>0)|ja<<ka|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=(c[m>>2]|0)+4|0;c[m>>2]=j;ya=ka+32|0;za=B;Aa=j}j=ya-A|0;c[U>>2]=za;c[k>>2]=j;va=za;wa=j;xa=Aa;break}if((ka|0)>(w|0)){Ba=ka-w|0;Ca=ja<<w|V;Da=la}else{j=la;x=fe(V>>>((w-ka|0)>>>0)|ja<<ka|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Ba=ka+v|0;Ca=V;Da=j}c[U>>2]=Ca;c[k>>2]=Ba;j=d[1148864+(q&255)|0]|0;if((Ba|0)>8){Ea=Ba-8|0;Fa=j|Ca<<8;Ga=Da}else{q=Da;x=fe(j>>>((8-Ba|0)>>>0)|Ca<<Ba|0)|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=(c[m>>2]|0)+4|0;c[m>>2]=q;Ea=Ba+24|0;Fa=j;Ga=q}c[U>>2]=Fa;c[k>>2]=Ea;va=Fa;wa=Ea;xa=Ga}}while(0);do{if((P&2|0)==0){Ha=va;Ia=wa;Ja=xa}else{q=b[p>>1]|0;j=q+31|0;if(j>>>0<63>>>0){A=d[1261345+(j<<1)|0]|0;B=d[1261344+(j<<1)|0]|0;if((wa|0)>(A|0)){Ka=wa;La=va<<A|B;Ma=xa}else{j=xa;x=fe(B>>>((A-wa|0)>>>0)|va<<wa|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Ka=wa+32|0;La=B;Ma=j}j=Ka-A|0;c[U>>2]=La;c[k>>2]=j;Ha=La;Ia=j;Ja=Ma;break}if((wa|0)>(w|0)){Na=wa-w|0;Oa=va<<w|V;Pa=xa}else{j=xa;x=fe(V>>>((w-wa|0)>>>0)|va<<wa|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Na=wa+v|0;Oa=V;Pa=j}c[U>>2]=Oa;c[k>>2]=Na;j=d[1148864+(q&255)|0]|0;if((Na|0)>8){Qa=Na-8|0;Ra=j|Oa<<8;Sa=Pa}else{q=Pa;x=fe(j>>>((8-Na|0)>>>0)|Oa<<Na|0)|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=(c[m>>2]|0)+4|0;c[m>>2]=q;Qa=Na+24|0;Ra=j;Sa=q}c[U>>2]=Ra;c[k>>2]=Qa;Ha=Ra;Ia=Qa;Ja=Sa}}while(0);if((L&1|0)==0){ga=Ha;ha=Ia;ia=Ja;break}q=b[T>>1]|0;j=q+31|0;if(j>>>0<63>>>0){A=d[1261345+(j<<1)|0]|0;B=d[1261344+(j<<1)|0]|0;if((Ia|0)>(A|0)){Ta=Ia;Ua=Ha<<A|B;Va=Ja}else{j=Ja;x=fe(B>>>((A-Ia|0)>>>0)|Ha<<Ia|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Ta=Ia+32|0;Ua=B;Va=j}j=Ta-A|0;c[U>>2]=Ua;c[k>>2]=j;ga=Ua;ha=j;ia=Va;break}if((Ia|0)>(w|0)){Wa=Ia-w|0;Xa=Ha<<w|V;Ya=Ja}else{j=Ja;x=fe(V>>>((w-Ia|0)>>>0)|Ha<<Ia|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Wa=Ia+v|0;Xa=V;Ya=j}c[U>>2]=Xa;c[k>>2]=Wa;j=d[1148864+(q&255)|0]|0;if((Wa|0)>8){Za=Wa-8|0;_a=j|Xa<<8;$a=Ya}else{q=Ya;x=fe(j>>>((8-Wa|0)>>>0)|Xa<<Wa|0)|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=(c[m>>2]|0)+4|0;c[m>>2]=q;Za=Wa+24|0;_a=j;$a=q}c[U>>2]=_a;c[k>>2]=Za;ga=_a;ha=Za;ia=$a}}while(0);T=r+1|0;if((T|0)>(t|0)){aa=ha;ca=ia;break}else{r=T;h=ga;J=ha;S=ia}}}S=u+1|0;if((S|0)<6){u=S;o=aa;l=ca}else{break}}i=g;return}function WY(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=e+3|0;if(f>>>0<7>>>0){g=d[1261241+(f<<1)|0]|0;h=d[1261240+(f<<1)|0]|0;f=b|0;i=c[f>>2]|0;j=b+4|0;k=c[j>>2]|0;if((k|0)>(g|0)){l=k-g|0;m=i<<g|h}else{n=fe(h>>>((g-k|0)>>>0)|i<<k|0)|0;i=b+12|0;o=c[i>>2]|0;x=n;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;l=32-g+k|0;m=h}c[f>>2]=m;c[j>>2]=l;return}l=d[1261247]|0;j=d[1261246]|0;m=b|0;f=c[m>>2]|0;h=b+4|0;k=c[h>>2]|0;if((k|0)>(l|0)){p=k-l|0;q=f<<l|j}else{g=fe(j>>>((l-k|0)>>>0)|f<<k|0)|0;f=b+12|0;i=c[f>>2]|0;x=g;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;p=32-l+k|0;q=j}c[m>>2]=q;c[h>>2]=p;j=e&255;if((p|0)>8){r=p-8|0;s=q<<8|j}else{e=fe(j>>>((8-p|0)>>>0)|q<<p|0)|0;q=b+12|0;b=c[q>>2]|0;x=e;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;r=p+24|0;s=j}c[m>>2]=s;c[h>>2]=r;return}function XY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+60|0;e=c[d>>2]|0;c[a+420>>2]=8;f=c[a+416>>2]|0;if((f-1|0)>>>0>1>>>0){yDb(a,16,2115944,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-22;i=b;return h|0}if((c[a+432>>2]|0)<1){yDb(a,16,2056720,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1163346256;i=b;return h|0}f=aLa(e+17420|0,6,1,-30517578125.0e-15)|0;do{if((f|0)==0){j=aLa(e+17484|0,8,1,-30517578125.0e-15)|0;if((j|0)!=0){k=j;break}j=aLa(e+17548|0,9,1,-30517578125.0e-15)|0;if((j|0)!=0){k=j;break}VXa(5);Jhb();fCb(e+17612|0,c[a+88>>2]&8388608);c[e+17408>>2]=e+13312;c[e+17412>>2]=e+14336;c[e+17416>>2]=e+15360;c[e+16>>2]=e+32;c[e+20>>2]=e+2080;c[e+5648>>2]=e+5664;c[e+5652>>2]=e+7712;h=0;i=b;return h|0}else{k=f}}while(0);yDb(a,16,2010616,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;g=c[d>>2]|0;bLa(g+17420|0);bLa(g+17484|0);bLa(g+17548|0);h=k;i=b;return h|0}function YY(b,f,h,j){b=b|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0,Z=0.0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;k=i;i=i+3368|0;l=k|0;m=k+56|0;n=c[j+24>>2]|0;o=c[b+60>>2]|0;p=o;q=b+416|0;if((c[j+28>>2]|0)<((c[q>>2]|0)*212|0|0)){yDb(b,16,2194288,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;r=-1094995529;i=k;return r|0}c[f+76>>2]=512;j=_$a(b,f,0)|0;if((j|0)<0){r=j;i=k;return r|0}a:do{if((c[q>>2]|0)>0){j=o;s=o+11264|0;t=o+17628|0;u=f+64|0;v=o+17408|0;w=o+17412|0;x=k+112|0;y=k+1136|0;z=o+17416|0;A=0;b:while(1){B=A*212|0;C=n+B|0;D=(C|0)==0?8:1704;E=C;C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>6;if((C&1|0)!=0){r=-1094995529;F=46;break}c[j+(A*5632|0)>>2]=2-(C&3);C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>4;if((C&1|0)!=0){r=-1094995529;F=46;break}c[j+(A*5632|0)+4>>2]=2-(C&3);C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>2&3;if(!((C|0)==3|(C|0)==0)){r=-1094995529;F=46;break}c[j+(A*5632|0)+8>>2]=C^3;C=n+(B|1)|0;E=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>5&7;C=D>>>0>11>>>0?11:D;G=d[1732696+E|0]|0;c[j+(A*5632|0)+12>>2]=G;H=G*10|0;I=n+((C>>>3)+B)|0;J=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(C&3)>>>30;I=C+2|0;C=D>>>0>I>>>0?I:D;I=d[1732688+J|0]|0;J=n+((C>>>3)+B)|0;K=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(C&7)>>>29;J=C+3|0;C=(d[1732680+K|0]|0)<<1;K=0;L=D>>>0>J>>>0?J:D;do{J=n+((L>>>3)+B)|0;M=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7)>>>28;J=L+4|0;L=D>>>0>J>>>0?J:D;a[l+K|0]=M;K=K+1|0;}while((K|0)<(G|0));K=H+32+I+C|0;M=0;J=L;do{N=n+((J>>>3)+B)|0;O=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(J&7)>>>26;N=J+6|0;J=D>>>0>N>>>0?N:D;a[m+M|0]=O;M=M+1|0;}while((M|0)<(G|0));if((E|0)==7){P=0;Q=K;R=0;S=J}else{M=52-G|0;TGb(m+G|0,0,M|0)|0;TGb(l+G|0,0,M|0)|0;P=0;Q=K;R=0;S=J}while(1){M=P+1|0;L=a[1732672+M|0]|0;if((R&255)>>>0<(L&255)>>>0){C=j+(A*5632|0)+(P<<2)|0;I=L&255;H=R&255;O=Q;N=S;while(1){T=d[431720+H|0]|0;U=a[l+H|0]|0;V=(U<<24>>24!=0)+(U&255)|0;W=+g[7959224+((d[m+H|0]|0)<<2)>>2];U=(ba(V,T)|0)+O|0;if((U|0)>1696){r=-1094995529;F=46;break b}X=e[((c[C>>2]|0)==0?1732568:1732464)+(H<<1)>>1]|0;if((V|0)==0){TGb(s+(X<<2)|0,0,T<<2|0)|0;Y=N}else{Z=1.0/+((1<<V-1)-1|0);_=32-V|0;$=0;aa=N;while(1){ca=n+((aa>>>3)+B)|0;da=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(aa&7)>>_;ca=aa+V|0;ea=D>>>0>ca>>>0?ca:D;g[s+($+X<<2)>>2]=Z*W*+(da|0);da=$+1|0;if((da|0)<(T|0)){$=da;aa=ea}else{Y=ea;break}}}aa=H+1|0;if((aa|0)<(I|0)){H=aa;O=U;N=Y}else{fa=U;ga=Y;break}}}else{fa=Q;ga=S}if((M|0)<3){P=M;Q=fa;R=L;S=ga}else{break}}D=j+(A*5632|0)+20|0;B=j+(A*5632|0)+16|0;J=0;K=0;G=0;while(1){E=e[483120+(J<<1)>>1]|0;N=c[j+(A*5632|0)+(J<<2)>>2]|0;O=1<<N;H=(O|0)==1;do{if(H){I=E>>>(N>>>0);C=(d[679088+J|0]|0)-N|0;if((C|0)==7){ha=C}else if((C|0)==5){ha=5}else if((C|0)==8){ha=C}else{r=-1094995529;F=46;break b}C=E+K|0;ia=ha;ja=I;ka=C;la=(c[D>>2]|0)+(C-16<<2)|0;F=32}else{C=E+K|0;if((O|0)<=0){ma=C;na=G;break}ia=5;ja=32;ka=C;la=(c[D>>2]|0)+(C-16<<2)|0;F=32}}while(0);do{if((F|0)==32){F=0;E=ia-5-(ia>>>0>6>>>0)|0;L=p+17420+(E<<6)|0;M=1<<ia;C=p+17420+(E<<6)+44|0;E=p+17408+(J<<2)|0;I=(M|0)/2|0;aa=(M|0)>1;$=M-1|0;M=c[B>>2]|0;c:do{if((J|0)==0){if(aa){T=0;X=G;V=la;_=0;ea=M;while(1){da=T+K|0;Xe[c[C>>2]&4095](L,ea+(da<<2)|0,p+11264+(X<<2)|0);le[c[t>>2]&1023]((c[E>>2]|0)+(T<<2)|0,V,(c[B>>2]|0)+(da<<2)|0,5452456,16);ca=c[B>>2]|0;oa=_+1|0;if((oa|0)<(O|0)){T=T+ja|0;X=X+ja|0;V=ca+(da+16<<2)|0;_=oa;ea=ca}else{pa=ca;break}}}else{ea=0;_=G;V=la;X=0;T=M;while(1){ca=ea+K|0;Xe[c[C>>2]&4095](L,T+(ca<<2)|0,p+11264+(_<<2)|0);le[c[t>>2]&1023]((c[E>>2]|0)+(ea<<2)|0,V,(c[B>>2]|0)+(ca<<2)|0,5452456,16);oa=c[B>>2]|0;da=X+1|0;if((da|0)<(O|0)){ea=ea+ja|0;_=_+ja|0;V=oa+(ca+16<<2)|0;X=da;T=oa}else{pa=oa;break}}}}else{if(aa){qa=0;ra=G;sa=la;ta=0;ua=M}else{T=0;X=G;V=la;_=0;ea=M;while(1){oa=T+K|0;Xe[c[C>>2]&4095](L,ea+(oa<<2)|0,p+11264+(X<<2)|0);le[c[t>>2]&1023]((c[E>>2]|0)+(T<<2)|0,V,(c[B>>2]|0)+(oa<<2)|0,5452456,16);da=c[B>>2]|0;ca=_+1|0;if((ca|0)<(O|0)){T=T+ja|0;X=X+ja|0;V=da+(oa+16<<2)|0;_=ca;ea=da}else{pa=da;break c}}}while(1){ea=qa+K|0;_=$+ra|0;V=0;do{X=p+11264+(_-V<<2)|0;W=+g[X>>2];T=p+11264+(V+ra<<2)|0;g[X>>2]=+g[T>>2];g[T>>2]=W;V=V+1|0;}while((V|0)<(I|0));Xe[c[C>>2]&4095](L,ua+(ea<<2)|0,p+11264+(ra<<2)|0);le[c[t>>2]&1023]((c[E>>2]|0)+(qa<<2)|0,sa,(c[B>>2]|0)+(ea<<2)|0,5452456,16);V=c[B>>2]|0;_=ta+1|0;if((_|0)<(O|0)){qa=qa+ja|0;ra=ra+ja|0;sa=V+(ea+16<<2)|0;ta=_;ua=V}else{pa=V;break}}}}while(0);L=(ja<<N)+G|0;if(!H){ma=ka;na=L;break}UGb((c[E>>2]|0)+128|0,pa+(K+16<<2)|0,960)|0;ma=ka;na=L}}while(0);H=J+1|0;if((H|0)<3){J=H;K=ma;G=na}else{break}}G=c[D>>2]|0;c[D>>2]=c[B>>2];c[B>>2]=G;G=c[(c[u>>2]|0)+(A<<2)>>2]|0;Mhb(c[v>>2]|0,c[w>>2]|0,128,x,j+(A*5632|0)+4128|0,y);K=j+(A*5632|0)+4512|0;UGb(K|0,j+(A*5632|0)+5536|0,92)|0;UGb(j+(A*5632|0)+4604|0,c[z>>2]|0,1024)|0;Mhb(x,K|0,256,G,j+(A*5632|0)+4320|0,y);A=A+1|0;if((A|0)>=(c[q>>2]|0)){break a}}if((F|0)==46){i=k;return r|0}}}while(0);c[h>>2]=1;r=c[b+432>>2]|0;i=k;return r|0}function ZY(a){a=a|0;var b=0;b=c[a+60>>2]|0;bLa(b+17420|0);bLa(b+17484|0);bLa(b+17548|0);return 0}function _Y(b){b=b|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;h=c[b+96>>2]|0;j=b+60|0;k=c[j>>2]|0;l=b+416|0;if(((c[l>>2]|0)-1|0)>>>0>1>>>0){yDb(b,16,1942992,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=f;return n|0}if(!(a[1788504]|0)){o=255;p=0;while(1){q=+U(((+(p|0)+.5)*.00390625+-.5)*3.141592653589793)+1.0;r=+U(((+(o|0)+.5)*.00390625+-.5)*3.141592653589793)+1.0;s=(q*q+r*r)*.5;t=q/s;g[4975160+(511-p<<2)>>2]=t;g[4975160+(p<<2)>>2]=t;t=r/s;g[4975160+(511-o<<2)>>2]=t;g[4975160+(o<<2)>>2]=t;u=p+1|0;if((u|0)<128){o=o-1|0;p=u}else{break}}Jhb();p=0;o=0;while(1){c[4284348+(p*20|0)>>2]=9166856+(o<<2);u=p+1|0;v=e[1788480+(u<<1)>>1]|0;c[4284356+(p*20|0)>>2]=v-o;N_(4284344+(p*20|0)|0,9,d[920032+p|0]|0,c[921072+(p<<2)>>2]|0,1,1,c[921040+(p<<2)>>2]|0,1,1,0,0,0,4)|0;if((u|0)<7){p=u;o=v}else{break}}}a[1788504]=1;o=c[b+100>>2]|0;do{if((o|0)==12|(o|0)==10){p=h;v=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+4|0;u=(de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=h+6|0;w=(de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=h+8|0;x=(de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;c[k+20>>2]=x;c[k+4384>>2]=1;if((v|0)==67108864){y=w;z=u;A=x;break}x=fe(v|0)|0;yDb(b,16,2291008,(m=i,i=i+8|0,c[m>>2]=x,m)|0);i=m;n=-1094995529;i=f;return n|0}else if((o|0)==14){x=b;v=h;yDb(x,48,1918400,(m=i,i=i+8|0,c[m>>2]=(d[v]|d[v+1|0]<<8)<<16>>16&65535,m)|0);i=m;v=h+6|0;u=k+20|0;c[u>>2]=(d[v]|d[v+1|0]<<8)<<16>>16&65535;v=h+8|0;yDb(x,48,1897640,(m=i,i=i+8|0,c[m>>2]=(d[v]|d[v+1|0]<<8)<<16>>16&65535,m)|0);i=m;v=h+10|0;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;v=h+12|0;yDb(x,48,2355016,(m=i,i=i+8|0,c[m>>2]=(d[v]|d[v+1|0]<<8)<<16>>16&65535,m)|0);i=m;v=c[l>>2]<<10;p=(c[u>>2]|0)!=0?18:2;c[u>>2]=p;c[k+4384>>2]=0;u=c[b+432>>2]|0;B=c[l>>2]|0;if((u|0)==(ba(w*96|0,B)|0)){y=2190;z=v;A=p;break}if((u|0)==(ba(w*152|0,B)|0)){y=2190;z=v;A=p;break}if((u|0)==(ba(w*192|0,B)|0)){y=2190;z=v;A=p;break}yDb(x,16,2334776,(m=i,i=i+24|0,c[m>>2]=u,c[m+8>>2]=B,c[m+16>>2]=w,m)|0);i=m;n=-1094995529;i=f;return n|0}else{yDb(0,16,2309816,(m=i,i=i+8|0,c[m>>2]=o,m)|0);i=m;n=-22;i=f;return n|0}}while(0);if(!((z|0)==2048|(z|0)==1024)){yDb(b,16,2275120,(m=i,i=i+8|0,c[m>>2]=z,m)|0);i=m;n=-1094995529;i=f;return n|0}if((y|0)!=2190){yDb(b,16,2259344,(m=i,i=i+8|0,c[m>>2]=y,m)|0);i=m;n=-1094995529;i=f;return n|0}do{if((A|0)==2){yDb(b,48,2244752,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}else if((A|0)==18){y=b;if((c[l>>2]|0)==2){yDb(y,48,2219848,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;break}yDb(y,16,2232408,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}else{yDb(b,16,2210600,(m=i,i=i+8|0,c[m>>2]=A,m)|0);i=m;n=-1094995529;i=f;return n|0}}while(0);A=c[b+432>>2]|0;if(A>>>0>2147483646>>>0){n=-22;i=f;return n|0}y=cEb(A+19&-4)|0;A=k+100|0;c[A>>2]=y;if((y|0)==0){n=-12;i=f;return n|0}c[b+420>>2]=8;y=aLa(k+4588|0,9,1,30517578125.0e-15)|0;if((y|0)<0){yDb(b,16,2201864,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;$Db(A);n=y;i=f;return n|0}c[k+76>>2]=0;c[k+80>>2]=7;c[k+84>>2]=0;c[k+88>>2]=7;c[k+92>>2]=0;c[k+96>>2]=7;c[k+28>>2]=3;c[k+44>>2]=3;c[k+60>>2]=3;c[k+32>>2]=3;c[k+48>>2]=3;c[k+64>>2]=3;c[k+36>>2]=3;c[k+52>>2]=3;c[k+68>>2]=3;c[k+40>>2]=3;c[k+56>>2]=3;c[k+72>>2]=3;Khb(k+4388|0,4,3);fCb(k+4672|0,c[b+88>>2]&8388608);iba(k+4652|0,b);b=cEb((c[l>>2]|0)*15936|0)|0;c[k+24>>2]=b;if((b|0)!=0){n=0;i=f;return n|0}b=c[j>>2]|0;ZDb(c[b+24>>2]|0);ZDb(c[b+100>>2]|0);bLa(b+4588|0);n=-12;i=f;return n|0}function $Y(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0.0,T=0.0,U=0,V=0.0,W=0.0,X=0.0,Y=0,Z=0,_=0.0,$=0.0,aa=0,ca=0,da=0,ea=0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=b+60|0;m=c[h>>2]|0;n=b+432|0;if((l|0)<(c[n>>2]|0)){yDb(b,16,2194240,(o=i,i=i+8|0,c[o>>2]=l,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+76>>2]=1024;l=_$a(b,e,0)|0;if((l|0)<0){p=l;i=j;return p|0}do{if((c[m+4384>>2]|0)==0){q=k}else{l=m+100|0;r=c[l>>2]|0;s=c[n>>2]|0;t=r;u=k&3;v=k+(-u|0)|0;w=(u|0)!=0;if(w){x=u<<3;y=fe(1400856835<<32-x|1400856835>>>(x>>>0)|0)|0}else{y=56721235}x=u+3+s|0;s=(x|0)/4|0;if((x|0)>3){x=0;do{c[t+(x<<2)>>2]=c[v+(x<<2)>>2]^y;x=x+1|0;}while((x|0)<(s|0))}if(!w){q=r;break}DDb(0,1971672,(o=i,i=i+8|0,c[o>>2]=u,o)|0);i=o;q=c[l>>2]|0}}while(0);y=c[e+64>>2]|0;e=c[h>>2]|0;h=e;k=e+20|0;a:do{if((c[k>>2]|0)==18){m=e;s=c[n>>2]<<3;x=s>>>0>2147483639>>>0|(q|0)==0;v=x?0:q;t=x?0:s;s=e;c[s>>2]=v;x=e+12|0;c[x>>2]=t;z=e+16|0;c[z>>2]=t+8;A=e+4|0;c[A>>2]=v+(t>>3);t=e+8|0;c[t>>2]=0;v=e+24|0;B=bZ(h,m,c[v>>2]|0,c[y>>2]|0,0,18)|0;if((B|0)!=0){C=B;D=55;break}B=e+100|0;E=c[B>>2]|0;F=c[n>>2]|0;G=F-1|0;do{if((E|0)==(q|0)){if((F|0)<=1){H=F;break}I=q+G|0;J=q;K=0;while(1){L=a[I]|0;a[I]=a[J]|0;a[J]=L;L=K+1|0;M=c[n>>2]|0;if((L|0)<((M|0)/2|0|0)){I=I-1|0;J=J+1|0;K=L}else{H=M;break}}}else{if((F|0)<=0){H=F;break}K=q+G|0;a[E]=a[K]|0;J=c[n>>2]|0;if((J|0)>1){N=K;O=1}else{H=J;break}while(1){J=N-1|0;a[(c[B>>2]|0)+O|0]=a[J]|0;K=O+1|0;I=c[n>>2]|0;if((K|0)<(I|0)){N=J;O=K}else{H=I;break}}}}while(0);E=c[B>>2]|0;if((a[E]|0)==-8){G=E;F=4;while(1){if((F|0)>=(H|0)){C=-1094995529;D=55;break a}l=G+1|0;if((a[l]|0)==-8){G=l;F=F+1|0}else{P=l;break}}}else{P=E}F=E+H-P|0;G=F>>>0>268435455>>>0?-8:F<<3;F=G>>>0>2147483639>>>0|(P|0)==0;B=F?0:P;l=F?0:G;c[s>>2]=B;c[x>>2]=l;G=l+8|0;c[z>>2]=G;c[A>>2]=B+(l>>3);c[t>>2]=0;l=e+76|0;F=e+84|0;VGb(l|0,F|0,16)|0;u=(d[B]|0)>>>7;r=(G|0)>0;w=r&1;c[t>>2]=w;c[e+92>>2]=u;u=B;I=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<w>>>29;w=r?4:3;r=G>>>0>w>>>0?w:G;c[t>>2]=r;c[e+96>>2]=I;I=e+44|0;w=e+28|0;c[w>>2]=c[I>>2];u=e+60|0;c[I>>2]=c[u>>2];K=B+(r>>>3)|0;J=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(r&7)>>>30;K=r+2|0;r=G>>>0>K>>>0?K:G;c[t>>2]=r;c[u>>2]=J;J=e+48|0;c[e+32>>2]=c[J>>2];u=e+64|0;c[J>>2]=c[u>>2];J=B+(r>>>3)|0;K=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(r&7)>>>30;J=r+2|0;r=G>>>0>J>>>0?J:G;c[t>>2]=r;c[u>>2]=K;K=e+52|0;c[e+36>>2]=c[K>>2];u=e+68|0;c[K>>2]=c[u>>2];K=B+(r>>>3)|0;J=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(r&7)>>>30;K=r+2|0;r=G>>>0>K>>>0?K:G;c[t>>2]=r;c[u>>2]=J;J=e+56|0;c[e+40>>2]=c[J>>2];u=e+72|0;c[J>>2]=c[u>>2];J=B+(r>>>3)|0;B=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(r&7)>>>30;J=r+2|0;c[t>>2]=G>>>0>J>>>0?J:G;c[u>>2]=B;B=y+4|0;u=bZ(h,m,(c[v>>2]|0)+15936|0,c[B>>2]|0,1,18)|0;if((u|0)!=0){C=u;D=55;break}u=c[y>>2]|0;G=c[B>>2]|0;B=0;J=0;r=8;while(1){K=c[w+(J<<2)>>2]|0;M=c[I+(J<<2)>>2]|0;do{if((K|0)==(M|0)){Q=B}else{L=K<<1;S=+g[684680+(L<<2)>>2];T=+g[684680+((L|1)<<2)>>2];L=M<<1;U=B|8;if((B|0)>=(U|0)){Q=B;break}V=S;W=+g[684680+(L<<2)>>2]-S;S=T;X=+g[684680+((L|1)<<2)>>2]-T;L=B;while(1){Y=u+(L<<2)|0;Z=G+(L<<2)|0;T=+g[Y>>2];_=+(L-B|0)*.125;$=T*(V+W*_)+ +g[Z>>2]*(S+X*_);g[Y>>2]=$;g[Z>>2]=T*2.0-$;Z=L+1|0;if((Z|0)<(U|0)){L=Z}else{Q=r;break}}}}while(0);do{if((M|0)==0){K=B+256|0;if((Q|0)<(K|0)){aa=Q}else{ca=K;break}while(1){L=u+(aa<<2)|0;X=+g[L>>2];U=G+(aa<<2)|0;S=+g[U>>2];g[L>>2]=S*2.0;g[U>>2]=(X-S)*2.0;U=aa+1|0;if((U|0)<(K|0)){aa=U}else{ca=K;break}}}else if((M|0)==1){K=B+256|0;if((Q|0)<(K|0)){da=Q}else{ca=K;break}while(1){U=u+(da<<2)|0;L=G+(da<<2)|0;S=+g[L>>2];g[U>>2]=(+g[U>>2]+S)*2.0;g[L>>2]=S*-2.0;L=da+1|0;if((L|0)<(K|0)){da=L}else{ca=K;break}}}else if((M|0)==2|(M|0)==3){K=B+256|0;if((Q|0)<(K|0)){ea=Q}else{ca=K;break}while(1){L=u+(ea<<2)|0;S=+g[L>>2];U=G+(ea<<2)|0;X=+g[U>>2];g[L>>2]=S+X;g[U>>2]=S-X;U=ea+1|0;if((U|0)<(K|0)){ea=U}else{ca=K;break}}}else{ca=B+256|0}}while(0);if((ca|0)<1024){B=ca;J=J+1|0;r=r+256|0}else{break}}r=c[e+80>>2]|0;J=c[e+88>>2]|0;if((r|0)==7){if((J|0)==7){break}else{fa=1.0;ga=1.0;D=42}}else{X=+(r&7|0)/7.0;S=+R(2.0-X*X);r=(c[l>>2]|0)==0;W=r?S:X;V=r?X:S;if((J|0)==7){ha=1.0;ia=1.0;ja=W;ka=V}else{fa=W;ga=V;D=42}}if((D|0)==42){V=+(J&7|0)/7.0;W=+R(2.0-V*V);J=(c[F>>2]|0)==0;ha=J?V:W;ia=J?W:V;ja=fa;ka=ga}V=ka;W=ja-ka;S=ha;X=ia-ha;J=256;while(1){$=+(J-256|0)*.125;r=u+(J<<2)|0;g[r>>2]=+g[r>>2]*(V+W*$);r=G+(J<<2)|0;g[r>>2]=+g[r>>2]*(S+X*$);r=J+1|0;if((r|0)<264){J=r}else{la=264;break}}while(1){J=u+(la<<2)|0;g[J>>2]=ha*+g[J>>2];J=G+(la<<2)|0;g[J>>2]=ia*+g[J>>2];J=la+1|0;if((J|0)<512){la=J}else{ma=512;break}}while(1){$=+(ma-512|0)*.125;J=u+(ma<<2)|0;g[J>>2]=+g[J>>2]*(V+W*$);J=G+(ma<<2)|0;g[J>>2]=+g[J>>2]*(S+X*$);J=ma+1|0;if((J|0)<520){ma=J}else{na=520;break}}while(1){J=u+(na<<2)|0;g[J>>2]=ha*+g[J>>2];J=G+(na<<2)|0;g[J>>2]=ia*+g[J>>2];J=na+1|0;if((J|0)<768){na=J}else{oa=768;break}}while(1){$=+(oa-768|0)*.125;J=u+(oa<<2)|0;g[J>>2]=+g[J>>2]*(V+W*$);J=G+(oa<<2)|0;g[J>>2]=+g[J>>2]*(S+X*$);J=oa+1|0;if((J|0)<776){oa=J}else{pa=776;break}}do{J=u+(pa<<2)|0;g[J>>2]=ha*+g[J>>2];J=G+(pa<<2)|0;g[J>>2]=ia*+g[J>>2];pa=pa+1|0;}while((pa|0)<1024)}else{G=b+416|0;u=e;J=e;F=e+12|0;l=e+16|0;r=e+4|0;B=e+8|0;I=e+24|0;w=0;while(1){v=c[G>>2]|0;if((w|0)>=(v|0)){break a}m=c[n>>2]|0;t=q+((ba(m,w)|0)/(v|0)|0)|0;A=(m<<3|0)/(v|0)|0;v=A>>>0>2147483639>>>0|(t|0)==0;m=v?0:t;t=v?0:A;c[J>>2]=m;c[F>>2]=t;c[l>>2]=t+8;c[r>>2]=m+(t+7>>3);c[B>>2]=0;t=bZ(h,u,(c[I>>2]|0)+(w*15936|0)|0,c[y+(w<<2)>>2]|0,w,c[k>>2]|0)|0;if((t|0)==0){w=w+1|0}else{C=t;D=55;break}}}}while(0);if((D|0)==55){yDb(0,16,2115920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=C;i=j;return p|0}C=b+416|0;if((c[C>>2]|0)>0){b=e+24|0;o=e+104|0;e=0;do{D=c[y+(e<<2)>>2]|0;k=D;h=D+2048|0;Mhb(k,D+1024|0,256,k,(c[b>>2]|0)+(e*15936|0)+15360|0,o);Mhb(D+3072|0,h,256,h,(c[b>>2]|0)+(e*15936|0)+15544|0,o);Mhb(k,h,512,k,(c[b>>2]|0)+(e*15936|0)+15728|0,o);e=e+1|0;}while((e|0)<(c[C>>2]|0))}c[f>>2]=1;p=c[n>>2]|0;i=j;return p|0}function aZ(a){a=a|0;var b=0;b=c[a+60>>2]|0;ZDb(c[b+24>>2]|0);ZDb(c[b+100>>2]|0);bLa(b+4588|0);return 0}function bZ(a,b,f,h,j,k){a=a|0;b=b|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0.0,ca=0,da=0,ea=0,fa=0,ga=0.0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;l=i;i=i+816|0;m=l|0;n=l+16|0;o=l+48|0;p=l+176|0;q=l+304|0;r=f+4104|0;s=c[r>>2]|0;t=1-s|0;u=b+8|0;v=c[u>>2]|0;w=b+16|0;x=c[w>>2]|0;y=b|0;z=c[y>>2]|0;A=z+(v>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(v&7);do{if((k|0)==18&(j|0)==1){A=v+2|0;C=x>>>0>A>>>0?A:x;c[u>>2]=C;if((B&-1073741824|0)==-1073741824){D=C;break}yDb(0,16,2056688,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1094995529;i=l;return F|0}else{C=v+6|0;A=x>>>0>C>>>0?C:x;c[u>>2]=A;if((B&-67108864|0)==-1610612736){D=A;break}yDb(0,16,2010592,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1094995529;i=l;return F|0}}while(0);E=z+(D>>>3)|0;B=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>30;E=D+2|0;c[u>>2]=x>>>0>E>>>0?E:x;x=f|0;c[x>>2]=B;E=0;a:do{D=c[u>>2]|0;v=c[w>>2]|0;j=z+(D>>>3)|0;k=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(D&7)>>>29;j=D+3|0;c[u>>2]=v>>>0>j>>>0?j:v;v=f+6668+(t*240|0)+(E*60|0)|0;c[v>>2]=k;if((k|0)!=0){k=0;do{j=c[u>>2]|0;D=c[w>>2]|0;A=z+(j>>>3)|0;C=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(j&7)>>>28;A=j+4|0;c[u>>2]=D>>>0>A>>>0?A:D;c[f+6668+(t*240|0)+(E*60|0)+4+(k<<2)>>2]=C;C=c[u>>2]|0;D=c[w>>2]|0;A=z+(C>>>3)|0;j=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(C&7)>>>27;A=C+5|0;c[u>>2]=D>>>0>A>>>0?A:D;c[f+6668+(t*240|0)+(E*60|0)+32+(k<<2)>>2]=j;if((k|0)!=0){if((j|0)<=(c[f+6668+(t*240|0)+(E*60|0)+32+(k-1<<2)>>2]|0)){F=-1094995529;G=66;break a}}k=k+1|0;}while((k|0)<(c[v>>2]|0))}E=E+1|0;}while((E|0)<=(B|0));if((G|0)==66){i=l;return F|0}if((E|0)<4){G=E;do{c[f+6668+(t*240|0)+(G*60|0)>>2]=0;G=G+1|0;}while((G|0)<4)}G=c[x>>2]|0;x=c[u>>2]|0;E=c[w>>2]|0;B=z+(x>>>3)|0;v=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>27;B=x+5|0;x=E>>>0>B>>>0?B:E;c[u>>2]=x;b:do{if((v|0)==0){H=0}else{B=z+(x>>>3)|0;k=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>30;B=x+2|0;j=E>>>0>B>>>0?B:E;c[u>>2]=j;if((k|0)==2){H=-1094995529;break}B=(G|0)<0;D=(k|0)==3;A=(G<<2)+4|0;C=(A|0)>0;I=n|0;J=0;K=k&1;k=1;L=j;while(1){if(B){M=L;N=c[w>>2]|0;O=c[y>>2]|0}else{j=c[y>>2]|0;P=c[w>>2]|0;Q=0;R=L;while(1){S=(d[j+(R>>>3)|0]|0)<<(R&7)>>>7;T=((R|0)<(P|0))+R|0;c[u>>2]=T;c[m+(Q<<2)>>2]=S&1;S=Q+1|0;if((S|0)>(G|0)){M=T;N=P;O=j;break}else{Q=S;R=T}}}R=O+(M>>>3)|0;Q=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(M&7)>>>29;R=M+3|0;j=N>>>0>R>>>0?R:N;c[u>>2]=j;R=O+(j>>>3)|0;P=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(j&7);R=P>>>29;T=j+3|0;j=N>>>0>T>>>0?T:N;c[u>>2]=j;if(P>>>0<1073741824>>>0){H=-1094995529;break b}if(D){P=(d[O+(j>>>3)|0]|0)<<(j&7)>>>7;c[u>>2]=((j|0)<(N|0))+j;U=P&1}else{U=K}if(C){P=Q+1|0;Q=904960+(R<<2)|0;j=J;T=0;while(1){c:do{if((c[m+(T>>2<<2)>>2]|0)==0){V=j}else{S=c[u>>2]|0;W=c[w>>2]|0;X=c[y>>2]|0;Y=X+(S>>>3)|0;Z=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(S&7)>>>29;Y=S+3|0;S=W>>>0>Y>>>0?Y:W;c[u>>2]=S;if((Z|0)==0){V=j;break}Y=T<<6;_=X+(S>>>3)|0;$=d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0;_=S+6|0;aa=W>>>0>_>>>0?_:W;c[u>>2]=aa;if((j|0)>63){H=-1094995529;break b}ba=+g[Q>>2];_=X;X=W;W=S;S=1;ca=j;da=$;$=aa;while(1){aa=(fe(da|0)|0)<<(W&7)>>>26;ea=_+($>>>3)|0;fa=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<($&7)>>>26;ea=$+6|0;c[u>>2]=X>>>0>ea>>>0?ea:X;ea=fa|Y;c[f+4108+(ca*40|0)>>2]=ea;fa=1024-ea|0;ea=(fa|0)>(P|0)?P:fa;ga=+g[7959224+(aa<<2)>>2]*ba;cZ(b,R,U,I,ea);c[f+4108+(ca*40|0)+4>>2]=ea;if((ea|0)>0){aa=0;do{g[f+4108+(ca*40|0)+8+(aa<<2)>>2]=ga*+(c[n+(aa<<2)>>2]|0);aa=aa+1|0;}while((aa|0)<(ea|0))}ea=ca+1|0;if((S|0)>=(Z|0)){V=ea;break c}aa=c[u>>2]|0;fa=c[w>>2]|0;ha=c[y>>2]|0;ia=ha+(aa>>>3)|0;ja=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;ia=aa+6|0;ka=fa>>>0>ia>>>0?ia:fa;c[u>>2]=ka;if((ea|0)>63){H=-1094995529;break b}else{_=ha;X=fa;W=aa;S=S+1|0;ca=ea;da=ja;$=ka}}}}while(0);$=T+1|0;if(($|0)<(A|0)){j=V;T=$}else{la=V;break}}}else{la=J}if((k|0)>=(v|0)){H=la;break b}J=la;K=U;k=k+1|0;L=c[u>>2]|0}}}while(0);U=f+4|0;c[U>>2]=H;if((H|0)<0){F=H;i=l;return F|0}H=c[u>>2]|0;la=c[w>>2]|0;w=c[y>>2]|0;y=w+(H>>>3)|0;v=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(H&7)>>>27;y=H+5|0;H=la>>>0>y>>>0?y:la;c[u>>2]=H;y=d[w+(H>>>3)|0]|0;V=((H|0)<(la|0))+H|0;c[u>>2]=V;n=0;m=V;do{V=w+(m>>>3)|0;N=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(m&7)>>>29;V=m+3|0;m=la>>>0>V>>>0?V:la;c[u>>2]=m;c[o+(n<<2)>>2]=N;n=n+1|0;}while((n|0)<=(v|0));n=y<<(H&7)>>>7;H=0;y=m;while(1){if((c[o+(H<<2)>>2]|0)==0){ma=y}else{m=w+(y>>>3)|0;N=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(y&7)>>>26;m=y+6|0;V=la>>>0>m>>>0?m:la;c[u>>2]=V;c[p+(H<<2)>>2]=N;ma=V}V=H+1|0;if((V|0)>(v|0)){break}else{H=V;y=ma}}ma=n&1;n=q|0;y=0;H=0;while(1){u=y+1|0;na=e[429696+(u<<1)>>1]|0;la=na-H|0;w=c[o+(y<<2)>>2]|0;do{if((w|0)==0){TGb(f+7168+(H<<2)|0,0,la<<2|0)|0}else{cZ(b,w,ma,n,la);ba=+g[7959224+(c[p+(y<<2)>>2]<<2)>>2]*+g[904960+(w<<2)>>2];if(H>>>0<na>>>0){oa=H;pa=0}else{break}while(1){g[f+7168+(oa<<2)>>2]=ba*+(c[q+(pa<<2)>>2]|0);V=oa+1|0;if((V|0)<(na|0)){oa=V;pa=pa+1|0}else{break}}}}while(0);if((u|0)>(v|0)){break}else{y=u;H=na}}TGb(f+7168+(na<<2)|0,0,1024-na<<2|0)|0;na=c[U>>2]|0;do{if((na|0)>0){U=-1;H=0;do{y=c[f+4108+(H*40|0)>>2]|0;pa=c[f+4108+(H*40|0)+4>>2]|0;oa=pa+y|0;U=(oa|0)>(U|0)?oa:U;if((pa|0)>0){oa=0;do{q=f+7168+(oa+y<<2)|0;g[q>>2]=+g[f+4108+(H*40|0)+8+(oa<<2)>>2]+ +g[q>>2];oa=oa+1|0;}while((oa|0)<(pa|0))}H=H+1|0;}while((H|0)<(na|0));H=(e[429696+(v<<1)>>1]|0)-1>>8;if(!((U|0)>-1)){qa=H;break}u=U+256>>8;qa=(u|0)>(H|0)?u:H}else{qa=(e[429696+(v<<1)>>1]|0)-1>>8}}while(0);v=f+11264|0;na=a+4388|0;H=f+11264|0;u=a+4588|0;pa=a+4628|0;oa=a+4672|0;a=0;do{if((a|0)>(qa|0)){TGb(v|0,0,2048)|0;ra=a<<8}else{y=a<<8;q=f+7168+(y<<2)|0;if((a&1|0)!=0){p=y|255;n=0;do{ma=f+7168+(p-n<<2)|0;ba=+g[ma>>2];b=f+7168+(n+y<<2)|0;g[ma>>2]=+g[b>>2];g[b>>2]=ba;n=n+1|0;}while((n|0)<128)}Xe[c[pa>>2]&4095](u,H,q);cf[c[oa>>2]&1023](H,H,4975160,512);ra=y}Lhb(na,H,f+8+(ra<<2)|0,f+6668+(s*240|0)+(a*60|0)|0,f+6668+(t*240|0)+(a*60|0)|0,256,h+(ra<<2)|0);a=a+1|0;}while((a|0)<4);c[r>>2]=c[r>>2]^1;F=0;i=l;return F|0}function cZ(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=(f|0)==1;if(j){k=(i|0)/2|0}else{k=i}if((g|0)!=0){g=d[1484536+f|0]|0;i=(k|0)>0;if((f|0)>1){if(!i){return}l=e+8|0;m=e+16|0;n=e|0;o=32-g|0;p=0;do{q=c[l>>2]|0;r=c[m>>2]|0;s=(c[n>>2]|0)+(q>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(q&7)>>o;s=q+g|0;c[l>>2]=r>>>0>s>>>0?s:r;c[h+(p<<2)>>2]=t;p=p+1|0;}while((p|0)<(k|0));return}if(!i){return}i=e+8|0;p=e+16|0;l=e|0;o=32-g|0;if((f|0)==0){n=0;do{m=n<<1;c[h+(m<<2)>>2]=0;c[h+((m|1)<<2)>>2]=0;n=n+1|0;}while((n|0)<(k|0));return}else{n=0;do{m=c[i>>2]|0;t=c[p>>2]|0;r=(c[l>>2]|0)+(m>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(m&7)>>>(o>>>0);r=m+g|0;c[i>>2]=t>>>0>r>>>0?r:t;t=n<<1;c[h+(t<<2)>>2]=a[685192+(s>>2)|0]|0;c[h+((t|1)<<2)>>2]=a[685192+(s&3)|0]|0;n=n+1|0;}while((n|0)<(k|0));return}}n=(k|0)>0;if(j){if(!n){return}j=e+8|0;i=e+16|0;g=c[1071087]|0;o=c[e>>2]|0;l=0;do{p=c[1071086]|0;s=c[j>>2]|0;t=c[i>>2]|0;r=o+(s>>>3)|0;m=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((32-p|0)>>>0);r=b[g+(m<<2)>>1]|0;q=b[g+(m<<2)+2>>1]|0;m=q<<16>>16;do{if(q<<16>>16<0){u=s+p|0;v=t>>>0>u>>>0?u:t;u=o+(v>>>3)|0;w=((fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(v&7)>>>((m+32|0)>>>0))+r|0;u=b[g+(w<<2)>>1]|0;x=b[g+(w<<2)+2>>1]|0;w=x<<16>>16;if(!(x<<16>>16<0)){y=w;z=u;A=v;break}x=v-m|0;v=t>>>0>x>>>0?x:t;x=o+(v>>>3)|0;B=((fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(v&7)>>>((w+32|0)>>>0))+u|0;y=b[g+(B<<2)+2>>1]|0;z=b[g+(B<<2)>>1]|0;A=v}else{y=m;z=r;A=s}}while(0);s=y+A|0;c[j>>2]=t>>>0>s>>>0?s:t;s=z<<1;r=l<<1;c[h+(r<<2)>>2]=a[685168+s|0]|0;c[h+((r|1)<<2)>>2]=a[685168+(s|1)|0]|0;l=l+1|0;}while((l|0)<(k|0));return}else{if(!n){return}n=f-1|0;f=4284344+(n*20|0)|0;l=e+8|0;z=e+16|0;j=c[4284348+(n*20|0)>>2]|0;n=c[e>>2]|0;e=0;do{A=c[f>>2]|0;y=c[l>>2]|0;g=c[z>>2]|0;o=n+(y>>>3)|0;i=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(y&7)>>>((32-A|0)>>>0);o=b[j+(i<<2)>>1]|0;s=b[j+(i<<2)+2>>1]|0;i=s<<16>>16;do{if(s<<16>>16<0){r=y+A|0;m=g>>>0>r>>>0?r:g;r=n+(m>>>3)|0;p=((fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(m&7)>>>((i+32|0)>>>0))+o|0;r=b[j+(p<<2)>>1]|0;q=b[j+(p<<2)+2>>1]|0;p=q<<16>>16;if(!(q<<16>>16<0)){C=p;D=r;E=m;break}q=m-i|0;m=g>>>0>q>>>0?q:g;q=n+(m>>>3)|0;v=((fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(m&7)>>>((p+32|0)>>>0))+r|0;C=b[j+(v<<2)+2>>1]|0;D=b[j+(v<<2)>>1]|0;E=m}else{C=i;D=o;E=y}}while(0);y=C+E|0;c[l>>2]=g>>>0>y>>>0?y:g;y=D+1|0;o=y>>1;c[h+(e<<2)>>2]=(y&1|0)==0?o:-o|0;e=e+1|0;}while((e|0)<(k|0));return}}function dZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=b+60|0;f=c[e>>2]|0;if((c[b+432>>2]|0)==0){yDb(b,16,1971648,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=d;return h|0}Nhb();fCb(f+20|0,c[b+88>>2]&8388608);aLa(f+65864|0,5,1,.0009765625)|0;gZ(b,f+65800|0);Khb(f+65600|0,6,2);hZ();j=f+65936|0;TGb(j|0,0,5)|0;k=c[b+416>>2]|0;switch(k|0){case 4:{l=b+448|0;c[l>>2]=263;c[l+4>>2]=0;c[f+65932>>2]=3;a[j]=1;a[f+65937|0]=0;a[f+65938|0]=0;m=110400;break};case 6:{l=b+448|0;c[l>>2]=63;c[l+4>>2]=0;c[f+65932>>2]=4;a[j]=1;a[f+65937|0]=0;a[f+65938|0]=1;a[f+65939|0]=0;m=147200;break};case 8:{l=b+448|0;c[l>>2]=1599;c[l+4>>2]=0;c[f+65932>>2]=5;a[j]=1;a[f+65937|0]=0;a[f+65938|0]=1;a[f+65939|0]=1;a[f+65940|0]=0;m=184e3;break};case 2:{l=b+448|0;c[l>>2]=3;c[l+4>>2]=0;c[f+65932>>2]=1;a[j]=1;m=36800;break};case 3:{l=b+448|0;c[l>>2]=7;c[l+4>>2]=0;c[f+65932>>2]=2;a[j]=1;a[f+65937|0]=0;m=73600;break};case 1:{l=b+448|0;if(!((c[l>>2]|0)==1&(c[l+4>>2]|0)==0)){c[l>>2]=4;c[l+4>>2]=0}c[f+65932>>2]=1;a[j]=0;m=36800;break};case 7:{l=b+448|0;c[l>>2]=319;c[l+4>>2]=0;c[f+65932>>2]=5;a[j]=1;a[f+65937|0]=0;a[f+65938|0]=1;a[f+65939|0]=0;a[f+65940|0]=0;m=184e3;break};default:{yDb(b,16,1942960,(g=i,i=i+8|0,c[g>>2]=k,g)|0);i=g;h=-1094995529;i=d;return h|0}}g=b+448|0;k=c[g+4>>2]|0;j=f+65944|0;c[j>>2]=c[g>>2];c[j+4>>2]=k;k=f+65932|0;j=cEb(m)|0;m=j;g=f+65928|0;c[g>>2]=m;if((j|0)==0){ZDb(c[(c[e>>2]|0)+65928>>2]|0);h=-12;i=d;return h|0}a:do{if((c[k>>2]|0)>0){e=0;j=m;while(1){c[j+(e*36800|0)+72>>2]=0;c[j+(e*36800|0)+4612>>2]=j+(e*36800|0)+4577;f=c[g>>2]|0;c[f+(e*36800|0)+4616>>2]=f+(e*36800|0)+4593;f=c[g>>2]|0;c[f+(e*36800|0)+6540>>2]=f+(e*36800|0)+4620;f=c[g>>2]|0;c[f+(e*36800|0)+6544>>2]=f+(e*36800|0)+5580;f=c[g>>2]|0;c[f+(e*36800|0)+7832>>2]=f+(e*36800|0)+6552;f=c[g>>2]|0;c[f+(e*36800|0)+7836>>2]=f+(e*36800|0)+7192;f=c[g>>2]|0;c[f+(e*36800|0)+7840>>2]=1;c[f+(e*36800|0)+12380>>2]=f+(e*36800|0)+12345;f=c[g>>2]|0;c[f+(e*36800|0)+12384>>2]=f+(e*36800|0)+12361;f=c[g>>2]|0;c[f+(e*36800|0)+14308>>2]=f+(e*36800|0)+12388;f=c[g>>2]|0;c[f+(e*36800|0)+14312>>2]=f+(e*36800|0)+13348;f=c[g>>2]|0;c[f+(e*36800|0)+15600>>2]=f+(e*36800|0)+14320;f=c[g>>2]|0;c[f+(e*36800|0)+15604>>2]=f+(e*36800|0)+14960;f=c[g>>2]|0;c[f+(e*36800|0)+17272>>2]=f+(e*36800|0)+15608;f=c[g>>2]|0;c[f+(e*36800|0)+17276>>2]=f+(e*36800|0)+16440;f=e+1|0;if((f|0)>=(c[k>>2]|0)){break a}e=f;j=c[g>>2]|0}}}while(0);c[b+420>>2]=8;h=0;i=d;return h|0}function eZ(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0.0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;k=i;i=i+64|0;l=k|0;m=c[e+60>>2]|0;n=m;o=c[f+64>>2]|0;c[f+76>>2]=2048;p=_$a(e,f,0)|0;if((p|0)<0){yDb(e,16,2194216,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=p;i=k;return r|0}p=m;f=c[j+24>>2]|0;s=c[j+28>>2]|0;j=s>>>0>268435455>>>0?-8:s<<3;s=j>>>0>2147483639>>>0|(f|0)==0;t=s?0:f;f=s?0:j;j=m;c[j>>2]=t;u=m+12|0;c[u>>2]=f;v=f+8|0;w=m+16|0;c[w>>2]=v;c[m+4>>2]=t+(f>>3);x=m+8|0;c[x>>2]=0;if(s){r=s?-1094995529:0;i=k;return r|0}s=a[t]|0;y=(v|0)>0|0;c[x>>2]=y;if(!(s<<24>>24>-1)){yDb(e,16,2115896,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=k;return r|0}a:do{if((f-y|0)>1){s=m+65932|0;z=m+65928|0;A=m+64|0;B=A;C=l;D=b[630220]|0;E=m+65864|0;F=m+20|0;G=m+65800|0;H=m+65600|0;I=m+49216|0;J=0;K=0;L=y;M=v;N=t;while(1){O=N+(L>>>3)|0;P=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>30;O=L+2|0;c[x>>2]=M>>>0>O>>>0?O:M;if((P|0)==3){break a}else if((P|0)==2){Q=9;break}if((J|0)>=(c[s>>2]|0)){Q=12;break}if((d[m+(J+65936)|0]|0)!=(P|0)){Q=12;break}O=c[z>>2]|0;c[O+(J*36800|0)>>2]=P;R=P+1|0;P=Phb(p,O+(J*36800|0)|0,R,e)|0;if((P|0)<0){r=P;Q=56;break}P=c[z>>2]|0;O=P+(J*36800|0)|0;TGb(C|0,0,64)|0;do{if((c[P+(J*36800|0)+20>>2]|0)==0){S=P+(J*36800|0)+12|0;T=c[S>>2]|0;if((T|0)>0){U=0;V=0;while(1){W=(c[P+(J*36800|0)+220+(V<<2)>>2]|0)+U+(c[P+(J*36800|0)+7988+(V<<2)>>2]|0)|0;X=V+1|0;if((X|0)<(T|0)){U=W;V=X}else{Y=W;break}}}else{Y=0}V=P+(J*36800|0)+16|0;U=c[V>>2]|0;if((U|0)>0){T=Y;W=0;while(1){c[l+(W<<2)>>2]=T&1020;X=W+1|0;if((X|0)<(U|0)){T=T+128|0;W=X}else{Z=0;break}}}else{Z=0}do{W=B+(Z<<13)|0;TGb(W|0,0,8192)|0;T=c[S>>2]|0;if((T|0)>0){U=0;X=D;while(1){_=X&65535;$=U+1|0;aa=b[1260440+($<<1)>>1]|0;ba=(aa&65535)-_|0;ca=c[P+(J*36800|0)+72+(Z*7768|0)+20+(U<<2)>>2]|0;do{if((ca|0)>0){da=+g[1260184+(c[P+(J*36800|0)+72+(Z*7768|0)+148+(U<<2)>>2]<<2)>>2]*+g[1260512+(ca<<2)>>2];if((ba|0)>0){ea=0}else{break}do{fa=ea+_|0;g[B+(Z<<13)+(fa<<2)>>2]=da*+(b[P+(J*36800|0)+72+(Z*7768|0)+404+(fa<<1)>>1]|0);ea=ea+1|0;}while((ea|0)<(ba|0))}}while(0);if(($|0)<(T|0)){U=$;X=aa}else{break}}}X=c[V>>2]|0;if((X|0)>0){U=W|0;T=0;while(1){kZ(O,Z,U,c[l+(T<<2)>>2]|0,T);ba=T+1|0;_=c[V>>2]|0;if((ba|0)<(_|0)){T=ba}else{ga=_;break}}}else{ga=X}Z=Z+1|0;}while((Z|0)<(R|0));if((c[O>>2]|0)==1&(ga|0)>0){ha=0}else{break}do{if((a[P+(J*36800|0)+40+ha|0]|0)!=0){V=ha<<7;S=0;do{T=S+V|0;U=B+8192+(T<<2)|0;da=+g[U>>2];W=B+(T<<2)|0;g[U>>2]=+g[W>>2];g[W>>2]=da;S=S+1|0;}while((S|0)<128)}if((a[P+(J*36800|0)+56+ha|0]|0)!=0){S=ha<<7;V=0;do{X=B+8192+(V+S<<2)|0;g[X>>2]=-0.0- +g[X>>2];V=V+1|0;}while((V|0)<128)}ha=ha+1|0;}while((ha|0)<(ga|0))}else{TGb(A|0,0,R<<13|0)|0}}while(0);P=c[z>>2]|0;O=P+(J*36800|0)|0;V=P+(J*36800|0)+8|0;S=P+(J*36800|0)+17272|0;X=P+(J*36800|0)+17276|0;W=0;while(1){U=c[V>>2]|0;if((U|0)>0){T=P+(J*36800|0)+72+(W*7768|0)+4544|0;_=P+(J*36800|0)+72+(W*7768|0)+4540|0;ba=P+(J*36800|0)+72+(W*7768|0)+6472|0;ca=P+(J*36800|0)+72+(W*7768|0)+6468|0;fa=0;while(1){ia=fa<<7;ja=n+16448+(W<<13)+(ia<<2)|0;lZ(F,G,n+64+(W<<13)+(ia<<2)|0,ja,(d[(c[_>>2]|0)+fa|0]|0)+(d[(c[T>>2]|0)+fa|0]<<1)|0,fa);Lhb(H,ja,P+(J*36800|0)+20416+(W<<13)+(ia<<2)|0,(c[ba>>2]|0)+(fa*60|0)|0,(c[ca>>2]|0)+(fa*60|0)|0,128,n+32832+(W<<13)+(ia<<2)|0);ia=fa+1|0;ja=c[V>>2]|0;if((ia|0)<(ja|0)){fa=ia}else{ka=ja;break}}}else{ka=U}TGb(P+(J*36800|0)+20416+(W<<13)+(ka<<7<<2)|0,0,16-ka<<9|0)|0;fa=c[V>>2]|0;TGb(n+32832+(W<<13)+(fa<<7<<2)|0,0,16-fa<<9|0)|0;if((c[c[S>>2]>>2]|0)==0){if((c[c[X>>2]>>2]|0)!=0){Q=43}}else{Q=43}do{if((Q|0)==43){Q=0;fa=c[V>>2]|0;if((fa|0)<=0){break}ca=P+(J*36800|0)+72+(W*7768|0)+7760|0;ba=P+(J*36800|0)+72+(W*7768|0)+7764|0;T=0;_=fa;while(1){if((c[(c[ca>>2]|0)+(T*40|0)+32>>2]|0)==0){if((c[(c[ba>>2]|0)+(T*40|0)+32>>2]|0)==0){la=_}else{Q=47}}else{Q=47}if((Q|0)==47){Q=0;iZ(O,F,W,T,n+32832+(W<<13)+(T<<7<<2)|0);la=c[V>>2]|0}fa=T+1|0;if((fa|0)<(la|0)){T=fa;_=la}else{break}}}}while(0);mZ(E,P+(J*36800|0)+17280+(W*1568|0)|0,n+32832+(W<<13)|0,n+49216+(W<<13)|0);U=W+1|0;if((U|0)<(R|0)){W=U}else{ma=0;break}}do{W=P+(J*36800|0)+72+(ma*7768|0)+4544|0;V=c[W>>2]|0;O=P+(J*36800|0)+72+(ma*7768|0)+4540|0;c[W>>2]=c[O>>2];c[O>>2]=V;V=P+(J*36800|0)+72+(ma*7768|0)+6472|0;O=c[V>>2]|0;W=P+(J*36800|0)+72+(ma*7768|0)+6468|0;c[V>>2]=c[W>>2];c[W>>2]=O;O=P+(J*36800|0)+72+(ma*7768|0)+7764|0;W=c[O>>2]|0;V=P+(J*36800|0)+72+(ma*7768|0)+7760|0;c[O>>2]=c[V>>2];c[V>>2]=W;ma=ma+1|0;}while((ma|0)<(R|0));P=c[X>>2]|0;c[X>>2]=c[S>>2];c[S>>2]=P;P=0;do{UGb(c[o+(P+K<<2)>>2]|0,I+(P<<13)|0,8192)|0;P=P+1|0;}while((P|0)<(R|0));P=c[x>>2]|0;if(((c[u>>2]|0)-P|0)<=1){break a}J=J+1|0;K=R+K|0;L=P;M=c[w>>2]|0;N=c[j>>2]|0}if((Q|0)==9){EDb(e,2056664,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1163346256;i=k;return r|0}else if((Q|0)==12){yDb(e,16,2010536,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=k;return r|0}else if((Q|0)==56){i=k;return r|0}}}while(0);c[h>>2]=1;r=c[e+432>>2]|0;i=k;return r|0}function fZ(a){a=a|0;ZDb(c[(c[a+60>>2]|0)+65928>>2]|0);return 0}function gZ(a,b){a=a|0;b=b|0;VXa(7);VXa(6);aLa(b,8,1,-1.0)|0;return}function hZ(){var a=0,b=0,c=0,d=0;a=0;while(1){g[4302968+(a<<2)>>2]=+U(+(a|0)*6.283185307179586*.00048828125);b=a+1|0;if((b|0)<2048){a=b}else{c=0;break}}while(1){g[5131328+(c<<2)>>2]=(1.0- +T(+(c|0)*6.283185307179586*.00390625))*.5;a=c+1|0;if((a|0)<256){c=a}else{d=0;break}}do{g[9183264+(d<<2)>>2]=+Wc(+((+(d|0)+-3.0)*.25));d=d+1|0;}while((d|0)<64);return}function iZ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+1024|0;j=h|0;k=h+512|0;TGb(j|0,0,512)|0;TGb(k|0,0,512)|0;l=c[a+72+(d*7768|0)+7764>>2]|0;m=l+(e*40|0)|0;n=c[a+72+(d*7768|0)+7760>>2]|0;d=n+(e*40|0)|0;do{if((c[d>>2]|0)==0){o=4}else{p=c[n+(e*40|0)+8>>2]|0;if((p|0)>=(c[n+(e*40|0)+12>>2]|0)){o=4;break}c[n+(e*40|0)+16>>2]=1;q=p+32|0;c[n+(e*40|0)+24>>2]=q;r=q}}while(0);do{if((o|0)==4){q=n+(e*40|0)+16|0;if((c[m>>2]|0)==0){c[q>>2]=0;c[n+(e*40|0)+24>>2]=0;r=0;break}else{c[q>>2]=1;q=c[l+(e*40|0)+8>>2]|0;c[n+(e*40|0)+24>>2]=q;r=q;break}}}while(0);do{if((c[l+(e*40|0)+4>>2]|0)==0){o=10}else{q=l+(e*40|0)+12|0;if((c[q>>2]|0)<(r|0)){o=10;break}c[n+(e*40|0)+20>>2]=1;c[n+(e*40|0)+28>>2]=c[q>>2]}}while(0);do{if((o|0)==10){q=n+(e*40|0)+20|0;if((c[n+(e*40|0)+4>>2]|0)==0){c[q>>2]=0;c[n+(e*40|0)+28>>2]=64;break}else{c[q>>2]=1;c[n+(e*40|0)+28>>2]=(c[n+(e*40|0)+12>>2]|0)+32;break}}}while(0);q=n+(e*40|0)+16|0;p=l+(e*40|0)+32|0;s=(c[l+(e*40|0)+28>>2]|0)<32;if(!((c[p>>2]|0)==0|s)){jZ(c[a+17276>>2]|0,m,l+(e*40|0)+16|0,128,j|0)}m=n+(e*40|0)+32|0;n=(r|0)>31;if(!((c[m>>2]|0)==0|n)){jZ(c[a+17272>>2]|0,d,q,0,k|0)}do{if((c[p>>2]|0)==0){o=22}else{if(!((c[m>>2]|0)==0|s|n)){d=b|0;a=j|0;cf[c[d>>2]&1023](a,a,5131840,128);a=k|0;cf[c[d>>2]&1023](a,a,5131328,128);t=0;break}if((c[l+(e*40|0)+20>>2]|0)!=0){o=22;break}a=j|0;cf[c[b>>2]&1023](a,a,5131840,128);o=22}}while(0);do{if((o|0)==22){if((c[m>>2]|0)==0){t=0;break}if((c[q>>2]|0)!=0){t=0;break}e=k|0;cf[c[b>>2]&1023](e,e,5131328,128);t=0}}while(0);do{b=f+(t<<2)|0;g[b>>2]=+g[b>>2]+(+g[j+(t<<2)>>2]+ +g[k+(t<<2)>>2]);t=t+1|0;}while((t|0)<128);i=h;return}function jZ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0;h=a+64+(c[b+36>>2]<<4)|0;i=c[b+32>>2]|0;if((i|0)>0){b=e^128;if((c[a+4>>2]|0)==0){a=0;j=h;while(1){k=+g[9183264+(c[j+4>>2]<<2)>>2]*(+((c[j+8>>2]|0)+1|0)/15.130000114440918);l=c[j>>2]|0;m=0;n=(c[j+12>>2]<<6)-(ba(l,b)|0)|0;while(1){o=n&2047;p=f+(m<<2)|0;g[p>>2]=+g[p>>2]+k*+g[4302968+(o<<2)>>2];p=m+1|0;if((p|0)<128){m=p;n=o+l|0}else{break}}l=a+1|0;if((l|0)<(i|0)){a=l;j=j+16|0}else{break}}}else{j=0;a=h;while(1){k=+g[9183264+(c[a+4>>2]<<2)>>2];h=c[a>>2]|0;l=0;n=(c[a+12>>2]<<6)-(ba(h,b)|0)|0;while(1){m=n&2047;o=f+(l<<2)|0;g[o>>2]=+g[o>>2]+k*+g[4302968+(m<<2)>>2];o=l+1|0;if((o|0)<128){l=o;n=m+h|0}else{break}}h=j+1|0;if((h|0)<(i|0)){j=h;a=a+16|0}else{break}}}}do{if((c[d>>2]|0)!=0){a=d+8|0;j=(c[a>>2]<<2)-e|0;if(!((j-1|0)>>>0<128>>>0)){break}TGb(f|0,0,j<<2|0)|0;if((c[d+4>>2]|0)!=0){if((c[a>>2]|0)==(c[d+12>>2]|0)){break}}a=f+(j<<2)|0;g[a>>2]=+g[1282832]*+g[a>>2];a=f+(j+1<<2)|0;g[a>>2]=+g[1282864]*+g[a>>2];a=f+(j+2<<2)|0;g[a>>2]=+g[1282896]*+g[a>>2];a=f+(j+3<<2)|0;g[a>>2]=+g[1282928]*+g[a>>2]}}while(0);if((c[d+4>>2]|0)==0){return}a=4-e+(c[d+12>>2]<<2)|0;d=a-1|0;if(!(d>>>0<128>>>0)){return}e=f+(a-4<<2)|0;g[e>>2]=+g[1282928]*+g[e>>2];e=f+(a-3<<2)|0;g[e>>2]=+g[1282896]*+g[e>>2];e=f+(a-2<<2)|0;g[e>>2]=+g[1282864]*+g[e>>2];e=f+(d<<2)|0;g[e>>2]=+g[1282832]*+g[e>>2];TGb(f+(a<<2)|0,0,128-a<<2|0)|0;return}function kZ(b,d,f,h,j){b=b|0;d=d|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0.0,C=0;k=i;i=i+512|0;l=k|0;if((c[b>>2]|0)==1){m=(a[b+40+j|0]|0)!=0|0}else{m=0}n=m^d;m=a[(c[429632+(j<<2)>>2]|0)+(b+72+(n*7768|0)+4500)|0]|0;if(m<<24>>24==15){i=k;return}else{o=0;p=h}while(1){g[l+(o<<2)>>2]=+g[630752+((p&1023)<<2)>>2];h=o+1|0;if((h|0)<128){o=h;p=p+1|0}else{break}}p=c[b+72+(n*7768|0)+6468>>2]|0;o=c[b+72+(n*7768|0)+6472>>2]|0;n=c[p+(j*60|0)>>2]|0;h=(n|0)>0;if(h){q=6-(c[p+(j*60|0)+4>>2]|0)+6|0}else{q=6}r=c[o+(j*60|0)>>2]|0;if((r|0)>0){s=0;t=0;while(1){u=q-(c[o+(j*60|0)+4+(t<<2)>>2]|0)|0;v=(s|0)>(u|0)?s:u;u=t+1|0;if((u|0)<(r|0)){s=v;t=u}else{w=v;break}}}else{w=0}if(h){h=w;t=0;while(1){s=6-(c[p+(j*60|0)+4+(t<<2)>>2]|0)|0;r=(h|0)>(s|0)?h:s;s=t+1|0;if((s|0)<(n|0)){h=r;t=s}else{x=r;break}}}else{x=w}y=+g[559504+((m&255)<<2)>>2]/+(1<<x|0);x=(c[429560+(j<<2)>>2]|0)+((j|0)==0?2:0)|0;m=c[429560+(j+1<<2)>>2]|0;if((x|0)<(m|0)){z=x}else{i=k;return}while(1){x=c[b+72+(d*7768|0)+20+(z<<2)>>2]|0;do{if((x|0)<1){A=z+1|0}else{B=y*(+g[1260184+(c[b+72+(d*7768|0)+148+(z<<2)>>2]<<2)>>2]*+g[1260512+(x<<2)>>2]/+(1<<x|0));j=e[1260440+(z<<1)>>1]|0;w=z+1|0;t=(e[1260440+(w<<1)>>1]|0)-j|0;if((t|0)>0){C=0}else{A=w;break}while(1){h=f+(C+j<<2)|0;g[h>>2]=+g[h>>2]+B*+g[l+(C<<2)>>2];h=C+1|0;if((h|0)<(t|0)){C=h}else{A=w;break}}}}while(0);if((A|0)<(m|0)){z=A}else{break}}i=k;return}function lZ(a,b,d,e,f,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0.0,k=0;if((h&1|0)!=0){h=0;do{i=d+(127-h<<2)|0;j=+g[i>>2];k=d+(h<<2)|0;g[i>>2]=+g[k>>2];g[k>>2]=j;h=h+1|0;}while((h|0)<64)}Xe[c[b+40>>2]&4095](b,e,d);if((f&2|0)==0){cf[c[a>>2]&1023](e,e,5461800,128)}else{TGb(e|0,0,128)|0;d=e+128|0;cf[c[a>>2]&1023](d,d,5433768,64)}d=c[a+24>>2]|0;if((f&1|0)==0){f=e+512|0;cf[d&1023](f,f,5461800,128);return}else{f=e+640|0;cf[d&1023](f,f,5433768,64);TGb(e+896|0,0,128)|0;return}}function mZ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+128|0;h=f|0;j=f+64|0;TGb(e|0,0,8192)|0;k=a+44|0;l=j|0;m=h|0;n=b+1536|0;o=0;do{g[m>>2]=+g[d+(o<<2)>>2];g[h+4>>2]=+g[d+(o+128<<2)>>2];g[h+8>>2]=+g[d+(o+256<<2)>>2];g[h+12>>2]=+g[d+(o+384<<2)>>2];g[h+16>>2]=+g[d+(o+512<<2)>>2];g[h+20>>2]=+g[d+(o+640<<2)>>2];g[h+24>>2]=+g[d+(o+768<<2)>>2];g[h+28>>2]=+g[d+(o+896<<2)>>2];g[h+32>>2]=+g[d+(o+1024<<2)>>2];g[h+36>>2]=+g[d+(o+1152<<2)>>2];g[h+40>>2]=+g[d+(o+1280<<2)>>2];g[h+44>>2]=+g[d+(o+1408<<2)>>2];g[h+48>>2]=+g[d+(o+1536<<2)>>2];g[h+52>>2]=+g[d+(o+1664<<2)>>2];g[h+56>>2]=+g[d+(o+1792<<2)>>2];g[h+60>>2]=+g[d+(o+1920<<2)>>2];Xe[c[k>>2]&4095](a,l,m);g[b+(c[n>>2]<<5)>>2]=+g[j+32>>2];g[b+768+(c[n>>2]<<5)>>2]=+g[j+28>>2];p=c[n>>2]|0;g[b+(p<<5)+4>>2]=+g[j+36>>2];g[b+768+(p<<5)+4>>2]=+g[j+24>>2];g[b+(p<<5)+8>>2]=+g[j+40>>2];g[b+768+(p<<5)+8>>2]=+g[j+20>>2];g[b+(p<<5)+12>>2]=+g[j+44>>2];g[b+768+(p<<5)+12>>2]=+g[j+16>>2];g[b+(p<<5)+16>>2]=+g[j+48>>2];g[b+768+(p<<5)+16>>2]=+g[j+12>>2];g[b+(p<<5)+20>>2]=+g[j+52>>2];g[b+768+(p<<5)+20>>2]=+g[j+8>>2];g[b+(p<<5)+24>>2]=+g[j+56>>2];g[b+768+(p<<5)+24>>2]=+g[j+4>>2];g[b+(p<<5)+28>>2]=+g[j+60>>2];g[b+768+(p<<5)+28>>2]=+g[l>>2];q=o<<4;r=0;s=p;while(1){t=c[678128+(s+2<<2)>>2]|0;u=0;do{v=u+q|0;w=e+(v<<2)|0;g[w>>2]=+g[w>>2]+(+g[b+(s<<5)+(u<<2)>>2]*+g[904040+(r<<6)+(u<<2)>>2]+ +g[b+768+(t<<5)+(u<<2)>>2]*+g[903272+(r<<6)+(u<<2)>>2]);w=7-u|0;x=u+8|0;y=e+(v+8<<2)|0;g[y>>2]=+g[y>>2]+(+g[b+(s<<5)+(w<<2)>>2]*+g[904040+(r<<6)+(x<<2)>>2]+ +g[b+768+(t<<5)+(w<<2)>>2]*+g[903272+(r<<6)+(x<<2)>>2]);u=u+1|0;}while((u|0)<8);u=r+1|0;if((u|0)<12){r=u;s=c[678128+(t+2<<2)>>2]|0}else{break}}c[n>>2]=c[678128+(p<<2)>>2];o=o+1|0;}while((o|0)<128);i=f;return}function nZ(a){a=a|0;var b=0;if((c[a+120>>2]&3|0)!=0){b=-22;return b|0}c[a+140>>2]=4;b=0;return b|0}function oZ(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;j=c[g+24>>2]|0;k=g+28|0;g=c[k>>2]|0;l=b+124|0;m=b+120|0;n=(ba(c[m>>2]|0,c[l>>2]|0)|0)+48|0;if((g|0)!=(n|0)){yDb(b,16,2194160,(o=i,i=i+16|0,c[o>>2]=g,c[o+8>>2]=n,o)|0);i=o;p=-1094995529;i=h;return p|0}o=_$a(b,e,0)|0;if((o|0)<0){p=o;i=h;return p|0}if((c[l>>2]|0)>0){o=e+32|0;b=e+36|0;n=e+40|0;g=c[e+4>>2]|0;q=c[e+8>>2]|0;r=0;s=c[e>>2]|0;e=j+48|0;while(1){t=a[e]|0;a[g]=t&-16;a[s]=t<<4;t=a[e+1|0]|0;a[q]=t&-16;a[s+1|0]=(a[j+(t&15|16)|0]|0)+(a[s]|0);t=e+2|0;u=c[m>>2]|0;v=u>>1;if((v|0)>1){w=1;x=e;y=t;z=s;A=q;B=g;while(1){C=z+2|0;D=A+1|0;E=B+1|0;F=d[y]|0;a[E]=(a[j+(F>>>4|16)|0]|0)+(a[B]|0);a[C]=(a[j+(F&15|16)|0]|0)+(a[z+1|0]|0);F=d[x+3|0]|0;a[D]=(a[j+(F>>>4|16)|0]|0)+(a[A]|0);a[z+3|0]=(a[j+(F&15|16)|0]|0)+(a[C]|0);F=w+1|0;G=y+2|0;H=c[m>>2]|0;I=H>>1;if((F|0)<(I|0)){w=F;x=y;y=G;z=C;A=D;B=E}else{J=E;K=D;L=C;M=G;N=H;O=I;break}}}else{J=g;K=q;L=s;M=t;N=u;O=v}B=1-O|0;A=r+1|0;if((A|0)<(c[l>>2]|0)){g=J+(B+(c[b>>2]|0))|0;q=K+(B+(c[n>>2]|0))|0;r=A;s=L+(2-N+(c[o>>2]|0))|0;e=M}else{break}}}c[f>>2]=1;p=c[k>>2]|0;i=h;return p|0}function pZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=WDb(88)|0;g=f;c[e>>2]=g;do{if((f|0)==0){h=g}else{if((BUa(g,a,b)|0)==0){h=g;break}$Db(e);h=c[e>>2]|0}}while(0);i=d;return h|0}function qZ(a,b){a=a|0;b=b|0;ne[c[a+84>>2]&1023](a,b);return}function rZ(a){a=a|0;if((a|0)==0){return}DUa(a);ZDb(a);return}function sZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=WDb(112)|0;g=f;c[e>>2]=g;do{if((f|0)==0){h=g}else{if((U0(g,a,b)|0)==0){h=g;break}$Db(e);h=c[e>>2]|0}}while(0);i=d;return h|0}function tZ(a,b){a=a|0;b=b|0;ne[c[a+104>>2]&1023](a,b);return}function uZ(a){a=a|0;if((a|0)==0){return}_0(a);ZDb(a);return}function vZ(a){a=a|0;var b=0;b=a+8|0;c[b>>2]=0;c[b+4>>2]=-2147483648;b=a+16|0;c[b>>2]=0;c[b+4>>2]=-2147483648;b=a+64|0;c[b>>2]=-1;c[b+4>>2]=-1;b=a+72|0;c[b>>2]=0;c[b+4>>2]=0;c[a>>2]=0;TGb(a+32|0,0,24)|0;return}function wZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;if(b>>>0>4294967279>>>0){f=-22;i=d;return f|0}g=$Ab(e,b+16|0)|0;if((g|0)<0){f=g;i=d;return f|0}g=c[e>>2]|0;e=g+4|0;TGb((c[e>>2]|0)+b|0,0,16)|0;h=a+8|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=a+16|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=a+64|0;c[h>>2]=-1;c[h+4>>2]=-1;h=a+72|0;c[h>>2]=0;c[h+4>>2]=0;TGb(a+32|0,0,24)|0;c[a>>2]=g;c[a+24>>2]=c[e>>2];c[a+28>>2]=b;c[a+52>>2]=146;f=0;i=d;return f|0}function xZ(a){a=a|0;yDb(0,0,2337456,(a=i,i=i+24|0,c[a>>2]=1971640,c[a+8>>2]=2194104,c[a+16>>2]=45,a)|0);i=a;Cd()}function yZ(a,b){a=a|0;b=b|0;var d=0;d=a+28|0;if((c[d>>2]|0)<=(b|0)){return}c[d>>2]=b;TGb((c[a+24>>2]|0)+b|0,0,16)|0;return}function zZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=a+28|0;g=c[f>>2]|0;if(!(g>>>0<2147483632>>>0)){yDb(0,0,2337456,(h=i,i=i+24|0,c[h>>2]=2335288,c[h+8>>2]=2194104,c[h+16>>2]=114,h)|0);i=h;Cd();return 0}if((g|0)==0){c[e>>2]=0;if(b>>>0>4294967279>>>0){j=-22;i=d;return j|0}h=$Ab(e,b+16|0)|0;if((h|0)<0){j=h;i=d;return j|0}h=c[e>>2]|0;e=h+4|0;TGb((c[e>>2]|0)+b|0,0,16)|0;k=a+8|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=a+16|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=a+64|0;c[k>>2]=-1;c[k+4>>2]=-1;k=a+72|0;c[k>>2]=0;c[k+4>>2]=0;TGb(a+32|0,0,24)|0;c[a>>2]=h;c[a+24>>2]=c[e>>2];c[f>>2]=b;c[a+52>>2]=146;j=0;i=d;return j|0}if((2147483631-g|0)>>>0<b>>>0){j=-1;i=d;return j|0}e=b+16+g|0;g=a|0;do{if((c[g>>2]|0)==0){h=UAb(e)|0;c[g>>2]=h;if((h|0)==0){j=-12;i=d;return j|0}else{k=a+24|0;UGb(c[h+4>>2]|0,c[k>>2]|0,(c[f>>2]|0)+((b|0)<0?b:0)|0)|0;c[a+52>>2]=146;l=k;break}}else{k=$Ab(g,e)|0;if((k|0)<0){j=k;i=d;return j|0}else{l=a+24|0;break}}}while(0);a=c[(c[g>>2]|0)+4>>2]|0;c[l>>2]=a;l=(c[f>>2]|0)+b|0;c[f>>2]=l;TGb(a+l|0,0,16)|0;j=0;i=d;return j|0}function AZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b+44|0;e=c[d>>2]|0;a:do{if((e|0)==0){f=0}else{g=WDb(e*12|0)|0;b:do{if((g|0)!=0){h=b+40|0;i=c[d>>2]|0;j=i*12|0;UGb(g|0,c[h>>2]|0,j)|0;k=a+40|0;c[k>>2]=g;if((b|0)!=(a|0)){TGb(g|0,0,j|0)|0}if((i|0)<=0){f=i;break a}i=0;j=c[h>>2]|0;while(1){l=c[j+(i*12|0)+4>>2]|0;if(l>>>0>4294967279>>>0){break b}m=WDb(l+16|0)|0;if((m|0)==0){break b}l=c[h>>2]|0;n=l+(i*12|0)+4|0;UGb(m|0,c[l+(i*12|0)>>2]|0,c[n>>2]|0)|0;TGb(m+(c[n>>2]|0)|0,0,16)|0;c[(c[k>>2]|0)+(i*12|0)>>2]=m;m=c[h>>2]|0;n=c[k>>2]|0;c[n+(i*12|0)+4>>2]=c[m+(i*12|0)+4>>2];c[n+(i*12|0)+8>>2]=c[m+(i*12|0)+8>>2];n=i+1|0;l=c[d>>2]|0;if((n|0)<(l|0)){i=n;j=m}else{f=l;break a}}}}while(0);if((a|0)==0){o=-12;return o|0}g=a|0;do{if((c[g>>2]|0)==0){j=a+52|0;i=c[j>>2]|0;if((i|0)==0){p=j;break}me[i&511](a);p=j}else{XAb(g);p=a+52|0}}while(0);c[p>>2]=0;c[a+24>>2]=0;c[a+28>>2]=0;g=a+44|0;j=a+40|0;if((c[g>>2]|0)>0){i=0;do{ZDb(c[(c[j>>2]|0)+(i*12|0)>>2]|0);i=i+1|0;}while((i|0)<(c[g>>2]|0))}$Db(j);c[g>>2]=0;o=-12;return o|0}}while(0);c[a+44>>2]=f;o=0;return o|0}function BZ(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){return}b=a|0;do{if((c[b>>2]|0)==0){d=a+52|0;e=c[d>>2]|0;if((e|0)==0){f=d;break}me[e&511](a);f=d}else{XAb(b);f=a+52|0}}while(0);c[f>>2]=0;c[a+24>>2]=0;c[a+28>>2]=0;f=a+44|0;b=a+40|0;if((c[f>>2]|0)>0){a=0;do{ZDb(c[(c[b>>2]|0)+(a*12|0)>>2]|0);a=a+1|0;}while((a|0)<(c[f>>2]|0))}$Db(b);c[f>>2]=0;return}function CZ(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+80|0;d=b|0;do{if((c[a>>2]|0)==0){if((c[a+24>>2]|0)==0){e=0;break}if((c[a+52>>2]|0)!=0){e=0;break}UGb(d|0,a|0,80)|0;e=DZ(a,d,1)|0}else{e=0}}while(0);i=b;return e|0}function DZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=a+24|0;c[e>>2]=0;f=a+40|0;c[f>>2]=0;g=a|0;a:do{if((c[g>>2]|0)==0){h=a+28|0;i=c[h>>2]|0;do{if(i>>>0>4294967279>>>0){j=0}else{$Ab(g,i+16|0)|0;k=c[g>>2]|0;if((k|0)==0){j=0;break}l=c[k+4>>2]|0;if((l|0)==0){j=k;break}UGb(l|0,c[b+24>>2]|0,c[h>>2]|0)|0;TGb(l+(c[h>>2]|0)|0,0,16)|0;m=l;break a}}while(0);if((a|0)==0){n=-12;return n|0}do{if((j|0)==0){i=a+52|0;l=c[i>>2]|0;if((l|0)==0){o=i;break}me[l&511](a);o=i}else{XAb(g);o=a+52|0}}while(0);c[o>>2]=0;c[e>>2]=0;c[h>>2]=0;i=a+44|0;if((c[i>>2]|0)>0){l=0;do{ZDb(c[(c[f>>2]|0)+(l*12|0)>>2]|0);l=l+1|0;}while((l|0)<(c[i>>2]|0))}$Db(f);c[i>>2]=0;n=-12;return n|0}else{l=WAb(c[b>>2]|0)|0;if((l|0)==0){n=-12;return n|0}else{c[g>>2]=l;m=c[l+4>>2]|0;break}}}while(0);c[e>>2]=m;c[a+52>>2]=146;m=c[a+44>>2]|0;e=(d|0)==0;if(!((m|0)==0|e)){c[f>>2]=c[b+40>>2]}if(!((m|0)!=0&e)){n=0;return n|0}n=AZ(a,b)|0;return n|0}function EZ(a,b){a=a|0;b=b|0;UGb(a|0,b|0,80)|0;return DZ(a,b,0)|0}function FZ(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+44|0;d=a+40|0;if((c[b>>2]|0)>0){e=0}else{f=d;$Db(f);c[b>>2]=0;return}do{ZDb(c[(c[d>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while((e|0)<(c[b>>2]|0));f=d;$Db(f);c[b>>2]=0;return}function GZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+44|0;f=c[e>>2]|0;if((f+1|0)>>>0>178956970>>>0|d>>>0>2147483631>>>0){g=0;return g|0}h=a+40|0;a=XDb(c[h>>2]|0,(f*12|0)+12|0)|0;c[h>>2]=a;if((a|0)==0){g=0;return g|0}a=cEb(d+16|0)|0;c[(c[h>>2]|0)+(f*12|0)>>2]=a;a=c[h>>2]|0;h=c[a+(f*12|0)>>2]|0;if((h|0)==0){g=0;return g|0}c[a+(f*12|0)+4>>2]=d;c[a+(f*12|0)+8>>2]=b;c[e>>2]=(c[e>>2]|0)+1;g=h;return g|0}function HZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[a+44>>2]|0;f=a+40|0;a=0;while(1){if((a|0)>=(e|0)){g=0;h=7;break}i=c[f>>2]|0;if((c[i+(a*12|0)+8>>2]|0)==(b|0)){break}else{a=a+1|0}}if((h|0)==7){return g|0}if((d|0)!=0){c[d>>2]=c[i+(a*12|0)+4>>2]}g=c[i+(a*12|0)>>2]|0;return g|0}function IZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;d=i;i=i+80|0;e=d|0;f=b+44|0;if((c[f>>2]|0)==0){g=0;i=d;return g|0}h=b+28|0;j=c[h>>2]|0;k=YGb(j,(j|0)<0|0?-1:0,24,0)|0;j=F;UGb(e|0,b|0,80)|0;l=e+44|0;m=c[l>>2]|0;if((m|0)>0){n=c[e+40>>2]|0;o=0;p=j;q=k;while(1){r=c[n+(o*12|0)+4>>2]|0;s=YGb(q,p,5,0)|0;t=YGb(s,F,r,(r|0)<0|0?-1:0)|0;r=F;s=o+1|0;if((s|0)<(m|0)){o=s;p=r;q=t}else{u=r;v=t;break}}}else{u=j;v=k}k=0;if(u>>>0>k>>>0|u>>>0==k>>>0&v>>>0>2147483647>>>0){g=-22;i=d;return g|0}k=UAb(v)|0;if((k|0)==0){g=-12;i=d;return g|0}c[b>>2]=k;j=c[k+4>>2]|0;k=b+24|0;c[k>>2]=j;c[b+52>>2]=146;q=YGb(v,u,-16,0)|0;c[h>>2]=q;q=e+24|0;u=e+28|0;v=c[u>>2]|0;UGb(j|0,c[q>>2]|0,v)|0;p=j+v|0;v=c[l>>2]|0;if((v|0)>0){j=e+40|0;o=p;m=v;while(1){v=m-1|0;n=c[j>>2]|0;t=c[n+(v*12|0)+4>>2]|0;UGb(o|0,c[n+(v*12|0)>>2]|0,t)|0;n=o+t|0;x=fe(c[(c[j>>2]|0)+(v*12|0)+4>>2]|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+(t+5)|0;a[o+(t+4)|0]=((v|0)==((c[l>>2]|0)-1|0))<<7|c[(c[j>>2]|0)+(v*12|0)+8>>2];if((v|0)>0){o=n;m=v}else{w=n;break}}}else{w=p}p=w;m=p|0;x=278744460;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=p+4|0;x=-18274930;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=w+8|0;if((m-(c[k>>2]|0)|0)!=(c[h>>2]|0)){yDb(0,0,2337456,(h=i,i=i+24|0,c[h>>2]=2115864,c[h+8>>2]=2194104,c[h+16>>2]=371,h)|0);i=h;Cd();return 0}TGb(m|0,0,16)|0;m=e|0;do{if((c[m>>2]|0)==0){h=e+52|0;k=c[h>>2]|0;if((k|0)==0){y=h;break}me[k&511](e);y=h}else{XAb(m);y=e+52|0}}while(0);c[y>>2]=0;c[q>>2]=0;c[u>>2]=0;u=e+40|0;if((c[l>>2]|0)>0){e=0;do{ZDb(c[(c[u>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while((e|0)<(c[l>>2]|0))}$Db(u);c[l>>2]=0;c[f>>2]=0;c[b+40>>2]=0;g=1;i=d;return g|0}function JZ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=b+44|0;if((c[f>>2]|0)!=0){g=0;i=e;return g|0}h=b+28|0;j=c[h>>2]|0;if((j|0)<=12){g=0;i=e;return g|0}k=b+24|0;l=c[k>>2]|0;m=l+(j-8)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;if(!((fe(m|0)|0)==(-1910117890|0)&(o|0)==(-1941070576|0))){g=0;i=e;return g|0}o=l+(j-13)|0;j=o;m=fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;if((m|0)<0){g=0;i=e;return g|0}j=l;l=1;n=o;o=m;while(1){if((n-j|0)>>>0<o>>>0){g=0;p=18;break}if((a[n+4|0]|0)<0){p=9;break}m=n+(-5-o)|0;q=m;r=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;if((r|0)<0){g=0;p=18;break}else{l=l+1|0;n=m;o=r}}if((p|0)==9){o=WDb(l*12|0)|0;l=b+40|0;c[l>>2]=o;if((o|0)==0){g=-12;i=e;return g|0}o=c[k>>2]|0;b=o+((c[h>>2]|0)-13)|0;n=b;j=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;if((j|0)>-1){s=0;t=b;u=j;v=o}else{yDb(0,0,2337456,(w=i,i=i+24|0,c[w>>2]=2056616,c[w+8>>2]=2194104,c[w+16>>2]=404,w)|0);i=w;Cd();return 0}while(1){if((t-v|0)>>>0<u>>>0){p=12;break}o=cEb(u+16|0)|0;c[(c[l>>2]|0)+(s*12|0)>>2]=o;o=c[l>>2]|0;c[o+(s*12|0)+4>>2]=u;j=t+4|0;c[o+(s*12|0)+8>>2]=a[j]&127;b=c[o+(s*12|0)>>2]|0;if((b|0)==0){g=-12;p=18;break}UGb(b|0,t+(-u|0)|0,u)|0;x=-5-u+(c[h>>2]|0)|0;c[h>>2]=x;if((a[j]|0)<0){p=17;break}j=t+(-5-u)|0;b=j;o=fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;if(!((o|0)>-1)){p=12;break}s=s+1|0;t=j;u=o;v=c[k>>2]|0}if((p|0)==12){yDb(0,0,2337456,(w=i,i=i+24|0,c[w>>2]=2056616,c[w+8>>2]=2194104,c[w+16>>2]=404,w)|0);i=w;Cd();return 0}else if((p|0)==17){c[h>>2]=x-8;c[f>>2]=s+1;g=1;i=e;return g|0}else if((p|0)==18){i=e;return g|0}}else if((p|0)==18){i=e;return g|0}return 0}function KZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;c[b>>2]=0;if((a|0)==0){f=0;i=d;return f|0}g=BBb(a,9203208,0,2)|0;if((g|0)==0){f=0;i=d;return f|0}else{h=g;j=0}while(1){g=h|0;k=SGb(c[g>>2]|0)|0;l=h+4|0;m=SGb(c[l>>2]|0)|0;n=k+2+m+(c[b>>2]|0)|0;o=XDb(j,n)|0;if((o|0)==0){break}c[e>>2]=o;if((n|0)<0){break}p=k+1|0;UGb(o+(c[b>>2]|0)|0,c[g>>2]|0,p)|0;UGb((c[e>>2]|0)+(p+(c[b>>2]|0))|0,c[l>>2]|0,m+1|0)|0;c[b>>2]=n;n=BBb(a,9203208,h,2)|0;m=c[e>>2]|0;if((n|0)==0){f=m;q=7;break}else{h=n;j=m}}if((q|0)==7){i=d;return f|0}$Db(e);c[b>>2]=0;f=0;i=d;return f|0}function LZ(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+c|0;if(!((b|0)!=0&(d|0)!=0&(c|0)!=0)){f=0;return f|0}if((a[b+(c-1)|0]|0)!=0){f=-1094995529;return f|0}if((c|0)>0){g=b}else{f=0;return f|0}while(1){b=SGb(g|0)|0;c=g+(b+1)|0;if(!(c>>>0<e>>>0)){f=-1094995529;h=7;break}i=CBb(d,g,c,0)|0;if((i|0)<0){f=i;h=7;break}j=g+(b+2+(SGb(c|0)|0))|0;if(j>>>0<e>>>0){g=j}else{f=i;h=7;break}}if((h|0)==7){return f|0}return 0}function MZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[a+44>>2]|0;f=a+40|0;a=0;while(1){if((a|0)>=(e|0)){g=-2;h=6;break}i=c[f>>2]|0;if((c[i+(a*12|0)+8>>2]|0)==(b|0)){break}else{a=a+1|0}}if((h|0)==6){return g|0}h=i+(a*12|0)+4|0;if((c[h>>2]|0)<(d|0)){g=-12;return g|0}c[h>>2]=d;g=0;return g|0}function NZ(a){a=a|0;var b=0,d=0,e=0;b=a+44|0;d=a+40|0;if((c[b>>2]|0)>0){e=0;do{ZDb(c[(c[d>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while((e|0)<(c[b>>2]|0))}$Db(d);c[b>>2]=0;b=a|0;XAb(b);d=a+8|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+16|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+64|0;c[d>>2]=-1;c[d+4>>2]=-1;d=a+72|0;c[d>>2]=0;c[d+4>>2]=0;c[b>>2]=0;TGb(a+24|0,0,32)|0;return}function OZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return kDb(a|0,a+32|0,b,c,d,e,1)|0}function PZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mDb(e,f,a|0,a+32|0,b,c,d,1)|0}function QZ(a,b,c){a=a|0;b=b|0;c=c|0;return lDb(a,b,c,1)|0}function RZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gDb(a|0,a+32|0,c,d,b,1)|0;if((e|0)>=0){f=0;return f|0}TGb(a|0,0,64)|0;f=e;return f|0}function SZ(a){a=a|0;ZDb(c[a>>2]|0);return}function TZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;jDb(a|0,a+32|0,b|0,b+32|0,c,d,e);return}function UZ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[b+60>>2]|0;g=b+100|0;do{if((c[g>>2]|0)<31){c[f+3008>>2]=1}else{h=(PGb((c[b+96>>2]|0)+28|0,2115768,3)|0)!=0;c[f+3008>>2]=h&1;do{if(!h){if((c[b+800>>2]|0)==0){break}yDb(b,16,2056464,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=e;return k|0}}while(0);if(h){break}j=hDb(c[b+120>>2]|0,c[b+124>>2]|0,0,b)|0;if((j|0)<0){k=j;i=e;return k|0}c[b+140>>2]=17;j=c[g>>2]|0;if((j|0)<=8){k=0;i=e;return k|0}l=c[b+96>>2]|0;m=d[l+4|0]|0;n=m+28|0;if((n|0)>=(j|0)){k=0;i=e;return k|0}j=(PGb(l+(m+4)|0,2010440,4)|0)==0;c[f+3012>>2]=j&1;if(!j){k=0;i=e;return k|0}c[f+3016>>2]=(a[l+n|0]|0)==1;k=0;i=e;return k|0}}while(0);k=uLa(b)|0;i=e;return k|0}function VZ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=c[a+60>>2]|0;h=c[e+24>>2]|0;j=c[e+28>>2]|0;if((c[g+3008>>2]|0)!=0){k=BLa(a,b,d,e)|0;i=f;return k|0}e=a+120|0;l=c[e>>2]<<1;m=(j|0)/(l|0)|0;n=a+124|0;if((j|0)<(ba(c[n>>2]|0,l)|0)){yDb(a,16,2194e3,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;k=-1094995529;i=f;return k|0}l=_$a(a,b,0)|0;if((l|0)<0){k=l;i=f;return k|0}c[b+88>>2]=1;c[b+84>>2]=1;l=c[n>>2]|0;a=c[e>>2]|0;o=ba(m-l|0,a)|0;do{if((c[g+3012>>2]|0)==0){if((l|0)<=0){break}p=b;q=b+32|0;r=0;s=h+(o<<1)|0;t=a;while(1){UGb((c[p>>2]|0)+(ba(c[q>>2]|0,r)|0)|0,s|0,t<<1)|0;u=c[e>>2]|0;v=r+1|0;if((v|0)<(c[n>>2]|0)){r=v;s=s+(u<<1)|0;t=u}else{break}}}else{if((l-1|0)<=0){break}t=b;s=g+3016|0;r=b+32|0;q=0;p=h+o|0;u=a;while(1){UGb((c[t>>2]|0)+(ba((c[s>>2]|0)+q|0,c[r>>2]|0)|0)|0,p|0,u<<1)|0;v=(c[t>>2]|0)+(ba((c[s>>2]|0)==0|q,c[r>>2]|0)|0)|0;w=c[e>>2]|0;UGb(v|0,p+((ba(w,m)|0)+4)|0,w<<1)|0;w=c[e>>2]|0;v=q+2|0;if((v|0)<((c[n>>2]|0)-1|0)){q=v;p=p+(w<<1)|0;u=w}else{break}}}}while(0);c[d>>2]=1;k=j;i=f;return k|0}function WZ(a){a=a|0;if((c[(c[a+60>>2]|0)+3008>>2]|0)==0){return 0}CLa(a)|0;return 0}function XZ(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=ICb()|0;c[b>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+140>>2]=11;V$a(a,318,198)|0;e=0;return e|0}function YZ(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;h=c[g+24>>2]|0;i=c[g+28>>2]|0;g=e;e=c[c[b+60>>2]>>2]|0;j=$$a(b,e)|0;if((j|0)<0){k=j;return k|0}j=e+88|0;c[j>>2]=2;b=e+84|0;c[b>>2]=0;l=c[e>>2]|0;m=c[e+32>>2]|0;n=h+i|0;if((i|0)<4){k=-1094995529;return k|0}o=d[h]|0;p=a[h+1|0]|0;q=h+4|0;if(p<<24>>24==3){r=c[e+4>>2]|0;s=q;t=(d[s]|d[s+1|0]<<8)<<16>>16;s=t&65535;u=h+6|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;u=v&65535;w=u+s|0;if((t&65535)>>>0>255>>>0|(w|0)>256){k=-1094995529;return k|0}if((i-4|0)<((u*3|0)+8|0)){k=-1094995529;return k|0}u=h+8|0;t=d[u]|0;if(v<<16>>16==0){x=u;y=t}else{v=s+1|0;z=(((w|0)>(v|0)?w:v)*3|0)+8+(s*-3|0)|0;v=s;s=u;u=t;do{t=(d[s+1|0]|0)<<10|u<<18|(d[s+2|0]|0)<<2;c[r+(v<<2)>>2]=t|t>>>6&197379|-16777216;v=v+1|0;s=s+3|0;u=d[s]|0}while((v|0)<(w|0));x=h+z|0;y=u}A=x+4|0;B=a[x+1|0]|0;C=y}else{A=q;B=p;C=o}if(!(B<<24>>24==1)){k=-1094995529;return k|0}if((C|0)==1){D=3;E=3}else if((C|0)==0){c[j>>2]=1;c[b>>2]=1;D=3;E=3}else if((C|0)==3){D=3;E=2}else if((C|0)==2){D=2;E=2}else{k=-1094995529;return k|0}b=ba(E<<8,D)|0;if((n-A|0)<(b|0)){k=-1094995529;return k|0}j=A+b|0;B=(C|0)!=0;do{if(B){o=ba(((318/(E>>>0)|0)+7|0)>>>3,198/(D>>>0)|0)|0;if((n-j|0)<(o|0)){k=-1094995529;return k|0}else{p=o<<3;q=p>>>0>2147483639>>>0|(j|0)==0;F=A+(o+b)|0;G=q?0:j;H=q?8:p+8|0;break}}else{F=j;G=0;H=0}}while(0);j=(C|0)==0;C=ba(D,E)|0;b=(D|0)==3;p=E<<1;q=0;o=0;y=F;a:while(1){F=ba(o,m)|0;x=ba(o+1|0,m)|0;u=ba(o+2|0,m)|0;if(j){z=0;h=y;while(1){if((n-h|0)<1){k=-1094995529;I=39;break a}w=h+1|0;v=ba(C,d[h]|0)|0;s=z+F|0;r=v+E|0;t=z+x|0;J=v+p|0;K=z+u|0;if(b){L=0;do{a[l+(s+L)|0]=a[A+(L+v)|0]|0;a[l+(t+L)|0]=a[A+(r+L)|0]|0;a[l+(K+L)|0]=a[A+(J+L)|0]|0;L=L+1|0;}while((L|0)<(E|0))}else{L=0;do{a[l+(s+L)|0]=a[A+(L+v)|0]|0;a[l+(t+L)|0]=a[A+(r+L)|0]|0;L=L+1|0;}while((L|0)<(E|0))}L=z+E|0;if((L|0)<318){z=L;h=w}else{M=q;N=w;break}}}else{h=q;z=0;L=y;while(1){r=((h|0)<(H|0))+h|0;if(((d[G+(h>>>3)|0]|0)&128>>>((h&7)>>>0)|0)==0){O=L}else{if((n-L|0)<1){k=-1094995529;I=39;break a}t=L+1|0;v=ba(C,d[L]|0)|0;s=z+F|0;J=v+E|0;K=z+x|0;P=v+p|0;Q=z+u|0;if(b){R=0;while(1){a[l+(s+R)|0]=a[A+(R+v)|0]|0;a[l+(K+R)|0]=a[A+(J+R)|0]|0;a[l+(Q+R)|0]=a[A+(P+R)|0]|0;S=R+1|0;if((S|0)<(E|0)){R=S}else{O=t;break}}}else{R=0;while(1){a[l+(s+R)|0]=a[A+(R+v)|0]|0;a[l+(K+R)|0]=a[A+(J+R)|0]|0;P=R+1|0;if((P|0)<(E|0)){R=P}else{O=t;break}}}}t=z+E|0;if((t|0)<318){h=r;z=t;L=O}else{M=r;N=O;break}}}do{if(B){L=-M&7;if((L|0)==0){T=M;break}z=L+M|0;T=H>>>0>z>>>0?z:H}else{T=M}}while(0);z=o+D|0;if((z|0)<198){q=T;o=z;y=N}else{I=37;break}}if((I|0)==37){N=MCb(g,e)|0;if((N|0)<0){k=N;return k|0}c[f>>2]=1;k=i;return k|0}else if((I|0)==39){return k|0}return 0}function ZZ(a){a=a|0;JCb(c[a+60>>2]|0);return 0}function _Z(a){a=a|0;c[a+140>>2]=300;return 0}function $Z(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;h=i;j=e;k=c[g+24>>2]|0;l=c[b+100>>2]|0;a:do{if(l>>>0>23>>>0){m=c[b+96>>2]|0;n=l;while(1){o=m;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=fe(p|0)|0;if((PGb(m+4|0,2193984,12)|0)==0){break}if((p|0)==0|o>>>0>n>>>0){q=1;break a}p=n-o|0;if(p>>>0>23>>>0){m=m+o|0;n=p}else{q=1;break a}}q=(a[m+19|0]|0)!=1|0}else{q=1}}while(0);l=b+124|0;n=c[l>>2]|0;p=(n|0)==486?10:16;o=b+120|0;r=(ba(c[o>>2]<<1,p+n|0)|0)+(q<<2)|0;n=g+28|0;g=c[n>>2]|0;if((g|0)<(r|0)){yDb(b,16,2115736,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-22;i=h;return t|0}if((c[b+792>>2]|0)==32){u=(g|0)>=((r<<1)+4|0)}else{u=0}g=r+5|0;r=_$a(b,j,0)|0;if((r|0)<0){t=r;i=h;return t|0}c[e+84>>2]=1;c[e+88>>2]=1;r=(q|0)!=0;j=c[o>>2]|0;if(r){v=k;w=g}else{b=ba(j,p)|0;v=k+b|0;w=b+g|0}g=q+1|0;b=e;s=e+32|0;x=e+4|0;y=e+36|0;z=e+8|0;A=e+40|0;B=e+12|0;C=e+44|0;e=k+w|0;w=v;v=0;k=j;while(1){j=ba(k,p)|0;D=w+j|0;E=e+j|0;j=c[l>>2]|0;if(r&(j|0)==486){F=1-v|0;G=c[s>>2]|0;H=ba(G,F)|0;I=c[y>>2]|0;J=(c[x>>2]|0)+(ba(I,F)|0)|0;K=c[A>>2]|0;L=(c[z>>2]|0)+(ba(K,F)|0)|0;M=c[C>>2]|0;N=(c[B>>2]|0)+(ba(M,F)|0)|0;O=L;P=J;Q=H;R=486;S=G;T=I;U=K;V=M}else{M=c[s>>2]|0;K=ba(M,v)|0;I=c[y>>2]|0;G=(c[x>>2]|0)+(ba(I,v)|0)|0;H=c[A>>2]|0;J=(c[z>>2]|0)+(ba(H,v)|0)|0;L=c[C>>2]|0;N=(c[B>>2]|0)+(ba(L,v)|0)|0;O=J;P=G;Q=K;R=j;S=M;T=I;U=H;V=L}if((R>>q|0)>0){L=E;H=(c[b>>2]|0)+Q|0;I=P;M=O;j=N;K=D;G=0;J=k;F=S;W=T;X=U;Y=V;Z=R;while(1){if((J>>1|0)>0){if(u){_=L;$=K;aa=0;while(1){a[I+aa|0]=a[$]|0;ca=aa<<1;a[H+ca|0]=a[$+1|0]|0;a[j+ca|0]=~a[_];a[M+aa|0]=a[$+2|0]|0;da=$+4|0;ea=ca|1;a[H+ea|0]=a[$+3|0]|0;a[j+ea|0]=~a[_+2|0];ea=_+4|0;ca=aa+1|0;fa=c[o>>2]|0;if((ca|0)<(fa>>1|0)){_=ea;$=da;aa=ca}else{ga=ea;ha=da;ia=fa;break}}}else{aa=L;$=K;_=0;while(1){a[I+_|0]=a[$]|0;fa=_<<1;a[H+fa|0]=a[$+1|0]|0;a[j+fa|0]=-1;a[M+_|0]=a[$+2|0]|0;da=$+4|0;ea=fa|1;a[H+ea|0]=a[$+3|0]|0;a[j+ea|0]=-1;ea=aa+2|0;fa=_+1|0;ca=c[o>>2]|0;if((fa|0)<(ca>>1|0)){aa=ea;$=da;_=fa}else{ga=ea;ha=da;ia=ca;break}}}ja=ga;ka=ha;la=ia;ma=c[s>>2]|0;na=c[y>>2]|0;oa=c[A>>2]|0;pa=c[C>>2]|0;qa=c[l>>2]|0}else{ja=L;ka=K;la=J;ma=F;na=W;oa=X;pa=Y;qa=Z}_=H+(ba(ma,g)|0)|0;$=I+(ba(na,g)|0)|0;aa=M+(ba(oa,g)|0)|0;ca=j+(ba(pa,g)|0)|0;da=G+1|0;if((da|0)<(qa>>q|0)){L=ja;H=_;I=$;M=aa;j=ca;K=ka;G=da;J=la;F=ma;W=na;X=oa;Y=pa;Z=qa}else{ra=ja;sa=ka;ta=la;break}}}else{ra=E;sa=D;ta=k}Z=v+1|0;if((Z|0)<(g|0)){e=ra+4|0;w=sa+4|0;v=Z;k=ta}else{break}}c[f>>2]=1;t=c[n>>2]|0;i=h;return t|0}function a_(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=ICb()|0;c[b+804>>2]=e;do{if((c[b+120>>2]|0)==720){f=c[b+124>>2]|0;if(!((f|0)==486|(f|0)==576)){break}if((e|0)==0){yDb(b,16,2115704,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-12;i=d;return h|0}f=cEb(40)|0;c[b+96>>2]=f;if((f|0)==0){h=-12;i=d;return h|0}c[b+100>>2]=24;UGb(f|0,2056440,16)|0;a[f+19|0]=(c[b+408>>2]|0)>>>0>1>>>0?2:1;h=0;i=d;return h|0}}while(0);yDb(b,16,2193888,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=d;return h|0}function b_(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d|0;g=(c[a+408>>2]|0)>>>0>1>>>0;h=g&1;i=a+124|0;j=c[i>>2]|0;k=(j|0)==486?10:16;l=a+120|0;m=(ba(c[l>>2]<<1,k+j|0)|0)+(h<<3)|0;j=r0a(a,b,m,(m|0)<0|0?-1:0)|0;if((j|0)<0){n=j;return n|0}j=c[b+24>>2]|0;if(g){o=j}else{o=j+(ba(c[l>>2]|0,k)|0)|0}j=c[a+804>>2]|0;c[j+84>>2]=1;c[j+88>>2]=1;j=d+32|0;d=g?2:1;if(g){g=0;a=o;while(1){m=c[i>>2]|0;p=c[f>>2]|0;if((m|0)==486){q=p+(ba(c[j>>2]|0,1-g|0)|0)|0;r=c[l>>2]|0;s=0;t=q;u=a+((ba(r,k)|0)+(g<<2))|0;v=r;w=9}else{r=p+(ba(c[j>>2]|0,g)|0)|0;p=c[l>>2]|0;q=a+((ba(p,k)|0)+(g<<2))|0;if((m|0)>0){s=0;t=r;u=q;v=p;w=9}else{x=q}}if((w|0)==9){while(1){w=0;UGb(u|0,t|0,v<<1)|0;q=t+(ba(c[j>>2]|0,d)|0)|0;p=c[l>>2]|0;r=u+(p<<1)|0;m=s+d|0;if((m|0)<(c[i>>2]|0)){s=m;t=q;u=r;v=p;w=9}else{x=r;break}}}r=g+1|0;if((r|0)>(h|0)){break}else{g=r;a=x}}}else{x=0;a=o;while(1){o=(c[f>>2]|0)+(ba(c[j>>2]|0,x)|0)|0;g=c[l>>2]|0;w=a+((ba(g,k)|0)+(x<<2))|0;if((c[i>>2]|0)>0){v=0;u=o;o=w;t=g;while(1){UGb(o|0,u|0,t<<1)|0;g=u+(ba(c[j>>2]|0,d)|0)|0;s=c[l>>2]|0;r=o+(s<<1)|0;p=v+d|0;if((p|0)<(c[i>>2]|0)){v=p;u=g;o=r;t=s}else{y=r;break}}}else{y=w}t=x+1|0;if((t|0)>(h|0)){break}else{x=t;a=y}}}y=b+36|0;c[y>>2]=c[y>>2]|1;c[e>>2]=1;n=0;return n|0}function c_(a){a=a|0;$Db(a+804|0);return 0}function d_(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[a+140>>2]=11;a=ICb()|0;c[b>>2]=a;return((a|0)==0?-12:0)|0}function e_(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;h=i;j=c[b+60>>2]|0;k=b+120|0;l=c[k>>2]|0;m=j;n=$$a(b,c[m>>2]|0)|0;if((n|0)<0){o=n;i=h;return o|0}n=c[m>>2]|0;p=n+32|0;q=(c[p>>2]|0)-(c[k>>2]|0)|0;do{if((c[g+44>>2]|0)>0){r=c[g+40>>2]|0;if((c[r+8>>2]|0)!=0){break}s=c[r>>2]|0;t=c[r+4>>2]|0;if(!((t|0)>-1)){yDb(0,0,2115600,(u=i,i=i+24|0,c[u>>2]=2056416,c[u+8>>2]=2010392,c[u+16>>2]=135,u)|0);i=u;Cd();return 0}r=j+4|0;c[r>>2]=s;c[j+12>>2]=s;c[j+8>>2]=s+t;v=c[n+4>>2]|0;if(t>>>0<768>>>0){o=-1094995529;i=h;return o|0}else{w=0;x=s}while(1){s=x+3|0;c[r>>2]=s;t=d[x+1|0]<<8|d[x]<<16|d[x+2|0];c[v+(w<<2)>>2]=t<<2|t>>>4&197379|-16777216;t=w+1|0;if((t|0)<256){w=t;x=s}else{break}}c[n+304>>2]=1}}while(0);x=c[g+24>>2]|0;w=g+28|0;g=c[w>>2]|0;if(!((g|0)>-1)){yDb(0,0,2115600,(u=i,i=i+24|0,c[u>>2]=2056416,c[u+8>>2]=2010392,c[u+16>>2]=135,u)|0);i=u;Cd();return 0}v=j+4|0;c[v>>2]=x;c[j+12>>2]=x;r=x+g|0;s=j+8|0;c[s>>2]=r;j=c[n>>2]|0;t=c[p>>2]|0;p=c[b+124>>2]|0;y=j+(ba(p,t)|0)|0;z=r;r=x;do{if((g|0)<1){A=j;B=0;C=x}else{D=x+1|0;c[v>>2]=D;E=a[x]|0;if((E|0)==4){if((z-D|0)<2){F=0;G=D}else{H=x+3|0;c[v>>2]=H;I=D;F=(d[I]|d[I+1|0]<<8)<<16>>16&65535;G=H}if((F|0)<(p|0)){A=j+(ba(t,F)|0)|0;B=4;C=G;break}else{o=-1094995529;i=h;return o|0}}else if((E|0)!=2){A=j;B=E;C=D;break}c[f>>2]=0;E=c[n+4>>2]|0;if((z-D|0)>>>0<768>>>0){yDb(b,16,2193856,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;o=-1094995529;i=h;return o|0}else{J=0;K=D}while(1){L=K+3|0;c[v>>2]=L;D=d[K+1|0]<<8|d[K]<<16|d[K+2|0];c[E+(J<<2)>>2]=D<<2|D>>>4&197379|-16777216;D=J+1|0;if((D|0)<256){J=D;K=L}else{break}}c[n+304>>2]=1;o=L-r|0;i=h;return o|0}}while(0);a:do{if((z-C|0)>=1){r=(B|0)==3;L=l;n=A;K=C;while(1){J=K+1|0;c[v>>2]=J;u=a[K]|0;if(u<<24>>24==0){break a}b=u&127;j=u<<24>>24>-1;b:do{if(j){if(r){u=b;G=n;F=L;t=J;while(1){if((u|0)<=(F|0)){M=F;N=G;O=u;break b}p=(c[s>>2]|0)-t|0;x=p>>>0>F>>>0?F:p;UGb(G|0,t|0,x)|0;p=(c[v>>2]|0)+x|0;c[v>>2]=p;x=G+(q+F)|0;if((x|0)==(y|0)){break a}else{u=u-F|0;G=x;F=c[k>>2]|0;t=p}}}else{t=b;F=n;G=L;u=J;while(1){if((t|0)<=(G|0)){M=G;N=F;O=t;break b}p=(c[s>>2]|0)-u|0;x=p>>>0>G>>>0?G:p;UGb(F|0,u|0,x)|0;p=(c[v>>2]|0)+x|0;c[v>>2]=p;x=F+(q+G)|0;if((x|0)==(y|0)){break a}else{t=t-G|0;F=x;G=c[k>>2]|0;u=p}}}}else{if(r){P=b;Q=n;R=L}else{u=b;G=n;F=L;while(1){if((u|0)<=(F|0)){M=F;N=G;O=u;break b}t=G+(q+F)|0;if((t|0)==(y|0)){break a}else{u=u-F|0;G=t;F=c[k>>2]|0}}}while(1){if((P|0)<=(R|0)){M=R;N=Q;O=P;break b}F=c[v>>2]|0;if(((c[s>>2]|0)-F|0)<1){S=0}else{S=a[F]|0}TGb(Q|0,S|0,R|0)|0;F=Q+(q+R)|0;if((F|0)==(y|0)){break a}else{P=P-R|0;Q=F;R=c[k>>2]|0}}}}while(0);do{if(j){b=c[v>>2]|0;J=(c[s>>2]|0)-b|0;F=J>>>0>O>>>0?O:J;UGb(N|0,b|0,F)|0;c[v>>2]=(c[v>>2]|0)+F}else{if(!r){break}F=c[v>>2]|0;if(((c[s>>2]|0)-F|0)<1){T=0}else{c[v>>2]=F+1;T=a[F]|0}TGb(N|0,T|0,O|0)|0}}while(0);j=c[v>>2]|0;if(((c[s>>2]|0)-j|0)<1){break}else{L=M-O|0;n=N+O|0;K=j}}}}while(0);O=MCb(e,c[m>>2]|0)|0;if((O|0)<0){o=O;i=h;return o|0}c[f>>2]=1;o=c[w>>2]|0;i=h;return o|0}function f_(a){a=a|0;JCb(c[a+60>>2]|0);return 0}function g_(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[a+140>>2]=11;d=cEb(ba(c[a+124>>2]|0,c[a+120>>2]|0)|0)|0;c[b+4>>2]=d;return((d|0)==0?-12:0)|0}function h_(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;h=i;j=c[g+28>>2]|0;k=c[b+60>>2]|0;l=k+4|0;m=c[l>>2]|0;n=b+120|0;o=c[b+124>>2]|0;p=ba(o,c[n>>2]|0)|0;q=m+p|0;r=_$a(b,e,0)|0;if((r|0)<0){s=r;i=h;return s|0}r=c[g+24>>2]|0;if(!((j|0)>-1)){yDb(0,0,2010360,(t=i,i=i+24|0,c[t>>2]=1971536,c[t+8>>2]=1942848,c[t+16>>2]=135,t)|0);i=t;Cd();return 0}g=r+j|0;u=e+88|0;if((c[b+428>>2]|0)==0){c[u>>2]=1;c[e+84>>2]=1;v=b+100|0;w=c[v>>2]|0;if((w|0)>768){yDb(0,16,2193832,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}x=c[e+4>>2]|0;if((w|0)>2){w=c[b+96>>2]|0;y=x;z=0;while(1){c[y>>2]=-16777216;A=z*3|0;B=d[w+A|0]|0;C=((B<<2|B>>>4)<<16)-16777216|0;c[y>>2]=C;B=d[w+(A+1)|0]|0;D=((B<<2|B>>>4)<<8)+C|0;c[y>>2]=D;C=d[w+(A+2)|0]|0;c[y>>2]=(C<<2|C>>>4)+D;D=z+1|0;if((D|0)<((c[v>>2]|0)/3|0|0)){y=y+4|0;z=D}else{break}}}UGb(k+8|0,x|0,1024)|0;c[e+304>>2]=1}else{c[u>>2]=2;c[e+84>>2]=0;c[e+304>>2]=0;UGb(c[e+4>>2]|0,k+8|0,1024)|0}k=g;a:do{if((p|0)!=0){u=r+(j>>>0>4>>>0?4:j)|0;x=m;z=0;b:while(1){y=u;v=z;while(1){if((k-y|0)<1){E=0;F=y}else{E=d[y]|0;F=y+1|0}w=E>>>6;D=E&63;C=k-F|0;if((g|0)==(F|0)){G=20;break b}A=(w|0)==1;do{if((D|0)==0){if(!A){if((C|0)<2){H=0;I=F}else{B=F;H=(d[B]|d[B+1|0]<<8)<<16>>16&65535;I=F+2|0}if((w|0)==2&(H|0)==0){break a}else{J=H;K=v;L=I;break}}if((C|0)<1){M=0;N=F}else{M=d[F]|0;N=F+1|0}if((k-N|0)<2){J=M;K=0;L=N;break}B=N;J=M;K=(d[B]|d[B+1|0]<<8)<<16>>16&65535;L=N+2|0}else{if(!A){J=D;K=v;L=F;break}if((C|0)<1){J=D;K=0;L=F;break}J=D;K=d[F]|0;L=F+1|0}}while(0);if((x+(J<<(d[1732704+w|0]|0))|0)>>>0>q>>>0){break a}if((w|0)==0){G=35;break}else if((w|0)==3){G=44;break}else if((w|0)==2){G=42;break}else if((w|0)!=1){y=L;v=K;continue}O=x+(-K|0)|0;if(O>>>0<(c[l>>2]|0)>>>0){y=L;v=K}else{G=39;break}}do{if((G|0)==35){G=0;if(!(J>>>0<(k-L|0)>>>0)){G=36;break b}UGb(x|0,L|0,J)|0;P=x+J|0;Q=L+J|0}else if((G|0)==39){G=0;v=J<<2;if((v|0)==0){P=x;Q=L;break}y=J<<2;D=O;C=x;A=v;while(1){v=A-1|0;a[C]=a[D]|0;if((v|0)==0){break}else{D=D+1|0;C=C+1|0;A=v}}P=x+y|0;Q=L}else if((G|0)==42){G=0;P=x+J|0;Q=L}else if((G|0)==44){G=0;if((k-L|0)<1){R=0;S=L}else{R=a[L]|0;S=L+1|0}if((k-S|0)<1){T=0;U=S}else{T=a[S]|0;U=S+1|0}if((J|0)==0){P=x;Q=U;break}A=J<<1;C=x;D=J;while(1){w=D-1|0;a[C]=R;a[C+1|0]=T;if((w|0)==0){break}else{C=C+2|0;D=w}}P=x+A|0;Q=U}}while(0);if((P|0)==(q|0)){break a}else{u=Q;x=P;z=K}}if((G|0)==20){yDb(b,16,2115552,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}else if((G|0)==36){yDb(b,16,2056352,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}}}while(0);if((o|0)!=0){t=e+32|0;b=c[l>>2]|0;l=o;o=c[e>>2]|0;e=c[n>>2]|0;while(1){G=l-1|0;UGb(o|0,b|0,e)|0;K=c[n>>2]|0;if((G|0)==0){break}else{b=b+K|0;l=G;o=o+(c[t>>2]|0)|0;e=K}}}c[f>>2]=1;s=j;i=h;return s|0}function i_(a){a=a|0;ZDb(c[(c[a+60>>2]|0)+4>>2]|0);return 0}function j_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;c[b>>2]=WDb(4096)|0;f=WDb(16)|0;c[d>>2]=f;if((c[b>>2]|0)==0|(f|0)==0){$Db(b);$Db(d);yDb(a,16,2336088,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-12;i=e;return g|0}else{TGb(f|0,-1|0,16)|0;g=0;i=e;return g|0}return 0}function k_(a,b){a=a|0;b=b|0;$Db(a);$Db(b);return}function l_(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;c[b>>2]=262143;c[e>>2]=0;e=a+8|0;b=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(b>>>3)|0;a=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(b&7)>>>14;h=b+18|0;c[e>>2]=g>>>0>h>>>0?h:g;c[f>>2]=a;return}function m_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+8|0;d=c[b>>2]|0;e=-d|0;f=(c[a+16>>2]|0)-d|0;if((e|0)>-16){g=e}else{g=(f|0)<-16?f:-16}c[b>>2]=g+d;return}function n_(b,f,g,h,i,j,k,l,m,n){b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;if((h|0)<0){o=0}else{o=(h|0)>3?3:h}p=o<<10;q=n+(o<<2)|0;if((c[q>>2]|0)!=(h|0)){o=1<<h;n=0;r=m+p|0;while(1){s=c[1500224+(n<<2)>>2]|0;t=0;u=r;while(1){v=t+1|0;w=v<<8;x=o;while(1){if((e[s+(x<<1)>>1]|0)>>>0>w>>>0){x=x+o|0}else{break}}a[u]=x>>>(h>>>0);if(v>>>0<64>>>0){t=v;u=u+1|0}else{break}}u=n+1|0;if(u>>>0<16>>>0){n=u;r=r+64|0}else{break}}c[q>>2]=h}q=c[j>>2]|0;r=c[k>>2]|0;n=c[l>>2]|0;if((f|0)==0){y=q;z=r;A=n;c[j>>2]=y;c[k>>2]=z;c[l>>2]=A;return}o=p+(i<<6)|0;p=c[1500224+(i<<2)>>2]|0;i=b+8|0;u=b|0;t=b+16|0;b=1<<h;s=q;q=r;r=n;n=0;w=g;while(1){g=s-q+1|0;B=((r-q<<14|16383)>>>0)/(g>>>0)|0;C=(d[m+(o+(B>>>8))|0]|0)<<h;if((e[p+(C<<1)>>1]|0)>>>0>B>>>0){D=C;while(1){E=D+b|0;if((e[p+(E<<1)>>1]|0)>>>0>B>>>0){D=E}else{F=E;break}}}else{F=C}D=F>>>(h>>>0);B=D-1|0;E=(((ba(e[p+(B<<h<<1)>>1]|0,g)|0)-16384|0)>>>14)+q|0;G=r;H=((ba(e[p+(D<<h<<1)>>1]|0,g)|0)>>>14)+q|0;D=E;a:while(1){do{if(D>>>0>131071>>>0){if(H>>>0>131071>>>0){I=G-131072|0;J=H-131072|0;K=D-131072|0;break}if(!(H>>>0>65535>>>0&D>>>0<196608>>>0)){break a}I=G-65536|0;J=H-65536|0;K=D-65536|0}else{I=G;J=H;K=D}}while(0);v=c[i>>2]|0;x=(d[(c[u>>2]|0)+(v>>>3)|0]|0)<<(v&7)>>>7;c[i>>2]=((v|0)<(c[t>>2]|0))+v;G=x&1|I<<1;H=J<<1;D=K<<1|1}c[w>>2]=B;g=n+1|0;if(g>>>0<f>>>0){s=D;q=H;r=G;n=g;w=w+4|0}else{y=D;z=H;A=G;break}}c[j>>2]=y;c[k>>2]=z;c[l>>2]=A;return}function o_(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+64|0;f=e|0;g=c[b+60>>2]|0;h=c[b+52>>2]|0;j=g+1472|0;c[j>>2]=h>>>24;if((c[b+100>>2]|0)<4){yDb(b,16,2275048,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=e;return l|0}k=c[b+96>>2]|0;m=g+1476|0;c[m>>2]=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24)&1048576;c[g+1480>>2]=h>>>0>1744830463>>>0;if((c[2216458]|0)==0){h=0;do{k=d[1693935+(h<<4)|0]|0;c[8865532+(h*20|0)>>2]=8638040+(h<<7<<2);c[8865540+(h*20|0)>>2]=1<<k;N_(8865528+(h*20|0)|0,k,16,1693920+(h<<4)|0,1,1,1694176+(h<<4)|0,1,1,0,0,0,6)|0;h=h+1|0;}while((h|0)<16)}h=g;c[h>>2]=b;k=ICb()|0;c[g+1468>>2]=k;if((k|0)==0){l=-12;i=e;return l|0}k=hDb(c[b+120>>2]|0,c[b+124>>2]|0,0,b)|0;if((k|0)<0){l=k;i=e;return l|0}c[b+140>>2]=(c[m>>2]|0)!=0?35:0;Z3(g+4|0,b);BFa(g+1248|0,c[b+88>>2]|0);C_(g+1456|0);b=c[h>>2]|0;h=ba(((c[b+120>>2]|0)+7|0)>>>3<<6,(c[b+124>>2]|0)+7>>3)|0;b=cEb(h)|0;m=g+1512|0;c[m>>2]=b;do{if((b|0)==0){n=g+1552|0}else{c[g+1516>>2]=b+h;k=cEb(h)|0;o=g+1552|0;c[o>>2]=k;if((k|0)==0){n=o;break}c[g+1556>>2]=k+h;k=cEb(h)|0;c[g+1592>>2]=k;if((k|0)==0){n=o;break}c[g+1596>>2]=k+h;k=cEb(h)|0;c[g+1632>>2]=k;if((k|0)==0){n=o;break}c[g+1636>>2]=k+h;k=cEb(h)|0;c[g+1672>>2]=k;if((k|0)==0){n=o;break}c[g+1676>>2]=k+h;k=cEb(h)|0;c[g+1712>>2]=k;if((k|0)==0){n=o;break}c[g+1716>>2]=k+h;k=cEb(h)|0;c[g+1752>>2]=k;if((k|0)==0){n=o;break}c[g+1756>>2]=k+h;k=cEb(h)|0;c[g+1792>>2]=k;if((k|0)==0){n=o;break}c[g+1796>>2]=k+h;k=cEb(h)|0;c[g+1832>>2]=k;if((k|0)==0){n=o;break}c[g+1836>>2]=k+h;k=cEb(h)|0;c[g+1872>>2]=k;if((k|0)==0){n=o;break}c[g+1876>>2]=k+h;if((c[j>>2]|0)!=98|a[1403296]){l=0;i=e;return l|0}k=0;while(1){a[f+(d[1694432+k|0]|0)|0]=k;o=k+1|0;if((o|0)<64){k=o}else{p=0;break}}do{k=d[1693464+p|0]|0;o=0;q=d[1693608+p|0]|0;r=q<<18|0>>>14;s=0<<18|q>>>14;q=0;do{t=d[f+q|0]|0;u=c[1693624+(q<<2)>>2]|0;v=u;w=(u|0)<0|0?-1:0;u=gHb(d[1693480+q|0]|0,0,k,o)|0;x=gHb(u,F,v,w)|0;u=eHb(x,F,r,s)|0;c[8857336+(p<<8)+(t<<2)>>2]=u;u=d[1693544+q|0]|0;x=gHb(v,w,k,o)|0;w=gHb(x,F,u,0)|0;u=eHb(w,F,r,s)|0;c[8861432+(p<<8)+(t<<2)>>2]=u;q=q+1|0;}while((q|0)<64);p=p+1|0;}while((p|0)<16);a[1403296]=1;l=0;i=e;return l|0}}while(0);$Db(m);$Db(n);$Db(g+1592|0);$Db(g+1632|0);$Db(g+1672|0);$Db(g+1712|0);$Db(g+1752|0);$Db(g+1792|0);$Db(g+1832|0);$Db(g+1872|0);l=-12;i=e;return l|0}function p_(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0;j=i;i=i+672|0;k=j|0;l=j+8|0;m=j+136|0;n=j+392|0;o=j+648|0;p=c[e+60>>2]|0;q=p;r=f;f=h+28|0;s=c[f>>2]<<3;t=p+1472|0;do{if((c[t>>2]|0)>98){u=_$a(e,r,1)|0;if((u|0)<0){v=u}else{break}i=j;return v|0}else{u=p+1468|0;w=$$a(e,c[u>>2]|0)|0;if((w|0)<0){v=w;i=j;return v|0}w=MCb(r,c[u>>2]|0)|0;if((w|0)<0){v=w}else{break}i=j;return v|0}}while(0);e=c[h+24>>2]|0;h=s>>>0>2147483639>>>0|(e|0)==0;w=h?0:e;e=h?0:s;h=o|0;c[h>>2]=w;c[o+12>>2]=e;u=e+8|0;y=o+16|0;c[y>>2]=u;c[o+4>>2]=w+(e>>3);e=o+8|0;c[e>>2]=0;do{if((c[p+1476>>2]|0)!=0){if((c[t>>2]|0)>104){c[e>>2]=(u|0)<32?u:32}w=s_(q,r,o,3,0)|0;if((w|0)<0){v=w}else{break}i=j;return v|0}}while(0);if((c[t>>2]|0)>104){u=c[e>>2]|0;w=-u|0;z=(c[y>>2]|0)-u|0;if((w|0)>32){A=w}else{A=(z|0)<32?z:32}c[e>>2]=A+u}u=p+1484|0;c[u>>2]=(c[u>>2]|0)+1;A=p+1480|0;z=m;w=l|0;l=m|0;m=p;B=p+1512|0;C=p+1524|0;D=p+1520|0;E=p+1488|0;F=p+1552|0;G=p+1564|0;H=p+1560|0;I=p+1528|0;J=p+1592|0;K=p+1604|0;L=p+1600|0;M=p+1568|0;N=p+1632|0;O=p+1644|0;P=p+1640|0;Q=p+1608|0;R=p+1672|0;S=p+1684|0;T=p+1680|0;U=p+1648|0;V=p+1712|0;W=p+1724|0;X=p+1720|0;Y=p+1688|0;Z=p+1752|0;_=p+1764|0;$=p+1760|0;aa=p+1728|0;ca=p+1792|0;da=p+1804|0;ea=p+1800|0;fa=p+1768|0;ga=p+1832|0;ha=p+1844|0;ia=p+1840|0;ja=p+1808|0;ka=p+1872|0;la=p+1884|0;ma=p+1880|0;na=p+1848|0;oa=p+1456|0;pa=p+40|0;qa=p+24|0;ra=p+1264|0;sa=p+1460|0;ta=p+1244|0;ua=k|0;va=k+4|0;wa=0;while(1){if((wa|0)>=3){xa=105;break}ya=(wa|0)!=0;if(ya){za=(c[A>>2]|0)==0?wa:wa^3}else{za=0}if((c[t>>2]|0)>98){Aa=s_(q,r,o,za,ya&1)|0;if((Aa|0)<0){v=Aa;xa=108;break}}else{Aa=(c[u>>2]|0)==1?-15:0;Ba=r+32+(za<<2)|0;Ca=c[Ba>>2]|0;Da=c[m>>2]|0;Ea=c[Da+120>>2]|0;if(ya){Fa=(c[Da+124>>2]|0)+15>>4;Ga=Ea+15>>4}else{Fa=(c[Da+124>>2]|0)+7>>3;Ga=Ea+7>>3}Ea=c[B>>2]|0;c[C>>2]=Ea;c[D>>2]=Ea;c[E>>2]=13;Ea=c[F>>2]|0;c[G>>2]=Ea;c[H>>2]=Ea;c[I>>2]=13;Ea=c[J>>2]|0;c[K>>2]=Ea;c[L>>2]=Ea;c[M>>2]=13;Ea=c[N>>2]|0;c[O>>2]=Ea;c[P>>2]=Ea;c[Q>>2]=13;Ea=c[R>>2]|0;c[S>>2]=Ea;c[T>>2]=Ea;c[U>>2]=13;Ea=c[V>>2]|0;c[W>>2]=Ea;c[X>>2]=Ea;c[Y>>2]=13;Ea=c[Z>>2]|0;c[_>>2]=Ea;c[$>>2]=Ea;c[aa>>2]=13;Ea=c[ca>>2]|0;c[da>>2]=Ea;c[ea>>2]=Ea;c[fa>>2]=13;Ea=c[ga>>2]|0;c[ha>>2]=Ea;c[ia>>2]=Ea;c[ja>>2]=13;Ea=c[ka>>2]|0;c[la>>2]=Ea;c[ma>>2]=Ea;c[na>>2]=13;Ea=r+(za<<2)|0;Da=c[Ea>>2]|0;ya=(ba(c[Ba>>2]|0,Fa)|0)+Ga|0;Ba=0;do{c[n+(Ba<<2)>>2]=(ba(Ba>>3,Ca)|0)+(Ba&7);Ba=Ba+1|0;}while((Ba|0)<64);Ba=Da+(ya<<3)|0;a:do{if((Fa|0)>0){Ha=Ca<<3;Ia=(Ga|0)>0;Ja=Ca<<1;Ka=Ca*3|0;La=Ca<<2;Ma=Ca*5|0;Na=Ca*6|0;Oa=Ca*7|0;Pa=0;b:while(1){Qa=0;do{Ra=c[1693880+(Qa<<2)>>2]|0;Sa=1<<Ra-1;Ta=q+1488+(Qa*40|0)+32|0;Ua=c[Ta>>2]|0;c:do{if((Ua|0)!=0){if(Ua>>>0>(c[q+1488+(Qa*40|0)+36>>2]|0)>>>0){break}Va=c[q+1488+(Qa*40|0)>>2]|0;Wa=c[e>>2]|0;Xa=c[y>>2]|0;Ya=c[h>>2]|0;Za=Ya+(Wa>>>3)|0;_a=32-Va|0;$a=(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)>>>((Wa&7)>>>0)<<_a>>>(_a>>>0);_a=Wa+Va|0;Va=Xa>>>0>_a>>>0?_a:Xa;c[e>>2]=Va;if(($a|0)==0){c[Ta>>2]=0;break}_a=Qa-5|0;if(((c[q+1488+(Qa*40|0)+28>>2]|0)-Ua|0)<(ba($a,_a>>>0<2>>>0?2:1)|0)){ab=-1094995529;break a}if(_a>>>0>1>>>0){_a=($a|0)>0;if((88>>>(Qa>>>0)&1|0)==0){if(!_a){break}Wa=32-Ra|0;Za=Ya+(Va>>>3)|0;bb=(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)>>>((Va&7)>>>0)<<Wa>>>(Wa>>>0);Za=Va+Ra|0;c[e>>2]=Xa>>>0>Za>>>0?Za:Xa;c[Ta>>2]=Ua+1;a[Ua]=bb;if(($a|0)>1){cb=1}else{break}while(1){bb=c[e>>2]|0;Za=c[y>>2]|0;db=c[Ta>>2]|0;cb=cb+1|0;eb=(c[h>>2]|0)+(bb>>>3)|0;fb=(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)>>>((bb&7)>>>0)<<Wa>>>(Wa>>>0);eb=bb+Ra|0;c[e>>2]=Za>>>0>eb>>>0?eb:Za;c[Ta>>2]=db+1;a[db]=fb;if((cb|0)>=($a|0)){break c}}}if(!_a){break}Wa=32-Ra|0;fb=1;db=Va;Za=Xa;eb=Ya;bb=Ua;while(1){gb=eb+(db>>>3)|0;hb=(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)>>>((db&7)>>>0)<<Wa>>>(Wa>>>0);gb=db+Ra|0;c[e>>2]=Za>>>0>gb>>>0?gb:Za;c[Ta>>2]=bb+1;a[bb]=hb-Sa;if((fb|0)>=($a|0)){break c}fb=fb+1|0;db=c[e>>2]|0;Za=c[y>>2]|0;eb=c[h>>2]|0;bb=c[Ta>>2]|0}}bb=Ua;eb=($a|0)>0;do{if((88>>>(Qa>>>0)&1|0)==0){if(!eb){ib=bb;break}Za=32-Ra|0;db=0;fb=bb;Wa=Va;while(1){_a=Ya+(Wa>>>3)|0;hb=(d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0)>>>((Wa&7)>>>0)<<Za>>>(Za>>>0);_a=Wa+Ra|0;gb=Xa>>>0>_a>>>0?_a:Xa;c[e>>2]=gb;b[fb>>1]=hb;hb=db+1|0;if((hb|0)<($a|0)){db=hb;fb=fb+2|0;Wa=gb}else{break}}ib=Ua+($a<<1)|0}else{if(!eb){ib=bb;break}Wa=32-Ra|0;fb=0;db=bb;Za=Va;while(1){gb=Ya+(Za>>>3)|0;hb=(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)>>>((Za&7)>>>0)<<Wa>>>(Wa>>>0);gb=Za+Ra|0;_a=Xa>>>0>gb>>>0?gb:Xa;c[e>>2]=_a;b[db>>1]=hb-Sa;hb=fb+1|0;if((hb|0)<($a|0)){fb=hb;db=db+2|0;Za=_a}else{break}}ib=Ua+($a<<1)|0}}while(0);c[Ta>>2]=ib}}while(0);Qa=Qa+1|0;}while((Qa|0)<10);d:do{if(Ia){Qa=ba(Pa,Ha)|0;Ta=(c[Ea>>2]|0)+Qa|0;Qa=1;while(1){Ua=c[C>>2]|0;c[C>>2]=Ua+1;jb=d[Ua]|0;e:do{switch(jb|0){case 5:{Ua=c[G>>2]|0;c[G>>2]=Ua+1;cf[c[ta>>2]&1023](Ta,a[Ua]|0,Ca,8);break};case 7:{Ua=c[O>>2]|0;c[O>>2]=Ua+1;Sa=a[Ua]|0;Ua=c[S>>2]|0;c[S>>2]=Ua+1;Ra=(ba((a[Ua]|0)+Aa|0,Ca)|0)+Sa|0;Sa=Ta+Ra|0;do{if(!(Sa>>>0<Da>>>0)){Ua=Ra+Ha|0;if((Ta+Ua|0)>>>0>Ba>>>0){break}if((Ua|0)>-1&(Ra|0)<(Ha|0)){Ua=Sa;$a=Ua|0;Xa=Ua+4|0;Ua=d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0;Xa=Ta+(Ra+Ca)|0;Ya=Xa|0;Va=d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0;Ya=Xa+4|0;Xa=d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0;Ya=Ta+(Ra+Ja)|0;bb=Ya|0;eb=d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0;bb=Ya+4|0;Ya=d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0;bb=Ta+(Ra+Ka)|0;Za=bb|0;db=d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0;Za=bb+4|0;bb=d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0;Za=Ta+(Ra+La)|0;fb=Za|0;Wa=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;fb=Za+4|0;Za=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;fb=Ta+(Ra+Ma)|0;_a=fb|0;hb=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;_a=fb+4|0;fb=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;_a=Ta+(Ra+Na)|0;gb=_a|0;kb=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;gb=_a+4|0;_a=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;gb=Ta+(Ra+Oa)|0;lb=gb|0;mb=d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0;lb=gb+4|0;gb=d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0;lb=Ta;nb=lb|0;x=d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=lb+4|0;x=Ua;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=Ta+Ca|0;Ua=nb|0;x=Va;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=nb+4|0;x=Xa;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=Ta+Ja|0;Xa=Ua|0;x=eb;a[Xa]=x;x=x>>8;a[Xa+1|0]=x;x=x>>8;a[Xa+2|0]=x;x=x>>8;a[Xa+3|0]=x;Xa=Ua+4|0;x=Ya;a[Xa]=x;x=x>>8;a[Xa+1|0]=x;x=x>>8;a[Xa+2|0]=x;x=x>>8;a[Xa+3|0]=x;Xa=Ta+Ka|0;Ya=Xa|0;x=db;a[Ya]=x;x=x>>8;a[Ya+1|0]=x;x=x>>8;a[Ya+2|0]=x;x=x>>8;a[Ya+3|0]=x;Ya=Xa+4|0;x=bb;a[Ya]=x;x=x>>8;a[Ya+1|0]=x;x=x>>8;a[Ya+2|0]=x;x=x>>8;a[Ya+3|0]=x;Ya=Ta+La|0;bb=Ya|0;x=Wa;a[bb]=x;x=x>>8;a[bb+1|0]=x;x=x>>8;a[bb+2|0]=x;x=x>>8;a[bb+3|0]=x;bb=Ya+4|0;x=Za;a[bb]=x;x=x>>8;a[bb+1|0]=x;x=x>>8;a[bb+2|0]=x;x=x>>8;a[bb+3|0]=x;bb=Ta+Ma|0;Za=bb|0;x=hb;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;Za=bb+4|0;x=fb;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;Za=Ta+Na|0;fb=Za|0;x=kb;a[fb]=x;x=x>>8;a[fb+1|0]=x;x=x>>8;a[fb+2|0]=x;x=x>>8;a[fb+3|0]=x;fb=Za+4|0;x=_a;a[fb]=x;x=x>>8;a[fb+1|0]=x;x=x>>8;a[fb+2|0]=x;x=x>>8;a[fb+3|0]=x;fb=Ta+Oa|0;_a=fb|0;x=mb;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;_a=fb+4|0;x=gb;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;break e}else{cf[c[ra>>2]&1023](Ta,Sa,Ca,8);break e}}}while(0);yDb(c[m>>2]|0,24,2115512,(ob=i,i=i+1|0,i=i+7&-8,c[ob>>2]=0,ob)|0);i=ob;break};case 8:{Sa=c[G>>2]|0;Ra=Ta;_a=Sa|0;gb=Sa+4|0;Sa=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;gb=Ra|0;x=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;gb=Ra+4|0;x=Sa;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;gb=(c[G>>2]|0)+8|0;Sa=Ta+Ca|0;Ra=gb|0;_a=gb+4|0;gb=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;_a=Sa|0;x=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;_a=Sa+4|0;x=gb;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;_a=(c[G>>2]|0)+16|0;gb=Ta+Ja|0;Sa=_a|0;Ra=_a+4|0;_a=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;Ra=gb|0;x=d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0;a[Ra]=x;x=x>>8;a[Ra+1|0]=x;x=x>>8;a[Ra+2|0]=x;x=x>>8;a[Ra+3|0]=x;Ra=gb+4|0;x=_a;a[Ra]=x;x=x>>8;a[Ra+1|0]=x;x=x>>8;a[Ra+2|0]=x;x=x>>8;a[Ra+3|0]=x;Ra=(c[G>>2]|0)+24|0;_a=Ta+Ka|0;gb=Ra|0;Sa=Ra+4|0;Ra=d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0;Sa=_a|0;x=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;a[Sa]=x;x=x>>8;a[Sa+1|0]=x;x=x>>8;a[Sa+2|0]=x;x=x>>8;a[Sa+3|0]=x;Sa=_a+4|0;x=Ra;a[Sa]=x;x=x>>8;a[Sa+1|0]=x;x=x>>8;a[Sa+2|0]=x;x=x>>8;a[Sa+3|0]=x;Sa=(c[G>>2]|0)+32|0;Ra=Ta+La|0;_a=Sa|0;gb=Sa+4|0;Sa=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;gb=Ra|0;x=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;gb=Ra+4|0;x=Sa;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;gb=(c[G>>2]|0)+40|0;Sa=Ta+Ma|0;Ra=gb|0;_a=gb+4|0;gb=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;_a=Sa|0;x=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;_a=Sa+4|0;x=gb;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;_a=(c[G>>2]|0)+48|0;gb=Ta+Na|0;Sa=_a|0;Ra=_a+4|0;_a=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;Ra=gb|0;x=d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0;a[Ra]=x;x=x>>8;a[Ra+1|0]=x;x=x>>8;a[Ra+2|0]=x;x=x>>8;a[Ra+3|0]=x;Ra=gb+4|0;x=_a;a[Ra]=x;x=x>>8;a[Ra+1|0]=x;x=x>>8;a[Ra+2|0]=x;x=x>>8;a[Ra+3|0]=x;Ra=(c[G>>2]|0)+56|0;_a=Ta+Oa|0;gb=Ra|0;Sa=Ra+4|0;Ra=d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0;Sa=_a|0;x=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;a[Sa]=x;x=x>>8;a[Sa+1|0]=x;x=x>>8;a[Sa+2|0]=x;x=x>>8;a[Sa+3|0]=x;Sa=_a+4|0;x=Ra;a[Sa]=x;x=x>>8;a[Sa+1|0]=x;x=x>>8;a[Sa+2|0]=x;x=x>>8;a[Sa+3|0]=x;c[G>>2]=(c[G>>2]|0)+64;break};case 1:{Sa=c[e>>2]|0;Ra=c[y>>2]|0;_a=c[h>>2]|0;gb=_a+(Sa>>>3)|0;fb=(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)>>>((Sa&7)>>>0)&15;gb=Sa+4|0;Sa=Ra>>>0>gb>>>0?gb:Ra;c[e>>2]=Sa;gb=0;mb=1694504+(fb<<6)|0;fb=Sa;Sa=_a;_a=Ra;while(1){Ra=a[Sa+(fb>>>3)|0]|0;Za=((fb|0)<(_a|0))+fb|0;c[e>>2]=Za;kb=d[1693400+gb|0]|0;bb=Sa+(Za>>>3)|0;hb=32-kb|0;Ya=(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)>>>((Za&7)>>>0)<<hb>>>(hb>>>0);hb=kb+Za|0;c[e>>2]=_a>>>0>hb>>>0?hb:_a;hb=Ya+1|0;pb=hb+gb|0;if((pb|0)>64){xa=59;break b}do{if((Ra&255&1<<(fb&7)|0)==0){if((hb|0)<=0){qb=mb;break}Ya=c[G>>2]|0;c[G>>2]=Ya+1;a[Ta+(c[n+(d[mb]<<2)>>2]|0)|0]=a[Ya]|0;if((hb|0)>1){Ya=1;Za=mb;do{Za=Za+1|0;Ya=Ya+1|0;kb=c[G>>2]|0;c[G>>2]=kb+1;a[Ta+(c[n+(d[Za]<<2)>>2]|0)|0]=a[kb]|0;}while((Ya|0)<(hb|0))}qb=mb+hb|0}else{Ya=c[G>>2]|0;c[G>>2]=Ya+1;Za=a[Ya]|0;if((hb|0)>0){rb=mb;sb=0}else{qb=mb;break}while(1){a[Ta+(c[n+(d[rb]<<2)>>2]|0)|0]=Za;Ya=sb+1|0;if((Ya|0)<(hb|0)){rb=rb+1|0;sb=Ya}else{break}}qb=mb+hb|0}}while(0);if((pb|0)>=63){break}gb=pb;mb=qb;fb=c[e>>2]|0;Sa=c[h>>2]|0;_a=c[y>>2]|0}if((pb|0)!=63){break e}_a=c[G>>2]|0;c[G>>2]=_a+1;a[Ta+(c[n+(d[qb]<<2)>>2]|0)|0]=a[_a]|0;break};case 4:{_a=c[O>>2]|0;c[O>>2]=_a+1;Sa=a[_a]|0;_a=c[S>>2]|0;c[S>>2]=_a+1;fb=(ba((a[_a]|0)+Aa|0,Ca)|0)+Sa|0;Sa=Ta+fb|0;do{if(Sa>>>0<Da>>>0){xa=82}else{_a=fb+Ha|0;if((Ta+_a|0)>>>0>Ba>>>0){xa=82;break}if((_a|0)>-1&(fb|0)<(Ha|0)){_a=Sa;mb=_a|0;gb=_a+4|0;_a=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;gb=Ta+(fb+Ca)|0;hb=gb|0;Ra=d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0;hb=gb+4|0;gb=d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0;hb=Ta+(fb+Ja)|0;Za=hb|0;Ya=d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0;Za=hb+4|0;hb=d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0;Za=Ta+(fb+Ka)|0;kb=Za|0;bb=d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0;kb=Za+4|0;Za=d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0;kb=Ta+(fb+La)|0;Wa=kb|0;Xa=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;Wa=kb+4|0;kb=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;Wa=Ta+(fb+Ma)|0;db=Wa|0;Ua=d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0;db=Wa+4|0;Wa=d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0;db=Ta+(fb+Na)|0;eb=db|0;nb=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;eb=db+4|0;db=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;eb=Ta+(fb+Oa)|0;Va=eb|0;lb=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;Va=eb+4|0;eb=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;Va=Ta;$a=Va|0;x=d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0;a[$a]=x;x=x>>8;a[$a+1|0]=x;x=x>>8;a[$a+2|0]=x;x=x>>8;a[$a+3|0]=x;$a=Va+4|0;x=_a;a[$a]=x;x=x>>8;a[$a+1|0]=x;x=x>>8;a[$a+2|0]=x;x=x>>8;a[$a+3|0]=x;$a=Ta+Ca|0;_a=$a|0;x=Ra;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;_a=$a+4|0;x=gb;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;_a=Ta+Ja|0;gb=_a|0;x=Ya;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;gb=_a+4|0;x=hb;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;gb=Ta+Ka|0;hb=gb|0;x=bb;a[hb]=x;x=x>>8;a[hb+1|0]=x;x=x>>8;a[hb+2|0]=x;x=x>>8;a[hb+3|0]=x;hb=gb+4|0;x=Za;a[hb]=x;x=x>>8;a[hb+1|0]=x;x=x>>8;a[hb+2|0]=x;x=x>>8;a[hb+3|0]=x;hb=Ta+La|0;Za=hb|0;x=Xa;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;Za=hb+4|0;x=kb;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;Za=Ta+Ma|0;kb=Za|0;x=Ua;a[kb]=x;x=x>>8;a[kb+1|0]=x;x=x>>8;a[kb+2|0]=x;x=x>>8;a[kb+3|0]=x;kb=Za+4|0;x=Wa;a[kb]=x;x=x>>8;a[kb+1|0]=x;x=x>>8;a[kb+2|0]=x;x=x>>8;a[kb+3|0]=x;kb=Ta+Na|0;Wa=kb|0;x=nb;a[Wa]=x;x=x>>8;a[Wa+1|0]=x;x=x>>8;a[Wa+2|0]=x;x=x>>8;a[Wa+3|0]=x;Wa=kb+4|0;x=db;a[Wa]=x;x=x>>8;a[Wa+1|0]=x;x=x>>8;a[Wa+2|0]=x;x=x>>8;a[Wa+3|0]=x;Wa=Ta+Oa|0;db=Wa|0;x=lb;a[db]=x;x=x>>8;a[db+1|0]=x;x=x>>8;a[db+2|0]=x;x=x>>8;a[db+3|0]=x;db=Wa+4|0;x=eb;a[db]=x;x=x>>8;a[db+1|0]=x;x=x>>8;a[db+2|0]=x;x=x>>8;a[db+3|0]=x;break}else{cf[c[ra>>2]&1023](Ta,Sa,Ca,8);break}}}while(0);if((xa|0)==82){xa=0;yDb(c[m>>2]|0,24,2115512,(ob=i,i=i+1|0,i=i+7&-8,c[ob>>2]=0,ob)|0);i=ob}TGb(z|0,0,256)|0;Sa=c[_>>2]|0;fb=b[Sa>>1]|0;c[_>>2]=Sa+2;c[l>>2]=fb<<16>>16;fb=c[ha>>2]|0;c[ha>>2]=fb+1;t_(o,l,8861432,d[fb]|0);Xe[c[sa>>2]&4095](Ta,Ca,l);break};case 0:{break};case 2:{TGb(z|0,0,256)|0;fb=c[W>>2]|0;Sa=b[fb>>1]|0;c[W>>2]=fb+2;c[l>>2]=Sa<<16>>16;Sa=c[da>>2]|0;c[da>>2]=Sa+1;t_(o,l,8857336,d[Sa]|0);Xe[c[oa>>2]&4095](Ta,Ca,l);break};case 3:{Sa=c[O>>2]|0;c[O>>2]=Sa+1;fb=a[Sa]|0;Sa=c[S>>2]|0;c[S>>2]=Sa+1;db=(ba((a[Sa]|0)+Aa|0,Ca)|0)+fb|0;fb=Ta+db|0;do{if(fb>>>0<Da>>>0){xa=75}else{Sa=db+Ha|0;if((Ta+Sa|0)>>>0>Ba>>>0){xa=75;break}if((Sa|0)>-1&(db|0)<(Ha|0)){Sa=fb;eb=Sa|0;Wa=Sa+4|0;Sa=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;Wa=Ta+(db+Ca)|0;lb=Wa|0;kb=d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0;lb=Wa+4|0;Wa=d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0;lb=Ta+(db+Ja)|0;nb=lb|0;Za=d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0;nb=lb+4|0;lb=d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0;nb=Ta+(db+Ka)|0;Ua=nb|0;hb=d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0;Ua=nb+4|0;nb=d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0;Ua=Ta+(db+La)|0;Xa=Ua|0;gb=d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0;Xa=Ua+4|0;Ua=d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0;Xa=Ta+(db+Ma)|0;bb=Xa|0;_a=d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0;bb=Xa+4|0;Xa=d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0;bb=Ta+(db+Na)|0;Ya=bb|0;$a=d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0;Ya=bb+4|0;bb=d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0;Ya=Ta+(db+Oa)|0;Ra=Ya|0;Va=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;Ra=Ya+4|0;Ya=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;Ra=Ta;mb=Ra|0;x=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;a[mb]=x;x=x>>8;a[mb+1|0]=x;x=x>>8;a[mb+2|0]=x;x=x>>8;a[mb+3|0]=x;mb=Ra+4|0;x=Sa;a[mb]=x;x=x>>8;a[mb+1|0]=x;x=x>>8;a[mb+2|0]=x;x=x>>8;a[mb+3|0]=x;mb=Ta+Ca|0;Sa=mb|0;x=kb;a[Sa]=x;x=x>>8;a[Sa+1|0]=x;x=x>>8;a[Sa+2|0]=x;x=x>>8;a[Sa+3|0]=x;Sa=mb+4|0;x=Wa;a[Sa]=x;x=x>>8;a[Sa+1|0]=x;x=x>>8;a[Sa+2|0]=x;x=x>>8;a[Sa+3|0]=x;Sa=Ta+Ja|0;Wa=Sa|0;x=Za;a[Wa]=x;x=x>>8;a[Wa+1|0]=x;x=x>>8;a[Wa+2|0]=x;x=x>>8;a[Wa+3|0]=x;Wa=Sa+4|0;x=lb;a[Wa]=x;x=x>>8;a[Wa+1|0]=x;x=x>>8;a[Wa+2|0]=x;x=x>>8;a[Wa+3|0]=x;Wa=Ta+Ka|0;lb=Wa|0;x=hb;a[lb]=x;x=x>>8;a[lb+1|0]=x;x=x>>8;a[lb+2|0]=x;x=x>>8;a[lb+3|0]=x;lb=Wa+4|0;x=nb;a[lb]=x;x=x>>8;a[lb+1|0]=x;x=x>>8;a[lb+2|0]=x;x=x>>8;a[lb+3|0]=x;lb=Ta+La|0;nb=lb|0;x=gb;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=lb+4|0;x=Ua;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=Ta+Ma|0;Ua=nb|0;x=_a;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=nb+4|0;x=Xa;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=Ta+Na|0;Xa=Ua|0;x=$a;a[Xa]=x;x=x>>8;a[Xa+1|0]=x;x=x>>8;a[Xa+2|0]=x;x=x>>8;a[Xa+3|0]=x;Xa=Ua+4|0;x=bb;a[Xa]=x;x=x>>8;a[Xa+1|0]=x;x=x>>8;a[Xa+2|0]=x;x=x>>8;a[Xa+3|0]=x;Xa=Ta+Oa|0;bb=Xa|0;x=Va;a[bb]=x;x=x>>8;a[bb+1|0]=x;x=x>>8;a[bb+2|0]=x;x=x>>8;a[bb+3|0]=x;bb=Xa+4|0;x=Ya;a[bb]=x;x=x>>8;a[bb+1|0]=x;x=x>>8;a[bb+2|0]=x;x=x>>8;a[bb+3|0]=x;break}else{cf[c[ra>>2]&1023](Ta,fb,Ca,8);break}}}while(0);if((xa|0)==75){xa=0;yDb(c[m>>2]|0,24,2115512,(ob=i,i=i+1|0,i=i+7&-8,c[ob>>2]=0,ob)|0);i=ob}me[c[pa>>2]&511](w);fb=c[la>>2]|0;c[la>>2]=fb+1;u_(o,w,d[fb]|0);Xe[c[qa>>2]&4095](Ta,w,Ca);break};case 6:{fb=c[G>>2]|0;db=fb+1|0;c[G>>2]=db;c[ua>>2]=d[fb]|0;c[G>>2]=fb+2;c[va>>2]=d[db]|0;db=0;do{fb=c[K>>2]|0;c[K>>2]=fb+1;bb=d[fb]|0;fb=ba(db,Ca)|0;a[Ta+fb|0]=c[k+((bb&1)<<2)>>2];a[Ta+(fb+1)|0]=c[k+((bb>>>1&1)<<2)>>2];a[Ta+(fb+2)|0]=c[k+((bb>>>2&1)<<2)>>2];a[Ta+(fb+3)|0]=c[k+((bb>>>3&1)<<2)>>2];a[Ta+(fb+4)|0]=c[k+((bb>>>4&1)<<2)>>2];a[Ta+(fb+5)|0]=c[k+((bb>>>5&1)<<2)>>2];a[Ta+(fb+6)|0]=c[k+((bb>>>6&1)<<2)>>2];a[Ta+(fb+7)|0]=c[k+(bb>>>7<<2)>>2];db=db+1|0;}while((db|0)<8);break};default:{xa=95;break b}}}while(0);if((Qa|0)>=(Ga|0)){break d}Ta=Ta+8|0;Qa=Qa+1|0}}}while(0);Qa=Pa+1|0;if((Qa|0)<(Fa|0)){Pa=Qa}else{xa=99;break a}}if((xa|0)==59){xa=0;yDb(c[m>>2]|0,16,2193792,(ob=i,i=i+1|0,i=i+7&-8,c[ob>>2]=0,ob)|0);i=ob;ab=-1094995529;break}else if((xa|0)==95){xa=0;yDb(c[m>>2]|0,16,2056328,(ob=i,i=i+8|0,c[ob>>2]=jb,ob)|0);i=ob;ab=-1094995529;break}}else{xa=99}}while(0);do{if((xa|0)==99){xa=0;Ca=c[e>>2]|0;Ba=Ca&31;if((Ba|0)==0){ab=0;break}Da=32-Ba|0;Ba=-Ca|0;Aa=(c[y>>2]|0)-Ca|0;if((Da|0)<(Ba|0)){tb=Ba}else{tb=(Aa|0)<(Da|0)?Aa:Da}c[e>>2]=tb+Ca;ab=0}}while(0);if((ab|0)<0){v=ab;xa=108;break}}if((c[e>>2]|0)<(s|0)){wa=wa+1|0}else{xa=105;break}}if((xa|0)==105){do{if((c[t>>2]|0)>98){wa=p+1468|0;KCb(c[wa>>2]|0);s=MCb(c[wa>>2]|0,r)|0;if((s|0)<0){v=s}else{break}i=j;return v|0}}while(0);c[g>>2]=1;v=c[f>>2]|0;i=j;return v|0}else if((xa|0)==108){i=j;return v|0}return 0}function q_(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+1468|0);$Db(b+1512|0);$Db(b+1552|0);$Db(b+1592|0);$Db(b+1632|0);$Db(b+1672|0);$Db(b+1712|0);$Db(b+1752|0);$Db(b+1792|0);$Db(b+1832|0);$Db(b+1872|0);return 0}function r_(a){a=a|0;c[(c[a+60>>2]|0)+1484>>2]=0;return}function s_(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0;k=i;i=i+712|0;l=k|0;m=k+136|0;n=k+200|0;o=k+456|0;p=k+8|0;q=m|0;r=n|0;s=c[f+32+(h<<2)>>2]|0;t=e|0;u=c[t>>2]|0;v=c[u+120>>2]|0;if((j|0)==0){w=(c[u+124>>2]|0)+7>>3;y=v+7>>3}else{w=(c[u+124>>2]|0)+15>>4;y=v+15>>4}u=v>>j;j=(u|0)>8?u+7|0:15;u=(j>>3)+511|0;v=u>>>0>65535>>>0;z=v?u>>>16:u;u=v?16:0;if((z&65280|0)==0){A=u;B=z}else{A=u|8;B=z>>>8}z=A+1+(d[1191992+B|0]|0)|0;c[e+1488>>2]=z;B=(j>>4)+511|0;j=B>>>0>65535>>>0;A=j?B>>>16:B;B=j?16:0;if((A&65280|0)==0){C=B;D=A}else{C=B|8;D=A>>>8}c[e+1528>>2]=C+1+(d[1191992+D|0]|0);D=(y<<6)+511|0;C=D>>>0>65535>>>0;A=C?D>>>16:D;D=C?16:0;if((A&65280|0)==0){E=D;F=A}else{E=D|8;F=A>>>8}A=e+1568|0;c[A>>2]=E+1+(d[1191992+F|0]|0);c[e+1688>>2]=z;c[e+1648>>2]=z;c[e+1768>>2]=z;c[e+1728>>2]=z;z=(y<<3)+511|0;F=z>>>0>65535>>>0;E=F?z>>>16:z;z=F?16:0;if((E&65280|0)==0){G=z;H=E}else{G=z|8;H=E>>>8}E=e+1608|0;c[E>>2]=G+1+(d[1191992+H|0]|0);H=(y*48|0)+511|0;G=H>>>0>65535>>>0;z=G?H>>>16:H;H=G?16:0;if((z&65280|0)==0){I=H;J=z}else{I=H|8;J=z>>>8}z=e+1808|0;c[z>>2]=I+1+(d[1191992+J|0]|0);J=e+1888|0;I=e+1908|0;H=e+1928|0;G=e+1948|0;F=e+1968|0;D=e+1988|0;C=e+2008|0;B=e+2028|0;j=e+2048|0;u=e+2068|0;v=e+2088|0;K=e+2108|0;L=e+2128|0;M=e+2148|0;N=e+2168|0;O=e+2188|0;P=e+2208|0;Q=0;do{if((Q|0)==2){y_(g,J);y_(g,I);y_(g,H);y_(g,G);y_(g,F);y_(g,D);y_(g,C);y_(g,B);y_(g,j);y_(g,u);y_(g,v);y_(g,K);y_(g,L);y_(g,M);y_(g,N);y_(g,O);c[P>>2]=0;R=18}else{if((Q-6|0)>>>0>1>>>0){R=18}}if((R|0)==18){R=0;y_(g,e+1488+(Q*40|0)+4|0)}S=c[e+1488+(Q*40|0)+24>>2]|0;c[e+1488+(Q*40|0)+36>>2]=S;c[e+1488+(Q*40|0)+32>>2]=S;Q=Q+1|0;}while((Q|0)<9);Q=e+1468|0;O=c[Q>>2]|0;N=c[O+(h<<2)>>2]|0;if((N|0)==0){T=c[f+(h<<2)>>2]|0}else{T=N}N=y-1+(ba(c[O+32+(h<<2)>>2]|0,w-1|0)|0)<<3;O=0;do{c[o+(O<<2)>>2]=(ba(O>>3,s)|0)+(O&7);O=O+1|0;}while((O|0)<64);O=T+N|0;a:do{if((w|0)>0){N=e+1488|0;M=e+1528|0;L=e+1600|0;K=e+1640|0;v=e+1648|0;u=e+1688|0;j=e+1728|0;B=e+1768|0;C=e+1840|0;D=f+(h<<2)|0;F=(y|0)>0;G=e+1524|0;H=e+1264|0;I=e+1564|0;J=g+8|0;S=g+16|0;U=g|0;V=e+1844|0;W=e+1604|0;X=e+1464|0;Y=n;Z=e+1764|0;_=e+1456|0;$=e+1240|0;aa=e+1644|0;ca=e+1684|0;da=e+1724|0;ea=e+40|0;fa=e+24|0;ga=e+1244|0;ha=e+1804|0;ia=e+1460|0;ja=e+1836|0;ka=e+1812|0;la=e+1636|0;ma=e+1612|0;na=e+1596|0;oa=e+1572|0;pa=e+1472|0;qa=0;b:while(1){ra=v_(c[t>>2]|0,g,N)|0;if((ra|0)<0){sa=ra;R=129;break}ra=v_(c[t>>2]|0,g,M)|0;if((ra|0)<0){sa=ra;R=129;break}ra=c[L>>2]|0;c:do{if((ra|0)!=0){if(ra>>>0>(c[W>>2]|0)>>>0){break}ta=c[A>>2]|0;ua=c[J>>2]|0;va=c[S>>2]|0;wa=c[U>>2]|0;xa=wa+(ua>>>3)|0;ya=32-ta|0;za=(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)>>>((ua&7)>>>0)<<ya>>>(ya>>>0);ya=ua+ta|0;ta=va>>>0>ya>>>0?ya:va;c[J>>2]=ta;if((za|0)==0){c[L>>2]=0;break}ya=ra+za|0;if(ya>>>0>(c[na>>2]|0)>>>0){R=43;break b}ua=d[wa+(ta>>>3)|0]|0;xa=((ta|0)<(va|0))+ta|0;c[J>>2]=xa;if((ua&1<<(ta&7)|0)!=0){ta=c[e+1888+((c[P>>2]|0)*20|0)>>2]|0;ua=c[8865532+(ta*20|0)>>2]|0;Aa=wa+(xa>>>3)|0;Ba=32-(c[8865528+(ta*20|0)>>2]|0)|0;ta=(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)>>>((xa&7)>>>0)<<Ba>>>(Ba>>>0);Ba=b[ua+(ta<<2)>>1]|0;Aa=(b[ua+(ta<<2)+2>>1]|0)+xa|0;c[J>>2]=va>>>0>Aa>>>0?Aa:va;c[P>>2]=d[e+1888+((c[P>>2]|0)*20|0)+4+Ba|0]|0;Ba=c[oa>>2]|0;Aa=c[8865532+(Ba*20|0)>>2]|0;ta=c[J>>2]|0;ua=c[S>>2]|0;Ca=wa+(ta>>>3)|0;Da=32-(c[8865528+(Ba*20|0)>>2]|0)|0;Ba=(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)>>>((ta&7)>>>0)<<Da>>>(Da>>>0);Da=b[Aa+(Ba<<2)>>1]|0;Ca=(b[Aa+(Ba<<2)+2>>1]|0)+ta|0;c[J>>2]=ua>>>0>Ca>>>0?Ca:ua;ua=c[P>>2]<<4|d[e+1576+Da|0];if((c[pa>>2]|0)<105){Ea=(ua>>>7&1|128)+(ua<<24>>31^ua&127)&255}else{Ea=ua&255}TGb(ra|0,Ea|0,za|0)|0;c[L>>2]=(c[L>>2]|0)+za;break}if((za|0)>0){Fa=ra;Ga=xa;Ha=va;Ia=wa}else{break}while(1){wa=c[e+1888+((c[P>>2]|0)*20|0)>>2]|0;va=c[8865532+(wa*20|0)>>2]|0;xa=Ia+(Ga>>>3)|0;za=32-(c[8865528+(wa*20|0)>>2]|0)|0;wa=(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)>>>((Ga&7)>>>0)<<za>>>(za>>>0);za=b[va+(wa<<2)>>1]|0;xa=(b[va+(wa<<2)+2>>1]|0)+Ga|0;c[J>>2]=Ha>>>0>xa>>>0?xa:Ha;c[P>>2]=d[e+1888+((c[P>>2]|0)*20|0)+4+za|0]|0;za=c[oa>>2]|0;xa=c[8865532+(za*20|0)>>2]|0;wa=c[J>>2]|0;va=c[S>>2]|0;ua=Ia+(wa>>>3)|0;Da=32-(c[8865528+(za*20|0)>>2]|0)|0;za=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((wa&7)>>>0)<<Da>>>(Da>>>0);Da=b[xa+(za<<2)>>1]|0;ua=(b[xa+(za<<2)+2>>1]|0)+wa|0;c[J>>2]=va>>>0>ua>>>0?ua:va;va=c[P>>2]<<4|d[e+1576+Da|0];if((c[pa>>2]|0)<105){Ja=(va>>>7&1|128)+(va<<24>>31^va&127)&255}else{Ja=va&255}c[L>>2]=Fa+1;a[Fa]=Ja;va=c[L>>2]|0;if(!(va>>>0<ya>>>0)){break c}Fa=va;Ga=c[J>>2]|0;Ha=c[S>>2]|0;Ia=c[U>>2]|0}}}while(0);Ka=c[t>>2]|0;ra=c[K>>2]|0;do{if((ra|0)==0){La=Ka}else{if(ra>>>0>(c[aa>>2]|0)>>>0){La=Ka;break}ya=c[E>>2]|0;va=c[J>>2]|0;Da=c[S>>2]|0;ua=c[U>>2]|0;wa=ua+(va>>>3)|0;za=32-ya|0;xa=(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)>>>((va&7)>>>0)<<za>>>(za>>>0);za=va+ya|0;ya=Da>>>0>za>>>0?za:Da;c[J>>2]=ya;if((xa|0)==0){c[K>>2]=0;La=Ka;break}za=ra+xa|0;if(za>>>0>(c[la>>2]|0)>>>0){R=52;break b}if((xa|0)>0){Ma=ra;Na=ya;Oa=Da;Pa=ua}else{La=Ka;break}while(1){ua=c[ma>>2]|0;Da=c[8865532+(ua*20|0)>>2]|0;ya=Pa+(Na>>>3)|0;xa=32-(c[8865528+(ua*20|0)>>2]|0)|0;ua=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((Na&7)>>>0)<<xa>>>(xa>>>0);xa=b[Da+(ua<<2)>>1]|0;ya=(b[Da+(ua<<2)+2>>1]|0)+Na|0;ua=Oa>>>0>ya>>>0?ya:Oa;c[J>>2]=ua;ya=a[e+1616+xa|0]|0;xa=c[ma>>2]|0;Da=c[8865532+(xa*20|0)>>2]|0;va=Pa+(ua>>>3)|0;wa=32-(c[8865528+(xa*20|0)>>2]|0)|0;xa=(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)>>>((ua&7)>>>0)<<wa>>>(wa>>>0);wa=b[Da+(xa<<2)>>1]|0;va=(b[Da+(xa<<2)+2>>1]|0)+ua|0;c[J>>2]=Oa>>>0>va>>>0?va:Oa;va=a[e+1616+wa|0]<<4|ya;c[K>>2]=Ma+1;a[Ma]=va;va=c[K>>2]|0;if(!(va>>>0<za>>>0)){break}Ma=va;Na=c[J>>2]|0;Oa=c[S>>2]|0;Pa=c[U>>2]|0}La=c[t>>2]|0}}while(0);ra=w_(La,g,v)|0;if((ra|0)<0){sa=ra;R=129;break}ra=w_(c[t>>2]|0,g,u)|0;if((ra|0)<0){sa=ra;R=129;break}ra=x_(c[t>>2]|0,g,j,0)|0;if((ra|0)<0){sa=ra;R=129;break}ra=x_(c[t>>2]|0,g,B,1)|0;if((ra|0)<0){sa=ra;R=129;break}Qa=c[t>>2]|0;ra=c[C>>2]|0;d:do{if((ra|0)!=0){if(ra>>>0>(c[V>>2]|0)>>>0){break}za=c[z>>2]|0;va=c[J>>2]|0;ya=c[S>>2]|0;wa=c[U>>2]|0;ua=wa+(va>>>3)|0;xa=32-za|0;Da=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((va&7)>>>0)<<xa>>>(xa>>>0);xa=va+za|0;za=ya>>>0>xa>>>0?xa:ya;c[J>>2]=za;if((Da|0)==0){c[C>>2]=0;break}xa=ra+Da|0;if(xa>>>0>(c[ja>>2]|0)>>>0){R=68;break b}va=d[wa+(za>>>3)|0]|0;ua=((za|0)<(ya|0))+za|0;c[J>>2]=ua;if((va&1<<(za&7)|0)!=0){za=wa+(ua>>>3)|0;va=(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)>>>((ua&7)>>>0);za=ua+4|0;c[J>>2]=ya>>>0>za>>>0?za:ya;TGb(ra|0,va&15|0,Da|0)|0;c[C>>2]=(c[C>>2]|0)+Da;break}if((Da|0)>0){Ra=ra;Sa=ua;Ta=ya;Ua=wa}else{break}while(1){wa=c[ka>>2]|0;ya=c[8865532+(wa*20|0)>>2]|0;ua=Ua+(Sa>>>3)|0;Da=32-(c[8865528+(wa*20|0)>>2]|0)|0;wa=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((Sa&7)>>>0)<<Da>>>(Da>>>0);Da=b[ya+(wa<<2)>>1]|0;ua=(b[ya+(wa<<2)+2>>1]|0)+Sa|0;c[J>>2]=Ta>>>0>ua>>>0?ua:Ta;ua=a[e+1816+Da|0]|0;c[C>>2]=Ra+1;a[Ra]=ua;ua=c[C>>2]|0;if(!(ua>>>0<xa>>>0)){break d}Ra=ua;Sa=c[J>>2]|0;Ta=c[S>>2]|0;Ua=c[U>>2]|0}}}while(0);ra=c[D>>2]|0;Va=qa<<3;xa=ba(Va,s)|0;ua=c[(c[Q>>2]|0)+(h<<2)>>2]|0;e:do{if(F){Da=(qa&1|0)!=0;wa=((ua|0)==0?ra:ua)+xa|0;ya=ra+xa|0;Wa=0;while(1){va=c[G>>2]|0;c[G>>2]=va+1;za=a[va]|0;Xa=za&255;f:do{if(Da&za<<24>>24==1){Ya=Wa+1|0;Za=ya+8|0;_a=wa+8|0}else{switch(Xa|0){case 9:{va=c[W>>2]|0;Ca=ya;ta=va|0;Ba=va+4|0;va=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;Ba=Ca|0;x=d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0;a[Ba]=x;x=x>>8;a[Ba+1|0]=x;x=x>>8;a[Ba+2|0]=x;x=x>>8;a[Ba+3|0]=x;Ba=Ca+4|0;x=va;a[Ba]=x;x=x>>8;a[Ba+1|0]=x;x=x>>8;a[Ba+2|0]=x;x=x>>8;a[Ba+3|0]=x;Ba=(c[W>>2]|0)+8|0;va=ya+s|0;Ca=Ba|0;ta=Ba+4|0;Ba=d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0;ta=va|0;x=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;ta=va+4|0;x=Ba;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;ta=(c[W>>2]|0)+16|0;Ba=ya+(s<<1)|0;va=ta|0;Ca=ta+4|0;ta=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;Ca=Ba|0;x=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[Ca]=x;x=x>>8;a[Ca+1|0]=x;x=x>>8;a[Ca+2|0]=x;x=x>>8;a[Ca+3|0]=x;Ca=Ba+4|0;x=ta;a[Ca]=x;x=x>>8;a[Ca+1|0]=x;x=x>>8;a[Ca+2|0]=x;x=x>>8;a[Ca+3|0]=x;Ca=(c[W>>2]|0)+24|0;ta=ya+(s*3|0)|0;Ba=Ca|0;va=Ca+4|0;Ca=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;va=ta|0;x=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;va=ta+4|0;x=Ca;a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;va=(c[W>>2]|0)+32|0;Ca=ya+(s<<2)|0;ta=va|0;Ba=va+4|0;va=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;Ba=Ca|0;x=d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0;a[Ba]=x;x=x>>8;a[Ba+1|0]=x;x=x>>8;a[Ba+2|0]=x;x=x>>8;a[Ba+3|0]=x;Ba=Ca+4|0;x=va;a[Ba]=x;x=x>>8;a[Ba+1|0]=x;x=x>>8;a[Ba+2|0]=x;x=x>>8;a[Ba+3|0]=x;Ba=(c[W>>2]|0)+40|0;va=ya+(s*5|0)|0;Ca=Ba|0;ta=Ba+4|0;Ba=d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0;ta=va|0;x=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;ta=va+4|0;x=Ba;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;ta=(c[W>>2]|0)+48|0;Ba=ya+(s*6|0)|0;va=ta|0;Ca=ta+4|0;ta=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;Ca=Ba|0;x=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[Ca]=x;x=x>>8;a[Ca+1|0]=x;x=x>>8;a[Ca+2|0]=x;x=x>>8;a[Ca+3|0]=x;Ca=Ba+4|0;x=ta;a[Ca]=x;x=x>>8;a[Ca+1|0]=x;x=x>>8;a[Ca+2|0]=x;x=x>>8;a[Ca+3|0]=x;Ca=(c[W>>2]|0)+56|0;ta=ya+(s*7|0)|0;Ba=Ca|0;va=Ca+4|0;Ca=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;va=ta|0;x=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;va=ta+4|0;x=Ca;a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;c[W>>2]=(c[W>>2]|0)+64;Ya=Wa;Za=ya;_a=wa;break f;break};case 0:{cf[c[H>>2]&1023](ya,wa,s,8);Ya=Wa;Za=ya;_a=wa;break f;break};case 1:{va=c[I>>2]|0;c[I>>2]=va+1;Ca=a[va]|0;$a=Ca&255;g:do{switch($a|0){case 5:{TGb(Y|0,0,256)|0;va=c[Z>>2]|0;ta=b[va>>1]|0;c[Z>>2]=va+2;c[r>>2]=ta;t_(g,r,1695528,-1);Xe[c[_>>2]&4095](q,8,r);R=96;break};case 8:{ta=c[W>>2]|0;va=ta+1|0;c[W>>2]=va;c[l>>2]=d[ta]|0;c[W>>2]=ta+2;c[l+4>>2]=d[va]|0;va=0;ta=c[aa>>2]|0;while(1){Ba=ta+1|0;c[aa>>2]=Ba;Aa=d[ta]|0;ab=va<<3;a[m+ab|0]=c[l+((Aa&1)<<2)>>2];a[m+(ab|1)|0]=c[l+((Aa>>>1&1)<<2)>>2];a[m+(ab|2)|0]=c[l+((Aa>>>2&1)<<2)>>2];a[m+(ab|3)|0]=c[l+((Aa>>>3&1)<<2)>>2];a[m+(ab|4)|0]=c[l+((Aa>>>4&1)<<2)>>2];a[m+(ab|5)|0]=c[l+((Aa>>>5&1)<<2)>>2];a[m+(ab|6)|0]=c[l+((Aa>>>6&1)<<2)>>2];a[m+(ab|7)|0]=c[l+(Aa>>>7<<2)>>2];Aa=va+1|0;if((Aa|0)<8){va=Aa;ta=Ba}else{R=95;break}}break};case 6:{ta=c[W>>2]|0;c[W>>2]=ta+1;cf[c[$>>2]&1023](ya,a[ta]|0,s,16);break};case 3:{ta=c[J>>2]|0;va=c[S>>2]|0;Ba=(c[U>>2]|0)+(ta>>>3)|0;Aa=(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)>>>((ta&7)>>>0)&15;Ba=ta+4|0;ta=va>>>0>Ba>>>0?Ba:va;c[J>>2]=ta;Ba=0;ab=1694504+(Aa<<6)|0;Aa=c[V>>2]|0;bb=ta;while(1){ta=Aa+1|0;c[V>>2]=ta;cb=d[Aa]|0;db=cb+1|0;eb=db+Ba|0;if((eb|0)>64){R=82;break b}fb=d[(c[U>>2]|0)+(bb>>>3)|0]|0;gb=((bb|0)<(va|0))+bb|0;c[J>>2]=gb;hb=c[W>>2]|0;if((fb&1<<(bb&7)|0)==0){fb=ab;ib=0;jb=hb;while(1){kb=jb+1|0;c[W>>2]=kb;a[m+(d[fb]|0)|0]=a[jb]|0;lb=ib+1|0;if((lb|0)<(db|0)){fb=fb+1|0;ib=lb;jb=kb}else{mb=kb;break}}}else{jb=hb+1|0;c[W>>2]=jb;ib=a[hb]|0;fb=ab;kb=0;while(1){a[m+(d[fb]|0)|0]=ib;lb=kb+1|0;if((lb|0)<(db|0)){fb=fb+1|0;kb=lb}else{mb=jb;break}}}nb=ab+(cb+1)|0;if((eb|0)<63){Ba=eb;ab=nb;Aa=ta;bb=gb}else{break}}if((eb|0)!=63){R=95;break g}c[W>>2]=mb+1;a[m+(d[nb]|0)|0]=a[mb]|0;R=95;break};case 9:{bb=0;Aa=c[W>>2]|0;while(1){ab=bb<<3;Ba=Aa+1|0;c[W>>2]=Ba;a[m+ab|0]=a[Aa]|0;va=Aa+2|0;c[W>>2]=va;a[m+(ab|1)|0]=a[Ba]|0;Ba=Aa+3|0;c[W>>2]=Ba;a[m+(ab|2)|0]=a[va]|0;va=Aa+4|0;c[W>>2]=va;a[m+(ab|3)|0]=a[Ba]|0;Ba=Aa+5|0;c[W>>2]=Ba;a[m+(ab|4)|0]=a[va]|0;va=Aa+6|0;c[W>>2]=va;a[m+(ab|5)|0]=a[Ba]|0;Ba=Aa+7|0;c[W>>2]=Ba;a[m+(ab|6)|0]=a[va]|0;va=Aa+8|0;c[W>>2]=va;a[m+(ab|7)|0]=a[Ba]|0;Ba=bb+1|0;if((Ba|0)<8){bb=Ba;Aa=va}else{R=95;break}}break};default:{R=94;break b}}}while(0);if((R|0)==95){R=0;if(!(Ca<<24>>24==6)){R=96}}if((R|0)==96){R=0;Xe[c[X>>2]&4095](q,ya,s)}Ya=Wa+1|0;Za=ya+8|0;_a=wa+8|0;break f;break};case 7:{Aa=c[ca>>2]|0;c[ca>>2]=Aa+1;ob=a[Aa]|0;Aa=c[da>>2]|0;c[da>>2]=Aa+1;pb=a[Aa]|0;Aa=wa+((ba(pb,s)|0)+ob)|0;if(Aa>>>0<T>>>0|Aa>>>0>O>>>0){R=118;break b}cf[c[H>>2]&1023](ya,Aa,s,8);TGb(Y|0,0,256)|0;Aa=c[ha>>2]|0;bb=b[Aa>>1]|0;c[ha>>2]=Aa+2;c[r>>2]=bb;t_(g,r,1699624,-1);Xe[c[ia>>2]&4095](ya,s,r);Ya=Wa;Za=ya;_a=wa;break f;break};case 4:{bb=c[ca>>2]|0;c[ca>>2]=bb+1;qb=a[bb]|0;bb=c[da>>2]|0;c[da>>2]=bb+1;rb=a[bb]|0;bb=wa+((ba(rb,s)|0)+qb)|0;if(bb>>>0<T>>>0|bb>>>0>O>>>0){R=113;break b}cf[c[H>>2]&1023](ya,bb,s,8);me[c[ea>>2]&511](p);bb=c[J>>2]|0;Aa=c[S>>2]|0;va=(c[U>>2]|0)+(bb>>>3)|0;Ba=(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)>>>((bb&7)>>>0)&127;va=bb+7|0;c[J>>2]=Aa>>>0>va>>>0?va:Aa;u_(g,p,Ba);Xe[c[fa>>2]&4095](ya,p,s);Ya=Wa;Za=ya;_a=wa;break f;break};case 8:{Ba=c[W>>2]|0;Aa=Ba+1|0;c[W>>2]=Aa;c[l>>2]=d[Ba]|0;c[W>>2]=Ba+2;c[l+4>>2]=d[Aa]|0;Aa=0;while(1){Ba=c[aa>>2]|0;c[aa>>2]=Ba+1;va=d[Ba]|0;Ba=ba(Aa,s)|0;a[ya+Ba|0]=c[l+((va&1)<<2)>>2];a[ya+(Ba+1)|0]=c[l+((va>>>1&1)<<2)>>2];a[ya+(Ba+2)|0]=c[l+((va>>>2&1)<<2)>>2];a[ya+(Ba+3)|0]=c[l+((va>>>3&1)<<2)>>2];a[ya+(Ba+4)|0]=c[l+((va>>>4&1)<<2)>>2];a[ya+(Ba+5)|0]=c[l+((va>>>5&1)<<2)>>2];a[ya+(Ba+6)|0]=c[l+((va>>>6&1)<<2)>>2];a[ya+(Ba+7)|0]=c[l+(va>>>7<<2)>>2];va=Aa+1|0;if((va|0)<8){Aa=va}else{Ya=Wa;Za=ya;_a=wa;break}}break};case 2:{Aa=c[ca>>2]|0;c[ca>>2]=Aa+1;sb=a[Aa]|0;Aa=c[da>>2]|0;c[da>>2]=Aa+1;tb=a[Aa]|0;Aa=wa+((ba(tb,s)|0)+sb)|0;if(Aa>>>0<T>>>0|Aa>>>0>O>>>0){R=99;break b}cf[c[H>>2]&1023](ya,Aa,s,8);Ya=Wa;Za=ya;_a=wa;break f;break};case 3:{Aa=c[J>>2]|0;Ca=c[S>>2]|0;va=(c[U>>2]|0)+(Aa>>>3)|0;Ba=(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)>>>((Aa&7)>>>0)&15;va=Aa+4|0;c[J>>2]=Ca>>>0>va>>>0?va:Ca;Ca=0;va=1694504+(Ba<<6)|0;do{Ba=c[V>>2]|0;c[V>>2]=Ba+1;Aa=d[Ba]|0;Ba=Aa+1|0;Ca=Ba+Ca|0;if((Ca|0)>64){R=103;break b}bb=c[J>>2]|0;ab=d[(c[U>>2]|0)+(bb>>>3)|0]|0;c[J>>2]=((bb|0)<(c[S>>2]|0))+bb;h:do{if((ab&1<<(bb&7)|0)==0){jb=va;kb=1;while(1){fb=c[W>>2]|0;c[W>>2]=fb+1;a[ya+(c[o+(d[jb]<<2)>>2]|0)|0]=a[fb]|0;if((kb|0)>=(Ba|0)){break h}jb=jb+1|0;kb=kb+1|0}}else{kb=c[W>>2]|0;c[W>>2]=kb+1;jb=a[kb]|0;kb=va;gb=0;while(1){a[ya+(c[o+(d[kb]<<2)>>2]|0)|0]=jb;ta=gb+1|0;if((ta|0)<(Ba|0)){kb=kb+1|0;gb=ta}else{break}}}}while(0);va=va+(Aa+1)|0;}while((Ca|0)<63);if((Ca|0)!=63){Ya=Wa;Za=ya;_a=wa;break f}Ba=c[W>>2]|0;c[W>>2]=Ba+1;a[ya+(c[o+(d[va]<<2)>>2]|0)|0]=a[Ba]|0;Ya=Wa;Za=ya;_a=wa;break f;break};case 5:{TGb(Y|0,0,256)|0;Ba=c[Z>>2]|0;bb=b[Ba>>1]|0;c[Z>>2]=Ba+2;c[r>>2]=bb;t_(g,r,1695528,-1);Xe[c[_>>2]&4095](ya,s,r);Ya=Wa;Za=ya;_a=wa;break f;break};case 6:{bb=c[W>>2]|0;c[W>>2]=bb+1;cf[c[ga>>2]&1023](ya,a[bb]|0,s,8);Ya=Wa;Za=ya;_a=wa;break f;break};default:{R=121;break b}}}}while(0);za=Ya+1|0;if((za|0)>=(y|0)){break e}wa=_a+8|0;ya=Za+8|0;Wa=za}}}while(0);xa=qa+1|0;if((xa|0)<(w|0)){qa=xa}else{ub=J;break a}}if((R|0)==43){yDb(c[t>>2]|0,16,2309728,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==52){yDb(Ka,16,2334568,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==68){yDb(Qa,16,1918248,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==82){yDb(c[t>>2]|0,16,2193792,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==94){yDb(c[t>>2]|0,16,1971504,(vb=i,i=i+8|0,c[vb>>2]=$a,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==99){yDb(c[t>>2]|0,16,1942816,(vb=i,i=i+16|0,c[vb>>2]=sb+(Wa<<3),c[vb+8>>2]=tb+Va,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==103){yDb(c[t>>2]|0,16,2193792,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==113){yDb(c[t>>2]|0,16,1942816,(vb=i,i=i+16|0,c[vb>>2]=qb+(Wa<<3),c[vb+8>>2]=rb+Va,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==118){yDb(c[t>>2]|0,16,1942816,(vb=i,i=i+16|0,c[vb>>2]=ob+(Wa<<3),c[vb+8>>2]=pb+Va,vb)|0);i=vb;sa=-1;i=k;return sa|0}else if((R|0)==121){yDb(c[t>>2]|0,16,2056328,(vb=i,i=i+8|0,c[vb>>2]=Xa,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==129){i=k;return sa|0}}else{ub=g+8|0}}while(0);R=c[ub>>2]|0;vb=R&31;if((vb|0)==0){sa=0;i=k;return sa|0}Xa=32-vb|0;vb=-R|0;t=(c[g+16>>2]|0)-R|0;if((Xa|0)<(vb|0)){wb=vb}else{wb=(t|0)<(Xa|0)?t:Xa}c[ub>>2]=wb+R;sa=0;i=k;return sa|0}function t_(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0;g=i;i=i+1280|0;h=g|0;j=g+512|0;k=g+1024|0;c[h+256>>2]=4;c[j+256>>2]=0;c[h+260>>2]=24;c[j+260>>2]=0;c[h+264>>2]=44;c[j+264>>2]=0;c[h+268>>2]=1;c[j+268>>2]=3;c[h+272>>2]=2;c[j+272>>2]=3;c[h+276>>2]=3;c[j+276>>2]=3;l=a+8|0;m=c[l>>2]|0;n=a+16|0;o=c[n>>2]|0;p=a|0;a=c[p>>2]|0;q=a+(m>>>3)|0;r=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((m&7)>>>0)&15;q=m+4|0;c[l>>2]=o>>>0>q>>>0?q:o;o=r-1|0;if((o|0)>-1){q=r;r=64;m=70;s=0;t=o;o=a;u=a;v=a;w=a;x=a;while(1){a:do{if((r|0)<(m|0)){y=(t|0)==0;z=33-q|0;A=1<<t;B=r;C=m;D=s;E=r;F=o;G=u;H=v;I=w;J=x;while(1){K=C;L=D;M=E;N=F;O=G;P=H;b:while(1){Q=j+(M<<2)|0;R=h+(M<<2)|0;c:do{if(y){S=M;T=L;U=Q;V=R;W=N;while(1){X=S;Y=U;Z=V;d:while(1){while(1){if((c[Z>>2]|c[Y>>2]|0)==0){break}_=c[l>>2]|0;$=d[W+(_>>>3)|0]|0;aa=c[n>>2]|0;ca=((_|0)<(aa|0))+_|0;c[l>>2]=ca;if(($&1<<(_&7)|0)==0){break}da=c[Z>>2]|0;_=c[Y>>2]|0;if((_|0)==3){break d}else if((_|0)==2){ea=Y;fa=Z;ga=da;ha=X;ia=T;ja=22;break b}else if((_|0)==0){ka=Y;la=Z;ma=da;na=X;oa=T;ja=21;break b}else if((_|0)==1){pa=Y;qa=da;ra=X;sa=T;ta=W;ua=O;va=P;break c}}_=X+1|0;if((_|0)<(K|0)){X=_;Y=j+(_<<2)|0;Z=h+(_<<2)|0}else{wa=T;xa=K;ya=B;za=W;Aa=O;Ba=P;Ca=I;Da=J;break a}}_=(d[O+(ca>>>3)|0]|0)>>>((ca&7)>>>0);c[l>>2]=((ca|0)<(aa|0))+ca;c[b+((d[1694432+da|0]|0)<<2)>>2]=1-(_<<1&2);_=T+1|0;c[k+(T<<2)>>2]=da;c[Z>>2]=0;$=X+1|0;c[Y>>2]=0;if(($|0)<(K|0)){S=$;T=_;U=j+($<<2)|0;V=h+($<<2)|0;W=O}else{wa=_;xa=K;ya=B;za=O;Aa=O;Ba=P;Ca=I;Da=J;break a}}}else{W=M;V=L;U=Q;T=R;S=N;_=O;$=P;while(1){Ea=W;Fa=U;Ga=T;Ha=S;Ia=_;e:while(1){Ja=Ha;Ka=Ia;while(1){if((c[Ga>>2]|c[Fa>>2]|0)==0){La=Ja;Ma=Ka;break}Na=c[l>>2]|0;Oa=d[$+(Na>>>3)|0]|0;Pa=c[n>>2]|0;Qa=((Na|0)<(Pa|0))+Na|0;c[l>>2]=Qa;if((Oa&1<<(Na&7)|0)==0){La=$;Ma=$;break}Ra=c[Ga>>2]|0;Na=c[Fa>>2]|0;if((Na|0)==2){ea=Fa;fa=Ga;ga=Ra;ha=Ea;ia=V;ja=22;break b}else if((Na|0)==0){ka=Fa;la=Ga;ma=Ra;na=Ea;oa=V;ja=21;break b}else if((Na|0)==3){break e}else if((Na|0)==1){pa=Fa;qa=Ra;ra=Ea;sa=V;ta=$;ua=$;va=$;break c}else{Ja=$;Ka=$}}Ka=Ea+1|0;if((Ka|0)<(K|0)){Ea=Ka;Fa=j+(Ka<<2)|0;Ga=h+(Ka<<2)|0;Ha=La;Ia=Ma}else{wa=V;xa=K;ya=B;za=La;Aa=Ma;Ba=$;Ca=I;Da=J;break a}}Ia=I+(Qa>>>3)|0;Ha=(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)>>>((Qa&7)>>>0)<<z>>>(z>>>0);Ia=Qa+t|0;Y=Pa>>>0>Ia>>>0?Ia:Pa;c[l>>2]=Y;Ia=(d[I+(Y>>>3)|0]|0)>>>((Y&7)>>>0);c[l>>2]=((Y|0)<(Pa|0))+Y;Y=Ia&1;c[b+((d[1694432+Ra|0]|0)<<2)>>2]=((Ha|A)^-Y)+Y;Y=V+1|0;c[k+(V<<2)>>2]=Ra;c[Ga>>2]=0;Ha=Ea+1|0;c[Fa>>2]=0;if((Ha|0)<(K|0)){W=Ha;V=Y;U=j+(Ha<<2)|0;T=h+(Ha<<2)|0;S=I;_=I;$=I}else{wa=Y;xa=K;ya=B;za=I;Aa=I;Ba=I;Ca=I;Da=J;break a}}}}while(0);c[pa>>2]=2;c[h+(K<<2)>>2]=qa+4;R=K+1|0;c[j+(K<<2)>>2]=2;c[h+(R<<2)>>2]=qa+8;Q=K+2|0;c[j+(R<<2)>>2]=2;c[h+(Q<<2)>>2]=qa+12;c[j+(Q<<2)>>2]=2;Q=K+3|0;if((ra|0)<(Q|0)){K=Q;L=sa;M=ra;N=ta;O=ua;P=va}else{wa=sa;xa=Q;ya=B;za=ta;Aa=ua;Ba=va;Ca=I;Da=J;break a}}if((ja|0)==21){ja=0;c[la>>2]=ma+4;Sa=na;Ta=1;Ua=ka;Va=ma;Wa=oa}else if((ja|0)==22){ja=0;c[fa>>2]=0;Sa=ha+1|0;Ta=0;Ua=ea;Va=ga;Wa=ia}c[Ua>>2]=Ta;P=c[p>>2]|0;f:do{if(y){O=Va;N=B;M=Wa;L=1;while(1){Q=c[l>>2]|0;R=d[P+(Q>>>3)|0]|0;$=c[n>>2]|0;_=((Q|0)<($|0))+Q|0;c[l>>2]=_;if((R&1<<(Q&7)|0)==0){Q=(d[P+(_>>>3)|0]|0)>>>((_&7)>>>0);c[l>>2]=((_|0)<($|0))+_;c[b+((d[1694432+O|0]|0)<<2)>>2]=1-(Q<<1&2);c[k+(M<<2)>>2]=O;Xa=M+1|0;Ya=N}else{Q=N-1|0;c[h+(Q<<2)>>2]=O;c[j+(Q<<2)>>2]=3;Xa=M;Ya=Q}if((L|0)>=4){Za=Ya;_a=Xa;break f}O=O+1|0;N=Ya;M=Xa;L=L+1|0}}else{L=Va;M=B;N=Wa;O=1;while(1){Q=c[l>>2]|0;_=d[P+(Q>>>3)|0]|0;$=c[n>>2]|0;R=((Q|0)<($|0))+Q|0;c[l>>2]=R;if((_&1<<(Q&7)|0)==0){Q=P+(R>>>3)|0;_=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((R&7)>>>0)<<z>>>(z>>>0);Q=R+t|0;R=$>>>0>Q>>>0?Q:$;c[l>>2]=R;Q=(d[P+(R>>>3)|0]|0)>>>((R&7)>>>0);c[l>>2]=((R|0)<($|0))+R;R=Q&1;c[b+((d[1694432+L|0]|0)<<2)>>2]=((_|A)^-R)+R;c[k+(N<<2)>>2]=L;$a=N+1|0;ab=M}else{R=M-1|0;c[h+(R<<2)>>2]=L;c[j+(R<<2)>>2]=3;$a=N;ab=R}if((O|0)>=4){Za=ab;_a=$a;break f}L=L+1|0;M=ab;N=$a;O=O+1|0}}}while(0);if((Sa|0)<(K|0)){B=Za;C=K;D=_a;E=Sa;F=P;G=P;H=P;I=P;J=P}else{wa=_a;xa=K;ya=Za;za=P;Aa=P;Ba=P;Ca=P;Da=P;break}}}else{wa=s;xa=m;ya=r;za=o;Aa=u;Ba=v;Ca=w;Da=x}}while(0);J=t-1|0;if((J|0)>-1){q=t;r=ya;m=xa;s=wa;t=J;o=za;u=Aa;v=Ba;w=Ca;x=Da}else{bb=wa;cb=Da;break}}}else{bb=0;cb=a}do{if((f|0)==-1){a=c[l>>2]|0;Da=c[n>>2]|0;wa=cb+(a>>>3)|0;x=(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)>>>((a&7)>>>0)&15;wa=a+4|0;c[l>>2]=Da>>>0>wa>>>0?wa:Da;db=x}else{if(!(f>>>0>15>>>0)){db=f;break}yDb(0,16,2010272,(x=i,i=i+8|0,c[x>>2]=f,x)|0);i=x;i=g;return}}while(0);c[b>>2]=(ba(c[e+(db<<8)>>2]|0,c[b>>2]|0)|0)>>11;if((bb|0)>0){eb=0}else{i=g;return}do{f=c[k+(eb<<2)>>2]|0;l=b+((d[1694432+f|0]|0)<<2)|0;c[l>>2]=(ba(c[e+(db<<8)+(f<<2)>>2]|0,c[l>>2]|0)|0)>>11;eb=eb+1|0;}while((eb|0)<(bb|0));i=g;return}function u_(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;g=i;i=i+1280|0;h=g|0;j=g+512|0;k=g+1024|0;c[h+256>>2]=4;c[j+256>>2]=0;c[h+260>>2]=24;c[j+260>>2]=0;c[h+264>>2]=44;c[j+264>>2]=0;c[h+268>>2]=0;c[j+268>>2]=2;l=a+8|0;m=c[l>>2]|0;n=a+16|0;o=c[n>>2]|0;p=a|0;a=(c[p>>2]|0)+(m>>>3)|0;q=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>((m&7)>>>0)&7;a=m+3|0;c[l>>2]=o>>>0>a>>>0?a:o;o=f;f=1<<q;q=64;a=68;m=0;a:while(1){if((m|0)>0){r=-f|0;s=o;t=0;while(1){u=c[l>>2]|0;v=d[(c[p>>2]|0)+(u>>>3)|0]|0;c[l>>2]=((u|0)<(c[n>>2]|0))+u;if((v&1<<(u&7)|0)==0){w=s}else{u=e+(c[k+(t<<2)>>2]<<1)|0;v=b[u>>1]|0;b[u>>1]=(v<<16>>16<0?r:f)+(v&65535);v=s-1|0;if((v|0)<0){x=26;break a}else{w=v}}v=t+1|0;if((v|0)<(m|0)){s=w;t=v}else{y=m;z=q;A=a;B=q;C=w;break}}}else{y=m;z=q;A=a;B=q;C=o}b:while(1){D=y;t=z;s=A;E=C;c:while(1){r=t;F=s;d:while(1){G=r;e:while(1){v=(G|0)<(F|0);H=h+(G<<2)|0;I=j+(G<<2)|0;while(1){if(!v){break b}J=c[H>>2]|0;u=c[I>>2]|0;if((u|J|0)==0){break}K=c[l>>2]|0;L=c[p>>2]|0;M=d[L+(K>>>3)|0]|0;N=c[n>>2]|0;O=((K|0)<(N|0))+K|0;c[l>>2]=O;if((M&1<<(K&7)|0)==0){break}if((u|0)==2){x=17;break c}else if((u|0)==3){break d}else if((u|0)==1){break e}else if((u|0)==0){x=16;break c}}G=G+1|0}c[I>>2]=2;c[h+(F<<2)>>2]=J+4;v=F+1|0;c[j+(F<<2)>>2]=2;c[h+(v<<2)>>2]=J+8;u=F+2|0;c[j+(v<<2)>>2]=2;c[h+(u<<2)>>2]=J+12;c[j+(u<<2)>>2]=2;r=G;F=F+3|0}r=d[1694432+J|0]|0;c[k+(D<<2)>>2]=r;u=(d[L+(O>>>3)|0]|0)>>>((O&7)>>>0);c[l>>2]=((O|0)<(N|0))+O;v=u&1;b[e+(r<<1)>>1]=(f^-v)+v;c[H>>2]=0;c[I>>2]=0;v=E-1|0;if((v|0)<0){x=26;break a}else{D=D+1|0;t=G+1|0;s=F;E=v}}if((x|0)==16){x=0;c[H>>2]=J+4;P=G;Q=1}else if((x|0)==17){x=0;c[H>>2]=0;P=G+1|0;Q=0}c[I>>2]=Q;s=E;t=0;v=J;r=B;u=D;K=O;while(1){M=d[L+(K>>>3)|0]|0;R=((K|0)<(N|0))+K|0;c[l>>2]=R;if((M&1<<(K&7)|0)==0){M=d[1694432+v|0]|0;c[k+(u<<2)>>2]=M;S=(d[L+(R>>>3)|0]|0)>>>((R&7)>>>0);T=((R|0)<(N|0))+R|0;c[l>>2]=T;U=S&1;b[e+(M<<1)>>1]=(f^-U)+U;U=s-1|0;if((U|0)<0){x=26;break a}else{V=u+1|0;W=r;X=U;Y=T}}else{T=r-1|0;c[h+(T<<2)>>2]=v;c[j+(T<<2)>>2]=3;V=u;W=T;X=s;Y=R}R=t+1|0;if((R|0)<4){s=X;t=R;v=v+1|0;r=W;u=V;K=Y}else{y=V;z=P;A=F;B=W;C=X;continue b}}}K=f>>1;if((K|0)==0){x=26;break}else{o=E;f=K;q=B;a=F;m=D}}if((x|0)==26){i=g;return}}function v_(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;j=g+32|0;k=c[j>>2]|0;if((k|0)==0){l=0;i=h;return l|0}if(k>>>0>(c[g+36>>2]|0)>>>0){l=0;i=h;return l|0}m=c[g>>2]|0;n=f+8|0;o=c[n>>2]|0;p=f+16|0;q=c[p>>2]|0;r=f|0;f=c[r>>2]|0;s=f+(o>>>3)|0;t=32-m|0;u=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((o&7)>>>0)<<t>>>(t>>>0);t=o+m|0;m=q>>>0>t>>>0?t:q;c[n>>2]=m;if((u|0)==0){c[j>>2]=0;l=0;i=h;return l|0}t=k+u|0;if(t>>>0>(c[g+28>>2]|0)>>>0){yDb(e,16,2290912,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;l=-1094995529;i=h;return l|0}e=d[f+(m>>>3)|0]|0;o=((m|0)<(q|0))+m|0;c[n>>2]=o;if((e&1<<(m&7)|0)!=0){m=f+(o>>>3)|0;f=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((o&7)>>>0);m=o+4|0;c[n>>2]=q>>>0>m>>>0?m:q;TGb(k|0,f&15|0,u|0)|0;c[j>>2]=(c[j>>2]|0)+u;l=0;i=h;return l|0}if((u|0)<=0){l=0;i=h;return l|0}u=g+4|0;f=t;q=0;m=k;a:while(1){k=m;while(1){o=c[u>>2]|0;e=c[8865532+(o*20|0)>>2]|0;s=c[n>>2]|0;v=c[p>>2]|0;w=(c[r>>2]|0)+(s>>>3)|0;x=32-(c[8865528+(o*20|0)>>2]|0)|0;o=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((s&7)>>>0)<<x>>>(x>>>0);x=b[e+(o<<2)>>1]|0;w=(b[e+(o<<2)+2>>1]|0)+s|0;c[n>>2]=v>>>0>w>>>0?w:v;y=a[g+8+x|0]|0;if((y&255)>>>0<12>>>0){break}x=d[1694496+((y&255)-12)|0]|0;if((f-k|0)<(x|0)){l=-1094995529;z=16;break a}TGb(k|0,q|0,x|0)|0;v=(c[j>>2]|0)+x|0;c[j>>2]=v;if(v>>>0<t>>>0){k=v}else{l=0;z=16;break a}}c[j>>2]=k+1;a[k]=y;v=c[j>>2]|0;if(v>>>0<t>>>0){q=y;m=v}else{l=0;z=16;break}}if((z|0)==16){i=h;return l|0}return 0}function w_(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;j=g+32|0;k=c[j>>2]|0;if((k|0)==0){l=0;i=h;return l|0}if(k>>>0>(c[g+36>>2]|0)>>>0){l=0;i=h;return l|0}m=c[g>>2]|0;n=f+8|0;o=c[n>>2]|0;p=f+16|0;q=c[p>>2]|0;r=f|0;f=c[r>>2]|0;s=f+(o>>>3)|0;t=32-m|0;u=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((o&7)>>>0)<<t>>>(t>>>0);t=o+m|0;m=q>>>0>t>>>0?t:q;c[n>>2]=m;if((u|0)==0){c[j>>2]=0;l=0;i=h;return l|0}t=k+u|0;if(t>>>0>(c[g+28>>2]|0)>>>0){yDb(e,16,2354872,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;l=-1094995529;i=h;return l|0}e=d[f+(m>>>3)|0]|0;o=((m|0)<(q|0))+m|0;c[n>>2]=o;if((e&1<<(m&7)|0)!=0){m=f+(o>>>3)|0;e=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((o&7)>>>0)&15;m=o+4|0;s=q>>>0>m>>>0?m:q;c[n>>2]=s;if((e|0)==0){v=e&255}else{m=(d[f+(s>>>3)|0]|0)>>>((s&7)>>>0);c[n>>2]=((s|0)<(q|0))+s;s=m&1;v=(e^-s)+s&255}TGb(k|0,v|0,u|0)|0;c[j>>2]=(c[j>>2]|0)+u;l=0;i=h;return l|0}if((u|0)<=0){l=0;i=h;return l|0}u=g+4|0;v=k;k=o;o=q;q=f;while(1){f=c[u>>2]|0;s=c[8865532+(f*20|0)>>2]|0;e=q+(k>>>3)|0;m=32-(c[8865528+(f*20|0)>>2]|0)|0;f=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>((k&7)>>>0)<<m>>>(m>>>0);m=b[s+(f<<2)>>1]|0;e=(b[s+(f<<2)+2>>1]|0)+k|0;f=o>>>0>e>>>0?e:o;c[n>>2]=f;e=a[g+8+m|0]|0;if(e<<24>>24==0){w=0}else{m=(d[q+(f>>>3)|0]|0)>>>((f&7)>>>0);c[n>>2]=((f|0)<(o|0))+f;f=m&1;w=(e&255^-f)+f&255}c[j>>2]=v+1;a[v]=w;f=c[j>>2]|0;if(!(f>>>0<t>>>0)){l=0;break}v=f;k=c[n>>2]|0;o=c[p>>2]|0;q=c[r>>2]|0}i=h;return l|0}function x_(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;h=i;j=f+32|0;k=c[j>>2]|0;l=c[f+28>>2]|0;if((k|0)==0){m=0;i=h;return m|0}if(k>>>0>(c[f+36>>2]|0)>>>0){m=0;i=h;return m|0}n=c[f>>2]|0;f=e+8|0;o=c[f>>2]|0;p=c[e+16>>2]|0;q=c[e>>2]|0;e=q+(o>>>3)|0;r=32-n|0;s=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>((o&7)>>>0)<<r>>>(r>>>0);r=o+n|0;n=p>>>0>r>>>0?r:p;c[f>>2]=n;if((s|0)==0){c[j>>2]=0;m=0;i=h;return m|0}r=11-g|0;o=q+(n>>>3)|0;e=32-r|0;t=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((n&7)>>>0)<<e>>>(e>>>0);e=n+r|0;r=p>>>0>e>>>0?e:p;c[f>>2]=r;if((t|0)==0|(g|0)==0){u=t;v=r}else{g=(d[q+(r>>>3)|0]|0)>>>((r&7)>>>0);e=((r|0)<(p|0))+r|0;c[f>>2]=e;r=g&1;u=(t^-r)+r|0;v=e}e=l;if((e-k|0)<2){m=-1094995529;i=h;return m|0}l=k+2|0;b[k>>1]=u;k=s-1|0;a:do{if((k|0)>0){r=0;t=u;g=l;n=-s|0;o=v;b:while(1){w=(n|0)>-9;x=k-r|0;y=(x|0)>8?8:x;if((e-g>>1|0)<(y|0)){m=-1094995529;z=25;break}x=q+(o>>>3)|0;A=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((o&7)>>>0)&15;x=o+4|0;B=p>>>0>x>>>0?x:p;c[f>>2]=B;x=(y|0)>0;do{if((A|0)==0){if(!x){C=g;D=t;E=B;break}F=t&65535;G=0;H=g;while(1){b[H>>1]=F;I=G+1|0;if((I|0)<(y|0)){G=I;H=H+2|0}else{break}}C=g+((w?~n:8)<<1)|0;D=t;E=B}else{if(!x){C=g;D=t;E=B;break}H=32-A|0;G=0;F=t;I=g;J=B;while(1){K=q+(J>>>3)|0;L=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((J&7)>>>0)<<H>>>(H>>>0);K=J+A|0;M=p>>>0>K>>>0?K:p;c[f>>2]=M;if((L|0)==0){N=0;O=M}else{K=(d[q+(M>>>3)|0]|0)>>>((M&7)>>>0);P=((M|0)<(p|0))+M|0;c[f>>2]=P;M=K&1;N=(L^-M)+M|0;O=P}Q=N+F|0;b[I>>1]=Q;if((Q+32768|0)>>>0>65535>>>0){break b}P=I+2|0;M=G+1|0;if((M|0)<(y|0)){G=M;F=Q;I=P;J=O}else{C=P;D=Q;E=O;break}}}}while(0);y=r+8|0;if((y|0)<(k|0)){r=y;t=D;g=C;n=n+8|0;o=E}else{R=C;break a}}if((z|0)==25){i=h;return m|0}yDb(a,16,1897488,(o=i,i=i+8|0,c[o>>2]=Q,o)|0);i=o;m=-1094995529;i=h;return m|0}else{R=l}}while(0);c[j>>2]=R;m=0;i=h;return m|0}function y_(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=i;i=i+32|0;g=f|0;h=g|0;TGb(h|0,0,16)|0;j=f+16|0;k=b+8|0;l=c[k>>2]|0;m=b+16|0;n=c[m>>2]|0;o=b|0;b=c[o>>2]|0;p=b+(l>>>3)|0;q=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((l&7)>>>0)&15;p=l+4|0;c[k>>2]=n>>>0>p>>>0?p:n;c[e>>2]=q;if((q|0)==0){a[e+4|0]=0;a[e+5|0]=1;a[e+6|0]=2;a[e+7|0]=3;a[e+8|0]=4;a[e+9|0]=5;a[e+10|0]=6;a[e+11|0]=7;a[e+12|0]=8;a[e+13|0]=9;a[e+14|0]=10;a[e+15|0]=11;a[e+16|0]=12;a[e+17|0]=13;a[e+18|0]=14;a[e+19|0]=15;i=f;return}q=c[k>>2]|0;n=d[b+(q>>>3)|0]|0;p=c[m>>2]|0;l=((q|0)<(p|0))+q|0;c[k>>2]=l;r=b+(l>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((l&7)>>>0);if((n&1<<(q&7)|0)!=0){q=s&7;n=l+3|0;r=p>>>0>n>>>0?n:p;c[k>>2]=r;n=0;t=r;r=p;u=b;while(1){b=u+(t>>>3)|0;v=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((t&7)>>>0);b=t+4|0;c[k>>2]=r>>>0>b>>>0?b:r;a[e+4+n|0]=v&15;a[g+(v&15)|0]=1;v=n+1|0;if((v|0)>(q|0)){w=0;x=q;break}n=v;t=c[k>>2]|0;r=c[m>>2]|0;u=c[o>>2]|0}while(1){if((a[g+w|0]|0)==0){u=x+1|0;a[e+4+u|0]=w;y=u}else{y=x}u=w+1|0;if((u|0)<16&(y|0)<15){w=u;x=y}else{break}}i=f;return}y=l+2|0;c[k>>2]=p>>>0>y>>>0?y:p;a[h]=0;a[g+1|0]=1;a[g+2|0]=2;a[g+3|0]=3;a[g+4|0]=4;a[g+5|0]=5;a[g+6|0]=6;a[g+7|0]=7;a[g+8|0]=8;a[g+9|0]=9;a[g+10|0]=10;a[g+11|0]=11;a[g+12|0]=12;a[g+13|0]=13;a[g+14|0]=14;a[g+15|0]=15;g=s&3;s=0;p=j;j=h;while(1){h=1<<s;y=h<<1;l=0;do{x=h;w=j+(l+h)|0;u=h;r=j+l|0;t=p+l|0;while(1){z=t+1|0;n=c[k>>2]|0;q=d[(c[o>>2]|0)+(n>>>3)|0]|0;c[k>>2]=((n|0)<(c[m>>2]|0))+n;if((q&1<<(n&7)|0)==0){a[t]=a[r]|0;A=x;B=w;C=u-1|0;D=r+1|0}else{a[t]=a[w]|0;A=x-1|0;B=w+1|0;C=u;D=r}E=(C|0)==0;F=(A|0)==0;if(E|F){break}else{x=A;w=B;u=C;r=D;t=z}}if(E){G=z}else{r=z;u=D;w=C;while(1){x=w-1|0;a[r]=a[u]|0;if((x|0)==0){break}else{r=r+1|0;u=u+1|0;w=x}}G=t+(C+1)|0}if(!F){w=G;u=B;r=A;while(1){x=r-1|0;a[w]=a[u]|0;if((x|0)==0){break}else{w=w+1|0;u=u+1|0;r=x}}}l=l+y|0;}while((l|0)<16);l=s+1|0;if((l|0)>(g|0)){break}else{y=p;p=j;s=l;j=y}}UGb(e+4|0,p|0,16)|0;i=f;return}function z_(b){b=b|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0;f=i;h=c[b+60>>2]|0;j=c[b+412>>2]|0;if((j|0)<22050){k=9}else{k=(j|0)<44100?10:11}l=b+416|0;m=c[l>>2]|0;if((m-1|0)>>>0>1>>>0){yDb(b,16,1971472,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-1094995529;i=f;return o|0}n=(m|0)==1;m=b+448|0;c[m>>2]=n?4:3;c[m+4>>2]=n?0:0;if((c[b+100>>2]|0)>3){p=(a[(c[b+96>>2]|0)+3|0]|0)==98|0}else{p=0}c[h+20>>2]=p;n=b+12|0;m=(c[(c[n>>2]|0)+12>>2]|0)==86064;do{if(m){c[b+420>>2]=3;q=ba(c[l>>2]|0,j)|0;c[h+28>>2]=1;if((p|0)!=0){r=k;s=q;t=1;break}u=c[l>>2]|0;v=u>>>0>65535>>>0;w=v?u>>>16:u;u=v?16:0;if((w&65280|0)==0){x=u;y=w}else{x=u|8;y=w>>>8}r=x+k+(d[1191992+y|0]|0)|0;s=q;t=1}else{q=c[l>>2]|0;c[h+28>>2]=q;c[b+420>>2]=8;r=k;s=j;t=q}}while(0);j=1<<r;k=h+32|0;c[k>>2]=j;b=(j|0)/16|0;c[h+36>>2]=b;c[h+40>>2]=ba(j-b|0,t)|0;t=(s+1|0)/2|0;z=+(j|0);A=+R(z)*32768.0;if(m){B=2.0/A;g[h+52>>2]=B;C=B}else{B=z/A;g[h+52>>2]=B;C=B}m=h+52|0;j=0;B=C;while(1){g[4601424+(j<<2)>>2]=+_(+(j|0)*.15289165079593658)*B;s=j+1|0;if((s|0)>=96){break}j=s;B=+g[m>>2]}m=h+44|0;j=1;while(1){c[m>>2]=j;if((j|0)>=25){break}if((t|0)>(e[1082480+(j-1<<1)>>1]|0)){j=j+1|0}else{break}}s=WDb((j<<2)+4|0)|0;j=s;c[h+48>>2]=j;if((s|0)==0){o=-12;i=f;return o|0}c[j>>2]=2;s=c[m>>2]|0;if((s|0)>1){b=1;while(1){c[j+(b<<2)>>2]=((ba(e[1082480+(b-1<<1)>>1]|0,c[k>>2]|0)|0)/(t|0)|0)&-2;l=b+1|0;y=c[m>>2]|0;if((l|0)<(y|0)){b=l}else{D=y;break}}}else{D=s}c[j+(D<<2)>>2]=c[k>>2];c[h+24>>2]=1;k=h+18500|0;if((c[(c[n>>2]|0)+12>>2]|0)==86064){BUa(k,r,3)|0;o=0;i=f;return o|0}else{U0(k,r,1)|0;o=0;i=f;return o|0}return 0}function A_(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var h=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0.0,U=0.0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0.0,ea=0,fa=0,ga=0,ha=0.0,ia=0,ja=0,ka=0,la=0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0.0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;h=i;i=i+104|0;j=h|0;l=c[a+60>>2]|0;m=l;n=b;o=l+8|0;p=l+12|0;do{if((c[p>>2]|0)==(c[o>>2]|0)){q=f+28|0;r=c[q>>2]|0;if((r|0)==0){c[e>>2]=0;s=0;i=h;return s|0}if((r|0)<4){yDb(a,16,2056304,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}u=l+18496|0;v=XDb(c[u>>2]|0,r+16|0)|0;if((v|0)==0){s=-12;i=h;return s|0}TGb(v+(c[q>>2]|0)|0,0,16)|0;c[u>>2]=v;UGb(v|0,c[f+24>>2]|0,c[q>>2]|0)|0;v=c[u>>2]|0;u=c[q>>2]|0;r=u>>>0>268435455>>>0?-8:u<<3;u=r>>>0>2147483639>>>0|(v|0)==0;w=u?0:v;v=u?0:r;c[l>>2]=w;c[p>>2]=v;r=v+8|0;c[l+16>>2]=r;c[l+4>>2]=w+(v>>3);c[o>>2]=0;if(u){s=u?-1094995529:0;i=h;return s|0}else{u=c[q>>2]|0;c[o>>2]=(r|0)<32?r:32;x=u;break}}else{x=0}}while(0);f=l+32|0;u=b+76|0;c[u>>2]=c[f>>2];r=_$a(a,n,0)|0;if((r|0)<0){s=r;i=h;return s|0}r=c[b+64>>2]|0;b=(c[(c[a+12>>2]|0)+12>>2]|0)==86065;if(b){n=c[l+16>>2]|0;q=(c[o>>2]|0)+2|0;c[o>>2]=n>>>0>q>>>0?q:n}n=l+28|0;do{if((c[n>>2]|0)>0){q=l+20|0;v=l+16|0;w=l;y=l+52|0;z=l+44|0;A=j|0;B=l+18500|0;C=B;D=l+18604|0;E=B;B=l+18584|0;F=l+48|0;G=0;do{H=c[r+(G<<2)>>2]|0;I=H;J=c[o>>2]|0;K=c[p>>2]|0;L=K-J|0;if((c[q>>2]|0)==0){if((L|0)<58){M=61;break}N=c[v>>2]|0;O=c[w>>2]|0;P=O+(J>>>3)|0;Q=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((J&7)>>>0)&31;P=J+5|0;R=N>>>0>P>>>0?P:N;c[o>>2]=R;P=O+(R>>>3)|0;O=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((R&7)>>>0)&8388607;P=R+23|0;c[o>>2]=N>>>0>P>>>0?P:N;S=+tGb(+(O>>>0>>>0),Q-23|0);Q=c[o>>2]|0;O=c[w>>2]|0;N=d[O+(Q>>>3)|0]|0;P=c[v>>2]|0;R=((Q|0)<(P|0))+Q|0;c[o>>2]=R;if((N&1<<(Q&7)|0)==0){T=S}else{T=-0.0-S}g[I>>2]=T*+g[y>>2];Q=O+(R>>>3)|0;N=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((R&7)>>>0)&31;Q=R+5|0;R=P>>>0>Q>>>0?Q:P;c[o>>2]=R;Q=O+(R>>>3)|0;O=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((R&7)>>>0)&8388607;Q=R+23|0;c[o>>2]=P>>>0>Q>>>0?Q:P;S=+tGb(+(O>>>0>>>0),N-23|0);N=c[o>>2]|0;O=c[w>>2]|0;P=d[O+(N>>>3)|0]|0;Q=c[v>>2]|0;R=((N|0)<(Q|0))+N|0;c[o>>2]=R;if((P&1<<(N&7)|0)==0){U=S}else{U=-0.0-S}g[H+4>>2]=U*+g[y>>2];V=R;W=c[p>>2]|0;X=Q;Y=O}else{if((L|0)<64){M=61;break}L=c[v>>2]|0;O=c[w>>2]|0;Q=O+(J>>>3)|0;R=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((J&7)>>>0)&65535;Q=J+16|0;J=L>>>0>Q>>>0?Q:L;c[o>>2]=J;Q=O+(J>>>3)|0;N=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((J&7)>>>0);Q=J+16|0;J=L>>>0>Q>>>0?Q:L;c[o>>2]=J;g[I>>2]=+g[y>>2]*(c[k>>2]=N<<16|R,+g[k>>2]);R=O+(J>>>3)|0;N=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((J&7)>>>0)&65535;R=J+16|0;J=L>>>0>R>>>0?R:L;c[o>>2]=J;R=O+(J>>>3)|0;Q=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((J&7)>>>0);R=J+16|0;J=L>>>0>R>>>0?R:L;c[o>>2]=J;g[H+4>>2]=+g[y>>2]*(c[k>>2]=Q<<16|N,+g[k>>2]);V=J;W=K;X=L;Y=O}O=c[z>>2]|0;if((W-V|0)<(O<<3|0)){M=61;break}if((O|0)>0){L=0;K=V;do{J=Y+(K>>>3)|0;N=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((K&7)>>>0)&255;J=K+8|0;K=X>>>0>J>>>0?J:X;c[o>>2]=K;g[j+(L<<2)>>2]=+g[4601424+((N>>>0>95>>>0?95:N)<<2)>>2];L=L+1|0;}while((L|0)<(O|0))}O=c[f>>2]|0;if((O|0)>2){S=+g[A>>2];L=0;K=2;N=O;while(1){do{if((c[q>>2]|0)==0){O=c[o>>2]|0;J=c[w>>2]|0;Q=d[J+(O>>>3)|0]|0;H=c[v>>2]|0;R=((O|0)<(H|0))+O|0;c[o>>2]=R;if((Q&1<<(O&7)|0)==0){Z=K+8|0;_=R;$=H;aa=J;break}else{O=J+(R>>>3)|0;Q=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((R&7)>>>0)&15;O=R+4|0;R=H>>>0>O>>>0?O:H;c[o>>2]=R;Z=((d[547512+Q|0]|0)<<3)+K|0;_=R;$=H;aa=J;break}}else{Z=K+16|0;_=c[o>>2]|0;$=c[v>>2]|0;aa=c[w>>2]|0}}while(0);J=(Z|0)>(N|0)?N:Z;H=aa+(_>>>3)|0;R=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((_&7)>>>0)&15;H=_+4|0;Q=$>>>0>H>>>0?H:$;c[o>>2]=Q;do{if((R|0)==0){TGb(I+(K<<2)|0,0,J-K<<2|0)|0;H=c[F>>2]|0;if((c[H+(L<<2)>>2]|0)>>>0<J>>>0){O=L;while(1){ca=O+1|0;if((c[H+(ca<<2)>>2]|0)>>>0<J>>>0){O=ca}else{break}}da=+g[j+(O<<2)>>2];ea=ca}else{da=S;ea=L}fa=J;ga=ea;ha=da;ia=c[f>>2]|0}else{if((K|0)>=(J|0)){fa=K;ga=L;ha=S;ia=N;break}H=32-R|0;P=~Z;ja=~N;ka=(P|0)>(ja|0);la=c[F>>2]|0;ma=S;na=L;oa=K;pa=Q;while(1){if((c[la+(na<<2)>>2]|0)==(oa|0)){qa=na+1|0;ra=+g[j+(na<<2)>>2]}else{qa=na;ra=ma}sa=aa+(pa>>>3)|0;ta=(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)>>>((pa&7)>>>0)<<H>>>(H>>>0);sa=pa+R|0;ua=$>>>0>sa>>>0?sa:$;c[o>>2]=ua;do{if((ta|0)==0){g[I+(oa<<2)>>2]=0.0;va=ua}else{sa=d[aa+(ua>>>3)|0]|0;wa=((ua|0)<($|0))+ua|0;c[o>>2]=wa;if((sa&1<<(ua&7)|0)==0){g[I+(oa<<2)>>2]=ra*+(ta|0);va=wa;break}else{g[I+(oa<<2)>>2]=+(ta|0)*(-0.0-ra);va=wa;break}}}while(0);ta=oa+1|0;if((ta|0)<(J|0)){ma=ra;na=qa;oa=ta;pa=va}else{break}}fa=~(ka?P:ja);ga=qa;ha=ra;ia=N}}while(0);if((fa|0)<(ia|0)){S=ha;L=ga;K=fa;N=ia}else{break}}}if(b){g[I>>2]=+g[I>>2]*2.0;ne[c[D>>2]&1023](C,I)}else{ne[c[B>>2]&1023](E,I)}G=G+1|0;xa=c[n>>2]|0;}while((G|0)<(xa|0));if((M|0)==61){yDb(a,16,2010248,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}if((xa|0)<=0){M=15;break}G=l+36|0;E=l+24|0;B=0;C=xa;while(1){D=c[G>>2]|0;F=ba(D,C)|0;w=r+(B<<2)|0;if((c[E>>2]|0)==0&(D|0)>0){v=c[w>>2]|0;S=+(F|0);q=0;A=B;while(1){z=v+(q<<2)|0;g[z>>2]=(+(F-A|0)*+g[m+16448+(B<<10)+(q<<2)>>2]+ +(A|0)*+g[z>>2])/S;z=q+1|0;if((z|0)<(D|0)){q=z;A=A+C|0}else{break}}}UGb(m+16448+(B<<10)|0,(c[w>>2]|0)+((c[f>>2]|0)-D<<2)|0,D<<2)|0;A=B+1|0;q=c[n>>2]|0;if((A|0)<(q|0)){B=A;C=q}else{ya=E;break}}}else{M=15}}while(0);if((M|0)==15){ya=l+24|0}c[ya>>2]=0;ya=c[o>>2]|0;M=-ya&31;if((M|0)!=0){n=c[l+16>>2]|0;f=M+ya|0;c[o>>2]=n>>>0>f>>>0?f:n}c[u>>2]=(c[l+40>>2]|0)/(c[a+416>>2]|0)|0;c[e>>2]=1;s=x;i=h;return s|0}function B_(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;$Db(b+48|0);$Db(b+18496|0);d=b+18500|0;if((c[(c[a+12>>2]|0)+12>>2]|0)==86064){DUa(d);return 0}else{_0(d);return 0}return 0}function C_(a){a=a|0;c[a+4>>2]=870;c[a>>2]=826;c[a+8>>2]=2058;return}function D_(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;i=i+256|0;h=g|0;G_(h|0,f);G_(h+4|0,f+4|0);G_(h+8|0,f+8|0);G_(h+12|0,f+12|0);G_(h+16|0,f+16|0);G_(h+20|0,f+20|0);G_(h+24|0,f+24|0);G_(h+28|0,f+28|0);j=0;while(1){k=j<<3;l=c[h+(k<<2)>>2]|0;m=k|4;n=c[h+(m<<2)>>2]|0;o=n+l|0;p=k|2;q=c[h+(p<<2)>>2]|0;r=k|6;s=c[h+(r<<2)>>2]|0;t=s+q|0;u=((q-s|0)*2896|0)>>11;s=k|5;q=c[h+(s<<2)>>2]|0;v=k|3;w=c[h+(v<<2)>>2]|0;x=w+q|0;y=q-w|0;w=k|1;q=c[h+(w<<2)>>2]|0;z=k|7;A=c[h+(z<<2)>>2]|0;B=A+q|0;C=q-A|0;A=B+x|0;q=((C+y|0)*3784|0)>>11;D=q+(((y*-5352|0)>>11)-A)|0;y=(((B-x|0)*2896|0)>>11)-D|0;x=y+(((C*2217|0)>>11)-q)|0;q=o+127+t|0;c[f+(k<<2)>>2]=A+q>>8;k=l-n+127|0;n=k-t+u|0;c[f+(w<<2)>>2]=D+n>>8;w=k+t-u|0;c[f+(p<<2)>>2]=y+w>>8;p=o-t+127|0;c[f+(v<<2)>>2]=p-x>>8;c[f+(m<<2)>>2]=x+p>>8;c[f+(s<<2)>>2]=w-y>>8;c[f+(r<<2)>>2]=n-D>>8;c[f+(z<<2)>>2]=q-A>>8;A=j+1|0;if((A|0)<8){j=A}else{E=b;F=f;G=0;break}}while(1){a[E]=(d[E]|0)+(c[F>>2]|0);f=E+1|0;a[f]=(d[f]|0)+(c[F+4>>2]|0);f=E+2|0;a[f]=(d[f]|0)+(c[F+8>>2]|0);f=E+3|0;a[f]=(d[f]|0)+(c[F+12>>2]|0);f=E+4|0;a[f]=(d[f]|0)+(c[F+16>>2]|0);f=E+5|0;a[f]=(d[f]|0)+(c[F+20>>2]|0);f=E+6|0;a[f]=(d[f]|0)+(c[F+24>>2]|0);f=E+7|0;a[f]=(d[f]|0)+(c[F+28>>2]|0);f=G+1|0;if((f|0)<8){E=E+e|0;F=F+32|0;G=f}else{break}}i=g;return}function E_(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+256|0;g=f|0;G_(g|0,e);G_(g+4|0,e+4|0);G_(g+8|0,e+8|0);G_(g+12|0,e+12|0);G_(g+16|0,e+16|0);G_(g+20|0,e+20|0);G_(g+24|0,e+24|0);G_(g+28|0,e+28|0);e=0;do{h=e<<3;j=c[g+(h<<2)>>2]|0;k=c[g+((h|4)<<2)>>2]|0;l=k+j|0;m=j-k|0;k=c[g+((h|2)<<2)>>2]|0;j=c[g+((h|6)<<2)>>2]|0;n=j+k|0;o=((k-j|0)*2896|0)>>11;j=c[g+((h|5)<<2)>>2]|0;k=c[g+((h|3)<<2)>>2]|0;p=k+j|0;q=j-k|0;k=c[g+((h|1)<<2)>>2]|0;j=c[g+((h|7)<<2)>>2]|0;h=j+k|0;r=k-j|0;j=h+p|0;k=((r+q|0)*3784|0)>>11;s=k+(((q*-5352|0)>>11)-j)|0;q=(((h-p|0)*2896|0)>>11)-s|0;p=((r*2217|0)>>11)-k+q|0;k=n+l+127|0;r=ba(e,d)|0;a[b+r|0]=(k+j|0)>>>8;h=m-n+o+127|0;a[b+(r+1)|0]=(h+s|0)>>>8;t=m-o+n+127|0;a[b+(r+2)|0]=(t+q|0)>>>8;o=l-n+127|0;a[b+(r+3)|0]=(o-p|0)>>>8;a[b+(r+4)|0]=(o+p|0)>>>8;a[b+(r+5)|0]=(t-q|0)>>>8;a[b+(r+6)|0]=(h-s|0)>>>8;a[b+(r+7)|0]=(k-j|0)>>>8;e=e+1|0;}while((e|0)<8);i=f;return}function F_(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=a;a=0;g=c;h=c+e|0;while(1){c=(d[f]|0)*257&65535;b[h>>1]=c;b[g>>1]=c;c=(d[f+1|0]|0)*257&65535;b[h+2>>1]=c;b[g+2>>1]=c;c=(d[f+2|0]|0)*257&65535;b[h+4>>1]=c;b[g+4>>1]=c;c=(d[f+3|0]|0)*257&65535;b[h+6>>1]=c;b[g+6>>1]=c;c=(d[f+4|0]|0)*257&65535;b[h+8>>1]=c;b[g+8>>1]=c;c=(d[f+5|0]|0)*257&65535;b[h+10>>1]=c;b[g+10>>1]=c;c=(d[f+6|0]|0)*257&65535;b[h+12>>1]=c;b[g+12>>1]=c;c=(d[f+7|0]|0)*257&65535;b[h+14>>1]=c;b[g+14>>1]=c;c=a+1|0;if((c|0)<8){f=f+8|0;a=c;g=g+(e<<1)|0;h=h+(e<<1)|0}else{break}}return}function G_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[b+32>>2]|0;e=c[b+64>>2]|0;f=c[b+96>>2]|0;g=c[b+128>>2]|0;h=c[b+160>>2]|0;i=c[b+192>>2]|0;j=c[b+224>>2]|0;k=c[b>>2]|0;if((e|d|f|g|h|i|j|0)==0){c[a+224>>2]=k;c[a+192>>2]=k;c[a+160>>2]=k;c[a+128>>2]=k;c[a+96>>2]=k;c[a+64>>2]=k;c[a+32>>2]=k;c[a>>2]=k;return}else{b=k+g|0;l=k-g|0;g=i+e|0;k=((e-i|0)*2896|0)>>11;i=h+f|0;e=h-f|0;f=j+d|0;h=d-j|0;j=f+i|0;d=((h+e|0)*3784|0)>>11;m=d+(((e*-5352|0)>>11)-j)|0;e=(((f-i|0)*2896|0)>>11)-m|0;i=((h*2217|0)>>11)-d+e|0;d=b+g|0;c[a>>2]=d+j;h=k-g+l|0;c[a+32>>2]=m+h;f=l-k+g|0;c[a+64>>2]=e+f;k=b-g|0;c[a+96>>2]=k-i;c[a+128>>2]=i+k;c[a+160>>2]=f-e;c[a+192>>2]=h-m;c[a+224>>2]=d-j;return}}function H_(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;e=c[a+60>>2]|0;c[a+140>>2]=11;f=c[a+96>>2]|0;do{if((f|0)==0){c[e+72>>2]=8;c[e+68>>2]=0;g=0;h=0;j=7}else{k=d[f]|0;c[e+72>>2]=k;l=d[f+1|0]|0;c[e+68>>2]=l;m=f+2|0;if((c[a+100>>2]|0)<(-(l&1)<<4&48|(k&-(l>>>1&1))<<8|2|0)){yDb(a,16,1971448,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=b;return o|0}k=e+68|0;if((l&1|0)==0){g=l;h=m;j=7;break}l=e+4|0;p=m;m=0;while(1){q=(d[p+1|0]|0)<<8|(d[p]|0)<<16|(d[p+2|0]|0);c[l+(m<<2)>>2]=q<<2|q>>>4&197379|-16777216;q=m+1|0;if((q|0)<16){p=p+3|0;m=q}else{break}}r=f+50|0;s=c[k>>2]|0}}while(0);if((j|0)==7){c[e+4>>2]=c[311036]|-16777216;c[e+8>>2]=c[311037]|-16777216;c[e+12>>2]=c[311038]|-16777216;c[e+16>>2]=c[311039]|-16777216;c[e+20>>2]=c[311040]|-16777216;c[e+24>>2]=c[311041]|-16777216;c[e+28>>2]=c[311042]|-16777216;c[e+32>>2]=c[311043]|-16777216;c[e+36>>2]=c[311044]|-16777216;c[e+40>>2]=c[311045]|-16777216;c[e+44>>2]=c[311046]|-16777216;c[e+48>>2]=c[311047]|-16777216;c[e+52>>2]=c[311048]|-16777216;c[e+56>>2]=c[311049]|-16777216;c[e+60>>2]=c[311050]|-16777216;c[e+64>>2]=c[311051]|-16777216;r=h;s=g}do{if((s&2|0)==0){g=e+72|0;h=c[g>>2]|0;if((h|0)==16){c[e+76>>2]=1739472;break}else if((h|0)!=8){yDb(a,24,1942784,(n=i,i=i+8|0,c[n>>2]=h,n)|0);i=n;c[g>>2]=8}c[e+76>>2]=1744336}else{c[e+76>>2]=r}}while(0);r=ICb()|0;c[e>>2]=r;o=(r|0)==0?-12:0;i=b;return o|0}function I_(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;h=b+60|0;i=c[h>>2]|0;j=c[g+24>>2]|0;k=j;l=c[g+28>>2]|0;g=j+l|0;c[i+84>>2]=0;c[i+80>>2]=0;m=i;n=$$a(b,c[m>>2]|0)|0;if((n|0)<0){o=n;return o|0}n=c[m>>2]|0;c[n+88>>2]=1;c[n+304>>2]=1;UGb(c[n+4>>2]|0,i+4|0,64)|0;i=c[b+48>>2]|0;a:do{if((i|0)==4801606){if((l|0)<=2){break}n=b+124|0;p=b+120|0;q=j;r=j+2|0;while(1){s=q;t=(d[s]|d[s+1|0]<<8)<<16>>16;b:do{if(t<<16>>16==1){s=q+6|0;if(s>>>0>g>>>0){break a}if((a[r]|0)==0){u=s;break}v=q+5|0;w=q+4|0;x=1;while(1){y=d[v]|0;z=c[h>>2]|0;A=z+84|0;B=c[A>>2]|0;C=z+72|0;D=c[C>>2]|0;do{if((B|0)<=((c[n>>2]|0)-D|0)){E=c[z>>2]|0;F=c[E+32>>2]|0;G=ba(F,B)|0;H=z+80|0;F$((c[E>>2]|0)+(G+(c[H>>2]|0))|0,F,c[z+76>>2]|0,D,d[w]|0,y&15,y>>>4);F=(c[H>>2]|0)+8|0;c[H>>2]=F;if((F|0)<=((c[p>>2]|0)-8|0)){break}c[H>>2]=0;c[A>>2]=(c[A>>2]|0)+(c[C>>2]|0)}}while(0);if((x|0)>=(d[r]|0)){u=s;break b}x=x+1|0}}else{x=d[q+1|0]|0;s=c[h>>2]|0;w=s+84|0;v=c[w>>2]|0;C=s+72|0;A=c[C>>2]|0;if((v|0)>((c[n>>2]|0)-A|0)){u=r;break}y=c[s>>2]|0;D=c[y+32>>2]|0;z=ba(D,v)|0;v=s+80|0;F$((c[y>>2]|0)+(z+(c[v>>2]|0))|0,D,c[s+76>>2]|0,A,t&255,x&15,x>>>4);x=(c[v>>2]|0)+8|0;c[v>>2]=x;if((x|0)<=((c[p>>2]|0)-8|0)){u=r;break}c[v>>2]=0;c[w>>2]=(c[w>>2]|0)+(c[C>>2]|0);u=r}}while(0);t=u+2|0;if(t>>>0<g>>>0){q=u;r=t}else{break}}}else if((i|0)==1480739150){if((l|0)<=2){break}r=b+124|0;q=b+120|0;p=(-k|0)-l|0;n=j;t=j+2|0;while(1){C=a[n]|0;w=C&255;v=w>>>6;x=(w&63)+1|0;w=n+1|0;c:do{if((v|0)==0){A=0;s=w;while(1){D=s+1|0;if(!(D>>>0<g>>>0)){I=s;break c}z=d[D]|0;D=c[h>>2]|0;y=D+84|0;B=c[y>>2]|0;H=D+72|0;F=c[H>>2]|0;do{if((B|0)<=((c[r>>2]|0)-F|0)){G=c[D>>2]|0;E=c[G+32>>2]|0;J=ba(E,B)|0;K=D+80|0;F$((c[G>>2]|0)+(J+(c[K>>2]|0))|0,E,c[D+76>>2]|0,F,d[s]|0,z&15,z>>>4);E=(c[K>>2]|0)+8|0;c[K>>2]=E;if((E|0)<=((c[q>>2]|0)-8|0)){break}c[K>>2]=0;c[y>>2]=(c[y>>2]|0)+(c[H>>2]|0)}}while(0);H=s+2|0;y=A+1|0;if((y|0)<(x|0)){A=y;s=H}else{I=H;break}}}else if((v|0)==1){s=d[w]|0;if(!(t>>>0<g>>>0)){I=t;break}A=t+p|0;H=~(C&63);y=-(A>>>0>H>>>0?A:H)|0;H=1;A=t;while(1){z=A+1|0;F=d[A]|0;D=c[h>>2]|0;B=D+84|0;K=c[B>>2]|0;E=D+72|0;J=c[E>>2]|0;do{if((K|0)<=((c[r>>2]|0)-J|0)){G=c[D>>2]|0;L=c[G+32>>2]|0;M=ba(L,K)|0;N=D+80|0;F$((c[G>>2]|0)+(M+(c[N>>2]|0))|0,L,c[D+76>>2]|0,J,s,F&15,F>>>4);L=(c[N>>2]|0)+8|0;c[N>>2]=L;if((L|0)<=((c[q>>2]|0)-8|0)){break}c[N>>2]=0;c[B>>2]=(c[B>>2]|0)+(c[E>>2]|0)}}while(0);if(!((H|0)<(x|0)&z>>>0<g>>>0)){break}H=H+1|0;A=z}I=t+y|0}else if((v|0)==2){A=d[w]|0;if(!(t>>>0<g>>>0)){I=t;break}H=A&15;s=A>>>4;A=t+p|0;E=~(C&63);B=-(A>>>0>E>>>0?A:E)|0;E=1;A=t;while(1){F=A+1|0;J=c[h>>2]|0;D=J+84|0;K=c[D>>2]|0;N=J+72|0;L=c[N>>2]|0;do{if((K|0)<=((c[r>>2]|0)-L|0)){M=c[J>>2]|0;G=c[M+32>>2]|0;O=ba(G,K)|0;P=J+80|0;F$((c[M>>2]|0)+(O+(c[P>>2]|0))|0,G,c[J+76>>2]|0,L,d[A]|0,H,s);G=(c[P>>2]|0)+8|0;c[P>>2]=G;if((G|0)<=((c[q>>2]|0)-8|0)){break}c[P>>2]=0;c[D>>2]=(c[D>>2]|0)+(c[N>>2]|0)}}while(0);if(!((E|0)<(x|0)&F>>>0<g>>>0)){break}E=E+1|0;A=F}I=t+B|0}else if((v|0)==3){A=d[w]|0;E=n+3|0;s=d[t]|0;if(!(E>>>0<g>>>0)){I=E;break}H=s&15;y=s>>>4;s=1;while(1){N=c[h>>2]|0;D=N+84|0;L=c[D>>2]|0;J=N+72|0;K=c[J>>2]|0;do{if((L|0)<=((c[r>>2]|0)-K|0)){z=c[N>>2]|0;P=c[z+32>>2]|0;G=ba(P,L)|0;O=N+80|0;F$((c[z>>2]|0)+(G+(c[O>>2]|0))|0,P,c[N+76>>2]|0,K,A,H,y);P=(c[O>>2]|0)+8|0;c[O>>2]=P;if((P|0)<=((c[q>>2]|0)-8|0)){break}c[O>>2]=0;c[D>>2]=(c[D>>2]|0)+(c[J>>2]|0)}}while(0);if((s|0)>=(x|0)){I=E;break c}s=s+1|0}}else{I=w}}while(0);w=I+2|0;if(w>>>0<g>>>0){n=I;t=w}else{break}}}else{if((l|0)<=1){break}t=b+124|0;n=b+120|0;q=j;r=j+1|0;while(1){p=d[r]|0;w=c[h>>2]|0;x=w+84|0;v=c[x>>2]|0;C=w+72|0;s=c[C>>2]|0;do{if((v|0)<=((c[t>>2]|0)-s|0)){E=c[w>>2]|0;y=c[E+32>>2]|0;H=ba(y,v)|0;A=w+80|0;F$((c[E>>2]|0)+(H+(c[A>>2]|0))|0,y,c[w+76>>2]|0,s,d[q]|0,p&15,p>>>4);y=(c[A>>2]|0)+8|0;c[A>>2]=y;if((y|0)<=((c[n>>2]|0)-8|0)){break}c[A>>2]=0;c[x>>2]=(c[x>>2]|0)+(c[C>>2]|0)}}while(0);C=q+3|0;if(!(C>>>0<g>>>0)){break a}q=q+2|0;r=C}}}while(0);g=MCb(e,c[m>>2]|0)|0;if((g|0)<0){o=g;return o|0}c[f>>2]=1;o=l;return o|0}function J_(a){a=a|0;JCb(c[a+60>>2]|0);return 0}function K_(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b+4|0;e=c[d>>2]|0;f=e&7;g=b|0;h=c[g>>2]|0;if((e|0)>(f|0)){i=e;j=h<<f;k=i-f|0;c[g>>2]=j;c[d>>2]=k;return}else{l=fe(h<<e|0)|0;h=b+12|0;b=c[h>>2]|0;x=l;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;i=e+32|0;j=0;k=i-f|0;c[g>>2]=j;c[d>>2]=k;return}}function L_(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a[d]|0;if(!(f<<24>>24==0)){g=b|0;h=b+4|0;i=b+12|0;j=d;d=f;f=c[g>>2]|0;k=c[h>>2]|0;while(1){l=d<<24>>24;if((k|0)>8){m=k-8|0;n=f<<8|l}else{o=fe(l>>>((8-k|0)>>>0)|f<<k|0)|0;p=c[i>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;m=k+24|0;n=l}c[g>>2]=n;c[h>>2]=m;l=j+1|0;p=a[l]|0;if(p<<24>>24==0){break}else{j=l;d=p;f=n;k=m}}}if((e|0)==0){return}e=b|0;m=c[e>>2]|0;k=b+4|0;n=c[k>>2]|0;if((n|0)>8){q=n-8|0;r=m<<8}else{f=fe(m<<n|0)|0;m=b+12|0;b=c[m>>2]|0;x=f;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;q=n+24|0;r=0}c[e>>2]=r;c[k>>2]=q;return}function M_(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=f>>4;h=f&15;if((f|0)==0){return}do{if((g|0)<16){i=6}else{f=b+4|0;j=c[f>>2]|0;k=b+8|0;l=b+12|0;if((-j&7|0)!=0){i=6;break}m=c[k>>2]|0;n=c[l>>2]|0;o=b|0;if((32-j+(n-m<<3)&31|0)==0){p=0;q=j;r=n}else{s=0;t=c[o>>2]|0;u=j;j=m;m=n;while(1){n=d[e+s|0]|0;if((u|0)>8){v=u-8|0;w=t<<8|n;y=j;z=m}else{A=m;x=fe(n>>>((8-u|0)>>>0)|t<<u|0)|0;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;A=(c[l>>2]|0)+4|0;c[l>>2]=A;v=u+24|0;w=n;y=c[k>>2]|0;z=A}c[o>>2]=w;c[f>>2]=v;A=s+1|0;if((32-v+(z-y<<3)&31|0)==0){p=A;q=v;r=z;break}else{s=A;t=w;u=v;j=y;m=z}}}if((q|0)<32){m=c[o>>2]<<q;c[o>>2]=m;j=m>>>24&255;m=r;while(1){c[l>>2]=m+1;a[m]=j;u=c[o>>2]|0;c[o>>2]=u<<8;t=(c[f>>2]|0)+8|0;c[f>>2]=t;if((t|0)>=32){break}j=u>>>16&255;m=c[l>>2]|0}B=c[l>>2]|0}else{B=r}c[f>>2]=32;c[o>>2]=0;m=g<<1;j=m-p|0;UGb(B|0,e+p|0,j)|0;c[l>>2]=(c[l>>2]|0)+j;C=m;D=o;E=f}}while(0);if((i|0)==6){i=b|0;p=b+4|0;if((g|0)>0){B=b+12|0;r=0;q=c[i>>2]|0;z=c[p>>2]|0;while(1){y=e+(r<<1)|0;v=(de((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535;if((z|0)>16){F=z-16|0;G=q<<16|v}else{y=fe(v>>>((16-z|0)>>>0)|q<<z|0)|0;w=c[B>>2]|0;x=y;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;F=z+16|0;G=v}c[i>>2]=G;c[p>>2]=F;v=r+1|0;if((v|0)<(g|0)){r=v;q=G;z=F}else{break}}}C=g<<1;D=i;E=p}p=e+C|0;C=((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)>>>((16-h|0)>>>0);p=c[D>>2]|0;e=c[E>>2]|0;if((e|0)>(h|0)){H=e-h|0;I=p<<h|C}else{i=fe(C>>>((h-e|0)>>>0)|p<<e|0)|0;p=b+12|0;b=c[p>>2]|0;x=i;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;H=32-h+e|0;I=C}c[D>>2]=I;c[E>>2]=H;return}function N_(f,g,h,j,k,l,m,n,o,p,q,r,s){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;var t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;t=i;i=i+12e3|0;u=t|0;c[f>>2]=g;v=(s&4|0)!=0;do{if(v){w=f+16|0;x=f;y=f+20|0;while(1){z=(D=c[w>>2]|0,(c[w>>2]|0)==0?(c[w>>2]=x)|0:0,D);if((z|0)==0){A=8;break}if((z|0)==(y|0)){A=5;break}}if((A|0)==5){y=c[f+8>>2]|0;if((y|0)==0){yDb(0,0,2333632,(B=i,i=i+24|0,c[B>>2]=2334360,c[B+8>>2]=2193632,c[B+16>>2]=284,B)|0);i=B;Cd();return 0}if((y|0)==(c[f+12>>2]|0)){C=0;i=t;return C|0}else{yDb(0,0,2333632,(B=i,i=i+24|0,c[B>>2]=2334360,c[B+8>>2]=2193632,c[B+16>>2]=284,B)|0);i=B;Cd();return 0}}else if((A|0)==8){if((c[f+8>>2]|0)!=0){yDb(0,0,2333632,(B=i,i=i+24|0,c[B>>2]=2115400,c[B+8>>2]=2193632,c[B+16>>2]=288,B)|0);i=B;Cd();return 0}if((h+1|0)>>>0<1501>>>0){E=u|0;break}else{yDb(0,0,2333632,(B=i,i=i+24|0,c[B>>2]=2056200,c[B+8>>2]=2193632,c[B+16>>2]=289,B)|0);i=B;Cd();return 0}}}else{c[f+4>>2]=0;c[f+12>>2]=0;c[f+8>>2]=0;y=WDb((h<<3)+8|0)|0;if((y|0)==0){C=-12}else{E=y;break}i=t;return C|0}}while(0);u=(p|0)==0;if(!((r|0)<3|u)){yDb(0,0,2333632,(B=i,i=i+24|0,c[B>>2]=2010184,c[B+8>>2]=2193632,c[B+16>>2]=302,B)|0);i=B;Cd();return 0}y=(h|0)>0;a:do{if(y){x=g*3|0;w=(s&2|0)==0;z=0;G=0;while(1){H=j+(ba(G,k)|0)|0;if((l|0)==2){I=b[H>>1]&255;a[E+(z<<3)|0]=I;J=I}else if((l|0)==1){I=a[H]|0;a[E+(z<<3)|0]=I;J=I}else{I=c[H>>2]&255;a[E+(z<<3)|0]=I;J=I}K=J&255;if((K|0)>(g|0)){if((K|0)>(x|0)|(J&255)>>>0>32>>>0){A=25;break}I=m+(ba(G,n)|0)|0;if((o|0)==1){H=d[I]|0;c[E+(z<<3)+4>>2]=H;L=H}else if((o|0)==2){H=e[I>>1]|0;c[E+(z<<3)+4>>2]=H;L=H}else{H=c[I>>2]|0;c[E+(z<<3)+4>>2]=H;L=H}H=0;I=_Gb(1,0,J&255|0)|0;M=F;if(!((H|0)<(M|0)|(H|0)==(M|0)&L>>>0<I>>>0)){A=32;break}if(w){N=L<<32-K}else{N=(d[1148864+(L>>>8&255)|0]|0)<<16|(d[1148864+(L&255)|0]|0)<<24|(d[1148864+(L>>>16&255)|0]|0)<<8|(d[1148864+(L>>>24)|0]|0)}c[E+(z<<3)+4>>2]=N;do{if(u){b[E+(z<<3)+2>>1]=G}else{I=p+(ba(G,q)|0)|0;if((r|0)==1){b[E+(z<<3)+2>>1]=d[I]|0;break}else if((r|0)==2){b[E+(z<<3)+2>>1]=b[I>>1]|0;break}else{b[E+(z<<3)+2>>1]=c[I>>2];break}}}while(0);O=z+1|0}else{O=z}I=G+1|0;if((I|0)<(h|0)){z=O;G=I}else{A=45;break}}if((A|0)==25){yDb(0,16,1971416,(B=i,i=i+8|0,c[B>>2]=K,B)|0);i=B;if(v){C=-1;i=t;return C|0}ZDb(E|0);C=-1;i=t;return C|0}else if((A|0)==32){yDb(0,16,1942752,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;if(v){C=-1;i=t;return C|0}ZDb(E|0);C=-1;i=t;return C|0}else if((A|0)==45){G=E|0;Yc(G|0,O|0,8,798);if(!y){P=O;Q=G;break}z=g*3|0;w=(s&2|0)==0;x=O;I=0;while(1){M=j+(ba(I,k)|0)|0;if((l|0)==1){H=a[M]|0;a[E+(x<<3)|0]=H;R=H}else if((l|0)==2){H=b[M>>1]&255;a[E+(x<<3)|0]=H;R=H}else{H=c[M>>2]&255;a[E+(x<<3)|0]=H;R=H}S=R&255;if(R<<24>>24==0|(S|0)>(g|0)){T=x}else{if((S|0)>(z|0)|(R&255)>>>0>32>>>0){A=53;break}H=m+(ba(I,n)|0)|0;if((o|0)==1){M=d[H]|0;c[E+(x<<3)+4>>2]=M;U=M}else if((o|0)==2){M=e[H>>1]|0;c[E+(x<<3)+4>>2]=M;U=M}else{M=c[H>>2]|0;c[E+(x<<3)+4>>2]=M;U=M}M=0;H=_Gb(1,0,R&255|0)|0;V=F;if(!((M|0)<(V|0)|(M|0)==(V|0)&U>>>0<H>>>0)){A=60;break}if(w){W=U<<32-S}else{W=(d[1148864+(U>>>8&255)|0]|0)<<16|(d[1148864+(U&255)|0]|0)<<24|(d[1148864+(U>>>16&255)|0]|0)<<8|(d[1148864+(U>>>24)|0]|0)}c[E+(x<<3)+4>>2]=W;do{if(u){b[E+(x<<3)+2>>1]=I}else{H=p+(ba(I,q)|0)|0;if((r|0)==2){b[E+(x<<3)+2>>1]=b[H>>1]|0;break}else if((r|0)==1){b[E+(x<<3)+2>>1]=d[H]|0;break}else{b[E+(x<<3)+2>>1]=c[H>>2];break}}}while(0);T=x+1|0}H=I+1|0;if((H|0)<(h|0)){x=T;I=H}else{P=T;Q=G;break a}}if((A|0)==53){yDb(0,16,1971416,(B=i,i=i+8|0,c[B>>2]=S,B)|0);i=B;if(v){C=-1;i=t;return C|0}ZDb(G);C=-1;i=t;return C|0}else if((A|0)==60){yDb(0,16,1942752,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;if(v){C=-1;i=t;return C|0}ZDb(G);C=-1;i=t;return C|0}}}else{I=E|0;Yc(I|0,0,8,798);P=0;Q=I}}while(0);A=P_(f,g,P,E,s)|0;if(!v){ZDb(Q);if((A|0)>=0){C=0;i=t;return C|0}$Db(f+4|0);C=A;i=t;return C|0}Q=c[f+8>>2]|0;v=c[f+12>>2]|0;if((Q|0)!=(v|0)){yDb(0,16,1918224,(B=i,i=i+16|0,c[B>>2]=Q,c[B+8>>2]=v,B)|0);i=B}v=f+16|0;if(((D=c[v>>2]|0,(c[v>>2]|0)==(f|0)?(c[v>>2]=f+20)|0:0,D)|0)!=(f|0)){yDb(0,0,2333632,(B=i,i=i+24|0,c[B>>2]=1897472,c[B+8>>2]=2193632,c[B+16>>2]=344,B)|0);i=B;Cd();return 0}if((A|0)>-1){C=0;i=t;return C|0}else{yDb(0,0,2333632,(B=i,i=i+24|0,c[B>>2]=2354856,c[B+8>>2]=2193632,c[B+16>>2]=345,B)|0);i=B;Cd();return 0}return 0}function O_(a,b){a=a|0;b=b|0;return((c[a+4>>2]|0)>>>1)-((c[b+4>>2]|0)>>>1)|0}function P_(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=i;l=1<<f;if((f|0)>30){m=-1;i=k;return m|0}n=e+8|0;o=c[n>>2]|0;p=o+l|0;c[n>>2]=p;q=e+12|0;r=c[q>>2]|0;do{if((p|0)>(r|0)){if((j&4|0)!=0){Cd();return 0}s=(1<<c[e>>2])+r|0;c[q>>2]=s;t=e+4|0;u=YDb(c[t>>2]|0,s,4)|0;c[t>>2]=u;if((u|0)!=0){break}c[q>>2]=0;c[n>>2]=0;m=-12;i=k;return m|0}}while(0);if((o|0)<0){m=o;i=k;return m|0}n=e+4|0;q=c[n>>2]|0;r=q+(o<<2)|0;if((l|0)>0){p=0;do{u=p+o|0;b[q+(u<<2)+2>>1]=0;b[q+(u<<2)>>1]=-1;p=p+1|0;}while((p|0)<(l|0))}if((g|0)<=0){m=o;i=k;return m|0}l=32-f|0;p=(j&2|0)==0;q=0;u=r;a:while(1){r=h+(q<<3)|0;t=r|0;s=a[t]|0;v=s&255;w=h+(q<<3)+4|0;x=c[w>>2]|0;y=b[h+(q<<3)+2>>1]|0;do{if((v|0)>(f|0)){z=v-f|0;A=x>>>(l>>>0);a[t]=z;c[w>>2]=x<<f;B=q+1|0;b:do{if((B|0)<(g|0)){C=z;D=q;E=B;while(1){F=h+(E<<3)|0;G=(d[F]|0)-f|0;if((G|0)<1){H=C;I=D;J=E;break b}K=h+(E<<3)+4|0;L=c[K>>2]|0;if((L>>>(l>>>0)|0)!=(A|0)){H=C;I=D;J=E;break b}a[F]=G;c[K>>2]=L<<f;L=(C|0)>(G|0)?C:G;G=E+1|0;if((G|0)<(g|0)){C=L;D=E;E=G}else{H=L;I=E;J=G;break}}}else{H=z;I=q;J=B}}while(0);B=(H|0)>(f|0)?f:H;if(p){M=A}else{M=(d[1148864+(A>>>8&255)|0]<<16|d[1148864+(A&255)|0]<<24|d[1148864+(A>>>16&255)|0]<<8|d[1148864+(A>>>24)|0])>>>(l>>>0)}b[u+(M<<2)+2>>1]=-B;z=P_(e,B,J-q|0,r,j)|0;if((z|0)<0){m=z;N=31;break a}B=c[n>>2]|0;E=z&65535;b[B+(M+o<<2)>>1]=E;if((E<<16>>16|0)!=(z|0)){N=28;break a}O=B+(o<<2)|0;P=I}else{B=1<<f-v;if(p){Q=1;R=x>>>(l>>>0)}else{Q=1<<v;R=d[1148864+(x>>>8&255)|0]<<16|d[1148864+(x&255)|0]<<24|d[1148864+(x>>>16&255)|0]<<8|d[1148864+(x>>>24)|0]}if((B|0)<=0){O=u;P=q;break}z=s&255;E=R;D=0;while(1){C=u+(E<<2)+2|0;if((b[C>>1]|0)!=0){N=18;break a}b[C>>1]=z;b[u+(E<<2)>>1]=y;C=D+1|0;if((C|0)<(B|0)){E=E+Q|0;D=C}else{O=u;P=q;break}}}}while(0);y=P+1|0;if((y|0)<(g|0)){q=y;u=O}else{m=o;N=31;break}}if((N|0)==18){yDb(0,16,2334520,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;m=-1094995529;i=k;return m|0}else if((N|0)==28){yDb(0,0,2333632,(S=i,i=i+24|0,c[S>>2]=2309656,c[S+8>>2]=2193632,c[S+16>>2]=235,S)|0);i=S;Cd();return 0}else if((N|0)==31){i=k;return m|0}return 0}function Q_(a){a=a|0;$Db(a+4|0);return}function R_(a){a=a|0;return c[((a|0)==0?5221504:a+16|0)>>2]|0}function S_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=5221504;while(1){d=c[b>>2]|0;if((d|0)==0){e=0;f=7;break}if((QGb(a,c[d>>2]|0)|0)==0){break}else{b=d+16|0}}if((f|0)==7){return e|0}f=cEb(16)|0;c[f+4>>2]=d;b=c[d+4>>2]|0;if((b|0)==0){g=0}else{g=cEb(b)|0}c[f>>2]=g;e=f;return e|0}function T_(a){a=a|0;var b=0;if((a|0)==0){return}b=c[(c[a+4>>2]|0)+12>>2]|0;if((b|0)!=0){me[b&511](a)}b=a;$Db(b);VRa(c[a+8>>2]|0);ZDb(b);return}function U_(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[e>>2]=g;c[f>>2]=h;return Ze[c[(c[a+4>>2]|0)+8>>2]&15](a,b,d,e,f,g,h,i)|0}function V_(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;j=i;i=i+16|0;k=j|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;h=f;if((m|0)<14){yDb(e,16,2193576,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-1094995529;i=j;return o|0}do{if((a[l]|0)==66){if((a[l+1|0]|0)!=77){break}p=l+2|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;if(m>>>0<q>>>0){yDb(e,16,2056096,(n=i,i=i+16|0,c[n>>2]=m,c[n+8>>2]=q,n)|0);i=n;r=m}else{r=q}q=l+10|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+18|0;s=l+14|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=t+14|0;if(s>>>0>p>>>0){yDb(e,16,2010152,(n=i,i=i+8|0,c[n>>2]=p,n)|0);i=n;o=-1094995529;i=j;return o|0}u=(r|0)==14|(r|0)==(s|0)?m-2|0:r;if(!(u>>>0>p>>>0)){yDb(e,16,1971352,(n=i,i=i+16|0,c[n>>2]=u,c[n+8>>2]=p,n)|0);i=n;o=-1094995529;i=j;return o|0}switch(t|0){case 40:case 56:case 64:case 108:case 124:{u=q;v=l+22|0;w=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;x=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;y=l+26|0;break};case 12:{v=q;q=l+20|0;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;x=(d[q]|d[q+1|0]<<8)<<16>>16&65535;y=l+22|0;break};default:{yDb(e,16,1942696,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1163346256;i=j;return o|0}}q=y;if(!((d[q]|d[q+1|0]<<8)<<16>>16<<16>>16==1)){yDb(e,16,1918168,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}q=y+2|0;v=(d[q]|d[q+1|0]<<8)<<16>>16&65535;do{if(t>>>0>39>>>0){q=y+4|0;u=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;if(u>>>0<4>>>0){if((u|0)!=3){z=0;A=0;B=0;C=0;D=u;E=0;break}q=y+28|0;F=y+32|0;G=y+36|0;H=y+40|0;z=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;A=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;B=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;C=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;D=3;E=1;break}else{yDb(e,16,1897424,(n=i,i=i+8|0,c[n>>2]=u,n)|0);i=n;o=-1094995529;i=j;return o|0}}else{z=0;A=0;B=0;C=0;D=0;E=0}}while(0);u=e+120|0;c[u>>2]=w;G=(x|0)>0;F=e+124|0;c[F>>2]=G?x:-x|0;q=e+140|0;c[q>>2]=-1;a:do{switch(v|0){case 24:{c[q>>2]=3;break};case 16:{if((D|0)==0){c[q>>2]=46;break a}if(!E){yDb(e,16,2290848,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}H=(C|0)==31;if((A|0)==63488&(B|0)==2016&H){c[q>>2]=44;break a}if((A|0)==31744&(B|0)==992&H){c[q>>2]=46;break a}if((A|0)==3840&(B|0)==240&(C|0)==15){c[q>>2]=62;break a}yDb(e,16,2354792,(n=i,i=i+24|0,c[n>>2]=A,c[n+8>>2]=B,c[n+16>>2]=C,n)|0);i=n;o=-22;i=j;return o|0};case 32:{if(!E){c[q>>2]=30;break a}H=(B|0)==16711680;if((A|0)==-16777216&H&(C|0)==65280){c[q>>2]=(z|0)!=0?29:297;break a}I=(B|0)==65280;if((A|0)==16711680&I&(C|0)==255){c[q>>2]=(z|0)!=0?30:298;break a}if((A|0)==65280&H&(C|0)==-16777216){c[q>>2]=(z|0)!=0?27:295;break a}if((A|0)==255&I&(C|0)==16711680){c[q>>2]=(z|0)!=0?28:296;break a}yDb(e,16,2354792,(n=i,i=i+24|0,c[n>>2]=A,c[n+8>>2]=B,c[n+16>>2]=C,n)|0);i=n;o=-22;i=j;return o|0};case 1:case 4:{if((p-t|0)!=14){c[q>>2]=11;break a}yDb(e,16,2334448,(n=i,i=i+8|0,c[n>>2]=1<<v,n)|0);i=n;o=-1094995529;i=j;return o|0};case 8:{if((p-t|0)==14){c[q>>2]=8;break a}else{c[q>>2]=11;break a}break};default:{yDb(e,16,2309608,(n=i,i=i+8|0,c[n>>2]=v,n)|0);i=n;o=-1094995529;i=j;return o|0}}}while(0);I=_$a(e,h,0)|0;if((I|0)<0){o=I;i=j;return o|0}c[f+88>>2]=1;c[f+84>>2]=1;I=l+p|0;H=m-p|0;J=((ba(c[u>>2]|0,v)|0)+31|0)>>>3&536870908;K=c[F>>2]|0;L=ba(J,K)|0;M=D-1|0;do{if((L|0)>(H|0)){if(!(M>>>0>1>>>0)){N=(D|0)==1;O=61;break}yDb(e,16,2274880,(n=i,i=i+16|0,c[n>>2]=H,c[n+8>>2]=L,n)|0);i=n;o=-1094995529;i=j;return o|0}else{P=(D|0)==1;if(M>>>0<2>>>0){N=P;O=61;break}Q=f;R=P;S=0}}while(0);if((O|0)==61){M=f;TGb(c[M>>2]|0,0,ba(c[f+32>>2]|0,K)|0)|0;Q=M;R=N;S=1}M=c[Q>>2]|0;if(G){L=c[f+32>>2]|0;T=M+(ba((c[F>>2]|0)-1|0,L)|0)|0;U=-L|0}else{T=M;U=c[f+32>>2]|0}b:do{if((c[q>>2]|0)==11){M=1<<v;L=f+4|0;TGb(c[L>>2]|0,0,1024)|0;do{if(t>>>0>35>>>0){P=l+46|0;V=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;if((V|0)<0|(V|0)>(M|0)){yDb(e,16,2259208,(n=i,i=i+16|0,c[n>>2]=V,c[n+8>>2]=v,n)|0);i=n;W=M;break}else{W=(V|0)==0?M:V;break}}else{W=M}}while(0);M=l+s|0;V=p-t-14|0;if(!(V>>>0<W<<2>>>0)){if((W|0)<=0){break}P=c[L>>2]|0;X=M;Y=0;while(1){Z=X;c[P+(Y<<2)>>2]=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|-16777216;Z=Y+1|0;if((Z|0)<(W|0)){X=X+4|0;Y=Z}else{break b}}}if(V>>>0<(W*3|0)>>>0){yDb(e,16,2244656,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}if((W|0)<=0){break}Y=c[L>>2]|0;X=M;P=0;while(1){c[Y+(P<<2)>>2]=d[X+2|0]<<16|d[X+1|0]<<8|d[X]|-16777216;Z=P+1|0;if((Z|0)<(W|0)){X=X+3|0;P=Z}else{break}}}}while(0);c:do{if(S){t=(x|0)<0;if(R&t){p=f+32|0;s=c[p>>2]|0;q=ba((c[F>>2]|0)-1|0,s)|0;c[Q>>2]=(c[Q>>2]|0)+q;c[p>>2]=-s}if(!((H|0)>-1)){yDb(0,0,2219744,(n=i,i=i+24|0,c[n>>2]=2210528,c[n+8>>2]=2201728,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}c[k>>2]=I;c[k+8>>2]=I;c[k+4>>2]=l+m;kQa(e,f,v,k)|0;if(!t){break}t=f+32|0;s=c[t>>2]|0;p=ba((c[F>>2]|0)-1|0,s)|0;c[Q>>2]=(c[Q>>2]|0)+p;c[t>>2]=-s}else{switch(v|0){case 1:{s=c[F>>2]|0;if((s|0)<=0){break c}if((J|0)==0){t=0;while(1){t=t+1|0;if((t|0)>=(s|0)){break c}}}else{_=I;$=0;aa=T}while(1){s=0;do{t=_+s|0;p=s<<3;a[aa+p|0]=(d[t]|0)>>>7;a[aa+(p|1)|0]=(d[t]|0)>>>6&1;a[aa+(p|2)|0]=(d[t]|0)>>>5&1;a[aa+(p|3)|0]=(d[t]|0)>>>4&1;a[aa+(p|4)|0]=(d[t]|0)>>>3&1;a[aa+(p|5)|0]=(d[t]|0)>>>2&1;a[aa+(p|6)|0]=(d[t]|0)>>>1&1;a[aa+(p|7)|0]=a[t]&1;s=s+1|0;}while((s|0)<(J|0));s=$+1|0;if((s|0)<(c[F>>2]|0)){_=_+J|0;$=s;aa=aa+U|0}else{break}}break};case 8:case 24:case 32:{if((c[F>>2]|0)>0){ca=I;da=0;ea=T}else{break c}while(1){UGb(ea|0,ca|0,J)|0;s=da+1|0;if((s|0)<(c[F>>2]|0)){ca=ca+J|0;da=s;ea=ea+U|0}else{break}}break};case 16:{s=c[F>>2]|0;if((s|0)<=0){break c}t=c[u>>2]|0;if((t|0)>0){fa=I;ga=0;ha=T}else{break c}while(1){p=0;q=fa;G=ha;while(1){b[G>>1]=b[q>>1]|0;K=p+1|0;if((K|0)<(t|0)){p=K;q=q+2|0;G=G+2|0}else{break}}G=ga+1|0;if((G|0)<(s|0)){fa=fa+J|0;ga=G;ha=ha+U|0}else{break}}break};case 4:{s=c[F>>2]|0;if((s|0)<=0){break c}if((J|0)==0){t=0;while(1){t=t+1|0;if((t|0)>=(s|0)){break c}}}else{ia=I;ja=0;ka=T}while(1){s=0;do{t=ia+s|0;G=s<<1;a[ka+G|0]=(d[t]|0)>>>4;a[ka+(G|1)|0]=a[t]&15;s=s+1|0;}while((s|0)<(J|0));s=ja+1|0;if((s|0)<(c[F>>2]|0)){ia=ia+J|0;ja=s;ka=ka+U|0}else{break}}break};default:{yDb(e,16,2232272,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}}}}while(0);c[g>>2]=1;o=m;i=j;return o|0}}while(0);yDb(e,16,2115328,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}function W_(a){a=a|0;var b=0,d=0,e=0;b=i;switch(c[a+140>>2]|0){case 22:case 19:case 24:case 21:case 8:case 11:{c[a+792>>2]=8;break};case 10:{c[a+792>>2]=1;break};case 46:case 44:case 62:{c[a+792>>2]=16;break};case 3:{c[a+792>>2]=24;break};case 30:{c[a+792>>2]=32;break};default:{yDb(a,32,2193528,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-22;i=b;return e|0}}d=ICb()|0;c[a+804>>2]=d;e=(d|0)==0?-12:0;i=b;return e|0}function X_(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;h=i;i=i+1024|0;j=c[d+792>>2]|0;k=c[d+804>>2]|0;c[k+88>>2]=1;c[k+84>>2]=1;k=c[d+140>>2]|0;switch(k|0){case 44:{l=3;m=547832;break};case 22:case 19:case 24:case 21:case 8:{n=h|0;fDb(n,k)|0;l=0;m=n;break};case 62:{l=3;m=547848;break};case 10:{l=0;m=676688;break};case 11:{l=0;m=c[f+4>>2]|0;break};default:{l=0;m=0}}n=(m|0)!=0&(l|0)==0?1<<j:l;k=d+120|0;o=c[k>>2]|0;p=gHb(o,(o|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;o=YGb(p,F,7,0)|0;p=o>>>3|F<<29;o=-p&3;q=d+124|0;r=o+p|0;s=ba(r,c[q>>2]|0)|0;t=(n<<2)+54|0;u=s+t|0;v=r0a(d,e,u,(u|0)<0|0?-1:0)|0;if((v|0)<0){w=v;i=h;return w|0}v=e+24|0;d=c[v>>2]|0;a[d]=66;a[d+1|0]=77;y=d+2|0;x=u;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;y=d+6|0;x=0;a[y]=x;x=x>>8;a[y+1|0]=x;y=d+8|0;x=0;a[y]=x;x=x>>8;a[y+1|0]=x;y=d+10|0;x=t;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;y=d+14|0;x=40;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;y=d+18|0;x=c[k>>2]|0;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;y=d+22|0;x=c[q>>2]|0;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;y=d+26|0;x=1;a[y]=x;x=x>>8;a[y+1|0]=x;y=d+28|0;x=j&65535;a[y]=x;x=x>>8;a[y+1|0]=x;y=d+30|0;x=l;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;y=d+34|0;x=s;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;TGb(d+38|0,0,16)|0;if((n|0)>0){y=d+54|0;d=0;while(1){s=y;x=c[m+(d<<2)>>2]&16777215;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=d+1|0;if((s|0)<(n|0)){y=y+4|0;d=s}else{break}}}d=c[q>>2]|0;y=f+32|0;n=(c[f>>2]|0)+(ba(d-1|0,c[y>>2]|0)|0)|0;f=(c[v>>2]|0)+t|0;a:do{if((d|0)>0){if((j|0)==16){z=f;A=n;B=0}else{t=f;v=n;m=0;while(1){UGb(t|0,v|0,p)|0;TGb(t+p|0,0,o|0)|0;s=m+1|0;if((s|0)<(c[q>>2]|0)){t=t+r|0;v=v+(-(c[y>>2]|0)|0)|0;m=s}else{break a}}}while(1){m=A;v=z;if((c[k>>2]|0)>0){t=0;do{s=v+(t<<1)|0;x=b[m+(t<<1)>>1]|0;a[s]=x;x=x>>8;a[s+1|0]=x;t=t+1|0;}while((t|0)<(c[k>>2]|0))}TGb(z+p|0,0,o|0)|0;t=B+1|0;if((t|0)<(c[q>>2]|0)){z=z+r|0;A=A+(-(c[y>>2]|0)|0)|0;B=t}else{break}}}}while(0);B=e+36|0;c[B>>2]=c[B>>2]|1;c[g>>2]=1;w=0;i=h;return w|0}function Y_(a){a=a|0;JCb(a+804|0);return 0}function Z_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;c[a+140>>2]=11;e=c[a+120>>2]|0;f=c[a+124>>2]|0;if((e|0)==640&(f|0)==429){c[d+4>>2]=d+648;g=0;i=b;return g|0}else{yDb(a,16,2290816,(a=i,i=i+16|0,c[a>>2]=e,c[a+8>>2]=f,a)|0);i=a;g=-1094995529;i=b;return g|0}return 0}function __(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;h=i;j=c[b+60>>2]|0;k=e;l=g+24|0;m=c[l>>2]|0;n=j+276232|0;o=m+1|0;c[n>>2]=o;p=d[m]|0;do{if((p&32|0)==0){q=o}else{c[n>>2]=m+2;r=(d[o]|0)*65|0;if((c[g+28>>2]|0)>=(r+2|0)){s=m+(r+2)|0;c[n>>2]=s;q=s;break}yDb(b,16,2010096,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}}while(0);do{if((p&16|0)==0){v=q}else{m=p>>>6&2^10;if((q+m-(c[l>>2]|0)|0)<=(c[g+28>>2]|0)){o=q+m|0;c[n>>2]=o;v=o;break}yDb(b,16,1971312,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}}while(0);q=p&8;a:do{if((q|0)!=0){if((v-(c[l>>2]|0)|0)>((c[g+28>>2]|0)-768|0)){yDb(b,16,1942656,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}o=j+275208|0;m=0;s=v;while(1){c[n>>2]=s+3;c[o+(m<<2)>>2]=(d[s]|0)<<16|(d[s+1|0]|0)<<8|(d[s+2|0]|0)|-16777216;r=m+1|0;if((r|0)>=256){break a}m=r;s=c[n>>2]|0}}}while(0);do{if((p&4|0)==0){w=(p&3|0)==3?-640:0}else{v=c[n>>2]|0;if((v-(c[l>>2]|0)|0)<=((c[g+28>>2]|0)-2|0)){c[n>>2]=v+2;s=v;w=(d[s]|d[s+1|0]<<8)<<16>>16<<16>>16;break}yDb(b,16,1918120,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}}while(0);p=_$a(b,k,0)|0;if((p|0)<0){u=p;i=h;return u|0}p=c[n>>2]|0;n=g+28|0;g=p;k=(c[l>>2]|0)-g+(c[n>>2]|0)|0;l=j+4|0;s=c[l>>2]|0;v=p+k|0;m=s+274560|0;o=w>>>0<4294966657>>>0;b:do{if((k|0)>=1){if(o){x=m;y=s;z=p}else{x=s-1|0;y=s+274559|0;z=p+(k-1)|0}r=x;A=s;B=m;C=v;D=0;E=0;F=k;G=y;H=z;while(1){I=(D|0)!=0;if((F|0)==4|I^1){if(!(H>>>0>=p>>>0&H>>>0<v>>>0)){break b}J=1;K=d[H]|0}else{J=0;K=E}c:do{if((K&12|0)==0){if(o){L=0;M=J;N=K;O=H;while(1){if((L|0)>22){break b}if((M|0)==0){if(!(O>>>0>=p>>>0&O>>>0<v>>>0)){break b}P=L+2|0;Q=d[O]|0;R=Q<<P|N;if((Q&12|0)==0){S=P;T=R}else{U=O;V=R;W=P;X=41;break c}}else{S=L;T=N}P=S+2|0;R=1<<P;Q=R-1&T|T>>>2&-R;R=O+1|0;if((Q&12<<P|0)==0){L=P;M=0;N=Q;O=R}else{Y=Q;Z=E;_=4;$=R;break}}}else{O=0;N=J;M=K;L=H;while(1){if((O|0)>22){break b}if((N|0)==0){if(!(L>>>0>=p>>>0&L>>>0<v>>>0)){break b}R=O+2|0;Q=d[L]|0;P=Q<<R|M;if((Q&12|0)==0){aa=R;ba=P}else{U=L;V=P;W=R;X=41;break c}}else{aa=O;ba=M}R=aa+2|0;P=1<<R;Q=P-1&ba|ba>>>2&-P;P=L-1|0;if((Q&12<<R|0)==0){O=R;N=0;M=Q;L=P}else{Y=Q;Z=E;_=4;$=P;break}}}}else{if(I&(F|0)!=4){Y=K;Z=E;_=4;$=H}else{U=H;V=K;W=0;X=41}}}while(0);if((X|0)==41){X=0;I=W+4|0;Y=(1<<I)-1&V;Z=V>>>(I>>>0);_=0;$=o?U+1|0:U-1|0}I=Y>>>1;L=I-1|0;if((L|0)<=0){X=43;break}M=D+1+(Y&1)|0;N=(M|0)>3?M-3|0:M;M=G;O=r-M|0;if((((O|0)>-1?O:-O|0)|0)<(L|0)){break b}do{if((N|0)==2){O=$;if(o){if((C-O|0)<(L|0)){break b}UGb(G|0,$|0,L)|0;ca=G+L|0;da=$+L|0;break}else{if((O-g|0)<(L|0)){break b}O=1-I|0;P=G+O|0;Q=$+O|0;UGb(P|0,Q|0,L)|0;ca=P;da=Q;break}}else if((N|0)==3){Q=a[o?G-1|0:G+1|0]|0;if(o){TGb(G|0,Q|0,L|0)|0;ca=G+L|0;da=$;break}else{P=G+(1-I)|0;TGb(P|0,Q|0,L|0)|0;ca=P;da=$;break}}else if((N|0)==1){if(o){P=M-A+640|0;if((P|0)<(w|0)|(P+w|0)<0){break b}P=B-M|0;if((P|0)<(L+w|0)|(P|0)<(L|0)){break b}else{ea=0}do{a[G+ea|0]=a[G+(ea+w)|0]|0;ea=ea+1|0;}while((ea|0)<(L|0));ca=G+L|0;da=$;break}P=1-I|0;Q=G+P|0;O=Q;R=O-A+640|0;if((R|0)<(w|0)|(R+w|0)<0){break b}R=B-O|0;if((R|0)<(L+w|0)|(R|0)<(L|0)){break b}R=I-2|0;if(!((R|0)>-1)){ca=Q;da=$;break}O=P+w|0;fa=R;while(1){a[G+(fa+P)|0]=a[G+(O+fa)|0]|0;if((fa|0)>0){fa=fa-1|0}else{ca=Q;da=$;break}}}else{ca=G;da=$}}while(0);if((ca|0)==(x|0)){break}else{D=N;E=Z;F=_;G=ca;H=da}}if((X|0)==43){yDb(0,0,2354760,(t=i,i=i+24|0,c[t>>2]=2334440,c[t+8>>2]=2309584,c[t+16>>2]=138,t)|0);i=t;Cd();return 0}UGb(c[e+4>>2]|0,j+275208|0,1024)|0;c[e+304>>2]=q;H=b+124|0;if((c[H>>2]|0)>0){G=b+120|0;F=e+32|0;E=0;D=c[l>>2]|0;B=c[e>>2]|0;A=c[G>>2]|0;while(1){UGb(B|0,D|0,A)|0;C=c[G>>2]|0;r=E+1|0;if((r|0)<(c[H>>2]|0)){E=r;D=D+C|0;B=B+(c[F>>2]|0)|0;A=C}else{break}}}c[f>>2]=1;u=c[n>>2]|0;i=h;return u|0}}while(0);yDb(b,16,1897392,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}function $_(a){a=a|0;var b=0;c[a+416>>2]=2;b=a+448|0;c[b>>2]=3;c[b+4>>2]=0;c[a+420>>2]=1;return 0}function a$(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=a[j]|0;l=g&255;m=(l*65|0)+1|0;if((k|0)<(m|0)){yDb(d,16,2056056,(n=i,i=i+16|0,c[n>>2]=m,c[n+8>>2]=k,n)|0);i=n;o=-1094995529;i=h;return o|0}c[e+76>>2]=l<<5;n=_$a(d,e,0)|0;if((n|0)<0){o=n;i=h;return o|0}if(!(g<<24>>24==0)){g=c[e>>2]|0;e=0;n=j+1|0;while(1){j=a[n]|0;d=((j&255)>>>1|j<<7)&255;j=c[1680112+((d&15)<<2)>>2]|0;m=c[1680112+(d>>>4<<2)>>2]|0;d=n+65|0;p=0;q=g;r=n;s=n+1|0;while(1){t=r+2|0;u=ba(a[s]|0,j)|0;v=u>>5;if((v+32768|0)>>>0>65535>>>0){w=(u>>31^32767)&65535}else{w=v&65535}b[q>>1]=w;v=ba(a[t]|0,m)|0;u=v>>5;if((u+32768|0)>>>0>65535>>>0){x=(v>>31^32767)&65535}else{x=u&65535}b[q+2>>1]=x;u=p+1|0;v=r+3|0;if((u|0)<32){p=u;q=q+4|0;r=t;s=v}else{break}}s=e+1|0;if((s|0)<(l|0)){g=g+128|0;e=s;n=d}else{break}}}c[f>>2]=1;o=k;i=h;return o|0}function b$(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=i;h=b;j=f+24|0;k=c[j>>2]|0;l=f+28|0;f=c[l>>2]|0;if(!((f|0)>-1)){yDb(0,0,2354728,(m=i,i=i+24|0,c[m>>2]=2334424,c[m+8>>2]=2309560,c[m+16>>2]=135,m)|0);i=m;Cd();return 0}n=k+f|0;o=k;if((f|0)<4){p=0;q=k}else{f=k;p=fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;q=k+4|0}if((n-q|0)<4){r=0;s=q}else{k=q;r=fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0;s=q+4|0}if((n-s|0)<4){t=0;u=s}else{q=s;t=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;u=s+4|0}do{if((n-u|0)>=4){s=u+4|0;q=u;if(!((p|0)==18&(r|0)==8&(t|0)==2&(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)==33554432)){break}do{if((n-s|0)<4){v=0}else{q=u+8|0;k=s;f=fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0;if(!((f|0)==61|(f|0)==3)){v=f;break}if((n-q|0)<4){w=0;x=q}else{f=q;w=fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;x=u+12|0}if((n-x|0)<1){y=0;z=x}else{y=d[x]|0;z=x+1|0}f=n-z|0;q=f>>>0>2>>>0?2:f;f=z+q|0;if((n-f|0)<2){A=0;B=f}else{k=f;A=(de((d[k]|d[k+1|0]<<8)<<16>>16|0)|0)&65535;B=z+(q+2)|0}if((n-B|0)<2){C=0;D=B}else{q=B;C=(de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;D=B+2|0}if(w>>>0<11>>>0){yDb(a,16,2055952,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}q=w-7|0;k=n-D|0;f=k>>>0>q>>>0?q:k;k=D+f|0;switch(y|0){case 6:{c[a+140>>2]=2;F=3;break};case 4:{c[a+140>>2]=45;F=2;break};case 3:{c[a+140>>2]=11;F=1;break};case 5:{c[a+140>>2]=43;F=2;break};case 7:{c[a+140>>2]=295;F=4;break};case 18:{c[a+140>>2]=66;F=2;break};default:{yDb(a,16,201e4,(m=i,i=i+8|0,c[m>>2]=y,m)|0);i=m;E=-1163346256;i=g;return E|0}}q=V$a(a,A,C)|0;if((q|0)<0){E=q;i=g;return E|0}q=_$a(a,h,0)|0;if((q|0)<0){E=q;i=g;return E|0}if((n-k|0)<4){G=0;H=k}else{q=k;G=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;H=D+(f+4)|0}a:do{if((c[a+140>>2]|0)==11){if(!((G|0)==61|(G|0)==3)){f=c[b+4>>2]|0;q=0;while(1){c[f>>2]=q*65793|0|-16777216;k=q+1|0;if((k|0)<256){f=f+4|0;q=k}else{break}}c[b+304>>2]=1;I=G;J=H;break}q=c[b+4>>2]|0;if((n-H|0)<4){K=0;L=H}else{f=H;K=fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;L=H+4|0}if((n-L|0)<1){M=0;N=L}else{M=d[L]|0;N=L+1|0}f=n-N|0;k=f>>>0>2>>>0?2:f;f=N+k|0;if((n-f|0)<2){O=f}else{O=N+(k+2)|0}k=(n-O|0)<2?O:O+2|0;if(K>>>0<11>>>0){yDb(a,16,1971256,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}f=K-7|0;P=n-k|0;Q=P>>>0>f>>>0?f:P;P=k+Q|0;if((M|0)!=7){yDb(a,16,1942592,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}if((n-P|0)<4){R=0;S=P}else{f=P;R=fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;S=k+(Q+4)|0}if((n-S|0)<4){T=0;U=S}else{Q=S;T=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)==134479872;U=S+4|0}Q=U;k=n-Q|0;f=U+(k>>>0>8>>>0?8:k)|0;do{if((R|0)==33&T){if((n-f|0)>>>0<1032>>>0){break}k=Q-1-n|0;P=k>>>0>4294967287>>>0?k:-9;k=1023-P|0;V=1019-P|0;P=f;W=q;X=0;while(1){c[W>>2]=(d[P+1|0]|0)<<16|(d[P+2|0]|0)<<8|(d[P+3|0]|0)|-16777216;Y=X+1|0;if((Y|0)<256){P=P+4|0;W=W+4|0;X=Y}else{break}}X=n-(U+k)|0;W=X>>>0>8>>>0?8:X;X=U+(V+(W+4))|0;c[b+304>>2]=1;if((n-X|0)<4){I=0;J=X;break a}P=X;I=fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;J=U+(V+(W+8))|0;break a}}while(0);yDb(a,16,1918096,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}else{I=G;J=H}}while(0);if((n-J|0)<4){Z=0;_=J}else{q=J;Z=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;_=J+4|0}q=n-_|0;f=ba(F,A)|0;Q=_+(q>>>0>8>>>0?8:q)|0;do{if((I|0)==33&(Z|0)==(n-Q|0)){if(((Z>>>0)/(f>>>0)|0)>>>0<C>>>0){break}iDb(c[b>>2]|0,c[b+32>>2]|0,(c[j>>2]|0)+(Q-o)|0,f,f,C);c[e>>2]=1;E=c[l>>2]|0;i=g;return E|0}}while(0);yDb(a,16,1897368,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}}while(0);yDb(a,16,2115120,(m=i,i=i+8|0,c[m>>2]=v,m)|0);i=m;E=-1094995529;i=g;return E|0}}while(0);yDb(a,16,2193336,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}function c$(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+60|0;d=c[b>>2]|0;c[a+140>>2]=11;a=d;c[a>>2]=ICb()|0;e=ICb()|0;c[d+4>>2]=e;if(!((c[a>>2]|0)==0|(e|0)==0)){f=0;return f|0}e=c[b>>2]|0;JCb(e);JCb(e+4|0);f=-12;return f|0}function d$(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[g+24>>2]|0;m=c[g+28>>2]|0;g=c[b+60>>2]|0;n=g+8|0;o=c[n>>2]|0;p=g;g=c[p+(o<<2)>>2]|0;q=c[p+((o^1)<<2)>>2]|0;o=V$a(b,320,192)|0;if((o|0)<0){r=o;i=h;return r|0}c[n>>2]=c[n>>2]^1;n=$$a(b,g)|0;if((n|0)<0){r=n;i=h;return r|0}n=c[g+32>>2]|0;if(!((m|0)>-1)){yDb(0,0,2009968,(s=i,i=i+24|0,c[s>>2]=1971240,c[s+8>>2]=1942568,c[s+16>>2]=135,s)|0);i=s;Cd();return 0}o=l+m|0;do{if((m|0)<1){t=l;u=0;v=g+88|0;w=9}else{p=l+1|0;x=d[l]|0;y=g+88|0;if((x&2|0)==0){t=p;u=x;v=y;w=9;break}c[y>>2]=1;c[g+84>>2]=1;z=p;A=x}}while(0);if((w|0)==9){c[v>>2]=2;c[g+84>>2]=0;z=t;A=u}u=g|0;t=q|0;v=j|0;l=k|0;x=j+1|0;p=z;z=0;y=0;a:while(1){B=p;C=z;D=0;E=(c[u>>2]|0)+(ba(y,n)|0)|0;while(1){F=c[t>>2]|0;if((C|0)==0){if((o-B|0)<1){G=0;w=61;break a}H=d[B]|0;I=B+1|0}else{H=C;I=B}J=H&15;b:do{switch(J|0){case 2:{if((o-I|0)<2){K=0;L=I}else{M=I;K=(d[M]|d[M+1|0]<<8)<<16>>16&65535;L=I+2|0}M=(K>>>0)%320|0;N=(K>>>0)/320|0;O=M-312|0;if((F|0)==0){P=L;break b}if((N+8|0)>>>0>192>>>0){w=25;break a}if((O|0)>0){Q=320-M|0;R=ba(N,n)|0;UGb(E+Q|0,F+R|0,O)|0;S=ba(N+1|0,n)|0;UGb(E+(n+Q)|0,F+S|0,O)|0;T=n<<1;U=ba(N+2|0,n)|0;UGb(E+(T+Q)|0,F+U|0,O)|0;V=n*3|0;W=ba(N+3|0,n)|0;UGb(E+(V+Q)|0,F+W|0,O)|0;X=n<<2;Y=ba(N+4|0,n)|0;UGb(E+(X+Q)|0,F+Y|0,O)|0;Z=n*5|0;_=ba(N+5|0,n)|0;UGb(E+(Z+Q)|0,F+_|0,O)|0;$=n*6|0;aa=ba(N+6|0,n)|0;UGb(E+($+Q)|0,F+aa|0,O)|0;ca=n*7|0;da=ba(N+7|0,n)|0;UGb(E+(ca+Q)|0,F+da|0,O)|0;ea=Q;fa=R;ga=S;ha=T;ia=U;ja=V;ka=W;la=X;ma=Y;na=Z;oa=_;pa=$;qa=aa;ra=ca;sa=da}else{ea=8;fa=ba(N,n)|0;ga=ba(N+1|0,n)|0;ha=n<<1;ia=ba(N+2|0,n)|0;ja=n*3|0;ka=ba(N+3|0,n)|0;la=n<<2;ma=ba(N+4|0,n)|0;na=n*5|0;oa=ba(N+5|0,n)|0;pa=n*6|0;qa=ba(N+6|0,n)|0;ra=n*7|0;sa=ba(N+7|0,n)|0}UGb(E|0,F+(fa+M)|0,ea)|0;UGb(E+n|0,F+(ga+M)|0,ea)|0;UGb(E+ha|0,F+(ia+M)|0,ea)|0;UGb(E+ja|0,F+(ka+M)|0,ea)|0;UGb(E+la|0,F+(ma+M)|0,ea)|0;UGb(E+na|0,F+(oa+M)|0,ea)|0;UGb(E+pa|0,F+(qa+M)|0,ea)|0;UGb(E+ra|0,F+(sa+M)|0,ea)|0;P=L;break};case 6:{ta=F;w=27;break};case 10:case 13:case 11:{M=I;N=0;while(1){da=M;ca=0;while(1){if((J|0)==10){aa=o-da|0;$=aa>>>0>2>>>0?2:aa;UGb(v|0,da|0,$)|0;aa=da+$|0;if((o-aa|0)<2){ua=0;va=aa}else{_=aa;ua=(d[_]|d[_+1|0]<<8)<<16>>16&65535;va=da+($+2)|0}$=ba(N,n)|0;a[E+(ca+$)|0]=a[j+(ua&1)|0]|0;_=ca|1;a[E+(_+$)|0]=a[j+(ua>>>1&1)|0]|0;aa=ca|2;a[E+(aa+$)|0]=a[j+(ua>>>2&1)|0]|0;Z=ca|3;a[E+(Z+$)|0]=a[j+(ua>>>3&1)|0]|0;$=ba(N|1,n)|0;a[E+(ca+$)|0]=a[j+(ua>>>4&1)|0]|0;a[E+(_+$)|0]=a[j+(ua>>>5&1)|0]|0;a[E+(aa+$)|0]=a[j+(ua>>>6&1)|0]|0;a[E+(Z+$)|0]=a[j+(ua>>>7&1)|0]|0;$=ba(N|2,n)|0;a[E+(ca+$)|0]=a[j+(ua>>>8&1)|0]|0;a[E+(_+$)|0]=a[j+(ua>>>9&1)|0]|0;a[E+(aa+$)|0]=a[j+(ua>>>10&1)|0]|0;a[E+(Z+$)|0]=a[j+(ua>>>11&1)|0]|0;$=ba(N|3,n)|0;a[E+(ca+$)|0]=a[j+(ua>>>12&1)|0]|0;a[E+(_+$)|0]=a[j+(ua>>>13&1)|0]|0;a[E+(aa+$)|0]=a[j+(ua>>>14&1)|0]|0;a[E+(Z+$)|0]=a[j+(ua>>>15)|0]|0;wa=va}else if((J|0)==13){$=o-da|0;Z=$>>>0>4>>>0?4:$;UGb(v|0,da|0,Z)|0;$=da+Z|0;if((o-$|0)<4){xa=0;ya=$}else{aa=$;xa=d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0;ya=da+(Z+4)|0}Z=ba(N,n)|0;a[E+(ca+Z)|0]=a[j+(xa&3)|0]|0;aa=ca|1;a[E+(aa+Z)|0]=a[j+(xa>>>2&3)|0]|0;$=ca|2;a[E+($+Z)|0]=a[j+(xa>>>4&3)|0]|0;_=ca|3;a[E+(_+Z)|0]=a[j+(xa>>>6&3)|0]|0;Z=ba(N|1,n)|0;a[E+(ca+Z)|0]=a[j+(xa>>>8&3)|0]|0;a[E+(aa+Z)|0]=a[j+(xa>>>10&3)|0]|0;a[E+($+Z)|0]=a[j+(xa>>>12&3)|0]|0;a[E+(_+Z)|0]=a[j+(xa>>>14&3)|0]|0;Z=ba(N|2,n)|0;a[E+(ca+Z)|0]=a[j+(xa>>>16&3)|0]|0;a[E+(aa+Z)|0]=a[j+(xa>>>18&3)|0]|0;a[E+($+Z)|0]=a[j+(xa>>>20&3)|0]|0;a[E+(_+Z)|0]=a[j+(xa>>>22&3)|0]|0;Z=ba(N|3,n)|0;a[E+(ca+Z)|0]=a[j+(xa>>>24&3)|0]|0;a[E+(aa+Z)|0]=a[j+(xa>>>26&3)|0]|0;a[E+($+Z)|0]=a[j+(xa>>>28&3)|0]|0;a[E+(_+Z)|0]=a[j+(xa>>>30)|0]|0;wa=ya}else{Z=o-da|0;_=Z>>>0>4>>>0?4:Z;UGb(l|0,da|0,_)|0;Z=da+_|0;if((o-Z|0)<2){za=0;Aa=Z}else{$=Z;za=(d[$]|d[$+1|0]<<8)<<16>>16&65535;Aa=da+(_+2)|0}_=k+1|0;$=za;Z=0;while(1){a[v]=a[k+((Z>>1)*3|0)|0]|0;aa=ba(Z+N|0,n)|0;a[x]=a[_]|0;a[E+(ca+aa)|0]=a[j+($&1)|0]|0;a[x]=a[_]|0;a[E+((ca|1)+aa)|0]=a[j+($>>>1&1)|0]|0;Y=k+2|0;a[x]=a[Y]|0;a[E+((ca|2)+aa)|0]=a[j+($>>>2&1)|0]|0;a[x]=a[Y]|0;a[E+((ca|3)+aa)|0]=a[j+($>>>3&1)|0]|0;aa=Z+1|0;if((aa|0)<4){$=$>>>4;Z=aa}else{wa=Aa;break}}}Z=ca+4|0;if((Z|0)<8){da=wa;ca=Z}else{break}}ca=N+4|0;if(ca>>>0<8>>>0){M=wa;N=ca}else{P=wa;break}}break};case 15:{N=o-I|0;M=N>>>0>8>>>0?8:N;UGb(E|0,I|0,M)|0;N=I+M|0;ca=o-N|0;da=ca>>>0>8>>>0?8:ca;UGb(E+n|0,N|0,da)|0;N=M+da|0;da=I+N|0;M=o-da|0;ca=M>>>0>8>>>0?8:M;UGb(E+(n<<1)|0,da|0,ca)|0;da=N+ca|0;ca=I+da|0;N=o-ca|0;M=N>>>0>8>>>0?8:N;UGb(E+(n*3|0)|0,ca|0,M)|0;ca=da+M|0;M=I+ca|0;da=o-M|0;N=da>>>0>8>>>0?8:da;UGb(E+(n<<2)|0,M|0,N)|0;M=ca+N|0;N=I+M|0;ca=o-N|0;da=ca>>>0>8>>>0?8:ca;UGb(E+(n*5|0)|0,N|0,da)|0;N=M+da|0;da=I+N|0;M=o-da|0;ca=M>>>0>8>>>0?8:M;UGb(E+(n*6|0)|0,da|0,ca)|0;da=N+ca|0;ca=I+da|0;N=o-ca|0;M=N>>>0>8>>>0?8:N;UGb(E+(n*7|0)|0,ca|0,M)|0;P=I+(da+M)|0;break};case 14:{P=I;break};case 7:{ta=c[u>>2]|0;w=27;break};case 8:{M=o-I|0;da=M>>>0>2>>>0?2:M;UGb(v|0,I|0,da)|0;M=I+da|0;da=0;while(1){if((o-M|0)<1){Ba=0;Ca=M}else{Ba=d[M]|0;Ca=M+1|0}ca=ba(da,n)|0;a[E+ca|0]=a[j+(Ba&1)|0]|0;a[E+(ca+1)|0]=a[j+(Ba>>>1&1)|0]|0;a[E+(ca+2)|0]=a[j+(Ba>>>2&1)|0]|0;a[E+(ca+3)|0]=a[j+(Ba>>>3&1)|0]|0;a[E+(ca+4)|0]=a[j+(Ba>>>4&1)|0]|0;a[E+(ca+5)|0]=a[j+(Ba>>>5&1)|0]|0;a[E+(ca+6)|0]=a[j+(Ba>>>6&1)|0]|0;a[E+(ca+7)|0]=a[j+(Ba>>>7)|0]|0;ca=da+1|0;if((ca|0)<8){M=Ca;da=ca}else{P=Ca;break}}break};default:{G=J;w=61;break a}}}while(0);if((w|0)==27){w=0;F=(J|0)==7;da=(ta|0)==0;M=I;ca=0;while(1){Da=ca+y|0;N=ba(ca,n)|0;Z=M;Ea=0;while(1){if((o-Z|0)<2){Fa=0;Ga=Z}else{$=Z;Fa=(d[$]|d[$+1|0]<<8)<<16>>16&65535;Ga=Z+2|0}Ha=(Fa>>>0)%320|0;$=(Fa>>>0)/320|0;if(F&($|0)==(Da|0)){_=Ha-D-Ea|0;if((((_|0)>-1?_:-_|0)-4|0)>>>0>312>>>0){w=33;break a}}_=Ea+N|0;aa=Ha-316|0;if(!da){if(($+4|0)>>>0>192>>>0){w=40;break a}if((aa|0)>0){Y=320-Ha|0;X=Y+_|0;W=ba($,n)|0;UGb(E+X|0,ta+W|0,aa)|0;V=ba($+1|0,n)|0;UGb(E+(X+n)|0,ta+V|0,aa)|0;U=n<<1;T=ba($+2|0,n)|0;UGb(E+(X+U)|0,ta+T|0,aa)|0;S=n*3|0;R=ba($+3|0,n)|0;UGb(E+(X+S)|0,ta+R|0,aa)|0;Ia=Y;Ja=W;Ka=V;La=U;Ma=T;Na=S;Oa=R}else{Ia=4;Ja=ba($,n)|0;Ka=ba($+1|0,n)|0;La=n<<1;Ma=ba($+2|0,n)|0;Na=n*3|0;Oa=ba($+3|0,n)|0}UGb(E+_|0,ta+(Ja+Ha)|0,Ia)|0;UGb(E+(n+_)|0,ta+(Ka+Ha)|0,Ia)|0;UGb(E+(La+_)|0,ta+(Ma+Ha)|0,Ia)|0;UGb(E+(Na+_)|0,ta+(Oa+Ha)|0,Ia)|0}_=Ea+4|0;if((_|0)<8){Z=Ga;Ea=_}else{break}}Z=ca+4|0;if(Z>>>0<8>>>0){M=Ga;ca=Z}else{P=Ga;break}}}Pa=H>>4;ca=D+8|0;if((ca|0)>=320){break}B=P;C=Pa;D=ca;E=E+8|0}E=y+8|0;if((E|0)<192){p=P;z=Pa;y=E}else{w=65;break}}if((w|0)==25){yDb(b,16,2055912,(s=i,i=i+8|0,c[s>>2]=K,s)|0);i=s;r=-1094995529;i=h;return r|0}else if((w|0)==33){DDb(b,2193248,(s=i,i=i+32|0,c[s>>2]=Ha,c[s+8>>2]=Ea+D,c[s+16>>2]=Da,c[s+24>>2]=Da,s)|0);i=s;r=-1094995529;i=h;return r|0}else if((w|0)==40){yDb(b,16,2055912,(s=i,i=i+8|0,c[s>>2]=Fa,s)|0);i=s;r=-1094995529;i=h;return r|0}else if((w|0)==61){yDb(b,16,2115024,(s=i,i=i+24|0,c[s>>2]=G,c[s+8>>2]=D,c[s+16>>2]=y,s)|0);i=s;r=-1094995529;i=h;return r|0}else if((w|0)==65){do{if((A&1|0)==0){w=c[q+4>>2]|0;if((w|0)==0){break}UGb(c[g+4>>2]|0,w|0,1024)|0}else{w=c[g+4>>2]|0;s=P;y=0;while(1){if((o-s|0)<3){Qa=-16777216;Ra=s}else{Qa=(d[s]|0)<<16|(d[s+1|0]|0)<<8|(d[s+2|0]|0)|-16777216;Ra=s+3|0}c[w+(y<<2)>>2]=Qa;D=y+1|0;if((D|0)<256){s=Ra;y=D}else{break}}c[g+304>>2]=1}}while(0);Ra=MCb(e,g)|0;if((Ra|0)<0){r=Ra;i=h;return r|0}c[f>>2]=1;r=m;i=h;return r|0}return 0}function e$(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b);JCb(b+4|0);return 0}function f$(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0;h=i;i=i+8|0;j=h|0;k=c[b+60>>2]|0;b=k;l=c[g+24>>2]|0;m=c[g+28>>2]|0;c[j>>2]=-1;if((m|0)==0){if((c[k+1620>>2]|0)!=0){n=0;i=h;return n|0}g=c[k+1596>>2]|0;if((c[g>>2]|0)==0){n=0;i=h;return n|0}c[f>>2]=1;QCb(e,g);n=0;i=h;return n|0}g=k+1700|0;c[g>>2]=0;o=l+m|0;m=f1a(l,o,j)|0;p=c[j>>2]|0;a:do{if(p>>>0>511>>>0|(m|0)==(o|0)){q=m}else{r=o;s=k+1568|0;t=s;u=s;s=k+1580|0;v=k+1584|0;w=k+1572|0;x=k+1576|0;y=k+1624|0;z=k+1628|0;A=k+1644|0;B=k+1648|0;C=k;D=k+1632|0;E=k+1620|0;F=k+1636|0;G=k+1640|0;H=k+1720|0;I=k+2316|0;J=k+1596|0;K=J;L=k+1604|0;M=L;N=k+1588|0;O=N;P=k+2312|0;Q=k+1592|0;R=k+1600|0;S=k+1612|0;T=k+1608|0;U=k+1616|0;V=k+2304|0;W=k+2308|0;X=k+2292|0;Y=k+1656|0;Z=k+1660|0;_=k+2e3|0;$=k+1996|0;aa=k+1680|0;ca=k+1664|0;da=k+1668|0;ea=k+1672|0;fa=k+1676|0;ga=e;ha=L;L=N;N=J;J=k+2296|0;ia=k+2300|0;ja=k+1652|0;ka=m;la=p;b:while(1){ma=r-ka<<3;c:do{switch(la|0){case 437:case 434:{break};case 435:{if((c[I>>2]|0)!=0){na=22;break c}KCb(c[K>>2]|0);KCb(c[M>>2]|0);c[I>>2]=1;na=22;break};case 438:{na=22;break};case 432:{oa=ma>>>0>2147483639>>>0|(ka|0)==0;pa=oa?0:ka;qa=oa?0:ma;c[u>>2]=pa;c[s>>2]=qa;oa=qa+8|0;c[v>>2]=oa;c[w>>2]=pa+(qa>>3);c[x>>2]=0;qa=pa;ra=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24)&255;qa=oa>>>0>8>>>0?8:oa;c[x>>2]=qa;c[y>>2]=ra;ra=pa+(qa>>>3)|0;sa=qa+8|0;c[z>>2]=(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24)&255;ra=(oa>>>0>sa>>>0?sa:oa)|1;sa=oa>>>0>ra>>>0?ra:oa;c[x>>2]=sa;ra=pa+(sa>>>3)|0;qa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>18;ra=sa+14|0;sa=oa>>>0>ra>>>0?ra:oa;c[x>>2]=sa;ra=pa+(sa>>>3)|0;ta=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>18;ra=sa+14|0;sa=oa>>>0>ra>>>0?ra:oa;c[x>>2]=sa;ra=c[A>>2]|0;if((ra|0)==0){if((c[B>>2]|0)!=0){na=13}}else{na=13}do{if((na|0)==13){na=0;if((ra|0)==(qa|0)){if((c[B>>2]|0)==(ta|0)){break}}EDb(c[C>>2]|0,2259176,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;break c}}while(0);if((qa|0)==0|(ta|0)==0){yDb(c[C>>2]|0,16,2244632,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;break c}c[A>>2]=qa;c[B>>2]=ta;ra=sa+2|0;va=(oa>>>0>ra>>>0?ra:oa)+3|0;ra=oa>>>0>va>>>0?va:oa;c[x>>2]=ra;va=pa+(ra>>>3)|0;wa=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(ra&7)>>>28;va=ra+4|0;ra=oa>>>0>va>>>0?va:oa;c[x>>2]=ra;c[D>>2]=wa;wa=pa+(ra>>>3)|0;va=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ra&7)>>>28;wa=ra+4|0;ra=(oa>>>0>wa>>>0?wa:oa)+18|0;wa=(oa>>>0>ra>>>0?ra:oa)+1|0;ra=(oa>>>0>wa>>>0?wa:oa)+12|0;wa=oa>>>0>ra>>>0?ra:oa;c[x>>2]=wa;ra=d[pa+(wa>>>3)|0]<<(wa&7)>>>7;c[x>>2]=((wa|0)<(oa|0))+wa;c[E>>2]=ra&1;c[F>>2]=(qa+15|0)>>>4;c[G>>2]=(ta+15|0)>>>4;ra=c[C>>2]|0;c[ra+108>>2]=c[1180208+(va<<3)>>2];c[ra+104>>2]=c[1180212+(va<<3)>>2];c[ra+120>>2]=c[A>>2];c[ra+124>>2]=c[B>>2];if((c[H>>2]|0)!=0){break c}eib(b);break};default:{if(!(la>>>0<432>>>0)){break c}ra=ma>>>0>2147483639>>>0|(ka|0)==0;va=ra?0:ka;wa=ra?0:ma;c[u>>2]=va;c[s>>2]=wa;c[v>>2]=wa+8;c[w>>2]=va+(wa>>3);c[x>>2]=0;h$(b,t)}}}while(0);d:do{if((na|0)==22){na=0;c[f>>2]=0;if((c[I>>2]|0)==0){break}wa=ma>>>0>2147483639>>>0|(ka|0)==0;va=wa?0:ka;ra=wa?0:ma;c[u>>2]=va;c[s>>2]=ra;c[v>>2]=ra+8;c[w>>2]=va+(ra>>3);c[x>>2]=0;c[g>>2]=c[j>>2];if((c[H>>2]|0)==0){yDb(c[C>>2]|0,16,1971208,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;break}KCb(c[O>>2]|0);ra=c[v>>2]|0;va=(c[x>>2]|0)+16|0;wa=ra>>>0>va>>>0?va:ra;c[x>>2]=wa;e:do{if((c[g>>2]|0)==438){va=(c[u>>2]|0)+(wa>>>3)|0;xa=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(wa&7)>>>30;va=wa+2|0;c[x>>2]=ra>>>0>va>>>0?va:ra;va=xa+1|0;xa=c[O>>2]|0;c[xa+88>>2]=va;if(va>>>0>3>>>0){yDb(c[C>>2]|0,16,1942544,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;break d}if((c[c[K>>2]>>2]|0)==0){break d}if((c[c[M>>2]>>2]|0)==0&(va|0)==3){break d}else{ya=xa;za=va}}else{va=c[O>>2]|0;c[va+88>>2]=1;xa=c[u>>2]|0;Aa=((wa|0)<(ra|0))+wa|0;if((d[xa+(wa>>>3)|0]&128>>>((wa&7)>>>0)|0)==0){Ba=Aa}else{Ca=Aa+24|0;Ba=ra>>>0>Ca>>>0?Ca:ra}c[x>>2]=Ba;do{if((c[E>>2]|0)==0){Ca=xa+(Ba>>>3)|0;Aa=(fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(Ba&7);if((Aa&8388608|0)==0){na=34;break}if((Aa&6291456|0)==0){if((c[ja>>2]|0)>0){break}else{ya=va;za=1;break e}}else{c[ja>>2]=1;break}}else{na=34}}while(0);if((na|0)==34){na=0;c[ja>>2]=1}xa=Ba+1|0;c[x>>2]=ra>>>0>xa>>>0?xa:ra;ya=va;za=1}}while(0);if((_$a(c[C>>2]|0,ya,(za|0)!=3|0)|0)<0){break}if((c[P>>2]|0)==0){ra=c[(c[O>>2]|0)+32>>2]|0;wa=cEb(((((ra|0)>-1?ra:-ra|0)<<1)+126&-64)*24|0)|0;c[P>>2]=wa;if((wa|0)==0){break}}if((dib(b)|0)<0){break}wa=c[x>>2]|0;ra=c[v>>2]|0;ta=c[u>>2]|0;qa=ta+(wa>>>3)|0;oa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(wa&7)>>>24;qa=wa+8|0;wa=ra>>>0>qa>>>0?qa:ra;c[x>>2]=wa;qa=oa<<1;c[Q>>2]=qa;oa=c[(c[O>>2]|0)+88>>2]|0;pa=(oa|0)==3;sa=c[R>>2]|0;if(pa){Da=512-qa+sa|0}else{Da=512-sa+qa|0}sa=(Da|0)%512|0;c[S>>2]=sa;xa=((qa|512)-(c[T>>2]|0)|0)%512|0;c[U>>2]=xa;qa=(sa|0)==0;if(qa){Ea=0}else{Ea=512/(sa|0)|0}c[V>>2]=Ea;Aa=(xa|0)==0;if(Aa){Fa=0}else{Fa=512/(xa|0)|0}c[W>>2]=Fa;if(pa){c[X>>2]=ba(Fa,sa)|0}else{if(qa){Ga=0}else{Ga=16384/(sa|0)|0}c[J>>2]=Ga;if(Aa){Ha=0}else{Ha=16384/(xa|0)|0}c[ia>>2]=Ha}do{if((c[E>>2]|0)==0){Ia=wa}else{xa=ta+(wa>>>3)|0;Aa=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(wa&7);if(Aa>>>0>134217727>>>0){xa=(d[1213744+(Aa>>>23)|0]|0)+wa|0;sa=ra>>>0>xa>>>0?xa:ra;c[x>>2]=sa;Ia=sa;break}sa=Aa>>>0>65535>>>0;xa=sa?Aa>>>16:Aa;Aa=sa?16:0;if((xa&65280|0)==0){Ja=Aa;Ka=xa}else{Ja=Aa|8;Ka=xa>>>8}xa=63-((d[1191992+Ka|0]|0)+Ja<<1)+wa|0;Aa=ra>>>0>xa>>>0?xa:ra;c[x>>2]=Aa;Ia=Aa}}while(0);wa=d[ta+(Ia>>>3)|0]<<(Ia&7)>>>7;Aa=((Ia|0)<(ra|0))+Ia|0;c[x>>2]=Aa;xa=wa&1;c[Y>>2]=xa;c[Z>>2]=1;do{if((xa|0)==0){wa=d[ta+(Aa>>>3)|0]<<(Aa&7)>>>7;sa=((Aa|0)<(ra|0))+Aa|0;c[x>>2]=sa;qa=wa&1;c[Z>>2]=qa;if((qa|0)!=0){La=sa;Ma=qa;break}if((c[g>>2]|0)!=438){La=sa;Ma=0;break}qa=sa+1|0;sa=ra>>>0>qa>>>0?qa:ra;c[x>>2]=sa;La=sa;Ma=0}else{La=Aa;Ma=1}}while(0);Aa=La+1|0;sa=(ra>>>0>Aa>>>0?Aa:ra)+1|0;Aa=ra>>>0>sa>>>0?sa:ra;c[x>>2]=Aa;sa=d[ta+(Aa>>>3)|0]<<(Aa&7)>>>7;qa=((Aa|0)<(ra|0))+Aa|0;c[x>>2]=qa;c[_>>2]=sa&1;sa=ta+(qa>>>3)|0;Aa=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(qa&7)>>>26;sa=qa+6|0;qa=ra>>>0>sa>>>0?sa:ra;c[x>>2]=qa;c[$>>2]=Aa;if((oa|0)==1){if((Ma|xa|0)==0){Aa=qa+1|0;sa=ra>>>0>Aa>>>0?Aa:ra;c[x>>2]=sa;Na=sa}else{Na=qa}sa=Na+4|0;Aa=ra>>>0>sa>>>0?sa:ra;c[x>>2]=Aa;Oa=Aa}else if((oa|0)==3){if((Ma|0)==1){Pa=qa;na=73}else{na=72}}else{na=72}if((na|0)==72){na=0;Aa=d[ta+(qa>>>3)|0]<<(qa&7)>>>7;sa=((qa|0)<(ra|0))+qa|0;c[x>>2]=sa;c[aa>>2]=Aa&1;Pa=sa;na=73}if((na|0)==73){na=0;sa=Pa+4|0;Aa=ra>>>0>sa>>>0?sa:ra;c[x>>2]=Aa;sa=d[ta+(Aa>>>3)|0]<<(Aa&7)>>>7;qa=((Aa|0)<(ra|0))+Aa|0;c[x>>2]=qa;c[ca>>2]=sa&1;Oa=qa}qa=d[ta+(Oa>>>3)|0]<<(Oa&7)>>>7;sa=((Oa|0)<(ra|0))+Oa|0;c[x>>2]=sa;Aa=qa&1;c[da>>2]=Aa;do{if((Aa|0)==0){qa=d[ta+(sa>>>3)|0]|0;wa=((sa|0)<(ra|0))+sa|0;c[x>>2]=wa;if((qa&128>>>((sa&7)>>>0)|0)==0){na=87;break}qa=ta+(wa>>>3)|0;pa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(wa&7);if(pa>>>0>134217727>>>0){qa=pa>>>23;Ca=(d[1213744+qa|0]|0)+wa|0;Qa=ra>>>0>Ca>>>0?Ca:ra;c[x>>2]=Qa;Ra=a[1139096+qa|0]|0;Sa=Qa}else{Qa=pa>>>0>65535>>>0;qa=Qa?pa>>>16:pa;pa=Qa?16:0;if((qa&65280|0)==0){Ta=pa;Ua=qa}else{Ta=pa|8;Ua=qa>>>8}qa=(d[1191992+Ua|0]|0)+Ta|0;pa=31-qa+wa|0;wa=ra>>>0>pa>>>0?pa:ra;pa=ta+(wa>>>3)|0;Qa=(fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(wa&7)>>>(qa>>>0);pa=wa+(32-qa)|0;qa=ra>>>0>pa>>>0?pa:ra;c[x>>2]=qa;pa=Qa>>>1;Ra=(Qa&1|0)==0?pa:-pa|0;Sa=qa}c[ea>>2]=Ra;qa=ta+(Sa>>>3)|0;pa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Sa&7);if(pa>>>0>134217727>>>0){qa=pa>>>23;Qa=(d[1213744+qa|0]|0)+Sa|0;c[x>>2]=ra>>>0>Qa>>>0?Qa:ra;Va=a[1139096+qa|0]|0}else{qa=pa>>>0>65535>>>0;Qa=qa?pa>>>16:pa;pa=qa?16:0;if((Qa&65280|0)==0){Wa=pa;Xa=Qa}else{Wa=pa|8;Xa=Qa>>>8}Qa=(d[1191992+Xa|0]|0)+Wa|0;pa=31-Qa+Sa|0;qa=ra>>>0>pa>>>0?pa:ra;pa=ta+(qa>>>3)|0;wa=(fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(qa&7)>>>(Qa>>>0);pa=qa+(32-Qa)|0;c[x>>2]=ra>>>0>pa>>>0?pa:ra;pa=wa>>>1;Va=(wa&1|0)==0?pa:-pa|0}c[fa>>2]=Va}else{na=87}}while(0);if((na|0)==87){na=0;c[fa>>2]=0;c[ea>>2]=0}if((oa|0)==2){ra=-1;while(1){ta=(i$(b)|0)==0;sa=ta?ra:-1;ta=c[ca>>2]|0;do{if((ta|0)!=0&(sa|0)<0){Aa=c[x>>2]|0;xa=c[v>>2]|0;pa=(c[u>>2]|0)+(Aa>>>3)|0;wa=(fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(Aa&7);if(wa>>>0>134217727>>>0){pa=wa>>>23;Qa=(d[1213744+pa|0]|0)+Aa|0;c[x>>2]=xa>>>0>Qa>>>0?Qa:xa;Ya=d[1108392+pa|0]|0;break}pa=wa>>>0>65535>>>0;Qa=pa?wa>>>16:wa;qa=pa?16:0;if((Qa&65280|0)==0){Za=qa;_a=Qa}else{Za=qa|8;_a=Qa>>>8}Qa=(d[1191992+_a|0]|0)+Za<<1;qa=63-Qa+Aa|0;c[x>>2]=xa>>>0>qa>>>0?qa:xa;Ya=(wa>>>((Qa-31|0)>>>0))-1|0}else{Ya=sa}}while(0);do{if((ta|0)==0){$a=Ya;na=99}else{sa=Ya-1|0;if((Ya|0)==0){$a=sa;na=99;break}k$(b,1);ab=sa}}while(0);do{if((na|0)==99){na=0;sa=c[x>>2]|0;va=c[v>>2]|0;Qa=(c[u>>2]|0)+(sa>>>3)|0;wa=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(sa&7);if(wa>>>0>134217727>>>0){Qa=wa>>>23;xa=(d[1213744+Qa|0]|0)+sa|0;c[x>>2]=va>>>0>xa>>>0?xa:va;bb=d[1108392+Qa|0]|0}else{Qa=wa>>>0>65535>>>0;xa=Qa?wa>>>16:wa;qa=Qa?16:0;if((xa&65280|0)==0){cb=qa;db=xa}else{cb=qa|8;db=xa>>>8}xa=(d[1191992+db|0]|0)+cb<<1;qa=63-xa+sa|0;c[x>>2]=va>>>0>qa>>>0?qa:va;bb=(wa>>>((xa-31|0)>>>0))-1|0}xa=ta+1+bb|0;if(xa>>>0>5>>>0){j$(b,xa-6|0);ab=$a;break}else{k$(b,xa);ab=$a;break}}}while(0);if((cib(b)|0)==0){break}else{ra=ab}}}else if((oa|0)==1){do{i$(b)|0;j$(b,0);}while((cib(b)|0)!=0)}else{oa=-1;while(1){ra=(i$(b)|0)==0;ta=ra?oa:-1;ra=c[ca>>2]|0;do{if((ra|0)!=0&(ta|0)<0){xa=c[x>>2]|0;wa=c[v>>2]|0;va=(c[u>>2]|0)+(xa>>>3)|0;qa=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(xa&7);if(qa>>>0>134217727>>>0){va=qa>>>23;sa=(d[1213744+va|0]|0)+xa|0;c[x>>2]=wa>>>0>sa>>>0?sa:wa;eb=d[1108392+va|0]|0;break}va=qa>>>0>65535>>>0;sa=va?qa>>>16:qa;Qa=va?16:0;if((sa&65280|0)==0){fb=Qa;gb=sa}else{fb=Qa|8;gb=sa>>>8}sa=(d[1191992+gb|0]|0)+fb<<1;Qa=63-sa+xa|0;c[x>>2]=wa>>>0>Qa>>>0?Qa:wa;eb=(qa>>>((sa-31|0)>>>0))-1|0}else{eb=ta}}while(0);do{if((ra|0)==0){hb=eb;na=117}else{ta=eb-1|0;if((eb|0)==0){hb=ta;na=117;break}l$(b,6);ib=ta}}while(0);do{if((na|0)==117){na=0;ta=c[x>>2]|0;sa=c[v>>2]|0;qa=(c[u>>2]|0)+(ta>>>3)|0;wa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ta&7);if(wa>>>0>134217727>>>0){qa=wa>>>23;Qa=(d[1213744+qa|0]|0)+ta|0;c[x>>2]=sa>>>0>Qa>>>0?Qa:sa;jb=d[1108392+qa|0]|0}else{qa=wa>>>0>65535>>>0;Qa=qa?wa>>>16:wa;xa=qa?16:0;if((Qa&65280|0)==0){kb=xa;lb=Qa}else{kb=xa|8;lb=Qa>>>8}Qa=(d[1191992+lb|0]|0)+kb<<1;xa=63-Qa+ta|0;c[x>>2]=sa>>>0>xa>>>0?xa:sa;jb=(wa>>>((Qa-31|0)>>>0))-1|0}Qa=ra+6+jb|0;if(Qa>>>0>29>>>0){j$(b,Qa-30|0);ib=hb;break}else{l$(b,Qa);ib=hb;break}}}while(0);if((cib(b)|0)==0){break}else{oa=ib}}}oa=c[O>>2]|0;do{if((c[oa+88>>2]|0)==3){c[f>>2]=1;mb=oa}else{KCb(c[M>>2]|0);ra=c[ha>>2]|0;Qa=c[ha+4>>2]|0;wa=c[L>>2]|0;sa=c[L+4>>2]|0;c[L>>2]=ra;c[L+4>>2]=Qa;Qa=c[N+4>>2]|0;c[ha>>2]=c[N>>2];c[ha+4>>2]=Qa;c[N>>2]=wa;c[N+4>>2]=sa;sa=ra;ra=(c[sa+88>>2]|0)==3;c[f>>2]=1;if(ra){mb=sa;break}sa=c[M>>2]|0;if((c[sa>>2]|0)==0){c[f>>2]=0;break d}else{ra=MCb(ga,sa)|0;if((ra|0)<0){n=ra;break b}else{break d}}}}while(0);QCb(ga,mb)}}while(0);ma=f1a(ka,o,j)|0;oa=c[j>>2]|0;if(oa>>>0>511>>>0|(ma|0)==(o|0)){q=ma;break a}else{ka=ma;la=oa}}i=h;return n|0}}while(0);if((c[g>>2]|0)==0){yDb(c[k>>2]|0,24,2193224,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua}ua=q-l|0;n=(ua|0)<0?0:ua;i=h;return n|0}function g$(a){a=a|0;c[(c[a+60>>2]|0)+2316>>2]=0;return}function h$(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=a+1700|0;g=c[f>>2]|0;if((g|0)>175){yDb(c[a>>2]|0,16,2114992,(h=i,i=i+8|0,c[h>>2]=g,h)|0);i=h;j=c[f>>2]|0}else{j=g}if((j|0)>=(c[a+1640>>2]|0)){yDb(c[a>>2]|0,16,2055880,(h=i,i=i+8|0,c[h>>2]=j,h)|0);i=h;i=e;return}g=a+1688|0;c[g>>2]=j;f=a+1636|0;c[a+1692>>2]=ba(c[f>>2]|0,j)|0;k=a+1696|0;c[k>>2]=c[k>>2]&-7;do{if((j|0)==0){k=a+2e3|0;if((c[k>>2]|0)!=0){break}l=b+8|0;m=c[l>>2]|0;n=c[b>>2]|0;o=(d[n+(m>>>3)|0]|0)<<(m&7)>>>7;p=b+16|0;c[l>>2]=((m|0)<(c[p>>2]|0))+m;c[k>>2]=o&1;o=c[l>>2]|0;k=c[p>>2]|0;p=n+(o>>>3)|0;n=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(o&7)>>>26;p=o+6|0;c[l>>2]=k>>>0>p>>>0?p:k;c[a+1996>>2]=n}}while(0);do{if((c[(c[a+1588>>2]|0)+88>>2]|0)==1){if((c[a+1660>>2]|0)!=0){i=e;return}if((c[g>>2]|0)>=((c[f>>2]|0)/2|0|0)){break}i=e;return}}while(0);f=b+8|0;g=c[f>>2]|0;j=d[(c[b>>2]|0)+(g>>>3)|0]|0;c[f>>2]=((g|0)<(c[b+16>>2]|0))+g;if((j&128>>>((g&7)>>>0)|0)==0){i=e;return}yDb(c[a>>2]|0,16,2009928,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;i=e;return}function i$(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=a+1568|0;if((c[a+1684>>2]|0)!=0){e=0;return e|0}f=a+1576|0;g=c[f>>2]|0;h=-g|0;i=h&7;j=c[b>>2]|0;if((i|0)==0){k=j+(g>>>3)|0;l=((fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(g&7)&-16777216|0)==-2147483648;m=l?8:0}else{m=i}i=m+24|0;if(i>>>0<26>>>0){l=j+(g>>>3)|0;n=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(g&7)>>>((8-m|0)>>>0)}else{l=c[a+1584>>2]|0;k=j+(g>>>3)|0;o=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(g&7)>>>16;k=g+16|0;p=l>>>0>k>>>0?k:l;l=j+(p>>>3)|0;n=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(p&7)>>>((24-m|0)>>>0)|o<<m+8}if((n&16777215|0)!=1){e=0;return e|0}n=c[a+1584>>2]|0;m=n-g|0;if((i|0)<(h|0)){q=h}else{q=(m|0)<(i|0)?m:i}i=q+g|0;c[f>>2]=i;g=j+(i>>>3)|0;j=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(i&7)>>>24;g=i+8|0;c[f>>2]=n>>>0>g>>>0?g:n;c[a+1700>>2]=j;if((j|0)>=(c[a+1640>>2]|0)){e=0;return e|0}h$(a,b);e=1;return e|0}function j$(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+40|0;g=f|0;h=f+8|0;j=f+32|0;k=b+1568|0;c[j>>2]=0;bib(b);l=b+1576|0;m=k|0;n=b+1584|0;o=0;do{p=d[473480+o|0]|0;q=c[b+1932+(p-1<<2)>>2]|0;r=c[b+1932+(p-3<<2)>>2]|0;s=(q|0)>(r|0)?r:q;q=(s|0)==-1?2:s;s=c[l>>2]|0;r=c[m>>2]|0;t=d[r+(s>>>3)|0]|0;u=c[n>>2]|0;v=((s|0)<(u|0))+s|0;c[l>>2]=v;if((t&128>>>((s&7)>>>0)|0)==0){s=r+(v>>>3)|0;r=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(v&7)>>>30;s=v+2|0;c[l>>2]=u>>>0>s>>>0?s:u;w=((r|0)>=(q|0))+r|0}else{w=q}c[b+1932+(p<<2)>>2]=w;o=o+1|0;}while((o|0)<4);o=c[l>>2]|0;w=c[n>>2]|0;p=(c[m>>2]|0)+(o>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(o&7);if(q>>>0>134217727>>>0){p=q>>>23;r=(d[1213744+p|0]|0)+o|0;c[l>>2]=w>>>0>r>>>0?r:w;x=d[1108392+p|0]|0}else{p=q>>>0>65535>>>0;r=p?q>>>16:q;u=p?16:0;if((r&65280|0)==0){y=u;z=r}else{y=u|8;z=r>>>8}r=(d[1191992+z|0]|0)+y<<1;y=63-r+o|0;c[l>>2]=w>>>0>y>>>0?y:w;x=(q>>>((r-31|0)>>>0))-1|0}c[g>>2]=x;if(x>>>0>6>>>0){yDb(c[b>>2]|0,16,2290784,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;i=f;return}Zhb(b,g);x=b+1588|0;do{if((c[(c[x>>2]|0)+88>>2]|0)==1){r=c[l>>2]|0;q=c[n>>2]|0;w=(c[m>>2]|0)+(r>>>3)|0;y=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(r&7);if(y>>>0>134217727>>>0){w=y>>>23;o=(d[1213744+w|0]|0)+r|0;c[l>>2]=q>>>0>o>>>0?o:q;B=d[1108392+w|0]|0;break}w=y>>>0>65535>>>0;o=w?y>>>16:y;z=w?16:0;if((o&65280|0)==0){C=z;D=o}else{C=z|8;D=o>>>8}o=(d[1191992+D|0]|0)+C<<1;z=63-o+r|0;c[l>>2]=q>>>0>z>>>0?z:q;B=(y>>>((o-31|0)>>>0))-1|0}else{B=e}}while(0);if(B>>>0>63>>>0){yDb(c[b>>2]|0,16,2274856,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;i=f;return}A=b+2004|0;c[A>>2]=d[1502720+(B<<1)|0]|0;do{if((B|0)!=4){if((c[b+2e3>>2]|0)!=0){break}e=b+1996|0;C=c[e>>2]|0;D=c[l>>2]|0;o=c[n>>2]|0;y=c[m>>2]|0;q=y+(D>>>3)|0;z=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(D&7);if(z>>>0>134217727>>>0){q=z>>>23;r=(d[1213744+q|0]|0)+D|0;c[l>>2]=o>>>0>r>>>0?r:o;E=a[1139096+q|0]|0}else{q=z>>>0>65535>>>0;r=q?z>>>16:z;z=q?16:0;if((r&65280|0)==0){F=z;G=r}else{F=z|8;G=r>>>8}r=(d[1191992+G|0]|0)+F|0;z=31-r+D|0;D=o>>>0>z>>>0?z:o;z=y+(D>>>3)|0;y=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(D&7)>>>(r>>>0);z=D+(32-r)|0;c[l>>2]=o>>>0>z>>>0?z:o;o=y>>>1;E=(y&1|0)==0?o:-o|0}c[e>>2]=E+C&63}}while(0);E=b+1704|0;l=h|0;h=b+1972|0;F=b+1996|0;G=0;do{m=(c[E>>2]|0)+(c[b+1980+(G<<2)>>2]|0)|0;Xhb(b,l,j,G);cf[c[b+2228+(c[b+1932+((a[473480+G|0]&255)<<2)>>2]<<2)>>2]&1023](m,l,c[j>>2]|0,c[h>>2]|0);if((c[A>>2]&1<<G|0)!=0){n$(b,k,906736,1,c[F>>2]|0,m,c[h>>2]|0)}G=G+1|0;}while((G|0)<4);Yhb(b);G=b+1708|0;h=b+1684|0;j=b+1976|0;cf[c[b+2260+(c[g>>2]<<2)>>2]&1023](c[G>>2]|0,(c[b+2144>>2]|0)+((c[h>>2]|0)*10|0)|0,b+2178|0,c[j>>2]|0);l=b+1712|0;cf[c[b+2260+(c[g>>2]<<2)>>2]&1023](c[l>>2]|0,(c[b+2148>>2]|0)+((c[h>>2]|0)*10|0)|0,b+2188|0,c[j>>2]|0);h=c[A>>2]|0;if((h&16|0)==0){H=h}else{n$(b,k,1486072,0,d[1669056+(c[F>>2]|0)|0]|0,c[G>>2]|0,c[j>>2]|0);H=c[A>>2]|0}if((H&32|0)!=0){n$(b,k,1486072,0,d[1669056+(c[F>>2]|0)|0]|0,c[l>>2]|0,c[j>>2]|0)}Whb(b,0);j=b+1768|0;l=1255584;F=c[l>>2]|0;k=c[l+4>>2]|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1800|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1808|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1776|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1864|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1896|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1904|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1872|0;c[j>>2]=F;c[j+4>>2]=k;if((c[(c[x>>2]|0)+88>>2]|0)==3){i=f;return}a[(c[b+2288>>2]|0)+(c[b+1692>>2]|0)|0]=0;i=f;return}function k$(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=b+1568|0;bib(b);switch(e|0){case 4:{if((c[b+1680>>2]|0)==0){g=b+1576|0;h=c[g>>2]|0;i=c[f>>2]|0;j=(d[i+(h>>>3)|0]|0)<<(h&7)>>>7;k=c[b+1584>>2]|0;l=((h|0)<(k|0))+h|0;c[g>>2]=l;h=(d[i+(l>>>3)|0]|0)<<(l&7)>>>7;c[g>>2]=((l|0)<(k|0))+l;m=h&1;n=j&1}else{m=0;n=0}aib(b,5,2,1,2,n);aib(b,6,3,3,2,m);break};case 1:{aib(b,5,3,4,0,0);break};case 3:{if((c[b+1680>>2]|0)==0){m=b+1576|0;n=c[m>>2]|0;j=c[f>>2]|0;h=(d[j+(n>>>3)|0]|0)<<(n&7)>>>7;l=c[b+1584>>2]|0;k=((n|0)<(l|0))+n|0;c[m>>2]=k;n=(d[j+(k>>>3)|0]|0)<<(k&7)>>>7;c[m>>2]=((k|0)<(l|0))+k;o=n&1;p=h&1}else{o=0;p=0}aib(b,5,3,2,1,p);aib(b,9,4,1,1,o);break};case 5:{if((c[b+1680>>2]|0)==0){o=b+1576|0;p=c[o>>2]|0;h=c[f>>2]|0;n=(d[h+(p>>>3)|0]|0)<<(p&7)>>>7;k=c[b+1584>>2]|0;l=((p|0)<(k|0))+p|0;c[o>>2]=l;p=(d[h+(l>>>3)|0]|0)<<(l&7)>>>7;m=((l|0)<(k|0))+l|0;c[o>>2]=m;l=(d[h+(m>>>3)|0]|0)<<(m&7)>>>7;j=((m|0)<(k|0))+m|0;c[o>>2]=j;m=(d[h+(j>>>3)|0]|0)<<(j&7)>>>7;c[o>>2]=((j|0)<(k|0))+j;q=m&1;r=p&1;s=n&1;t=l&1}else{q=0;r=0;s=0;t=0}aib(b,5,2,0,3,s);aib(b,6,3,0,3,r);aib(b,9,6,0,3,t);aib(b,10,5,0,3,q);break};case 2:{if((c[b+1680>>2]|0)==0){q=b+1576|0;t=c[q>>2]|0;r=(d[(c[f>>2]|0)+(t>>>3)|0]|0)<<(t&7)>>>7;c[q>>2]=((t|0)<(c[b+1584>>2]|0))+t;u=r&1}else{u=0}aib(b,5,3,0,0,u);break};default:{}}_hb(b,e);u=b+1956|0;if((c[b+1652>>2]|0)>0){c[u>>2]=-1;c[b+1944>>2]=-1;r=b+1684|0;t=c[b+1968>>2]|0;c[t+((c[r>>2]<<1|1)<<2)>>2]=-1;c[t+(c[r>>2]<<1<<2)>>2]=-1}else{c[u>>2]=2;c[b+1944>>2]=2;u=b+1684|0;r=c[b+1968>>2]|0;c[r+((c[u>>2]<<1|1)<<2)>>2]=2;c[r+(c[u>>2]<<1<<2)>>2]=2}u=b+1692|0;r=b+1928|0;t=b+1768|0;q=(c[r>>2]|0)+(c[u>>2]<<2<<3)|0;f=c[t+4>>2]|0;c[q>>2]=c[t>>2];c[q+4>>2]=f;f=b+1776|0;q=(c[r>>2]|0)+((c[u>>2]<<2|1)<<3)|0;t=c[f+4>>2]|0;c[q>>2]=c[f>>2];c[q+4>>2]=t;t=b+1800|0;q=(c[r>>2]|0)+((c[u>>2]<<2|2)<<3)|0;f=c[t+4>>2]|0;c[q>>2]=c[t>>2];c[q+4>>2]=f;f=b+1808|0;q=(c[r>>2]|0)+((c[u>>2]<<2|3)<<3)|0;r=c[f+4>>2]|0;c[q>>2]=c[f>>2];c[q+4>>2]=r;if((e|0)==1){Whb(b,e);v=e&255;w=c[u>>2]|0;x=b+2288|0;y=c[x>>2]|0;z=y+w|0;a[z]=v;return}m$(b);Whb(b,e);v=e&255;w=c[u>>2]|0;x=b+2288|0;y=c[x>>2]|0;z=y+w|0;a[z]=v;return}function l$(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+16|0;h=g|0;bib(e);j=e+1768|0;k=j;l=1255592;m=c[l>>2]|0;n=c[l+4>>2]|0;c[k>>2]=m;c[k+4>>2]=n;k=e+1800|0;c[k>>2]=m;c[k+4>>2]=n;k=e+1808|0;c[k>>2]=m;c[k+4>>2]=n;k=e+1776|0;c[k>>2]=m;c[k+4>>2]=n;k=e+1864|0;l=k;c[l>>2]=m;c[l+4>>2]=n;o=e+1896|0;p=o;c[p>>2]=m;c[p+4>>2]=n;q=e+1904|0;c[q>>2]=m;c[q+4>>2]=n;r=e+1872|0;s=r;c[s>>2]=m;c[s+4>>2]=n;a:do{switch(f|0){case 9:{aib(e,17,15,0,0,0);break};case 6:case 7:{n=e+1692|0;m=c[n>>2]|0;if((a[(c[e+2288>>2]|0)+m|0]|0)==0){aib(e,5,3,5,0,1);aib(e,17,15,5,0,0);break a}t=e+1928|0;u=e+1616|0;v=e+1612|0;w=0;x=m;while(1){m=d[643056+w|0]|0;y=(x<<2)+w|0;z=c[t>>2]|0;A=c[e+2296+(b[z+(y<<3)+6>>1]<<2)>>2]|0;B=z+(y<<3)|0;C=b[B>>1]|0;D=C>>31;E=c[u>>2]&65535;b[e+1728+(m<<3)+4>>1]=E;F=c[v>>2]&65535;G=m+12|0;b[e+1728+(G<<3)+4>>1]=F;b[e+1728+(m<<3)+6>>1]=1;b[e+1728+(G<<3)+6>>1]=0;H=ba(E<<16>>16,A)|0;E=A+1073741823|0;I=(C>>>31)+E|0;b[e+1728+(m<<3)>>1]=((((ba(H,b[B>>1]|0)|0)^D)+I|0)>>>14^D)-D;C=ba(F<<16>>16,A)|0;b[e+1728+(G<<3)>>1]=D-((((ba(C,b[B>>1]|0)|0)^D)+I|0)>>>14^D);D=z+(y<<3)+2|0;y=b[D>>1]|0;z=y>>31;I=(y>>>31)+E|0;b[e+1728+(m<<3)+2>>1]=((I+((ba(H,y)|0)^z)|0)>>>14^z)-z;b[e+1728+(G<<3)+2>>1]=z-((((ba(C,b[D>>1]|0)|0)^z)+I|0)>>>14^z);z=w+1|0;if((z|0)>=4){break a}w=z;x=c[n>>2]|0}break};case 8:{aib(e,5,3,0,0,1);break};case 10:{aib(e,5,3,0,0,1);n=c[e+1612>>2]|0;x=c[e+2292>>2]|0;b[k>>1]=-(((ba(b[j>>1]|0,x)|0)+256|0)>>>9);b[e+1866>>1]=-(((ba(b[e+1770>>1]|0,x)|0)+256|0)>>>9);b[e+1870>>1]=0;b[e+1868>>1]=n;n=c[l>>2]|0;x=c[l+4>>2]|0;c[p>>2]=n;c[p+4>>2]=x;c[q>>2]=n;c[q+4>>2]=x;c[s>>2]=n;c[s+4>>2]=x;break};case 29:{x=e+1576|0;n=c[x>>2]|0;w=c[e+1584>>2]|0;v=c[e+1568>>2]|0;u=v+(n>>>3)|0;t=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(n&7)>>>30;u=n+2|0;n=w>>>0>u>>>0?u:w;c[x>>2]=n;c[h>>2]=t;u=v+(n>>>3)|0;z=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(n&7)>>>30;u=n+2|0;n=w>>>0>u>>>0?u:w;c[x>>2]=n;c[h+4>>2]=z;u=v+(n>>>3)|0;I=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(n&7)>>>30;u=n+2|0;n=w>>>0>u>>>0?u:w;c[x>>2]=n;c[h+8>>2]=I;u=v+(n>>>3)|0;v=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(n&7)>>>30;u=n+2|0;c[x>>2]=w>>>0>u>>>0?u:w;c[h+12>>2]=v;w=e+1692|0;u=e+2288|0;x=e+1928|0;n=e+1616|0;D=e+1612|0;C=e+2292|0;G=0;y=t;while(1){do{if((y|0)==3){H=d[643056+G|0]|0;aib(e,H,H-3|0,0,3,1);m=c[D>>2]|0;E=c[C>>2]|0;B=H+12|0;b[e+1728+(B<<3)>>1]=-(((ba(b[e+1728+(H<<3)>>1]|0,E)|0)+256|0)>>>9);b[e+1728+(B<<3)+2>>1]=-(((ba(b[e+1728+(H<<3)+2>>1]|0,E)|0)+256|0)>>>9);b[e+1728+(B<<3)+6>>1]=0;b[e+1728+(B<<3)+4>>1]=m}else if((y|0)==0){m=c[w>>2]|0;B=d[643056+G|0]|0;if((a[(c[u>>2]|0)+m|0]|0)==0){aib(e,B,B-3|0,5,3,1);aib(e,B+12|0,B+9|0,5,3,0);break}else{E=(m<<2)+G|0;m=c[x>>2]|0;H=c[e+2296+(b[m+(E<<3)+6>>1]<<2)>>2]|0;A=m+(E<<3)|0;F=b[A>>1]|0;J=F>>31;K=c[n>>2]&65535;b[e+1728+(B<<3)+4>>1]=K;L=c[D>>2]&65535;M=B+12|0;b[e+1728+(M<<3)+4>>1]=L;b[e+1728+(B<<3)+6>>1]=1;b[e+1728+(M<<3)+6>>1]=0;N=ba(K<<16>>16,H)|0;K=H+1073741823|0;O=(F>>>31)+K|0;b[e+1728+(B<<3)>>1]=((((ba(N,b[A>>1]|0)|0)^J)+O|0)>>>14^J)-J;F=ba(L<<16>>16,H)|0;b[e+1728+(M<<3)>>1]=J-((((ba(F,b[A>>1]|0)|0)^J)+O|0)>>>14^J);J=m+(E<<3)+2|0;E=b[J>>1]|0;m=E>>31;O=(E>>>31)+K|0;b[e+1728+(B<<3)+2>>1]=((O+((ba(N,E)|0)^m)|0)>>>14^m)-m;b[e+1728+(M<<3)+2>>1]=m-((((ba(F,b[J>>1]|0)|0)^m)+O|0)>>>14^m);break}}else if((y|0)==1){m=d[643056+G|0]|0;aib(e,m,m-3|0,0,3,1)}}while(0);m=G+1|0;if((m|0)>=4){break}G=m;y=c[h+(m<<2)>>2]|0}if((t|0)==2){aib(e,17,14,0,3,0)}if((z|0)==2){aib(e,18,15,0,3,0)}if((I|0)==2){aib(e,21,18,0,3,0)}if((v|0)!=2){break a}aib(e,22,19,0,3,0);break};default:{if(f>>>0<11>>>0){yDb(c[e>>2]|0,16,1918064,(y=i,i=i+8|0,c[y>>2]=f,y)|0);i=y;i=g;return}y=d[1255552+f|0]|0;G=(y&1|0)!=0;if((f&1|0)==0){if(G){aib(e,5,2,1,2,1)}if((y&16|0)!=0){D=c[e+1612>>2]|0;n=c[e+2292>>2]|0;b[k>>1]=-(((ba(b[j>>1]|0,n)|0)+256|0)>>>9);b[e+1866>>1]=-(((ba(b[e+1770>>1]|0,n)|0)+256|0)>>>9);b[e+1870>>1]=0;b[e+1868>>1]=D;D=c[l+4>>2]|0;c[p>>2]=c[l>>2];c[p+4>>2]=D}if((y&2|0)!=0){aib(e,6,3,3,2,1)}if((y&32|0)!=0){D=c[e+1612>>2]|0;n=c[e+2292>>2]|0;b[r>>1]=-(((ba(b[e+1776>>1]|0,n)|0)+256|0)>>>9);b[e+1874>>1]=-(((ba(b[e+1778>>1]|0,n)|0)+256|0)>>>9);b[e+1878>>1]=0;b[e+1876>>1]=D;D=c[s+4>>2]|0;c[q>>2]=c[s>>2];c[q+4>>2]=D}if((y&4|0)!=0){aib(e,17,14,1,2,0)}if((y&8|0)==0){break a}aib(e,18,15,3,2,0);break a}else{if(G){aib(e,5,3,2,1,1)}if((y&16|0)!=0){G=c[e+1612>>2]|0;D=c[e+2292>>2]|0;b[k>>1]=-(((ba(b[j>>1]|0,D)|0)+256|0)>>>9);b[e+1866>>1]=-(((ba(b[e+1770>>1]|0,D)|0)+256|0)>>>9);b[e+1870>>1]=0;b[e+1868>>1]=G;G=c[l+4>>2]|0;c[s>>2]=c[l>>2];c[s+4>>2]=G}if((y&2|0)!=0){aib(e,9,4,1,1,1)}if((y&32|0)!=0){G=c[e+1612>>2]|0;D=c[e+2292>>2]|0;b[o>>1]=-(((ba(b[e+1800>>1]|0,D)|0)+256|0)>>>9);b[e+1898>>1]=-(((ba(b[e+1802>>1]|0,D)|0)+256|0)>>>9);b[e+1902>>1]=0;b[e+1900>>1]=G;G=c[p+4>>2]|0;c[q>>2]=c[p>>2];c[q+4>>2]=G}if((y&4|0)!=0){aib(e,17,15,2,1,0)}if((y&8|0)==0){break a}aib(e,21,16,1,1,0);break a}}}}while(0);_hb(e,f);q=e+1956|0;if((c[e+1652>>2]|0)>0){c[q>>2]=-1;c[e+1944>>2]=-1;p=e+1684|0;o=c[e+1968>>2]|0;c[o+((c[p>>2]<<1|1)<<2)>>2]=-1;c[o+(c[p>>2]<<1<<2)>>2]=-1}else{c[q>>2]=2;c[e+1944>>2]=2;q=e+1684|0;p=c[e+1968>>2]|0;c[p+((c[q>>2]<<1|1)<<2)>>2]=2;c[p+(c[q>>2]<<1<<2)>>2]=2}if((f|0)!=6){m$(e)}Whb(e,f);i=g;return}function m$(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;f=b+1568|0;g=b+1576|0;h=c[g>>2]|0;j=c[b+1584>>2]|0;k=c[f>>2]|0;l=k+(h>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7);if(m>>>0>134217727>>>0){l=m>>>23;n=(d[1213744+l|0]|0)+h|0;o=j>>>0>n>>>0?n:j;c[g>>2]=o;p=d[1108392+l|0]|0;q=o}else{o=m>>>0>65535>>>0;l=o?m>>>16:m;n=o?16:0;if((l&65280|0)==0){r=n;s=l}else{r=n|8;s=l>>>8}l=(d[1191992+s|0]|0)+r<<1;r=63-l+h|0;h=j>>>0>r>>>0?r:j;c[g>>2]=h;p=(m>>>((l-31|0)>>>0))-1|0;q=h}if(p>>>0>63>>>0){yDb(c[b>>2]|0,16,1897344,(h=i,i=i+8|0,c[h>>2]=p,h)|0);i=h;i=e;return}h=d[1502721+(p<<1)|0]|0;l=b+2004|0;c[l>>2]=h;do{if((p|0)!=0){if((c[b+2e3>>2]|0)!=0){break}m=b+1996|0;r=c[m>>2]|0;s=k+(q>>>3)|0;n=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(q&7);if(n>>>0>134217727>>>0){s=n>>>23;o=(d[1213744+s|0]|0)+q|0;c[g>>2]=j>>>0>o>>>0?o:j;t=a[1139096+s|0]|0}else{s=n>>>0>65535>>>0;o=s?n>>>16:n;n=s?16:0;if((o&65280|0)==0){u=n;v=o}else{u=n|8;v=o>>>8}o=(d[1191992+v|0]|0)+u|0;n=31-o+q|0;s=j>>>0>n>>>0?n:j;n=k+(s>>>3)|0;w=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(s&7)>>>(o>>>0);n=s+(32-o)|0;c[g>>2]=j>>>0>n>>>0?n:j;n=w>>>1;t=(w&1|0)==0?n:-n|0}c[m>>2]=t+r&63}}while(0);t=b+1996|0;j=b+1704|0;g=b+1972|0;if((h&1|0)==0){x=h}else{n$(b,f,910472,0,c[t>>2]|0,(c[j>>2]|0)+(c[b+1980>>2]|0)|0,c[g>>2]|0);x=c[l>>2]|0}if((x&2|0)==0){y=x}else{n$(b,f,910472,0,c[t>>2]|0,(c[j>>2]|0)+(c[b+1984>>2]|0)|0,c[g>>2]|0);y=c[l>>2]|0}if((y&4|0)==0){z=y}else{n$(b,f,910472,0,c[t>>2]|0,(c[j>>2]|0)+(c[b+1988>>2]|0)|0,c[g>>2]|0);z=c[l>>2]|0}if((z&8|0)==0){A=z}else{n$(b,f,910472,0,c[t>>2]|0,(c[j>>2]|0)+(c[b+1992>>2]|0)|0,c[g>>2]|0);A=c[l>>2]|0}if((A&16|0)==0){B=A}else{n$(b,f,1486072,0,d[1669056+(c[t>>2]|0)|0]|0,c[b+1708>>2]|0,c[b+1976>>2]|0);B=c[l>>2]|0}if((B&32|0)==0){i=e;return}n$(b,f,1486072,0,d[1669056+(c[t>>2]|0)|0]|0,c[b+1712>>2]|0,c[b+1976>>2]|0);i=e;return}function n$(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;n=i;i=i+208|0;o=n|0;p=n+136|0;q=c[f+2320>>2]|0;r=g+8|0;s=g+16|0;t=g|0;g=-2147483648>>>(j>>>0);u=(j|0)==0;v=32-j|0;w=0;x=h;while(1){h=a[x+204|0]|0;y=h<<24>>24;z=c[r>>2]|0;A=c[s>>2]|0;B=c[t>>2]|0;C=B+(z>>>3)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(z&7);if(D>>>0>134217727>>>0){C=D>>>23;E=(d[1213744+C|0]|0)+z|0;F=A>>>0>E>>>0?E:A;c[r>>2]=F;G=d[1108392+C|0]|0;H=F}else{F=D>>>0>65535>>>0;C=F?D>>>16:D;E=F?16:0;if((C&65280|0)==0){I=E;J=C}else{I=E|8;J=C>>>8}C=(d[1191992+J|0]|0)+I<<1;E=63-C+z|0;z=A>>>0>E>>>0?E:A;c[r>>2]=z;G=(D>>>((C-31|0)>>>0))-1|0;H=z}if(!(G>>>0<-2147483648>>>(y>>>0)>>>0)){K=8;break}if(h<<24>>24==0){L=G;M=H}else{h=B+(H>>>3)|0;z=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(H&7)>>>((32-y|0)>>>0);h=H+y|0;C=A>>>0>h>>>0?h:A;c[r>>2]=C;L=z+(G<<y)|0;M=C}if(L>>>0>58>>>0){C=((L-59|0)>>>1)+1|0;if(C>>>0>64>>>0){N=C;break}y=B+(M>>>3)|0;z=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(M&7);if(z>>>0>134217727>>>0){y=z>>>23;h=(d[1213744+y|0]|0)+M|0;D=A>>>0>h>>>0?h:A;c[r>>2]=D;O=d[1108392+y|0]|0;P=D}else{D=z>>>0>65535>>>0;y=D?z>>>16:z;h=D?16:0;if((y&65280|0)==0){Q=h;R=y}else{Q=h|8;R=y>>>8}y=(d[1191992+R|0]|0)+Q<<1;h=63-y+M|0;D=A>>>0>h>>>0?h:A;c[r>>2]=D;O=(z>>>((y-31|0)>>>0))-1|0;P=D}do{if(O>>>0<g>>>0){if(u){S=O;break}D=B+(P>>>3)|0;y=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(P&7)>>>(v>>>0);D=P+j|0;c[r>>2]=A>>>0>D>>>0?D:A;S=y+(O<<j)|0}else{yDb(0,16,2309528,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;S=-1094995529}}while(0);if(C>>>0>(a[x+212|0]|0)>>>0){U=1}else{U=a[x+177+C|0]|0}A=U+S|0;B=x;while(1){if((A|0)>(c[B+208>>2]|0)){B=B+216|0}else{break}}y=L&1;V=C&255;W=B;X=(A^-y)+y&65535}else{y=a[x+(L*3|0)|0]|0;if(y<<24>>24==0){Y=w;K=31;break}V=a[x+(L*3|0)+1|0]|0;W=x+((a[x+(L*3|0)+2|0]|0)*216|0)|0;X=y<<24>>24}b[o+(w<<1)>>1]=X;a[p+w|0]=V;y=w+1|0;if((y|0)<65){w=y;x=W}else{Y=y;K=31;break}}if((K|0)==8){yDb(0,16,2309528,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;N=1599985855}else if((K|0)==31){K=e[1381200+(k<<1)>>1]|0;W=d[1381136+k|0]|0;k=1<<W-1;a:do{if((Y|0)>0){x=-1;w=Y;while(1){w=w-1|0;x=(d[p+w|0]|0)+x|0;if((x|0)>63){break}V=(ba(b[o+(w<<1)>>1]|0,K)|0)+k>>W&65535;b[q+(d[f+2012+x|0]<<1)>>1]=V;if((w|0)<=0){break a}}w=c[f+1684>>2]|0;x=c[f+1688>>2]|0;yDb(c[f>>2]|0,16,2334304,(T=i,i=i+24|0,c[T>>2]=c[f+1592>>2],c[T+8>>2]=w,c[T+16>>2]=x,T)|0);i=T;i=n;return}}while(0);Xe[c[f+1560>>2]&4095](l,q,m);me[c[f+40>>2]&511](q);i=n;return}yDb(c[f>>2]|0,16,2354704,(T=i,i=i+8|0,c[T>>2]=N,T)|0);i=T;i=n;return}function o$(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=ICb()|0;c[b>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+120>>2]=300;c[a+124>>2]=216;c[a+140>>2]=11;e=0;return e|0}function p$(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;h=i;i=i+16|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=j|0;TGb(g|0,0,16)|0;m=e;n=c[b+60>>2]|0;if((l|0)<6){yDb(b,16,2193168,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}if((l|0)>24){yDb(b,16,2114936,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}q=n;r=$$a(b,c[q>>2]|0)|0;if((r|0)<0){p=r;i=h;return p|0}if((c[b+428>>2]|0)==0){r=c[q>>2]|0;TGb(c[r>>2]|0,0,ba(c[b+124>>2]|0,c[r+32>>2]|0)|0)|0;TGb(c[(c[q>>2]|0)+4>>2]|0,0,1024)|0}r=a[k]|0;s=d[k+1|0]|0;if((l|0)>8){UGb(g|0,k+4|0,l-8|0)|0}do{if((r&63)==9){k=s&63;a:do{switch(k|0){case 30:case 31:{if((l-8|0)<16){yDb(b,16,2055824,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}t=c[q>>2]|0;u=(k|0)==30?0:8;v=c[t+4>>2]|0;w=0;do{x=w<<1;y=(a[j+(x|1)|0]&63|(d[j+x|0]|0)<<6)&65535;c[v+(w+u<<2)>>2]=((y&15)*17|0)&255|(ba(y>>>8&15,1114112)|0)|((y>>>4&15)*4352|0)&65280|-16777216;w=w+1|0;}while((w|0)<8);c[t+304>>2]=1;break};case 20:case 24:{if((l-8|0)<3){yDb(b,16,1942512,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}w=_$a(b,m,1)|0;if((w|0)<0){p=w;i=h;return p|0}w=(k|0)==24;u=c[q>>2]|0;v=c[u+32>>2]|0;y=c[u>>2]|0;x=c[e>>2]|0;z=a[g]&15;A=d[j+1|0]|0;B=A>>>4&3;C=d[j+2|0]|0;D=C>>>4&3;E=A&7;A=E>>>0>5>>>0?5:E;E=C&15;C=E>>>0>11>>>0?11:E;E=n+4|0;F=A-(c[E>>2]|0)|0;G=n+8|0;H=C-(c[G>>2]|0)|0;c[E>>2]=A;c[G>>2]=C;C=(D|0)==2?H-12|0:H;H=(D|0)==1?C+12|0:C;C=-H|0;D=(B|0)==2?F-6|0:F;F=(B|0)==1?D+6|0:D;D=-F|0;b:do{if((H|F|0)!=0){UGb(c[e+4>>2]|0,c[u+4>>2]|0,64)|0;B=(H|0)<0;G=B?0:H;A=H+216|0;E=(H|0)>0;I=E?216:A;if((G|0)<(I|0)){J=(F|0)<0?0:F;K=J-F|0;L=((F|0)>0?0:F)+v|0;M=G;do{UGb(x+((ba(M,v)|0)+J)|0,y+(K+(ba(M-H|0,v)|0))|0,L)|0;M=M+1|0;}while((M|0)<(I|0))}c:do{if(E){if(w){I=216-H|0;M=0;do{UGb(x+(ba(M,v)|0)|0,y+(ba(I+M|0,v)|0)|0,v)|0;M=M+1|0;}while((M|0)<(H|0))}else{M=z&255;I=0;do{TGb(x+(ba(I,v)|0)|0,M|0,v|0)|0;I=I+1|0;}while((I|0)<(H|0))}}else{if(!B){break}I=(C|0)>0;if(w){if(I){N=0}else{break}while(1){UGb(x+(ba(N+A|0,v)|0)|0,y+(ba(N,v)|0)|0,v)|0;N=N+1|0;if((N|0)>=(C|0)){break c}}}if(!I){break}M=z&255;L=A;do{TGb(x+(ba(L,v)|0)|0,M|0,v|0)|0;L=L+1|0;}while((L|0)<216)}}while(0);if((F|0)>0){A=300-F|0;if(w){B=0;while(1){E=ba(B,v)|0;UGb(x+E|0,y+(A+E)|0,F)|0;B=B+1|0;if((B|0)>=216){break b}}}B=z&255;A=0;while(1){TGb(x+(ba(A,v)|0)|0,B|0,F|0)|0;A=A+1|0;if((A|0)>=216){break b}}}if((F|0)>=0){break}A=F+300|0;if(w){B=0;while(1){E=ba(B,v)|0;UGb(x+(E+A)|0,y+E|0,D)|0;B=B+1|0;if((B|0)>=216){break b}}}B=z&255;E=0;do{TGb(x+((ba(E,v)|0)+A)|0,B|0,D|0)|0;E=E+1|0;}while((E|0)<216)}}while(0);KCb(c[q>>2]|0);D=MCb(c[q>>2]|0,m)|0;if((D|0)<0){p=D}else{break a}i=h;return p|0};case 1:{if(!((a[j+1|0]&15)==0)){break a}D=c[q>>2]|0;TGb(c[D>>2]|0,a[g]&15|0,(c[D+32>>2]|0)*216|0|0)|0;break};case 2:{D=c[q>>2]|0;v=c[D>>2]|0;x=c[D+32>>2]|0;if(!((a[j+1|0]&15)==0)){break a}D=a[g]&15;z=x*12|0;TGb(v|0,D|0,z|0)|0;TGb(v+(x*204|0)|0,D|0,z|0)|0;z=12;do{y=ba(z,x)|0;TGb(v+y|0,D|0,6)|0;TGb(v+(y+294)|0,D|0,6)|0;z=z+1|0;}while((z|0)<204);break};case 38:case 6:{if((l-8|0)<16){yDb(b,16,2009872,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}z=c[q>>2]|0;D=c[z>>2]|0;v=c[z+32>>2]|0;z=((a[j+2|0]&31)*12|0)+(c[n+8>>2]|0)|0;x=((a[j+3|0]&63)*6|0)+(c[n+4>>2]|0)|0;if(z>>>0>204>>>0|x>>>0>294>>>0){yDb(b,16,1971176,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}y=a[g]|0;w=a[j+1|0]|0;if((k|0)==38){F=0;do{C=(ba(F+z|0,v)|0)+x|0;H=a[j+(F+4)|0]|0;u=D+C|0;a[u]=((H&32)==0?y:w)&15^a[u];u=D+(C+1)|0;a[u]=((H&16)==0?y:w)&15^a[u];u=D+(C+2)|0;a[u]=((H&8)==0?y:w)&15^a[u];u=D+(C+3)|0;a[u]=((H&4)==0?y:w)&15^a[u];u=D+(C+4)|0;a[u]=((H&2)==0?y:w)&15^a[u];u=D+(C+5)|0;a[u]=((H&1)==0?y:w)&15^a[u];F=F+1|0;}while((F|0)<12)}else{F=0;do{u=(ba(F+z|0,v)|0)+x|0;H=a[j+(F+4)|0]|0;a[D+u|0]=((H&32)==0?y:w)&15;a[D+(u+1)|0]=((H&16)==0?y:w)&15;a[D+(u+2)|0]=((H&8)==0?y:w)&15;a[D+(u+3)|0]=((H&4)==0?y:w)&15;a[D+(u+4)|0]=((H&2)==0?y:w)&15;a[D+(u+5)|0]=((H&1)==0?y:w)&15;F=F+1|0;}while((F|0)<12)}break};default:{}}}while(0);if((c[e>>2]|0)!=0){O=l;P=1;break}k=MCb(m,c[q>>2]|0)|0;if((k|0)<0){p=k}else{O=l;P=1;break}i=h;return p|0}else{O=0;P=0}}while(0);c[f>>2]=P;p=O;i=h;return p|0}function q$(a){a=a|0;JCb(c[a+60>>2]|0);return 0}function r$(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+36>>2]=0;c[b>>2]=a;return 0}function s$(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;h=i;i=i+320|0;j=h|0;k=h+256|0;l=c[b+60>>2]|0;m=l;n=e;o=c[g+28>>2]|0;p=c[g+24>>2]|0;if((o|0)<32){q=-1094995529;i=h;return q|0}g=d[p+1|0]|0;r=g&7;s=g&224;c[l+8>>2]=s;g=p+14|0;t=(de((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;g=p+16|0;u=(de((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;g=a[p+19|0]|0;v=l+4|0;c[v>>2]=g&255;w=p+20|0;y=de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0;w=y&65535;z=l+20|0;c[z>>2]=w;A=l+16|0;c[A>>2]=p+32;B=w+32|0;c[l+24>>2]=p+B;p=l+28|0;c[p>>2]=o-32-w;if((y&65535)>>>0>512>>>0|(o|0)<(B|0)|g<<24>>24==0){q=-1094995529;i=h;return q|0}if(!((s|0)==0|(s|0)==128)){DDb(b,2193120,(C=i,i=i+8|0,c[C>>2]=s,C)|0);i=C;q=-1163346256;i=h;return q|0}s=V$a(b,t,u)|0;if((s|0)<0){q=s;i=h;return q|0}s=l;g=c[(c[s>>2]|0)+120>>2]|0;B=g+15&-16;c[l+12>>2]=B-g;g=ba(B,c[b+124>>2]|0)|0;B=c[v>>2]|0;if((c[p>>2]|0)<((ba(g,B)|0)/8|0|0)){q=-1094995529;i=h;return q|0}g=(r|0)!=0;do{if(g){if((r|0)!=1){D=14;break}if(!((B|0)==6|(B|0)==8)){D=14;break}if((c[z>>2]|0)==(1<<B-1|0)){c[b+140>>2]=3;break}else{q=-1094995529;i=h;return q|0}}else{if(!((c[z>>2]|0)!=0&(B|0)<9)){D=14;break}c[b+140>>2]=11}}while(0);if((D|0)==14){DDb(b,2114896,(C=i,i=i+16|0,c[C>>2]=r,c[C+8>>2]=B,C)|0);i=C;q=-1163346256;i=h;return q|0}C=_$a(b,n,0)|0;if((C|0)<0){q=C;i=h;return q|0}c[e+88>>2]=1;a:do{if(g){C=l+32|0;O$a(C,l+36|0,(ba(u,t)|0)+16|0);n=c[C>>2]|0;if((n|0)==0){q=-12;i=h;return q|0}if((c[v>>2]|0)==8){C=c[s>>2]|0;b=c[e>>2]|0;B=j|0;r=c[z>>2]|0;if((r|0)>1){D=c[A>>2]|0;p=(r|0)/2|0;r=0;do{y=D+(r<<1)|0;w=(de((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535;c[j+(r<<2)>>2]=(w&15)*17|0|((w>>>4&15)*4352|0)|(ba(w>>>8&15,1114112)|0)|-16777216;r=r+1|0;}while((r|0)<(p|0))}p=C+120|0;u$(m,c[p>>2]|0,n);r=C+124|0;D=c[r>>2]|0;if((D|0)<=0){break}w=e+32|0;y=n;E=b;F=1;G=c[p>>2]|0;H=D;while(1){D=c[B>>2]|0;if((G|0)>0){I=D&65280;J=D&255;K=y;L=D&16711680;D=0;while(1){M=K+1|0;N=a[K]|0;O=N&63;P=(N&255)>>>6&255;if((P|0)==1){Q=L;R=(O&255)<<2|J&3;S=I}else if((P|0)==2){Q=(O&255)<<18|L&196608;R=J;S=I}else if((P|0)==0){N=c[j+((O&255)<<2)>>2]|0;Q=N&16711680;R=N&255;S=N&65280}else if((P|0)==3){Q=L;R=J;S=(O&255)<<10|I&768}else{Q=L;R=J;S=I}O=R|S|Q;P=D*3|0;a[E+P|0]=O;a[E+(P+1)|0]=O>>>8;a[E+(P+2)|0]=O>>>16;O=D+1|0;T=c[p>>2]|0;if((O|0)<(T|0)){I=S;J=R;K=M;L=Q;D=O}else{break}}U=M;V=T;W=c[r>>2]|0}else{U=y;V=G;W=H}if((F|0)>=(W|0)){break a}y=U;E=E+(c[w>>2]|0)|0;F=F+1|0;G=V;H=W}}else{H=c[s>>2]|0;G=c[e>>2]|0;F=k|0;w=c[z>>2]|0;if((w|0)>1){E=c[A>>2]|0;y=(w|0)/2|0;w=0;do{r=E+(w<<1)|0;p=(de((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535;c[k+(w<<2)>>2]=(p&15)*17|0|((p>>>4&15)*4352|0)|(ba(p>>>8&15,1114112)|0)|-16777216;w=w+1|0;}while((w|0)<(y|0))}y=H+120|0;u$(m,c[y>>2]|0,n);w=H+124|0;E=c[w>>2]|0;if((E|0)<=0){break}p=e+32|0;r=n;B=G;b=1;C=c[y>>2]|0;D=E;while(1){E=c[F>>2]|0;if((C|0)>0){L=E&65280;K=E&255;J=r;I=E&16711680;E=0;while(1){X=J+1|0;O=a[J]|0;P=O&15;N=(O&255)>>>4&255;if((N|0)==1){Y=I;Z=(P&255)*17|0;_=L}else if((N|0)==3){Y=I;Z=K;_=(P&255)*4352|0}else if((N|0)==0){O=c[k+((P&255)<<2)>>2]|0;Y=O&16711680;Z=O&255;_=O&65280}else if((N|0)==2){Y=ba(P&255,1114112)|0;Z=K;_=L}else{Y=I;Z=K;_=L}P=Z|_|Y;N=E*3|0;a[B+N|0]=P;a[B+(N+1)|0]=P>>>8;a[B+(N+2)|0]=P>>>16;P=E+1|0;$=c[y>>2]|0;if((P|0)<($|0)){L=_;K=Z;J=X;I=Y;E=P}else{break}}aa=X;ca=$;da=c[w>>2]|0}else{aa=r;ca=C;da=D}if((b|0)>=(da|0)){break a}r=aa;B=B+(c[p>>2]|0)|0;b=b+1|0;C=ca;D=da}}}else{D=c[e+4>>2]|0;C=D;TGb(D|0,0,1024)|0;if((c[z>>2]|0)>1){D=0;do{b=(c[A>>2]|0)+(D<<1)|0;p=(de((d[b]|d[b+1|0]<<8)<<16>>16|0)|0)&65535;b=C+(D<<2)|0;x=(p&15)*17|0|((p>>>4&15)*4352|0)|(ba(p>>>8&15,1114112)|0)|-16777216;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;D=D+1|0;}while((D|0)<((c[z>>2]|0)/2|0|0))}u$(m,c[e+32>>2]|0,c[e>>2]|0)}}while(0);c[f>>2]=1;q=o;i=h;return q|0}function t$(a){a=a|0;$Db((c[a+60>>2]|0)+32|0);return 0}function u$(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=b|0;TGb(f|0,0,ba(c[(c[g>>2]|0)+124>>2]|0,e)|0)|0;h=c[b+8>>2]|0;if((h|0)==0){i=c[b+24>>2]|0;j=c[b+28>>2]<<3>>>0>2147483639>>>0|(i|0)==0?0:i;i=b+4|0;k=c[i>>2]|0;if((k|0)<=0){return}l=b+12|0;m=0;n=0;o=c[g>>2]|0;p=k;while(1){if((c[o+124>>2]|0)>0){k=m;q=0;r=o;while(1){if((c[r+120>>2]|0)>0){s=ba(q,e)|0;t=k;u=0;while(1){v=t+1|0;w=f+(u+s)|0;a[w]=((d[j+(t>>>3)|0]|0)<<(t&7)>>>7&1)<<n|(d[w]|0);w=u+1|0;x=c[g>>2]|0;if((w|0)<(c[x+120>>2]|0)){t=v;u=w}else{y=v;z=x;break}}}else{y=k;z=r}A=(c[l>>2]|0)+y|0;u=q+1|0;if((u|0)<(c[z+124>>2]|0)){k=A;q=u;r=z}else{break}}B=A;C=z;D=c[i>>2]|0}else{B=m;C=o;D=p}r=n+1|0;if((r|0)<(D|0)){m=B;n=r;o=C;p=D}else{break}}return}else if((h|0)==128){h=c[b+24>>2]|0;D=c[b+28>>2]<<3>>>0>2147483639>>>0|(h|0)==0?0:h;h=c[g>>2]|0;if((c[h+124>>2]|0)<=0){return}p=b+4|0;C=b+12|0;b=0;o=0;n=c[p>>2]|0;B=h;while(1){if((n|0)>0){h=ba(o,e)|0;m=b;i=0;z=B;A=n;while(1){if((c[z+120>>2]|0)>0){y=m;l=0;while(1){E=y+1|0;j=f+(l+h)|0;a[j]=((d[D+(y>>>3)|0]|0)<<(y&7)>>>7&1)<<i|(d[j]|0);j=l+1|0;F=c[g>>2]|0;if((j|0)<(c[F+120>>2]|0)){y=E;l=j}else{break}}G=E;H=F;I=c[p>>2]|0}else{G=m;H=z;I=A}l=(c[C>>2]|0)+G|0;y=i+1|0;if((y|0)<(I|0)){m=l;i=y;z=H;A=I}else{J=l;K=I;L=H;break}}}else{J=b;K=n;L=B}A=o+1|0;if((A|0)<(c[L+124>>2]|0)){b=J;o=A;n=K;B=L}else{break}}return}else{return}}function v$(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;TGb(a|0,0,f<<1|0)|0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;i=b[h>>1]|0;if(!(i<<16>>16==0)){a:do{if((g|0)>0){j=f-g|0;k=0;l=i;while(1){m=(ba(b[d+(j+k<<1)>>1]|0,l<<16>>16)|0)>>>15;n=a+(k<<1)|0;b[n>>1]=m+(e[n>>1]|0);n=k+1|0;if((n|0)>=(g|0)){o=g;break a}k=n;l=b[h>>1]|0}}else{o=g}}while(0);do{i=(ba(b[d+(o-g<<1)>>1]|0,b[h>>1]|0)|0)>>>15;l=a+(o<<1)|0;b[l>>1]=i+(e[l>>1]|0);o=o+1|0;}while((o|0)<(f|0))}g=g+1|0;}while((g|0)<(f|0));return}function w$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=f|0;var h=0,i=0,j=0,k=0,l=0;if((d|0)>0){h=f-d|0;i=0;while(1){g[a+(i<<2)>>2]=+g[b+(i<<2)>>2]+ +g[c+(h+i<<2)>>2]*e;j=i+1|0;if((j|0)<(d|0)){i=j}else{k=d;break}}}else{k=0}if((k|0)<(f|0)){l=k}else{return}do{g[a+(l<<2)>>2]=+g[b+(l<<2)>>2]+ +g[c+(l-d<<2)>>2]*e;l=l+1|0;}while((l|0)<(f|0));return}function x$(a,c,d,e,f,g,h,i){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((e|0)<=0){j=0;return j|0}k=-i|0;l=(g|0)==0;if((f|0)<1){g=0;while(1){m=(b[d+(g<<1)>>1]|0)+(i>>12)>>h;if((m+32768|0)>>>0>65535>>>0){n=(m>>31^32767)&65535}else{n=m&65535}if(!l){if((n<<16>>16|0)!=(m|0)){j=1;o=20;break}}b[a+(g<<1)>>1]=n;m=g+1|0;if((m|0)<(e|0)){g=m}else{j=0;o=20;break}}if((o|0)==20){return j|0}}if(l){l=0;while(1){g=1;n=k;do{n=(ba(b[a+(l-g<<1)>>1]|0,b[c+(g-1<<1)>>1]|0)|0)+n|0;g=g+1|0;}while((g|0)<=(f|0));g=(b[d+(l<<1)>>1]|0)+(-n>>12)>>h;if((g+32768|0)>>>0>65535>>>0){p=(g>>31^32767)&65535}else{p=g&65535}b[a+(l<<1)>>1]=p;g=l+1|0;if((g|0)<(e|0)){l=g}else{j=0;break}}return j|0}else{q=0}while(1){l=1;p=k;do{p=(ba(b[a+(q-l<<1)>>1]|0,b[c+(l-1<<1)>>1]|0)|0)+p|0;l=l+1|0;}while((l|0)<=(f|0));l=(b[d+(q<<1)>>1]|0)+(-p>>12)>>h;if((l+32768|0)>>>0>65535>>>0){r=(l>>31^32767)&65535}else{r=l&65535}if((r<<16>>16|0)!=(l|0)){j=1;o=20;break}b[a+(q<<1)>>1]=r;l=q+1|0;if((l|0)<(e|0)){q=l}else{j=0;o=20;break}}if((o|0)==20){return j|0}return 0}function y$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,h=0,i=0.0,j=0,k=0.0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0.0,U=0.0,V=0.0,W=0.0,X=0,Y=0.0,Z=0.0,_=0.0,$=0.0;f=+g[b>>2];h=b+4|0;i=+g[h>>2];j=b+8|0;k=+g[j>>2];l=i-f*f;m=k-f*i-f*l;n=d-4|0;a:do{if((n|0)<0){o=0;p=c;q=a}else{r=b+12|0;s=(e|0)>5;t=+g[a-16>>2];u=+g[a-12>>2];v=+g[a-8>>2];w=+g[a-4>>2];x=4;y=c;z=a;A=k;B=i;C=f;while(1){D=+g[r>>2];E=+g[y>>2]-u*A-v*B-w*C-t*D;F=+g[y+4>>2]-v*A-w*B-u*D;G=+g[y+8>>2]-w*A-v*D;H=+g[y+12>>2]-w*D;if(s){D=F;I=G;J=H;K=t;L=u;M=v;N=E;O=5;while(1){P=+g[z+(-O<<2)>>2];Q=+g[b+(O-1<<2)>>2];R=+g[z+(~O<<2)>>2];S=+g[b+(O<<2)>>2];T=N-P*Q-R*S;U=D-K*Q-P*S;V=I-L*Q-K*S;W=J-M*Q-L*S;X=O+2|0;if((X|0)<(e|0)){D=U;I=V;J=W;M=K;K=R;L=P;N=T;O=X}else{Y=U;Z=V;_=W;$=T;break}}}else{Y=F;Z=G;_=H;$=E}N=Y-f*$;L=Z-f*Y-l*$;K=_-f*Z-l*Y-m*$;g[z>>2]=$;g[z+4>>2]=N;g[z+8>>2]=L;g[z+12>>2]=K;O=z+16|0;X=y+16|0;if((x|0)>(n|0)){o=x;p=X;q=O;break a}t=$;u=N;v=L;w=K;x=x+4|0;y=X;z=O;A=+g[j>>2];B=+g[h>>2];C=+g[b>>2]}}}while(0);if((o|0)>=(d|0)){return}h=(e|0)<1;j=o;do{n=j-o|0;$=+g[p+(n<<2)>>2];a=q+(n<<2)|0;g[a>>2]=$;if(!h){c=1;m=$;do{m=m- +g[b+(c-1<<2)>>2]*+g[q+(n-c<<2)>>2];g[a>>2]=m;c=c+1|0;}while((c|0)<=(e|0))}j=j+1|0;}while((j|0)<(d|0));return}function z$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0.0,j=0,k=0,l=0.0;if((d|0)<=0){return}f=(e|0)<1;h=0;do{i=+g[c+(h<<2)>>2];j=a+(h<<2)|0;g[j>>2]=i;if(!f){k=1;l=i;do{l=l+ +g[b+(k-1<<2)>>2]*+g[c+(h-k<<2)>>2];g[j>>2]=l;k=k+1|0;}while((k|0)<=(e|0))}h=h+1|0;}while((h|0)<(d|0));return}function A$(a){a=a|0;c[a>>2]=398;c[a+4>>2]=52;return}function B$(a){a=a|0;var b=0,c=0,f=0,g=0,h=0;b=a>>>0>65535>>>0;c=b?a>>>16:a;f=b?16:0;if((c&65280|0)==0){g=f;h=c}else{g=f|8;h=c>>>8}c=(d[1191992+h|0]|0)+g&255;g=a<<31-c;a=g>>>26&31;h=e[213160+(a<<1)>>1]|0;return(c<<15)+h+((ba(g>>>11&32767,(e[213160+(a+1<<1)>>1]|0)-h|0)|0)>>15)|0}function C$(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)>0){e=0;f=0;g=0}else{h=0;i=0;return(F=h,i)|0}while(1){j=ba(b[c+(e<<1)>>1]|0,b[a+(e<<1)>>1]|0)|0;k=YGb(j,(j|0)<0|0?-1:0,g,f)|0;j=F;l=e+1|0;if((l|0)<(d|0)){e=l;f=j;g=k}else{h=j;i=k;break}}return(F=h,i)|0}function D$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0.0,e=0,f=0.0,h=0.0,i=0;if((c|0)>0){d=0.0;e=0}else{f=0.0;return+f}while(1){h=d+ +g[a+(e<<2)>>2]*+g[b+(e<<2)>>2];i=e+1|0;if((i|0)<(c|0)){d=h;e=i}else{f=h;break}}return+f}function E$(a){a=a|0;c[a>>2]=2;return}function F$(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;if((e|0)<=0){return}i=ba(f,e)|0;f=b;b=0;while(1){j=d+(b+i)|0;a[f]=(a[j]|0)<0?g:h;a[f+1|0]=(a[j]&64)!=0?g:h;a[f+2|0]=(a[j]&32)!=0?g:h;a[f+3|0]=(a[j]&16)!=0?g:h;a[f+4|0]=(a[j]&8)!=0?g:h;a[f+5|0]=(a[j]&4)!=0?g:h;a[f+6|0]=(a[j]&2)!=0?g:h;a[f+7|0]=(a[j]&1)!=0?g:h;j=b+1|0;if((j|0)<(e|0)){f=f+c|0;b=j}else{break}}return}function G$(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+16>>2]=(c[a+120>>2]|0)+3&-4;c[b+20>>2]=(c[a+124>>2]|0)+3&-4;c[b+196956>>2]=-1;d=b+24|0;if((c[a+792>>2]|0)==8){c[d>>2]=1;c[a+140>>2]=11;e=ICb()|0;f=b+4|0;g=f;c[g>>2]=e;h=(e|0)==0;i=h?-12:0;return i|0}else{c[d>>2]=0;c[a+140>>2]=2;e=ICb()|0;f=b+4|0;g=f;c[g>>2]=e;h=(e|0)==0;i=h?-12:0;return i|0}return 0}function H$(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0;k=i;l=c[j+28>>2]|0;m=c[f+60>>2]|0;n=m;o=m+8|0;c[o>>2]=c[j+24>>2];p=m+12|0;c[p>>2]=l;q=m+4|0;r=$$a(f,c[q>>2]|0)|0;if((r|0)<0){s=r;i=k;return s|0}r=m+24|0;do{if((c[r>>2]|0)!=0){t=HZ(j,0,0)|0;if((t|0)==0){break}c[(c[q>>2]|0)+304>>2]=1;UGb(m+196960|0,t|0,1024)|0}}while(0);j=c[o>>2]|0;t=c[p>>2]|0;p=j+t|0;a:do{if((t|0)<10){u=82}else{v=a[j]|0;w=j+8|0;x=(de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535;w=d[j+2|0]<<8|d[j+1|0]<<16|d[j+3|0];y=m+196956|0;z=c[y>>2]|0;b:do{if((z|0)==-1){if((w|0)==0){DDb(c[m>>2]|0,2114840,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;u=82;break a}do{if((w|0)!=(t|0)){if(((t|0)%(w|0)|0|0)==0){break}do{if((t|0)>15){if(!((a[j+10|0]|0)==-2)){break}if((a[j+11|0]|0)!=0){break}if((a[j+12|0]|0)!=0){break}if((a[j+13|0]|0)!=6){break}if((a[j+14|0]|0)!=0){break}if((a[j+15|0]|0)!=0){break}c[y>>2]=6;B=16;break b}}while(0);c[y>>2]=2;B=12;break b}}while(0);c[y>>2]=0;B=10}else{B=z+10|0}}while(0);z=j+B|0;c[o>>2]=z;y=x>>>0>32>>>0?32:x;c[(c[q>>2]|0)+84>>2]=0;if((y|0)==0){break}w=p;C=m+16|0;D=m+20|0;E=m;F=(v&1)!=0;G=0;H=0;I=z;while(1){if((I+12|0)>>>0>p>>>0){u=82;break a}z=a[I]|0;b[n+28+(G*6154|0)>>1]=z&255;J=(c[o>>2]|0)+4|0;K=(d[J]|d[J+1|0]<<8)<<16>>16;J=n+28+(G*6154|0)+4|0;b[J>>1]=de(K|0)|0;if(K<<16>>16==0){b[J>>1]=H;K=(c[o>>2]|0)+8|0;b[n+28+(G*6154|0)+8>>1]=(de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)+H}else{K=(c[o>>2]|0)+8|0;b[n+28+(G*6154|0)+8>>1]=de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0}K=(c[o>>2]|0)+6|0;L=n+28+(G*6154|0)+2|0;b[L>>1]=de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0;K=(c[o>>2]|0)+10|0;M=n+28+(G*6154|0)+6|0;b[M>>1]=de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0;if(z<<24>>24==16){c[(c[q>>2]|0)+84>>2]=1}z=c[o>>2]|0;K=d[z+2|0]<<8|d[z+1|0]<<16|d[z+3|0];N=K-12|0;if((N|0)<0){u=82;break a}O=z+12|0;c[o>>2]=O;if((z+K|0)>>>0>p>>>0){P=w-O|0}else{P=N}if((G|0)<1|F){Q=O}else{O=G-1|0;UGb(n+28+(G*6154|0)+10|0,n+28+(O*6154|0)+10|0,3072)|0;UGb(n+28+(G*6154|0)+3082|0,n+28+(O*6154|0)+3082|0,3072)|0;Q=c[o>>2]|0}O=Q+P|0;N=b[M>>1]|0;if((N&65535|0)>(c[C>>2]|0)){u=82;break a}K=n+28+(G*6154|0)+8|0;z=b[K>>1]|0;if((z&65535|0)>(c[D>>2]|0)){u=82;break a}if(!((e[L>>1]|0)>>>0<(N&65535)>>>0)){u=82;break a}if((e[J>>1]|0)>>>0>=(z&65535)>>>0|(P|0)<4){u=82;break a}z=O;N=n+28+(G*6154|0)+10|0;R=n+28+(G*6154|0)+3082|0;S=Q;T=Q+4|0;c:while(1){U=d[S]|0;V=d[S+2|0]<<8|d[S+1|0]<<16|d[S+3|0];W=V-4|0;if((W|0)<0){u=82;break a}if((S+V|0)>>>0>O>>>0){X=z-T|0}else{X=W}switch(U|0){case 32:case 33:case 36:case 37:{J$(N,U,X,T);break};case 34:case 35:case 38:case 39:{J$(R,U,X,T);break};case 48:case 49:case 50:{break c;break};default:{}}W=S+(X+8)|0;if(W>>>0>O>>>0){u=82;break a}else{S=S+(X+4)|0;T=W}}O=S+(X+4)|0;R=b[J>>1]|0;N=b[K>>1]|0;if((R&65535)>>>0<(N&65535)>>>0){z=(U&1|0)==0;W=(U&2|0)==0;V=0;Y=0;Z=T;_=R&65535;R=c[r>>2]|0;$=N;while(1){N=c[q>>2]|0;aa=c[N>>2]|0;ca=b[L>>1]|0;da=ca&65535;if((R|0)==0){ea=da*3|0}else{ea=da}fa=c[N+32>>2]|0;N=(ba(fa,_)|0)+ea|0;ga=aa+N|0;ha=(c[(c[E>>2]|0)+124>>2]|0)-_|0;do{if(ha>>>0>1>>>0){ia=N+fa|0;ja=aa+ia|0;if(!(ha>>>0>2>>>0)){ka=ga;la=ga;ma=ja;break}na=ia+fa|0;ia=aa+na|0;if(!(ha>>>0>3>>>0)){ka=ga;la=ia;ma=ja;break}ka=aa+(na+fa)|0;la=ia;ma=ja}else{ka=ga;la=ga;ma=ga}}while(0);if((ca&65535)>>>0<(e[M>>1]|0)>>>0){fa=V;aa=Y;ha=Z;N=da;ja=ga;ia=ma;na=la;oa=ka;pa=R;while(1){if(z){qa=fa;ra=aa;sa=ha;u=60}else{ta=fa>>>1;if((ta|0)==0){ua=ha+4|0;if(ua>>>0>O>>>0){u=82;break a}va=ha;wa=-2147483648;xa=fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0;ya=ua}else{wa=ta;xa=aa;ya=ha}if((wa&xa|0)==0){za=ya;Aa=xa;Ba=wa}else{qa=wa;ra=xa;sa=ya;u=60}}d:do{if((u|0)==60){u=0;do{if(W){ta=qa>>>1;if((ta|0)==0){ua=sa+4|0;if(ua>>>0>O>>>0){u=82;break a}va=sa;Ca=-2147483648;Da=fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0;Ea=ua}else{Ca=ta;Da=ra;Ea=sa}if((Ca&~Da|0)!=0){Fa=Ca;Ga=Da;Ha=Ea;break}if((Ca&Da|0)==0){za=Ea;Aa=Da;Ba=Ca;break d}ta=Ea+4|0;if(ta>>>0>O>>>0){u=82;break a}ua=d[Ea]|0;va=n+28+(G*6154|0)+10+(ua*12|0)|0;Ia=d[Ea+1|0]|0;Ja=n+28+(G*6154|0)+10+(Ia*12|0)|0;Ka=d[Ea+2|0]|0;La=n+28+(G*6154|0)+10+(Ka*12|0)|0;Ma=d[Ea+3|0]|0;Na=n+28+(G*6154|0)+10+(Ma*12|0)|0;Oa=n+28+(G*6154|0)+10+(Ka*12|0)+6|0;if((pa|0)==0){a[oa]=a[Oa]|0;a[oa+1|0]=a[Oa+1|0]|0;a[oa+2|0]=a[Oa+2|0]|0;a[oa+3|0]=a[Oa+3|0]|0;a[oa+4|0]=a[Oa+4|0]|0;a[oa+5|0]=a[Oa+5|0]|0;Pa=oa+6|0;Qa=n+28+(G*6154|0)+10+(Ma*12|0)+6|0;a[Pa]=a[Qa]|0;a[Pa+1|0]=a[Qa+1|0]|0;a[Pa+2|0]=a[Qa+2|0]|0;a[Pa+3|0]=a[Qa+3|0]|0;a[Pa+4|0]=a[Qa+4|0]|0;a[Pa+5|0]=a[Qa+5|0]|0;a[na]=a[La]|0;a[na+1|0]=a[La+1|0]|0;a[na+2|0]=a[La+2|0]|0;a[na+3|0]=a[La+3|0]|0;a[na+4|0]=a[La+4|0]|0;a[na+5|0]=a[La+5|0]|0;Qa=na+6|0;a[Qa]=a[Na]|0;a[Qa+1|0]=a[Na+1|0]|0;a[Qa+2|0]=a[Na+2|0]|0;a[Qa+3|0]=a[Na+3|0]|0;a[Qa+4|0]=a[Na+4|0]|0;a[Qa+5|0]=a[Na+5|0]|0;Qa=n+28+(G*6154|0)+10+(ua*12|0)+6|0;a[ia]=a[Qa]|0;a[ia+1|0]=a[Qa+1|0]|0;a[ia+2|0]=a[Qa+2|0]|0;a[ia+3|0]=a[Qa+3|0]|0;a[ia+4|0]=a[Qa+4|0]|0;a[ia+5|0]=a[Qa+5|0]|0;Qa=ia+6|0;Pa=n+28+(G*6154|0)+10+(Ia*12|0)+6|0;a[Qa]=a[Pa]|0;a[Qa+1|0]=a[Pa+1|0]|0;a[Qa+2|0]=a[Pa+2|0]|0;a[Qa+3|0]=a[Pa+3|0]|0;a[Qa+4|0]=a[Pa+4|0]|0;a[Qa+5|0]=a[Pa+5|0]|0;a[ja]=a[va]|0;a[ja+1|0]=a[va+1|0]|0;a[ja+2|0]=a[va+2|0]|0;a[ja+3|0]=a[va+3|0]|0;a[ja+4|0]=a[va+4|0]|0;a[ja+5|0]=a[va+5|0]|0;Pa=ja+6|0;a[Pa]=a[Ja]|0;a[Pa+1|0]=a[Ja+1|0]|0;a[Pa+2|0]=a[Ja+2|0]|0;a[Pa+3|0]=a[Ja+3|0]|0;a[Pa+4|0]=a[Ja+4|0]|0;a[Pa+5|0]=a[Ja+5|0]|0;za=ta;Aa=Da;Ba=Ca;break d}else{a[oa]=a[Oa]|0;a[oa+1|0]=a[n+28+(G*6154|0)+10+(Ka*12|0)+9|0]|0;a[oa+2|0]=a[n+28+(G*6154|0)+10+(Ma*12|0)+6|0]|0;a[oa+3|0]=a[n+28+(G*6154|0)+10+(Ma*12|0)+9|0]|0;a[na]=a[La]|0;a[na+1|0]=a[n+28+(G*6154|0)+10+(Ka*12|0)+3|0]|0;a[na+2|0]=a[Na]|0;a[na+3|0]=a[n+28+(G*6154|0)+10+(Ma*12|0)+3|0]|0;a[ia]=a[n+28+(G*6154|0)+10+(ua*12|0)+6|0]|0;a[ia+1|0]=a[n+28+(G*6154|0)+10+(ua*12|0)+9|0]|0;a[ia+2|0]=a[n+28+(G*6154|0)+10+(Ia*12|0)+6|0]|0;a[ia+3|0]=a[n+28+(G*6154|0)+10+(Ia*12|0)+9|0]|0;a[ja]=a[va]|0;a[ja+1|0]=a[n+28+(G*6154|0)+10+(ua*12|0)+3|0]|0;a[ja+2|0]=a[Ja]|0;a[ja+3|0]=a[n+28+(G*6154|0)+10+(Ia*12|0)+3|0]|0;za=ta;Aa=Da;Ba=Ca;break d}}else{Fa=qa;Ga=ra;Ha=sa}}while(0);if(!(Ha>>>0<O>>>0)){u=82;break a}ta=Ha+1|0;Ia=d[Ha]|0;Ja=n+28+(G*6154|0)+3082+(Ia*12|0)+6|0;if((pa|0)==0){a[oa]=a[Ja]|0;a[oa+1|0]=a[Ja+1|0]|0;a[oa+2|0]=a[Ja+2|0]|0;ua=oa+3|0;a[ua]=a[Ja]|0;a[ua+1|0]=a[Ja+1|0]|0;a[ua+2|0]=a[Ja+2|0]|0;a[na]=a[Ja]|0;a[na+1|0]=a[Ja+1|0]|0;a[na+2|0]=a[Ja+2|0]|0;ua=na+3|0;a[ua]=a[Ja]|0;a[ua+1|0]=a[Ja+1|0]|0;a[ua+2|0]=a[Ja+2|0]|0;ua=n+28+(G*6154|0)+3082+(Ia*12|0)+9|0;va=oa+6|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=oa+9|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=na+6|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=na+9|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;ua=n+28+(G*6154|0)+3082+(Ia*12|0)|0;a[ia]=a[ua]|0;a[ia+1|0]=a[ua+1|0]|0;a[ia+2|0]=a[ua+2|0]|0;va=ia+3|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;a[ja]=a[ua]|0;a[ja+1|0]=a[ua+1|0]|0;a[ja+2|0]=a[ua+2|0]|0;va=ja+3|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;ua=n+28+(G*6154|0)+3082+(Ia*12|0)+3|0;va=ia+6|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=ia+9|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=ja+6|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=ja+9|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;za=ta;Aa=Ga;Ba=Fa;break}else{ua=a[Ja]|0;a[na+1|0]=ua;a[na]=ua;a[oa+1|0]=ua;a[oa]=ua;ua=a[n+28+(G*6154|0)+3082+(Ia*12|0)+9|0]|0;a[na+3|0]=ua;a[na+2|0]=ua;a[oa+3|0]=ua;a[oa+2|0]=ua;ua=a[n+28+(G*6154|0)+3082+(Ia*12|0)|0]|0;a[ja+1|0]=ua;a[ja]=ua;a[ia+1|0]=ua;a[ia]=ua;ua=a[n+28+(G*6154|0)+3082+(Ia*12|0)+3|0]|0;a[ja+3|0]=ua;a[ja+2|0]=ua;a[ia+3|0]=ua;a[ia+2|0]=ua;za=ta;Aa=Ga;Ba=Fa;break}}}while(0);Ra=c[r>>2]|0;if((Ra|0)==0){Sa=oa+12|0;Ta=na+12|0;Ua=ia+12|0;Va=ja+12|0}else{Sa=oa+4|0;Ta=na+4|0;Ua=ia+4|0;Va=ja+4|0}ta=N+4|0;if(ta>>>0<(e[M>>1]|0)>>>0){fa=Ba;aa=Aa;ha=za;N=ta;ja=Va;ia=Ua;na=Ta;oa=Sa;pa=Ra}else{break}}Wa=Ba;Xa=Aa;Ya=za;Za=Ra;_a=b[K>>1]|0}else{Wa=V;Xa=Y;Ya=Z;Za=R;_a=$}pa=_+4|0;if(pa>>>0<(_a&65535)>>>0){V=Wa;Y=Xa;Z=Ya;_=pa;R=Za;$=_a}else{break}}}$=(c[o>>2]|0)+P|0;c[o>>2]=$;R=G+1|0;if((R|0)<(y|0)){G=R;H=b[K>>1]|0;I=$}else{break}}}}while(0);if((u|0)==82){yDb(f,16,2193048,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A}if((c[r>>2]|0)!=0){UGb(c[(c[q>>2]|0)+4>>2]|0,m+196960|0,1024)|0}m=MCb(g,c[q>>2]|0)|0;if((m|0)<0){s=m;i=k;return s|0}c[h>>2]=1;s=l;i=k;return s|0}function I$(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function J$(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;g=f+e|0;e=c>>>1&2;h=e^6;i=b|0;b=(e|0)==0;if((c&1|0)==0){c=i;e=0;j=f;while(1){if((j+h|0)>>>0>g>>>0){k=27;break}l=c+12|0;m=a[j]|0;TGb(c|0,m|0,3)|0;n=a[j+1|0]|0;TGb(c+3|0,n|0,3)|0;o=a[j+2|0]|0;TGb(c+6|0,o|0,3)|0;p=a[j+3|0]|0;TGb(c+9|0,p|0,3)|0;q=j+4|0;if(b){r=a[q]|0;s=a[j+5|0]|0;t=s<<1;u=(r|0)/2|0;v=r<<1;r=m&255;m=r+t|0;w=r-u-s|0;x=r+v|0;if(m>>>0>255>>>0){y=-m>>31&255}else{y=m&255}a[c]=y;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[c+1|0]=z;if(x>>>0>255>>>0){A=-x>>31&255}else{A=x&255}a[c+2|0]=A;x=n&255;n=x+t|0;w=x-u-s|0;m=x+v|0;if(n>>>0>255>>>0){B=-n>>31&255}else{B=n&255}a[c+3|0]=B;if(w>>>0>255>>>0){C=-w>>31&255}else{C=w&255}a[c+4|0]=C;if(m>>>0>255>>>0){D=-m>>31&255}else{D=m&255}a[c+5|0]=D;m=o&255;o=m+t|0;w=m-u-s|0;n=m+v|0;if(o>>>0>255>>>0){E=-o>>31&255}else{E=o&255}a[c+6|0]=E;if(w>>>0>255>>>0){F=-w>>31&255}else{F=w&255}a[c+7|0]=F;if(n>>>0>255>>>0){G=-n>>31&255}else{G=n&255}a[c+8|0]=G;n=p&255;p=n+t|0;t=n-u-s|0;s=n+v|0;if(p>>>0>255>>>0){H=-p>>31&255}else{H=p&255}a[c+9|0]=H;if(t>>>0>255>>>0){I=-t>>31&255}else{I=t&255}a[c+10|0]=I;if(s>>>0>255>>>0){J=-s>>31&255}else{J=s&255}a[c+11|0]=J;K=j+6|0}else{K=q}q=e+1|0;if((q|0)<256){c=l;e=q;j=K}else{k=27;break}}if((k|0)==27){return}}else{L=i;M=0;N=0;O=0;P=f}a:while(1){f=N>>>1;if((f|0)==0){i=P+4|0;if(i>>>0>g>>>0){k=27;break}K=P;Q=-2147483648;R=fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0;S=i}else{Q=f;R=O;S=P}do{if((Q&R|0)==0){T=S;U=L+12|0}else{if((S+h|0)>>>0>g>>>0){k=27;break a}f=L+12|0;i=a[S]|0;TGb(L|0,i|0,3)|0;K=a[S+1|0]|0;TGb(L+3|0,K|0,3)|0;j=a[S+2|0]|0;TGb(L+6|0,j|0,3)|0;e=a[S+3|0]|0;TGb(L+9|0,e|0,3)|0;c=S+4|0;if(!b){T=c;U=f;break}J=a[c]|0;c=a[S+5|0]|0;I=c<<1;H=(J|0)/2|0;G=J<<1;J=i&255;i=J+I|0;F=J-H-c|0;E=J+G|0;if(i>>>0>255>>>0){V=-i>>31&255}else{V=i&255}a[L]=V;if(F>>>0>255>>>0){W=-F>>31&255}else{W=F&255}a[L+1|0]=W;if(E>>>0>255>>>0){X=-E>>31&255}else{X=E&255}a[L+2|0]=X;E=K&255;K=E+I|0;F=E-H-c|0;i=E+G|0;if(K>>>0>255>>>0){Y=-K>>31&255}else{Y=K&255}a[L+3|0]=Y;if(F>>>0>255>>>0){Z=-F>>31&255}else{Z=F&255}a[L+4|0]=Z;if(i>>>0>255>>>0){_=-i>>31&255}else{_=i&255}a[L+5|0]=_;i=j&255;j=i+I|0;F=i-H-c|0;K=i+G|0;if(j>>>0>255>>>0){$=-j>>31&255}else{$=j&255}a[L+6|0]=$;if(F>>>0>255>>>0){aa=-F>>31&255}else{aa=F&255}a[L+7|0]=aa;if(K>>>0>255>>>0){ba=-K>>31&255}else{ba=K&255}a[L+8|0]=ba;K=e&255;e=K+I|0;I=K-H-c|0;c=K+G|0;if(e>>>0>255>>>0){ca=-e>>31&255}else{ca=e&255}a[L+9|0]=ca;if(I>>>0>255>>>0){da=-I>>31&255}else{da=I&255}a[L+10|0]=da;if(c>>>0>255>>>0){ea=-c>>31&255}else{ea=c&255}a[L+11|0]=ea;T=S+6|0;U=f}}while(0);f=M+1|0;if((f|0)<256){L=U;M=f;N=Q;O=R;P=T}else{k=27;break}}if((k|0)==27){return}}function K$(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;d=c[a+60>>2]|0;e=a+120|0;f=c[e>>2]|0;g=a+124|0;h=c[g>>2]|0;do{if((f&3|0)==0){if((h&3|0)!=0){break}j=d+372|0;k=c[j>>2]|0;l=d+376|0;m=c[l>>2]|0;if((k|0)>(m|0)){yDb(a,16,1942440,(n=i,i=i+16|0,c[n>>2]=k,c[n+8>>2]=m,n)|0);i=n;o=-22;i=b;return o|0}m=ICb()|0;k=d+32|0;c[k>>2]=m;if((m|0)==0){o=-12;i=b;return o|0}m=ICb()|0;p=d+36|0;c[p>>2]=m;a:do{if((m|0)==0){q=d+40|0}else{r=ICb()|0;s=d+40|0;c[s>>2]=r;if((r|0)==0){q=s;break}r=a+140|0;t=c[r>>2]|0;if((t|0)==2){u=ICb()|0;c[d+44>>2]=u;if((u|0)==0){q=s;break}v=c[r>>2]|0}else{v=t}t=WDb((ba(ba(c[g>>2]|0,c[e>>2]|0)|0,(v|0)==2?24:16)|0)>>>2)|0;c[d+344>>2]=t;if((t|0)==0){q=s;break}t=WDb((ba(c[g>>2]|0,c[e>>2]|0)|0)&1073741823)|0;c[d+348>>2]=t;if((t|0)==0){q=s;break}t=d+8|0;u=t;w=0;while(1){x=(c[r>>2]|0)==2;if((w|0)>=((x?4:3)|0)){break}y=WDb((ba(ba(c[e>>2]|0,x?6:4)|0,c[g>>2]|0)|0)>>2)|0;c[u+(w<<2)>>2]=y;if((y|0)==0){q=s;break a}else{w=w+1|0}}w=(ba(c[g>>2]|0,c[e>>2]|0)|0)/16|0;u=(((w+15|0)/16|0)+w<<2)+3160|0;y=(ba(u,c[l>>2]|0)|0)+10|0;x=WDb(u)|0;c[d+24>>2]=x;if((x|0)==0){q=s;break}x=WDb(y)|0;c[d+28>>2]=x;if((x|0)==0){q=s;break}x=WDb(w*36|0)|0;c[d+352>>2]=x;if((x|0)==0){q=s;break}oDb(d+72|0,1);c[d+4>>2]=a;x=c[e>>2]|0;w=d+52|0;c[w>>2]=x;u=d+56|0;c[u>>2]=c[g>>2];c[d+60>>2]=y;c[d+64>>2]=0;c[d+68>>2]=c[a+360>>2];y=c[r>>2]|0;c[d+48>>2]=y;c[c[k>>2]>>2]=c[t>>2];c[(c[k>>2]|0)+32>>2]=x;c[c[p>>2]>>2]=c[d+12>>2];c[(c[p>>2]|0)+32>>2]=c[w>>2];c[c[s>>2]>>2]=c[d+16>>2];c[(c[s>>2]|0)+32>>2]=c[w>>2];if((y|0)==2){y=c[k>>2]|0;x=c[w>>2]|0;z=ba(c[u>>2]|0,x)|0;c[y+4>>2]=(c[y>>2]|0)+z;y=c[k>>2]|0;c[y+8>>2]=(c[y+4>>2]|0)+(z>>2);z=x>>1;x=c[k>>2]|0;c[x+40>>2]=z;c[x+36>>2]=z;z=c[p>>2]|0;x=c[w>>2]|0;y=ba(c[u>>2]|0,x)|0;c[z+4>>2]=(c[z>>2]|0)+y;z=c[p>>2]|0;c[z+8>>2]=(c[z+4>>2]|0)+(y>>2);y=x>>1;x=c[p>>2]|0;c[x+40>>2]=y;c[x+36>>2]=y;y=c[s>>2]|0;x=c[w>>2]|0;z=ba(c[u>>2]|0,x)|0;c[y+4>>2]=(c[y>>2]|0)+z;y=c[s>>2]|0;c[y+8>>2]=(c[y+4>>2]|0)+(z>>2);z=x>>1;x=c[s>>2]|0;c[x+40>>2]=z;c[x+36>>2]=z;z=d+44|0;c[c[z>>2]>>2]=c[d+20>>2];x=c[z>>2]|0;c[x+32>>2]=c[w>>2];y=c[w>>2]|0;w=ba(c[u>>2]|0,y)|0;c[x+4>>2]=(c[x>>2]|0)+w;x=c[z>>2]|0;c[x+8>>2]=(c[x+4>>2]|0)+(w>>2);w=y>>1;y=c[z>>2]|0;c[y+40>>2]=w;c[y+36>>2]=w}c[d+356>>2]=c[j>>2];c[d+360>>2]=c[l>>2];o=0;i=b;return o|0}}while(0);JCb(k);JCb(p);JCb(q);l=a+140|0;if((c[l>>2]|0)==2){JCb(d+44|0)}$Db(d+344|0);$Db(d+348|0);$Db(d+24|0);$Db(d+28|0);$Db(d+352|0);j=d+8|0;m=0;while(1){$Db(j+(m<<2)|0);w=m+1|0;if((w|0)<(((c[l>>2]|0)==2?4:3)|0)){m=w}else{o=-12;break}}i=b;return o|0}}while(0);yDb(a,16,1971112,(n=i,i=i+16|0,c[n>>2]=f,c[n+8>>2]=h,n)|0);i=n;o=-22;i=b;return o|0}function L$(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,ee=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0;h=i;i=i+12640|0;j=h|0;k=h+64|0;l=h+128|0;m=h+192|0;n=h+256|0;o=h+12560|0;p=h+12568|0;q=h+12576|0;r=c[b+60>>2]|0;s=r;t=c[f+168>>2]|0;if((t|0)==0){u=0;v=256}else{w=t-1|0;u=(w|0)<0|0?-1:0;v=w}w=r+336|0;c[w>>2]=v;c[w+4>>2]=u;u=c[r+60>>2]|0;v=r0a(b,e,u,(u|0)<0|0?-1:0)|0;if((v|0)<0){y=v;i=h;return y|0}v=r+64|0;u=(c[v>>2]|0)==0;t=c[e+24>>2]|0;z=r+48|0;A=r+56|0;do{if((c[z>>2]|0)==2){B=c[A>>2]|0;if((B|0)<=0){C=0;D=0;E=0;G=0;break}H=r+52|0;I=f|0;J=f+32|0;K=r+44|0;L=0;M=0;N=0;O=0;P=0;Q=c[H>>2]|0;R=B;while(1){if((Q|0)>0){B=P>>1;S=L;T=M;U=N;V=O;W=0;while(1){X=c[I>>2]|0;Y=c[J>>2]|0;Z=(ba(Y,P)|0)+(W*3|0)|0;_=Z+Y|0;Y=c[K>>2]|0;$=c[Y>>2]|0;aa=c[Y+32>>2]|0;ca=ba(aa,P)|0;if((c[z>>2]|0)==2){da=W>>1;ea=c[Y+36>>2]|0;fa=(c[Y+4>>2]|0)+((ba(ea,B)|0)+da)|0;ga=c[Y+40>>2]|0;ha=fa;ia=(c[Y+8>>2]|0)+((ba(ga,B)|0)+da)|0;ja=ea;ka=ga}else{ha=V;ia=U;ja=T;ka=S}ga=ca+W|0;ca=d[X+Z|0]|0;ea=d[X+(Z|1)|0]|0;da=d[X+(Z+2)|0]|0;a[$+ga|0]=((ba(ea,4793251)|0)+(ba(ca,2396625)|0)+(ba(da,1198732)|0)|0)>>>23;Y=d[X+(Z+3)|0]|0;fa=d[X+(Z+4)|0]|0;la=d[X+(Z+5)|0]|0;Z=ga|1;a[$+Z|0]=((ba(fa,4793251)|0)+(ba(Y,2396625)|0)+(ba(la,1198732)|0)|0)>>>23;ma=d[X+_|0]|0;na=d[X+(_+1)|0]|0;oa=d[X+(_+2)|0]|0;a[$+(ga+aa)|0]=((ba(na,4793251)|0)+(ba(ma,2396625)|0)+(ba(oa,1198732)|0)|0)>>>23;ga=d[X+(_+3)|0]|0;pa=d[X+(_+4)|0]|0;qa=d[X+(_+5)|0]|0;_=Y+ca+ma+ga|0;ma=la+da+oa+qa|0;a[$+(Z+aa)|0]=((ba(pa,4793251)|0)+(ba(ga,2396625)|0)+(ba(qa,1198732)|0)|0)>>>23;qa=(fa+ea+na+pa|0)*-599156|0;pa=qa+(_*-299683|0)+(ma*898839|0)>>23;if((pa|0)<-128){ra=0}else{ra=(pa|0)>127?-1:pa+128&255}a[ha]=ra;pa=qa+(_*748893|0)+(ma*-149737|0)>>23;if((pa|0)<-128){sa=0}else{sa=(pa|0)>127?-1:pa+128&255}a[ia]=sa;pa=W+2|0;ta=c[H>>2]|0;if((pa|0)<(ta|0)){S=ka;T=ja;U=ia;V=ha;W=pa}else{break}}ua=ka;va=ja;wa=ia;xa=ha;ya=ta;za=c[A>>2]|0}else{ua=L;va=M;wa=N;xa=O;ya=Q;za=R}W=P+2|0;if((W|0)<(za|0)){L=ua;M=va;N=wa;O=xa;P=W;Q=ya;R=za}else{C=xa;D=wa;E=va;G=ua;break}}}else{C=0;D=0;E=0;G=0}}while(0);ua=r+356|0;va=r+360|0;wa=r+28|0;xa=u&1^1;za=r+52|0;ya=r+40|0;ta=r+36|0;ha=r+4|0;ia=r+44|0;ja=q|0;ka=q+32|0;sa=q+4|0;ra=q+36|0;R=q+8|0;Q=q+40|0;P=r+32|0;O=n+12288|0;N=n+12292|0;M=n+12296|0;L=r+24|0;H=j|0;K=r+368|0;J=r+352|0;I=k|0;W=k+32|0;V=k+4|0;U=k+36|0;T=k+8|0;S=k+40|0;B=u?16:17;pa=r+364|0;ma=l|0;_=l+32|0;qa=l+4|0;na=l+36|0;ea=l+8|0;fa=l+40|0;ga=m|0;aa=m+32|0;Z=m+4|0;$=m+36|0;oa=m+8|0;da=m+40|0;la=f|0;ca=f+32|0;Y=c[ua>>2]|0;X=0;Aa=0;Ba=0;Ca=0;Da=0;Ea=0;Fa=C;C=D;D=E;E=G;G=0;Ga=0;Ha=0;Ia=0;a:while(1){if((Y|0)>(c[va>>2]|0)){Ja=X;Ka=Ca;La=149;break}Ma=c[A>>2]|0;if((Y|0)>((Ma|0)/4|0|0)){Ja=X;Ka=Ca;La=149;break}if((Ma|0)>0){Na=Ia;Oa=Ha;Pa=Ga;Qa=G;Ra=E;Sa=D;Ta=C;Ua=Fa;Va=Da;Wa=Ea;Xa=0;Ya=0;Za=0;_a=0;$a=1;ab=Ma;while(1){Ma=(ba($a,ab)|0)/(Y|0)|0;bb=Ma&3;if((bb|0)==0){cb=Ma}else{cb=Ma+4-bb|0}bb=cb-_a|0;if((bb|0)<1){yDb(c[ha>>2]|0,32,2192960,(Ma=i,i=i+16|0,c[Ma>>2]=$a,c[Ma+8>>2]=Y,Ma)|0);i=Ma;db=Ya;eb=Za;fb=Xa;gb=Va;hb=Wa;ib=Ua;jb=Ta;kb=Sa;lb=Ra;mb=Qa;nb=Pa;ob=Oa;pb=Na}else{Ma=c[z>>2]|0;if((Ma|0)==2){qb=c[ia>>2]|0;rb=c[qb+32>>2]|0;sb=(c[qb>>2]|0)+(ba(rb,_a)|0)|0;c[ja>>2]=sb;c[ka>>2]=rb;tb=_a>>1;ub=c[qb+36>>2]|0;c[sa>>2]=(c[qb+4>>2]|0)+(ba(ub,tb)|0);c[ra>>2]=ub;ub=c[qb+40>>2]|0;c[R>>2]=(c[qb+8>>2]|0)+(ba(ub,tb)|0);c[Q>>2]=ub;vb=2;wb=sb;xb=rb}else{rb=c[ca>>2]|0;sb=(c[la>>2]|0)+(ba(rb,_a)|0)|0;c[ja>>2]=sb;c[ka>>2]=rb;vb=Ma;wb=sb;xb=rb}rb=c[P>>2]|0;sb=c[rb>>2]|0;Ma=c[rb+32>>2]|0;ub=ba(Ma,_a)|0;if((vb|0)==2){tb=_a>>1;qb=c[rb+36>>2]|0;yb=(c[rb+4>>2]|0)+(ba(qb,tb)|0)|0;zb=c[rb+40>>2]|0;Ab=(c[rb+8>>2]|0)+(ba(zb,tb)|0)|0;rb=c[ya>>2]|0;Bb=c[rb+36>>2]|0;Cb=(c[rb+4>>2]|0)+(ba(Bb,tb)|0)|0;Db=c[rb+40>>2]|0;Eb=Cb;Fb=(c[rb+8>>2]|0)+(ba(Db,tb)|0)|0;Gb=Bb;Hb=Db;Ib=zb;Jb=qb;Kb=Ab;Lb=yb;Mb=rb}else{Eb=Ua;Fb=Ta;Gb=Sa;Hb=Ra;Ib=Na;Jb=Oa;Kb=Pa;Lb=Qa;Mb=c[ya>>2]|0}rb=c[Mb+32>>2]|0;yb=c[Mb>>2]|0;Ab=ba(rb,_a)|0;qb=(c[wa>>2]|0)+(Xa+10)|0;do{if(!u){if((bb|0)<=0){break}zb=c[sa>>2]|0;Db=c[ra>>2]|0;Bb=c[R>>2]|0;tb=c[Q>>2]|0;Cb=0;Nb=0;Ob=c[za>>2]|0;Pb=vb;Qb=wb;Rb=xb;while(1){if((Ob|0)>0){Sb=Cb>>1;Tb=ba(Cb+_a|0,Ma)|0;if((Pb|0)==2){Ub=ba(Sb,Jb)|0;Vb=ba(Sb,Ib)|0;Wb=c[J>>2]|0;Xb=ba(Cb,Rb)|0;Yb=ba(Db,Sb)|0;Zb=ba(tb,Sb)|0;Sb=0;_b=Nb;while(1){c[ma>>2]=sb+(Sb+Tb);c[_>>2]=Ma;$b=Sb>>1;c[qa>>2]=Lb+($b+Ub);c[na>>2]=Jb;c[ea>>2]=Kb+($b+Vb);c[fa>>2]=Ib;c[ga>>2]=Qb+(Sb+Xb);c[aa>>2]=Rb;c[Z>>2]=zb+($b+Yb);c[$>>2]=Db;c[oa>>2]=Bb+($b+Zb);c[da>>2]=tb;c[Wb+(_b*36|0)+28>>2]=R$(s,l,m)|0;$b=Sb+4|0;ac=_b+1|0;bc=c[za>>2]|0;if(($b|0)<(bc|0)){Sb=$b;_b=ac}else{cc=ac;dc=bc;ec=2;fc=Qb;gc=Rb;break}}}else{_b=c[J>>2]|0;Sb=ba(Cb,xb)|0;Wb=0;Zb=Nb;while(1){c[ma>>2]=sb+(Wb+Tb);c[_>>2]=Ma;c[ga>>2]=wb+(Wb+Sb);c[aa>>2]=xb;c[_b+(Zb*36|0)+28>>2]=R$(s,l,m)|0;Yb=Wb+4|0;Xb=Zb+1|0;Vb=c[za>>2]|0;if((Yb|0)<(Vb|0)){Wb=Yb;Zb=Xb}else{cc=Xb;dc=Vb;ec=Pb;fc=wb;gc=xb;break}}}}else{cc=Nb;dc=Ob;ec=Pb;fc=Qb;gc=Rb}Zb=Cb+4|0;if((Zb|0)<(bb|0)){Cb=Zb;Nb=cc;Ob=dc;Pb=ec;Qb=fc;Rb=gc}else{break}}}}while(0);Rb=(bb|0)>0;Qb=de(bb&65535|0)|0;Pb=Ab+rb|0;Ob=ub+Ma|0;Nb=Ab+(rb<<1)|0;Cb=ub+(Ma<<1)|0;tb=_a+3|0;Bb=ba(rb,tb)|0;Db=ba(Ma,tb)|0;tb=0;zb=1;Zb=Va;Wb=Wa;while(1){if((zb|0)>-1){_b=(zb|0)>3?zb>>2:1;Sb=tb;Tb=0;Vb=0;Xb=Zb;Yb=Wb;while(1){Ub=(Vb|0)==0;bc=Sb;ac=Tb;$b=0;hc=0;ic=Xb;jc=Yb;while(1){b:do{if(u&(hc|0)==2){kc=$b;lc=ac;mc=bc;nc=ic;oc=jc}else{c:do{if((hc|0)==0){c[O>>2]=zb;pc=N$(s,bb,q,1,n,3)|0;c[O>>2]=pc;qc=(pc|0)<(zb|0)?1:ac;c[N>>2]=0;c[M>>2]=0;rc=ba(c[za>>2]|0,bb)|0;sc=(rc|0)/16|0;tc=c[w>>2]|0;uc=c[w+4>>2]|0;if((pc|0)==0){vc=0;wc=4}else{xc=(ba((c[z>>2]|0)==2?6:4,pc)|0)+8|0;vc=(xc|0)<0|0?-1:0;wc=xc}xc=YGb(wc,vc,sc,(sc|0)<0|0?-1:0)|0;pc=gHb(xc<<3|0>>>29,F<<3|xc>>>29,tc,uc)|0;uc=F;if((rc|0)>15){yc=0;zc=uc;Ac=pc}else{Bc=uc;Cc=pc;Dc=qc;Ec=$b;break}while(1){pc=c[J>>2]|0;uc=c[pc+(yc*36|0)+4>>2]<<7;rc=YGb(uc,(uc|0)<0|0?-1:0,Ac,zc)|0;uc=F;c[pc+(yc*36|0)+32>>2]=0;pc=yc+1|0;if((pc|0)<(sc|0)){yc=pc;zc=uc;Ac=rc}else{Bc=uc;Cc=rc;Dc=qc;Ec=$b;break}}}else{if(Ub){kc=$b;lc=ac;mc=bc;nc=ic;oc=jc;break b}if((hc|0)==1){c[N>>2]=Vb;qc=N$(s,bb,q,0,n,3)|0;c[N>>2]=qc;Fc=(qc|0)<(Vb|0)?1:$b;Gc=qc}else{Fc=$b;Gc=c[N>>2]|0}c[M>>2]=hc;O$(s,bb,c[O>>2]|0,Gc,hc,0,o,p)|0;qc=c[pa>>2]|0;c[O>>2]=zb;sc=N$(s,bb,q,1,n,0)|0;if((sc|0)<(c[O>>2]|0)){c[O>>2]=sc}c[N>>2]=Vb;sc=N$(s,bb,q,0,n,1)|0;rc=c[N>>2]|0;if((sc|0)<(rc|0)){c[N>>2]=sc;Hc=qc;Ic=sc}else{Hc=qc;Ic=rc}while(1){rc=O$(s,bb,c[O>>2]|0,Ic,c[M>>2]|0,1,o,p)|0;qc=F;sc=(c[o>>2]|0)==0;if(sc){if((c[p>>2]|0)==0){Bc=qc;Cc=rc;Dc=ac;Ec=Fc;break c}}uc=Hc-1|0;if((Hc|0)==0){Bc=qc;Cc=rc;Dc=ac;Ec=Fc;break c}do{if(!sc){c[O>>2]=zb;rc=N$(s,bb,q,1,n,0)|0;if((rc|0)>=(c[O>>2]|0)){break}c[O>>2]=rc}}while(0);if((c[p>>2]|0)==0){Hc=uc;Ic=c[N>>2]|0;continue}c[N>>2]=Vb;sc=N$(s,bb,q,0,n,1)|0;rc=c[N>>2]|0;if((sc|0)>=(rc|0)){Hc=uc;Ic=rc;continue}c[N>>2]=sc;Hc=uc;Ic=sc}}}while(0);if(!((bc|0)==0|((Bc|0)<(ic|0)|(Bc|0)==(ic|0)&Cc>>>0<jc>>>0))){kc=Ec;lc=Dc;mc=bc;nc=ic;oc=jc;break}sc=c[L>>2]|0;rc=sc+12|0;qc=ba(c[za>>2]|0,bb)|0;pc=(qc|0)/16|0;tc=c[N>>2]|0;if((tc|0)==0){if((c[K>>2]|0)==0){La=73}else{Jc=0}}else{La=73}do{if((La|0)==73){La=0;xc=(c[z>>2]|0)==2;Kc=xc?6:4;Lc=ba(Kc,tc)|0;a[rc]=xc?32:36;xc=Lc+4|0;a[sc+15|0]=xc;a[sc+14|0]=xc>>>8;a[sc+13|0]=xc>>>16;if((tc|0)>0){Mc=4;Nc=0}else{Jc=4;break}while(1){Lc=ba(Nc,Kc)|0;Oc=Mc;Pc=0;while(1){a[sc+(Oc+12)|0]=c[n+6144+(Pc+Lc<<2)>>2]^((Pc|0)>3?128:0);Qc=Pc+1|0;if((Qc|0)<(Kc|0)){Oc=Oc+1|0;Pc=Qc}else{break}}Pc=Nc+1|0;if((Pc|0)<(tc|0)){Mc=Mc+Kc|0;Nc=Pc}else{Jc=xc;break}}}}while(0);tc=c[O>>2]|0;if((tc|0)==0){if((c[K>>2]|0)==0){La=79}else{Rc=Jc}}else{La=79}if((La|0)==79){La=0;rc=Jc+12|0;xc=(c[z>>2]|0)==2;Kc=xc?6:4;Pc=ba(Kc,tc)|0;a[sc+rc|0]=xc?34:38;xc=Pc+4|0;a[sc+(Jc+15)|0]=xc;a[sc+(Jc+14)|0]=xc>>>8;a[sc+(Jc+13)|0]=xc>>>16;if((tc|0)>0){Pc=4;Oc=0;while(1){Lc=ba(Oc,Kc)|0;uc=Pc;Qc=0;while(1){a[sc+(uc+rc)|0]=c[n+(Qc+Lc<<2)>>2]^((Qc|0)>3?128:0);Sc=Qc+1|0;if((Sc|0)<(Kc|0)){uc=uc+1|0;Qc=Sc}else{break}}Qc=Oc+1|0;if((Qc|0)<(tc|0)){Pc=Pc+Kc|0;Oc=Qc}else{Tc=xc;break}}}else{Tc=4}Rc=Tc+Jc|0}if(Rb){xc=0;Oc=0;Kc=0;Pc=0;tc=0;rc=0;Qc=c[za>>2]|0;while(1){if((Qc|0)>0){uc=tc>>1;Lc=ba(tc,rb)|0;Sc=ba(uc,Gb)|0;Uc=ba(uc,Hb)|0;Vc=ba(tc,Ma)|0;Wc=ba(uc,Jb)|0;Xc=ba(uc,Ib)|0;uc=xc;Yc=Oc;Zc=Kc;_c=Pc;$c=rc;ad=0;while(1){bd=c[J>>2]|0;cd=c[z>>2]|0;dd=ad+Lc|0;ed=yb+(dd+Ab)|0;c[I>>2]=ed;c[W>>2]=rb;fd=(cd|0)==2;if(fd){cd=ad>>1;c[V>>2]=Eb+(cd+Sc);c[U>>2]=Gb;c[T>>2]=Fb+(cd+Uc);c[S>>2]=Hb}cd=c[M>>2]|0;do{if((cd|0)==2){gd=c[bd+($c*36|0)+32>>2]|0;if((gd|0)!=2){hd=gd;La=97;break}gd=ad+Vc|0;if(fd){id=ad>>1;jd=Lb+(id+Wc)|0;kd=Kb+(id+Xc)|0;ld=Jb;md=Ib}else{jd=_c;kd=Zc;ld=Yc;md=uc}id=sb+(gd+ub)|0;nd=ed;x=d[id]|d[id+1|0]<<8|d[id+2|0]<<16|d[id+3|0]<<24|0;a[nd]=x;x=x>>8;a[nd+1|0]=x;x=x>>8;a[nd+2|0]=x;x=x>>8;a[nd+3|0]=x;nd=sb+(Ob+gd)|0;id=yb+(Pb+dd)|0;x=d[nd]|d[nd+1|0]<<8|d[nd+2|0]<<16|d[nd+3|0]<<24|0;a[id]=x;x=x>>8;a[id+1|0]=x;x=x>>8;a[id+2|0]=x;x=x>>8;a[id+3|0]=x;id=sb+(Cb+gd)|0;nd=yb+(Nb+dd)|0;x=d[id]|d[id+1|0]<<8|d[id+2|0]<<16|d[id+3|0]<<24|0;a[nd]=x;x=x>>8;a[nd+1|0]=x;x=x>>8;a[nd+2|0]=x;x=x>>8;a[nd+3|0]=x;nd=sb+(gd+Db)|0;gd=yb+(dd+Bb)|0;x=d[nd]|d[nd+1|0]<<8|d[nd+2|0]<<16|d[nd+3|0]<<24|0;a[gd]=x;x=x>>8;a[gd+1|0]=x;x=x>>8;a[gd+2|0]=x;x=x>>8;a[gd+3|0]=x;if((c[z>>2]|0)!=2){od=jd;pd=kd;qd=ld;rd=md;break}gd=c[V>>2]|0;nd=jd;id=gd;x=(d[nd]|d[nd+1|0]<<8)<<16>>16;a[id]=x;x=x>>8;a[id+1|0]=x;id=jd+ld|0;nd=gd+(c[U>>2]|0)|0;x=(d[id]|d[id+1|0]<<8)<<16>>16;a[nd]=x;x=x>>8;a[nd+1|0]=x;nd=c[T>>2]|0;id=kd;gd=nd;x=(d[id]|d[id+1|0]<<8)<<16>>16;a[gd]=x;x=x>>8;a[gd+1|0]=x;gd=kd+md|0;id=nd+(c[S>>2]|0)|0;x=(d[gd]|d[gd+1|0]<<8)<<16>>16;a[id]=x;x=x>>8;a[id+1|0]=x;od=jd;pd=kd;qd=ld;rd=md}else if((cd|0)==0){La=98}else{hd=c[bd+($c*36|0)+32>>2]|0;La=97}}while(0);do{if((La|0)==97){La=0;if((hd|0)==0){La=98;break}Q$(s,k,bd+($c*36|0)+8|0,n);od=_c;pd=Zc;qd=Yc;rd=uc}}while(0);if((La|0)==98){La=0;P$(s,k,c[bd+($c*36|0)>>2]|0,n);od=_c;pd=Zc;qd=Yc;rd=uc}cd=ad+4|0;dd=$c+1|0;ed=c[za>>2]|0;if((cd|0)<(ed|0)){uc=rd;Yc=qd;Zc=pd;_c=od;$c=dd;ad=cd}else{sd=rd;td=qd;ud=pd;vd=od;wd=dd;xd=ed;break}}}else{sd=xc;td=Oc;ud=Kc;vd=Pc;wd=rc;xd=Qc}ad=tc+4|0;if((ad|0)<(bb|0)){xc=sd;Oc=td;Kc=ud;Pc=vd;tc=ad;rc=wd;Qc=xd}else{break}}}Qc=c[M>>2]|0;do{if((Qc|0)==0){a[sc+(Rc+12)|0]=50;rc=pc+4|0;a[sc+(Rc+15)|0]=rc;a[sc+(Rc+14)|0]=rc>>>8;a[sc+(Rc+13)|0]=rc>>>16;tc=Rc+4|0;if((qc|0)>15){yd=tc;zd=0}else{Ad=tc;break}while(1){a[sc+(yd+12)|0]=c[(c[J>>2]|0)+(zd*36|0)>>2];tc=zd+1|0;if((tc|0)<(pc|0)){yd=yd+1|0;zd=tc}else{break}}Ad=Rc+((qc|0)>31?rc:5)|0}else if((Qc|0)==1){tc=Rc+4|0;if((qc|0)>15){Pc=tc;Kc=0;while(1){Oc=Kc+32|0;xc=(Oc|0)>(pc|0)?pc:Oc;if((Kc|0)<(xc|0)){ad=c[J>>2]|0;$c=Kc|31;_c=Kc;Zc=0;while(1){if((c[ad+(_c*36|0)+32>>2]|0)==1){Bd=1<<$c-_c|Zc}else{Bd=Zc}Yc=_c+1|0;if((Yc|0)<(xc|0)){_c=Yc;Zc=Bd}else{break}}Zc=sc+(Pc+12)|0;x=fe(Bd|0)|0;a[Zc]=x;x=x>>8;a[Zc+1|0]=x;x=x>>8;a[Zc+2|0]=x;x=x>>8;a[Zc+3|0]=x;Zc=Kc;_c=Pc+4|0;while(1){$c=c[J>>2]|0;if((c[$c+(Zc*36|0)+32>>2]|0)==0){a[sc+(_c+12)|0]=c[$c+(Zc*36|0)>>2];Cd=_c+1|0}else{a[sc+(_c+12)|0]=c[$c+(Zc*36|0)+8>>2];a[sc+(_c+13)|0]=c[$c+(Zc*36|0)+12>>2];a[sc+(_c+14)|0]=c[$c+(Zc*36|0)+16>>2];a[sc+(_c+15)|0]=c[$c+(Zc*36|0)+20>>2];Cd=_c+4|0}$c=Zc+1|0;if(($c|0)<(xc|0)){Zc=$c;_c=Cd}else{Dd=Cd;break}}}else{_c=sc+(Pc+12)|0;x=0;a[_c]=x;x=x>>8;a[_c+1|0]=x;x=x>>8;a[_c+2|0]=x;x=x>>8;a[_c+3|0]=x;Dd=Pc+4|0}if((Oc|0)<(pc|0)){Pc=Dd;Kc=Oc}else{Ed=Dd;break}}}else{Ed=tc}Kc=Ed-Rc|0;a[sc+(Rc+12)|0]=48;a[sc+(Rc+15)|0]=Kc;a[sc+(Rc+14)|0]=Kc>>>8;a[sc+(Rc+13)|0]=Kc>>>16;Ad=Ed}else if((Qc|0)==2){Kc=Rc+4|0;do{if((qc|0)>15){Pc=0;rc=0;_c=0;Zc=Kc;xc=0;while(1){$c=c[J>>2]|0;ad=$c+(xc*36|0)+32|0;bd=c[ad>>2]|0;Yc=(bd|0)!=2;uc=rc+1|0;Xc=(Yc&1)<<31-rc|Pc;do{if(Yc){if((uc|0)>=32){Fd=1;Gd=uc;Hd=Xc;break}Fd=0;Gd=rc+2|0;Hd=Xc|((bd|0)==1)<<30-rc}else{Fd=0;Gd=uc;Hd=Xc}}while(0);do{if((Gd|0)==32){Xc=sc+(Zc+12)|0;x=fe(Hd|0)|0;a[Xc]=x;x=x>>8;a[Xc+1|0]=x;x=x>>8;a[Xc+2|0]=x;x=x>>8;a[Xc+3|0]=x;Xc=Zc+4|0;uc=c[ad>>2]|0;if((uc|0)!=2&(Fd|0)==0){Id=1;Jd=Xc;Kd=_c;Ld=0;Md=0;Nd=uc;break}UGb(sc+(Zc+16)|0,H|0,_c)|0;Id=0;Jd=Xc+_c|0;Kd=0;Ld=0;Md=0;Nd=c[ad>>2]|0}else{Id=0;Jd=Zc;Kd=_c;Ld=Gd;Md=Hd;Nd=bd}}while(0);if((Fd|0)==0){Od=Ld;Pd=Md}else{Od=1;Pd=((Nd|0)==1)<<31}if((Nd|0)==1){a[j+Kd|0]=c[$c+(xc*36|0)+8>>2];a[j+(Kd+1)|0]=c[$c+(xc*36|0)+12>>2];a[j+(Kd+2)|0]=c[$c+(xc*36|0)+16>>2];a[j+(Kd+3)|0]=c[$c+(xc*36|0)+20>>2];Qd=Kd+4|0}else if((Nd|0)==0){a[j+Kd|0]=c[$c+(xc*36|0)>>2];Qd=Kd+1|0}else{Qd=Kd}if((Id|0)==0){Rd=Jd;Sd=Qd}else{UGb(sc+(Jd+12)|0,H|0,Qd)|0;Rd=Qd+Jd|0;Sd=0}bd=xc+1|0;if((bd|0)<(pc|0)){Pc=Pd;rc=Od;_c=Sd;Zc=Rd;xc=bd}else{break}}if((Od|0)<=0){Td=Rd;break}xc=sc+(Rd+12)|0;x=fe(Pd|0)|0;a[xc]=x;x=x>>8;a[xc+1|0]=x;x=x>>8;a[xc+2|0]=x;x=x>>8;a[xc+3|0]=x;UGb(sc+(Rd+16)|0,H|0,Sd)|0;Td=Sd+4+Rd|0}else{Td=Kc}}while(0);Kc=Td-Rc|0;a[sc+(Rc+12)|0]=49;a[sc+(Rc+15)|0]=Kc;a[sc+(Rc+14)|0]=Kc>>>8;a[sc+(Rc+13)|0]=Kc>>>16;Ad=Td}else{Ad=Rc}}while(0);sc=c[L>>2]|0;a[sc]=B;pc=Ad+12|0;a[sc+3|0]=pc;a[sc+2|0]=pc>>>8;a[sc+1|0]=pc>>>16;pc=sc+4|0;x=0;a[pc]=x;x=x>>8;a[pc+1|0]=x;pc=sc+6|0;x=0;a[pc]=x;x=x>>8;a[pc+1|0]=x;pc=sc+8|0;x=Qb;a[pc]=x;x=x>>8;a[pc+1|0]=x;pc=sc+10|0;x=de(c[za>>2]&65535|0)|0;a[pc]=x;x=x>>8;a[pc+1|0]=x;kc=Ec;lc=Dc;mc=Ad;nc=Bc;oc=Cc}}while(0);pc=hc+1|0;if(pc>>>0<3>>>0){bc=mc;ac=lc;$b=kc;hc=pc;ic=nc;jc=oc}else{break}}jc=Ub?_b:Vb<<2;if((jc|0)<=(zb|0)&(kc|0)==0){Sb=mc;Tb=lc;Vb=jc;Xb=nc;Yb=oc}else{Ud=mc;Vd=lc;Wd=nc;Xd=oc;break}}}else{Ud=tb;Vd=0;Wd=Zb;Xd=Wb}Yb=zb<<2;if((Yb|0)<257&(Vd|0)==0){tb=Ud;zb=Yb;Zb=Wd;Wb=Xd}else{break}}Wb=Ud+12|0;UGb(qb|0,c[L>>2]|0,Wb)|0;if((Wb|0)<0){Yd=Wb;break a}Zb=YGb(Xd,Wd,Za,Ya)|0;db=F;eb=Zb;fb=Wb+Xa|0;gb=Wd;hb=Xd;ib=Eb;jb=Fb;kb=Gb;lb=Hb;mb=Lb;nb=Kb;ob=Jb;pb=Ib}Wb=c[A>>2]|0;if((cb|0)<(Wb|0)){Na=pb;Oa=ob;Pa=nb;Qa=mb;Ra=lb;Sa=kb;Ta=jb;Ua=ib;Va=gb;Wa=hb;Xa=fb;Ya=db;Za=eb;_a=cb;$a=$a+1|0;ab=Wb}else{Zd=pb;_d=ob;$d=nb;ae=mb;be=lb;ce=kb;ee=jb;ge=ib;he=gb;ie=hb;je=fb;ke=db;le=eb;break}}}else{Zd=Ia;_d=Ha;$d=Ga;ae=G;be=E;ce=D;ee=C;ge=Fa;he=Da;ie=Ea;je=0;ke=0;le=0}if((Ba|0)==0&(Aa|0)==0|((ke|0)<(Aa|0)|(ke|0)==(Aa|0)&le>>>0<Ba>>>0)){ab=c[wa>>2]|0;a[ab]=xa;$a=je+10|0;a[ab+3|0]=$a;a[ab+2|0]=$a>>>8;a[ab+1|0]=$a>>>16;_a=ab+4|0;x=de(c[za>>2]&65535|0)|0;a[_a]=x;x=x>>8;a[_a+1|0]=x;_a=ab+6|0;x=de(c[A>>2]&65535|0)|0;a[_a]=x;x=x>>8;a[_a+1|0]=x;_a=ab+8|0;x=de(Y&65535|0)|0;a[_a]=x;x=x>>8;a[_a+1|0]=x;_a=c[ya>>2]|0;c[ya>>2]=c[ta>>2];c[ta>>2]=_a;UGb(t|0,c[wa>>2]|0,$a)|0;me=Y;ne=ke;oe=le;pe=$a}else{me=X;ne=Aa;oe=Ba;pe=Ca}if((Y-me|0)>4){Ja=me;Ka=pe;La=149;break}Y=Y+1|0;X=me;Aa=ne;Ba=oe;Ca=pe;Da=he;Ea=ie;Fa=ge;C=ee;D=ce;E=be;G=ae;Ga=$d;Ha=_d;Ia=Zd}do{if((La|0)==149){Zd=c[r+380>>2]|0;if((Zd|0)!=0){Ia=Zd+Ja|0;c[va>>2]=Ia;_d=c[r+376>>2]|0;if((Ia|0)>=(_d|0)){c[va>>2]=_d}_d=Ja-Zd|0;c[ua>>2]=_d;Zd=c[r+372>>2]|0;if((_d|0)>=(Zd|0)){Yd=Ka;break}c[ua>>2]=Zd;Yd=Ka;break}do{if((Ja|0)==(c[va>>2]|0)){Zd=Ja+1|0;c[va>>2]=Zd;_d=c[r+376>>2]|0;if((Zd|0)<(_d|0)){qe=Zd;break}c[va>>2]=_d;qe=_d}else{c[va>>2]=Ja;qe=Ja}}while(0);_d=qe-1|0;c[ua>>2]=_d;Zd=c[r+372>>2]|0;if((_d|0)>=(Zd|0)){Yd=Ka;break}c[ua>>2]=Zd;Yd=Ka}}while(0);c[e+28>>2]=Yd;if((c[v>>2]|0)==0){Yd=e+36|0;c[Yd>>2]=c[Yd>>2]|1}c[g>>2]=1;c[b+804>>2]=f;f=c[ta>>2]|0;c[ta>>2]=c[P>>2];c[P>>2]=f;f=(c[v>>2]|0)+1|0;c[v>>2]=f;if((f|0)<(c[r+68>>2]|0)){y=0;i=h;return y|0}c[v>>2]=0;y=0;i=h;return y|0}function M$(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;JCb(b+32|0);JCb(b+36|0);JCb(b+40|0);d=a+140|0;if((c[d>>2]|0)==2){JCb(b+44|0)}$Db(b+344|0);$Db(b+348|0);$Db(b+24|0);$Db(b+28|0);$Db(b+352|0);a=b+8|0;b=0;do{$Db(a+(b<<2)|0);b=b+1|0;}while((b|0)<(((c[d>>2]|0)==2?4:3)|0));return 0}function N$(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;j=i;i=i+152|0;k=j|0;l=j+24|0;m=j+88|0;n=a+48|0;o=(c[n>>2]|0)==2?6:4;p=(f|0)!=0;f=(p?g|0:g+6144|0)|0;q=c[(p?g+12288|0:g+12292|0)>>2]|0;r=(b|0)>0;if(!r){s=0;i=j;return s|0}t=a+52|0;u=(h|0)==3;v=a+344|0;w=p?1:4;x=a+352|0;y=o<<1;z=0;A=0;B=0;C=c[t>>2]|0;while(1){if((C|0)>0){D=z;E=A;F=0;G=C;while(1){if(u){H=6}else{if((c[(c[x>>2]|0)+(D*36|0)+32>>2]|0)==(h|0)){H=6}else{I=E;J=G}}if((H|0)==6){H=0;K=c[v>>2]|0;L=ba(E,o)|0;if(p){M=0;N=0;while(1){O=(M|0)<4;P=O&1^1;Q=(O?M:0)+B>>P;R=Q+1|0;S=F>>P;if(O){O=e+32|0;T=c[O>>2]|0;U=ba(T,Q)|0;V=c[e>>2]|0;W=S+1|0;X=ba(T,R)|0;c[K+(N+L<<2)>>2]=((d[V+(U+W)|0]|0)+(d[V+(U+S)|0]|0)+(d[V+(X+S)|0]|0)+(d[V+(X+W)|0]|0)|0)>>>2;W=(F|2)>>P;P=c[O>>2]|0;O=ba(P,Q)|0;X=W+1|0;U=ba(P,R)|0;c[K+((N|1)+L<<2)>>2]=((d[V+(O+X)|0]|0)+(d[V+(O+W)|0]|0)+(d[V+(U+W)|0]|0)+(d[V+(U+X)|0]|0)|0)>>>2}else{X=c[e+36>>2]|0;U=ba(X,Q)|0;V=c[e+4>>2]|0;W=S+1|0;O=ba(X,R)|0;c[K+(N+L<<2)>>2]=((d[V+(U+W)|0]|0)+(d[V+(U+S)|0]|0)+(d[V+(O+S)|0]|0)+(d[V+(O+W)|0]|0)|0)>>>2;O=c[e+40>>2]|0;V=ba(O,Q)|0;Q=c[e+8>>2]|0;U=ba(O,R)|0;c[K+((N|1)+L<<2)>>2]=((d[Q+(V+W)|0]|0)+(d[Q+(V+S)|0]|0)+(d[Q+(U+S)|0]|0)+(d[Q+(U+W)|0]|0)|0)>>>2}W=M+2|0;if((W|0)<(o|0)){M=W;N=N+2|0}else{break}}}else{N=B>>1;M=F>>1;W=0;U=0;while(1){Q=(W|0)>3;S=Q?W-3|0:0;if(Q){Y=N;Z=M}else{Y=B+(W>>1)|0;Z=W&1|F}Q=(ba(c[e+32+(S<<2)>>2]|0,Y)|0)+Z|0;c[K+(U+L<<2)>>2]=d[(c[e+(S<<2)>>2]|0)+Q|0]|0;Q=W+1|0;if((Q|0)<(o|0)){W=Q;U=U+1|0}else{break}}U=F|2;W=U>>1;Q=0;S=o;while(1){V=(Q|0)>3;R=V?Q-3|0:0;if(V){_=N;$=W}else{_=B+(Q>>1)|0;$=Q&1|U}V=(ba(c[e+32+(R<<2)>>2]|0,_)|0)+$|0;c[K+(S+L<<2)>>2]=d[(c[e+(R<<2)>>2]|0)+V|0]|0;V=Q+1|0;if((V|0)<(o|0)){Q=V;S=S+1|0}else{break}}S=B|2;Q=S>>1;N=0;V=y;while(1){R=(N|0)>3;O=R?N-3|0:0;if(R){aa=Q;ca=M}else{aa=S+(N>>1)|0;ca=N&1|F}R=(ba(c[e+32+(O<<2)>>2]|0,aa)|0)+ca|0;c[K+(V+L<<2)>>2]=d[(c[e+(O<<2)>>2]|0)+R|0]|0;R=N+1|0;if((R|0)<(o|0)){N=R;V=V+1|0}else{break}}V=0;N=o+y|0;while(1){M=(V|0)>3;R=M?V-3|0:0;if(M){da=Q;ea=W}else{da=S+(V>>1)|0;ea=V&1|U}M=(ba(c[e+32+(R<<2)>>2]|0,da)|0)+ea|0;c[K+(N+L<<2)>>2]=d[(c[e+(R<<2)>>2]|0)+M|0]|0;M=V+1|0;if((M|0)<(o|0)){V=M;N=N+1|0}else{break}}}I=E+w|0;J=c[t>>2]|0}N=F+4|0;V=D+1|0;if((N|0)<(J|0)){D=V;E=I;F=N;G=J}else{fa=V;ga=I;ha=J;break}}}else{fa=z;ga=A;ha=C}G=B+4|0;if((G|0)<(b|0)){z=fa;A=ga;B=G;C=ha}else{break}}if((ga|0)==0){s=0;i=j;return s|0}ha=(ga|0)<(q|0)?ga:q;q=a+344|0;C=a+348|0;B=a+72|0;D8(c[q>>2]|0,o,ga,f,ha,1,c[C>>2]|0,B);E8(c[q>>2]|0,o,ga,f,ha,1,c[C>>2]|0,B);c[m>>2]=k;c[m+32>>2]=4;c[m+4>>2]=k+16;c[m+8>>2]=k+20;c[m+40>>2]=2;c[m+36>>2]=2;if(r){r=a+52|0;k=a+352|0;B=(h|0)==3;f=e|0;ga=e+32|0;o=l|0;q=l+32|0;A=e+4|0;fa=e+36|0;z=l+4|0;J=l+36|0;I=e+8|0;t=e+40|0;e=l+8|0;w=l+40|0;ea=p?1:4;da=0;y=0;ca=0;aa=c[r>>2]|0;while(1){a:do{if((aa|0)>0){$=ca>>1;if(B){_=da;Z=y;Y=0;while(1){v=c[k>>2]|0;H=c[n>>2]|0;x=c[ga>>2]|0;c[o>>2]=(c[f>>2]|0)+((ba(x,ca)|0)+Y);c[q>>2]=x;if((H|0)==2){H=Y>>1;x=c[fa>>2]|0;c[z>>2]=(c[A>>2]|0)+((ba(x,$)|0)+H);c[J>>2]=x;x=c[t>>2]|0;c[e>>2]=(c[I>>2]|0)+((ba(x,$)|0)+H);c[w>>2]=x}x=c[C>>2]|0;H=c[x+(Z<<2)>>2]|0;if(p){c[v+(_*36|0)>>2]=H;P$(a,m,H,g);c[v+(_*36|0)+4>>2]=R$(a,l,m)|0}else{u=v+(_*36|0)+8|0;c[u>>2]=H;c[v+(_*36|0)+12>>2]=c[x+(Z+1<<2)>>2];c[v+(_*36|0)+16>>2]=c[x+(Z+2<<2)>>2];c[v+(_*36|0)+20>>2]=c[x+(Z+3<<2)>>2];Q$(a,m,u,g);c[v+(_*36|0)+24>>2]=R$(a,l,m)|0}v=Z+ea|0;u=c[r>>2]|0;x=Y+4|0;H=_+1|0;if((x|0)<(u|0)){_=H;Z=v;Y=x}else{ia=H;ja=v;ka=u;break a}}}else{la=da;ma=y;na=0;oa=aa}while(1){Y=c[k>>2]|0;if((c[Y+(la*36|0)+32>>2]|0)==(h|0)){Z=c[n>>2]|0;_=c[ga>>2]|0;c[o>>2]=(c[f>>2]|0)+((ba(_,ca)|0)+na);c[q>>2]=_;if((Z|0)==2){Z=na>>1;_=c[fa>>2]|0;c[z>>2]=(c[A>>2]|0)+((ba(_,$)|0)+Z);c[J>>2]=_;_=c[t>>2]|0;c[e>>2]=(c[I>>2]|0)+((ba(_,$)|0)+Z);c[w>>2]=_}_=c[C>>2]|0;Z=c[_+(ma<<2)>>2]|0;if(p){c[Y+(la*36|0)>>2]=Z;P$(a,m,Z,g);c[Y+(la*36|0)+4>>2]=R$(a,l,m)|0}else{u=Y+(la*36|0)+8|0;c[u>>2]=Z;c[Y+(la*36|0)+12>>2]=c[_+(ma+1<<2)>>2];c[Y+(la*36|0)+16>>2]=c[_+(ma+2<<2)>>2];c[Y+(la*36|0)+20>>2]=c[_+(ma+3<<2)>>2];Q$(a,m,u,g);c[Y+(la*36|0)+24>>2]=R$(a,l,m)|0}pa=ma+ea|0;qa=c[r>>2]|0}else{pa=ma;qa=oa}Y=na+4|0;u=la+1|0;if((Y|0)<(qa|0)){la=u;ma=pa;na=Y;oa=qa}else{ia=u;ja=pa;ka=qa;break}}}else{ia=da;ja=y;ka=aa}}while(0);$=ca+4|0;if(($|0)<(b|0)){da=ia;y=ja;ca=$;aa=ka}else{ra=ja;break}}}else{ra=0}if((ra|0)<(ha|0)){yDb(0,0,2114760,(ra=i,i=i+24|0,c[ra>>2]=2055776,c[ra+8>>2]=2009840,c[ra+16>>2]=898,ra)|0);i=ra;Cd();return 0}else{s=ha;i=j;return s|0}return 0}function O$(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;j=(c[a+48>>2]|0)==2?6:4;k=ba(c[a+52>>2]|0,b)|0;b=(k|0)/16|0;l=a+336|0;m=c[l>>2]|0;n=c[l+4>>2]|0;if((d|0)==0){o=4}else{o=(ba(j,d)|0)+8|0}if((e|0)==0){p=0}else{p=(ba(j,e)|0)+4|0}e=o+p|0;p=gHb(m<<3|0>>>29,n<<3|m>>>29,e,(e|0)<0|0?-1:0)|0;e=F;if((f|0)==2){o=(k|0)>15;if((g|0)==0){if(!o){q=e;r=p;return(F=q,r)|0}j=a+352|0;d=0;s=e;t=p;u=n;v=m;while(1){w=c[j>>2]|0;x=c[w+(d*36|0)+28>>2]<<7;y=YGb(x,(x|0)<0|0?-1:0,v,u)|0;x=F;z=gHb(v,u,10,0)|0;A=c[w+(d*36|0)+4>>2]<<7;B=YGb(A,(A|0)<0|0?-1:0,z,F)|0;z=F;A=gHb(v,u,34,0)|0;C=c[w+(d*36|0)+24>>2]<<7;D=YGb(C,(C|0)<0|0?-1:0,A,F)|0;A=F;do{if((x|0)>(z|0)|(x|0)==(z|0)&y>>>0>B>>>0|((x|0)>(A|0)|(x|0)==(A|0)&y>>>0>D>>>0)){C=w+(d*36|0)+32|0;if((z|0)>(A|0)|(z|0)==(A|0)&B>>>0>D>>>0){c[C>>2]=1;E=A;G=D;break}else{c[C>>2]=0;E=z;G=B;break}}else{c[w+(d*36|0)+32>>2]=2;E=x;G=y}}while(0);y=YGb(G,E,t,s)|0;x=F;w=d+1|0;if((w|0)>=(b|0)){q=x;r=y;break}d=w;s=x;t=y;u=c[l+4>>2]|0;v=c[l>>2]|0}return(F=q,r)|0}else{a:do{if(o){v=a+352|0;u=0;t=e;s=p;d=0;E=0;G=n;j=m;while(1){y=c[v>>2]|0;x=c[y+(u*36|0)+28>>2]<<7;w=YGb(x,(x|0)<0|0?-1:0,j,G)|0;x=F;B=y+(u*36|0)+32|0;z=c[B>>2]|0;do{if((z|0)==0){D=gHb(j,G,10,0)|0;A=c[y+(u*36|0)+4>>2]<<7;C=YGb(A,(A|0)<0|0?-1:0,D,F)|0;D=F;if((D|0)<(x|0)|(D|0)==(x|0)&C>>>0<w>>>0){H=E;I=d;J=D;K=C;break}c[B>>2]=2;H=E;I=d+1|0;J=x;K=w}else if((z|0)==2){H=E;I=d;J=x;K=w}else{C=gHb(j,G,34,0)|0;D=c[y+(u*36|0)+24>>2]<<7;A=YGb(D,(D|0)<0|0?-1:0,C,F)|0;C=F;if((C|0)<(x|0)|(C|0)==(x|0)&A>>>0<w>>>0){H=E;I=d;J=C;K=A;break}c[B>>2]=2;H=E+1|0;I=d;J=x;K=w}}while(0);w=YGb(K,J,s,t)|0;x=F;B=u+1|0;if((B|0)>=(b|0)){L=x;M=w;N=I;O=H;break a}u=B;t=x;s=w;d=I;E=H;G=c[l+4>>2]|0;j=c[l>>2]|0}}else{L=e;M=p;N=0;O=0}}while(0);c[h>>2]=N;c[i>>2]=O;q=L;r=M;return(F=q,r)|0}}else if((f|0)==0){M=b;L=gHb(M<<3|0>>>29,((b|0)<0|0?-1:0)<<3|M>>>29,m,n)|0;M=YGb(L,F,p,e)|0;L=F;if((k|0)<=15){q=L;r=M;return(F=q,r)|0}O=a+352|0;N=0;H=L;L=M;while(1){M=c[O>>2]|0;I=c[M+(N*36|0)+4>>2]<<7;J=YGb(I,(I|0)<0|0?-1:0,L,H)|0;I=F;c[M+(N*36|0)+32>>2]=0;M=N+1|0;if((M|0)<(b|0)){N=M;H=I;L=J}else{q=I;r=J;break}}return(F=q,r)|0}else if((f|0)==1){if((g|0)==0){if((k|0)<=15){q=e;r=p;return(F=q,r)|0}g=a+352|0;f=0;L=e;H=p;N=n;O=m;while(1){J=c[g>>2]|0;I=gHb(O,N,9,0)|0;M=c[J+(f*36|0)+4>>2]<<7;K=YGb(M,(M|0)<0|0?-1:0,I,F)|0;I=F;M=gHb(O,N,33,0)|0;o=c[J+(f*36|0)+24>>2]<<7;j=YGb(o,(o|0)<0|0?-1:0,M,F)|0;M=F;o=(I|0)>(M|0)|(I|0)==(M|0)&K>>>0>j>>>0;c[J+(f*36|0)+32>>2]=o&1;J=YGb(o?j:K,o?M:I,H,L)|0;I=F;M=f+1|0;if((M|0)>=(b|0)){q=I;r=J;break}f=M;L=I;H=J;N=c[l+4>>2]|0;O=c[l>>2]|0}return(F=q,r)|0}c[i>>2]=0;c[h>>2]=0;if((k|0)<=15){q=e;r=p;return(F=q,r)|0}k=c[a+352>>2]|0;a=gHb(m,n,9,0)|0;h=F;i=gHb(m,n,33,0)|0;n=F;m=0;l=e;O=p;while(1){if((c[k+(m*36|0)+32>>2]|0)==0){N=c[k+(m*36|0)+4>>2]<<7;H=YGb(N,(N|0)<0|0?-1:0,a,h)|0;P=F;Q=H}else{H=c[k+(m*36|0)+24>>2]<<7;N=YGb(H,(H|0)<0|0?-1:0,i,n)|0;P=F;Q=N}N=YGb(Q,P,O,l)|0;H=F;L=m+1|0;if((L|0)<(b|0)){m=L;l=H;O=N}else{q=H;r=N;break}}return(F=q,r)|0}else{q=e;r=p;return(F=q,r)|0}return 0}function P$(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=b+48|0;b=ba((c[g>>2]|0)==2?6:4,e)|0;e=c[f+(b<<2)>>2]&255;h=d+32|0;i=d|0;a[(c[i>>2]|0)+((c[h>>2]|0)+1)|0]=e;a[(c[i>>2]|0)+(c[h>>2]|0)|0]=e;a[(c[i>>2]|0)+1|0]=e;a[c[i>>2]|0]=e;e=c[f+((b|1)<<2)>>2]&255;a[(c[i>>2]|0)+((c[h>>2]|0)+3)|0]=e;a[(c[i>>2]|0)+((c[h>>2]|0)+2)|0]=e;a[(c[i>>2]|0)+3|0]=e;a[(c[i>>2]|0)+2|0]=e;e=c[f+(b+2<<2)>>2]&255;a[(c[i>>2]|0)+(((c[h>>2]|0)*3|0)+1)|0]=e;a[(c[i>>2]|0)+((c[h>>2]|0)*3|0)|0]=e;a[(c[i>>2]|0)+(c[h>>2]<<1|1)|0]=e;a[(c[i>>2]|0)+(c[h>>2]<<1)|0]=e;e=c[f+(b+3<<2)>>2]&255;a[(c[i>>2]|0)+(((c[h>>2]|0)*3|0)+3)|0]=e;a[(c[i>>2]|0)+(((c[h>>2]|0)*3|0)+2)|0]=e;a[(c[i>>2]|0)+((c[h>>2]<<1)+3)|0]=e;a[(c[i>>2]|0)+((c[h>>2]<<1)+2)|0]=e;if((c[g>>2]|0)!=2){return}g=c[f+(b+4<<2)>>2]&255;e=d+36|0;h=d+4|0;a[(c[h>>2]|0)+((c[e>>2]|0)+1)|0]=g;a[(c[h>>2]|0)+(c[e>>2]|0)|0]=g;a[(c[h>>2]|0)+1|0]=g;a[c[h>>2]|0]=g;g=c[f+(b+5<<2)>>2]&255;b=d+40|0;f=d+8|0;a[(c[f>>2]|0)+((c[b>>2]|0)+1)|0]=g;a[(c[f>>2]|0)+(c[b>>2]|0)|0]=g;a[(c[f>>2]|0)+1|0]=g;a[c[f>>2]|0]=g;return}function Q$(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=b+48|0;b=(c[g>>2]|0)==2?6:4;h=d+32|0;i=d|0;j=d+36|0;k=d+4|0;l=d+40|0;m=d+8|0;d=0;do{n=d|1;o=d>>1;p=0;q=d;while(1){r=e+(q<<2)|0;s=c[f+6144+((ba(c[r>>2]|0,b)|0)<<2)>>2]&255;t=(ba(c[h>>2]|0,d)|0)+p|0;a[(c[i>>2]|0)+t|0]=s;s=c[f+6144+((ba(c[r>>2]|0,b)|0|1)<<2)>>2]&255;t=p|1;u=(ba(c[h>>2]|0,d)|0)+t|0;a[(c[i>>2]|0)+u|0]=s;s=c[f+6144+((ba(c[r>>2]|0,b)|0)+2<<2)>>2]&255;u=(ba(c[h>>2]|0,n)|0)+p|0;a[(c[i>>2]|0)+u|0]=s;s=c[f+6144+((ba(c[r>>2]|0,b)|0)+3<<2)>>2]&255;u=(ba(c[h>>2]|0,n)|0)+t|0;a[(c[i>>2]|0)+u|0]=s;if((c[g>>2]|0)==2){s=c[f+6144+((ba(c[r>>2]|0,b)|0)+4<<2)>>2]&255;u=p>>1;t=(ba(c[j>>2]|0,o)|0)+u|0;a[(c[k>>2]|0)+t|0]=s;s=c[f+6144+((ba(c[r>>2]|0,b)|0)+5<<2)>>2]&255;r=(ba(c[l>>2]|0,o)|0)+u|0;a[(c[m>>2]|0)+r|0]=s}s=p+2|0;if((s|0)<4){p=s;q=q+1|0}else{break}}d=d+2|0;}while((d|0)<4);return}function R$(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[b+32>>2]|0;g=c[b>>2]|0;h=c[e+32>>2]|0;i=c[e>>2]|0;j=0;k=0;do{l=ba(f,j)|0;m=ba(h,j)|0;n=(d[g+l|0]|0)-(d[i+m|0]|0)|0;o=(ba(n,n)|0)+k|0;n=(d[g+(l+1)|0]|0)-(d[i+(m+1)|0]|0)|0;p=(ba(n,n)|0)+o|0;o=(d[g+(l+2)|0]|0)-(d[i+(m+2)|0]|0)|0;n=(ba(o,o)|0)+p|0;p=(d[g+(l+3)|0]|0)-(d[i+(m+3)|0]|0)|0;k=(ba(p,p)|0)+n|0;j=j+1|0;}while((j|0)<4);if((c[a+48>>2]|0)!=2){q=k;return q|0}a=c[b+36>>2]|0;j=c[b+4>>2]|0;i=c[e+36>>2]|0;g=c[e+4>>2]|0;h=(d[j]|0)-(d[g]|0)|0;f=(ba(h,h)|0)+k|0;k=(d[j+1|0]|0)-(d[g+1|0]|0)|0;h=(ba(k,k)|0)+f|0;f=(d[j+a|0]|0)-(d[g+i|0]|0)|0;k=(ba(f,f)|0)+h|0;h=(d[j+(a+1)|0]|0)-(d[g+(i+1)|0]|0)|0;i=(ba(h,h)|0)+k|0;k=c[b+40>>2]|0;h=c[b+8>>2]|0;b=c[e+40>>2]|0;g=c[e+8>>2]|0;e=(d[h]|0)-(d[g]|0)|0;a=(ba(e,e)|0)+i|0;i=(d[h+1|0]|0)-(d[g+1|0]|0)|0;e=(ba(i,i)|0)+a|0;a=(d[h+k|0]|0)-(d[g+b|0]|0)|0;i=(ba(a,a)|0)+e|0;e=(d[h+(k+1)|0]|0)-(d[g+(b+1)|0]|0)|0;q=(ba(e,e)|0)+i|0;return q|0}function S$(a){a=a|0;c[a+140>>2]=7;return 0}function T$(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=e;l=b+124|0;m=c[l>>2]|0;do{if((m|0)>=1){n=b+120|0;o=c[n>>2]|0;if((o|0)<1){break}if(((k|0)/(m|0)|0|0)<(o|0)){yDb(b,16,1971056,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}o=_$a(b,g,0)|0;if((o|0)<0){q=o;i=h;return q|0}c[e+88>>2]=1;c[e+84>>2]=1;o=k<<3;r=o>>>0>2147483639>>>0|(j|0)==0;s=r?0:j;t=r?8:o+8|0;o=c[l>>2]|0;if((o|0)>0){r=e+32|0;u=e;v=e+36|0;w=e+4|0;x=e+40|0;y=e+8|0;z=0;A=0;B=c[n>>2]|0;C=o;while(1){if((B|0)>0){o=ba(c[x>>2]|0,A)|0;D=ba(c[v>>2]|0,A)|0;E=z;F=0;G=(c[u>>2]|0)+(ba(c[r>>2]|0,A)|0)|0;H=(c[w>>2]|0)+D|0;D=(c[y>>2]|0)+o|0;while(1){o=s+(E>>>3)|0;I=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(E&7)>>>27;o=E+5|0;J=t>>>0>o>>>0?o:t;a[G+3|0]=(I*33|0)>>>2;I=s+(J>>>3)|0;o=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>27;I=J+5|0;J=t>>>0>I>>>0?I:t;a[G+2|0]=(o*33|0)>>>2;o=s+(J>>>3)|0;I=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(J&7)>>>27;o=J+5|0;J=t>>>0>o>>>0?o:t;a[G+1|0]=(I*33|0)>>>2;I=s+(J>>>3)|0;o=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>27;I=J+5|0;J=t>>>0>I>>>0?I:t;a[G]=(o*33|0)>>>2;o=s+(J>>>3)|0;I=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(J&7)>>>26;o=J+6|0;J=t>>>0>o>>>0?o:t;a[H]=I<<2;I=s+(J>>>3)|0;o=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>26;I=J+6|0;K=t>>>0>I>>>0?I:t;a[D]=o<<2;o=F+4|0;L=c[n>>2]|0;if((o|0)<(L|0)){E=K;F=o;G=G+4|0;H=H+1|0;D=D+1|0}else{break}}M=K;N=L;O=c[l>>2]|0}else{M=z;N=B;O=C}D=A+1|0;if((D|0)<(O|0)){z=M;A=D;B=N;C=O}else{break}}}c[f>>2]=1;q=k;i=h;return q|0}}while(0);yDb(b,16,2009808,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}function U$(a){a=a|0;var b=0;b=ICb()|0;c[a+804>>2]=b;return((b|0)==0?-12:0)|0}function V$(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;h=c[b+60>>2]|0;i=c[b+428>>2]|0;j=b+124|0;k=b+120|0;l=(ba(c[j>>2]<<5,c[k>>2]|0)|0)/4|0;m=r0a(b,e,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){n=m;return n|0}m=c[b+804>>2]|0;c[m+88>>2]=1;c[m+84>>2]=1;m=e+28|0;b=(c[m>>2]|0)<0?0:c[e+24>>2]|0;l=c[j>>2]|0;if((l|0)>0){o=f+32|0;p=f|0;q=f+36|0;r=f+4|0;s=f+40|0;t=f+8|0;f=h+4|0;h=b;u=0;v=i;i=0;w=c[k>>2]|0;y=l;while(1){if((w|0)>0){l=ba(c[s>>2]|0,u)|0;z=ba(c[q>>2]|0,u)|0;A=u&1;B=h;C=0;D=v;E=(c[p>>2]|0)+(ba(c[o>>2]|0,u)|0)|0;F=(c[r>>2]|0)+z|0;z=(c[t>>2]|0)+l|0;l=i;while(1){G=c[f>>2]|0;if((G|0)==0){H=1227489280}else if((G|0)==1){H=(ba(D,1664525)|0)+1013904223|0}else if((G|0)==2){H=c[1343016+(A<<3)+((C>>>2&1)<<2)>>2]|0}else{H=D}I=(((d[z]|0)+(H>>>16&3)|0)*253|0)>>>10;G=B;x=fe(I|((((d[F]|0)+(H>>>18&3)|0)*253|0)>>>10|((((d[E]|0)+(H>>>20&7)|0)*249|0)>>>11|((((d[E+1|0]|0)+(H>>>23&7)|0)*249|0)>>>11|((((d[E+2|0]|0)+(H>>>26&7)|0)*249|0)>>>11|((((d[E+3|0]|0)+(H>>>29)|0)*249|0)>>>11|l<<5)<<5)<<5)<<5)<<6)<<6|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;J=B+4|0;G=C+4|0;K=c[k>>2]|0;if((G|0)<(K|0)){B=J;C=G;D=H;E=E+4|0;F=F+1|0;z=z+1|0;l=I}else{break}}L=J;M=H;N=I;O=K;P=c[j>>2]|0}else{L=h;M=v;N=i;O=w;P=y}l=u+1|0;if((l|0)<(P|0)){h=L;u=l;v=M;i=N;w=O;y=P}else{Q=L;break}}}else{Q=b}c[m>>2]=(Q-b<<3|0)/8|0;b=e+36|0;c[b>>2]=c[b>>2]|1;c[g>>2]=1;n=0;return n|0}function W$(a){a=a|0;JCb(a+804|0);return 0}function X$(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+1244>>2]=a;c[b+1248>>2]=0;c[b+1252>>2]=0;Z3(b,a);return 0}function Y$(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0;j=i;i=i+224|0;k=j|0;l=j+16|0;m=j+80|0;n=j+120|0;o=j+200|0;p=c[e+60>>2]|0;q=p;r=f;s=c[h+24>>2]|0;t=s;a:do{if((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)==1330007625){u=s+4|0;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;do{if(!(v>>>0>4294967287>>>0)){u=v+8|0;w=h+28|0;if(u>>>0>(c[w>>2]|0)>>>0){break}yDb(e,48,2114720,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=s+u|0;z=u;A=w;break a}}while(0);yDb(e,16,2192760,(x=i,i=i+8|0,c[x>>2]=v,x)|0);i=x;B=-1094995529;i=j;return B|0}else{y=s;z=0;A=h+28|0}}while(0);h=(c[A>>2]|0)-z&-2;z=p+1248|0;s=z;O$a(z,p+1252|0,h);z=c[s>>2]|0;if((z|0)==0){yDb(e,16,2055720,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;B=-12;i=j;return B|0}Xe[c[p+1100>>2]&4095](z,y,(h|0)/2|0);z=c[s>>2]|0;s=h<<3;h=s>>>0>2147483639>>>0|(z|0)==0;t=h?0:z;z=h?0:s;s=o|0;c[s>>2]=t;c[o+12>>2]=z;h=z|8;w=o+16|0;c[w>>2]=h;c[o+4>>2]=t+(z>>3);z=o+8|0;c[z>>2]=0;u=y;y=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>8&255;u=e;yDb(u,48,2009784,(x=i,i=i+8|0,c[x>>2]=y,x)|0);i=x;if((y|0)==3){c[e+140>>2]=27;c[e+796>>2]=8;C=_$a(e,r,0)|0;if((C|0)<0){B=C;i=j;return B|0}C=p+1244|0;D=c[C>>2]|0;E=c[f>>2]|0;c[z>>2]=h>>>0>16>>>0?16:h;F=0;while(1){if((F|0)>=4){break}G=_$(q,o,n+(F*20|0)|0)|0;if((G|0)<0){H=62;break}else{F=F+1|0}}if((H|0)==62){if((F|0)>=0){I=0;do{Q_(n+(I*20|0)|0);I=I+1|0;}while((I|0)<=(F|0))}yDb(c[C>>2]|0,16,1942408,(x=i,i=i+8|0,c[x>>2]=F,x)|0);i=x;B=G;i=j;return B|0}G=D+124|0;b:do{if((c[G>>2]|0)>0){D=n+4|0;F=n+24|0;I=n+44|0;J=n+64|0;K=f+32|0;L=128;M=128;N=128;O=0;P=E;Q=1;R=c[z>>2]|0;S=c[C>>2]|0;while(1){T=c[w>>2]|0;c:do{if((c[S+120>>2]|0)>0){U=1;V=R;W=O;X=N;Y=M;Z=L;_=P;while(1){$=c[s>>2]|0;aa=$+(V>>>3)|0;ba=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(V&7)>>>25;aa=c[D>>2]|0;ca=b[aa+(ba<<2)>>1]|0;da=b[aa+(ba<<2)+2>>1]|0;ba=da<<16>>16;if(da<<16>>16<0){da=V+7|0;ea=T>>>0>da>>>0?da:T;da=$+(ea>>>3)|0;$=((fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ea&7)>>>((ba+32|0)>>>0))+ca|0;fa=b[aa+($<<2)+2>>1]|0;ga=ea;ha=b[aa+($<<2)>>1]|0}else{fa=ba;ga=V;ha=ca}ca=fa+ga|0;ba=T>>>0>ca>>>0?ca:T;ca=ha+W|0;$=ca&255;a[_]=$;if($<<24>>24==0){a[_+1|0]=0;a[_+2|0]=0;a[_+3|0]=0;ia=Z;ja=Y;ka=X;la=ba}else{$=c[s>>2]|0;aa=$+(ba>>>3)|0;ea=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ba&7)>>>25;aa=c[F>>2]|0;da=b[aa+(ea<<2)>>1]|0;ma=b[aa+(ea<<2)+2>>1]|0;ea=ma<<16>>16;if(ma<<16>>16<0){ma=ba+7|0;na=T>>>0>ma>>>0?ma:T;ma=$+(na>>>3)|0;$=((fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(na&7)>>>((ea+32|0)>>>0))+da|0;oa=b[aa+($<<2)+2>>1]|0;pa=na;qa=b[aa+($<<2)>>1]|0}else{oa=ea;pa=ba;qa=da}da=oa+pa|0;ba=T>>>0>da>>>0?da:T;da=qa+X|0;a[_+1|0]=da;ea=c[s>>2]|0;$=ea+(ba>>>3)|0;aa=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ba&7)>>>25;$=c[I>>2]|0;na=b[$+(aa<<2)>>1]|0;ma=b[$+(aa<<2)+2>>1]|0;aa=ma<<16>>16;if(ma<<16>>16<0){ma=ba+7|0;ra=T>>>0>ma>>>0?ma:T;ma=ea+(ra>>>3)|0;ea=((fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(ra&7)>>>((aa+32|0)>>>0))+na|0;sa=b[$+(ea<<2)+2>>1]|0;ta=ra;ua=b[$+(ea<<2)>>1]|0}else{sa=aa;ta=ba;ua=na}na=sa+ta|0;ba=T>>>0>na>>>0?na:T;na=ua+Y|0;a[_+2|0]=na;aa=c[s>>2]|0;ea=aa+(ba>>>3)|0;$=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ba&7)>>>25;ea=c[J>>2]|0;ra=b[ea+($<<2)>>1]|0;ma=b[ea+($<<2)+2>>1]|0;$=ma<<16>>16;if(ma<<16>>16<0){ma=ba+7|0;va=T>>>0>ma>>>0?ma:T;ma=aa+(va>>>3)|0;aa=((fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(va&7)>>>(($+32|0)>>>0))+ra|0;wa=b[ea+(aa<<2)+2>>1]|0;xa=va;ya=b[ea+(aa<<2)>>1]|0}else{wa=$;xa=ba;ya=ra}ra=wa+xa|0;ba=ya+Z|0;a[_+3|0]=ba;ia=ba;ja=na;ka=da;la=T>>>0>ra>>>0?ra:T}ra=c[C>>2]|0;if((U|0)>=(c[ra+120>>2]|0)){za=la;Aa=ra;break c}U=U+1|0;V=la;W=ca;X=ka;Y=ja;Z=ia;_=_+4|0}}else{za=R;Aa=S}}while(0);c[z>>2]=za;T=a[P]|0;if(T<<24>>24==0){Ba=N;Ca=M;Da=L}else{Ba=d[P+1|0]|0;Ca=d[P+2|0]|0;Da=d[P+3|0]|0}if((Q|0)>=(c[G>>2]|0)){break b}L=Da;M=Ca;N=Ba;O=T&255;P=P+(c[K>>2]|0)|0;Q=Q+1|0;R=za;S=Aa}}}while(0);Q_(n|0);Q_(n+20|0);Q_(n+40|0);Q_(n+60|0)}else if((y|0)==0){c[e+140>>2]=4;c[e+796>>2]=8;n=_$a(e,r,0)|0;if((n|0)<0){B=n;i=j;return B|0}n=p+1244|0;Aa=c[n>>2]|0;za=c[f>>2]|0;Ba=c[f+4>>2]|0;Ca=c[f+8>>2]|0;Da=t+1|0;t=d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0;c[z>>2]=h>>>0>16>>>0?16:h;if((t&255|0)==0){Ea=0}else{DDb(Aa,1897256,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;B=-1163346256;i=j;return B|0}while(1){if((Ea|0)>=2){break}Fa=_$(q,o,m+(Ea*20|0)|0)|0;if((Fa|0)<0){H=17;break}else{Ea=Ea+1|0}}if((H|0)==17){if((Ea|0)>=0){t=0;do{Q_(m+(t*20|0)|0);t=t+1|0;}while((t|0)<=(Ea|0))}yDb(c[n>>2]|0,16,1942408,(x=i,i=i+8|0,c[x>>2]=Ea,x)|0);i=x;B=Fa;i=j;return B|0}Fa=Aa+124|0;d:do{if((c[Fa>>2]|0)>0){Aa=m+4|0;Ea=m+24|0;t=f+32|0;Da=f+40|0;G=f+36|0;ia=128;ja=128;ka=128;la=1;C=za;ya=c[z>>2]|0;xa=c[n>>2]|0;wa=Ba;ua=Ca;while(1){ta=c[w>>2]|0;if((c[xa+120>>2]|0)>0){sa=0;qa=ya;pa=ka;do{oa=c[s>>2]|0;ha=oa+(qa>>>3)|0;ga=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(qa&7)>>>25;ha=c[Aa>>2]|0;fa=b[ha+(ga<<2)>>1]|0;E=b[ha+(ga<<2)+2>>1]|0;ga=E<<16>>16;if(E<<16>>16<0){E=qa+7|0;S=ta>>>0>E>>>0?E:ta;E=oa+(S>>>3)|0;oa=((fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(S&7)>>>((ga+32|0)>>>0))+fa|0;Ga=b[ha+(oa<<2)+2>>1]|0;Ha=b[ha+(oa<<2)>>1]|0;Ia=S}else{Ga=ga;Ha=fa;Ia=qa}fa=Ga+Ia|0;qa=ta>>>0>fa>>>0?fa:ta;pa=Ha+pa|0;a[C+sa|0]=pa;sa=sa+1|0;Ja=c[n>>2]|0;}while((sa|0)<(c[Ja+120>>2]|0));Ka=qa;La=c[w>>2]|0;Ma=Ja}else{Ka=ya;La=ta;Ma=xa}c[z>>2]=Ka;sa=d[C]|0;if((c[Ma+120>>2]>>1|0)>0){pa=0;fa=Ka;ga=ja;do{S=c[s>>2]|0;oa=S+(fa>>>3)|0;ha=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(fa&7)>>>25;oa=c[Ea>>2]|0;E=b[oa+(ha<<2)>>1]|0;R=b[oa+(ha<<2)+2>>1]|0;ha=R<<16>>16;if(R<<16>>16<0){R=fa+7|0;Q=La>>>0>R>>>0?R:La;R=S+(Q>>>3)|0;S=((fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Q&7)>>>((ha+32|0)>>>0))+E|0;Na=b[oa+(S<<2)+2>>1]|0;Oa=b[oa+(S<<2)>>1]|0;Pa=Q}else{Na=ha;Oa=E;Pa=fa}E=Na+Pa|0;fa=La>>>0>E>>>0?E:La;ga=Oa+ga|0;a[wa+pa|0]=ga;pa=pa+1|0;Qa=c[n>>2]|0;}while((pa|0)<(c[Qa+120>>2]>>1|0));Ra=fa;Sa=c[w>>2]|0;Ta=Qa}else{Ra=Ka;Sa=La;Ta=Ma}c[z>>2]=Ra;pa=d[wa]|0;if((c[Ta+120>>2]>>1|0)>0){ga=0;ta=Ra;qa=ia;while(1){E=c[s>>2]|0;ha=E+(ta>>>3)|0;Q=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ta&7)>>>25;ha=c[Ea>>2]|0;S=b[ha+(Q<<2)>>1]|0;oa=b[ha+(Q<<2)+2>>1]|0;Q=oa<<16>>16;if(oa<<16>>16<0){oa=ta+7|0;R=Sa>>>0>oa>>>0?oa:Sa;oa=E+(R>>>3)|0;E=((fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(R&7)>>>((Q+32|0)>>>0))+S|0;Ua=b[ha+(E<<2)+2>>1]|0;Va=b[ha+(E<<2)>>1]|0;Wa=R}else{Ua=Q;Va=S;Wa=ta}S=Ua+Wa|0;Q=Sa>>>0>S>>>0?S:Sa;S=Va+qa|0;a[ua+ga|0]=S;R=ga+1|0;E=c[n>>2]|0;if((R|0)<(c[E+120>>2]>>1|0)){ga=R;ta=Q;qa=S}else{Xa=Q;Ya=E;break}}}else{Xa=Ra;Ya=Ta}c[z>>2]=Xa;if((la|0)>=(c[Fa>>2]|0)){break d}ia=d[ua]|0;ja=pa;ka=sa;la=la+1|0;C=C+(c[t>>2]|0)|0;ya=Xa;xa=Ya;wa=wa+(c[G>>2]|0)|0;ua=ua+(c[Da>>2]|0)|0}}}while(0);Q_(m|0);Q_(m+20|0)}else if((y|0)==1|(y|0)==2){c[e+140>>2]=2;c[e+796>>2]=8;m=_$a(e,r,0)|0;if((m|0)<0){B=m;i=j;return B|0}m=p+1244|0;p=c[m>>2]|0;c[k>>2]=128;c[k+4>>2]=128;c[k+8>>2]=128;r=c[f>>2]|0;c[z>>2]=h>>>0>16>>>0?16:h;h=0;while(1){if((h|0)>=3){break}Za=_$(q,o,l+(h*20|0)|0)|0;if((Za|0)<0){H=43;break}else{h=h+1|0}}if((H|0)==43){if((h|0)>=0){H=0;do{Q_(l+(H*20|0)|0);H=H+1|0;}while((H|0)<=(h|0))}yDb(c[m>>2]|0,16,1942408,(x=i,i=i+8|0,c[x>>2]=h,x)|0);i=x;B=Za;i=j;return B|0}Za=p+124|0;if((c[Za>>2]|0)>0){p=f+32|0;h=r;r=0;H=c[z>>2]|0;o=c[m>>2]|0;while(1){q=0;e=H;Ya=o;while(1){Xa=k+(q<<2)|0;Fa=h+q|0;Ta=c[w>>2]|0;e:do{if((c[Ya+120>>2]|0)>0){Ra=l+(q*20|0)+4|0;n=1;Va=e;Sa=c[Xa>>2]|0;Wa=Fa;while(1){Ua=c[s>>2]|0;Ma=Ua+(Va>>>3)|0;La=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Va&7)>>>25;Ma=c[Ra>>2]|0;Ka=b[Ma+(La<<2)>>1]|0;Qa=b[Ma+(La<<2)+2>>1]|0;La=Qa<<16>>16;if(Qa<<16>>16<0){Qa=Va+7|0;Oa=Ta>>>0>Qa>>>0?Qa:Ta;Qa=Ua+(Oa>>>3)|0;Ua=((fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Oa&7)>>>((La+32|0)>>>0))+Ka|0;_a=b[Ma+(Ua<<2)+2>>1]|0;$a=Oa;ab=b[Ma+(Ua<<2)>>1]|0}else{_a=La;$a=Va;ab=Ka}Ka=_a+$a|0;La=Ta>>>0>Ka>>>0?Ka:Ta;Ka=ab+Sa|0;a[Wa]=Ka;Ua=c[m>>2]|0;if((n|0)>=(c[Ua+120>>2]|0)){bb=La;cb=Ua;break e}n=n+1|0;Va=La;Sa=Ka;Wa=Wa+3|0}}else{bb=e;cb=Ya}}while(0);c[z>>2]=bb;c[Xa>>2]=d[Fa]|0;Ta=q+1|0;if((Ta|0)<3){q=Ta;e=bb;Ya=cb}else{break}}Ya=r+1|0;if((Ya|0)<(c[Za>>2]|0)){h=h+(c[p>>2]|0)|0;r=Ya;H=bb;o=cb}else{break}}}Q_(l|0);Q_(l+20|0);Q_(l+40|0)}else{yDb(u,16,1971024,(x=i,i=i+8|0,c[x>>2]=y,x)|0);i=x;B=-1094995529;i=j;return B|0}c[f+84>>2]=1;c[f+88>>2]=1;c[g>>2]=1;B=c[A>>2]|0;i=j;return B|0}function Z$(a){a=a|0;$Db((c[a+60>>2]|0)+1248|0);return 0}function _$(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+1024|0;j=h|0;k=h+256|0;l=h+512|0;m=f+8|0;n=c[m>>2]|0;o=c[f+16>>2]|0;p=c[f>>2]|0;f=p+(n>>>3)|0;q=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(n&7)>>>27;f=n+5|0;n=o>>>0>f>>>0?f:o;c[m>>2]=n;a:do{if((q|0)==0){r=0}else{f=0;s=0;t=0;u=0;v=n;while(1){w=p+(v>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)>>>23;w=v+9|0;y=o>>>0>w>>>0?w:o;c[m>>2]=y;z=x+f|0;if((z|0)>256){break}w=t+1|0;if((x|0)==0){A=s;B=u;C=y}else{D=w&255;E=x>>>0>1>>>0?x:1;F=u+E|0;G=s;H=0;I=u;J=y;while(1){y=p+(J>>>3)|0;K=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(J&7)>>>24;y=J+8|0;L=o>>>0>y>>>0?y:o;c[m>>2]=L;a[j+I|0]=K;a[k+I|0]=D;b[l+(I<<1)>>1]=G;K=H+1|0;if((K|0)<(x|0)){G=G+1|0;H=K;I=I+1|0;J=L}else{break}}A=s+E|0;B=F;C=L}if((w|0)<(q|0)){f=z;s=A<<1;t=w;u=B;v=C}else{r=B;break a}}c[g+4>>2]=0;yDb(c[e+1244>>2]|0,16,1918008,(v=i,i=i+8|0,c[v>>2]=z,v)|0);i=v;M=-1094995529;i=h;return M|0}}while(0);M=N_(g,7,r,k|0,1,1,l,2,2,j|0,1,1,0)|0;i=h;return M|0}function $$(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+60|0;d=c[b>>2]|0;c[a+420>>2]=1;c[a+416>>2]=1;c[a+412>>2]=8e3;e=d+12|0;c[e>>2]=12;f=a+424|0;c[f>>2]=640;a=d;c[a>>2]=cEb(c[e>>2]<<2)|0;g=d+4|0;c[g>>2]=cEb(c[e>>2]<<2)|0;h=d+8|0;c[h>>2]=cEb(c[e>>2]<<2)|0;i=d+28|0;c[i>>2]=cEb((c[e>>2]|0)+(c[f>>2]|0)<<2)|0;e=cEb(c[f>>2]<<2)|0;c[d+32>>2]=e;do{if((c[a>>2]|0)!=0){if((c[g>>2]|0)==0){break}if((c[h>>2]|0)==0){break}if((c[i>>2]|0)==0|(e|0)==0){break}oDb(d+36|0,0);j=0;return j|0}}while(0);d=c[b>>2]|0;ZDb(c[d>>2]|0);ZDb(c[d+4>>2]|0);ZDb(c[d+8>>2]|0);ZDb(c[d+28>>2]|0);ZDb(c[d+32>>2]|0);j=-12;return j|0}function a0(a,e,f,h){a=a|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;j=i;i=i+400|0;k=j|0;l=e;m=c[a+60>>2]|0;n=h+28|0;o=c[n>>2]|0;do{if((o|0)!=0){p=h+24|0;c[m+20>>2]=~~(+S(+10.0,+(+(-(d[c[p>>2]|0]|0)|0)/10.0))*1081109975.0*.75);q=m+4|0;r=m+12|0;TGb(c[q>>2]|0,0,c[r>>2]<<2|0)|0;s=(c[n>>2]|0)-1|0;t=c[r>>2]|0;r=(s|0)>(t|0)?t:s;if((r|0)<=0){break}s=c[p>>2]|0;p=c[q>>2]|0;q=0;while(1){t=q+1|0;g[p+(q<<2)>>2]=+((d[s+t|0]|0)-127|0)*.0078125;if((t|0)<(r|0)){q=t}else{break}}}}while(0);n=m+24|0;do{if((c[n>>2]|0)==0){c[m+16>>2]=c[m+20>>2];h=m;q=m+12|0;UGb(c[h>>2]|0,c[m+4>>2]|0,c[q>>2]<<2)|0;c[n>>2]=1;u=c[q>>2]|0;v=h}else{h=m+16|0;c[h>>2]=((c[m+20>>2]|0)/2|0)+((c[h>>2]|0)/2|0);h=c[m+12>>2]|0;q=m;if((h|0)<=0){u=h;v=q;break}r=c[q>>2]|0;s=c[m+4>>2]|0;p=0;while(1){t=r+(p<<2)|0;g[t>>2]=+g[t>>2]*.6+ +g[s+(p<<2)>>2]*.4;t=p+1|0;if((t|0)<(h|0)){p=t}else{u=h;v=q;break}}}}while(0);n=m+8|0;q=c[n>>2]|0;h=c[v>>2]|0;p=m+12|0;do{if((u|0)>0){s=q;r=0;t=k|0;while(1){w=h+(r<<2)|0;g[t+(r<<2)>>2]=+g[w>>2];if((r|0)>0){x=r-1|0;y=0;do{g[t+(y<<2)>>2]=+g[s+(y<<2)>>2]+ +g[w>>2]*+g[s+(x-y<<2)>>2];y=y+1|0;}while((y|0)<(r|0))}y=r+1|0;if((y|0)<(u|0)){x=s;s=t;r=y;t=x}else{break}}if((t|0)==(q|0)){z=u;break}UGb(q|0,t|0,u<<2)|0;z=c[p>>2]|0}else{z=u}}while(0);if((z|0)>0){u=c[v>>2]|0;A=1.0;v=0;while(1){B=+g[u+(v<<2)>>2];C=A*(1.0-B*B);q=v+1|0;if((q|0)<(z|0)){A=C;v=q}else{D=C;break}}}else{D=1.0}A=+R(D*+(c[m+16>>2]|0)/1081110016.0);v=a+424|0;u=c[v>>2]|0;if((u|0)>0){q=m+36|0;h=m+292|0;k=m+32|0;r=0;s=c[h>>2]|0;do{c[q+((s&63)<<2)>>2]=(c[q+((s+9&63)<<2)>>2]|0)+(c[q+((s+40&63)<<2)>>2]|0);x=c[h>>2]|0;s=x+1|0;c[h>>2]=s;E=c[k>>2]|0;g[E+(r<<2)>>2]=A*+((c[q+((x&63)<<2)>>2]&65535)-32768|0);r=r+1|0;F=c[v>>2]|0;}while((r|0)<(F|0));G=F;H=c[p>>2]|0;I=E}else{G=u;H=z;I=c[m+32>>2]|0}z=m+28|0;y$((c[z>>2]|0)+(H<<2)|0,c[n>>2]|0,I,G,H);c[e+76>>2]=c[v>>2];H=_$a(a,l,0)|0;if((H|0)<0){J=H;i=j;return J|0}H=c[e>>2]|0;e=c[v>>2]|0;if((e|0)>0){v=c[p>>2]|0;l=c[z>>2]|0;a=0;while(1){b[H+(a<<1)>>1]=~~+g[l+(v+a<<2)>>2];G=a+1|0;if((G|0)<(e|0)){a=G}else{K=l;L=v;break}}}else{K=c[z>>2]|0;L=c[p>>2]|0}UGb(K|0,K+(e<<2)|0,L<<2)|0;c[f>>2]=1;J=o;i=j;return J|0}function b0(a){a=a|0;var b=0;b=c[a+60>>2]|0;ZDb(c[b>>2]|0);ZDb(c[b+4>>2]|0);ZDb(c[b+8>>2]|0);ZDb(c[b+28>>2]|0);ZDb(c[b+32>>2]|0);return 0}function c0(a){a=a|0;c[(c[a+60>>2]|0)+24>>2]=0;return}function d0(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+60|0;e=c[d>>2]|0;if((c[a+416>>2]|0)!=1){yDb(a,16,2114680,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}f=a+424|0;c[f>>2]=640;a=e+28|0;c[a>>2]=10;h=FKa(e,c[f>>2]|0,10,2)|0;if((h|0)<0){g=h;i=b;return g|0}h=e+32|0;c[h>>2]=WDb(c[f>>2]<<2)|0;f=WDb(c[a>>2]<<3)|0;c[e+36>>2]=f;if(!((c[h>>2]|0)==0|(f|0)==0)){g=0;i=b;return g|0}f=c[d>>2]|0;EKa(f);ZDb(c[f+32>>2]|0);ZDb(c[f+36>>2]|0);g=-12;i=b;return g|0}function e0(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0,u=0.0,v=0,w=0;j=i;k=c[d+60>>2]|0;l=c[f>>2]|0;m=k+28|0;n=s0a(e,(c[m>>2]|0)+1|0)|0;if((n|0)!=0){yDb(d,16,2192688,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;o=n;i=j;return o|0}n=f+76|0;f=c[n>>2]|0;if((f|0)>0){d=c[k+32>>2]|0;p=0;q=0.0;while(1){r=b[l+(p<<1)>>1]|0;c[d+(p<<2)>>2]=r;s=q+ +(ba(r,r)|0);r=p+1|0;t=c[n>>2]|0;if((r|0)<(t|0)){p=r;q=s}else{u=s;v=t;break}}}else{u=0.0;v=f}q=u/+(v|0);do{if(q>0.0){v=~~(-0.0- +P(+ad(+(q/1081109975.0))*10.0));if((v|0)<0){w=0;break}w=(v|0)>127?127:v&255}else{w=127}}while(0);v=k+36|0;CKa(k,c[k+32>>2]|0,c[m>>2]|0,c[v>>2]|0)|0;k=e+24|0;a[c[k>>2]|0]=w;if((c[m>>2]|0)>0){w=0;while(1){f=w+1|0;a[(c[k>>2]|0)+f|0]=~~(+h[(c[v>>2]|0)+(w<<3)>>3]*127.0+127.0);if((f|0)<(c[m>>2]|0)){w=f}else{break}}}c[g>>2]=1;c[e+28>>2]=(c[m>>2]|0)+1;o=0;i=j;return o|0}function f0(a){a=a|0;var b=0;b=c[a+60>>2]|0;EKa(b);ZDb(c[b+32>>2]|0);ZDb(c[b+36>>2]|0);return 0}function g0(a){a=a|0;var b=0,d=0,e=0,f=0;b=0;while(1){if(!(b>>>0<371>>>0)){d=0;e=4;break}f=1462888+(b*20|0)|0;if((c[f>>2]|0)==(a|0)){d=f;e=4;break}else{b=b+1|0}}if((e|0)==4){return d|0}return 0}function h0(a){a=a|0;if((a|0)==0){return 1462888}else{return(((a-1462888|0)/20|0)>>>0<370>>>0?a+20|0:0)|0}return 0}function i0(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=0;while(1){if((b|0)==0){d=1462888}else{e=((b-1462888|0)/20|0)>>>0<370>>>0?b+20|0:0;if((e|0)==0){f=0;g=5;break}else{d=e}}if((QGb(c[d+8>>2]|0,a)|0)==0){f=d;g=5;break}else{b=d}}if((g|0)==5){return f|0}return 0}function j0(a){a=a|0;var b=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0.0,da=0,ea=0;b=i;e=c[a+60>>2]|0;f=e;h=c[a+96>>2]|0;j=a+100|0;k=c[j>>2]|0;l=h+k|0;m=e+20|0;c[m>>2]=a;n=a;if((k|0)<1){yDb(n,16,1896880,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}yDb(n,48,2354416,(o=i,i=i+8|0,c[o>>2]=k,o)|0);i=o;q=a+416|0;if((c[q>>2]|0)==0){yDb(n,16,2333968,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}oDb(e+1296|0,0);Z3(e+24|0,a);r=e+22792|0;s=a+432|0;t=e+1292|0;u=e+22820|0;v=e+22788|0;w=0;x=0;y=0;z=k;k=h;a:while(1){if(!(k>>>0<l>>>0)){A=-63;B=52;break}do{if((z|0)>7){h=k;C=fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;c[r+(y*8432|0)+12>>2]=C;h=k+4|0;D=(de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;h=k+6|0;E=(de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;c[r+(y*8432|0)+16>>2]=E;h=z-8|0;if((h|0)<=7){F=h;G=k+8|0;H=D;I=E;J=C;break}h=k+12|0;K=de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0;L=K&65535;c[r+(y*8432|0)+20>>2]=L;if((K&65535)>>>0>50>>>0){B=11;break a}K=k+14|0;c[r+(y*8432|0)+24>>2]=(de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535;F=z-16|0;G=k+16|0;H=D;I=E;J=C}else{F=z;G=k;H=w;I=c[r+(y*8432|0)+16>>2]|0;J=c[r+(y*8432|0)+12>>2]|0}}while(0);C=r+(y*8432|0)+28|0;c[C>>2]=(H|0)/(c[q>>2]|0)|0;c[r+(y*8432|0)+64>>2]=c[s>>2]<<3;E=r+(y*8432|0)+32|0;c[E>>2]=5;D=r+(y*8432|0)+16|0;K=r+(y*8432|0)+72|0;c[K>>2]=I;h=r+(y*8432|0)+8|0;c[h>>2]=1;yDb(n,48,2290560,(o=i,i=i+16|0,c[o>>2]=y,c[o+8>>2]=J,o)|0);i=o;M=r+(y*8432|0)+60|0;c[M>>2]=0;N=c[r+(y*8432|0)+12>>2]|0;do{if((N|0)==33554432){yDb(n,48,2210376,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;if((F|0)>3){O=G;P=fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;c[r+(y*8432|0)+36>>2]=P;Q=P|x;T=G+4|0;U=P}else{Q=x;T=G;U=c[r+(y*8432|0)+36>>2]|0}if((hBb(U,0)|0)<=1){c[C>>2]=H;V=Q;W=T;break}c[K>>2]=(c[r+(y*8432|0)+20>>2]|0)+(c[D>>2]|0);c[M>>2]=1;c[h>>2]=2;P=H>>1;c[C>>2]=P;if((P|0)<=256){V=Q;W=T;break}c[E>>2]=6;if((P|0)<=512){V=Q;W=T;break}c[E>>2]=7;V=Q;W=T}else if((N|0)==16777218){if((c[q>>2]|0)!=1){c[r+(y*8432|0)+68>>2]=1;c[h>>2]=2}yDb(n,48,2244456,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;V=x;W=G}else if((N|0)==16777217){if((c[q>>2]|0)!=1){B=15;break a}yDb(n,48,2258936,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;V=x;W=G}else if((N|0)==16777219){if((c[q>>2]|0)!=2){B=21;break a}yDb(n,48,2219656,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;if((c[j>>2]|0)>15){c[K>>2]=(c[r+(y*8432|0)+20>>2]|0)+(c[D>>2]|0);c[M>>2]=1;c[h>>2]=2}P=c[C>>2]|0;if((P|0)<=256){V=x;W=G;break}c[E>>2]=6;if((P|0)<=512){V=x;W=G;break}c[E>>2]=7;V=x;W=G}else{B=35;break a}}while(0);if((y|0)>1){if((c[C>>2]|0)!=(c[t>>2]|0)){B=38;break}}c[t>>2]=c[u>>2];c[r+(y*8432|0)+76>>2]=1<<c[E>>2];if((c[K>>2]|0)>53){B=40;break}X=c[r+(y*8432|0)+24>>2]|0;Y=c[M>>2]|0;if((X|0)>6){B=43;break}if((X|0)<(Y<<1|0)){B=43;break}P=c[D>>2]|0;if((P|0)>50){B=45;break}if((P|0)==0){B=47;break}c[r+(y*8432|0)+8272>>2]=r+(y*8432|0)+8288;c[r+(y*8432|0)+8276>>2]=r+(y*8432|0)+8324;c[r+(y*8432|0)+8280>>2]=r+(y*8432|0)+8360;c[r+(y*8432|0)+8284>>2]=r+(y*8432|0)+8396;Z=c[v>>2]|0;_=c[(c[m>>2]|0)+416>>2]|0;if(((c[h>>2]|0)+Z|0)>(_|0)){B=49;break}c[v>>2]=Z+1;P=y+1|0;if((P|0)>5){B=51;break}else{w=H;x=V;y=P;z=F;k=W}}if((B|0)==11){yDb(n,16,2309312,(o=i,i=i+8|0,c[o>>2]=L,o)|0);i=o;p=-1094995529;i=b;return p|0}else if((B|0)==15){DDb(n,2274648,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==21){DDb(n,2232024,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==35){DDb(n,2201640,(o=i,i=i+8|0,c[o>>2]=N,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==38){yDb(n,16,2193384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}else if((B|0)==40){DDb(n,2176920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==43){yDb(n,16,2166184,(o=i,i=i+16|0,c[o>>2]=X,c[o+8>>2]=Y<<1,o)|0);i=o;p=-1094995529;i=b;return p|0}else if((B|0)==45){DDb(n,2159544,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==47){DDb(n,2152512,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==49){yDb(n,16,2145664,(o=i,i=i+16|0,c[o>>2]=Z,c[o+8>>2]=_,o)|0);i=o;p=-1094995529;i=b;return p|0}else if((B|0)==51){DDb(n,2139680,(o=i,i=i+8|0,c[o>>2]=5,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==52){while(1){B=0;_=A+63|0;g[4649208+(_<<2)>>2]=+sGb(1.0,A);g[4546104+(_<<2)>>2]=+R(+sGb(1.0,A));_=A+1|0;if((_|0)<64){A=_;B=52}else{break}}B=(c[t>>2]|0)/8|0;A=e+2028|0;c[A>>2]=B;g[e+2032>>2]=+S(+(+g[1162354]),+(1.0/+(B|0)));_=1;Z=B;while(1){g[f+2032+(_<<2)>>2]=+S(+(+g[4649208+(_+52<<2)>>2]),+(1.0/+(Z|0)));B=_+1|0;if((B|0)>=23){break}_=B;Z=c[A>>2]|0}c[e+22768>>2]=1418608;c[e+22772>>2]=1418568;c[e+22776>>2]=1418496;c[e+22780>>2]=1418360;c[e+22784>>2]=1418096;A=0;Z=0;do{Z=N_(f+1628+(A*20|0)|0,9,24,1342504+(A*24|0)|0,1,1,1341880+(A*48|0)|0,2,2,0,0,0,0)|0|Z;A=A+1|0;}while((A|0)<13);yDb(c[m>>2]|0,48,2121072,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;A=0;_=Z;do{_=N_(f+1888+(A*20|0)|0,c[136816+(A<<2)>>2]|0,c[136848+(A<<2)>>2]|0,c[1414808+(A<<2)>>2]|0,1,1,c[1413312+(A<<2)>>2]|0,2,2,0,0,0,0)|0|_;A=A+1|0;}while((A|0)<7);A=c[v>>2]|0;if((A|0)>0){Z=0;B=_;Y=A;while(1){if((c[f+22792+(Z*8432|0)+60>>2]|0)==1){A=c[f+22792+(Z*8432|0)+24>>2]|0;X=A-2|0;N=N_(f+22792+(Z*8432|0)+40|0,6,(1<<A)-1|0,c[1502024+(X<<2)>>2]|0,1,1,c[1501872+(X<<2)>>2]|0,2,2,0,0,0,0)|0|B;yDb(c[m>>2]|0,48,2115168,(o=i,i=i+8|0,c[o>>2]=Z,o)|0);i=o;$=N;aa=c[v>>2]|0}else{$=B;aa=Y}N=Z+1|0;if((N|0)<(aa|0)){Z=N;B=$;Y=aa}else{ba=$;break}}}else{ba=_}yDb(c[m>>2]|0,48,2100768,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;if((ba|0)!=0){p=ba;i=b;return p|0}ba=c[s>>2]|0;if(ba>>>0>2147483646>>>0){p=-22;i=b;return p|0}s=cEb(ba+19-((ba+3|0)%4|0)|0)|0;c[e+2124>>2]=s;if((s|0)==0){p=-12;i=b;return p|0}s=c[t>>2]|0;ba=WDb(s<<2)|0;_=ba;$=e+1624|0;aa=$;c[aa>>2]=_;if((ba|0)==0){p=-12;i=b;return p|0}UXa(_,s);if((s|0)>0){ca=+R(2.0/+(c[t>>2]|0));_=c[aa>>2]|0;aa=0;do{ba=_+(aa<<2)|0;g[ba>>2]=ca*+g[ba>>2];aa=aa+1|0;}while((aa|0)<(s|0))}aa=s>>>0>65535>>>0;_=aa?s>>>16:s;s=aa?16:0;if((_&65280|0)==0){da=s;ea=_}else{da=s|8;ea=_>>>8}_=da+1+(d[1191992+ea|0]|0)|0;ea=aLa(e+1560|0,_,1,30517578125.0e-15)|0;if((ea|0)!=0){$Db($);p=ea;i=b;return p|0}yDb(c[m>>2]|0,48,2126920,(o=i,i=i+8|0,c[o>>2]=_,o)|0);i=o;c[e>>2]=272;c[e+4>>2]=2;c[e+8>>2]=426;c[e+12>>2]=28;c[e+16>>2]=306;e=c[t>>2]|0;if(!((e|0)==256|(e|0)==512|(e|0)==1024)){DDb(n,2133312,(o=i,i=i+8|0,c[o>>2]=e,o)|0);i=o;p=-1163346256;i=b;return p|0}c[a+420>>2]=8;if((x|0)==0){o=(c[q>>2]|0)==2;q=a+448|0;c[q>>2]=o?3:4;c[q+4>>2]=o?0:0;p=0;i=b;return p|0}else{o=a+448|0;c[o>>2]=x;c[o+4>>2]=0;p=0;i=b;return p|0}}return 0}function k0(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;k=i;i=i+80|0;l=k|0;m=c[j+24>>2]|0;n=c[j+28>>2]|0;j=c[e+60>>2]|0;o=j;p=e+432|0;q=c[p>>2]|0;if((n|0)<(q|0)){r=n;i=k;return r|0}n=j+1556|0;do{if((c[n>>2]|0)>1){c[f+76>>2]=c[j+1292>>2];s=_$a(e,f,0)|0;if((s|0)<0){r=s;i=k;return r|0}else{t=c[f+64>>2]|0;u=c[p>>2]|0;break}}else{t=0;u=q}}while(0);q=j+22792|0;f=j+22796|0;c[f>>2]=u;u=j+22788|0;s=c[u>>2]|0;v=1;while(1){if((v|0)>=(s|0)){break}w=d[m+(v-s+(c[p>>2]|0))|0]<<1;c[q+(v*8432|0)+4>>2]=w;x=(c[f>>2]|0)-(w|1)|0;c[f>>2]=x;if((x|0)<0){y=10;break}else{v=v+1|0}}if((y|0)==10){yDb(e,48,2055e3,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;r=-1094995529;i=k;return r|0}a:do{if((s|0)>0){v=e;f=j+10336|0;x=f;w=j+14432|0;A=(t|0)!=0;B=j+2144|0;C=B;D=j+1292|0;E=j+1560|0;F=j+1600|0;G=j+8|0;H=j+12|0;I=j+2028|0;J=j+16|0;K=j+1276|0;L=l;M=j+18528|0;N=j+1268|0;O=j+1284|0;P=j+4|0;Q=0;R=0;S=0;b:while(1){T=q+(Q*8432|0)|0;U=q+(Q*8432|0)+4|0;V=c[U>>2]|0;c[q+(Q*8432|0)+64>>2]=V<<3>>c[q+(Q*8432|0)+68>>2];W=T|0;c[W>>2]=S;X=q+(Q*8432|0)+60|0;Y=c[X>>2]|0;Z=c[p>>2]|0;yDb(v,48,2009032,(z=i,i=i+40|0,c[z>>2]=Q,c[z+8>>2]=V,c[z+16>>2]=Y,c[z+24>>2]=R,c[z+32>>2]=Z,z)|0);i=z;Z=c[U>>2]|0;TGb(f|0,0,4096)|0;Y=q+(Q*8432|0)+8272|0;m0(o,T,m+R|0,Y);do{if((c[X>>2]|0)==0){V=n0(o,T,x)|0;if((V|0)<0){r=V;y=64;break b}if((c[q+(Q*8432|0)+8>>2]|0)!=2){break}m0(o,T,m+(((Z|0)/2|0)+R)|0,q+(Q*8432|0)+8280|0);V=n0(o,T,w)|0;if((V|0)<0){r=V;y=64;break b}}else{TGb(L|0,0,80)|0;TGb(f|0,0,12432)|0;V=c[K>>2]|0;_=c[N>>2]|0;$=a[_+(V>>>3)|0]|0;aa=c[O>>2]|0;ca=((V|0)<(aa|0))+V|0;c[K>>2]=ca;da=q+(Q*8432|0)+20|0;ea=c[1418632+(c[da>>2]<<2)>>2]|0;fa=q+(Q*8432|0)+16|0;ga=c[1418632+((c[fa>>2]|0)-1<<2)>>2]|0;ha=ga-ea+1|0;c:do{if((ea|0)<=(ga|0)){ia=(ha|0)>0;if(($&255&128>>>((V&7)>>>0)|0)==0){if(!ia){break}ja=c[q+(Q*8432|0)+24>>2]|0;ka=0;la=ca;while(1){ma=_+(la>>>3)|0;na=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7)>>>((32-ja|0)>>>0);ma=la+ja|0;la=aa>>>0>ma>>>0?ma:aa;c[K>>2]=la;if((na|0)==((1<<ja)-1|0)){y=23;break b}c[l+(ka+ea<<2)>>2]=na;ka=ka+1|0;if((ka|0)>=(ha|0)){break c}}}if(!ia){break}ka=c[q+(Q*8432|0)+44>>2]|0;ja=c[q+(Q*8432|0)+40>>2]|0;la=0;na=ca;do{ma=_+(na>>>3)|0;oa=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(na&7)>>>((32-ja|0)>>>0);ma=b[ka+(oa<<2)>>1]|0;pa=b[ka+(oa<<2)+2>>1]|0;oa=pa<<16>>16;if(pa<<16>>16<0){pa=ja+na|0;qa=aa>>>0>pa>>>0?pa:aa;pa=_+(qa>>>3)|0;ra=((fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(qa&7)>>>((oa+32|0)>>>0))+ma|0;sa=b[ka+(ra<<2)+2>>1]|0;ta=b[ka+(ra<<2)>>1]|0;ua=qa}else{sa=oa;ta=ma;ua=na}ma=sa+ua|0;na=aa>>>0>ma>>>0?ma:aa;c[K>>2]=na;c[l+(la+ea<<2)>>2]=ta;la=la+1|0;}while((la|0)<(ha|0))}}while(0);ha=n0(o,T,M)|0;if((ha|0)<0){r=ha;y=64;break b}ha=c[da>>2]|0;if((ha|0)>0){ea=0;do{aa=ea*40|0;_=ea*20|0;ca=aa+20|0;V=0;do{$=V+_|0;g[o+10336+($<<2)>>2]=+g[o+18528+(V+aa<<2)>>2];g[o+14432+($<<2)>>2]=+g[o+18528+(ca+V<<2)>>2];V=V+1|0;}while((V|0)<20);ea=ea+1|0;}while((ea|0)<(ha|0))}ea=q+(Q*8432|0)+24|0;if((ha|0)<(c[fa>>2]|0)){va=ha}else{break}do{da=c[ea>>2]|0;V=c[l+(c[1418632+(va<<2)>>2]<<2)>>2]|0;ca=c[o+22768+(da-2<<2)>>2]|0;qe[c[P>>2]&3](o,T,va,+g[ca+(V+1<<2)>>2],+g[ca+((1<<da)-1-V<<2)>>2],M,x,w);va=va+1|0;}while((va|0)<(c[fa>>2]|0))}}while(0);T=q+(Q*8432|0)+80|0;if(A){wa=c[t+(c[W>>2]<<2)>>2]|0}else{wa=0}Z=c[D>>2]|0;Xe[c[F>>2]&4095](E,C,x);cf[c[G>>2]&1023](o,o+2144+(Z<<2)|0,Y,T);fa=Y|0;ea=0;while(1){ha=c[fa>>2]|0;V=c[ha+(ea<<2)>>2]|0;da=ea+1|0;ca=c[ha+(da<<2)>>2]|0;if((ca|V|0)!=0){ha=o+2144+((ba(c[I>>2]|0,ea)|0)+Z<<2)|0;cf[c[H>>2]&1023](o,ha,V,ca)}if((da|0)<8){ea=da}else{break}}UGb(T|0,B|0,c[D>>2]<<2)|0;if((wa|0)!=0){ne[c[J>>2]&1023](o,wa)}ea=q+(Q*8432|0)+8|0;do{if((c[ea>>2]|0)==2){if((c[X>>2]|0)==0){Z=q+(Q*8432|0)+8280|0;da=q+(Q*8432|0)+4176|0;if(A){xa=c[t+((c[W>>2]|0)+1<<2)>>2]|0}else{xa=0}ca=c[D>>2]|0;Xe[c[F>>2]&4095](E,C,w);cf[c[G>>2]&1023](o,o+2144+(ca<<2)|0,Z,da);V=Z|0;Z=0;while(1){ha=c[V>>2]|0;aa=c[ha+(Z<<2)>>2]|0;_=Z+1|0;$=c[ha+(_<<2)>>2]|0;if(($|aa|0)!=0){ha=o+2144+((ba(c[I>>2]|0,Z)|0)+ca<<2)|0;cf[c[H>>2]&1023](o,ha,aa,$)}if((_|0)<8){Z=_}else{break}}UGb(da|0,B|0,c[D>>2]<<2)|0;if((xa|0)==0){break}ne[c[J>>2]&1023](o,xa);break}else{Z=q+(Q*8432|0)+4176|0;if(A){ya=c[t+((c[W>>2]|0)+1<<2)>>2]|0}else{ya=0}ca=c[D>>2]|0;Xe[c[F>>2]&4095](E,C,w);cf[c[G>>2]&1023](o,o+2144+(ca<<2)|0,Y,Z);V=0;while(1){_=c[fa>>2]|0;$=c[_+(V<<2)>>2]|0;aa=V+1|0;ha=c[_+(aa<<2)>>2]|0;if((ha|$|0)!=0){_=o+2144+((ba(c[I>>2]|0,V)|0)+ca<<2)|0;cf[c[H>>2]&1023](o,_,$,ha)}if((aa|0)<8){V=aa}else{break}}UGb(Z|0,B|0,c[D>>2]<<2)|0;if((ya|0)==0){break}ne[c[J>>2]&1023](o,ya);break}}}while(0);fa=c[U>>2]|0;Y=(c[ea>>2]|0)+S|0;W=c[K>>2]|0;yDb(v,48,1970600,(z=i,i=i+24|0,c[z>>2]=Q,c[z+8>>2]=fa<<3,c[z+16>>2]=W,z)|0);i=z;W=Q+1|0;if((W|0)<(c[u>>2]|0)){Q=W;R=fa+R|0;S=Y}else{break a}}if((y|0)==23){yDb(c[j+20>>2]|0,16,1917672,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;r=-1094995529;i=k;return r|0}else if((y|0)==64){i=k;return r|0}}}while(0);y=c[n>>2]|0;if((y|0)<2){c[n>>2]=y+1;c[h>>2]=0;r=c[p>>2]|0;i=k;return r|0}else{c[h>>2]=1;r=c[p>>2]|0;i=k;return r|0}return 0}function l0(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+60>>2]|0;e=a;yDb(e,48,2191272,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;$Db(d+1624|0);$Db(d+2124|0);bLa(d+1560|0);Q_(d+1628|0);Q_(d+1648|0);Q_(d+1668|0);Q_(d+1688|0);Q_(d+1708|0);Q_(d+1728|0);Q_(d+1748|0);Q_(d+1768|0);Q_(d+1788|0);Q_(d+1808|0);Q_(d+1828|0);Q_(d+1848|0);Q_(d+1868|0);Q_(d+1888|0);Q_(d+1908|0);Q_(d+1928|0);Q_(d+1948|0);Q_(d+1968|0);Q_(d+1988|0);Q_(d+2008|0);f=d+22788|0;if((c[f>>2]|0)<=0){yDb(e,48,2113600,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}g=d+22792|0;d=0;do{Q_(g+(d*8432|0)+40|0);d=d+1|0;}while((d|0)<(c[f>>2]|0));yDb(e,48,2113600,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function m0(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=c[a+2124>>2]|0;h=b+64|0;b=c[h>>2]|0;i=g;j=e&3;k=e+(-j|0)|0;e=c[1403888+(j<<2)>>2]|0;l=j+3+((b|0)/8|0)|0;m=(l|0)/4|0;if((l|0)>3){l=0;do{c[i+(l<<2)>>2]=c[k+(l<<2)>>2]^e;l=l+1|0;}while((l|0)<(m|0));n=c[h>>2]|0}else{n=b}b=g+j|0;j=n>>>0>2147483639>>>0|(b|0)==0;g=j?0:b;b=j?0:n;c[a+1268>>2]=g;c[a+1280>>2]=b;n=b+8|0;j=a+1284|0;c[j>>2]=n;c[a+1272>>2]=g+(b+7>>3);h=a+1276|0;c[h>>2]=0;a=f|0;m=c[a>>2]|0;l=0;e=0;while(1){if((l|0)>=(b|0)){o=e;break}k=d[g+(e>>>3)|0]|0;i=((e|0)<(n|0))+e|0;c[h>>2]=i;if((k&128>>>((e&7)>>>0)|0)==0){o=i;break}else{l=l+1|0;e=i}}do{if((l|0)==0){p=0}else{e=0;b=l;i=o;k=n;while(1){q=b-1|0;r=g+(i>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(i&7)>>>29;r=i+3|0;t=k>>>0>r>>>0?r:k;c[h>>2]=t;r=d[g+(t>>>3)|0]|0;u=((t|0)<(k|0))+t|0;c[h>>2]=u;if((r&128>>>((t&7)>>>0)|0)==0){v=-1}else{t=g+(u>>>3)|0;r=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(u&7)>>>28;t=u+4|0;c[h>>2]=k>>>0>t>>>0?t:k;v=r-7|0}if((e|0)>(s|0)){w=e}else{r=e;while(1){t=r+1|0;c[m+(r<<2)>>2]=v;if((t|0)>(s|0)){break}else{r=t}}w=s+1|0}if((q|0)==0){break}e=w;b=q;i=c[h>>2]|0;k=c[j>>2]|0}if((w|0)<9){p=w;break}else{x=m}y=f+4|0;z=c[y>>2]|0;c[y>>2]=x;c[a>>2]=z;return}}while(0);TGb(m+(p<<2)|0,0,36-(p<<2)|0)|0;x=c[a>>2]|0;y=f+4|0;z=c[y>>2]|0;c[y>>2]=x;c[a>>2]=z;return}function n0(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;g=i;i=i+408|0;h=g|0;j=h;k=i;i=i+408|0;l=i;i=i+1024|0;m=i;i=i+80|0;n=i;i=i+80|0;o=i;i=i+512|0;p=o;q=i;i=i+512|0;r=q;s=i;i=i+408|0;TGb(p|0,0,512)|0;TGb(r|0,0,512)|0;t=a+1276|0;u=c[t>>2]|0;v=a+1284|0;w=c[v>>2]|0;x=a+1268|0;y=c[x>>2]|0;z=y+(u>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(u&7)>>>26;z=u+6|0;u=w>>>0>z>>>0?z:w;c[t>>2]=u;z=A-6|0;c[s>>2]=z;A=e+72|0;B=e+20|0;C=1;D=u;u=z;while(1){if((C|0)>=(c[A>>2]|0)){break}z=c[B>>2]|0;if((C|0)<(z<<1|0)){E=(C|0)<2?1:(C|0)/2|0}else{E=C-z|0}z=(E|0)>13?12:E-1|0;F=c[a+1628+(z*20|0)+4>>2]|0;G=c[a+1628+(z*20|0)>>2]|0;z=y+(D>>>3)|0;H=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(D&7)>>>((32-G|0)>>>0);z=b[F+(H<<2)>>1]|0;I=b[F+(H<<2)+2>>1]|0;H=I<<16>>16;if(I<<16>>16<0){I=D+G|0;G=w>>>0>I>>>0?I:w;I=y+(G>>>3)|0;J=((fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(G&7)>>>((H+32|0)>>>0))+z|0;K=b[F+(J<<2)+2>>1]|0;L=b[F+(J<<2)>>1]|0;M=G}else{K=H;L=z;M=D}z=K+M|0;H=w>>>0>z>>>0?z:w;c[t>>2]=H;z=u+L|0;N=z-12|0;c[s+(C<<2)>>2]=N;if((z+51|0)>>>0>126>>>0){O=9;break}else{C=C+1|0;D=H;u=N}}if((O|0)==9){yDb(c[a+20>>2]|0,16,1941936,(u=i,i=i+16|0,c[u>>2]=N,c[u+8>>2]=C,u)|0);i=u;P=-1094995529;i=g;return P|0}u=c[e+32>>2]|0;C=y+(D>>>3)|0;y=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(D&7)>>>((32-u|0)>>>0);C=D+u|0;u=w>>>0>C>>>0?C:w;c[t>>2]=u;c[a+1288>>2]=y;TGb(j|0,0,408)|0;TGb(k|0,0,408)|0;TGb(l|0,0,1024)|0;w=c[e+76>>2]|0;C=e+64|0;e=(c[C>>2]|0)-u|0;u=c[a+1292>>2]|0;if((e|0)>(u|0)){Q=(((e-u|0)*5|0|0)/8|0)+u|0}else{Q=e}e=c[A>>2]|0;u=(e|0)>0;D=Q-32|0;if(u){N=0;L=0;M=e;while(1){K=32-(c[s+(L<<2)>>2]|0)-32|0;E=(K|0)/2|0;if((K|0)<-1){R=0}else{R=(E|0)>7?7:E}S=(c[1320992+(R<<2)>>2]|0)+N|0;E=M-1|0;if((E|0)<=0){break}N=S;L=L+1|0;M=E}M=(S|0)<(D|0)?-32:0;S=0;L=0;N=e;while(1){R=16-(c[s+(L<<2)>>2]|0)+M|0;E=(R|0)/2|0;if((R|0)<-1){T=0}else{T=(E|0)>7?7:E}U=(c[1320992+(T<<2)>>2]|0)+S|0;E=N-1|0;if((E|0)<=0){break}S=U;L=L+1|0;N=E}N=((U|0)<(D|0)?0:16)|M;M=0;U=0;L=e;while(1){S=8-(c[s+(U<<2)>>2]|0)+N|0;T=(S|0)/2|0;if((S|0)<-1){V=0}else{V=(T|0)>7?7:T}W=(c[1320992+(V<<2)>>2]|0)+M|0;T=L-1|0;if((T|0)<=0){break}M=W;U=U+1|0;L=T}L=((W|0)<(D|0)?0:8)|N;N=0;W=0;U=e;while(1){M=4-(c[s+(W<<2)>>2]|0)+L|0;V=(M|0)/2|0;if((M|0)<-1){X=0}else{X=(V|0)>7?7:V}Y=(c[1320992+(X<<2)>>2]|0)+N|0;V=U-1|0;if((V|0)<=0){break}N=Y;W=W+1|0;U=V}U=((Y|0)<(D|0)?0:4)|L;L=0;Y=0;W=e;while(1){N=2-(c[s+(Y<<2)>>2]|0)+U|0;X=(N|0)/2|0;if((N|0)<-1){Z=0}else{Z=(X|0)>7?7:X}_=(c[1320992+(Z<<2)>>2]|0)+L|0;X=W-1|0;if((X|0)<=0){break}L=_;Y=Y+1|0;W=X}W=((_|0)<(D|0)?0:2)|U;U=0;_=0;Y=e;while(1){L=1-(c[s+(_<<2)>>2]|0)+W|0;Z=(L|0)/2|0;if((L|0)<-1){$=0}else{$=(Z|0)>7?7:Z}aa=(c[1320992+($<<2)>>2]|0)+U|0;Z=Y-1|0;if((Z|0)<=0){break}U=aa;_=_+1|0;Y=Z}Y=(aa|0)>=(D|0)|W;W=0;aa=0;while(1){_=Y-(c[s+(aa<<2)>>2]|0)|0;U=(_|0)/2|0;if((_|0)<-1){ca=0}else{ca=(U|0)>7?7:U}U=(c[1320992+(ca<<2)>>2]|0)+W|0;c[k+(aa<<2)>>2]=ca;c[h+(aa<<2)>>2]=ca;_=aa+1|0;if((_|0)<(e|0)){W=U;aa=_}else{da=U;ea=Y;break}}}else{Y=(D|0)>0;da=0;ea=((Y?0:16)|(Y?-32:0)|(Y?0:8)|(Y?0:4)|(Y?0:2)|Y&1)^1}a:do{if((w|0)>1){Y=Q<<1;D=da;aa=da;W=1;ca=w;U=w;while(1){if((D+aa|0)>(Y|0)){if(u){fa=-1;ga=0;ha=-999999}else{ia=U;break a}while(1){_=c[k+(ga<<2)>>2]|0;if((_|0)<7){$=(_*-2|0)-(c[s+(ga<<2)>>2]|0)+ea|0;_=($|0)<(ha|0);ja=_?ha:$;ka=_?fa:ga}else{ja=ha;ka=fa}_=ga+1|0;if((_|0)<(e|0)){fa=ka;ga=_;ha=ja}else{break}}if((ka|0)==-1){la=U;O=23;break a}c[l+(ca<<2)>>2]=ka;_=k+(ka<<2)|0;$=c[_>>2]|0;Z=$+1|0;L=D-(c[1320992+($<<2)>>2]|0)+(c[1320992+(Z<<2)>>2]|0)|0;c[_>>2]=Z;ma=U;na=ca+1|0;oa=aa;pa=L}else{if(u){qa=-1;ra=0;sa=999999}else{ia=U;break a}while(1){L=c[h+(ra<<2)>>2]|0;if((L|0)>0){Z=(L*-2|0)-(c[s+(ra<<2)>>2]|0)+ea|0;L=(Z|0)<(sa|0);ta=L?Z:sa;ua=L?ra:qa}else{ta=sa;ua=qa}L=ra+1|0;if((L|0)<(e|0)){qa=ua;ra=L;sa=ta}else{break}}if((ua|0)==-1){la=U;O=23;break a}L=U-1|0;c[l+(L<<2)>>2]=ua;Z=h+(ua<<2)|0;_=c[Z>>2]|0;$=_-1|0;X=aa-(c[1320992+(_<<2)>>2]|0)+(c[1320992+($<<2)>>2]|0)|0;c[Z>>2]=$;ma=L;na=ca;oa=X;pa=D}X=W+1|0;if((X|0)<(w|0)){D=pa;aa=oa;W=X;ca=na;U=ma}else{la=ma;O=23;break}}}else{la=w;O=23}}while(0);do{if((O|0)==23){if(!u){ia=la;break}UGb(r|0,j|0,(e|0)>1?e<<2:4)|0;ia=la}}while(0);la=w-1|0;if((la|0)>0){UGb(p|0,l+(ia<<2)|0,(la|0)>1?la<<2:4)|0}if((y|0)>0){la=0;while(1){ia=q+(c[o+(la<<2)>>2]<<2)|0;l=c[ia>>2]|0;p=l+1|0;c[ia>>2]=p>>>0>8>>>0?l:p;p=la+1|0;if((p|0)<(y|0)){la=p}else{va=0;break}}}else{va=0}while(1){if((va|0)>=(e|0)){break}if((c[q+(va<<2)>>2]|0)>7){P=-1094995529;O=69;break}else{va=va+1|0}}if((O|0)==69){i=g;return P|0}va=m;e=n;if(!u){P=0;i=g;return P|0}u=a|0;la=m|0;y=n|0;o=0;while(1){p=c[q+(o<<2)>>2]|0;do{if((p|0)<7){l=c[143128+(p<<2)>>2]|0;ia=a+1888+(p*20|0)+4|0;w=a+1888+(p*20|0)|0;j=c[103832+(p<<2)>>2]|0;r=c[x>>2]|0;ma=c[904856+(p<<2)>>2]|0;na=(c[879864+(p<<2)>>2]|0)+1|0;oa=c[v>>2]|0;pa=0;ua=0;h=c[t>>2]|0;while(1){ta=c[ia>>2]|0;sa=c[w>>2]|0;ra=r+(h>>>3)|0;qa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(h&7)>>>((32-sa|0)>>>0);ra=b[ta+(qa<<2)>>1]|0;ea=b[ta+(qa<<2)+2>>1]|0;qa=ea<<16>>16;do{if(ea<<16>>16<0){ka=sa+h|0;k=oa>>>0>ka>>>0?ka:oa;ka=r+(k>>>3)|0;ja=((fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(k&7)>>>((qa+32|0)>>>0))+ra|0;ka=b[ta+(ja<<2)>>1]|0;ha=b[ta+(ja<<2)+2>>1]|0;ja=ha<<16>>16;if(!(ha<<16>>16<0)){wa=ja;xa=ka;ya=k;break}ha=k-qa|0;k=oa>>>0>ha>>>0?ha:oa;ha=r+(k>>>3)|0;ga=((fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(k&7)>>>((ja+32|0)>>>0))+ka|0;wa=b[ta+(ga<<2)+2>>1]|0;xa=b[ta+(ga<<2)>>1]|0;ya=k}else{wa=qa;xa=ra;ya=h}}while(0);ra=wa+ya|0;qa=oa>>>0>ra>>>0?ra:oa;c[t>>2]=qa;ra=(c[C>>2]|0)<(qa|0);ta=ba(pa,l)|0;sa=ra?0:xa;ea=l;while(1){k=ea-1|0;ga=(ba(sa,ma)|0)/1048576|0;c[m+(k+ta<<2)>>2]=sa-(ba(ga,na)|0);if((k|0)>0){sa=ga;ea=k}else{break}}ea=0;sa=ra?1:ua;k=qa;while(1){ga=ea+ta|0;do{if((c[m+(ga<<2)>>2]|0)==0){c[n+(ga<<2)>>2]=0;za=sa;Aa=k}else{if((k|0)<(c[C>>2]|0)){ka=d[r+(k>>>3)|0]<<(k&7)>>>7;ja=((k|0)<(oa|0))+k|0;c[t>>2]=ja;c[n+(ga<<2)>>2]=ka&1;za=sa;Aa=ja;break}else{c[n+(ga<<2)>>2]=0;za=1;Aa=k;break}}}while(0);ga=ea+1|0;if((ga|0)<(l|0)){ea=ga;sa=za;k=Aa}else{break}}k=pa+1|0;if((k|0)<(j|0)){pa=k;ua=za;h=Aa}else{break}}if((za|0)==0){if((p|0)>6){Ba=p;O=67;break}else{Ca=p;break}}h=c[A>>2]|0;if((h|0)>0){Da=0}else{Ba=7;O=67;break}while(1){c[q+(Da+o<<2)>>2]=7;ua=Da+1|0;if((ua|0)<(h|0)){Da=ua}else{Ba=7;O=67;break}}}else{Ba=p;O=67}}while(0);if((O|0)==67){O=0;TGb(va|0,0,80)|0;TGb(e|0,0,80)|0;Ca=Ba}Se[c[u>>2]&511](a,Ca,c[s+(o<<2)>>2]|0,la,y,f+((o*20|0)<<2)|0);p=o+1|0;if((p|0)<(c[A>>2]|0)){o=p}else{P=0;break}}i=g;return P|0}function o0(a,b,d,e,f,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0.0,n=0,o=0.0;i=1361040+(b<<2)|0;j=a+1552|0;k=4546104+(d+63<<2)|0;d=0;do{l=c[e+(d<<2)>>2]|0;do{if((l|0)==0){m=+g[i>>2];n=c[j>>2]|0;c[a+1296+((n&63)<<2)>>2]=(c[a+1296+((n+9&63)<<2)>>2]|0)+(c[a+1296+((n+40&63)<<2)>>2]|0);n=c[j>>2]|0;c[j>>2]=n+1;if(!((c[a+1296+((n&63)<<2)>>2]|0)>-1)){o=m;break}o=-0.0-m}else{m=+g[553e3+(b*56|0)+(l<<2)>>2];if((c[f+(d<<2)>>2]|0)==0){o=m;break}o=-0.0-m}}while(0);g[h+(d<<2)>>2]=o*+g[k>>2];d=d+1|0;}while((d|0)<20);return}function p0(a,b,d,e,f,h,i,j){a=a|0;b=b|0;d=d|0;e=+e;f=+f;h=h|0;i=i|0;j=j|0;var k=0,l=0;a=((c[b+20>>2]|0)+d|0)*20|0;b=d*20|0;d=0;do{k=h+(a+d<<2)|0;l=d+b|0;g[i+(l<<2)>>2]=+g[k>>2]*e;g[j+(l<<2)>>2]=+g[k>>2]*f;d=d+1|0;}while((d|0)<20);return}function q0(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0.0,h=0,i=0;f=+g[4649208+((c[c[d+4>>2]>>2]|0)+63<<2)>>2];d=c[a+1292>>2]|0;if((d|0)<=0){return}h=c[a+1624>>2]|0;a=0;do{i=b+(a<<2)|0;g[i>>2]=f*+g[i>>2]*+g[h+(a<<2)>>2]- +g[e+(a<<2)>>2]*+g[h+(d+~a<<2)>>2];a=a+1|0;}while((a|0)<(d|0));return}function r0(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0.0,h=0,i=0,j=0,k=0.0,l=0.0,m=0;f=+g[4649208+(d+63<<2)>>2];if((d|0)==(e|0)){h=c[a+2028>>2]|0;if((h|0)>0){i=0}else{return}do{j=b+(i<<2)|0;g[j>>2]=f*+g[j>>2];i=i+1|0;}while((i|0)<(h|0));return}else{k=+g[a+2032+(11-d+e<<2)>>2];e=c[a+2028>>2]|0;if((e|0)>0){l=f;m=0}else{return}while(1){a=b+(m<<2)|0;g[a>>2]=l*+g[a>>2];a=m+1|0;if((a|0)<(e|0)){l=k*l;m=a}else{break}}return}}function s0(a,b){a=a|0;b=b|0;var d=0;d=c[a+1292>>2]|0;af[c[a+1128>>2]&3](b,a+2144+(d<<2)|0,-1.0,1.0,d+7&-8);return}function t0(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[a+140>>2]=0;d=a+104|0;do{if((c[d>>2]|0)==1){e=a+108|0;if((c[e>>2]|0)!=1e6){break}c[d>>2]=1;c[e>>2]=60}}while(0);d=ICb()|0;c[b>>2]=d;return((d|0)==0?-12:0)|0}function u0(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;h=i;j=c[g+24>>2]|0;k=c[b+60>>2]|0;l=c[k>>2]|0;m=g+28|0;g=c[m>>2]|0;do{if((g|0)>=64){if((a[j]|0)!=25){break}if((a[j+1|0]|0)!=104){break}n=j+17|0;o=a[n]|0;if(!((o&255)>>>0<2>>>0)){break}p=a[j+18|0]|0;if(!((p&255)>>>0<2>>>0)){break}q=j+28|0;r=a[q]|0;if(!((r&255)>>>0<2>>>0)){break}s=a[j+29|0]|0;if(!((s&255)>>>0<2>>>0)){break}if(o<<24>>24==1){yDb(b,16,2113536,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1163346256;i=h;return u|0}if(p<<24>>24==1){yDb(b,16,2054968,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1163346256;i=h;return u|0}if(s<<24>>24==1){yDb(b,16,2009e3,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1163346256;i=h;return u|0}s=l+88|0;if(r<<24>>24==0){c[s>>2]=1;c[l+84>>2]=1}else{c[s>>2]=2;c[l+84>>2]=0}s=$$a(b,l)|0;if((s|0)<0){u=s;i=h;return u|0}s=l+72|0;a:do{if((c[s>>2]|0)>0){r=l+32|0;p=l|0;o=l+36|0;v=l+4|0;w=l+40|0;x=l+8|0;y=b;z=g-64|0;A=j+64|0;B=0;while(1){C=A;D=(d[C]|d[C+1|0]<<8)<<16>>16&65535;if((z|0)<(D|0)){E=22;break}C=D-1|0;F=A+(D+1)|0;if(!((a[F]|0)==-3)){E=24;break}G=c[r>>2]|0;H=ba(G,B)|0;I=c[p>>2]|0;J=I+H|0;K=B>>1;L=c[o>>2]|0;M=ba(L,K)|0;N=c[v>>2]|0;O=c[w>>2]|0;P=ba(O,K)|0;K=c[x>>2]|0;Q=I+(G-1+H)|0;H=N+(L-1+M)|0;L=K+(O-1+P)|0;O=(a[n]|0)==0;b:do{if((B&1|0)==0){if(!O){break}G=D-4|0;if((G|0)>0){R=J;S=N+M|0;T=K+P|0;U=0}else{break}while(1){I=R+1|0;if(I>>>0>Q>>>0|S>>>0>H>>>0|T>>>0>L>>>0){break}V=a[A+(U+2)|0]|0;do{if((V&1)==0){E=41}else{if((a[q]|0)!=1){E=41;break}W=(V&255)>>>1&255;X=W>>>1;Y=U+1|0;Z=T+X|0;_=S+X|0;$=R+W|0}}while(0);if((E|0)==41){E=0;a[R]=V;a[S]=a[A+(U+3)|0]|0;W=U+4|0;a[I]=a[A+W|0]|0;a[T]=a[A+(U+5)|0]|0;Y=W;Z=T+1|0;_=S+1|0;$=R+2|0}if((Y|0)<(G|0)){R=$;S=_;T=Z;U=Y}else{break b}}zCb(l,1);yDb(y,24,1917632,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else{if(O&(C|0)>0){aa=J;ca=0}else{break}while(1){if(aa>>>0>Q>>>0){break}G=a[A+(ca+2)|0]|0;do{if((G&1)==0){E=32}else{if((a[q]|0)!=1){E=32;break}da=aa+((G&255)>>>1&255)|0}}while(0);if((E|0)==32){E=0;a[aa]=G;da=aa+1|0}I=ca+1|0;if((I|0)<(C|0)){aa=da;ca=I}else{break b}}zCb(l,1);yDb(y,24,1917632,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}}while(0);C=B+1|0;if((C|0)<(c[s>>2]|0)){z=z-D|0;A=A+(D+2)|0;B=C}else{break a}}if((E|0)==22){zCb(l,1);yDb(y,24,1970568,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((E|0)==24){zCb(l,1);B=d[F]|0;yDb(y,24,1941864,(t=i,i=i+16|0,c[t>>2]=D,c[t+8>>2]=B,t)|0);i=t;break}}}while(0);c[f>>2]=1;s=MCb(e,c[k>>2]|0)|0;if((s|0)<0){u=s;i=h;return u|0}u=c[m>>2]|0;i=h;return u|0}}while(0);yDb(b,16,2191160,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}function v0(a){a=a|0;JCb(c[a+60>>2]|0);return 0}function w0(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+60>>2]|0;e=a+792|0;f=c[e>>2]|0;if((f|0)==24){c[a+140>>2]=3}else if((f|0)==32){c[a+140>>2]=30}else if((f|0)==16){c[a+140>>2]=46}else{yDb(a,16,1970520,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-1094995529;i=b;return h|0}c[d+12>>2]=f;f=(ba(c[e>>2]|0,c[a+120>>2]|0)|0)/8|0;c[d+4>>2]=f;e=c[a+124>>2]|0;c[d+8>>2]=e;j=ba(f+3&-4,e)|0;c[d+16>>2]=j;e=WDb(j+12|0)|0;c[d+20>>2]=e;if((e|0)==0){yDb(a,16,1941824,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-12;i=b;return h|0}else{g=ICb()|0;c[d>>2]=g;h=(g|0)==0?-12:0;i=b;return h|0}return 0}function x0(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;if((n|0)<2){yDb(b,16,2191112,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}q=g;r=$$a(b,c[q>>2]|0)|0;if((r|0)<0){p=r;i=h;return p|0}r=(d[m]|0)>>>1&7;do{if((r|0)==1){c[l>>2]=c[g+16>>2];if((Zb(c[g+20>>2]|0,l|0,m+2|0,n-2|0)|0)==0){break}yDb(b,16,2054912,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}else if((r|0)==0){c[j>>2]=c[g+16>>2];c[k>>2]=n-2;if((FDb(c[g+20>>2]|0,j,m+2|0,k)|0)==0){break}yDb(b,16,2113504,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}else{yDb(b,16,2008976,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}}while(0);o=c[q>>2]|0;b=o+88|0;do{if((a[m]&1)==0){c[b>>2]=2;c[o+84>>2]=0;k=c[g+4>>2]|0;j=c[g+8>>2]|0;r=o+32|0;if((j|0)==0){break}l=k+3&-4;if((k|0)==0){break}s=(c[o>>2]|0)+(ba(c[r>>2]|0,j-1|0)|0)|0;t=j;j=c[g+20>>2]|0;u=s;while(1){s=k;v=j;w=u;while(1){a[w]=(a[w]|0)+(a[v]|0);x=s-1|0;if((x|0)==0){break}else{s=x;v=v+1|0;w=w+1|0}}w=t-1|0;if((w|0)==0){break}else{t=w;j=j+l|0;u=u+(-(c[r>>2]|0)|0)|0}}}else{c[b>>2]=1;c[o+84>>2]=1;r=c[g+4>>2]|0;u=c[g+8>>2]|0;l=r+3&-4;j=o+32|0;if((u|0)==0){break}t=ba(c[j>>2]|0,u-1|0)|0;k=u;u=c[g+20>>2]|0;w=(c[o>>2]|0)+t|0;while(1){UGb(w|0,u|0,r)|0;t=k-1|0;if((t|0)==0){break}else{k=t;u=u+l|0;w=w+(-(c[j>>2]|0)|0)|0}}}}while(0);c[f>>2]=1;f=MCb(e,c[q>>2]|0)|0;p=(f|0)<0?f:n;i=h;return p|0}function y0(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+20|0);JCb(b);return 0}function z0(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;d=c[a+120>>2]|0;c[b+4>>2]=d;if((d&3|0)!=0){e=-1094995529;return e|0}c[b+8>>2]=c[a+124>>2];e=0;return e|0}function A0(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=e;m=j+16|0;n=g+8|0;o=c[n>>2]|0;p=g+4|0;g=c[p>>2]|0;q=ba(o<<1,g+1&-2)|0;r=(c[b+48>>2]|0)==124;s=r?m:j;t=r?j+32|0:m;m=(ba((g*3|0|0)/4|0,o)|0)+48|0;do{if((k|0)==(m|0)){c[b+140>>2]=7}else{if((k|0)==(q|0)){c[b+140>>2]=17;break}yDb(b,16,2054792,(o=i,i=i+16|0,c[o>>2]=k,c[o+8>>2]=m,o)|0);i=o;u=-1094995529;i=h;return u|0}}while(0);m=_$a(b,l,0)|0;if((m|0)<0){u=m;i=h;return u|0}m=c[e>>2]|0;l=c[e+4>>2]|0;b=c[e+8>>2]|0;a:do{if((k|0)==(q|0)){o=(c[p>>2]<<1)+2&-4;g=e+32|0;if((k|0)<=0){break}r=c[g>>2]|0;v=0;w=m+(ba(c[n>>2]|0,r)|0)|0;x=r;while(1){r=w+(-x|0)|0;UGb(r|0,j+v|0,o)|0;y=v+o|0;if((y|0)>=(k|0)){break a}v=y;w=r;x=c[g>>2]|0}}else{g=e+32|0;if((ba(c[g>>2]|0,c[n>>2]|0)|0)<=0){break}x=e+36|0;w=e+40|0;v=0;o=0;r=48;y=0;while(1){z=a[j+r|0]|0;A=z&-16;a[l+o|0]=A;B=(z&255)<<4;a[m+y|0]=B;z=a[j+(r+1)|0]|0;C=z&-16;a[b+v|0]=C;D=(d[s+(z&15)|0]|0)+B|0;a[m+(y+1)|0]=D;B=d[j+(r+2)|0]|0;z=(d[s+(B&15)|0]|0)+D|0;a[m+(y+2)|0]=z;D=z+(d[s+(B>>>4)|0]|0)&255;a[m+(y+3)|0]=D;B=c[p>>2]|0;z=(B|0)/4|0;E=y+4|0;F=r+3|0;G=z-1|0;H=o+1|0;I=v+1|0;if((G|0)==0){J=E;K=F;L=H;M=I;N=B}else{B=v+z|0;O=z*3|0;P=z<<2;Q=D;D=A;A=C;C=r;R=y;S=E;E=F;F=G;G=H;H=I;while(1){I=d[j+E|0]|0;T=(a[t+(I>>>4)|0]|0)+D&255;a[l+G|0]=T;U=(a[s+(I&15)|0]|0)+Q&255;a[m+S|0]=U;I=d[j+(C+4)|0]|0;V=(a[j+(I>>>4|32)|0]|0)+A&255;a[b+H|0]=V;W=(a[s+(I&15)|0]|0)+U&255;a[m+(R+5)|0]=W;U=d[j+(C+5)|0]|0;I=(a[s+(U&15)|0]|0)+W&255;a[m+(R+6)|0]=I;W=I+(a[s+(U>>>4)|0]|0)&255;a[m+(R+7)|0]=W;U=F-1|0;if((U|0)==0){break}else{Q=W;D=T;A=V;C=E;R=S;S=S+4|0;E=E+3|0;F=U;G=G+1|0;H=H+1|0}}J=y+P|0;K=r+O|0;L=o+z|0;M=B;N=c[p>>2]|0}H=c[g>>2]|0;G=H+J-N|0;F=(N|0)/-4|0;if((G|0)<(ba(H,c[n>>2]|0)|0)){v=F+M+(c[w>>2]|0)|0;o=(c[x>>2]|0)+L+F|0;r=K;y=G}else{break}}}}while(0);c[f>>2]=1;u=k;i=h;return u|0}function B0(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;j=e>>>0>g>>>0?g:e;e=c;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=fe(k|0)|0;l=k&65535;if((e|0)==536864768|(e|0)==(-14745368|0)){m=(g|0)<0?0:f;g=0;n=j+1>>1;do{if((n|0)>0){a:do{if((k|0)==15269663){o=m;p=32;q=c;r=1;s=0;t=l;while(1){u=(de(t|0)|0)&16383;if((p|0)>14){v=p-14|0;w=s<<14|u;y=o}else{z=o;x=fe(u>>>((14-p|0)>>>0)|s<<p|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;v=p+18|0;w=u;y=o+4|0}g=w;u=q+2|0;if((r|0)>=(n|0)){A=y;B=v;C=w;break a}z=u;o=y;p=v;q=u;r=r+1|0;s=w;t=(d[z]|d[z+1|0]<<8)<<16>>16}}else{t=m;s=32;r=c;q=1;p=0;o=l;while(1){z=o&16383;if((s|0)>14){D=s-14|0;E=p<<14|z;F=t}else{u=t;x=fe(z>>>((14-s|0)>>>0)|p<<s|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;D=s+18|0;E=z;F=t+4|0}g=E;z=r+2|0;if((q|0)>=(n|0)){A=F;B=D;C=E;break a}u=z;t=F;s=D;r=z;q=q+1|0;p=E;o=(d[u]|d[u+1|0]<<8)<<16>>16}}}while(0);if((B|0)>=32){G=A;break}o=C<<B;g=o;p=((31-B|0)>>>3)+1|0;q=o>>>24&255;o=B;r=A;while(1){a[r]=q;s=g;g=s<<8;t=o+8|0;if((t|0)<32){q=s>>>16&255;o=t;r=r+1|0}else{break}}G=A+p|0}else{G=m}}while(0);g=0;H=G-m<<3>>3;i=h;return H|0}else if((e|0)==2147385345){UGb(f|0,c|0,j)|0;H=j;i=h;return H|0}else if((e|0)==(-25230976|0)){e=j+1>>1;if((e|0)>0){I=1;J=c;K=f;L=l}else{H=j;i=h;return H|0}while(1){l=J+2|0;b[K>>1]=de(L|0)|0;if((I|0)>=(e|0)){H=j;break}I=I+1|0;J=l;K=K+2|0;L=b[l>>1]|0}i=h;return H|0}else{H=-1094995529;i=h;return H|0}return 0}function C0(a){a=a|0;c[(c[a>>2]|0)+40>>2]=0;return 0}function D0(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=i;i=i+48|0;l=k|0;m=k+32|0;n=k+40|0;c[m>>2]=h;c[n>>2]=j;o=c[b>>2]|0;do{if((c[b+176>>2]&1|0)==0){p=o;q=o+20|0;r=c[q>>2]|0;s=o+16|0;t=c[s>>2]|0;a:do{if((r|0)==0){if((j|0)<=0){u=t;v=0;w=31;break}x=j-2|0;y=o+40|0;z=0;A=t;while(1){B=d[h+z|0]|A<<8;do{if((B|0)==(-14745368|0)){if((z|0)>=(x|0)){break}if(!((a[h+(z+1)|0]&-16)<<24>>24==-16)){break}if((a[h+(z+2)|0]|0)==7){w=12}}else if((B|0)==536864768){if((z|0)>=(x|0)){break}if((a[h+(z+1)|0]|0)!=7){break}if((a[h+(z+2)|0]&-16)<<24>>24==-16){w=12}}else if((B|0)==(-25230976|0)|(B|0)==2147385345|(B|0)==1683496997){w=12}}while(0);if((w|0)==12){w=0;C=c[y>>2]|0;if((B|0)==(C|0)){break}if((C|0)==1683496997|(C|0)==0){break}}C=z+1|0;if((C|0)<(j|0)){z=C;A=B}else{u=B;v=0;w=31;break a}}c[y>>2]=B;D=B;E=z+1|0;F=1;w=16}else{D=t;E=0;F=r;w=16}}while(0);b:do{if((w|0)==16){if((E|0)>=(j|0)){u=D;v=F;w=31;break}r=o+44|0;t=o+52|0;A=o+40|0;x=o+48|0;C=j-2|0;G=E;H=D;I=c[r>>2]|0;c:while(1){J=I+1|0;c[r>>2]=J;K=d[h+G|0]|H<<8;do{if((K|0)==1683496997){if((c[t>>2]|0)!=0){w=27;break}c[t>>2]=J;w=27}else if((K|0)==536864768){if((G|0)>=(C|0)){break}if((a[h+(G+1)|0]|0)!=7){break}if((a[h+(G+2)|0]&-16)<<24>>24==-16){w=27}}else if((K|0)==(-14745368|0)){if((G|0)>=(C|0)){break}if(!((a[h+(G+1)|0]&-16)<<24>>24==-16)){break}if((a[h+(G+2)|0]|0)==7){w=27}}else if((K|0)==(-25230976|0)|(K|0)==2147385345){w=27}}while(0);do{if((w|0)==27){w=0;L=c[A>>2]|0;if(!((K|0)==(L|0)|(L|0)==1683496997)){break}if((c[x>>2]|0)<=(J|0)){break c}}}while(0);L=G+1|0;if((L|0)<(j|0)){G=L;H=K;I=J}else{u=K;v=F;w=31;break b}}c[q>>2]=0;c[s>>2]=-1;c[r>>2]=0;M=G-3|0}}while(0);if((w|0)==31){c[q>>2]=v;c[s>>2]=u;M=-100}if((WRa(p,M,m,n)|0)>=0){N=M;O=c[m>>2]|0;P=c[n>>2]|0;break}c[f>>2]=0;c[g>>2]=0;Q=c[n>>2]|0;i=k;return Q|0}else{N=j;O=h;P=j}}while(0);j=o+48|0;o=l|0;TGb(o|0,0,28)|0;do{if((P|0)<12){w=41}else{if((B0(O,12,o,12)|0)<0){w=41;break}h=l+4|0;M=((fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)>>>18&127)+1|0;if(M>>>0<8>>>0){w=41;break}h=l+5|0;u=((fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)>>>12&16383)+1|0;c[j>>2]=u;if(u>>>0<95>>>0){w=41;break}u=l+8|0;h=c[1744272+(((d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>2&15)<<2)>>2]|0;if((h|0)==0){w=41;break}c[b+304>>2]=((M|0)/8|0)<<8;c[e+412>>2]=h}}while(0);if((w|0)==41){c[b+304>>2]=0}c[f>>2]=c[m>>2];c[g>>2]=c[n>>2];Q=N;i=k;return Q|0}function E0(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=c[f+60>>2]|0;c[g+4>>2]=f;if(!(a[1405392]|0)){c[2187372]=1;c[2187381]=2;h=0;i=0;while(1){j=i&65535;c[8749532+(h*20|0)>>2]=8655e3+(j<<2);k=h+1|0;l=b[1405136+(k<<1)>>1]|0;c[8749540+(h*20|0)>>2]=(l&65535)-j;N_(8749528+(h*20|0)|0,d[1689888+h|0]|0,12,1690016+(h*12|0)|0,1,1,1689896+(h*24|0)|0,2,2,0,0,0,4)|0;if((k|0)<5){h=k;i=l}else{break}}c[2163700]=-64;c[2163709]=2;i=0;h=1794;do{l=h&65535;c[8654844+(i*20|0)>>2]=8655e3+(l<<2);h=b[1405136+(i+6<<1)>>1]|0;c[8654852+(i*20|0)>>2]=(h&65535)-l;N_(8654840+(i*20|0)|0,9,129,474784+(i*129|0)|0,1,1,473488+(i*258|0)|0,2,2,0,0,0,4)|0;i=i+1|0;}while((i|0)<5);c[2163100]=0;c[2163109]=1;c[2163111]=8676456;c[2163113]=8;N_(8652440,3,4,186256,1,1,186224,2,2,0,0,0,4)|0;c[2163116]=8676488;c[2163118]=8;N_(8652460,3,4,186260,1,1,186232,2,2,0,0,0,4)|0;c[2163121]=8676520;c[2163123]=8;N_(8652480,3,4,186264,1,1,186240,2,2,0,0,0,4)|0;c[2163126]=8676552;c[2163128]=4;N_(8652500,2,4,186268,1,1,186248,2,2,0,0,0,4)|0;i=0;h=14;while(1){l=1685432+i|0;k=i+1|0;j=8652600+(k*200|0)|0;m=8652636+(k*200|0)|0;n=1685416+i|0;o=0;p=h;while(1){q=c[1685520+(i<<5)+(o<<2)>>2]|0;if((q|0)==0){r=p;break}c[j>>2]=a[l]|0;c[m>>2]=(o|0)>4?2:1;s=e[1405136+(p<<1)>>1]|0;c[8652640+(k*200|0)+(o*20|0)+4>>2]=8655e3+(s<<2);t=p+1|0;c[8652640+(k*200|0)+(o*20|0)+12>>2]=(e[1405136+(t<<1)>>1]|0)-s;N_(8652640+(k*200|0)+(o*20|0)|0,d[1685448+(i*7|0)+o|0]|0,d[n]|0,c[1685840+(i<<5)+(o<<2)>>2]|0,1,1,q,2,2,0,0,0,4)|0;q=o+1|0;if((q|0)<7){o=q;p=t}else{r=t;break}}if((k|0)<10){i=k;h=r}else{break}}a[1405392]=1}fCb(g+291844|0,c[f+88>>2]&8388608);aLa(g+291880|0,6,1,1.0)|0;$Za(g+291944|0);L0(g+291948|0);iba(g+291964|0,f);c[f+420>>2]=8;if((c[f+440>>2]|0)==2){g=f+456|0;c[g>>2]=3;c[g+4>>2]=0}g=f+416|0;if((c[g>>2]|0)<=2){return 0}r=f+456|0;if(!((c[r>>2]|0)==3&(c[r+4>>2]|0)==0)){return 0}c[g>>2]=2;return 0}function F0(b,f,h,j){b=b|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0.0,$c=0.0,ad=0,bd=0,cd=0,dd=0,ed=0;k=i;i=i+6432|0;l=k|0;m=k+32|0;n=k+4128|0;o=k+4256|0;p=k+6304|0;q=k+6336|0;r=k+6352|0;s=k+6368|0;t=k+6400|0;u=f;v=c[j+24>>2]|0;w=c[j+28>>2]|0;j=c[b+60>>2]|0;x=j;y=j+290800|0;c[y>>2]=0;z=j+269256|0;A=B0(v,w,z,20480)|0;v=j+290760|0;c[v>>2]=A;if((A|0)==-1094995529){yDb(b,16,2190920,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=k;return C|0}D=A<<3;A=D>>>0>2147483639>>>0|(z|0)==0;E=A?0:z;z=A?0:D;D=j+290768|0;A=j+290780|0;G=z+8|0;H=j+290784|0;I=j+290776|0;c[D>>2]=E;c[A>>2]=z;c[H>>2]=G;c[j+290772>>2]=E+(z>>3);z=(G|0)<32?G:32;c[I>>2]=z;J=E+(z>>>3)|0;K=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>7&1;J=z|1;z=G>>>0>J>>>0?J:G;c[I>>2]=z;c[j+8>>2]=K;K=E+(z>>>3)|0;J=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(z&7)>>>27;K=z+5|0;z=G>>>0>K>>>0?K:G;c[I>>2]=z;c[j+12>>2]=J+1;J=E+(z>>>3)|0;K=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(z&7)>>>31;J=z+1|0;z=G>>>0>J>>>0?J:G;c[I>>2]=z;c[j+16>>2]=K;J=E+(z>>>3)|0;L=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(z&7)>>>25;J=z+7|0;z=G>>>0>J>>>0?J:G;c[I>>2]=z;J=j+20|0;c[J>>2]=L+1;L=E+(z>>>3)|0;M=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(z&7)>>>18;L=z+14|0;z=G>>>0>L>>>0?L:G;c[I>>2]=z;L=M+1|0;M=j+24|0;c[M>>2]=L;if(L>>>0<95>>>0){C=-1094995529;i=k;return C|0}L=E+(z>>>3)|0;N=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(z&7)>>>26;L=z+6|0;z=G>>>0>L>>>0?L:G;c[I>>2]=z;L=j+28|0;c[L>>2]=N;O=E+(z>>>3)|0;P=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(z&7)>>>28;O=z+4|0;z=G>>>0>O>>>0?O:G;c[I>>2]=z;O=c[1744272+(P<<2)>>2]|0;P=j+32|0;c[P>>2]=O;if((O|0)==0){C=-1094995529;i=k;return C|0}O=E+(z>>>3)|0;Q=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(z&7)>>>27;O=z+5|0;c[j+40>>2]=Q;z=j+36|0;c[z>>2]=c[1407792+(Q<<2)>>2];Q=(G>>>0>O>>>0?O:G)+1|0;O=G>>>0>Q>>>0?Q:G;c[I>>2]=O;Q=E+(O>>>3)|0;R=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>31;Q=O+1|0;O=G>>>0>Q>>>0?Q:G;c[I>>2]=O;c[j+44>>2]=R;R=E+(O>>>3)|0;Q=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>31;R=O+1|0;O=G>>>0>R>>>0?R:G;c[I>>2]=O;c[j+48>>2]=Q;Q=E+(O>>>3)|0;R=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>31;Q=O+1|0;O=G>>>0>Q>>>0?Q:G;c[I>>2]=O;c[j+52>>2]=R;R=E+(O>>>3)|0;Q=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>31;R=O+1|0;O=G>>>0>R>>>0?R:G;c[I>>2]=O;c[j+56>>2]=Q;Q=E+(O>>>3)|0;R=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>29;Q=O+3|0;O=G>>>0>Q>>>0?Q:G;c[I>>2]=O;Q=j+60|0;c[Q>>2]=R;R=E+(O>>>3)|0;S=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>31;R=O+1|0;O=G>>>0>R>>>0?R:G;c[I>>2]=O;R=j+64|0;c[R>>2]=S;S=E+(O>>>3)|0;T=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(O&7)>>>31;S=O+1|0;O=G>>>0>S>>>0?S:G;c[I>>2]=O;S=j+68|0;c[S>>2]=T;T=E+(O>>>3)|0;U=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(O&7)>>>30;T=O+2|0;O=G>>>0>T>>>0?T:G;c[I>>2]=O;T=j+72|0;c[T>>2]=U;V=E+(O>>>3)|0;W=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(O&7)>>>31;V=O+1|0;O=G>>>0>V>>>0?V:G;c[I>>2]=O;c[j+76>>2]=W;if((U|0)==3){c[T>>2]=0;yDb(c[j+4>>2]|0,16,2040048,(B=i,i=i+8|0,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=k;return C|0}if((K|0)==0){X=O}else{K=E+(O>>>3)|0;W=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(O&7)>>>16;K=O+16|0;O=G>>>0>K>>>0?K:G;c[I>>2]=O;c[j+80>>2]=W;X=O}O=E+(X>>>3)|0;W=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(X&7)>>>31;O=X+1|0;X=G>>>0>O>>>0?O:G;c[I>>2]=X;O=j+84|0;c[O>>2]=W;W=E+(X>>>3)|0;K=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(X&7)>>>28;W=X+4|0;X=G>>>0>W>>>0?W:G;c[I>>2]=X;c[j+88>>2]=K;K=E+(X>>>3)|0;W=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(X&7)>>>30;K=X+2|0;X=G>>>0>K>>>0?K:G;c[I>>2]=X;c[j+92>>2]=W;W=E+(X>>>3)|0;K=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(X&7)>>>29;W=X+3|0;X=G>>>0>W>>>0?W:G;c[I>>2]=X;W=j+96|0;c[W>>2]=K;K=E+(X>>>3)|0;V=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(X&7)>>>31;K=X+1|0;X=G>>>0>K>>>0?K:G;c[I>>2]=X;c[j+100>>2]=V;V=E+(X>>>3)|0;K=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(X&7)>>>31;V=X+1|0;X=G>>>0>V>>>0?V:G;c[I>>2]=X;c[j+104>>2]=K;K=E+(X>>>3)|0;V=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(X&7)>>>28;K=X+4|0;X=G>>>0>K>>>0?K:G;c[I>>2]=X;c[j+108>>2]=V;V=j+39776|0;c[V>>2]=(U|0)==0?N:N|128;N=E+(X>>>3)|0;E=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(X&7)>>>28;N=X+4|0;c[I>>2]=G>>>0>N>>>0?N:G;c[j+112>>2]=E+1;I0(x,0,0);c[b+412>>2]=c[P>>2];c[b+72>>2]=c[z>>2];z=j+291836|0;c[z>>2]=20;P=0;while(1){if((P|0)>=((c[J>>2]|0)/8|0|0)){break}Y=H0(x,0,P)|0;if((Y|0)==0){P=P+1|0}else{Z=12;break}}if((Z|0)==12){yDb(b,16,2113408,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=Y;i=k;return C|0}Y=j+120|0;P=c[Y>>2]|0;E=((c[T>>2]|0)!=0)+P|0;a:do{if((E|0)>2){G=b+456|0;if(!((c[G>>2]|0)==3&(c[G+4>>2]|0)==0)){break}do{if((a[j+14852|0]|0)!=0){G=j+14853|0;N=a[G]|0;if(!((N<<24>>24|0)==2|(N<<24>>24|0)==4)){break}if((E|0)>0){X=j+14854|0;U=j+14784|0;K=0;do{_=e[X+(K<<3)>>1]|0;$=_&255;if(($|0)==0){aa=0.0}else{aa=+((_>>>7&2)-1|0)*+g[1405432+($-1<<2)>>2]}g[U+(K<<3)>>2]=aa;$=e[X+(K<<3)+2>>1]|0;_=$&255;if((_|0)==0){ca=0.0}else{ca=+(($>>>7&2)-1|0)*+g[1405432+(_-1<<2)>>2]}g[U+(K<<3)+4>>2]=ca;K=K+1|0;}while((K|0)<(((c[T>>2]|0)!=0)+(c[Y>>2]|0)|0));da=a[G]|0}else{da=N}c[V>>2]=da&255;break a}}while(0);K=c[L>>2]&63;if(K>>>0>9>>>0){yDb(c[j+4>>2]|0,16,2054760,(B=i,i=i+8|0,c[B>>2]=K,B)|0);i=B;C=-1094995529;i=k;return C|0}if(E>>>0>6>>>0){DDb(c[j+4>>2]|0,2008856,(B=i,i=i+8|0,c[B>>2]=E,B)|0);i=B;C=-1163346256;i=k;return C|0}if((E|0)<=0){break}U=j+14784|0;X=0;do{g[U+(X<<3)>>2]=+g[1406400+(K*48|0)+(X<<3)>>2];g[U+(X<<3)+4>>2]=+g[1406400+(K*48|0)+(X<<3)+4>>2];X=X+1|0;}while((X|0)<(((c[T>>2]|0)!=0)+(c[Y>>2]|0)|0))}}while(0);if((c[R>>2]|0)==0){c[j+290796>>2]=0;ea=0}else{R=c[1405400+(c[Q>>2]<<2)>>2]|0;c[j+290796>>2]=R;ea=R}R=c[M>>2]|0;Q=c[v>>2]|0;E=((R|0)>(Q|0)?Q:R)<<3;R=j+290796|0;do{if((ea&-2147483638|0)==0){Q=c[I>>2]|0;da=E-Q|0;X=-Q|0;K=(c[H>>2]|0)-Q|0;if((da|0)<(X|0)){fa=X}else{fa=(K|0)<(da|0)?K:da}da=fa+Q|0;c[I>>2]=da;ga=ea;ha=da}else{da=(ea|0)>0?ea:0;c[R>>2]=da;Q=c[I>>2]|0;K=-Q|0;X=K&31;U=c[H>>2]|0;_=U-Q|0;if((X|0)<(K|0)){ia=K}else{ia=(_|0)<(X|0)?_:X}X=ia+Q|0;c[I>>2]=X;if((E-X|0)<=31){ga=da;ha=X;break}da=j+290804|0;Q=b;_=X;X=U;while(1){U=c[D>>2]|0;K=U+(_>>>3)|0;$=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(_&7)&-65536;K=_+16|0;ja=X>>>0>K>>>0?K:X;c[I>>2]=ja;K=U+(ja>>>3)|0;ka=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(ja&7)>>>16;K=ja+16|0;ja=X>>>0>K>>>0?K:X;c[I>>2]=ja;K=ka|$;do{if((K|0)==496366178){$=U+(ja>>>3)|0;ka=((fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ja&7)>>>20)+1|0;if((c[M>>2]|0)!=((ja>>3)-4+ka|0)){break}yDb(Q,48,1896824,(B=i,i=i+8|0,c[B>>2]=ja,B)|0);i=B;$=c[H>>2]|0;la=(c[I>>2]|0)+12|0;c[I>>2]=$>>>0>la>>>0?la:$;yDb(Q,48,2353936,(B=i,i=i+8|0,c[B>>2]=ka,B)|0);i=B;ka=c[I>>2]|0;$=c[H>>2]|0;la=(c[D>>2]|0)+(ka>>>3)|0;ma=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ka&7)>>>28;la=ka+4|0;c[I>>2]=$>>>0>la>>>0?la:$;yDb(Q,48,2333904,(B=i,i=i+8|0,c[B>>2]=ma,B)|0);i=B;c[R>>2]=c[R>>2]|4;Z=57}else if((K|0)==1191201283){c[R>>2]=c[R>>2]|2;J0(x);Z=57}else if((K|0)==1515870810){ma=c[Y>>2]|0;c[da>>2]=ma;$=U+(ja>>>3)|0;la=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ja&7)>>>22;$=c[M>>2]|0;ka=(ja>>3)-4+la|0;if(!(($|0)==(ka|0)|($|0)==(ka+1|0))){break}ka=ja+10|0;$=X>>>0>ka>>>0?ka:X;c[I>>2]=$;c[R>>2]=c[R>>2]|8;ka=U+($>>>3)|0;la=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<($&7)>>>28;ka=$+4|0;c[I>>2]=X>>>0>ka>>>0?ka:X;if((la|0)!=1){yDb(Q,16,1970472,(B=i,i=i+8|0,c[B>>2]=la,B)|0);i=B;break}if((ma|0)<2){DDb(Q,1941776,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}I0(x,ma,0);if((c[J>>2]|0)>7){ma=0;do{if((H0(x,c[da>>2]|0,ma)|0)!=0){yDb(Q,16,1917568,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}ma=ma+1|0;}while((ma|0)<((c[J>>2]|0)/8|0|0))}c[y>>2]=1;Z=57}else{Z=57}}while(0);if((Z|0)==57){Z=0;U=c[I>>2]|0;ja=-U|0;K=ja&31;N=(c[H>>2]|0)-U|0;if((K|0)<(ja|0)){na=ja}else{na=(N|0)<(K|0)?N:K}c[I>>2]=na+U}oa=c[I>>2]|0;if((E-oa|0)<=31){break}_=oa;X=c[H>>2]|0}ga=c[R>>2]|0;ha=oa}}while(0);do{if((ga&4|0)==0){if((ga&10|0)==0){break}c[z>>2]=30}else{c[z>>2]=40}}while(0);b:do{if(((c[v>>2]|0)-(c[M>>2]|0)|0)>32){ga=c[H>>2]|0;oa=c[D>>2]|0;E=oa+(ha>>>3)|0;na=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(ha&7)&-65536;E=ha+16|0;ia=ga>>>0>E>>>0?E:ga;c[I>>2]=ia;E=oa+(ia>>>3)|0;ea=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(ia&7)>>>16;E=ia+16|0;ia=ga>>>0>E>>>0?E:ga;c[I>>2]=ia;if((ea|na|0)!=1683496997){break}if(((c[A>>2]|0)-ia|0)<52){break}na=ia+8|0;ea=ga>>>0>na>>>0?na:ga;c[I>>2]=ea;na=oa+(ea>>>3)|0;E=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ea&7)>>>30;na=ea+2|0;ea=ga>>>0>na>>>0?na:ga;c[I>>2]=ea;na=d[oa+(ea>>>3)|0]<<(ea&7)>>>7;fa=((ea|0)<(ga|0))+ea|0;c[I>>2]=fa;ea=na<<2&4;na=ea|8;X=oa+(fa>>>3)|0;_=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(fa&7)>>>((32-na|0)>>>0);X=na+fa|0;fa=ea|16;ea=(ga>>>0>X>>>0?X:ga)+fa|0;X=ga>>>0>ea>>>0?ea:ga;c[I>>2]=X;ea=d[oa+(X>>>3)|0]<<(X&7)>>>7;na=((X|0)<(ga|0))+X|0;c[I>>2]=na;X=ea&1;ea=j+291808|0;c[ea>>2]=X;do{if((X|0)==0){pa=1;qa=na;ra=ga;sa=oa}else{Q=na+2|0;da=(ga>>>0>Q>>>0?Q:ga)+3|0;Q=ga>>>0>da>>>0?da:ga;c[I>>2]=Q;da=d[oa+(Q>>>3)|0]|0;U=((Q|0)<(ga|0))+Q|0;c[I>>2]=U;if((da&128>>>((Q&7)>>>0)|0)==0){ta=U}else{Q=-U|0;da=ga-U|0;if((Q|0)>36){ua=Q}else{ua=(da|0)<36?da:36}da=ua+U|0;c[I>>2]=da;ta=da}da=oa+(ta>>>3)|0;U=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ta&7)>>>29;da=ta+3|0;Q=ga>>>0>da>>>0?da:ga;c[I>>2]=Q;da=U+1|0;if(da>>>0>1>>>0){DDb(c[j+4>>2]|0,2231952,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}U=oa+(Q>>>3)|0;K=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(Q&7)>>>29;U=Q+3|0;Q=ga>>>0>U>>>0?U:ga;c[I>>2]=Q;U=K+1|0;if(U>>>0>1>>>0){DDb(c[j+4>>2]|0,2219624,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}K=E+1|0;N=E^31;ja=0;G=Q;while(1){Q=oa+(G>>>3)|0;ma=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(G&7)>>>(N>>>0);Q=K+G|0;la=ga>>>0>Q>>>0?Q:ga;c[I>>2]=la;c[t+(ja<<2)>>2]=ma;ma=ja+1|0;if((ma|0)<(da|0)){ja=ma;G=la}else{va=0;wa=la;break}}while(1){G=c[t+(va<<2)>>2]|0;ja=0;K=wa;while(1){if((1<<ja&G|0)==0){xa=K}else{N=K+8|0;la=ga>>>0>N>>>0?N:ga;c[I>>2]=la;xa=la}la=ja+1|0;if((la|0)>(E|0)){break}else{ja=la;K=xa}}K=va+1|0;if((K|0)<(da|0)){va=K;wa=xa}else{break}}da=d[oa+(xa>>>3)|0]<<(xa&7)>>>7;K=((xa|0)<(ga|0))+xa|0;c[I>>2]=K;ja=da&1;c[j+291812>>2]=ja;if((ja|0)==0){pa=U;qa=K;ra=ga;sa=oa;break}ja=K+2|0;K=ga>>>0>ja>>>0?ja:ga;c[I>>2]=K;ja=oa+(K>>>3)|0;da=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(K&7)>>>30;ja=K+2|0;K=ga>>>0>ja>>>0?ja:ga;c[I>>2]=K;ja=da<<2;da=ja+4|0;G=oa+(K>>>3)|0;la=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(K&7)>>>30;G=K+2|0;K=ga>>>0>G>>>0?G:ga;c[I>>2]=K;G=j+291816|0;c[G>>2]=la+1;la=28-ja|0;ja=0;N=K;K=ga;ma=oa;while(1){Q=ma+(N>>>3)|0;ka=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(N&7)>>>(la>>>0);Q=da+N|0;c[I>>2]=K>>>0>Q>>>0?Q:K;Q=ka-(ka>>>1&1431655765)|0;$=(Q>>>2&858993459)+(Q&858993459)|0;Q=($>>>4)+$&252645135;$=(Q>>>8)+Q|0;Q=ka&44646;ka=Q-(Q>>>1&21777)|0;Q=(ka>>>2&858993459)+(ka&858993459)|0;ka=(Q>>>4)+Q&252645135;Q=(ka>>>8)+ka|0;c[x+291820+(ja<<2)>>2]=((Q>>>16)+Q&63)+(($>>>16)+$&63);$=ja+1|0;Q=c[I>>2]|0;ka=c[H>>2]|0;ya=c[D>>2]|0;if(($|0)<(c[G>>2]|0)){ja=$;N=Q;K=ka;ma=ya}else{pa=U;qa=Q;ra=ka;sa=ya;break}}}}while(0);oa=32-fa|0;ga=0;E=qa;do{na=sa+(E>>>3)|0;X=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(E&7)>>>(oa>>>0);na=E+fa|0;E=ra>>>0>na>>>0?na:ra;c[I>>2]=E;c[s+(ga<<2)>>2]=X;ga=ga+1|0;}while((ga|0)<(pa|0));ga=j+291812|0;fa=j+4|0;oa=j+291816|0;X=1;na=E;while(1){U=c[A>>2]|0;if((U-na|0)<16){break b}ma=c[H>>2]|0;K=c[D>>2]|0;N=K+(na>>>3)|0;ja=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(na&7)>>>23;N=na+9|0;G=(ma>>>0>N>>>0?N:ma)+3|0;N=ma>>>0>G>>>0?G:ma;c[I>>2]=N;do{if((c[ea>>2]|0)==0){za=0;Aa=0;Ba=0;Ca=N}else{G=((N|0)<(ma|0))+N|0;if((d[K+(N>>>3)|0]&128>>>((N&7)>>>0)|0)==0){Da=G}else{da=G+4|0;Da=ma>>>0>da>>>0?da:ma}c[I>>2]=Da;da=d[K+(Da>>>3)|0]|0;G=((Da|0)<(ma|0))+Da|0;c[I>>2]=G;if((da&128>>>((Da&7)>>>0)|0)==0){Ea=G}else{da=-G|0;la=ma-G|0;if((da|0)>24){Fa=da}else{Fa=(la|0)<24?la:24}la=Fa+G|0;c[I>>2]=la;Ea=la}la=d[K+(Ea>>>3)|0]|0;G=((Ea|0)<(ma|0))+Ea|0;c[I>>2]=G;if((la&128>>>((Ea&7)>>>0)|0)==0){Ga=G}else{la=K+(G>>>3)|0;da=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(G&7)>>>22;la=G+10|0;G=ma>>>0>la>>>0?la:ma;c[I>>2]=G;la=(da<<3)+8|0;if((U-G|0)<(la|0)){break b}da=-G|0;ya=ma-G|0;if((la|0)<(da|0)){Ha=da}else{Ha=(ya|0)<(la|0)?ya:la}la=Ha+G|0;c[I>>2]=la;Ga=la}la=Ga+5|0;G=(ma>>>0>la>>>0?la:ma)+4|0;la=ma>>>0>G>>>0?G:ma;c[I>>2]=la;G=K+(la>>>3)|0;ya=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(la&7)>>>24;G=la+8|0;la=ma>>>0>G>>>0?G:ma;c[I>>2]=la;G=ya+1|0;ya=d[K+(la>>>3)|0]|0;da=((la|0)<(ma|0))+la|0;c[I>>2]=da;if((128>>>((la&7)>>>0)&ya|0)==0){ya=da+3|0;la=ma>>>0>ya>>>0?ya:ma;c[I>>2]=la;za=G;Aa=0;Ba=0;Ca=la;break}do{if(G>>>0>2>>>0){la=d[K+(da>>>3)|0]<<(da&7)>>>7;ya=((da|0)<(ma|0))+da|0;c[I>>2]=ya;ka=la&1;if(!(G>>>0>6>>>0)){Ia=0;Ja=ka;Ka=ya;break}la=d[K+(ya>>>3)|0]<<(ya&7)>>>7;Q=((ya|0)<(ma|0))+ya|0;c[I>>2]=Q;Ia=la&1;Ja=ka;Ka=Q}else{Ia=0;Ja=0;Ka=da}}while(0);da=d[K+(Ka>>>3)|0]|0;Q=((Ka|0)<(ma|0))+Ka|0;c[I>>2]=Q;if((da&128>>>((Ka&7)>>>0)|0)==0){La=16;Ma=Q}else{da=K+(Q>>>3)|0;ka=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Q&7)>>>30;da=Q+2|0;Q=(ka<<2)+4|0;ka=Q+(ma>>>0>da>>>0?da:ma)|0;da=ma>>>0>ka>>>0?ka:ma;c[I>>2]=da;La=Q;Ma=da}da=K+(Ma>>>3)|0;Q=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Ma&7)>>>29;da=Ma+3|0;ka=ma>>>0>da>>>0?da:ma;c[I>>2]=ka;if((Q|0)==0){za=G;Aa=Ja;Ba=Ia;Ca=ka;break}da=32-La|0;la=0;ya=ka;while(1){ka=K+(ya>>>3)|0;$=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ya&7)>>>(da>>>0);ka=ya+La|0;Na=ma>>>0>ka>>>0?ka:ma;c[I>>2]=Na;ka=$-($>>>1&1431655765)|0;Oa=(ka>>>2&858993459)+(ka&858993459)|0;ka=(Oa>>>4)+Oa&252645135;Oa=(ka>>>8)+ka|0;ka=$&44646;$=ka-(ka>>>1&21777)|0;ka=($>>>2&858993459)+($&858993459)|0;$=(ka>>>4)+ka&252645135;ka=($>>>8)+$|0;c[l+(la<<2)>>2]=((ka>>>16)+ka&63)+((Oa>>>16)+Oa&63);Oa=la+1|0;if((Oa|0)<(Q|0)){la=Oa;ya=Na}else{Pa=0;Qa=Na;break}}while(1){ya=K+(Qa>>>3)|0;la=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(Qa&7)>>>27;ya=Qa+5|0;da=ma>>>0>ya>>>0?ya:ma;c[I>>2]=da;ya=la+1|0;if((U-da|0)<0){break b}Na=c[l+(Pa<<2)>>2]|0;if((Na|0)>0){Oa=ya>>>0<26>>>0;ka=la^31;$=la-15|0;Ra=47-la|0;la=0;Sa=da;while(1){Ta=K+(Sa>>>3)|0;Ua=(fe(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(Sa&7);if(Oa){Ta=Sa+ya|0;Va=ma>>>0>Ta>>>0?Ta:ma;c[I>>2]=Va;Wa=Ua>>>(ka>>>0);Xa=Va}else{Va=Sa+16|0;Ta=ma>>>0>Va>>>0?Va:ma;c[I>>2]=Ta;Va=K+(Ta>>>3)|0;Ya=(fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)>>>(Ra>>>0);Va=Ta+$|0;Ta=ma>>>0>Va>>>0?Va:ma;c[I>>2]=Ta;Wa=Ya|Ua>>>16<<$;Xa=Ta}Ta=Wa-(Wa>>>1&1431655765)|0;Ua=(Ta>>>2&858993459)+(Ta&858993459)|0;Ta=(Ua>>>4)+Ua&252645135;Ua=(Ta>>>8)+Ta|0;Ta=((Ua>>>16)+Ua&63)*5|0;Ua=-Xa|0;Ya=ma-Xa|0;if((Ta|0)<(Ua|0)){Za=Ua}else{Za=(Ya|0)<(Ta|0)?Ya:Ta}Ta=Za+Xa|0;c[I>>2]=Ta;Ya=la+1|0;if((Ya|0)<(Na|0)){la=Ya;Sa=Ta}else{_a=Ta;break}}}else{_a=da}Sa=Pa+1|0;if((Sa|0)<(Q|0)){Pa=Sa;Qa=_a}else{za=G;Aa=Ja;Ba=Ia;Ca=_a;break}}}}while(0);N=((Ca|0)<(ma|0))+Ca|0;G=(d[K+(Ca>>>3)|0]&128>>>((Ca&7)>>>0)|0)!=0;if(G){Q=N+8|0;$a=ma>>>0>Q>>>0?Q:ma}else{$a=N}c[I>>2]=$a;N=(($a|0)<(ma|0))+$a|0;if((d[K+($a>>>3)|0]&128>>>(($a&7)>>>0)|0)==0){ab=N}else{Q=N+5|0;ab=ma>>>0>Q>>>0?Q:ma}Q=(Aa|0)==0;if(Q|G^1){bb=ab}else{G=ab+8|0;bb=ma>>>0>G>>>0?G:ma}c[I>>2]=bb;c:do{if((c[ga>>2]|0)==0){cb=bb}else{G=d[K+(bb>>>3)|0]|0;N=((bb|0)<(ma|0))+bb|0;c[I>>2]=N;if((G&128>>>((bb&7)>>>0)|0)==0){cb=N;break}G=N+1|0;N=(ma>>>0>G>>>0?G:ma)+6|0;G=ma>>>0>N>>>0?N:ma;c[I>>2]=G;N=K+(G>>>3)|0;Sa=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(G&7);N=G+2|0;G=ma>>>0>N>>>0?N:ma;c[I>>2]=G;if((Sa&-1073741824|0)==-1073741824){Sa=G+8|0;db=ma>>>0>Sa>>>0?Sa:ma}else{Sa=G+3|0;db=ma>>>0>Sa>>>0?Sa:ma}c[I>>2]=db;Sa=d[K+(db>>>3)|0]|0;G=((db|0)<(ma|0))+db|0;c[I>>2]=G;N=c[oa>>2]|0;if((Sa&128>>>((db&7)>>>0)|0)==0){Sa=N*6|0;la=-G|0;Na=ma-G|0;if((Sa|0)<(la|0)){eb=la}else{eb=(Na|0)<(Sa|0)?Na:Sa}Sa=eb+G|0;c[I>>2]=Sa;fb=Sa}else{if((N|0)>0){gb=0;hb=G}else{cb=G;break}while(1){G=(c[x+291820+(gb<<2)>>2]|0)*6|0;Sa=-hb|0;Na=ma-hb|0;if((G|0)<(Sa|0)){ib=Sa}else{ib=(Na|0)<(G|0)?Na:G}G=ib+hb|0;c[I>>2]=G;Na=gb+1|0;if((Na|0)<(N|0)){gb=Na;hb=G}else{fb=G;break}}}if((N|0)<=0){cb=fb;break}G=(Ba|0)==0;if((za|0)>0){jb=0;kb=fb}else{Na=0;Sa=fb;while(1){if((U-Sa|0)<0){break b}la=x+291820+(Na<<2)|0;if(G){lb=Sa}else{$=c[la>>2]|0;Ra=32-$|0;ka=0;ya=Sa;while(1){Oa=K+(ya>>>3)|0;Ta=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(ya&7)>>>(Ra>>>0);Oa=ya+$|0;Ya=ma>>>0>Oa>>>0?Oa:ma;c[I>>2]=Ya;Oa=Ta-(Ta>>>1&1431655765)|0;Ta=(Oa>>>2&858993459)+(Oa&858993459)|0;Oa=(Ta>>>4)+Ta&252645135;Ta=(Oa>>>8)+Oa|0;Oa=((Ta>>>16)+Ta&63)*6|0;Ta=-Ya|0;Ua=ma-Ya|0;if((Oa|0)<(Ta|0)){mb=Ta}else{mb=(Ua|0)<(Oa|0)?Ua:Oa}Oa=mb+Ya|0;c[I>>2]=Oa;Ya=ka+1|0;if((Ya|0)<6){ka=Ya;ya=Oa}else{lb=Oa;break}}}if(Q){nb=lb}else{ya=c[la>>2]|0;ka=32-ya|0;$=K+(lb>>>3)|0;Ra=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(lb&7)>>>(ka>>>0);$=ya+lb|0;da=ma>>>0>$>>>0?$:ma;c[I>>2]=da;$=Ra-(Ra>>>1&1431655765)|0;Ra=($>>>2&858993459)+($&858993459)|0;$=(Ra>>>4)+Ra&252645135;Ra=($>>>8)+$|0;$=((Ra>>>16)+Ra&63)*6|0;Ra=-da|0;Oa=ma-da|0;if(($|0)<(Ra|0)){ob=Ra}else{ob=(Oa|0)<($|0)?Oa:$}$=ob+da|0;c[I>>2]=$;da=K+($>>>3)|0;Oa=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<($&7)>>>(ka>>>0);ka=$+ya|0;ya=ma>>>0>ka>>>0?ka:ma;c[I>>2]=ya;ka=Oa-(Oa>>>1&1431655765)|0;Oa=(ka>>>2&858993459)+(ka&858993459)|0;ka=(Oa>>>4)+Oa&252645135;Oa=(ka>>>8)+ka|0;ka=((Oa>>>16)+Oa&63)*6|0;Oa=-ya|0;$=ma-ya|0;if((ka|0)<(Oa|0)){pb=Oa}else{pb=($|0)<(ka|0)?$:ka}ka=pb+ya|0;c[I>>2]=ka;nb=ka}ka=Na+1|0;if((ka|0)<(N|0)){Na=ka;Sa=nb}else{cb=nb;break c}}}while(1){if((U-kb|0)<0){break b}Sa=x+291820+(jb<<2)|0;Na=c[Sa>>2]|0;ka=32-Na|0;ya=0;$=kb;do{Oa=K+($>>>3)|0;da=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<($&7)>>>(ka>>>0);Oa=$+Na|0;Ra=ma>>>0>Oa>>>0?Oa:ma;c[I>>2]=Ra;Oa=da-(da>>>1&1431655765)|0;da=(Oa>>>2&858993459)+(Oa&858993459)|0;Oa=(da>>>4)+da&252645135;da=(Oa>>>8)+Oa|0;Oa=((da>>>16)+da&63)*6|0;da=-Ra|0;Ya=ma-Ra|0;if((Oa|0)<(da|0)){qb=da}else{qb=(Ya|0)<(Oa|0)?Ya:Oa}$=qb+Ra|0;c[I>>2]=$;ya=ya+1|0;}while((ya|0)<(za|0));if(G){rb=$}else{ya=c[Sa>>2]|0;Na=32-ya|0;ka=0;la=$;while(1){Ra=K+(la>>>3)|0;Oa=(fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(la&7)>>>(Na>>>0);Ra=la+ya|0;Ya=ma>>>0>Ra>>>0?Ra:ma;c[I>>2]=Ya;Ra=Oa-(Oa>>>1&1431655765)|0;Oa=(Ra>>>2&858993459)+(Ra&858993459)|0;Ra=(Oa>>>4)+Oa&252645135;Oa=(Ra>>>8)+Ra|0;Ra=((Oa>>>16)+Oa&63)*6|0;Oa=-Ya|0;da=ma-Ya|0;if((Ra|0)<(Oa|0)){sb=Oa}else{sb=(da|0)<(Ra|0)?da:Ra}Ra=sb+Ya|0;c[I>>2]=Ra;Ya=ka+1|0;if((Ya|0)<6){ka=Ya;la=Ra}else{rb=Ra;break}}}if(Q){tb=rb}else{la=c[Sa>>2]|0;ka=32-la|0;ya=K+(rb>>>3)|0;Na=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(rb&7)>>>(ka>>>0);ya=la+rb|0;$=ma>>>0>ya>>>0?ya:ma;c[I>>2]=$;ya=Na-(Na>>>1&1431655765)|0;Na=(ya>>>2&858993459)+(ya&858993459)|0;ya=(Na>>>4)+Na&252645135;Na=(ya>>>8)+ya|0;ya=((Na>>>16)+Na&63)*6|0;Na=-$|0;Ra=ma-$|0;if((ya|0)<(Na|0)){ub=Na}else{ub=(Ra|0)<(ya|0)?Ra:ya}ya=ub+$|0;c[I>>2]=ya;$=K+(ya>>>3)|0;Ra=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ya&7)>>>(ka>>>0);ka=ya+la|0;la=ma>>>0>ka>>>0?ka:ma;c[I>>2]=la;ka=Ra-(Ra>>>1&1431655765)|0;Ra=(ka>>>2&858993459)+(ka&858993459)|0;ka=(Ra>>>4)+Ra&252645135;Ra=(ka>>>8)+ka|0;ka=((Ra>>>16)+Ra&63)*6|0;Ra=-la|0;ya=ma-la|0;if((ka|0)<(Ra|0)){vb=Ra}else{vb=(ya|0)<(ka|0)?ya:ka}ka=vb+la|0;c[I>>2]=ka;tb=ka}ka=jb+1|0;if((ka|0)<(N|0)){jb=ka;kb=tb}else{cb=tb;break}}}}while(0);Q=K+(cb>>>3)|0;N=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(cb&7)>>>30;Q=cb+2|0;G=ma>>>0>Q>>>0?Q:ma;c[I>>2]=G;if((N|0)==0){Q=K+(G>>>3)|0;ka=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(G&7)>>>20;Q=G+12|0;la=ma>>>0>Q>>>0?Q:ma;c[I>>2]=la;wb=ka;xb=la}else if((N|0)==1){wb=512;xb=G}else if((N|0)==2){wb=256;xb=G}else if((N|0)==3){wb=0;xb=G}else{wb=0;xb=G}G=-xb|0;if((U-xb|0)<0){break b}N=(ja<<3)+8|0;if((xb-na|0)>(N|0)){Z=180;break}la=N+na-xb|0;N=ma-xb|0;if((la|0)<(G|0)){yb=G}else{yb=(N|0)<(la|0)?N:la}c[I>>2]=yb+xb;do{if((wb&512|0)==0){if((wb&224|0)==0){break}c[z>>2]=50}else{c[z>>2]=60}}while(0);if((wb&1|0)==0){yDb(c[fa>>2]|0,24,2145568,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}ma=wb&14;ja=c[R>>2]|0;if((ma|0)!=(ja|0)){yDb(c[fa>>2]|0,24,2139568,(B=i,i=i+16|0,c[B>>2]=ma,c[B+8>>2]=ja,B)|0);i=B}if((X|0)>=(pa|0)){break}X=X+1|0;na=c[I>>2]|0}if((Z|0)==180){yDb(c[fa>>2]|0,24,2152448,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}na=c[I>>2]|0;X=ia-24+(_<<3)|0;if((X|0)>(na|0)){oa=X-na|0;X=-na|0;ga=(c[H>>2]|0)-na|0;if((oa|0)<(X|0)){zb=X}else{zb=(ga|0)<(oa|0)?ga:oa}oa=zb+na|0;c[I>>2]=oa;Ab=oa}else{Ab=na}na=0;oa=Ab;while(1){ga=c[H>>2]|0;X=c[D>>2]|0;ea=X+(oa>>>3)|0;E=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(oa&7)&-65536;ea=oa+16|0;ja=ga>>>0>ea>>>0?ea:ga;c[I>>2]=ja;ea=X+(ja>>>3)|0;X=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ja&7)>>>16;ea=ja+16|0;c[I>>2]=ga>>>0>ea>>>0?ea:ga;ga=X|E;d:do{if((ga|0)==1700671838){yDb(c[fa>>2]|0,48,2201600,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;E=c[I>>2]|0;X=c[H>>2]|0;ea=c[D>>2]|0;ja=ea+(E>>>3)|0;ma=d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0;ja=E&7;U=E+6|0;K=X>>>0>U>>>0?U:X;c[I>>2]=K;U=ea+(K>>>3)|0;la=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(K&7)>>>30;U=K+2|0;K=X>>>0>U>>>0?U:X;c[I>>2]=K;U=la+1|0;la=0;N=K;do{K=ea+(N>>>3)|0;G=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(N&7)>>>18;K=N+14|0;N=X>>>0>K>>>0?K:X;c[I>>2]=N;c[q+(la<<2)>>2]=G+1;la=la+1|0;}while((la|0)<(U|0));la=fe(ma|0)|0;G=a[ea+(N>>>3)|0]|0;K=((N|0)<(X|0))+N|0;c[I>>2]=K;ka=0;Q=K;while(1){K=ea+(Q>>>3)|0;ya=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(Q&7)>>>29;K=Q+3|0;Ra=X>>>0>K>>>0?K:X;c[I>>2]=Ra;K=ya+1|0;c[r+(ka<<2)>>2]=K;ya=ea+(Ra>>>3)|0;$=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(Ra&7)>>>30;ya=Ra+2|0;Ra=X>>>0>ya>>>0?ya:X;c[I>>2]=Ra;ya=$+5|0;Na=27-$|0;$=0;Bb=Ra;do{Ra=ea+(Bb>>>3)|0;Ya=(fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Bb&7)>>>(Na>>>0);Ra=ya+Bb|0;Bb=X>>>0>Ra>>>0?Ra:X;c[I>>2]=Bb;c[n+(ka<<5)+($<<2)>>2]=Ya+1;$=$+1|0;}while(($|0)<(K|0));K=ka+1|0;if((K|0)<(U|0)){ka=K;Q=Bb}else{break}}Q=N&7;ka=G&255;ea=E-24+(la<<ja>>>26<<3)|0;if((ea|0)>(Bb|0)){ma=ea-Bb|0;ea=-Bb|0;K=X-Bb|0;if((ma|0)<(ea|0)){Cb=ea}else{Cb=(K|0)<(ma|0)?K:ma}ma=Cb+Bb|0;c[I>>2]=ma;Db=ma}else{Db=Bb}ma=(ka&128>>>(Q>>>0)|0)==0;Q=0;ka=0;K=Db;ea=Db;e:while(1){$=r+(ka<<2)|0;ya=c[$>>2]|0;if((ya+Q|0)>(c[Y>>2]|0)){break d}if((c[J>>2]|0)>7){Na=0;Sa=0;Ya=0;Ra=ya;da=ya;while(1){do{if((Sa|0)==0){if((Ra|0)>0){Oa=c[H>>2]|0;Ua=c[D>>2]|0;Ta=0;Va=c[I>>2]|0;while(1){Eb=Ua+(Va>>>3)|0;Fb=(fe(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(Va&7)>>>30;Eb=Va+2|0;Gb=Oa>>>0>Eb>>>0?Eb:Oa;c[I>>2]=Gb;c[p+(Ta<<2)>>2]=Fb+2;Fb=Ta+1|0;if((Fb|0)<(Ra|0)){Ta=Fb;Va=Gb}else{Hb=0;Ib=Ra;Jb=da;break}}while(1){Va=c[n+(ka<<5)+(Hb<<2)>>2]|0;Ta=c[p+(Hb<<2)>>2]|0;if((Va|0)==0){Kb=Ib;Lb=Jb}else{Oa=32-Ta|0;Gb=Va;Va=o+(Hb<<8)|0;while(1){Fb=Gb-1|0;Eb=c[I>>2]|0;Mb=c[H>>2]|0;Nb=Ua+(Eb>>>3)|0;Ob=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Oa>>>0);Nb=Eb+Ta|0;c[I>>2]=Mb>>>0>Nb>>>0?Nb:Mb;c[Va>>2]=Ob;if((Fb|0)==0){break}Gb=Fb;Va=Va+4|0}Va=c[$>>2]|0;Kb=Va;Lb=Va}Va=Hb+1|0;if((Va|0)<(Kb|0)){Hb=Va;Ib=Kb;Jb=Lb}else{Pb=Kb;Qb=Lb;break}}}else{Pb=Ra;Qb=da}Ua=0;while(1){if((Ua|0)>=(Pb|0)){break}Va=c[I>>2]|0;Gb=c[H>>2]|0;Ta=(c[D>>2]|0)+(Va>>>3)|0;Oa=(fe(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(Va&7)>>>29;Ta=Va+3|0;c[I>>2]=Gb>>>0>Ta>>>0?Ta:Gb;c[p+(Ua<<2)>>2]=Oa;if((Oa|0)==0){Z=229;break e}else{Ua=Ua+1|0}}if((Pb|0)>0){Rb=0}else{Sb=Qb;Tb=Pb;break}while(1){Ua=(c[x+236+(Rb+Q<<2)>>2]|0)==6?478968:479480;Oa=c[p+(Rb<<2)>>2]|0;Gb=c[n+(ka<<5)+(Rb<<2)>>2]|0;if((Gb|0)>0){Ta=32-Oa|0;Va=0;do{do{if((c[o+(Rb<<8)+(Va<<2)>>2]|0)>0){Fb=c[I>>2]|0;Ob=c[H>>2]|0;Mb=c[D>>2]|0;Nb=Mb+(Fb>>>3)|0;Eb=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Fb&7)>>>(Ta>>>0);Nb=Fb+Oa|0;Fb=Ob>>>0>Nb>>>0?Nb:Ob;c[I>>2]=Fb;c[m+(Rb<<9)+(Va<<3)>>2]=c[Ua+(Eb<<2)>>2];if(ma){break}if((c[x+7588+(Rb<<8)+(Va<<2)>>2]|0)==0){break}Eb=Mb+(Fb>>>3)|0;Mb=(fe(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(Fb&7)>>>(Ta>>>0);Eb=Fb+Oa|0;c[I>>2]=Ob>>>0>Eb>>>0?Eb:Ob;c[m+(Rb<<9)+(Va<<3)+4>>2]=c[Ua+(Mb<<2)>>2]}}while(0);Va=Va+1|0;}while((Va|0)<(Gb|0))}Gb=Rb+1|0;if((Gb|0)<(Pb|0)){Rb=Gb}else{Ub=Pb;Vb=Qb;Z=239;break}}}else{Ub=Ra;Vb=da;Z=239}}while(0);do{if((Z|0)==239){Z=0;if((Ub|0)>0){Wb=0}else{Sb=Vb;Tb=Ub;break}while(1){Gb=c[n+(ka<<5)+(Wb<<2)>>2]|0;if((Gb|0)>0){Va=Wb+Q|0;Ua=0;do{Oa=c[o+(Wb<<8)+(Ua<<2)>>2]|0;ca=+g[766872+(Oa<<2)>>2];do{if(ma){Xb=0}else{Ta=c[x+7588+(Wb<<8)+(Ua<<2)>>2]|0;if((Ta|0)==0){Xb=0;break}Xb=(Sa|0)>=(Ta|0)|0}}while(0);aa=ca*+(c[m+(Wb<<9)+(Ua<<3)+(Xb<<2)>>2]|0);if((Oa|0)>=1){if((Oa|0)>7){Ta=Oa-3|0;Mb=35-Oa|0;Ob=c[D>>2]|0;Eb=c[I>>2]|0;Fb=c[H>>2]|0;Nb=Ob+(Eb>>>3)|0;Yb=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;Zb=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;_b=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;$b=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;ac=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;bc=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;cc=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;Ob=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Mb=Eb+Ta|0;c[I>>2]=Fb>>>0>Mb>>>0?Mb:Fb;dc=Yb;ec=Zb;fc=_b;gc=$b;hc=ac;ic=bc;jc=cc;kc=Ob}else{Ob=Oa-1|0;cc=d[1878e3+Ob|0]|0;bc=d[1878008+Ob|0]|0;Ob=c[I>>2]|0;ac=c[H>>2]|0;$b=c[D>>2]|0;_b=$b+(Ob>>>3)|0;Zb=32-cc|0;Yb=(fe(d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)|0)<<(Ob&7)>>>(Zb>>>0);_b=Ob+cc|0;Ob=ac>>>0>_b>>>0?_b:ac;c[I>>2]=Ob;_b=$b+(Ob>>>3)|0;$b=(fe(d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)|0)<<(Ob&7)>>>(Zb>>>0);Zb=Ob+cc|0;c[I>>2]=ac>>>0>Zb>>>0?Zb:ac;ac=bc-1>>1;Zb=c[1199552+(bc<<2)>>2]|0;cc=0;gHb(Zb,cc,Yb,(Yb|0)<0|0?-1:0)|0;Ob=F;_b=Yb-ac-(ba(Ob,bc)|0)|0;gHb(Ob,(Ob|0)<0|0?-1:0,Zb,cc)|0;Yb=F;Fb=Ob-ac-(ba(Yb,bc)|0)|0;gHb(Yb,(Yb|0)<0|0?-1:0,Zb,cc)|0;Ob=F;Mb=Yb-ac-(ba(Ob,bc)|0)|0;gHb(Ob,(Ob|0)<0|0?-1:0,Zb,cc)|0;Yb=F;Ta=Ob-ac-(ba(Yb,bc)|0)|0;gHb($b,($b|0)<0|0?-1:0,Zb,cc)|0;Ob=F;Eb=$b-ac-(ba(Ob,bc)|0)|0;gHb(Ob,(Ob|0)<0|0?-1:0,Zb,cc)|0;$b=F;Nb=Ob-ac-(ba($b,bc)|0)|0;gHb($b,($b|0)<0|0?-1:0,Zb,cc)|0;Ob=F;lc=$b-ac-(ba(Ob,bc)|0)|0;gHb(Ob,(Ob|0)<0|0?-1:0,Zb,cc)|0;cc=F;Zb=Ob-ac-(ba(cc,bc)|0)|0;if((cc|Yb|0)==0&0==0){dc=_b;ec=Fb;fc=Mb;gc=Ta;hc=Eb;ic=Nb;jc=lc;kc=Zb}else{Z=249;break e}}Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)|0;g[Zb>>2]=+g[Zb>>2]+aa*+(dc|0);Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+4|0;g[Zb>>2]=aa*+(ec|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+8|0;g[Zb>>2]=aa*+(fc|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+12|0;g[Zb>>2]=aa*+(gc|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+16|0;g[Zb>>2]=aa*+(hc|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+20|0;g[Zb>>2]=aa*+(ic|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+24|0;g[Zb>>2]=aa*+(jc|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+28|0;g[Zb>>2]=aa*+(kc|0)+ +g[Zb>>2]}Ua=Ua+1|0;}while((Ua|0)<(Gb|0))}Gb=Wb+1|0;if((Gb|0)<(Ub|0)){Wb=Gb}else{Sb=Vb;Tb=Ub;break}}}}while(0);if((c[S>>2]|0)==0){Gb=c[x+2084+(Na<<2)>>2]|0;if((Sa|0)==(Gb-1|0)){Z=255}else{mc=Gb}}else{Z=255}if((Z|0)==255){Z=0;Gb=c[I>>2]|0;Ua=c[H>>2]|0;Va=(c[D>>2]|0)+(Gb>>>3)|0;Zb=(fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Gb&7);Va=Gb+16|0;c[I>>2]=Ua>>>0>Va>>>0?Va:Ua;if(!((Zb&-65536|0)==-65536)){Z=257;break e}mc=c[x+2084+(Na<<2)>>2]|0}Zb=Sa+1|0;Ua=(Zb|0)<(mc|0);Va=Ya+1|0;if((Va|0)<((c[J>>2]|0)/8|0|0)){Na=(Ua&1^1)+Na|0;Sa=Ua?Zb:0;Ya=Va;Ra=Tb;da=Sb}else{break}}da=c[I>>2]|0;nc=da;oc=Sb;pc=da}else{nc=K;oc=ya;pc=ea}da=(c[q+(ka<<2)>>2]<<3)+K|0;if((da|0)==(nc|0)){qc=nc;rc=pc}else{Ra=da-nc|0;if(Ra>>>0>7>>>0){yDb(c[fa>>2]|0,16,2159440,(B=i,i=i+8|0,c[B>>2]=Ra,B)|0);i=B;sc=c[I>>2]|0}else{sc=pc}da=-sc|0;Ya=(c[H>>2]|0)-sc|0;if((Ra|0)<(da|0)){tc=da}else{tc=(Ya|0)<(Ra|0)?Ya:Ra}Ra=tc+sc|0;c[I>>2]=Ra;qc=Ra;rc=Ra}Ra=ka+1|0;if((Ra|0)>=(U|0)){break d}Q=oc+Q|0;ka=Ra;K=qc;ea=rc}if((Z|0)==229){Z=0;yDb(c[fa>>2]|0,16,2193360,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}else if((Z|0)==249){Z=0;yDb(c[fa>>2]|0,16,2176784,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}else if((Z|0)==257){Z=0;yDb(c[fa>>2]|0,16,2166128,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}}else if((ga|0)==1191201283){J0(x);c[R>>2]=c[R>>2]|2}else{yDb(c[fa>>2]|0,48,2210336,(B=i,i=i+8|0,c[B>>2]=ga,B)|0);i=B}}while(0);ga=c[I>>2]|0;ea=(c[s+(na<<2)>>2]<<3)+oa|0;if((ea|0)>(ga|0)){K=ea-ga|0;ea=-ga|0;ka=(c[H>>2]|0)-ga|0;if((K|0)<(ea|0)){uc=ea}else{uc=(ka|0)<(K|0)?ka:K}K=uc+ga|0;c[I>>2]=K;vc=K}else{vc=ga}ga=na+1|0;if((ga|0)<(pa|0)){na=ga;oa=vc}else{break}}}}while(0);c[b+840>>2]=c[z>>2];z=c[Y>>2]|0;vc=c[T>>2]|0;pa=(vc|0)!=0|0;I=pa+z|0;f:do{if((c[R>>2]&2|0)==0){Z=279}else{uc=c[b+440>>2]|0;g:do{if((uc|0)>0){H=pa+P|0;s=j+290840|0;if((uc|0)<(H+(c[s>>2]|0)|0)){Z=279;break f}rc=j+290820|0;qc=c[rc>>2]|0;if((uc|0)>=(z|0)){wc=rc;xc=qc;Z=308;break}oc=s;s=c[j+290812>>2]|0;if((s|0)<=0){yc=qc;zc=H;Ac=rc;Bc=s;break}sc=j+290824|0;tc=H;H=0;pc=qc;while(1){qc=(c[oc+(H<<2)>>2]|0)+tc|0;if((qc|0)>(uc|0)){yc=pc;zc=tc;Ac=rc;Bc=s;break g}nc=c[sc+(H<<2)>>2]|pc;q=H+1|0;if((q|0)<(s|0)){tc=qc;H=q;pc=nc}else{yc=nc;zc=qc;Ac=rc;Bc=s;break}}}else{s=j+290820|0;wc=s;xc=c[s>>2]|0;Z=308}}while(0);do{if((Z|0)==308){uc=c[j+290812>>2]|0;if((uc|0)<=0){yc=xc;zc=I;Ac=wc;Bc=uc;break}s=j+290824|0;rc=0;pc=xc;while(1){H=c[s+(rc<<2)>>2]|pc;tc=rc+1|0;if((tc|0)<(uc|0)){rc=tc;pc=H}else{yc=H;zc=I;Ac=wc;Bc=uc;break}}}}while(0);uc=j+290816|0;pc=c[uc>>2]|0;if((pc|0)>0){rc=0;s=0;while(1){if((1<<rc&yc|0)==0){Cc=s}else{Cc=c[684800+(rc<<2)>>2]|s}H=rc+1|0;if((H|0)<(pc|0)){rc=H;s=Cc}else{Dc=Cc;break}}}else{Dc=0}s=yc-(yc>>>1&1431655765)|0;rc=(s>>>2&858993459)+(s&858993459)|0;s=(rc>>>4)+rc&252645135;rc=(s>>>8)+s|0;s=Dc>>>1;H=Dc-(s&1431655765)|0;tc=(H>>>2&858993459)+(H&858993459)|0;H=(tc>>>4)+tc&252645135;tc=(H>>>8)+H|0;if((((tc>>>16)+tc^(rc>>>16)+rc)&63|0)!=0){yDb(b,48,2274568,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=k;return C|0}rc=b+448|0;c[rc>>2]=Dc;c[rc+4>>2]=(Dc|0)<0|0?-1:0;rc=b+456|0;tc=c[rc+4>>2]|0;H=0;if((tc|0)<(H|0)|(tc|0)==(H|0)&(c[rc>>2]|0)>>>0<0>>>0){if((zc|0)>0){rc=0;do{a[j+(rc+291772)|0]=rc;rc=rc+1|0;}while((rc|0)<(zc|0))}a[j+291804|0]=zc+255}else{rc=j+290812|0;if((Bc|0)>-1){H=j+290824|0;tc=-1;sc=0;oc=pc;qc=Bc;while(1){if((tc|0)>-1){Ec=H+(tc<<2)|0}else{Ec=Ac}if((oc|0)>0){nc=c[Ec>>2]&-65569;q=sc;Sb=0;Tb=oc;while(1){if((nc&1<<Sb|0)==0){Fc=q;Gc=Tb}else{mc=(c[684800+(Sb<<2)>>2]|0)-1&Dc;D=mc-(mc>>>1&1431655765)|0;mc=(D>>>2&858993459)+(D&858993459)|0;D=(mc>>>4)+mc&252645135;mc=(D>>>8)+D|0;a[j+(q+291772)|0]=(mc>>>16)+mc&63;Fc=q+1|0;Gc=c[uc>>2]|0}mc=Sb+1|0;if((mc|0)<(Gc|0)){q=Fc;Sb=mc;Tb=Gc}else{break}}Hc=Fc;Ic=Gc;Jc=c[rc>>2]|0}else{Hc=sc;Ic=oc;Jc=qc}Tb=tc+1|0;if((Tb|0)<(Jc|0)){tc=Tb;sc=Hc;oc=Ic;qc=Jc}else{break}}}qc=(Dc&7)-(s&1)|0;oc=(qc>>>2&858993459)+(qc&858993459)|0;qc=(oc>>>4)+oc&252645135;oc=(qc>>>8)+qc|0;a[j+291804|0]=(oc>>>16)+oc&63}c[j+290764>>2]=j+291772;Kc=zc}}while(0);if((Z|0)==279){zc=c[L>>2]|0;if((zc|0)>=16){yDb(b,16,2290496,(B=i,i=i+8|0,c[B>>2]=zc,B)|0);i=B;C=-1094995529;i=k;return C|0}Dc=1406944+(zc<<3)|0;Jc=c[Dc>>2]|0;Ic=c[Dc+4>>2]|0;Dc=b+448|0;c[Dc>>2]=Jc;c[Dc+4>>2]=Ic;do{if((c[y>>2]|0)==0){Z=288}else{if((c[j+290808>>2]|0)!=0){Z=288;break}Hc=c[b+440>>2]|0;if((Hc|0)!=0){if((Hc|0)<=(pa+P|0)){Z=288;break}}Hc=Jc|256;Gc=Ic|0;c[Dc>>2]=Hc;c[Dc+4>>2]=Gc;if((vc|0)==0){Fc=1407088+(zc*9|0)|0;c[j+290764>>2]=Fc;Lc=Gc;Mc=Hc;Nc=Fc}else{Fc=Jc|264;Hc=Ic|0;c[Dc>>2]=Fc;c[Dc+4>>2]=Hc;Gc=1407376+(zc*9|0)|0;c[j+290764>>2]=Gc;Lc=Hc;Mc=Fc;Nc=Gc}if((a[Nc+(c[j+290804>>2]|0)|0]|0)<0){C=-1094995529}else{Oc=I;Pc=vc;Qc=Nc;Rc=Lc;Sc=Mc;break}i=k;return C|0}}while(0);do{if((Z|0)==288){Mc=pa+P|0;c[y>>2]=0;if((vc|0)==0){Lc=1407232+(zc*9|0)|0;c[j+290764>>2]=Lc;Oc=Mc;Pc=0;Qc=Lc;Rc=Ic;Sc=Jc;break}else{Lc=Jc|8;Nc=Ic|0;c[Dc>>2]=Lc;c[Dc+4>>2]=Nc;Gc=1407520+(zc*9|0)|0;c[j+290764>>2]=Gc;Oc=Mc;Pc=vc;Qc=Gc;Rc=Nc;Sc=Lc;break}}}while(0);vc=(Pc|0)!=0|0;do{if((Oc|0)>(vc|0)){if((a[Qc+(Oc-1-vc)|0]|0)<0){C=-1094995529}else{break}i=k;return C|0}}while(0);if((hBb(Sc,Rc)|0)!=(Oc|0)){Rc=hBb(c[Dc>>2]|0,c[Dc+4>>2]|0)|0;yDb(b,16,2309232,(B=i,i=i+16|0,c[B>>2]=Oc,c[B+8>>2]=Rc,B)|0);i=B;C=-1094995529;i=k;return C|0}Rc=c[Y>>2]|0;Sc=b+456|0;vc=c[Sc>>2]|0;Qc=c[Sc+4>>2]|0;do{if((((c[T>>2]|0)!=0)+Rc|0)>2&((vc|0)==3&(Qc|0)==0)){if((Rc|0)==2){Tc=c[L>>2]|0}else{Tc=2}c[V>>2]=Tc;c[Dc>>2]=3;c[Dc+4>>2]=0;Uc=2}else{Sc=0;if(!((Qc|0)<(Sc|0)|(Qc|0)==(Sc|0)&vc>>>0<0>>>0)){Uc=Oc;break}c[j+290764>>2]=1406928;Uc=Oc}}while(0);a[j+291804|0]=a[1405376+(c[L>>2]|0)|0]|0;c[j+290872>>2]=0;Kc=Uc}Uc=b+416|0;Oc=c[Uc>>2]|0;if((Oc|0)!=(Kc|0)){if((Oc|0)!=0){yDb(b,32,2258824,(B=i,i=i+16|0,c[B>>2]=Oc,c[B+8>>2]=Kc,B)|0);i=B}c[Uc>>2]=Kc}Oc=f+76|0;c[Oc>>2]=((c[J>>2]|0)/8|0)<<8;vc=_$a(b,u,0)|0;if((vc|0)<0){C=vc;i=k;return C|0}vc=c[f+64>>2]|0;do{if((c[Uc>>2]|0)<(I|0)){f=I-Kc|0;Qc=b+420|0;Dc=DFb(0,f,c[Oc>>2]|0,c[Qc>>2]|0,0)|0;if((Dc|0)<0){C=Dc;i=k;return C|0}Tc=j+269248|0;kEb(Tc,j+269252|0,Dc);Dc=c[Tc>>2]|0;if((Dc|0)==0){C=-12;i=k;return C|0}Tc=EFb(j+269216|0,0,Dc,f,c[Oc>>2]|0,c[Qc>>2]|0,0)|0;if((Tc|0)<0){C=Tc}else{break}i=k;return C|0}}while(0);Oc=c[J>>2]|0;if((Oc|0)>7){b=(Kc|0)>0;Uc=j+290764|0;Tc=j+291956|0;Qc=j+291944|0;f=j+291880|0;Dc=j+39648|0;Rc=j+4|0;Sc=j+269184|0;Pc=Sc;zc=j+269188|0;Ic=j+14784|0;Jc=j+14792|0;pa=j+14800|0;Z=j+14788|0;Lc=j+14796|0;Nc=j+14804|0;Gc=j+14808|0;Mc=j+14816|0;Fc=j+14812|0;Hc=j+14820|0;Ec=j+290872|0;Ac=j+290812|0;Bc=j+290840|0;yc=j+290856|0;Cc=j+291804|0;wc=Sc;Sc=j+290876|0;xc=j+291848|0;z=j+290804|0;R=j+269216|0;oc=0;while(1){if(b){qc=oc<<8;sc=0;while(1){c[wc+(sc<<2)>>2]=(c[vc+(sc<<2)>>2]|0)+(qc<<2);tc=sc+1|0;if((tc|0)<(Kc|0)){sc=tc}else{Vc=Kc;break}}}else{Vc=0}if((Vc|0)<(I|0)){sc=oc<<8;qc=Vc;do{c[wc+(qc<<2)>>2]=(c[R+(qc-Kc<<2)>>2]|0)+(sc<<2);qc=qc+1|0;}while((qc|0)<(I|0))}qc=c[Y>>2]|0;if((qc|0)>0){sc=0;s=qc;while(1){tc=a[(c[Uc>>2]|0)+sc|0]|0;if(tc<<24>>24>-1){ve[c[Tc>>2]&3](x+39808+(oc*14336|0)+(sc<<11)|0,c[x+124+(sc<<2)>>2]|0,Qc,f,x+24384+(sc<<11)|0,x+39616+(sc<<2)|0,x+38720+(sc<<7)|0,(c[O>>2]|0)==0?1056144:1052048,c[x+269184+(tc<<24>>24<<2)>>2]|0,Dc,762939453125.0e-17);Wc=c[Y>>2]|0}else{Wc=s}tc=sc+1|0;if((tc|0)<(Wc|0)){sc=tc;s=Wc}else{Xc=Wc;break}}}else{Xc=qc}s=c[T>>2]|0;do{if((s|0)==0){Yc=Xc;Zc=0}else{sc=s<<1;tc=(s|0)==1;rc=tc&1;uc=tc?854080:853056;if((sc|0)<=0){Yc=Xc;Zc=s;break}tc=ba(sc,oc+4|0)|0;H=x+291948+(rc<<2)|0;pc=(rc<<6)+64|0;rc=x+16712+(tc<<2)|0;tc=c[x+269184+(a[Cc]<<2)>>2]|0;Tb=0;while(1){Xe[c[H>>2]&4095](tc,rc,uc);Sb=Tb+1|0;if((Sb|0)<(sc|0)){rc=rc+4|0;tc=tc+(pc<<2)|0;Tb=Sb}else{break}}Yc=c[Y>>2]|0;Zc=c[T>>2]|0}}while(0);s=(Zc|0)!=0;do{if(((s&1)+Yc|0)>2){qc=(c[Rc>>2]|0)+456|0;if(!((c[qc>>2]|0)==3&(c[qc+4>>2]|0)==0)){break}qc=c[L>>2]|0;Tb=c[Uc>>2]|0;switch(qc|0){case 0:case 10:{yDb(0,16,2244408,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break};case 5:{pc=c[x+269184+(a[Tb]<<2)>>2]|0;tc=c[x+269184+(a[Tb+1|0]<<2)>>2]|0;rc=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;sc=c[Pc>>2]|0;uc=c[zc>>2]|0;H=0;do{aa=+g[pc+(H<<2)>>2];_c=+g[tc+(H<<2)>>2];$c=+g[rc+(H<<2)>>2];g[sc+(H<<2)>>2]=aa*+g[Ic>>2]+_c*+g[Jc>>2]+$c*+g[pa>>2];g[uc+(H<<2)>>2]=aa*+g[Z>>2]+_c*+g[Lc>>2]+$c*+g[Nc>>2];H=H+1|0;}while((H|0)<256);break};case 6:{H=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;uc=c[Pc>>2]|0;sc=c[zc>>2]|0;rc=0;do{tc=H+(rc<<2)|0;pc=uc+(rc<<2)|0;g[pc>>2]=+g[tc>>2]*+g[pa>>2]+ +g[pc>>2];pc=sc+(rc<<2)|0;g[pc>>2]=+g[tc>>2]*+g[Nc>>2]+ +g[pc>>2];rc=rc+1|0;}while((rc|0)<256);break};case 7:{rc=c[x+269184+(a[Tb]<<2)>>2]|0;sc=c[x+269184+(a[Tb+1|0]<<2)>>2]|0;uc=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;H=c[Pc>>2]|0;pc=c[zc>>2]|0;tc=c[x+269184+(a[Tb+3|0]<<2)>>2]|0;Sb=0;do{$c=+g[rc+(Sb<<2)>>2];_c=+g[sc+(Sb<<2)>>2];aa=+g[uc+(Sb<<2)>>2];q=H+(Sb<<2)|0;g[q>>2]=$c*+g[Ic>>2]+_c*+g[Jc>>2]+aa*+g[pa>>2];nc=pc+(Sb<<2)|0;g[nc>>2]=$c*+g[Z>>2]+_c*+g[Lc>>2]+aa*+g[Nc>>2];mc=tc+(Sb<<2)|0;g[q>>2]=+g[mc>>2]*+g[Gc>>2]+ +g[q>>2];g[nc>>2]=+g[mc>>2]*+g[Fc>>2]+ +g[nc>>2];Sb=Sb+1|0;}while((Sb|0)<256);break};case 8:{Sb=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;tc=c[x+269184+(a[Tb+3|0]<<2)>>2]|0;pc=c[Pc>>2]|0;H=c[zc>>2]|0;uc=0;do{sc=Sb+(uc<<2)|0;rc=tc+(uc<<2)|0;nc=pc+(uc<<2)|0;g[nc>>2]=+g[nc>>2]+(+g[sc>>2]*+g[pa>>2]+ +g[rc>>2]*+g[Gc>>2]);nc=H+(uc<<2)|0;g[nc>>2]=+g[nc>>2]+(+g[sc>>2]*+g[Nc>>2]+ +g[rc>>2]*+g[Fc>>2]);uc=uc+1|0;}while((uc|0)<256);break};case 9:{uc=c[x+269184+(a[Tb]<<2)>>2]|0;H=c[x+269184+(a[Tb+1|0]<<2)>>2]|0;pc=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;tc=c[Pc>>2]|0;Sb=c[zc>>2]|0;rc=c[x+269184+(a[Tb+3|0]<<2)>>2]|0;sc=c[x+269184+(a[Tb+4|0]<<2)>>2]|0;nc=0;do{aa=+g[uc+(nc<<2)>>2];_c=+g[H+(nc<<2)>>2];$c=+g[pc+(nc<<2)>>2];mc=tc+(nc<<2)|0;g[mc>>2]=aa*+g[Ic>>2]+_c*+g[Jc>>2]+$c*+g[pa>>2];q=Sb+(nc<<2)|0;g[q>>2]=aa*+g[Z>>2]+_c*+g[Lc>>2]+$c*+g[Nc>>2];D=rc+(nc<<2)|0;S=sc+(nc<<2)|0;g[mc>>2]=+g[mc>>2]+(+g[D>>2]*+g[Gc>>2]+ +g[S>>2]*+g[Mc>>2]);g[q>>2]=+g[q>>2]+(+g[D>>2]*+g[Fc>>2]+ +g[S>>2]*+g[Hc>>2]);nc=nc+1|0;}while((nc|0)<256);break};default:{}}if(!s){break}nc=d[1407072+qc|0]|0;sc=c[x+269184+(a[1405376+qc|0]<<2)>>2]|0;rc=x+14784+(nc<<3)|0;Sb=c[Pc>>2]|0;tc=x+14784+(nc<<3)+4|0;nc=c[zc>>2]|0;pc=0;do{H=sc+(pc<<2)|0;uc=Sb+(pc<<2)|0;g[uc>>2]=+g[H>>2]*+g[rc>>2]+ +g[uc>>2];uc=nc+(pc<<2)|0;g[uc>>2]=+g[H>>2]*+g[tc>>2]+ +g[uc>>2];pc=pc+1|0;}while((pc|0)<256)}}while(0);do{if((c[W>>2]&1|0)!=0){if((c[y>>2]|0)==0){break}s=c[z>>2]|0;pc=c[Uc>>2]|0;tc=c[wc+(a[pc+s|0]<<2)>>2]|0;nc=c[wc+(a[pc+(s-1)|0]<<2)>>2]|0;te[c[xc>>2]&7](c[wc+(a[pc+(s-2)|0]<<2)>>2]|0,tc,-.7071067690849304,256);te[c[xc>>2]&7](nc,tc,-.7071067690849304,256)}}while(0);tc=c[Ec>>2]|0;h:do{if((tc|0)!=0){if((c[Ac>>2]|0)>0){ad=0;bd=P;cd=tc}else{break}while(1){nc=c[Bc+(ad<<2)>>2]|0;s=nc+bd|0;if((nc|0)>0){nc=(s|0)>0;pc=bd;do{do{if((1<<pc&cd|0)!=0){rc=c[wc+(a[(c[Uc>>2]|0)+pc|0]<<2)>>2]|0;if(nc){dd=0}else{break}do{$c=+g[Sc+(pc<<7)+(dd<<2)>>2];if($c!=0.0){te[c[xc>>2]&7](c[wc+(a[(c[Uc>>2]|0)+dd|0]<<2)>>2]|0,rc,-0.0-$c,256)}dd=dd+1|0;}while((dd|0)<(s|0))}}while(0);pc=pc+1|0;}while((pc|0)<(s|0))}do{if((cd&1<<bd|0)!=0){$c=+g[yc+(ad<<2)>>2];if(!($c!=1.0)){break}if((bd|0)>0){pc=c[Uc>>2]|0;nc=0;do{ya=c[wc+(a[pc+nc|0]<<2)>>2]|0;rc=0;do{Sb=ya+(rc<<2)|0;g[Sb>>2]=$c*+g[Sb>>2];rc=rc+1|0;}while((rc|0)<256);nc=nc+1|0;}while((nc|0)<(bd|0))}if((c[T>>2]|0)==0){break}nc=c[wc+(a[Cc]<<2)>>2]|0;pc=0;do{rc=nc+(pc<<2)|0;g[rc>>2]=$c*+g[rc>>2];pc=pc+1|0;}while((pc|0)<256)}}while(0);pc=ad+1|0;if((pc|0)>=(c[Ac>>2]|0)){break h}ad=pc;bd=s;cd=c[Ec>>2]|0}}}while(0);tc=oc+1|0;pc=(c[J>>2]|0)/8|0;if((tc|0)<(pc|0)){oc=tc}else{ed=pc;break}}}else{ed=(Oc|0)/8|0}Oc=c[T>>2]|0;oc=ba(ed<<1,Oc)|0;if((Oc<<3|0)>0){Oc=j+16712|0;j=0;do{g[Oc+(j<<2)>>2]=+g[Oc+(j+oc<<2)>>2];j=j+1|0;}while((j|0)<(c[T>>2]<<3|0))}T=W$a(u,(c[V>>2]&-129|0)==4|0)|0;if((T|0)<0){C=T;i=k;return C|0}c[h>>2]=1;C=w;i=k;return C|0}function G0(a){a=a|0;var b=0;b=c[a+60>>2]|0;bLa(b+291880|0);$Db(b+269248|0);return 0}function H0(e,f,h){e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0.0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0.0,Ja=0,Ka=0.0,La=0.0,Ma=0.0,Na=0.0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;j=i;i=i+2304|0;k=j|0;l=j+2048|0;m=e+290788|0;n=c[m>>2]|0;o=e+112|0;p=c[o>>2]|0;if((n|0)>=(p|0)){yDb(c[e+4>>2]|0,48,2121048,(q=i,i=i+16|0,c[q>>2]=n,c[q+8>>2]=p,q)|0);i=q;r=-1094995529;i=j;return r|0}p=e+290792|0;do{if((c[p>>2]|0)==0){s=e+290768|0;t=e+290776|0;u=c[t>>2]|0;v=e+290780|0;if(((c[v>>2]|0)-u|0)<0){r=-1094995529;i=j;return r|0}w=(f|0)!=0;if(w){x=f}else{y=e+290784|0;z=c[y>>2]|0;A=s|0;B=(c[A>>2]|0)+(u>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(u&7)>>>30;B=u+2|0;c[t>>2]=z>>>0>B>>>0?B:z;c[e+2084+(n<<2)>>2]=C+1;C=c[t>>2]|0;z=c[y>>2]|0;y=(c[A>>2]|0)+(C>>>3)|0;A=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(C&7)>>>29;y=C+3|0;c[t>>2]=z>>>0>y>>>0?y:z;c[e+2148+(c[m>>2]<<2)>>2]=A;x=0}A=e+120|0;z=c[A>>2]|0;if((x|0)<(z|0)){y=e+290784|0;C=s|0;B=x;u=z;while(1){D=e+124+(B<<2)|0;if((c[D>>2]|0)>0){E=0;do{G=c[t>>2]|0;H=c[y>>2]|0;I=(c[C>>2]|0)+(G>>>3)|0;J=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(G&7)>>>31;I=G+1|0;c[t>>2]=H>>>0>I>>>0?I:H;c[e+2212+(B<<8)+(E<<2)>>2]=J;E=E+1|0;}while((E|0)<(c[D>>2]|0));K=c[A>>2]|0}else{K=u}D=B+1|0;if((D|0)<(K|0)){B=D;u=K}else{L=K;break}}}else{L=z}if((L|0)>(f|0)){u=e+290784|0;B=s|0;C=f;y=L;while(1){D=e+124+(C<<2)|0;E=c[D>>2]|0;if((E|0)>0){J=0;H=E;while(1){if((c[e+2212+(C<<8)+(J<<2)>>2]|0)>0){E=c[t>>2]|0;I=c[u>>2]|0;G=(c[B>>2]|0)+(E>>>3)|0;M=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7)>>>20;G=E+12|0;c[t>>2]=I>>>0>G>>>0?G:I;c[e+4004+(C<<8)+(J<<2)>>2]=M;N=c[D>>2]|0}else{N=H}M=J+1|0;if((M|0)<(N|0)){J=M;H=N}else{break}}O=c[A>>2]|0}else{O=y}H=C+1|0;if((H|0)<(O|0)){C=H;y=O}else{P=O;break}}}else{P=L}a:do{if((P|0)>(f|0)){y=e+290784|0;C=s|0;B=f;u=P;b:while(1){z=e+152+(B<<2)|0;H=e+264+(B<<2)|0;if((c[z>>2]|0)>0){J=0;do{D=c[H>>2]|0;if((D|0)==7){break b}else if((D|0)==5){M=c[t>>2]|0;I=c[y>>2]|0;G=(c[C>>2]|0)+(M>>>3)|0;E=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(M&7)>>>28;G=M+4|0;c[t>>2]=I>>>0>G>>>0?G:I;c[e+5796+(B<<8)+(J<<2)>>2]=E}else if((D|0)==6){E=c[t>>2]|0;I=c[y>>2]|0;G=(c[C>>2]|0)+(E>>>3)|0;M=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7)>>>27;G=E+5|0;c[t>>2]=I>>>0>G>>>0?G:I;c[e+5796+(B<<8)+(J<<2)>>2]=M;Q=M;R=36}else{M=c[8749532+(D*20|0)>>2]|0;I=c[8749528+(D*20|0)>>2]|0;D=c[2187381]|0;G=c[t>>2]|0;E=c[y>>2]|0;S=c[C>>2]|0;T=S+(G>>>3)|0;U=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(G&7)>>>((32-I|0)>>>0);T=b[M+(U<<2)>>1]|0;V=b[M+(U<<2)+2>>1]|0;U=V<<16>>16;do{if((D|0)>1&V<<16>>16<0){W=G+I|0;X=E>>>0>W>>>0?W:E;W=S+(X>>>3)|0;Y=((fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(X&7)>>>((U+32|0)>>>0))+T|0;W=b[M+(Y<<2)>>1]|0;Z=b[M+(Y<<2)+2>>1]|0;Y=Z<<16>>16;if(!((D|0)>2&Z<<16>>16<0)){_=Y;$=W;aa=X;break}Z=X-U|0;X=E>>>0>Z>>>0?Z:E;Z=S+(X>>>3)|0;ca=((fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(X&7)>>>((Y+32|0)>>>0))+W|0;_=b[M+(ca<<2)+2>>1]|0;$=b[M+(ca<<2)>>1]|0;aa=X}else{_=U;$=T;aa=G}}while(0);G=_+aa|0;c[t>>2]=E>>>0>G>>>0?G:E;G=(c[2187372]|0)+$|0;c[e+5796+(B<<8)+(J<<2)>>2]=G;Q=G;R=36}if((R|0)==36){R=0;if((Q|0)>26){r=-1094995529;R=196;break b}}J=J+1|0;}while((J|0)<(c[z>>2]|0));da=c[A>>2]|0}else{da=u}z=B+1|0;if((z|0)<(da|0)){B=z;u=da}else{ea=da;break a}}if((R|0)==196){i=j;return r|0}yDb(c[e+4>>2]|0,16,2060552,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=j;return r|0}else{ea=P}}while(0);if((ea|0)>(f|0)){u=e+290784|0;B=s|0;C=f;y=ea;while(1){z=e+124+(C<<2)|0;if((c[z>>2]|0)>0){J=e+152+(C<<2)|0;H=e+208+(C<<2)|0;G=0;do{T=e+7588+(C<<8)+(G<<2)|0;c[T>>2]=0;do{if((c[e+2084+(c[m>>2]<<2)>>2]|0)>1){if((G|0)>=(c[J>>2]|0)){break}if((c[e+5796+(C<<8)+(G<<2)>>2]|0)<=0){break}U=c[H>>2]|0;M=c[8652444+(U*20|0)>>2]|0;S=c[8652440+(U*20|0)>>2]|0;U=c[2163109]|0;D=c[t>>2]|0;I=c[u>>2]|0;V=c[B>>2]|0;X=V+(D>>>3)|0;ca=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(D&7)>>>((32-S|0)>>>0);X=b[M+(ca<<2)>>1]|0;W=b[M+(ca<<2)+2>>1]|0;ca=W<<16>>16;do{if((U|0)>1&W<<16>>16<0){Y=D+S|0;Z=I>>>0>Y>>>0?Y:I;Y=V+(Z>>>3)|0;fa=((fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(Z&7)>>>((ca+32|0)>>>0))+X|0;Y=b[M+(fa<<2)>>1]|0;ga=b[M+(fa<<2)+2>>1]|0;fa=ga<<16>>16;if(!((U|0)>2&ga<<16>>16<0)){ha=fa;ia=Y;ja=Z;break}ga=Z-ca|0;Z=I>>>0>ga>>>0?ga:I;ga=V+(Z>>>3)|0;ka=((fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(Z&7)>>>((fa+32|0)>>>0))+Y|0;ha=b[M+(ka<<2)+2>>1]|0;ia=b[M+(ka<<2)>>1]|0;ja=Z}else{ha=ca;ia=X;ja=D}}while(0);D=ha+ja|0;c[t>>2]=I>>>0>D>>>0?D:I;c[T>>2]=(c[2163100]|0)+ia}}while(0);G=G+1|0;}while((G|0)<(c[z>>2]|0));la=c[A>>2]|0}else{la=y}z=C+1|0;if((z|0)<(la|0)){C=z;y=la}else{ma=la;break}}}else{ma=ea}if(((c[v>>2]|0)-(c[t>>2]|0)|0)<0){r=-1094995529;i=j;return r|0}if((ma|0)>(f|0)){y=f;while(1){C=e+124+(y<<2)|0;TGb(e+9380+(y<<9)|0,0,c[C>>2]<<3|0)|0;B=e+236+(y<<2)|0;u=(c[B>>2]|0)==6;z=u?7:6;G=u?478968:479480;if((c[C>>2]|0)>0){u=e+152+(y<<2)|0;H=0;J=0;while(1){T=c[u>>2]|0;if((J|0)<(T|0)){if((c[e+5796+(y<<8)+(J<<2)>>2]|0)>0){R=59}else{na=H;oa=T}}else{R=59}if((R|0)==59){R=0;T=K0(s,c[B>>2]|0,H,z)|0;c[e+9380+(y<<9)+(J<<3)>>2]=c[G+(T<<2)>>2];na=T;oa=c[u>>2]|0}do{if((J|0)<(oa|0)){if((c[e+7588+(y<<8)+(J<<2)>>2]|0)==0){pa=na;break}T=K0(s,c[B>>2]|0,na,z)|0;c[e+9380+(y<<9)+(J<<3)+4>>2]=c[G+(T<<2)>>2];pa=T}else{pa=na}}while(0);T=J+1|0;if((T|0)<(c[C>>2]|0)){H=pa;J=T}else{break}}}J=y+1|0;H=c[A>>2]|0;if((J|0)<(H|0)){y=J}else{qa=H;break}}}else{qa=ma}if((qa|0)>(f|0)){y=e+290784|0;H=s|0;J=f;C=qa;while(1){if((c[e+180+(J<<2)>>2]|0)>0){G=c[t>>2]|0;z=c[y>>2]|0;B=(c[H>>2]|0)+(G>>>3)|0;u=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(G&7)>>>29;B=G+3|0;c[t>>2]=z>>>0>B>>>0?B:z;c[e+12964+(J<<2)>>2]=u;ra=c[A>>2]|0}else{ra=C}u=J+1|0;if((u|0)<(ra|0)){J=u;C=ra}else{sa=ra;break}}}else{sa=qa}if(((c[v>>2]|0)-(c[t>>2]|0)|0)<0){r=-1094995529;i=j;return r|0}if((sa|0)>(f|0)){C=e+291840|0;J=e+4|0;H=f;while(1){y=c[e+180+(H<<2)>>2]|0;do{if((y|0)>0){u=c[e+124+(H<<2)>>2]|0;z=e+124+(y-1<<2)|0;if((u|0)<(c[z>>2]|0)){B=e+12964+(H<<2)|0;G=u;do{c[e+12992+(H<<8)+(G<<2)>>2]=K0(s,c[B>>2]|0,64,7)|0;G=G+1|0;}while((G|0)<(c[z>>2]|0))}if((c[C>>2]&2|0)!=0){break}yDb(c[J>>2]|0,48,2055976,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[C>>2]=c[C>>2]|2}}while(0);y=H+1|0;z=c[A>>2]|0;if((y|0)<(z|0)){H=y}else{ta=z;break}}}else{ta=sa}do{if(!w){if((c[e+44>>2]|0)==0){break}H=c[t>>2]|0;C=c[e+290784>>2]|0;J=(c[s>>2]|0)+(H>>>3)|0;v=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>24;J=H+8|0;c[t>>2]=C>>>0>J>>>0?J:C;c[e+14848>>2]=v}}while(0);if((c[e+16>>2]|0)!=0){v=c[e+290784>>2]|0;C=(c[t>>2]|0)+16|0;c[t>>2]=v>>>0>C>>>0?C:v}if((ta|0)>(f|0)){v=e+290784|0;C=s|0;J=f;H=ta;while(1){z=c[e+152+(J<<2)>>2]|0;y=e+124+(J<<2)|0;if((z|0)<(c[y>>2]|0)){G=z;do{z=c[t>>2]|0;B=c[v>>2]|0;u=(c[C>>2]|0)+(z>>>3)|0;T=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(z&7)>>>22;u=z+10|0;c[t>>2]=B>>>0>u>>>0?u:B;c[e+14920+(J<<8)+(G<<2)>>2]=T;G=G+1|0;}while((G|0)<(c[y>>2]|0));ua=c[A>>2]|0}else{ua=H}y=J+1|0;if((y|0)<(ua|0)){J=y;H=ua}else{break}}}if(w){va=A;break}H=c[e+72>>2]|0;if((H|0)==0){va=A;break}J=H<<1;H=h+4|0;C=ba(J,H)|0;v=ba((c[e+2084+(c[m>>2]<<2)>>2]|0)+H|0,J)|0;J=(C|0)<(v|0);H=c[t>>2]|0;y=e+290784|0;G=c[y>>2]|0;T=s|0;B=(c[T>>2]|0)+(H>>>3)|0;u=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(H&7);if(J){B=C;z=H;D=G;X=u;while(1){ca=z+8|0;c[t>>2]=D>>>0>ca>>>0?ca:D;g[e+16712+(B<<2)>>2]=+(X>>24|0);ca=B+1|0;M=c[t>>2]|0;V=c[y>>2]|0;U=(c[T>>2]|0)+(M>>>3)|0;S=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(M&7);if((ca|0)<(v|0)){B=ca;z=M;D=V;X=S}else{wa=M;xa=V;ya=S;break}}}else{wa=H;xa=G;ya=u}X=wa+8|0;c[t>>2]=xa>>>0>X>>>0?X:xa;if((ya|0)<0){DDb(c[e+4>>2]|0,2045048,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=j;return r|0}else{X=c[478968+(ya>>>24<<2)>>2]|0;c[e+17192>>2]=X;za=+(X|0)*.035;if(J){Aa=C}else{va=A;break}while(1){X=e+16712+(Aa<<2)|0;g[X>>2]=za*+g[X>>2];X=Aa+1|0;if((X|0)<(v|0)){Aa=X}else{va=A;break}}}}else{va=e+120|0}}while(0);Aa=c[p>>2]|0;ya=k|0;xa=(c[e+40>>2]|0)==31?766872:766744;wa=c[va>>2]|0;c:do{if((wa|0)>(f|0)){ua=e+290776|0;ta=e+290780|0;sa=e+291964|0;qa=e+291968|0;ra=l|0;ma=e+291840|0;pa=e+4|0;na=e+291960|0;oa=Aa<<3;ea=e+76|0;la=e+290784|0;ia=e+290768|0;ja=f;d:while(1){ha=c[ua>>2]|0;if(((c[ta>>2]|0)-ha|0)<0){r=-1094995529;R=196;break}P=e+152+(ja<<2)|0;da=c[P>>2]|0;if((da|0)>0){Q=0;$=ha;while(1){ha=c[e+5796+(ja<<8)+(Q<<2)>>2]|0;za=+g[xa+(ha<<2)>>2];aa=c[e+292+(ja<<7)+(ha<<2)>>2]|0;e:do{if((ha|0)==0){g[l+(Q<<2)>>2]=0.0;TGb(k+(Q<<3<<2)|0,0,32)|0;Ba=$}else{_=c[e+7588+(ja<<8)+(Q<<2)>>2]|0;if((_|0)==0){Ca=0}else{Ca=(Aa|0)>=(_|0)|0}g[l+(Q<<2)>>2]=+g[e+1188+(ja<<7)+(aa<<2)>>2]*za*+(c[e+9380+(ja<<9)+(Q<<3)+(Ca<<2)>>2]|0);do{if((ha|0)<=10){_=c[8652640+(ha*200|0)+(aa*20|0)+4>>2]|0;if((_|0)==0){if((ha|0)>=8){break}L=ha-1|0;O=d[1878e3+L|0]|0;N=d[1878008+L|0]|0;L=c[la>>2]|0;K=c[ia>>2]|0;x=K+($>>>3)|0;n=32-O|0;A=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<($&7)>>>(n>>>0);x=O+$|0;v=L>>>0>x>>>0?x:L;c[ua>>2]=v;x=K+(v>>>3)|0;K=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(v&7)>>>(n>>>0);n=v+O|0;O=L>>>0>n>>>0?n:L;c[ua>>2]=O;L=Q<<3;n=N-1>>1;v=c[1199552+(N<<2)>>2]|0;x=0;gHb(v,x,A,(A|0)<0|0?-1:0)|0;C=F;c[k+(L<<2)>>2]=A-n-(ba(C,N)|0);gHb(C,(C|0)<0|0?-1:0,v,x)|0;A=F;c[k+((L|1)<<2)>>2]=C-n-(ba(A,N)|0);gHb(A,(A|0)<0|0?-1:0,v,x)|0;C=F;c[k+((L|2)<<2)>>2]=A-n-(ba(C,N)|0);gHb(C,(C|0)<0|0?-1:0,v,x)|0;A=F;c[k+((L|3)<<2)>>2]=C-n-(ba(A,N)|0);gHb(K,(K|0)<0|0?-1:0,v,x)|0;C=F;c[k+((L|4)<<2)>>2]=K-n-(ba(C,N)|0);gHb(C,(C|0)<0|0?-1:0,v,x)|0;K=F;c[k+((L|5)<<2)>>2]=C-n-(ba(K,N)|0);gHb(K,(K|0)<0|0?-1:0,v,x)|0;C=F;c[k+((L|6)<<2)>>2]=K-n-(ba(C,N)|0);gHb(C,(C|0)<0|0?-1:0,v,x)|0;x=F;c[k+((L|7)<<2)>>2]=C-n-(ba(x,N)|0);if((x|A|0)==0&0==0){Ba=O;break e}else{break d}}O=8652640+(ha*200|0)+(aa*20|0)|0;A=8652636+(ha*200|0)|0;x=8652600+(ha*200|0)|0;N=Q<<3;n=c[la>>2]|0;C=c[ia>>2]|0;L=0;v=$;while(1){K=c[O>>2]|0;J=c[A>>2]|0;t=C+(v>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>((32-K|0)>>>0);t=b[_+(u<<2)>>1]|0;G=b[_+(u<<2)+2>>1]|0;u=G<<16>>16;do{if((J|0)>1&G<<16>>16<0){H=K+v|0;X=n>>>0>H>>>0?H:n;H=C+(X>>>3)|0;D=((fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(X&7)>>>((u+32|0)>>>0))+t|0;H=b[_+(D<<2)>>1]|0;z=b[_+(D<<2)+2>>1]|0;D=z<<16>>16;if(!((J|0)>2&z<<16>>16<0)){Da=D;Ea=H;Fa=X;break}z=X-u|0;X=n>>>0>z>>>0?z:n;z=C+(X>>>3)|0;B=((fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(X&7)>>>((D+32|0)>>>0))+H|0;Da=b[_+(B<<2)+2>>1]|0;Ea=b[_+(B<<2)>>1]|0;Fa=X}else{Da=u;Ea=t;Fa=v}}while(0);t=Da+Fa|0;u=n>>>0>t>>>0?t:n;c[ua>>2]=u;c[k+(L+N<<2)>>2]=(c[x>>2]|0)+Ea;t=L+1|0;if((t|0)<8){L=t;v=u}else{Ba=u;break e}}}}while(0);I=ha-3|0;v=35-ha|0;L=Q<<3;x=c[la>>2]|0;N=c[ia>>2]|0;n=N+($>>>3)|0;_=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<($&7)>>v;n=I+$|0;C=x>>>0>n>>>0?n:x;c[ua>>2]=C;c[k+(L<<2)>>2]=_;_=N+(C>>>3)|0;n=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(C&7)>>v;_=I+C|0;C=x>>>0>_>>>0?_:x;c[ua>>2]=C;c[k+((L|1)<<2)>>2]=n;n=N+(C>>>3)|0;_=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7)>>v;n=I+C|0;C=x>>>0>n>>>0?n:x;c[ua>>2]=C;c[k+((L|2)<<2)>>2]=_;_=N+(C>>>3)|0;n=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(C&7)>>v;_=I+C|0;C=x>>>0>_>>>0?_:x;c[ua>>2]=C;c[k+((L|3)<<2)>>2]=n;n=N+(C>>>3)|0;_=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7)>>v;n=I+C|0;C=x>>>0>n>>>0?n:x;c[ua>>2]=C;c[k+((L|4)<<2)>>2]=_;_=N+(C>>>3)|0;n=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(C&7)>>v;_=I+C|0;C=x>>>0>_>>>0?_:x;c[ua>>2]=C;c[k+((L|5)<<2)>>2]=n;n=N+(C>>>3)|0;_=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7)>>v;n=I+C|0;C=x>>>0>n>>>0?n:x;c[ua>>2]=C;c[k+((L|6)<<2)>>2]=_;_=N+(C>>>3)|0;N=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(C&7)>>v;v=I+C|0;C=x>>>0>v>>>0?v:x;c[ua>>2]=C;c[k+((L|7)<<2)>>2]=N;Ba=C}}while(0);ha=Q+1|0;aa=c[P>>2]|0;if((ha|0)<(aa|0)){Q=ha;$=Ba}else{Ga=aa;break}}}else{Ga=da}$=e+39808+(h*14336|0)+(ja<<11)|0;Q=$|0;le[c[qa>>2]&1023](sa,$|0,ya,ra,Ga<<3);$=c[P>>2]|0;if(($|0)>0){aa=0;ha=$;while(1){if((c[e+2212+(ja<<8)+(aa<<2)>>2]|0)==0){Ha=ha}else{if((c[ea>>2]|0)==0){Ia=+g[e+39808+(h*14336|0)+(ja<<11)+(aa<<5)>>2];Ja=e+4004+(ja<<8)+(aa<<2)|0}else{C=e+4004+(ja<<8)+(aa<<2)|0;N=c[C>>2]|0;L=e+39808+(h*14336|0)+(ja<<11)+(aa<<5)|0;za=+g[L>>2]+(+(b[1809416+(N<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+12>>2]+ +(b[1809418+(N<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+8>>2]+ +(b[1809420+(N<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+4>>2]+ +(b[1809422+(N<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)>>2])*.0001220703125;g[L>>2]=za;Ia=za;Ja=C}C=1;za=Ia;do{L=c[Ja>>2]|0;Ka=za*+(b[1809416+(L<<3)>>1]|0);do{if((C|0)<2){if((c[ea>>2]|0)==0){La=Ka;break}La=Ka+ +(b[1809418+(L<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+(C+2<<2)>>2]}else{La=Ka+ +(b[1809418+(L<<3)>>1]|0)*+g[e+39808+(h*14336|0)+(ja<<11)+(aa<<5)+(C-2<<2)>>2]}}while(0);do{if((C|0)<3){if((c[ea>>2]|0)==0){Ma=La;break}Na=La+ +(b[1809420+(L<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+(C+1<<2)>>2];R=149}else{Ka=La+ +(b[1809420+(L<<3)>>1]|0)*+g[e+39808+(h*14336|0)+(ja<<11)+(aa<<5)+(C-3<<2)>>2];if((C|0)<4){if((c[ea>>2]|0)==0){Ma=Ka;break}else{Na=Ka;R=149;break}}else{Ma=Ka+ +(b[1809422+(L<<3)>>1]|0)*+g[e+39808+(h*14336|0)+(ja<<11)+(aa<<5)+(C-4<<2)>>2];break}}}while(0);if((R|0)==149){R=0;Ma=Na+ +(b[1809422+(L<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+(C<<2)>>2]}N=e+39808+(h*14336|0)+(ja<<11)+(aa<<5)+(C<<2)|0;za=Ma*.0001220703125+ +g[N>>2];g[N>>2]=za;C=C+1|0;}while((C|0)<8);Ha=c[P>>2]|0}C=aa+1|0;if((C|0)<(Ha|0)){aa=C;ha=Ha}else{Oa=Ha;break}}}else{Oa=$}ha=e+124+(ja<<2)|0;aa=c[ha>>2]|0;if((aa|0)>(Oa|0)){if((c[ma>>2]|0)==0){yDb(c[pa>>2]|0,48,2069096,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[ma>>2]=c[ma>>2]|1;Pa=c[P>>2]|0;Qa=c[ha>>2]|0}else{Pa=Oa;Qa=aa}Ke[c[na>>2]&1023](Q,e+14920+(ja<<8)|0,948568,oa,e+9380+(ja<<9)|0,Pa,Qa)}aa=ja+1|0;ha=c[va>>2]|0;if((aa|0)<(ha|0)){ja=aa}else{Ra=ha;break c}}if((R|0)==196){i=j;return r|0}yDb(c[pa>>2]|0,16,2073624,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=j;return r|0}else{Ra=wa}}while(0);if((c[e+68>>2]|0)==0){if((Aa|0)==((c[e+2084+(c[m>>2]<<2)>>2]|0)-1|0)){R=138}}else{R=138}do{if((R|0)==138){Aa=e+290776|0;wa=c[Aa>>2]|0;Qa=c[e+290784>>2]|0;Pa=(c[e+290768>>2]|0)+(wa>>>3)|0;Oa=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(wa&7);Pa=wa+16|0;c[Aa>>2]=Qa>>>0>Pa>>>0?Pa:Qa;if((Oa&-65536|0)==-65536){break}yDb(c[e+4>>2]|0,16,2064480,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=j;return r|0}}while(0);if((Ra|0)>(f|0)){Oa=f;Qa=Ra;while(1){Ra=e+152+(Oa<<2)|0;if((c[Ra>>2]|0)>0){Pa=0;do{Aa=e+39808+(h*14336|0)+(Oa<<11)+(Pa<<5)+16|0;wa=c[Aa+4>>2]|0;Ha=e+17200+(Oa<<10)+(Pa<<4)|0;c[Ha>>2]=c[Aa>>2];c[Ha+4>>2]=wa;wa=e+39808+(h*14336|0)+(Oa<<11)+(Pa<<5)+24|0;Ha=c[wa+4>>2]|0;Aa=e+17200+(Oa<<10)+(Pa<<4)+8|0;c[Aa>>2]=c[wa>>2];c[Aa+4>>2]=Ha;Pa=Pa+1|0;}while((Pa|0)<(c[Ra>>2]|0));Sa=c[va>>2]|0}else{Sa=Qa}Ra=Oa+1|0;if((Ra|0)<(Sa|0)){Oa=Ra;Qa=Sa}else{break}}}Sa=(c[p>>2]|0)+1|0;c[p>>2]=Sa;Qa=c[m>>2]|0;if((Sa|0)<(c[e+2084+(Qa<<2)>>2]|0)){Ta=Qa}else{c[p>>2]=0;p=Qa+1|0;c[m>>2]=p;Ta=p}if(!((Ta|0)>=(c[o>>2]|0)&(f|0)==0)){r=0;i=j;return r|0}if((c[e+48>>2]|0)!=0){f=e+290776|0;o=c[f>>2]|0;Ta=-o|0;p=(c[e+290784>>2]|0)-o|0;if((Ta|0)>32){Ua=Ta}else{Ua=(p|0)<32?p:32}c[f>>2]=Ua+o}do{if((c[e+52>>2]|0)!=0){o=e+290776|0;Ua=c[o>>2]|0;f=e+290784|0;p=c[f>>2]|0;Ta=e+290768|0;m=c[Ta>>2]|0;Qa=m+(Ua>>>3)|0;Sa=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Ua&7)>>>26;Qa=Ua+6|0;Ua=p>>>0>Qa>>>0?Qa:p;c[o>>2]=Ua;Qa=-Ua|0;Oa=Qa&31;h=p-Ua|0;if((Oa|0)<(Qa|0)){Va=Qa}else{Va=(h|0)<(Oa|0)?h:Oa}Oa=Va+Ua|0;c[o>>2]=Oa;Ua=Oa+(Sa<<3)|0;Sa=m+(Oa>>>3)|0;h=(fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Oa&7)&-65536;Sa=Oa+16|0;Oa=p>>>0>Sa>>>0?Sa:p;c[o>>2]=Oa;Sa=m+(Oa>>>3)|0;Qa=(fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Oa&7)>>>16;Sa=Oa+16|0;Oa=p>>>0>Sa>>>0?Sa:p;c[o>>2]=Oa;Sa=Qa|h;if(!((Sa|0)==-1710160480)){yDb(c[e+4>>2]|0,16,2115144,(q=i,i=i+8|0,c[q>>2]=Sa,q)|0);i=q;r=-1094995529;i=j;return r|0}Sa=d[m+(Oa>>>3)|0]|0;h=((Oa|0)<(p|0))+Oa|0;c[o>>2]=h;if((Sa&128>>>((Oa&7)>>>0)|0)==0){Wa=h;Xa=m;Ya=p}else{DDb(c[e+4>>2]|0,2100728,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=c[o>>2]|0;m=c[f>>2]|0;h=(-p&4)+p|0;p=m>>>0>h>>>0?h:m;c[o>>2]=p;h=-p|0;Oa=m-p|0;if((h|0)>44){Za=h}else{Za=(Oa|0)<44?Oa:44}Oa=Za+p|0;c[o>>2]=Oa;Wa=Oa;Xa=c[Ta>>2]|0;Ya=m}m=d[Xa+(Wa>>>3)|0]<<(Wa&7)>>>7;Oa=((Wa|0)<(Ya|0))+Wa|0;c[o>>2]=Oa;p=m&1;a[e+14852|0]=p;do{if(p<<24>>24==0){_a=Oa;$a=Ya}else{m=Xa+(Oa>>>3)|0;h=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(Oa&7)>>>29;m=Oa+3|0;c[o>>2]=Ya>>>0>m>>>0?m:Ya;switch(h|0){case 0:{a[e+14853|0]=0;ab=0;break};case 1:{a[e+14853|0]=2;ab=2;break};case 2:{a[e+14853|0]=4;ab=4;break};case 3:{a[e+14853|0]=5;ab=5;break};case 4:{a[e+14853|0]=6;ab=6;break};case 5:{a[e+14853|0]=8;ab=8;break};case 6:{a[e+14853|0]=7;ab=7;break};default:{yDb(c[e+4>>2]|0,16,2093976,(q=i,i=i+8|0,c[q>>2]=h,q)|0);i=q;r=-1094995529;i=j;return r|0}}h=e+14853|0;m=e+72|0;Sa=0;Qa=c[va>>2]|0;Ra=c[m>>2]|0;Pa=ab;f:while(1){if((((Ra|0)!=0)+Qa|0)>0){pa=0;do{Ha=c[o>>2]|0;Aa=c[f>>2]|0;wa=(c[Ta>>2]|0)+(Ha>>>3)|0;bb=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Ha&7)>>>23;wa=Ha+9|0;c[o>>2]=Aa>>>0>wa>>>0?wa:Aa;if((bb&254)>>>0>241>>>0){break f}b[e+14854+(pa<<3)+(Sa<<1)>>1]=bb;pa=pa+1|0;cb=c[va>>2]|0;db=c[m>>2]|0;}while((pa|0)<(((db|0)!=0)+cb|0));eb=cb;fb=db;gb=a[h]|0}else{eb=Qa;fb=Ra;gb=Pa}pa=Sa+1|0;if((pa|0)<(d[1407072+(gb&255)|0]|0)){Sa=pa;Qa=eb;Ra=fb;Pa=gb}else{R=184;break}}if((R|0)==184){_a=c[o>>2]|0;$a=c[f>>2]|0;break}yDb(c[e+4>>2]|0,16,2088848,(q=i,i=i+8|0,c[q>>2]=bb,q)|0);i=q;r=-1094995529;i=j;return r|0}}while(0);Ta=-_a&7;if((Ta|0)==0){hb=_a}else{Oa=Ta+_a|0;Ta=$a>>>0>Oa>>>0?Oa:$a;c[o>>2]=Ta;hb=Ta}Ta=hb+16|0;Oa=$a>>>0>Ta>>>0?Ta:$a;c[o>>2]=Oa;Ta=Ua-Oa|0;if((Ta|0)<0){yDb(c[e+4>>2]|0,16,2083992,(q=i,i=i+8|0,c[q>>2]=-Ta,q)|0);i=q;r=-1094995529;i=j;return r|0}if((Ua|0)==(Oa|0)){break}DDb(c[e+4>>2]|0,2078504,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;Oa=c[o>>2]|0;p=-Oa|0;Pa=(c[f>>2]|0)-Oa|0;if((Ta|0)<(p|0)){ib=p}else{ib=(Pa|0)<(Ta|0)?Pa:Ta}c[o>>2]=ib+Oa}}while(0);if((c[e+16>>2]|0)==0){r=0;i=j;return r|0}if((c[e+44>>2]|0)==0){r=0;i=j;return r|0}ib=e+290776|0;q=c[e+290784>>2]|0;e=(c[ib>>2]|0)+16|0;c[ib>>2]=q>>>0>e>>>0?e:q;r=0;i=j;return r|0}function I0(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;f=i;i=i+32|0;h=f|0;j=(e|0)!=0;e=a+290776|0;k=c[e>>2]|0;l=c[a+290784>>2]|0;m=c[a+290768>>2]|0;if(j){n=m+(k>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7)>>>25;n=k+7|0;p=l>>>0>n>>>0?n:l;c[e>>2]=p;q=k;r=(o<<3)+8|0;s=p}else{q=0;r=0;s=k}k=a+290776|0;p=a+290784|0;o=a+290768|0;e=m+(s>>>3)|0;n=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(s&7)>>>29;e=s+3|0;s=l>>>0>e>>>0?e:l;c[k>>2]=s;e=n+1|0;n=e+b|0;c[a+116>>2]=n;t=a+120|0;c[t>>2]=n;do{if(j){u=a+290816|0;v=c[u>>2]|0;w=m+(s>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(s&7)>>>((38-v|0)>>>0);w=v-6+s|0;c[k>>2]=l>>>0>w>>>0?w:l;w=a+290812|0;c[a+290824+(c[w>>2]<<2)>>2]=x<<6;c[a+290840+(c[w>>2]<<2)>>2]=e;x=c[k>>2]|0;v=c[o>>2]|0;y=d[v+(x>>>3)|0]|0;z=c[p>>2]|0;A=((x|0)<(z|0))+x|0;c[k>>2]=A;if((y&128>>>((x&7)>>>0)|0)==0){B=c[t>>2]|0;break}x=(d[v+(A>>>3)|0]|0)<<(A&7)>>>7;y=((A|0)<(z|0))+A|0;c[k>>2]=y;A=x&1;x=v+(y>>>3)|0;v=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7)>>>26;x=y+6|0;c[k>>2]=z>>>0>x>>>0?x:z;g[a+290856+(c[w>>2]<<2)>>2]=1.0/+g[1405432+((v<<2)-4<<2)>>2];v=c[t>>2]|0;z=(v|0)>(b|0);if(!z){B=v;break}x=c[u>>2]|0;y=c[p>>2]|0;C=c[o>>2]|0;D=b;E=c[k>>2]|0;do{F=C+(E>>>3)|0;G=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>((32-x|0)>>>0);F=E+x|0;E=y>>>0>F>>>0?F:y;c[k>>2]=E;c[h+(D<<2)>>2]=G;D=D+1|0;}while((D|0)<(v|0));if(!z){B=v;break}D=a+290872|0;E=a+4|0;y=a+290820|0;x=b;while(1){TGb(a+290876+(x<<7)|0,0,128)|0;c[D>>2]=c[D>>2]|A<<x;if((c[u>>2]|0)>0){C=c[h+(x<<2)>>2]|0;G=0;do{F=1<<G;do{if((C&F|0)!=0){if((F|0)==32){yDb(c[E>>2]|0,24,2126816,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;break}H=c[k>>2]|0;I=c[p>>2]|0;J=(c[o>>2]|0)+(H>>>3)|0;K=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>25;J=H+7|0;c[k>>2]=I>>>0>J>>>0?J:I;L=(K&64|0)!=0?1.0:-1.0;M=+g[1405432+((K<<2&252)-4<<2)>>2];K=c[y>>2]&-33;I=c[w>>2]|0;a:do{if((I|0)<-1){N=0;O=K}else{J=-1;H=0;P=K;while(1){if((P&F|0)!=0){N=H;O=P;break a}Q=P-(P>>>1&1431655765)|0;R=(Q>>>2&858993459)+(Q&858993459)|0;Q=(R>>>4)+R&252645135;R=(Q>>>8)+Q|0;Q=((R>>>16)+R&63)+H|0;R=J+1|0;S=c[a+290824+(R<<2)>>2]|0;if((R|0)>(I|0)){N=Q;O=S;break}else{J=R;H=Q;P=S}}}}while(0);I=O&F-1;K=I-(I>>>1&1431655765)|0;I=(K>>>2&858993459)+(K&858993459)|0;K=(I>>>4)+I&252645135;I=(K>>>8)+K|0;g[a+290876+(x<<7)+(((I>>>16)+I&63)+N<<2)>>2]=M*L}}while(0);G=G+1|0;}while((G|0)<(c[u>>2]|0))}G=x+1|0;C=c[t>>2]|0;if((G|0)<(C|0)){x=G}else{B=C;break}}}else{B=n}}while(0);if((B|0)>7){c[t>>2]=7;T=7}else{T=B}if((T|0)>(b|0)){B=b;while(1){n=c[k>>2]|0;N=c[p>>2]|0;O=(c[o>>2]|0)+(n>>>3)|0;h=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(n&7)>>>27;O=n+5|0;c[k>>2]=N>>>0>O>>>0?O:N;c[a+124+(B<<2)>>2]=h+2;h=B+1|0;N=c[t>>2]|0;if((h|0)<(N|0)){B=h}else{U=N;break}}}else{U=T}if((U|0)>(b|0)){T=b;while(1){B=c[k>>2]|0;N=c[p>>2]|0;h=(c[o>>2]|0)+(B>>>3)|0;O=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(B&7)>>>27;h=B+5|0;c[k>>2]=N>>>0>h>>>0?h:N;c[a+152+(T<<2)>>2]=O+1;O=T+1|0;N=c[t>>2]|0;if((O|0)<(N|0)){T=O}else{V=N;break}}}else{V=U}if((V|0)==(b|0)){W=V}else{U=c[o>>2]|0;T=V-b|0;V=a+180+(b<<2)|0;while(1){N=T-1|0;O=c[k>>2]|0;h=c[p>>2]|0;B=U+(O>>>3)|0;n=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(O&7)>>>29;B=O+3|0;c[k>>2]=h>>>0>B>>>0?B:h;c[V>>2]=n;if((N|0)==0){break}T=N;V=V+4|0}W=c[t>>2]|0}b:do{if((W|0)!=(b|0)){V=c[o>>2]|0;T=W-b|0;U=a+208+(b<<2)|0;while(1){N=T-1|0;n=c[k>>2]|0;h=c[p>>2]|0;B=V+(n>>>3)|0;O=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(n&7)>>>30;B=n+2|0;c[k>>2]=h>>>0>B>>>0?B:h;c[U>>2]=O;if((N|0)==0){break}T=N;U=U+4|0}U=c[t>>2]|0;if((U|0)==(b|0)){break}T=c[o>>2]|0;V=U-b|0;U=a+236+(b<<2)|0;while(1){N=V-1|0;O=c[k>>2]|0;h=c[p>>2]|0;B=T+(O>>>3)|0;n=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(O&7)>>>29;B=O+3|0;c[k>>2]=h>>>0>B>>>0?B:h;c[U>>2]=n;if((N|0)==0){break}V=N;U=U+4|0}U=c[t>>2]|0;if((U|0)==(b|0)){break}V=c[o>>2]|0;T=U-b|0;U=a+264+(b<<2)|0;while(1){N=T-1|0;n=c[k>>2]|0;h=c[p>>2]|0;B=V+(n>>>3)|0;O=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(n&7)>>>29;B=n+3|0;c[k>>2]=h>>>0>B>>>0?B:h;c[U>>2]=O;if((N|0)==0){break b}T=N;U=U+4|0}}}while(0);if((b|0)==0){TGb(a+292|0,0,896)|0}W=1;U=c[t>>2]|0;while(1){if((U|0)>(b|0)){T=c[1405312+(W<<2)>>2]|0;V=32-T|0;N=b;while(1){O=c[k>>2]|0;h=c[p>>2]|0;B=(c[o>>2]|0)+(O>>>3)|0;n=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(O&7)>>>(V>>>0);B=O+T|0;c[k>>2]=h>>>0>B>>>0?B:h;c[a+292+(N<<7)+(W<<2)>>2]=n;n=N+1|0;h=c[t>>2]|0;if((n|0)<(h|0)){N=n}else{X=h;break}}}else{X=U}N=W+1|0;if((N|0)<11){W=N;U=X}else{Y=0;Z=X;break}}while(1){if((Z|0)>(b|0)){X=b;while(1){g[a+1188+(X<<7)+(Y<<2)>>2]=1.0;U=X+1|0;W=c[t>>2]|0;if((U|0)<(W|0)){X=U}else{_=W;break}}}else{_=Z}X=Y+1|0;if((X|0)<11){Y=X;Z=_}else{$=1;aa=_;break}}while(1){if((aa|0)>(b|0)){_=c[1405264+($<<2)>>2]|0;Z=b;Y=aa;while(1){if((c[a+292+(Z<<7)+($<<2)>>2]|0)<(_|0)){X=c[k>>2]|0;W=c[p>>2]|0;U=(c[o>>2]|0)+(X>>>3)|0;N=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(X&7)>>>30;U=X+2|0;c[k>>2]=W>>>0>U>>>0?U:W;g[a+1188+(Z<<7)+($<<2)>>2]=+g[1405360+(N<<2)>>2];ba=c[t>>2]|0}else{ba=Y}N=Z+1|0;if((N|0)<(ba|0)){Z=N;Y=ba}else{ca=ba;break}}}else{ca=aa}Y=$+1|0;if((Y|0)<11){$=Y;aa=ca}else{break}}if(!j){if((c[a+16>>2]|0)==0){da=a+290788|0;c[da>>2]=0;ea=a+290792|0;c[ea>>2]=0;i=f;return}j=c[p>>2]|0;ca=(c[k>>2]|0)+16|0;c[k>>2]=j>>>0>ca>>>0?ca:j;da=a+290788|0;c[da>>2]=0;ea=a+290792|0;c[ea>>2]=0;i=f;return}j=c[k>>2]|0;ca=q+r|0;if((ca|0)<=(j|0)){da=a+290788|0;c[da>>2]=0;ea=a+290792|0;c[ea>>2]=0;i=f;return}r=ca-j|0;ca=-j|0;q=(c[p>>2]|0)-j|0;if((r|0)<(ca|0)){fa=ca}else{fa=(q|0)<(r|0)?q:r}c[k>>2]=fa+j;da=a+290788|0;c[da>>2]=0;ea=a+290792|0;c[ea>>2]=0;i=f;return}function J0(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+32|0;e=b|0;f=a+290776|0;g=c[f>>2]|0;h=a+290784|0;j=c[h>>2]|0;k=c[a+290768>>2]|0;l=k+(g>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(g&7)>>>26;l=g+6|0;n=(j>>>0>l>>>0?l:j)+1|0;l=j>>>0>n>>>0?n:j;c[f>>2]=l;n=k+(l>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(l&7)>>>27;n=l+5|0;l=j>>>0>n>>>0?n:j;c[f>>2]=l;n=o+1|0;p=k+(l>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(l&7)>>>30;p=l+2|0;l=j>>>0>p>>>0?p:j;c[f>>2]=l;p=q+1|0;q=k+(l>>>3)|0;r=0;s=l;t=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(l&7);do{l=s+14|0;s=j>>>0>l>>>0?l:j;c[f>>2]=s;c[e+(r<<2)>>2]=(t>>>18)+1;r=r+1|0;l=k+(s>>>3)|0;t=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(s&7)}while((r|0)<(p|0));r=s+n|0;s=j>>>0>r>>>0?r:j;c[f>>2]=s;c[a+290820>>2]=t>>>((o^31)>>>0);c[a+290816>>2]=n;c[a+290872>>2]=0;n=g-24+(m<<3)|0;if((n|0)>(s|0)){m=n-s|0;n=-s|0;g=j-s|0;if((m|0)<(n|0)){u=n}else{u=(g|0)<(m|0)?g:m}m=u+s|0;c[f>>2]=m;v=m}else{v=s}s=a+120|0;m=a+290812|0;u=a+20|0;g=a+4|0;n=0;j=v;while(1){v=c[s>>2]|0;c[m>>2]=n;I0(a,v,1);if((c[u>>2]|0)>7){o=0;do{if((H0(a,v,o)|0)!=0){yDb(c[g>>2]|0,16,2133208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}o=o+1|0;}while((o|0)<((c[u>>2]|0)/8|0|0))}o=c[f>>2]|0;v=(c[e+(n<<2)>>2]<<3)+j|0;if((v|0)>(o|0)){t=v-o|0;v=-o|0;r=(c[h>>2]|0)-o|0;if((t|0)<(v|0)){w=v}else{w=(r|0)<(t|0)?r:t}t=w+o|0;c[f>>2]=t;x=t}else{x=o}o=n+1|0;if((o|0)<(p|0)){n=o;j=x}else{break}}c[m>>2]=p;i=b;return}function K0(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((e|0)<5){h=c[8654844+(e*20|0)>>2]|0;i=c[8654840+(e*20|0)>>2]|0;j=c[2163709]|0;k=a+8|0;l=c[k>>2]|0;m=c[a+16>>2]|0;n=c[a>>2]|0;o=n+(l>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>((32-i|0)>>>0);o=b[h+(p<<2)>>1]|0;q=b[h+(p<<2)+2>>1]|0;p=q<<16>>16;do{if((j|0)>1&q<<16>>16<0){r=l+i|0;s=m>>>0>r>>>0?r:m;r=n+(s>>>3)|0;t=((fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((p+32|0)>>>0))+o|0;r=b[h+(t<<2)>>1]|0;u=b[h+(t<<2)+2>>1]|0;t=u<<16>>16;if(!((j|0)>2&u<<16>>16<0)){v=t;w=r;x=s;break}u=s-p|0;s=m>>>0>u>>>0?u:m;u=n+(s>>>3)|0;y=((fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(s&7)>>>((t+32|0)>>>0))+r|0;v=b[h+(y<<2)+2>>1]|0;w=b[h+(y<<2)>>1]|0;x=s}else{v=p;w=o;x=l}}while(0);l=v+x|0;c[k>>2]=m>>>0>l>>>0?l:m;m=w+f+(c[2163700]|0)|0;w=(1<<g)-1|0;if((m|0)<0){z=0;return z|0}z=(m|0)>(w|0)?w:m;return z|0}else{if((e|0)>=8){z=f;return z|0}f=e+1|0;if((f|0)>(g|0)){m=a+8|0;w=c[a+16>>2]|0;l=(c[m>>2]|0)+(f-g)|0;k=w>>>0>l>>>0?l:w;c[m>>2]=k;l=(c[a>>2]|0)+(k>>>3)|0;x=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(k&7)>>>((32-g|0)>>>0);l=k+g|0;c[m>>2]=w>>>0>l>>>0?l:w;z=x;return z|0}else{x=a+8|0;w=c[x>>2]|0;l=c[a+16>>2]|0;m=(c[a>>2]|0)+(w>>>3)|0;a=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(w&7)>>>((31-e|0)>>>0);e=w+f|0;c[x>>2]=l>>>0>e>>>0?e:l;z=a;return z|0}}return 0}function L0(a){a=a|0;c[a>>2]=642;c[a+4>>2]=966;c[a+8>>2]=2;c[a+12>>2]=8;return}function M0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0;d=c;c=a+252|0;e=a;a=0;while(1){f=+g[b>>2];h=+g[d>>2];i=+g[b-28>>2];j=+g[b-4>>2];k=+g[d+4>>2];l=+g[b-24>>2];m=+g[b-8>>2];n=+g[d+8>>2];o=+g[b-20>>2];p=+g[b-12>>2];q=+g[d+12>>2];r=+g[b-16>>2];s=+g[d+16>>2];t=+g[d+20>>2];u=+g[d+24>>2];v=+g[d+28>>2];g[e>>2]=f*h+0.0+j*k+m*n+p*q+r*s+o*t+l*u+i*v;g[c>>2]=h*i+0.0+k*l+n*o+q*r+s*p+t*m+u*j+v*f;w=a+1|0;if((w|0)<32){d=d+32|0;c=c-4|0;e=e+4|0;a=w}else{break}}return}function N0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0;d=c;c=a+508|0;e=a;a=0;while(1){f=+g[b>>2];h=+g[d>>2];i=+g[b-12>>2];j=+g[b-4>>2];k=+g[d+4>>2];l=+g[b-8>>2];m=+g[d+8>>2];n=+g[d+12>>2];g[e>>2]=f*h+0.0+j*k+l*m+i*n;g[c>>2]=h*i+0.0+k*l+m*j+n*f;o=a+1|0;if((o|0)<64){d=d+16|0;c=c-4|0;e=e+4|0;a=o}else{break}}return}function O0(a,b,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=+l;var m=0,n=0;do{if((b|0)<32){TGb(k+(b<<2)|0,0,128-(b<<2)|0)|0;m=d|0;if((b|0)>0){n=m;break}Ce[c[m>>2]&3](e,f,g,h,i,j,k,l);Ce[c[m>>2]&3](e,f,g,h,i,j+128|0,k,l);Ce[c[m>>2]&3](e,f,g,h,i,j+256|0,k,l);Ce[c[m>>2]&3](e,f,g,h,i,j+384|0,k,l);Ce[c[m>>2]&3](e,f,g,h,i,j+512|0,k,l);Ce[c[m>>2]&3](e,f,g,h,i,j+640|0,k,l);Ce[c[m>>2]&3](e,f,g,h,i,j+768|0,k,l);Ce[c[m>>2]&3](e,f,g,h,i,j+896|0,k,l);return}else{n=d|0}}while(0);d=0;m=j;while(1){j=0;do{c[k+(j<<2)>>2]=c[a+(j<<5)+(d<<2)>>2]^(j<<30)-1073741824&-2147483648;j=j+1|0;}while((j|0)<(b|0));Ce[c[n>>2]&3](e,f,g,h,i,m,k,l);j=d+1|0;if((j|0)<8){d=j;m=m+128|0}else{break}}return}function P0(b,d,e,f,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;var k=0,l=0.0;if((i|0)<(j|0)){k=i}else{return}do{i=c[d+(k<<2)>>2]|0;l=+(c[h+(k<<3)>>2]|0)*.0625;g[b+(k<<5)>>2]=l*+(a[e+(i<<5)+f|0]|0);g[b+(k<<5)+4>>2]=l*+(a[f+1+(e+(i<<5))|0]|0);g[b+(k<<5)+8>>2]=l*+(a[f+2+(e+(i<<5))|0]|0);g[b+(k<<5)+12>>2]=l*+(a[f+3+(e+(i<<5))|0]|0);g[b+(k<<5)+16>>2]=l*+(a[f+4+(e+(i<<5))|0]|0);g[b+(k<<5)+20>>2]=l*+(a[f+5+(e+(i<<5))|0]|0);g[b+(k<<5)+24>>2]=l*+(a[f+6+(e+(i<<5))|0]|0);g[b+(k<<5)+28>>2]=l*+(a[f+7+(e+(i<<5))|0]|0);k=k+1|0;}while((k|0)<(j|0));return}function Q0(a){a=a|0;var b=0,d=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0.0,D=0.0,E=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0,M=0,N=0;b=i;d=c[a+60>>2]|0;f=a+448|0;h=c[f>>2]|0;j=c[f+4>>2]|0;f=a+416|0;k=c[f>>2]|0;c[d+36>>2]=k;l=d+32|0;c[l>>2]=k;k=c[f>>2]|0;if((k|0)==3){m=1}else{m=(k|0)==6|0}k=d+40|0;c[k>>2]=m;c[d+56>>2]=8876176;c[d+60>>2]=8874096;c[d+44016>>2]=-2047;c[d+44020>>2]=-2047;if((h|0)==0&(j|0)==0){yDb(a,24,1896728,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=jBb(c[f>>2]|0)|0;o=F;p=m}else{o=j;p=h}h=1551;j=0;m=1543;f=0;q=3;r=0;s=4;t=0;if((p|0)==1539&(o|0)==0){c[d+52>>2]=8}else if((p|0)==(q|0)&(o|0)==(r|0)){c[d+52>>2]=2}else if((p|0)==(h|0)&(o|0)==(j|0)){c[d+52>>2]=9}else if((p|0)==(m|0)&(o|0)==(f|0)){c[d+52>>2]=9}else if((p|0)==(s|0)&(o|0)==(t|0)){c[d+52>>2]=0}else{yDb(a,16,2353904,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;u=-1163346256;i=b;return u|0}if((c[k>>2]|0)!=0){c[l>>2]=(c[l>>2]|0)-1}t=a+412|0;o=0;while(1){if((o|0)>=9){break}if((c[483176+(o<<2)>>2]|0)==(c[t>>2]|0)){break}else{o=o+1|0}}if((o|0)==9){u=-22;i=b;return u|0}c[d+44>>2]=o;o=a+72|0;s=c[o>>2]|0;if((s-32e3|0)>>>0>3808e3>>>0){yDb(a,16,2333872,(n=i,i=i+8|0,c[n>>2]=s,n)|0);i=n;u=-22;i=b;return u|0}else{v=0}while(1){w=c[1407664+(v<<2)>>2]|0;if(w>>>0<s>>>0){v=v+1|0}else{break}}c[d+48>>2]=v;c[o>>2]=w;o=c[t>>2]|0;t=((o-1+(w<<9)|0)/(o|0)|0)+31&-32;c[d+28>>2]=t;if((t|0)<(((c[l>>2]|0)*1389|0)+132+((c[k>>2]|0)*72|0)|0)|(t|0)>131072){u=-22;i=b;return u|0}c[d+24>>2]=(t|7|0)/8|0;c[a+424>>2]=512;if((c[2190600]|0)==0){x=0}else{u=0;i=b;return u|0}while(1){y=+(x|0);c[8762400+(x<<2)>>2]=~~(+T(y*3.141592653589793*.0009765625)*2147483647.0);c[8844256+(x<<2)>>2]=~~(+S(+10.0,+(y*-.005))*2147483647.0);a=x+1|0;if((a|0)<2048){x=a}else{z=0;break}}while(1){x=~~(+g[852032+(z<<2)>>2]*33554432.0);c[5012064+(z<<2)>>2]=x;c[5012064+(511-z<<2)>>2]=x;x=z+1|0;if((x|0)<256){z=x}else{A=0;break}}while(1){c[8874128+(A<<2)>>2]=~~(+g[105e4+(A<<2)>>2]*68719476736.0);c[8876176+(A<<2)>>2]=~~(+g[1054096+(A<<2)>>2]*68719476736.0);z=A+1|0;if((z|0)<512){A=z}else{B=0;break}}while(1){y=+(c[483176+(B<<2)>>2]|0);A=0;do{C=+(e[1312528+(A<<1)>>1]|0|0);D=+(e[1341056+(A<<1)>>1]|0|0);z=0;do{E=(+(z|0)+.5)*y*.001953125;G=E/1.0e3;H=G+ -3.4;I=G+ -8.7;J=G*G;K=+S(+G,+-.8)*-3.64+ +_(H*H*-.6)*6.8- +_(I*I*-.15)*6.0-J*J*6.0e-4;J=(E-C)/D;E=J*J+1.0;c[8936440+(B*25600|0)+(A<<10)+(z<<2)>>2]=~~((K+ +ad(+(1.0/(E*E)))*20.0)*10.0);z=z+1|0;}while((z|0)<256);A=A+1|0;}while((A|0)<25);A=B+1|0;if((A|0)<9){B=A}else{L=0;break}}while(1){c[8852448+(L<<2)>>2]=~~(+ad(+(+S(+10.0,+(+(L|0)*-.01))+1.0))*100.0);B=L+1|0;if((B|0)<256){L=B}else{M=0;break}}while(1){y=+(M|0)+.5;L=0;D=0.0;do{D=D+ +T(y*(+(L|0)+.5+-256.0)*6.283185307179586*.001953125)*+((L>>>5&2^2)-1|0)*+g[105e4+(L<<2)>>2];L=L+1|0;}while((L|0)<512);c[8874064+(M<<2)>>2]=~~(+ad(+D)*200.0);L=M+1|0;if((L|0)<8){M=L}else{N=0;break}}while(1){y=+(N|0)+.5;M=0;C=0.0;do{C=C+ +T(y*(+(M|0)+.5+-256.0)*6.283185307179586*.001953125)*+((M>>>5&2^2)-1|0)*+g[1054096+(M<<2)>>2];M=M+1|0;}while((M|0)<512);c[8874096+(N<<2)>>2]=~~(+ad(+C)*200.0);M=N+1|0;if((M|0)<8){N=M}else{u=0;break}}i=b;return u|0}function R0(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0;h=i;i=i+12552|0;j=h|0;k=h+2048|0;l=h+4096|0;m=h+6144|0;n=h+7168|0;o=h+9216|0;p=h+10240|0;q=h+10248|0;r=h+12296|0;s=c[b+60>>2]|0;t=s;u=s+24|0;v=c[u>>2]|0;w=r0a(b,e,v,(v|0)<0|0?-1:0)|0;if((w|0)<0){y=w;i=h;return y|0}w=c[f>>2]|0;v=r;z=s+32|0;if((c[z>>2]|0)>0){A=s+56|0;B=s+36|0;C=0;do{D=0;while(1){c[q+(D<<2)>>2]=c[t+80+(D*24|0)+(C<<2)>>2];E=D+1|0;if((E|0)<512){D=E}else{G=0;H=0;break}}while(1){TGb(v|0,0,256)|0;D=c[A>>2]|0;E=H;I=0;J=0;while(1){K=c[q+(E<<2)>>2]|0;L=c[D+(J<<2)>>2]|0;M=gHb(L,(L|0)<0|0?-1:0,K,(K|0)<0|0?-1:0)|0;YGb(M,F,-2147483648,0)|0;M=r+(I<<2)|0;c[M>>2]=F+(c[M>>2]|0);N=I+1&63;M=E+1|0;if((M|0)<512){E=M;I=N;J=J+1|0}else{break}}if((H|0)==0){O=16}else{J=0;I=N;E=512-H|0;while(1){M=c[q+(J<<2)>>2]|0;K=c[D+(E<<2)>>2]|0;L=gHb(K,(K|0)<0|0?-1:0,M,(M|0)<0|0?-1:0)|0;YGb(L,F,-2147483648,0)|0;L=r+(I<<2)|0;c[L>>2]=F+(c[L>>2]|0);L=J+1|0;if((L|0)<(H|0)){J=L;I=I+1&63;E=E+1|0}else{O=16;break}}}while(1){E=r+(O<<2)|0;c[E>>2]=(c[E>>2]|0)-(c[r+(31-O<<2)>>2]|0);E=O+1|0;if((E|0)<32){O=E}else{P=32;break}}while(1){E=r+(P<<2)|0;c[E>>2]=(c[r+(95-P<<2)>>2]|0)+(c[E>>2]|0);E=P+1|0;if((E|0)<48){P=E}else{Q=0;break}}while(1){E=Q<<4|8;I=16;J=0;do{D=c[r+(I<<2)>>2]|0;L=c[8762400+(((ba((I<<1)+33|0,E)|0)&2040)<<2)>>2]|0;M=gHb(L,(L|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;YGb(M,F,-2147483648,0)|0;J=(F>>3)+J|0;I=I+1|0;}while((I|0)<48);I=Q+1|0;c[t+12368+(G*768|0)+(Q*24|0)+(C<<2)>>2]=(I&2|0)!=0?-J|0:J;if((I|0)<32){Q=I}else{break}}I=G<<5;E=c[B>>2]|0;M=0;do{c[q+(M+H<<2)>>2]=c[w+((ba(M+I|0,E)|0)+C<<2)>>2];M=M+1|0;}while((M|0)<32);M=G+1|0;if((M|0)<16){G=M;H=H+32&511}else{break}}C=C+1|0;}while((C|0)<(c[z>>2]|0))}C=s+40|0;if((c[C>>2]|0)==0){R=0}else{H=s+36|0;G=(c[H>>2]|0)-1|0;B=0;while(1){c[q+(B<<2)>>2]=c[t+80+(B*24|0)+(G<<2)>>2];Q=B+1|0;if((Q|0)<512){B=Q}else{S=0;T=0;break}}while(1){B=T;G=0;Q=0;while(1){r=c[q+(B<<2)>>2]|0;P=c[5012064+(G<<2)>>2]|0;O=gHb(P,(P|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;YGb(O,F,-2147483648,0)|0;U=F+Q|0;O=B+1|0;if((O|0)<512){B=O;G=G+1|0;Q=U}else{break}}if((T|0)==0){V=U}else{Q=0;G=512-T|0;B=U;while(1){O=c[q+(Q<<2)>>2]|0;r=c[5012064+(G<<2)>>2]|0;P=gHb(r,(r|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;YGb(P,F,-2147483648,0)|0;P=F+B|0;O=Q+1|0;if((O|0)<(T|0)){Q=O;G=G+1|0;B=P}else{V=P;break}}}c[t+37712+(S<<2)>>2]=V;B=S<<6;G=c[H>>2]|0;Q=G-1|0;P=0;do{c[q+(P+T<<2)>>2]=c[w+(Q+(ba(P+B|0,G)|0)<<2)>>2];P=P+1|0;}while((P|0)<64);P=S+1|0;if((P|0)<8){S=P;T=T+64&511}else{R=0;break}}}do{c[t+37744+(R<<2)>>2]=-2047;c[t+38768+(R<<2)>>2]=-2047;R=R+1|0;}while((R|0)<256);R=s+44|0;T=s+36|0;S=0;H=384;V=c[z>>2]|0;while(1){if((V|0)>0){U=S<<8|128;P=0;while(1){G=0;B=U;while(1){c[q+(G<<2)>>2]=c[t+80+(B*24|0)+(P<<2)>>2];Q=B+1|0;if((Q|0)<512){G=G+1|0;B=Q}else{break}}B=c[T>>2]|0;G=H;Q=0;while(1){c[q+(G<<2)>>2]=c[w+((ba(Q,B)|0)+P<<2)>>2];O=G+1|0;if((O|0)<512){G=O;Q=Q+1|0}else{break}}Q=c[R>>2]|0;G=0;while(1){B=G<<1;O=c[q+(B<<2)>>2]|0;r=G<<3;N=1073741823-(c[8762400+((r|2)<<2)>>2]>>1)|0;A=gHb(N,(N|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;YGb(A,F,-2147483648,0)|0;c[k+(G<<3)>>2]=F;A=c[q+((B|1)<<2)>>2]|0;B=1073741823-(c[8762400+((r|6)<<2)>>2]>>1)|0;r=gHb(B,(B|0)<0|0?-1:0,A,(A|0)<0|0?-1:0)|0;YGb(r,F,-2147483648,0)|0;c[k+(G<<3)+4>>2]=F;r=G+1|0;if((r|0)<256){G=r}else{W=0;break}}while(1){G=W<<2|2;r=c[8762400+(G<<2)>>2]|0;A=c[k+(W<<3)>>2]|0;B=r;O=(r|0)<0|0?-1:0;r=A;N=(A|0)<0|0?-1:0;A=gHb(r,N,B,O)|0;YGb(A,F,-2147483648,0)|0;A=F;v=c[8762400+((G+1536&2046)<<2)>>2]|0;G=c[k+(W<<3)+4>>2]|0;M=v;E=(v|0)<0|0?-1:0;v=G;I=(G|0)<0|0?-1:0;G=gHb(v,I,M,E)|0;YGb(G,F,-2147483648,0)|0;c[j+(W<<3)>>2]=A-F;A=gHb(v,I,B,O)|0;YGb(A,F,-2147483648,0)|0;A=F;O=gHb(M,E,r,N)|0;YGb(O,F,-2147483648,0)|0;c[j+(W<<3)+4>>2]=A+F;A=W+1|0;if((A|0)<256){W=A}else{X=1;Y=256;break}}while(1){A=(Y|0)/2|0;O=X<<3;if((Y|0)>1){N=0;do{r=N+A|0;E=N;do{M=ba(E,O)|0;B=j+(E<<3)|0;I=c[B>>2]|0;v=E+A|0;G=j+(v<<3)|0;D=c[G>>2]|0;L=j+(E<<3)+4|0;K=c[L>>2]|0;Z=j+(v<<3)+4|0;v=c[Z>>2]|0;_=I-D|0;$=K-v|0;c[B>>2]=I+1+D>>1;c[L>>2]=K+1+v>>1;v=c[8762400+((M&2040)<<2)>>2]|0;K=_;L=(_|0)<0|0?-1:0;_=v;D=(v|0)<0|0?-1:0;v=gHb(_,D,K,L)|0;YGb(v,F,-2147483648,0)|0;v=F;I=c[8762400+((M+1536&2040)<<2)>>2]|0;M=$;B=($|0)<0|0?-1:0;$=I;aa=(I|0)<0|0?-1:0;I=gHb($,aa,M,B)|0;YGb(I,F,-2147483648,0)|0;c[G>>2]=v-F;v=gHb(_,D,M,B)|0;YGb(v,F,-2147483648,0)|0;v=F;B=gHb($,aa,K,L)|0;YGb(B,F,-2147483648,0)|0;c[Z>>2]=F+v;E=E+1|0;}while((E|0)<(r|0));N=N+Y|0;}while((N|0)<256)}else{N=0;do{N=N+Y|0;}while((N|0)<256)}N=Y>>1;if((N|0)==1){ca=0;break}else{X=X<<1;Y=N}}while(1){N=d[1148864+ca|0]|0;A=c[j+(N<<3)>>2]|0;O=ca<<2;J=c[8762400+(O<<2)>>2]|0;r=A;E=(A|0)<0|0?-1:0;A=J;v=(J|0)<0|0?-1:0;J=gHb(A,v,r,E)|0;YGb(J,F,-2147483648,0)|0;J=F;Z=c[j+(N<<3)+4>>2]|0;N=c[8762400+((O+1536&2044)<<2)>>2]|0;O=Z;B=(Z|0)<0|0?-1:0;Z=N;L=(N|0)<0|0?-1:0;N=gHb(Z,L,O,B)|0;YGb(N,F,-2147483648,0)|0;c[l+(ca<<3)>>2]=J-F;J=gHb(O,B,A,v)|0;YGb(J,F,-2147483648,0)|0;J=F;v=gHb(Z,L,r,E)|0;YGb(v,F,-2147483648,0)|0;c[l+(ca<<3)+4>>2]=F+J;J=ca+1|0;if((J|0)<256){ca=J}else{da=0;break}}do{J=c[l+(da<<3)>>2]|0;v=255-da|0;E=c[l+(v<<3)>>2]|0;r=J-E|0;L=c[l+(da<<3)+4>>2]|0;Z=c[l+(v<<3)+4>>2]|0;v=Z+L|0;A=L-Z|0;Z=E+J|0;J=A+r|0;E=da<<1|1;L=c[8762400+(E<<2)>>2]|0;B=L;O=(L|0)<0|0?-1:0;L=gHb(J,(J|0)<0|0?-1:0,B,O)|0;YGb(L,F,-2147483648,0)|0;L=F;J=v+Z|0;N=c[8762400+(E+1536<<2)>>2]|0;E=N;K=(N|0)<0|0?-1:0;N=gHb(E,K,J,(J|0)<0|0?-1:0)|0;YGb(N,F,-2147483648,0)|0;c[n+(da<<3)>>2]=L+F;L=v-Z|0;Z=gHb(L,(L|0)<0|0?-1:0,B,O)|0;YGb(Z,F,-2147483648,0)|0;Z=F;O=A-r|0;r=gHb(E,K,O,(O|0)<0|0?-1:0)|0;YGb(r,F,-2147483648,0)|0;c[n+(da<<3)+4>>2]=F+Z;da=da+1|0;}while((da|0)<256);Z=c[2212088]|0;r=0;while(1){O=c[n+(r<<3)>>2]|0;K=(O|0)<0?-O|0:O;O=(Z|0)<(K|0)?0:1024;E=O|512;A=(c[8844256+(E<<2)>>2]|0)<(K|0)?O:E;E=A|256;O=(c[8844256+(E<<2)>>2]|0)<(K|0)?A:E;E=O|128;A=(c[8844256+(E<<2)>>2]|0)<(K|0)?O:E;E=A+64|0;O=(c[8844256+(E<<2)>>2]|0)<(K|0)?A:E;E=O+32|0;A=(c[8844256+(E<<2)>>2]|0)<(K|0)?O:E;E=A+16|0;O=(c[8844256+(E<<2)>>2]|0)<(K|0)?A:E;E=O+8|0;A=(c[8844256+(E<<2)>>2]|0)<(K|0)?O:E;E=A+4|0;O=(c[8844256+(E<<2)>>2]|0)<(K|0)?A:E;E=O+2|0;A=(c[8844256+(E<<2)>>2]|0)<(K|0)?O:E;E=A+1|0;O=-((c[8844256+(E<<2)>>2]|0)<(K|0)?A:E)|0;E=c[n+(r<<3)+4>>2]|0;A=(E|0)<0?-E|0:E;E=(Z|0)<(A|0)?0:1024;K=E|512;B=(c[8844256+(K<<2)>>2]|0)<(A|0)?E:K;K=B|256;E=(c[8844256+(K<<2)>>2]|0)<(A|0)?B:K;K=E|128;B=(c[8844256+(K<<2)>>2]|0)<(A|0)?E:K;K=B+64|0;E=(c[8844256+(K<<2)>>2]|0)<(A|0)?B:K;K=E+32|0;B=(c[8844256+(K<<2)>>2]|0)<(A|0)?E:K;K=B+16|0;E=(c[8844256+(K<<2)>>2]|0)<(A|0)?B:K;K=E+8|0;B=(c[8844256+(K<<2)>>2]|0)<(A|0)?E:K;K=B+4|0;E=(c[8844256+(K<<2)>>2]|0)<(A|0)?B:K;K=E+2|0;B=(c[8844256+(K<<2)>>2]|0)<(A|0)?E:K;K=B+1|0;E=-((c[8844256+(K<<2)>>2]|0)<(A|0)?B:K)|0;K=(O|0)<(E|0);B=K?E:O;A=B-(K?O:E)|0;if((A|0)>255){ea=B}else{ea=(c[8852448+(A<<2)>>2]|0)+B|0}c[m+(r<<2)>>2]=ea;c[o+(r<<2)>>2]=-2047;B=r+1|0;if((B|0)<256){r=B}else{fa=0;break}}while(1){r=-1114;Z=0;while(1){B=(c[8936440+(Q*25600|0)+(fa<<10)+(Z<<2)>>2]|0)+(c[m+(Z<<2)>>2]|0)|0;A=(r|0)<(B|0);E=A?B:r;O=E-(A?r:B)|0;if((O|0)>255){ga=E}else{ga=(c[8852448+(O<<2)>>2]|0)+E|0}E=Z+1|0;if((E|0)<256){r=ga;Z=E}else{ha=0;break}}do{Z=o+(ha<<2)|0;r=c[Z>>2]|0;E=(c[8936440+(Q*25600|0)+(fa<<10)+(ha<<2)>>2]|0)-ga|0;O=(r|0)<(E|0);B=O?E:r;A=B-(O?r:E)|0;if((A|0)>255){ia=B}else{ia=(c[8852448+(A<<2)>>2]|0)+B|0}c[Z>>2]=ia;ha=ha+1|0;}while((ha|0)<256);Z=fa+1|0;if((Z|0)<25){fa=Z}else{ja=0;break}}do{Q=t+37744+(S<<10)+(ja<<2)|0;Z=c[Q>>2]|0;B=1114-(c[o+(ja<<2)>>2]|0)-928|0;A=(Z|0)<(B|0);E=A?B:Z;r=E-(A?Z:B)|0;if((r|0)>255){ka=E}else{ka=(c[8852448+(r<<2)>>2]|0)+E|0}c[Q>>2]=ka;ja=ja+1|0;}while((ja|0)<256);Q=P+1|0;E=c[z>>2]|0;if((Q|0)<(E|0)){P=Q}else{la=E;break}}}else{la=V}P=S+1|0;if((P|0)<2){S=P;H=H-256|0;V=la}else{ma=0;break}}do{la=c[t+37744+(ma<<2)>>2]|0;V=(la|0)<2048?la:2048;la=c[t+38768+(ma<<2)>>2]|0;c[t+42864+(ma<<2)>>2]=(la|0)<(V|0)?la:V;ma=ma+1|0;}while((ma|0)<256);ma=s+43888|0;V=s+42864|0;la=s+42868|0;H=s+42872|0;S=s+42876|0;ja=s+44012|0;ka=s+43872|0;o=s+43876|0;fa=s+43880|0;ha=s+43884|0;ia=s+60|0;ga=0;do{m=t+43888+(ga<<2)|0;c[m>>2]=2048;do{if((ga|0)==0){ea=c[V>>2]|0;n=c[ma>>2]|0;if((ea|0)<(n|0)){c[ma>>2]=ea;na=ea}else{na=n}n=c[la>>2]|0;if((n|0)<(na|0)){c[ma>>2]=n;oa=n}else{oa=na}n=c[H>>2]|0;if((n|0)<(oa|0)){c[ma>>2]=n;pa=n}else{pa=oa}n=c[S>>2]|0;if((n|0)>=(pa|0)){break}c[ma>>2]=n}else{n=ga<<3;ea=c[ia>>2]|0;da=(c[t+42864+(n-4<<2)>>2]|0)-(c[ea+28>>2]|0)|0;if((da|0)<2048){c[m>>2]=da;qa=c[ia>>2]|0;ra=da}else{qa=ea;ra=2048}ea=(c[t+42864+(n-3<<2)>>2]|0)-(c[qa+24>>2]|0)|0;if((ea|0)<(ra|0)){c[m>>2]=ea;sa=c[ia>>2]|0;ta=ea}else{sa=qa;ta=ra}ea=(c[t+42864+(n-2<<2)>>2]|0)-(c[sa+20>>2]|0)|0;if((ea|0)<(ta|0)){c[m>>2]=ea;ua=c[ia>>2]|0;va=ea}else{ua=sa;va=ta}ea=(c[t+42864+(n-1<<2)>>2]|0)-(c[ua+16>>2]|0)|0;if((ea|0)<(va|0)){c[m>>2]=ea;wa=c[ia>>2]|0;xa=ea}else{wa=ua;xa=va}ea=(c[t+42864+(n<<2)>>2]|0)-(c[wa+12>>2]|0)|0;if((ea|0)<(xa|0)){c[m>>2]=ea;ya=c[ia>>2]|0;za=ea}else{ya=wa;za=xa}ea=(c[t+42864+((n|1)<<2)>>2]|0)-(c[ya+8>>2]|0)|0;if((ea|0)<(za|0)){c[m>>2]=ea;Aa=c[ia>>2]|0;Ba=ea}else{Aa=ya;Ba=za}ea=(c[t+42864+((n|2)<<2)>>2]|0)-(c[Aa+4>>2]|0)|0;if((ea|0)<(Ba|0)){c[m>>2]=ea;Ca=c[ia>>2]|0;Da=ea}else{Ca=Aa;Da=Ba}ea=(c[t+42864+((n|3)<<2)>>2]|0)-(c[Ca>>2]|0)|0;if((ea|0)>=(Da|0)){break}c[m>>2]=ea}}while(0);do{if((ga|0)==31){ea=c[ka>>2]|0;n=c[ja>>2]|0;if((ea|0)<(n|0)){c[ja>>2]=ea;Ea=ea}else{Ea=n}n=c[o>>2]|0;if((n|0)<(Ea|0)){c[ja>>2]=n;Fa=n}else{Fa=Ea}n=c[fa>>2]|0;if((n|0)<(Fa|0)){c[ja>>2]=n;Ga=n}else{Ga=Fa}n=c[ha>>2]|0;if((n|0)>=(Ga|0)){break}c[ja>>2]=n}else{n=ga<<3;ea=n|4;da=c[ia>>2]|0;l=(c[t+42864+(ea<<2)>>2]|0)-(c[da>>2]|0)|0;ca=c[m>>2]|0;if((l|0)<(ca|0)){c[m>>2]=l;Ha=c[ia>>2]|0;Ia=l}else{Ha=da;Ia=ca}ca=(c[t+42864+((n|5)<<2)>>2]|0)-(c[Ha+4>>2]|0)|0;if((ca|0)<(Ia|0)){c[m>>2]=ca;Ja=c[ia>>2]|0;Ka=ca}else{Ja=Ha;Ka=Ia}ca=(c[t+42864+((n|6)<<2)>>2]|0)-(c[Ja+8>>2]|0)|0;if((ca|0)<(Ka|0)){c[m>>2]=ca;La=c[ia>>2]|0;Ma=ca}else{La=Ja;Ma=Ka}ca=(c[t+42864+((n|7)<<2)>>2]|0)-(c[La+12>>2]|0)|0;if((ca|0)<(Ma|0)){c[m>>2]=ca;Na=c[ia>>2]|0;Oa=ca}else{Na=La;Oa=Ma}ca=(c[t+42864+(ea+4<<2)>>2]|0)-(c[Na+16>>2]|0)|0;if((ca|0)<(Oa|0)){c[m>>2]=ca;Pa=c[ia>>2]|0;Qa=ca}else{Pa=Na;Qa=Oa}ca=(c[t+42864+(ea+5<<2)>>2]|0)-(c[Pa+20>>2]|0)|0;if((ca|0)<(Qa|0)){c[m>>2]=ca;Ra=c[ia>>2]|0;Sa=ca}else{Ra=Pa;Sa=Qa}ca=(c[t+42864+(ea+6<<2)>>2]|0)-(c[Ra+24>>2]|0)|0;if((ca|0)<(Sa|0)){c[m>>2]=ca;Ta=c[ia>>2]|0;Ua=ca}else{Ta=Ra;Ua=Sa}ca=(c[t+42864+(ea+7<<2)>>2]|0)-(c[Ta+28>>2]|0)|0;if((ca|0)>=(Ua|0)){break}c[m>>2]=ca}}while(0);ga=ga+1|0;}while((ga|0)<32);ga=0;Ua=c[z>>2]|0;while(1){if((Ua|0)>0){Ta=0;while(1){Sa=0;Ra=0;do{ia=c[t+12368+(Sa*768|0)+(ga*24|0)+(Ta<<2)>>2]|0;Qa=(ia|0)>-1?ia:-ia|0;Ra=(Ra|0)<(Qa|0)?Qa:Ra;Sa=Sa+1|0;}while((Sa|0)<16);Sa=(Ra|0)<0?-Ra|0:Ra;Qa=(c[2212088]|0)<(Sa|0)?0:1024;ia=Qa|512;Pa=(c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa|256;Qa=(c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia;ia=Qa|128;Pa=(c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa+64|0;Qa=(c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia;ia=Qa+32|0;Pa=(c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa+16|0;Qa=(c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia;ia=Qa+8|0;Pa=(c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa+4|0;Qa=(c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia;ia=Qa+2|0;Pa=(c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa+1|0;c[t+36944+(ga*24|0)+(Ta<<2)>>2]=-((c[8844256+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia);ia=Ta+1|0;Pa=c[z>>2]|0;if((ia|0)<(Pa|0)){Ta=ia}else{Va=Pa;break}}}else{Va=Ua}Ta=ga+1|0;if((Ta|0)<32){ga=Ta;Ua=Va}else{break}}if((c[C>>2]|0)!=0){Va=c[s+37712>>2]|0;Ua=(Va|0)>-1?Va:-Va|0;Va=(Ua|0)>0?Ua:0;Ua=c[s+37716>>2]|0;ga=(Ua|0)>-1?Ua:-Ua|0;Ua=(Va|0)<(ga|0)?ga:Va;Va=c[s+37720>>2]|0;ga=(Va|0)>-1?Va:-Va|0;Va=(Ua|0)<(ga|0)?ga:Ua;Ua=c[s+37724>>2]|0;ga=(Ua|0)>-1?Ua:-Ua|0;Ua=(Va|0)<(ga|0)?ga:Va;Va=c[s+37728>>2]|0;ga=(Va|0)>-1?Va:-Va|0;Va=(Ua|0)<(ga|0)?ga:Ua;Ua=c[s+37732>>2]|0;ga=(Ua|0)>-1?Ua:-Ua|0;Ua=(Va|0)<(ga|0)?ga:Va;Va=c[s+37736>>2]|0;ga=(Va|0)>-1?Va:-Va|0;Va=(Ua|0)<(ga|0)?ga:Ua;Ua=c[s+37740>>2]|0;ga=(Ua|0)>-1?Ua:-Ua|0;Ua=(Va|0)<(ga|0)?ga:Va;Va=(Ua|0)<0?-Ua|0:Ua;Ua=(c[2212088]|0)<(Va|0)?0:1024;ga=Ua|512;Ta=(c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta|256;Ua=(c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ta:ga;ga=Ua|128;Ta=(c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta+64|0;Ua=(c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ta:ga;ga=Ua+32|0;Ta=(c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta+16|0;Ua=(c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ta:ga;ga=Ua+8|0;Ta=(c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta+4|0;Ua=(c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ta:ga;ga=Ua+2|0;Ta=(c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta+1|0;c[s+76>>2]=-((c[8844256+(ga<<2)>>2]|0)<(Va|0)?Ta:ga)}ga=s+44016|0;T0(t,c[ga>>2]|0)|0;Ta=c[ga>>2]|0;Va=s+44024|0;Ua=s+28|0;a:do{if((c[Va>>2]|0)>(c[Ua>>2]|0)){Pa=Ta;ia=0;while(1){if((ia|0)==1){break}Sa=Pa+128|0;Qa=T0(t,Sa)|0;if((c[Va>>2]|0)>(c[Ua>>2]|0)){Pa=Sa;ia=Qa}else{Wa=Sa;Xa=129;break a}}yDb(0,0,2113272,(ia=i,i=i+24|0,c[ia>>2]=1917552,c[ia+8>>2]=2008736,c[ia+16>>2]=601,ia)|0);i=ia;Cd();return 0}else{ia=Ta;Pa=0;while(1){if((Pa|0)==4){Ya=ia;break a}Sa=ia-128|0;Qa=T0(t,Sa)|0;if((c[Va>>2]|0)>(c[Ua>>2]|0)){Wa=ia;Xa=129;break}else{ia=Sa;Pa=Qa}}}}while(0);if((Xa|0)==129){Xa=Wa-64|0;T0(t,Xa)|0;Ta=(c[Va>>2]|0)>(c[Ua>>2]|0)?Wa:Xa;Xa=Ta-32|0;T0(t,Xa)|0;Wa=(c[Va>>2]|0)>(c[Ua>>2]|0)?Ta:Xa;Xa=Wa-16|0;T0(t,Xa)|0;Ta=(c[Va>>2]|0)>(c[Ua>>2]|0)?Wa:Xa;Xa=Ta-8|0;T0(t,Xa)|0;Wa=(c[Va>>2]|0)>(c[Ua>>2]|0)?Ta:Xa;Xa=Wa-4|0;T0(t,Xa)|0;Ta=(c[Va>>2]|0)>(c[Ua>>2]|0)?Wa:Xa;Xa=Ta-2|0;T0(t,Xa)|0;Wa=(c[Va>>2]|0)>(c[Ua>>2]|0)?Ta:Xa;Xa=Wa-1|0;T0(t,Xa)|0;Ta=(c[Va>>2]|0)>(c[Ua>>2]|0)?Wa:Xa;T0(t,Ta)|0;Ya=Ta}c[ga>>2]=Ya;ga=s+44020|0;if((Ya|0)>(c[ga>>2]|0)){c[ga>>2]=Ya}Ya=0;ga=c[z>>2]|0;while(1){if((ga|0)>0){Ta=0;while(1){c[t+40560+(Ya*24|0)+(Ta<<2)>>2]=S0(c[t+36944+(Ya*24|0)+(Ta<<2)>>2]|0,c[t+39792+(Ya*24|0)+(Ta<<2)>>2]|0,t+41328+(Ya*48|0)+(Ta<<3)|0)|0;Xa=Ta+1|0;Wa=c[z>>2]|0;if((Xa|0)<(Wa|0)){Ta=Xa}else{Za=Wa;break}}}else{Za=ga}Ta=Ya+1|0;if((Ta|0)<32){Ya=Ta;ga=Za}else{break}}if((c[C>>2]|0)==0){_a=0;$a=Za}else{c[s+64>>2]=S0(c[s+76>>2]|0,11,s+68|0)|0;_a=0;$a=c[z>>2]|0}while(1){Za=0;ga=$a;while(1){if((ga|0)>0){Ya=0;while(1){Ta=c[t+12368+(_a*768|0)+(Za*24|0)+(Ya<<2)>>2]|0;Wa=c[t+41328+(Za*48|0)+(Ya<<3)>>2]|0;Xa=c[t+41328+(Za*48|0)+(Ya<<3)+4>>2]|0;Ua=gHb(Wa,(Wa|0)<0|0?-1:0,Ta,(Ta|0)<0|0?-1:0)|0;YGb(Ua,F,-2147483648,0)|0;c[t+24656+(_a*768|0)+(Za*24|0)+(Ya<<2)>>2]=F+(1<<Xa-1)>>Xa;Xa=Ya+1|0;Ua=c[z>>2]|0;if((Xa|0)<(Ua|0)){Ya=Xa}else{ab=Ua;break}}}else{ab=ga}Ya=Za+1|0;if((Ya|0)<32){Za=Ya;ga=ab}else{break}}ga=_a+1|0;if((ga|0)<16){_a=ga;$a=ab}else{break}}ab=0;$a=c[T>>2]|0;while(1){if(($a|0)>0){_a=0;ga=$a;while(1){c[t+80+(ab*24|0)+(_a<<2)>>2]=c[w+((ba(ga,ab)|0)+_a<<2)>>2];Za=_a+1|0;Ya=c[T>>2]|0;if((Za|0)<(Ya|0)){_a=Za;ga=Ya}else{bb=Ya;break}}}else{bb=$a}ga=ab+1|0;if((ga|0)<512){ab=ga;$a=bb}else{break}}bb=e+28|0;$a=c[bb>>2]|0;ab=($a|0)<0;T=ab?0:c[e+24>>2]|0;w=ab?0:$a;c[s+20>>2]=w<<3;c[s+8>>2]=T;c[s+16>>2]=T+w;w=s+12|0;c[w>>2]=T;$a=s+4|0;ab=s;ga=T;x=25230975;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;ga=(c[w>>2]|0)+4|0;c[w>>2]=ga;T=c[s+52>>2]|0;_a=ga;x=fe(T>>>2|((c[u>>2]<<4)+67108848|-63176704)|0)|0;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;_a=(c[w>>2]|0)+4|0;c[w>>2]=_a;ga=_a;x=fe(((c[C>>2]|0)!=0?1024:0)|(c[s+48>>2]|(d[1683816+(c[R>>2]|0)|0]|0|T<<4)<<5)<<21|312|0)|0;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;ga=(c[w>>2]|0)+4|0;c[w>>2]=ga;T=c[z>>2]|0;R=T-1|0;c[ab>>2]=R;c[$a>>2]=17;do{if((T|0)>0){_a=0;Ya=R;Za=17;Ra=T;Ua=ga;while(1){if((Za|0)>5){cb=Za-5|0;db=Ya<<5|30;eb=Ra;fb=Ua}else{Xa=Ua;x=fe(30>>>((5-Za|0)>>>0)|Ya<<Za|0)|0;a[Xa]=x;x=x>>8;a[Xa+1|0]=x;x=x>>8;a[Xa+2|0]=x;x=x>>8;a[Xa+3|0]=x;Xa=(c[w>>2]|0)+4|0;c[w>>2]=Xa;cb=Za+27|0;db=30;eb=c[z>>2]|0;fb=Xa}c[ab>>2]=db;c[$a>>2]=cb;Xa=_a+1|0;if((Xa|0)<(eb|0)){_a=Xa;Ya=db;Za=cb;Ra=eb;Ua=fb}else{break}}if((eb|0)>0){gb=0;hb=db;ib=cb;jb=eb;kb=fb}else{lb=1;mb=eb;nb=db;ob=cb;pb=fb;break}while(1){if((ib|0)>5){qb=ib-5|0;rb=hb<<5|31;sb=jb;tb=kb}else{Ua=kb;x=fe(31>>>((5-ib|0)>>>0)|hb<<ib|0)|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;qb=ib+27|0;rb=31;sb=c[z>>2]|0;tb=Ua}c[ab>>2]=rb;c[$a>>2]=qb;Ua=gb+1|0;if((Ua|0)<(sb|0)){gb=Ua;hb=rb;ib=qb;jb=sb;kb=tb}else{break}}if((sb|0)>0){ub=0;vb=rb;wb=qb;xb=sb;yb=tb}else{lb=1;mb=sb;nb=rb;ob=qb;pb=tb;break}while(1){if((wb|0)>3){zb=wb-3|0;Ab=vb<<3;Bb=xb;Cb=yb}else{Ua=yb;x=fe(vb<<wb|0)|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;zb=wb+29|0;Ab=0;Bb=c[z>>2]|0;Cb=Ua}c[ab>>2]=Ab;c[$a>>2]=zb;Ua=ub+1|0;if((Ua|0)<(Bb|0)){ub=Ua;vb=Ab;wb=zb;xb=Bb;yb=Cb}else{break}}if((Bb|0)>0){Db=0;Eb=Ab;Fb=zb;Gb=Bb;Hb=Cb}else{lb=1;mb=Bb;nb=Ab;ob=zb;pb=Cb;break}while(1){if((Fb|0)>2){Ib=Fb-2|0;Jb=Eb<<2;Kb=Gb;Lb=Hb}else{Ua=Hb;x=fe(Eb<<Fb|0)|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;Ib=Fb+30|0;Jb=0;Kb=c[z>>2]|0;Lb=Ua}c[ab>>2]=Jb;c[$a>>2]=Ib;Ua=Db+1|0;if((Ua|0)<(Kb|0)){Db=Ua;Eb=Jb;Fb=Ib;Gb=Kb;Hb=Lb}else{break}}if((Kb|0)>0){Mb=0;Nb=Jb;Ob=Ib;Pb=Kb;Qb=Lb}else{lb=1;mb=Kb;nb=Jb;ob=Ib;pb=Lb;break}while(1){if((Ob|0)>3){Rb=Ob-3|0;Sb=Nb<<3|6;Tb=Pb;Ub=Qb}else{Ua=Qb;x=fe(6>>>((3-Ob|0)>>>0)|Nb<<Ob|0)|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;Rb=Ob+29|0;Sb=6;Tb=c[z>>2]|0;Ub=Ua}c[ab>>2]=Sb;c[$a>>2]=Rb;Ua=Mb+1|0;if((Ua|0)<(Tb|0)){Mb=Ua;Nb=Sb;Ob=Rb;Pb=Tb;Qb=Ub}else{break}}if((Tb|0)>0){Vb=0;Wb=Sb;Xb=Rb;Yb=Tb;Zb=Ub}else{lb=1;mb=Tb;nb=Sb;ob=Rb;pb=Ub;break}while(1){if((Xb|0)>3){_b=Xb-3|0;$b=Wb<<3|6;ac=Yb;bc=Zb}else{Ua=Zb;x=fe(6>>>((3-Xb|0)>>>0)|Wb<<Xb|0)|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;_b=Xb+29|0;$b=6;ac=c[z>>2]|0;bc=Ua}c[ab>>2]=$b;c[$a>>2]=_b;Ua=Vb+1|0;if((Ua|0)<(ac|0)){Vb=Ua;Wb=$b;Xb=_b;Yb=ac;Zb=bc}else{lb=1;mb=ac;nb=$b;ob=_b;pb=bc;break}}}else{lb=1;mb=T;nb=R;ob=17;pb=ga}}while(0);while(1){if((mb|0)>0){ga=c[559616+(lb<<2)>>2]|0;R=c[559568+(lb<<2)>>2]|0;T=32-ga|0;bc=0;_b=nb;$b=ob;ac=mb;Zb=pb;while(1){if(($b|0)>(ga|0)){cc=$b-ga|0;dc=_b<<ga|R;ec=ac;fc=Zb}else{Yb=Zb;x=fe(R>>>((ga-$b|0)>>>0)|_b<<$b|0)|0;a[Yb]=x;x=x>>8;a[Yb+1|0]=x;x=x>>8;a[Yb+2|0]=x;x=x>>8;a[Yb+3|0]=x;Yb=(c[w>>2]|0)+4|0;c[w>>2]=Yb;cc=T+$b|0;dc=R;ec=c[z>>2]|0;fc=Yb}c[ab>>2]=dc;c[$a>>2]=cc;Yb=bc+1|0;if((Yb|0)<(ec|0)){bc=Yb;_b=dc;$b=cc;ac=ec;Zb=fc}else{gc=ec;hc=dc;ic=cc;jc=fc;break}}}else{gc=mb;hc=nb;ic=ob;jc=pb}Zb=lb+1|0;if((Zb|0)<11){lb=Zb;mb=gc;nb=hc;ob=ic;pb=jc}else{break}}pb=s+68|0;ob=s+72|0;nb=s+64|0;if((ic|0)>2){kc=ic-2|0;lc=hc<<2|1;mc=jc}else{s=jc;x=fe(1>>>((2-ic|0)>>>0)|hc<<ic|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=(c[w>>2]|0)+4|0;c[w>>2]=s;kc=ic+30|0;lc=1;mc=s}c[ab>>2]=lc;c[$a>>2]=kc;if((kc|0)>3){nc=kc-3|0;oc=lc<<3;pc=mc}else{s=mc;x=fe(lc<<kc|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=(c[w>>2]|0)+4|0;c[w>>2]=s;nc=kc+29|0;oc=0;pc=s}c[ab>>2]=oc;c[$a>>2]=nc;s=c[z>>2]|0;do{if((s|0)>0){kc=0;lc=oc;mc=nc;ic=pc;while(1){hc=0;jc=lc;gc=mc;mb=ic;while(1){if((gc|0)>1){qc=gc-1|0;rc=jc<<1;sc=mb}else{lb=mb;x=fe(jc<<gc|0)|0;a[lb]=x;x=x>>8;a[lb+1|0]=x;x=x>>8;a[lb+2|0]=x;x=x>>8;a[lb+3|0]=x;lb=(c[w>>2]|0)+4|0;c[w>>2]=lb;qc=gc+31|0;rc=0;sc=lb}c[ab>>2]=rc;c[$a>>2]=qc;lb=hc+1|0;if((lb|0)<32){hc=lb;jc=rc;gc=qc;mb=sc}else{break}}mb=kc+1|0;tc=c[z>>2]|0;if((mb|0)<(tc|0)){kc=mb;lc=rc;mc=qc;ic=sc}else{break}}if((tc|0)>0){uc=0;vc=rc;wc=qc;xc=sc}else{yc=rc;zc=qc;Ac=tc;Bc=sc;break}while(1){ic=0;mc=vc;lc=wc;kc=xc;while(1){mb=c[t+39792+(ic*24|0)+(uc<<2)>>2]|0;if((lc|0)>5){Cc=lc-5|0;Dc=mb|mc<<5;Ec=kc}else{gc=kc;x=fe(mb>>>((5-lc|0)>>>0)|mc<<lc|0)|0;a[gc]=x;x=x>>8;a[gc+1|0]=x;x=x>>8;a[gc+2|0]=x;x=x>>8;a[gc+3|0]=x;gc=(c[w>>2]|0)+4|0;c[w>>2]=gc;Cc=lc+27|0;Dc=mb;Ec=gc}c[ab>>2]=Dc;c[$a>>2]=Cc;gc=ic+1|0;if((gc|0)<32){ic=gc;mc=Dc;lc=Cc;kc=Ec}else{break}}kc=uc+1|0;Fc=c[z>>2]|0;if((kc|0)<(Fc|0)){uc=kc;vc=Dc;wc=Cc;xc=Ec}else{break}}if((Fc|0)>0){Gc=0;Hc=Dc;Ic=Cc;Jc=Ec}else{yc=Dc;zc=Cc;Ac=Fc;Bc=Ec;break}while(1){kc=0;lc=Hc;mc=Ic;ic=Jc;while(1){if((mc|0)>1){Kc=mc-1|0;Lc=lc<<1;Mc=ic}else{gc=ic;x=fe(lc<<mc|0)|0;a[gc]=x;x=x>>8;a[gc+1|0]=x;x=x>>8;a[gc+2|0]=x;x=x>>8;a[gc+3|0]=x;gc=(c[w>>2]|0)+4|0;c[w>>2]=gc;Kc=mc+31|0;Lc=0;Mc=gc}c[ab>>2]=Lc;c[$a>>2]=Kc;gc=kc+1|0;if((gc|0)<32){kc=gc;lc=Lc;mc=Kc;ic=Mc}else{break}}ic=Gc+1|0;Nc=c[z>>2]|0;if((ic|0)<(Nc|0)){Gc=ic;Hc=Lc;Ic=Kc;Jc=Mc}else{break}}if((Nc|0)>0){Oc=0;Pc=Lc;Qc=Kc;Rc=Mc}else{yc=Lc;zc=Kc;Ac=Nc;Bc=Mc;break}while(1){ic=0;mc=Pc;lc=Qc;kc=Rc;while(1){gc=c[t+40560+(ic*24|0)+(Oc<<2)>>2]|0;if((lc|0)>7){Sc=lc-7|0;Tc=gc|mc<<7;Uc=kc}else{mb=kc;x=fe(gc>>>((7-lc|0)>>>0)|mc<<lc|0)|0;a[mb]=x;x=x>>8;a[mb+1|0]=x;x=x>>8;a[mb+2|0]=x;x=x>>8;a[mb+3|0]=x;mb=(c[w>>2]|0)+4|0;c[w>>2]=mb;Sc=lc+25|0;Tc=gc;Uc=mb}c[ab>>2]=Tc;c[$a>>2]=Sc;mb=ic+1|0;if((mb|0)<32){ic=mb;mc=Tc;lc=Sc;kc=Uc}else{break}}kc=Oc+1|0;lc=c[z>>2]|0;if((kc|0)<(lc|0)){Oc=kc;Pc=Tc;Qc=Sc;Rc=Uc}else{yc=Tc;zc=Sc;Ac=lc;Bc=Uc;break}}}else{yc=oc;zc=nc;Ac=s;Bc=pc}}while(0);if((c[C>>2]|0)==0){Vc=0;Wc=yc;Xc=zc;Yc=Ac;Zc=Bc}else{Ac=0;C=yc;yc=zc;zc=Bc;while(1){Bc=c[t+37712+(Ac<<2)>>2]|0;pc=c[pb>>2]|0;s=c[ob>>2]|0;nc=gHb(pc,(pc|0)<0|0?-1:0,Bc,(Bc|0)<0|0?-1:0)|0;YGb(nc,F,-2147483648,0)|0;nc=F+(1<<s-1)>>s&255;if((yc|0)>8){_c=yc-8|0;$c=nc|C<<8;ad=zc}else{s=zc;x=fe(nc>>>((8-yc|0)>>>0)|C<<yc|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=(c[w>>2]|0)+4|0;c[w>>2]=s;_c=yc+24|0;$c=nc;ad=s}c[ab>>2]=$c;c[$a>>2]=_c;s=Ac+1|0;if((s|0)<8){Ac=s;C=$c;yc=_c;zc=ad}else{break}}zc=c[nb>>2]|0;if((_c|0)>8){bd=_c-8|0;cd=zc|$c<<8;dd=ad}else{nb=ad;x=fe(zc>>>((8-_c|0)>>>0)|$c<<_c|0)|0;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=(c[w>>2]|0)+4|0;c[w>>2]=nb;bd=_c+24|0;cd=zc;dd=nb}c[ab>>2]=cd;c[$a>>2]=bd;Vc=0;Wc=cd;Xc=bd;Yc=c[z>>2]|0;Zc=dd}while(1){if((Yc|0)>0){dd=Vc<<3;bd=dd|3;cd=dd|2;nb=dd|1;zc=dd|4;_c=dd|7;$c=dd|6;ad=dd|5;yc=0;C=Wc;Ac=Xc;ob=Zc;while(1){pb=0;s=C;nc=Ac;Bc=ob;while(1){pc=t+39792+(pb*24|0)+(yc<<2)|0;oc=c[pc>>2]|0;b:do{if((oc|0)<8){Uc=c[552864+(oc<<2)>>2]|0;Sc=(Uc-1|0)/2|0;Tc=ba(Sc+(c[t+24656+(bd*768|0)+(pb*24|0)+(yc<<2)>>2]|0)|0,Uc)|0;Rc=ba((c[t+24656+(cd*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Sc+Tc|0,Uc)|0;Tc=ba((c[t+24656+(nb*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Sc+Rc|0,Uc)|0;Uc=(c[t+24656+(dd*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Sc+Tc|0;Tc=(c[1692880+(oc<<2)>>2]|0)/4|0;if((nc|0)>(Tc|0)){ed=nc;fd=Uc|s<<Tc;gd=Bc}else{Sc=Bc;x=fe(Uc>>>((Tc-nc|0)>>>0)|s<<nc|0)|0;a[Sc]=x;x=x>>8;a[Sc+1|0]=x;x=x>>8;a[Sc+2|0]=x;x=x>>8;a[Sc+3|0]=x;Sc=(c[w>>2]|0)+4|0;c[w>>2]=Sc;ed=nc+32|0;fd=Uc;gd=Sc}Sc=ed-Tc|0;c[ab>>2]=fd;c[$a>>2]=Sc;Tc=c[pc>>2]|0;Uc=c[552864+(Tc<<2)>>2]|0;Rc=(Uc-1|0)/2|0;Qc=ba(Rc+(c[t+24656+(_c*768|0)+(pb*24|0)+(yc<<2)>>2]|0)|0,Uc)|0;Pc=ba((c[t+24656+($c*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Rc+Qc|0,Uc)|0;Qc=ba((c[t+24656+(ad*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Rc+Pc|0,Uc)|0;Uc=(c[t+24656+(zc*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Rc+Qc|0;Qc=(c[1692880+(Tc<<2)>>2]|0)/4|0;if((Sc|0)>(Qc|0)){hd=Sc;id=Uc|fd<<Qc;jd=gd}else{Tc=gd;x=fe(Uc>>>((Qc-Sc|0)>>>0)|fd<<Sc|0)|0;a[Tc]=x;x=x>>8;a[Tc+1|0]=x;x=x>>8;a[Tc+2|0]=x;x=x>>8;a[Tc+3|0]=x;Tc=(c[w>>2]|0)+4|0;c[w>>2]=Tc;hd=Sc+32|0;id=Uc;jd=Tc}Tc=hd-Qc|0;c[ab>>2]=id;c[$a>>2]=Tc;kd=id;ld=Tc;md=jd}else{Tc=0;Qc=s;Uc=nc;Sc=oc;Rc=Bc;while(1){Pc=(c[1692880+(Sc<<2)>>2]|0)/16|0;Oc=(1<<Pc)-1&c[t+24656+((Tc+dd|0)*768|0)+(pb*24|0)+(yc<<2)>>2];if((Uc|0)>(Pc|0)){nd=Uc;od=Oc|Qc<<Pc;pd=Rc}else{Mc=Rc;x=fe(Oc>>>((Pc-Uc|0)>>>0)|Qc<<Uc|0)|0;a[Mc]=x;x=x>>8;a[Mc+1|0]=x;x=x>>8;a[Mc+2|0]=x;x=x>>8;a[Mc+3|0]=x;Mc=(c[w>>2]|0)+4|0;c[w>>2]=Mc;nd=Uc+32|0;od=Oc;pd=Mc}Mc=nd-Pc|0;c[ab>>2]=od;c[$a>>2]=Mc;Pc=Tc+1|0;if((Pc|0)>=8){kd=od;ld=Mc;md=pd;break b}Tc=Pc;Qc=od;Uc=Mc;Sc=c[pc>>2]|0;Rc=pd}}}while(0);pc=pb+1|0;if((pc|0)<32){pb=pc;s=kd;nc=ld;Bc=md}else{break}}Bc=yc+1|0;nc=c[z>>2]|0;if((Bc|0)<(nc|0)){yc=Bc;C=kd;Ac=ld;ob=md}else{qd=kd;rd=ld;sd=nc;td=md;break}}}else{qd=Wc;rd=Xc;sd=Yc;td=Zc}ob=Vc+1|0;if((ob|0)<2){Vc=ob;Wc=qd;Xc=rd;Yc=sd;Zc=td}else{break}}if((rd|0)>16){ud=rd-16|0;vd=qd<<16|65535;wd=td}else{Zc=td;x=fe(65535>>>((16-rd|0)>>>0)|qd<<rd|0)|0;a[Zc]=x;x=x>>8;a[Zc+1|0]=x;x=x>>8;a[Zc+2|0]=x;x=x>>8;a[Zc+3|0]=x;Zc=(c[w>>2]|0)+4|0;c[w>>2]=Zc;ud=rd+16|0;vd=65535;wd=Zc}c[ab>>2]=vd;c[$a>>2]=ud;c:do{if((ud|0)<32){Zc=vd<<ud;c[ab>>2]=Zc;rd=Zc>>>24&255;Zc=wd;while(1){c[w>>2]=Zc+1;a[Zc]=rd;qd=c[ab>>2]|0;c[ab>>2]=qd<<8;td=(c[$a>>2]|0)+8|0;c[$a>>2]=td;if((td|0)>=32){break c}rd=qd>>>16&255;Zc=c[w>>2]|0}}}while(0);c[$a>>2]=32;c[ab>>2]=0;ab=f+136|0;$a=c[ab+4>>2]|0;w=e+8|0;c[w>>2]=c[ab>>2];c[w+4>>2]=$a;$a=c[f+76>>2]|0;c[p>>2]=1;c[p+4>>2]=c[b+412>>2];f=KDb($a,($a|0)<0|0?-1:0,p,b+104|0)|0;c[e+48>>2]=f;c[bb>>2]=(c[u>>2]|0)+1;c[g>>2]=1;y=0;i=h;return y|0}function S0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;if((a|0)>=1){yDb(0,0,2113272,(f=i,i=i+24|0,c[f>>2]=2054640,c[f+8>>2]=2008736,c[f+16>>2]=653,f)|0);i=f;Cd();return 0}if(!((a|0)>-2048)){yDb(0,0,2113272,(f=i,i=i+24|0,c[f>>2]=1970440,c[f+8>>2]=2008736,c[f+16>>2]=654,f)|0);i=f;Cd();return 0}g=c[8844256+(-a<<2)>>2]|0;a=c[431284+(b<<3)>>2]|0;h=431280+(b<<3)|0;j=552864+(b<<2)|0;b=g;k=(g|0)<0|0?-1:0;g=127;l=64;while(1){m=g-l|0;n=a+(c[475436+(m<<3)>>2]|0)|0;if((n|0)<18){o=g}else{p=c[475432+(m<<3)>>2]|0;q=c[h>>2]|0;r=gHb(q,(q|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;YGb(r,F,-2147483648,0)|0;r=F;p=((c[j>>2]|0)-1|0)/2|0;q=gHb(r,(r|0)<0|0?-1:0,b,k)|0;YGb(q,F,-2147483648,0)|0;o=(p|0)<(F+(1<<n-18)>>n-17|0)?g:m}m=l>>1;if((m|0)>0){g=o;l=m}else{break}}l=(o|0)>124?124:o;o=c[475432+(l<<3)>>2]|0;g=c[h>>2]|0;h=gHb(g,(g|0)<0|0?-1:0,o,(o|0)<0|0?-1:0)|0;YGb(h,F,-2147483648,0)|0;h=F;c[d>>2]=h;o=(c[475436+(l<<3)>>2]|0)-17+a|0;c[d+4>>2]=o;d=((c[j>>2]|0)-1|0)/2|0;j=gHb(h,(h|0)<0|0?-1:0,b,k)|0;YGb(j,F,-2147483648,0)|0;if((d|0)<(F+(1<<o-1)>>o|0)){yDb(0,0,2113272,(f=i,i=i+24|0,c[f>>2]=1941712,c[f+8>>2]=2008736,c[f+16>>2]=674,f)|0);i=f;Cd();return 0}else{i=e;return l|0}return 0}function T0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a+32|0;e=c[d>>2]|0;f=e*493|0;g=a+44024|0;c[g>>2]=f+132;if((c[a+40>>2]|0)!=0){c[g>>2]=f+204}if((e|0)>0){f=0;h=0;while(1){i=0;j=f;while(1){k=(c[a+36944+(i*24|0)+(h<<2)>>2]|0)-(c[a+43888+(i<<2)>>2]|0)-b|0;do{if((k|0)>1311){c[a+39792+(i*24|0)+(h<<2)>>2]=26;l=j|4}else{if((k|0)>221){m=k-222|0;n=gHb(m,(m|0)<0|0?-1:0,69e6,0)|0;YGb(n,F,-2147483648,0)|0;c[a+39792+(i*24|0)+(h<<2)>>2]=F+8;l=j|2;break}if((k|0)>-1){n=gHb(k,(k|0)<0|0?-1:0,106e6,0)|0;YGb(n,F,-2147483648,0)|0;c[a+39792+(i*24|0)+(h<<2)>>2]=F+2;l=j|2;break}else{c[a+39792+(i*24|0)+(h<<2)>>2]=1;l=j|1;break}}}while(0);k=i+1|0;if((k|0)<32){i=k;j=l}else{break}}j=h+1|0;i=c[d>>2]|0;if((j|0)<(i|0)){f=l;h=j}else{o=l;p=i;break}}}else{o=0;p=e}e=0;do{if((p|0)>0){l=0;h=c[g>>2]|0;do{h=h+(c[1692880+(c[a+39792+(e*24|0)+(l<<2)>>2]<<2)>>2]|0)|0;c[g>>2]=h;l=l+1|0;}while((l|0)<(p|0))}e=e+1|0;}while((e|0)<32);return o|0}function U0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0.0,k=0;e=1<<b;TGb(a|0,0,112)|0;c[a>>2]=b;c[a+4>>2]=d;do{if((d|0)==0&(b|0)==5){c[a+104>>2]=10}else{f=b+2|0;_8(f);c[a+96>>2]=c[1237600+(f<<2)>>2];f=(e|0)/2|0;h=a+100|0;c[h>>2]=WDb(f<<2)|0;if((BUa(a+8|0,b,(d|0)==1|0)|0)<0){ZDb(c[h>>2]|0);i=-1;return i|0}if((e|0)>1){j=3.141592653589793/+(e<<1|0);k=c[h>>2]|0;h=0;do{g[k+(h<<2)>>2]=.5/+U(+(h<<1|1|0)*j);h=h+1|0;}while((h|0)<(f|0))}if((d|0)==1){c[a+104>>2]=222;break}else if((d|0)==0){c[a+104>>2]=214;break}else if((d|0)==2){c[a+104>>2]=176;break}else if((d|0)==3){c[a+104>>2]=218;break}else{break}}}while(0);c[a+108>>2]=404;i=0;return i|0}function V0(a,b){a=a|0;b=b|0;ne[c[a+108>>2]&1023](b,b);return}function W0(a,b){a=a|0;b=b|0;var d=0,e=0.0,f=0,h=0.0,i=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0.0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0,v=0.0;d=1<<c[a>>2];e=+g[b>>2];f=b+(d<<2)|0;h=(e- +g[f>>2])*-.5;i=(d|0)/2|0;a:do{if((d|0)>1){j=c[a+96>>2]|0;k=h;l=0;m=e;while(1){n=b+(d-l<<2)|0;o=+g[n>>2];p=l<<1;q=m-o;r=q*+g[j+(d-p<<2)>>2];s=k+q*+g[j+(p<<2)>>2];q=(m+o)*.5;g[b+(l<<2)>>2]=q-r;g[n>>2]=q+r;n=l+1|0;if((n|0)>=(i|0)){t=s;break a}k=s;l=n;m=+g[b+(n<<2)>>2]}}else{t=h}}while(0);ne[c[a+92>>2]&1023](a+8|0,b);a=b+4|0;g[f>>2]=+g[a>>2];g[a>>2]=t;if((d|0)<3){return}else{u=3;v=t}do{a=b+(u<<2)|0;v=v- +g[a>>2];g[a>>2]=v;u=u+2|0;}while((u|0)<=(d|0));return}function X0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0.0,l=0,m=0.0,n=0.0,o=0.0,p=0.0;d=1<<c[a>>2];e=(d|0)/2|0;if((d|0)>1){f=d-1|0;h=c[a+96>>2]|0;i=0;do{j=b+(i<<2)|0;k=+g[j>>2];l=b+(f-i<<2)|0;m=+g[l>>2];n=(k-m)*+g[h+(d-(i<<1|1)<<2)>>2];o=(k+m)*.5;g[j>>2]=o+n;g[l>>2]=o-n;i=i+1|0;}while((i|0)<(e|0))}ne[c[a+92>>2]&1023](a+8|0,b);e=b+4|0;n=+g[e>>2];g[e>>2]=n*-1.0;e=d-2|0;if(!((e|0)>-1)){return}i=c[a+96>>2]|0;o=n*.5;a=d;h=e;while(1){e=b+(h<<2)|0;n=+g[e>>2];f=b+(a-1<<2)|0;m=+g[f>>2];k=+g[i+(h<<2)>>2];p=+g[i+(d-h<<2)>>2];g[e>>2]=n*k+m*p;g[f>>2]=o;f=h-2|0;if((f|0)>-1){o=o+(n*p-m*k);a=h;h=f}else{break}}return}function Y0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0.0,h=0.0,i=0,j=0,k=0,l=0,m=0.0,n=0,o=0.0,p=0.0,q=0.0;d=1<<c[a>>2];e=d-1|0;f=+g[b+(e<<2)>>2];h=1.0/+(d|0);i=d-2|0;if((i|0)>1){j=c[a+96>>2]|0;k=d;l=i;while(1){i=b+(l<<2)|0;m=+g[i>>2];n=b+(k-1<<2)|0;o=+g[b+(k-3<<2)>>2]- +g[n>>2];p=+g[j+(l<<2)>>2];q=+g[j+(d-l<<2)>>2];g[i>>2]=m*p+o*q;g[n>>2]=m*q-o*p;n=l-2|0;if((n|0)>1){k=l;l=n}else{break}}}g[b+4>>2]=f*2.0;ne[c[a+92>>2]&1023](a+8|0,b);l=(d|0)/2|0;if((d|0)<=1){return}d=c[a+100>>2]|0;a=0;do{k=b+(a<<2)|0;f=h*+g[k>>2];j=b+(e-a<<2)|0;p=h*+g[j>>2];o=+g[d+(a<<2)>>2]*(f-p);q=f+p;g[k>>2]=q+o;g[j>>2]=q-o;a=a+1|0;}while((a|0)<(l|0));return}function Z0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0.0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0.0,q=0,r=0;d=1<<c[a>>2];g[b>>2]=0.0;e=(d|0)/2|0;if((d|0)>3){f=c[a+96>>2]|0;h=1;do{i=b+(h<<2)|0;j=+g[i>>2];k=b+(d-h<<2)|0;l=+g[k>>2];m=(j+l)*+g[f+(d-(h<<1)<<2)>>2];n=(j-l)*.5;g[i>>2]=n+m;g[k>>2]=m-n;h=h+1|0;}while((h|0)<(e|0))}h=b+(e<<2)|0;g[h>>2]=+g[h>>2]*2.0;ne[c[a+92>>2]&1023](a+8|0,b);n=+g[b>>2]*.5;g[b>>2]=n;a=d-2|0;if((a|0)>1){o=1;p=n}else{q=d-1|0;r=b+(q<<2)|0;g[r>>2]=0.0;return}while(1){h=b+(o+1<<2)|0;n=p+ +g[h>>2];g[h>>2]=n;h=o+2|0;g[b+(o<<2)>>2]=-0.0- +g[b+(h<<2)>>2];if((h|0)<(a|0)){o=h;p=n}else{break}}q=d-1|0;r=b+(q<<2)|0;g[r>>2]=0.0;return}function _0(a){a=a|0;DUa(a+8|0);ZDb(c[a+100>>2]|0);return}function $0(a,b){a=a|0;b=b|0;var c=0.0,d=0.0,e=0.0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0;c=+g[b>>2];d=+g[b+124>>2];e=c+d;f=(c-d)*.5006030201911926;d=+g[b+60>>2];c=+g[b+64>>2];h=d+c;i=(d-c)*10.190008163452148;c=e+h;d=(e-h)*.5024192929267883;h=f+i;e=(i-f)*-.5024192929267883;f=+g[b+28>>2];i=+g[b+96>>2];j=f+i;k=(f-i)*.6748083233833313;i=+g[b+32>>2];f=+g[b+92>>2];l=i+f;m=(i-f)*.744536280632019;f=j+l;i=(j-l)*5.10114860534668;l=k+m;j=(m-k)*-5.10114860534668;k=c+f;m=(c-f)*.509795606136322;f=d+i;c=(i-d)*-.509795606136322;d=h+l;i=(h-l)*.509795606136322;l=e+j;h=(j-e)*-.509795606136322;e=+g[b+12>>2];j=+g[b+112>>2];n=e+j;o=(e-j)*.5310425758361816;j=+g[b+48>>2];e=+g[b+76>>2];p=j+e;q=(j-e)*1.4841645956039429;e=n+p;j=(n-p)*.6468217968940735;p=o+q;n=(q-o)*-.6468217968940735;o=+g[b+16>>2];q=+g[b+108>>2];r=o+q;s=(o-q)*.5531039237976074;q=+g[b+44>>2];o=+g[b+80>>2];t=q+o;u=(q-o)*1.1694399118423462;o=r+t;q=(r-t)*.7881546020507812;t=s+u;r=(u-s)*-.7881546020507812;s=e+o;u=(e-o)*2.562915563583374;o=j+q;e=(q-j)*-2.562915563583374;j=p+t;q=(p-t)*2.562915563583374;t=n+r;p=(r-n)*-2.562915563583374;n=k+s;r=(k-s)*.5411961078643799;s=m+u;k=(u-m)*-.5411961078643799;m=f+o;u=(f-o)*.5411961078643799;o=c+e;f=(e-c)*-.5411961078643799;c=d+j;e=(d-j)*.5411961078643799;j=i+q;d=(q-i)*-.5411961078643799;i=l+t;q=(l-t)*.5411961078643799;t=h+p;l=(p-h)*-.5411961078643799;h=+g[b+4>>2];p=+g[b+120>>2];v=h+p;w=(h-p)*.5054709315299988;p=+g[b+56>>2];h=+g[b+68>>2];x=p+h;y=(p-h)*3.4076085090637207;h=v+x;p=(v-x)*.522498607635498;x=w+y;v=(y-w)*-.522498607635498;w=+g[b+24>>2];y=+g[b+100>>2];z=w+y;A=(w-y)*.6225041151046753;y=+g[b+36>>2];w=+g[b+88>>2];B=y+w;C=(y-w)*.839349627494812;w=z+B;y=(z-B)*1.722447156906128;B=A+C;z=(C-A)*-1.722447156906128;A=h+w;C=(h-w)*.601344883441925;w=p+y;h=(y-p)*-.601344883441925;p=x+B;y=(x-B)*.601344883441925;B=v+z;x=(z-v)*-.601344883441925;v=+g[b+8>>2];z=+g[b+116>>2];D=v+z;E=(v-z)*.5154473185539246;z=+g[b+52>>2];v=+g[b+72>>2];F=z+v;G=(z-v)*2.0577809810638428;v=D+F;z=(D-F)*.5669440627098083;F=E+G;D=(G-E)*-.5669440627098083;E=+g[b+20>>2];G=+g[b+104>>2];H=E+G;I=(E-G)*.5829349756240845;G=+g[b+40>>2];E=+g[b+84>>2];J=G+E;K=(G-E)*.9725682139396667;E=H+J;G=(H-J)*1.0606776475906372;J=I+K;H=(K-I)*-1.0606776475906372;I=v+E;K=(v-E)*.8999761939048767;E=z+G;v=(G-z)*-.8999761939048767;z=F+J;G=(F-J)*.8999761939048767;J=D+H;F=(H-D)*-.8999761939048767;D=A+I;H=(A-I)*1.3065630197525024;I=C+K;A=(K-C)*-1.3065630197525024;C=w+E;K=(w-E)*1.3065630197525024;E=h+v;w=(v-h)*-1.3065630197525024;h=p+z;v=(p-z)*1.3065630197525024;z=y+G;p=(G-y)*-1.3065630197525024;y=B+J;G=(B-J)*1.3065630197525024;J=x+F;B=(F-x)*-1.3065630197525024;x=(H-r)*-.7071067690849304;F=(s-I)*.7071067690849304;L=(A-k)*-.7071067690849304;M=k+A+L;A=(m-C)*.7071067690849304;k=(K-u)*-.7071067690849304;N=u+K+k;K=(o-E)*.7071067690849304;u=(w-f)*-.7071067690849304;O=f+w+u;w=o+E+O;E=K+O;O=K+u;K=(c-h)*.7071067690849304;o=(v-e)*-.7071067690849304;f=e+v+o;v=(j-z)*.7071067690849304;e=(p-d)*-.7071067690849304;P=d+p+e;p=j+z+P;z=v+P;P=v+e;v=(i-y)*.7071067690849304;j=(G-q)*-.7071067690849304;d=q+G+j;G=(t-J)*.7071067690849304;q=(B-l)*-.7071067690849304;Q=l+B+q;B=t+J+Q;J=G+Q;Q=G+q;g[a>>2]=n+D;g[a+64>>2]=(n-D)*.7071067690849304;g[a+32>>2]=r+H+x;g[a+96>>2]=x;g[a+16>>2]=s+I+M;g[a+80>>2]=F+L;g[a+48>>2]=F+M;g[a+112>>2]=L;g[a+8>>2]=m+C+w;g[a+72>>2]=A+O;g[a+40>>2]=N+E;g[a+104>>2]=k+u;g[a+24>>2]=N+w;g[a+88>>2]=k+O;g[a+56>>2]=A+E;g[a+120>>2]=u;u=i+y+B;y=d+B;B=d+J;d=v+J;J=v+Q;v=j+Q;Q=j+q;g[a+4>>2]=c+h+u;g[a+68>>2]=K+J;g[a+36>>2]=f+B;g[a+100>>2]=o+Q;g[a+20>>2]=p+y;g[a+84>>2]=P+v;g[a+52>>2]=z+d;g[a+116>>2]=e+q;g[a+12>>2]=p+u;g[a+76>>2]=P+J;g[a+44>>2]=z+B;g[a+108>>2]=e+Q;g[a+28>>2]=f+y;g[a+92>>2]=o+v;g[a+60>>2]=K+d;g[a+124>>2]=q;return}function a1(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+60>>2]|0;c[a+140>>2]=11;e=a+120|0;f=c[e>>2]|0;if((f|0)==0){g=-1094995529;i=b;return g|0}h=a+124|0;j=c[h>>2]|0;if((j|0)==0){g=-1094995529;i=b;return g|0}if(!((hDb(f,j,0,a)|0)>-1)){yDb(0,0,2309192,(a=i,i=i+24|0,c[a>>2]=2258760,c[a+8>>2]=2244384,c[a+16>>2]=45,a)|0);i=a;Cd();return 0}a=cEb(ba(c[h>>2]|0,c[e>>2]|0)|0)|0;c[d+1024>>2]=a;g=(a|0)==0?-12:0;i=b;return g|0}function b1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;i=i+16|0;j=h|0;k=c[b+60>>2]|0;if((c[b+100>>2]|0)==2){l=c[b+96>>2]|0;m=(d[l]|d[l+1|0]<<8)<<16>>16&65535}else{m=0}l=_$a(b,e,0)|0;if((l|0)<0){n=l;i=h;return n|0}l=c[g+24>>2]|0;o=g+28|0;g=c[o>>2]|0;if(!((g|0)>-1)){yDb(0,0,2309192,(p=i,i=i+24|0,c[p>>2]=2290472,c[p+8>>2]=2274544,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}q=j|0;c[q>>2]=l;c[j+8>>2]=l;r=l+g|0;s=j+4|0;c[s>>2]=r;t=k+1024|0;a:do{if((g|0)==0){u=b+124|0}else{v=b+120|0;w=b+124|0;x=b;y=e+304|0;z=k;A=r;B=l;b:while(1){C=A;D=C-B|0;E=D>>>0>4>>>0?4:D;D=B+E|0;c[q>>2]=D;if((C-D|0)<4){F=0;G=D}else{H=B+(E+4)|0;c[q>>2]=H;E=D;F=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;G=H}if((C-G|0)<4){u=w;break a}H=G+4|0;c[q>>2]=H;E=G;D=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;do{if((D|0)==1){if(F>>>0>770>>>0){I=256;J=15}else{if(!(F>>>0<3>>>0)){I=(F>>>0)/3|0;J=15}}if((J|0)==15){J=0;E=0;K=H;while(1){if((C-K|0)<3){L=0;M=K}else{N=K+3|0;c[q>>2]=N;L=(d[K+1|0]|0)<<8|(d[K]|0)<<16|(d[K+2|0]|0);M=N}c[z+(E<<2)>>2]=L<<2|L>>>4&197379|-16777216;N=E+1|0;if((N|0)<(I|0)){E=N;K=M}else{break}}}c[y>>2]=1}else if((D|0)==0){u=w;break a}else{if(D>>>0<10>>>0){O=D-2|0;if((_e[c[1402832+(O<<2)>>2]&1023](j,c[t>>2]|0,c[v>>2]|0,c[w>>2]|0)|0)==0){break}else{break b}}else{yDb(x,24,2113216,(p=i,i=i+8|0,c[p>>2]=D,p)|0);i=p;break}}}while(0);D=c[q>>2]|0;C=c[s>>2]|0;if((C|0)==(D|0)){u=w;break a}else{A=C;B=D}}yDb(x,16,2190608,(p=i,i=i+8|0,c[p>>2]=c[1485824+(O<<2)>>2],p)|0);i=p;n=-1094995529;i=h;return n|0}}while(0);p=c[t>>2]|0;t=c[e>>2]|0;O=c[u>>2]|0;c:do{if((O|0)>0){s=e+32|0;q=b+120|0;if((m|0)==256){P=t;Q=0;R=O}else{j=t;M=0;I=p;while(1){UGb(j|0,I|0,c[q>>2]|0)|0;L=M+1|0;if((L|0)<(c[u>>2]|0)){j=j+(c[s>>2]|0)|0;M=L;I=I+(c[q>>2]|0)|0}else{break c}}}while(1){I=c[q>>2]|0;if((I|0)>0){M=Q&3;j=(Q|0)/4|0;x=0;L=I;I=R;while(1){a[P+x|0]=a[p+((ba((L|0)/4|0,M)|0)+((x|0)/4|0)+(ba((ba((I|0)/4|0,x&3)|0)+j|0,L)|0))|0]|0;J=x+1|0;F=c[q>>2]|0;G=c[u>>2]|0;if((J|0)<(F|0)){x=J;L=F;I=G}else{S=G;break}}}else{S=R}I=Q+1|0;if((I|0)<(S|0)){P=P+(c[s>>2]|0)|0;Q=I;R=S}else{break}}}}while(0);UGb(c[e+4>>2]|0,k|0,1024)|0;c[f>>2]=1;n=c[o>>2]|0;i=h;return n|0}function c1(a){a=a|0;$Db((c[a+60>>2]|0)+1024|0);return 0}function d1(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=ba(e,d)|0;d=a|0;e=c[d>>2]|0;g=(c[a+4>>2]|0)-e|0;a=g>>>0>f>>>0?f:g;UGb(b|0,e|0,a)|0;c[d>>2]=(c[d>>2]|0)+a;return((a|0)==(f|0)?0:-1094995529)|0}function e1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=ba(g,f)|0;f=b+4|0;g=c[f>>2]|0;i=b|0;b=c[i>>2]|0;j=g;if((j-b|0)<4){k=0;l=b}else{m=b+4|0;c[i>>2]=m;n=b;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;l=m}if((j-l|0)<4){o=0;p=l}else{j=l+4|0;c[i>>2]=j;m=l;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;p=j}j=(k|0)==0;if(j&(o|0)==(h|0)){q=0;return q|0}m=e+h|0;l=e;n=h>>>0<=o>>>0;if(n|j){q=n?-1094995529:0;return q|0}n=65536;j=0;h=e+o|0;o=k;k=p;p=g;while(1){g=o-1|0;e=p;if((e-k|0)>>>0<2>>>0){q=-1094995529;r=24;break}if((n|0)==65536){b=k+2|0;c[i>>2]=b;s=k;t=(d[s]|d[s+1|0]<<8)<<16>>16&65535;u=1;v=b}else{t=j;u=n;v=k}b=h;s=m-b|0;if((s|0)<2){q=-1094995529;r=24;break}w=e-v|0;if((t&u|0)==0){if((w|0)<1){x=0}else{c[i>>2]=v+1;x=a[v]|0}a[h]=x;e=c[i>>2]|0;if(((c[f>>2]|0)-e|0)<1){y=0}else{c[i>>2]=e+1;y=a[e]|0}a[h+1|0]=y;z=h+2|0}else{if((w|0)<2){A=0}else{c[i>>2]=v+2;w=v;A=(d[w]|d[w+1|0]<<8)<<16>>16&65535}w=A<<1&16382;e=(A>>>13<<1)+4|0;if((b-l|0)>>>0<w>>>0|(s|0)<(e|0)){q=-1094995529;r=24;break}iEb(h,w,e);z=h+e|0}if((g|0)==0){q=0;r=24;break}n=u<<1;j=t;h=z;o=g;k=c[i>>2]|0;p=c[f>>2]|0}if((r|0)==24){return q|0}return 0}function f1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=b+4|0;i=c[h>>2]|0;j=b|0;b=c[j>>2]|0;k=i;if((k-b|0)<2){l=0;m=b}else{n=b+2|0;c[j>>2]=n;o=b;l=(d[o]|d[o+1|0]<<8)<<16>>16&65535;m=n}if((l|0)>=(g|0)){p=-1094995529;return p|0}n=e+(ba(l,f)|0)|0;if((k-m|0)<2){q=0;r=m}else{k=m+2|0;c[j>>2]=k;e=m;q=(d[e]|d[e+1|0]<<8)<<16>>16&65535;r=k}if((q+l|0)>(g|0)){p=-1094995529;return p|0}if((q|0)==0){p=0;return p|0}else{s=n;t=q;u=r;v=i}a:while(1){i=t-1|0;if((v|0)==(u|0)){p=-1094995529;w=28;break}r=s+f|0;q=u+1|0;c[j>>2]=q;n=a[u]|0;b:do{if(!(n<<24>>24==0)){g=r;l=s;k=n&255;e=q;m=v;while(1){o=k-1|0;b=m;x=(b-e|0)<1;if(x){y=0}else{y=d[e]|0}if(!((g-l|0)>>>0>y>>>0)){p=-1094995529;w=28;break a}if(x){z=0;A=e}else{x=e+1|0;c[j>>2]=x;z=d[e]|0;A=x}x=l+z|0;do{if((b-A|0)<1){B=0;C=A;w=20}else{D=A+1|0;c[j>>2]=D;E=a[A]|0;F=E<<24>>24;if(((E&255)<<24|0)>-16777216){B=F;C=D;w=20;break}E=-F|0;if((g-x|0)<(E|0)){p=-1094995529;w=28;break a}if((b-D|0)<1){G=0}else{c[j>>2]=A+2;G=a[D]|0}TGb(x|0,G|0,E|0)|0;H=E}}while(0);if((w|0)==20){w=0;if((g-x|0)<(B|0)){p=-1094995529;w=28;break a}E=b-C|0;D=E>>>0>B>>>0?B:E;UGb(x|0,C|0,D)|0;c[j>>2]=(c[j>>2]|0)+D;if((D|0)==(B|0)){H=B}else{p=-1094995529;w=28;break a}}if((o|0)==0){break b}l=l+(H+z)|0;k=o;e=c[j>>2]|0;m=c[h>>2]|0}}}while(0);if((i|0)==0){p=0;w=28;break}s=r;t=i;u=c[j>>2]|0;v=c[h>>2]|0}if((w|0)==28){return p|0}return 0}function g1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=e+(ba(g,f)|0)|0;i=b+4|0;j=c[i>>2]|0;k=b|0;b=c[k>>2]|0;if((j-b|0)<2){l=0;m=b}else{n=b+2|0;c[k>>2]=n;o=b;l=(d[o]|d[o+1|0]<<8)<<16>>16&65535;m=n}if((l|0)>(g|0)){p=-1094995529;return p|0}if((l|0)==0){p=0;return p|0}n=h;o=f-1|0;b=-f|0;q=0;r=e;e=l;l=m;m=j;a:while(1){j=e-1|0;s=m;if((s-l|0)>>>0<2>>>0){p=-1094995529;t=40;break}u=l+2|0;c[k>>2]=u;v=l;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;b:do{if((w&49152|0)==49152){v=w;y=q;z=r;A=u;while(1){B=v<<16>>16;C=ba(B,b)|0;if(!((n-z|0)>>>0>C>>>0)){p=-1094995529;t=40;break a}if((y+j-B|0)>>>0>g>>>0){p=-1094995529;t=40;break a}D=z+C|0;C=y-B|0;if((s-A|0)<2){E=0;F=C;G=D;H=A;break b}B=A+2|0;c[k>>2]=B;I=A;J=(d[I]|d[I+1|0]<<8)<<16>>16&65535;if((J&49152|0)==49152){v=J;y=C;z=D;A=B}else{E=J;F=C;G=D;H=B;break}}}else{E=w;F=q;G=r;H=u}}while(0);if(!(h>>>0>G>>>0)){p=-1094995529;t=40;break}do{if((E&32768|0)==0){K=E;L=H;M=m}else{a[G+o|0]=E;u=c[i>>2]|0;w=c[k>>2]|0;if((u-w|0)<2){K=0;L=w;M=u;break}s=w+2|0;c[k>>2]=s;A=w;K=(d[A]|d[A+1|0]<<8)<<16>>16&65535;L=s;M=u}}while(0);if((n-G|0)<(f|0)){p=-1094995529;t=40;break}u=G+f|0;s=F+1|0;c:do{if((K|0)!=0){A=u;w=G;z=K;y=L;v=M;while(1){B=z-1|0;D=v;C=(D-y|0)<1;if(C){N=0}else{N=d[y]|0}if(!((A-w|0)>>>0>N>>>0)){p=-1094995529;t=40;break a}if(C){O=0;P=y}else{C=y+1|0;c[k>>2]=C;O=d[y]|0;P=C}C=w+O|0;do{if((D-P|0)<1){Q=0;R=P;t=29}else{J=P+1|0;c[k>>2]=J;I=a[P]|0;S=(I&255)<<24;if((S|0)>-16777216){Q=S;R=J;t=29;break}S=I<<24>>24;T=-S|0;if((A-C|0)<(T<<1|0)){p=-1094995529;t=40;break a}if((D-J|0)<2){U=0}else{c[k>>2]=P+3;V=J;U=(d[V]|d[V+1|0]<<8)<<16>>16}if(!(I<<24>>24<0)){W=C;break}I=-S|0;S=O+((I|0)>1?I<<1:2)|0;I=C;V=0;while(1){J=I;x=U;a[J]=x;x=x>>8;a[J+1|0]=x;J=V+1|0;if((J|0)<(T|0)){I=I+2|0;V=J}else{break}}W=w+S|0}}while(0);if((t|0)==29){t=0;V=Q>>23;if((A-C|0)<(V|0)){p=-1094995529;t=40;break a}I=D-R|0;T=I>>>0>V>>>0?V:I;UGb(C|0,R|0,T)|0;c[k>>2]=(c[k>>2]|0)+T;if((T|0)!=(V|0)){p=-1094995529;t=40;break a}W=w+(V+O)|0}if((B|0)==0){break c}w=W;z=B;y=c[k>>2]|0;v=c[i>>2]|0}}}while(0);if((j|0)==0){p=0;t=40;break}q=s;r=u;e=j;l=c[k>>2]|0;m=c[i>>2]|0}if((t|0)==40){return p|0}return 0}function h1(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=b+(ba(f,e)|0)|0;e=a+4|0;f=c[e>>2]|0;h=a|0;a=c[h>>2]|0;if((f-a|0)<4){i=0;return i|0}j=a+4|0;c[h>>2]=j;k=a;a=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;if((a|0)==0){i=0;return i|0}k=g;g=b;b=a;a=j;j=f;while(1){f=b-1|0;l=j;if((l-a|0)>>>0<2>>>0){i=-1094995529;m=9;break}n=a+1|0;c[h>>2]=n;o=(d[a]|0)<<1;p=a+2|0;c[h>>2]=p;q=(d[n]|0)<<1;n=q+o|0;if((k-g|0)<(n|0)){i=-1094995529;m=9;break}r=l-p|0;if(r>>>0<o>>>0){i=-1094995529;m=9;break}l=r>>>0>o>>>0?o:r;UGb(g+q|0,p|0,l)|0;p=(c[h>>2]|0)+l|0;c[h>>2]=p;if((f|0)==0){i=0;m=9;break}g=g+n|0;b=f;a=p;j=c[e>>2]|0}if((m|0)==9){return i|0}return 0}function i1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=e+(ba(g,f)|0)|0;f=b+4|0;g=c[f>>2]|0;i=b|0;b=c[i>>2]|0;if((g-b|0)<2){j=0;return j|0}k=b+2|0;c[i>>2]=k;l=b;b=(d[l]|d[l+1|0]<<8)<<16>>16;if(b<<16>>16==0){j=0;return j|0}l=h;h=e;m=0;n=65536;o=e;e=b&65535;b=k;k=g;a:while(1){g=e-1|0;p=k;if((p-b|0)>>>0<2>>>0){j=-1094995529;q=24;break}if((n|0)==65536){r=b+2|0;c[i>>2]=r;s=b;t=1;u=(d[s]|d[s+1|0]<<8)<<16>>16&65535;v=r}else{t=n;u=m;v=b}r=o;s=l-r|0;if((s|0)<2){j=-1094995529;q=24;break}do{if((t&u|0)==0){w=p-v|0;if((t<<1&u|0)!=0){if((w|0)<2){x=0}else{c[i>>2]=v+2;y=v;x=(d[y]|d[y+1|0]<<8)<<16>>16&65535}z=o+x|0;break}if((w|0)<1){A=0}else{c[i>>2]=v+1;A=a[v]|0}a[o]=A;w=c[i>>2]|0;if(((c[f>>2]|0)-w|0)<1){B=0}else{c[i>>2]=w+1;B=a[w]|0}a[o+1|0]=B;z=o+2|0}else{if((p-v|0)<2){C=0}else{c[i>>2]=v+2;w=v;C=(d[w]|d[w+1|0]<<8)<<16>>16&65535}w=C<<1&16382;y=(C>>>13<<1)+4|0;if((r-h|0)<(w|0)|(s|0)<(y|0)){j=-1094995529;q=24;break a}iEb(o,w,y);z=o+y|0}}while(0);if((g|0)==0){j=0;q=24;break}m=u;n=t<<2;o=z;e=g;b=c[i>>2]|0;k=c[f>>2]|0}if((q|0)==24){return j|0}return 0}function j1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;TGb(b|0,0,ba(d,c)|0)|0;return 0}function k1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=b+4|0;i=c[h>>2]|0;j=b|0;b=c[j>>2]|0;if((i-b|0)<2){k=0;return k|0}l=e+(ba(g,f)|0)|0;g=b+2|0;c[j>>2]=g;m=b;b=(d[m]|d[m+1|0]<<8)<<16>>16;m=l;if(b<<16>>16==0){k=0;return k|0}l=f+3|0;n=f+1|0;o=f+2|0;p=e;q=65536;r=0;s=e;e=b&65535;b=g;g=i;a:while(1){i=e-1|0;t=g;if((t-b|0)>>>0<2>>>0){k=-1094995529;u=28;break}if((q|0)==65536){v=b+2|0;c[j>>2]=v;w=b;x=(d[w]|d[w+1|0]<<8)<<16>>16&65535;y=1;z=v}else{x=r;y=q;z=b}do{if((x&y|0)==0){if((x&y<<1|0)!=0){if((t-z|0)<2){A=0}else{c[j>>2]=z+2;v=z;A=((d[v]|d[v+1|0]<<8)<<16>>16&65535)<<1}if((s-m|0)<(A|0)){k=-1094995529;u=28;break a}B=s+A|0;break}if((m-s|0)<(l|0)){k=-1094995529;u=28;break a}if((t-z|0)<1){C=0}else{c[j>>2]=z+1;C=a[z]|0}a[s+n|0]=C;a[s+f|0]=C;a[s+1|0]=C;a[s]=C;v=c[j>>2]|0;if(((c[h>>2]|0)-v|0)<1){D=0}else{c[j>>2]=v+1;D=a[v]|0}a[s+l|0]=D;a[s+o|0]=D;a[s+3|0]=D;a[s+2|0]=D;B=s+4|0}else{if((t-z|0)<2){E=0}else{c[j>>2]=z+2;v=z;E=(d[v]|d[v+1|0]<<8)<<16>>16&65535}v=E<<2&32764;w=E>>>13;F=(w<<1)+4|0;G=s;if((G-p|0)<(v|0)){k=-1094995529;u=28;break a}if((m-G|0)<((F<<1)+f|0)){k=-1094995529;u=28;break a}G=-v|0;v=w<<2;w=0;H=s;while(1){I=a[H+G|0]|0;a[H+n|0]=I;a[H+f|0]=I;a[H+1|0]=I;a[H]=I;I=w+1|0;if((I|0)<(F|0)){w=I;H=H+2|0}else{break}}B=s+(v+8)|0}}while(0);if((i|0)==0){k=0;u=28;break}q=y<<2;r=x;s=B;e=i;b=c[j>>2]|0;g=c[h>>2]|0}if((u|0)==28){return k|0}return 0}function l1(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=f+8|0;m=c[l>>2]|0;n=f+16|0;o=c[n>>2]|0;p=f|0;f=c[p>>2]|0;q=f+(m>>>3)|0;r=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(m&7);if((r&-1434451968|0)==0){q=1;s=m;t=r;while(1){u=t>>>24;v=a[1201432+u|0]|0;w=v&255;x=((v&255)>>>0>8>>>0?8:w)+s|0;y=o>>>0>x>>>0;z=y?x:o;if(!(v<<24>>24==9)){A=4;break}v=d[1201688+u|0]|q<<4;if(!(v>>>0<134217728>>>0)){B=v;break}x=f+(z>>>3)|0;C=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7);if(y){q=v;s=z;t=C}else{B=v;break}}if((A|0)==4){B=d[1201688+u|0]|q<<(w-1>>1)}c[l>>2]=z;D=B-1|0;E=z}else{z=r>>>24;r=(d[1201432+z|0]|0)+m|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;D=d[1200920+z|0]|0;E=m}m=f+(E>>>3)|0;z=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(E&7);a:do{if((z&-1434451968|0)==0){m=1;r=E;B=z;while(1){w=B>>>24;q=a[1201432+w|0]|0;u=((q&255)>>>0>8>>>0?8:q&255)+r|0;t=o>>>0>u>>>0;s=t?u:o;if(!(q<<24>>24==9)){F=s;break a}q=d[1201688+w|0]|m<<4;if(!(q>>>0<134217728>>>0)){F=s;break a}w=f+(s>>>3)|0;u=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(s&7);if(t){m=q;r=s;B=u}else{F=s;break}}}else{B=(d[1201432+(z>>>24)|0]|0)+E|0;F=o>>>0>B>>>0?B:o}}while(0);c[l>>2]=F;E=f+(F>>>3)|0;z=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(F&7);if((z&-1434451968|0)==0){E=1;B=F;r=z;while(1){G=r>>>24;m=a[1201432+G|0]|0;H=m&255;s=((m&255)>>>0>8>>>0?8:H)+B|0;u=o>>>0>s>>>0;I=u?s:o;if(!(m<<24>>24==9)){A=16;break}m=d[1201688+G|0]|E<<4;if(!(m>>>0<134217728>>>0)){J=m;break}s=f+(I>>>3)|0;q=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(I&7);if(u){E=m;B=I;r=q}else{J=m;break}}if((A|0)==16){J=d[1201688+G|0]|E<<(H-1>>1)}c[l>>2]=I;K=J-1|0}else{J=z>>>24;z=(d[1201432+J|0]|0)+F|0;c[l>>2]=o>>>0>z>>>0?z:o;K=d[1200920+J|0]|0}c[e+840>>2]=K;K=c[l>>2]|0;J=c[n>>2]|0;o=f+(K>>>3)|0;z=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(K&7);if((z&-1434451968|0)==0){o=1;F=K;I=z;while(1){L=I>>>24;H=a[1201432+L|0]|0;M=H&255;E=((H&255)>>>0>8>>>0?8:M)+F|0;G=J>>>0>E>>>0;N=G?E:J;if(!(H<<24>>24==9)){A=23;break}H=d[1201688+L|0]|o<<4;if(!(H>>>0<134217728>>>0)){O=H;break}E=f+(N>>>3)|0;r=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(N&7);if(G){o=H;F=N;I=r}else{O=H;break}}if((A|0)==23){O=d[1201688+L|0]|o<<(M-1>>1)}c[l>>2]=N;P=O-1|0}else{O=z>>>24;z=(d[1201432+O|0]|0)+K|0;c[l>>2]=J>>>0>z>>>0?z:J;P=d[1200920+O|0]|0}c[e+844>>2]=P;P=c[l>>2]|0;O=c[n>>2]|0;J=f+(P>>>3)|0;z=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(P&7);if((z&-1434451968|0)==0){J=1;K=P;N=z;while(1){Q=N>>>24;M=a[1201432+Q|0]|0;R=M&255;o=((M&255)>>>0>8>>>0?8:R)+K|0;L=O>>>0>o>>>0;S=L?o:O;if(!(M<<24>>24==9)){A=30;break}M=d[1201688+Q|0]|J<<4;if(!(M>>>0<134217728>>>0)){T=M;break}o=f+(S>>>3)|0;I=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(S&7);if(L){J=M;K=S;N=I}else{T=M;break}}if((A|0)==30){T=d[1201688+Q|0]|J<<(R-1>>1)}c[l>>2]=S;U=T-1|0}else{T=z>>>24;z=(d[1201432+T|0]|0)+P|0;c[l>>2]=O>>>0>z>>>0?z:O;U=d[1200920+T|0]|0}do{if(D>>>0<2>>>0){yDb(e,24,2309352,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}else{if(!(D>>>0>2>>>0)){break}yDb(e,24,2328176,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}}while(0);if(U>>>0>20>>>0){W=-1094995529;i=h;return W|0}D=g;T=1361704+(U*24|0)|0;c[D>>2]=c[T>>2];c[D+4>>2]=c[T+4>>2];c[D+8>>2]=c[T+8>>2];c[D+12>>2]=c[T+12>>2];c[D+16>>2]=c[T+16>>2];c[D+20>>2]=c[T+20>>2];T=c[l>>2]|0;D=c[p>>2]|0;U=d[D+(T>>>3)|0]|0;O=c[n>>2]|0;z=((T|0)<(O|0))+T|0;c[l>>2]=z;if((U&128>>>((T&7)>>>0)|0)==0){X=z;Y=O}else{T=D+(z>>>3)|0;U=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(z&7);if((U&-1434451968|0)==0){T=1;P=z;S=U;while(1){Z=S>>>24;R=a[1201432+Z|0]|0;_=R&255;J=((R&255)>>>0>8>>>0?8:_)+P|0;Q=O>>>0>J>>>0;$=Q?J:O;if(!(R<<24>>24==9)){A=43;break}R=d[1201688+Z|0]|T<<4;if(!(R>>>0<134217728>>>0)){aa=R;break}J=D+($>>>3)|0;N=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<($&7);if(Q){T=R;P=$;S=N}else{aa=R;break}}if((A|0)==43){aa=d[1201688+Z|0]|T<<(_-1>>1)}c[l>>2]=$;ba=aa-1|0}else{aa=U>>>24;U=(d[1201432+aa|0]|0)+z|0;c[l>>2]=O>>>0>U>>>0?U:O;ba=d[1200920+aa|0]|0}c[g>>2]=ba;ba=c[l>>2]|0;aa=c[n>>2]|0;O=D+(ba>>>3)|0;U=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(ba&7);if((U&-1434451968|0)==0){O=1;z=ba;$=U;while(1){ca=$>>>24;_=a[1201432+ca|0]|0;da=_&255;T=((_&255)>>>0>8>>>0?8:da)+z|0;Z=aa>>>0>T>>>0;ea=Z?T:aa;if(!(_<<24>>24==9)){A=50;break}_=d[1201688+ca|0]|O<<4;if(!(_>>>0<134217728>>>0)){fa=_;break}T=D+(ea>>>3)|0;S=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(ea&7);if(Z){O=_;z=ea;$=S}else{fa=_;break}}if((A|0)==50){fa=d[1201688+ca|0]|O<<(da-1>>1)}c[l>>2]=ea;ga=fa-1|0}else{fa=U>>>24;U=(d[1201432+fa|0]|0)+ba|0;c[l>>2]=aa>>>0>U>>>0?U:aa;ga=d[1200920+fa|0]|0}c[g+4>>2]=ga;X=c[l>>2]|0;Y=c[n>>2]|0}ga=d[D+(X>>>3)|0]|0;fa=((X|0)<(Y|0))+X|0;c[l>>2]=fa;if((ga&128>>>((X&7)>>>0)|0)==0){ha=a[g+8|0]|0}else{X=D+(fa>>>3)|0;ga=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(fa&7);if((ga&-1434451968|0)==0){X=1;aa=fa;U=ga;while(1){ia=U>>>24;ba=a[1201432+ia|0]|0;ja=ba&255;ea=((ba&255)>>>0>8>>>0?8:ja)+aa|0;da=Y>>>0>ea>>>0;ka=da?ea:Y;if(!(ba<<24>>24==9)){A=60;break}ba=d[1201688+ia|0]|X<<4;if(!(ba>>>0<134217728>>>0)){la=ba;break}ea=D+(ka>>>3)|0;O=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ka&7);if(da){X=ba;aa=ka;U=O}else{la=ba;break}}if((A|0)==60){la=d[1201688+ia|0]|X<<(ja-1>>1)}c[l>>2]=ka;ma=la+255&255}else{la=ga>>>24;ga=(d[1201432+la|0]|0)+fa|0;c[l>>2]=Y>>>0>ga>>>0?ga:Y;ma=a[1200920+la|0]|0}a[g+8|0]=ma;ha=ma}ma=g+8|0;if((ha&255)>>>0>2>>>0){yDb(e,16,2113072,(V=i,i=i+8|0,c[V>>2]=ha&255,V)|0);i=V;W=-1094995529;i=h;return W|0}ha=c[l>>2]|0;la=c[p>>2]|0;Y=d[la+(ha>>>3)|0]|0;ga=c[n>>2]|0;fa=((ha|0)<(ga|0))+ha|0;c[l>>2]=fa;if((Y&128>>>((ha&7)>>>0)|0)==0){na=a[g+9|0]|0}else{ha=la+(fa>>>3)|0;Y=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(fa&7);if((Y&-1434451968|0)==0){ha=1;ka=fa;ja=Y;while(1){oa=ja>>>24;X=a[1201432+oa|0]|0;pa=X&255;ia=((X&255)>>>0>8>>>0?8:pa)+ka|0;U=ga>>>0>ia>>>0;qa=U?ia:ga;if(!(X<<24>>24==9)){A=72;break}X=d[1201688+oa|0]|ha<<4;if(!(X>>>0<134217728>>>0)){ra=X;break}ia=la+(qa>>>3)|0;aa=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(qa&7);if(U){ha=X;ka=qa;ja=aa}else{ra=X;break}}if((A|0)==72){ra=d[1201688+oa|0]|ha<<(pa-1>>1)}c[l>>2]=qa;sa=ra+255&255}else{ra=Y>>>24;Y=(d[1201432+ra|0]|0)+fa|0;c[l>>2]=ga>>>0>Y>>>0?Y:ga;sa=a[1200920+ra|0]|0}a[g+9|0]=sa;na=sa}if((na&255)>>>0>1>>>0){W=-1094995529;i=h;return W|0}na=c[l>>2]|0;sa=c[p>>2]|0;ra=d[sa+(na>>>3)|0]|0;ga=c[n>>2]|0;Y=((na|0)<(ga|0))+na|0;c[l>>2]=Y;do{if((ra&128>>>((na&7)>>>0)|0)==0){ta=0;ua=0;va=g+11|0}else{fa=sa+(Y>>>3)|0;qa=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Y&7);if((qa&-1434451968|0)==0){fa=1;pa=Y;ha=qa;while(1){wa=ha>>>24;oa=a[1201432+wa|0]|0;xa=oa&255;ja=((oa&255)>>>0>8>>>0?8:xa)+pa|0;ka=ga>>>0>ja>>>0;ya=ka?ja:ga;if(!(oa<<24>>24==9)){A=83;break}oa=d[1201688+wa|0]|fa<<4;if(!(oa>>>0<134217728>>>0)){za=oa;break}ja=sa+(ya>>>3)|0;la=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ya&7);if(ka){fa=oa;pa=ya;ha=la}else{za=oa;break}}if((A|0)==83){za=d[1201688+wa|0]|fa<<(xa-1>>1)}c[l>>2]=ya;Aa=za-1|0}else{ha=qa>>>24;pa=(d[1201432+ha|0]|0)+Y|0;c[l>>2]=ga>>>0>pa>>>0?pa:ga;Aa=d[1200920+ha|0]|0}ha=Aa&255;pa=g+11|0;a[pa]=ha;if((Aa&255)>>>0>10>>>0){W=-1094995529;i=h;return W|0}if(!(ha<<24>>24==0)){ta=0;ua=0;va=pa;break}ha=c[l>>2]|0;oa=c[n>>2]|0;la=c[p>>2]|0;ka=la+(ha>>>3)|0;ja=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ha&7);if((ja&-1434451968|0)==0){ka=1;X=ha;aa=ja;while(1){Ba=aa>>>24;U=a[1201432+Ba|0]|0;Ca=U&255;ia=((U&255)>>>0>8>>>0?8:Ca)+X|0;D=oa>>>0>ia>>>0;Da=D?ia:oa;if(!(U<<24>>24==9)){A=92;break}U=d[1201688+Ba|0]|ka<<4;if(!(U>>>0<134217728>>>0)){Ea=U;break}ia=la+(Da>>>3)|0;ba=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(Da&7);if(D){ka=U;X=Da;aa=ba}else{Ea=U;break}}if((A|0)==92){Ea=d[1201688+Ba|0]|ka<<(Ca-1>>1)}c[l>>2]=Da;Fa=Ea-1|0;Ga=Da}else{aa=ja>>>24;X=(d[1201432+aa|0]|0)+ha|0;qa=oa>>>0>X>>>0?X:oa;c[l>>2]=qa;Fa=d[1200920+aa|0]|0;Ga=qa}qa=la+(Ga>>>3)|0;aa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Ga&7);if((aa&-1434451968|0)==0){Ha=1;Ia=Ga;Ja=aa}else{qa=aa>>>24;aa=(d[1201432+qa|0]|0)+Ga|0;c[l>>2]=oa>>>0>aa>>>0?aa:oa;ta=Fa;ua=d[1200920+qa|0]|0;va=pa;break}while(1){Ka=Ja>>>24;qa=a[1201432+Ka|0]|0;La=qa&255;aa=((qa&255)>>>0>8>>>0?8:La)+Ia|0;X=oa>>>0>aa>>>0;Ma=X?aa:oa;if(!(qa<<24>>24==9)){A=99;break}qa=d[1201688+Ka|0]|Ha<<4;if(!(qa>>>0<134217728>>>0)){Na=qa;break}aa=la+(Ma>>>3)|0;fa=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(Ma&7);if(X){Ha=qa;Ia=Ma;Ja=fa}else{Na=qa;break}}if((A|0)==99){Na=d[1201688+Ka|0]|Ha<<(La-1>>1)}c[l>>2]=Ma;ta=Fa;ua=Na-1|0;va=pa}}while(0);Na=a[va]|0;va=Na&255;do{if(Na<<24>>24==0){Oa=ta;Pa=ua}else{if((Na&255)>>>0<9>>>0){Oa=c[1180208+(va<<3)>>2]|0;Pa=c[1180212+(va<<3)>>2]|0;break}else{Fa=va-9|0;Oa=c[1362296+(Fa<<3)>>2]|0;Pa=c[1362300+(Fa<<3)>>2]|0;break}}}while(0);iFb(e+104|0,e+108|0,Pa,(Pa|0)<0|0?-1:0,Oa,(Oa|0)<0|0?-1:0,1073741824,0)|0;Oa=c[l>>2]|0;Pa=c[p>>2]|0;va=d[Pa+(Oa>>>3)|0]|0;Na=c[n>>2]|0;ua=((Oa|0)<(Na|0))+Oa|0;c[l>>2]=ua;do{if((va&128>>>((Oa&7)>>>0)|0)==0){Qa=g+12|0}else{ta=Pa+(ua>>>3)|0;Fa=(fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(ua&7);if((Fa&-1434451968|0)==0){ta=1;Ma=ua;La=Fa;while(1){Ra=La>>>24;Ha=a[1201432+Ra|0]|0;Sa=Ha&255;Ka=((Ha&255)>>>0>8>>>0?8:Sa)+Ma|0;Ja=Na>>>0>Ka>>>0;Ta=Ja?Ka:Na;if(!(Ha<<24>>24==9)){A=112;break}Ha=d[1201688+Ra|0]|ta<<4;if(!(Ha>>>0<134217728>>>0)){Ua=Ha;break}Ka=Pa+(Ta>>>3)|0;Ia=(fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ta&7);if(Ja){ta=Ha;Ma=Ta;La=Ia}else{Ua=Ha;break}}if((A|0)==112){Ua=d[1201688+Ra|0]|ta<<(Sa-1>>1)}c[l>>2]=Ta;Va=Ua-1|0}else{La=Fa>>>24;Ma=(d[1201432+La|0]|0)+ua|0;c[l>>2]=Na>>>0>Ma>>>0?Ma:Na;Va=d[1200920+La|0]|0}La=Va&255;Ma=g+12|0;a[Ma]=La;if((Va&255)>>>0>6>>>0){W=-1094995529;i=h;return W|0}if(!(La<<24>>24==0)){Qa=Ma;break}La=c[l>>2]|0;pa=c[n>>2]|0;Ha=c[p>>2]|0;Ia=Ha+(La>>>3)|0;Ja=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(La&7);if((Ja&-1434451968|0)==0){Ia=1;Ka=La;Ga=Ja;while(1){Wa=Ga>>>24;Da=a[1201432+Wa|0]|0;Xa=Da&255;Ea=((Da&255)>>>0>8>>>0?8:Xa)+Ka|0;Ca=pa>>>0>Ea>>>0;Ya=Ca?Ea:pa;if(!(Da<<24>>24==9)){A=121;break}Da=d[1201688+Wa|0]|Ia<<4;if(!(Da>>>0<134217728>>>0)){Za=Da;break}Ea=Ha+(Ya>>>3)|0;Ba=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ya&7);if(Ca){Ia=Da;Ka=Ya;Ga=Ba}else{Za=Da;break}}if((A|0)==121){Za=d[1201688+Wa|0]|Ia<<(Xa-1>>1)}c[l>>2]=Ya;_a=Za-1|0}else{Ga=Ja>>>24;Ka=(d[1201432+Ga|0]|0)+La|0;c[l>>2]=pa>>>0>Ka>>>0?Ka:pa;_a=d[1200920+Ga|0]|0}c[e+224>>2]=_a;Ga=c[l>>2]|0;Ka=c[n>>2]|0;Fa=Ha+(Ga>>>3)|0;ta=(fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ga&7);if((ta&-1434451968|0)==0){Fa=1;Da=Ga;Ba=ta;while(1){$a=Ba>>>24;Ca=a[1201432+$a|0]|0;ab=Ca&255;Ea=((Ca&255)>>>0>8>>>0?8:ab)+Da|0;Aa=Ka>>>0>Ea>>>0;bb=Aa?Ea:Ka;if(!(Ca<<24>>24==9)){A=128;break}Ca=d[1201688+$a|0]|Fa<<4;if(!(Ca>>>0<134217728>>>0)){cb=Ca;break}Ea=Ha+(bb>>>3)|0;ga=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(bb&7);if(Aa){Fa=Ca;Da=bb;Ba=ga}else{cb=Ca;break}}if((A|0)==128){cb=d[1201688+$a|0]|Fa<<(ab-1>>1)}c[l>>2]=bb;db=cb-1|0}else{Ba=ta>>>24;Da=(d[1201432+Ba|0]|0)+Ga|0;c[l>>2]=Ka>>>0>Da>>>0?Da:Ka;db=d[1200920+Ba|0]|0}c[e+228>>2]=db;Qa=Ma}}while(0);db=a[Qa]|0;if(!(db<<24>>24==0)){Qa=1362224+((db&255)-1<<3)|0;db=e+224|0;cb=c[Qa+4>>2]|0;c[db>>2]=c[Qa>>2];c[db+4>>2]=cb}cb=c[l>>2]|0;db=c[p>>2]|0;Qa=d[db+(cb>>>3)|0]|0;bb=c[n>>2]|0;ab=((cb|0)<(bb|0))+cb|0;c[l>>2]=ab;if((Qa&128>>>((cb&7)>>>0)|0)==0){eb=ab}else{cb=db+(ab>>>3)|0;Qa=(fe(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(ab&7);if((Qa&-1434451968|0)==0){cb=1;$a=ab;_a=Qa;while(1){fb=_a>>>24;Za=a[1201432+fb|0]|0;gb=Za&255;Ya=((Za&255)>>>0>8>>>0?8:gb)+$a|0;Xa=bb>>>0>Ya>>>0;hb=Xa?Ya:bb;if(!(Za<<24>>24==9)){A=139;break}Za=d[1201688+fb|0]|cb<<4;if(!(Za>>>0<134217728>>>0)){ib=Za;break}Ya=db+(hb>>>3)|0;Wa=(fe(d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0)|0)<<(hb&7);if(Xa){cb=Za;$a=hb;_a=Wa}else{ib=Za;break}}if((A|0)==139){ib=d[1201688+fb|0]|cb<<(gb-1>>1)}c[l>>2]=hb;jb=ib+65535&65535;kb=hb}else{hb=Qa>>>24;Qa=(d[1201432+hb|0]|0)+ab|0;ab=bb>>>0>Qa>>>0?Qa:bb;c[l>>2]=ab;jb=d[1200920+hb|0]|0;kb=ab}b[g+14>>1]=jb;jb=db+(kb>>>3)|0;ab=(fe(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(kb&7);if((ab&-1434451968|0)==0){jb=1;hb=kb;Qa=ab;while(1){lb=Qa>>>24;ib=a[1201432+lb|0]|0;mb=ib&255;gb=((ib&255)>>>0>8>>>0?8:mb)+hb|0;cb=bb>>>0>gb>>>0;nb=cb?gb:bb;if(!(ib<<24>>24==9)){A=146;break}ib=d[1201688+lb|0]|jb<<4;if(!(ib>>>0<134217728>>>0)){ob=ib;break}gb=db+(nb>>>3)|0;fb=(fe(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(nb&7);if(cb){jb=ib;hb=nb;Qa=fb}else{ob=ib;break}}if((A|0)==146){ob=d[1201688+lb|0]|jb<<(mb-1>>1)}c[l>>2]=nb;pb=ob+65535&65535;qb=nb}else{nb=ab>>>24;ab=(d[1201432+nb|0]|0)+kb|0;kb=bb>>>0>ab>>>0?ab:bb;c[l>>2]=kb;pb=d[1200920+nb|0]|0;qb=kb}b[g+16>>1]=pb;pb=db+(qb>>>3)|0;kb=(fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(qb&7);if((kb&-1434451968|0)==0){pb=1;nb=qb;ab=kb;while(1){rb=ab>>>24;ob=a[1201432+rb|0]|0;sb=ob&255;mb=((ob&255)>>>0>8>>>0?8:sb)+nb|0;jb=bb>>>0>mb>>>0;tb=jb?mb:bb;if(!(ob<<24>>24==9)){A=153;break}ob=d[1201688+rb|0]|pb<<4;if(!(ob>>>0<134217728>>>0)){ub=ob;break}mb=db+(tb>>>3)|0;lb=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(tb&7);if(jb){pb=ob;nb=tb;ab=lb}else{ub=ob;break}}if((A|0)==153){ub=d[1201688+rb|0]|pb<<(sb-1>>1)}c[l>>2]=tb;vb=ub+65535&65535;wb=tb}else{tb=kb>>>24;kb=(d[1201432+tb|0]|0)+qb|0;qb=bb>>>0>kb>>>0?kb:bb;c[l>>2]=qb;vb=d[1200920+tb|0]|0;wb=qb}b[g+18>>1]=vb;vb=db+(wb>>>3)|0;qb=(fe(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(wb&7);if((qb&-1434451968|0)==0){vb=1;tb=wb;kb=qb;while(1){xb=kb>>>24;ub=a[1201432+xb|0]|0;yb=ub&255;sb=((ub&255)>>>0>8>>>0?8:yb)+tb|0;pb=bb>>>0>sb>>>0;zb=pb?sb:bb;if(!(ub<<24>>24==9)){A=160;break}ub=d[1201688+xb|0]|vb<<4;if(!(ub>>>0<134217728>>>0)){Ab=ub;break}sb=db+(zb>>>3)|0;rb=(fe(d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)|0)<<(zb&7);if(pb){vb=ub;tb=zb;kb=rb}else{Ab=ub;break}}if((A|0)==160){Ab=d[1201688+xb|0]|vb<<(yb-1>>1)}c[l>>2]=zb;Bb=Ab+65535&65535;Cb=zb}else{zb=qb>>>24;qb=(d[1201432+zb|0]|0)+wb|0;wb=bb>>>0>qb>>>0?qb:bb;c[l>>2]=wb;Bb=d[1200920+zb|0]|0;Cb=wb}b[g+20>>1]=Bb;eb=Cb}Cb=d[db+(eb>>>3)|0]|0;Bb=((eb|0)<(bb|0))+eb|0;c[l>>2]=Bb;do{if((Cb&128>>>((eb&7)>>>0)|0)==0){Db=16;Eb=8;Fb=g+22|0}else{wb=db+(Bb>>>3)|0;zb=(fe(d[wb]|d[wb+1|0]<<8|d[wb+2|0]<<16|d[wb+3|0]<<24|0)|0)<<(Bb&7);if((zb&-1434451968|0)==0){wb=1;qb=Bb;Ab=zb;while(1){Gb=Ab>>>24;yb=a[1201432+Gb|0]|0;Hb=yb&255;vb=((yb&255)>>>0>8>>>0?8:Hb)+qb|0;xb=bb>>>0>vb>>>0;Ib=xb?vb:bb;if(!(yb<<24>>24==9)){A=170;break}yb=d[1201688+Gb|0]|wb<<4;if(!(yb>>>0<134217728>>>0)){Jb=yb;break}vb=db+(Ib>>>3)|0;kb=(fe(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(Ib&7);if(xb){wb=yb;qb=Ib;Ab=kb}else{Jb=yb;break}}if((A|0)==170){Jb=d[1201688+Gb|0]|wb<<(Hb-1>>1)}c[l>>2]=Ib;Kb=Jb-1|0}else{Ab=zb>>>24;qb=(d[1201432+Ab|0]|0)+Bb|0;c[l>>2]=bb>>>0>qb>>>0?qb:bb;Kb=d[1200920+Ab|0]|0}Ab=Kb&255;qb=g+22|0;a[qb]=Ab;if((Kb&255)>>>0>4>>>0){W=-1094995529;i=h;return W|0}if(!(Ab<<24>>24==0)){Db=16;Eb=8;Fb=qb;break}Ab=c[l>>2]|0;Ma=c[n>>2]|0;Ka=c[p>>2]|0;Ga=Ka+(Ab>>>3)|0;ta=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ab&7);if((ta&-1434451968|0)==0){Ga=1;Fa=Ab;yb=ta;while(1){Lb=yb>>>24;kb=a[1201432+Lb|0]|0;Mb=kb&255;xb=((kb&255)>>>0>8>>>0?8:Mb)+Fa|0;vb=Ma>>>0>xb>>>0;Nb=vb?xb:Ma;if(!(kb<<24>>24==9)){A=179;break}kb=d[1201688+Lb|0]|Ga<<4;if(!(kb>>>0<134217728>>>0)){Ob=kb;break}xb=Ka+(Nb>>>3)|0;tb=(fe(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0)<<(Nb&7);if(vb){Ga=kb;Fa=Nb;yb=tb}else{Ob=kb;break}}if((A|0)==179){Ob=d[1201688+Lb|0]|Ga<<(Mb-1>>1)}c[l>>2]=Nb;Pb=Ob-1|0;Qb=Nb}else{yb=ta>>>24;Fa=(d[1201432+yb|0]|0)+Ab|0;zb=Ma>>>0>Fa>>>0?Fa:Ma;c[l>>2]=zb;Pb=d[1200920+yb|0]|0;Qb=zb}zb=Ka+(Qb>>>3)|0;yb=(fe(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)|0)<<(Qb&7);if((yb&-1434451968|0)==0){zb=1;Fa=Qb;wb=yb;while(1){Rb=wb>>>24;kb=a[1201432+Rb|0]|0;Sb=kb&255;tb=((kb&255)>>>0>8>>>0?8:Sb)+Fa|0;vb=Ma>>>0>tb>>>0;Tb=vb?tb:Ma;if(!(kb<<24>>24==9)){A=186;break}kb=d[1201688+Rb|0]|zb<<4;if(!(kb>>>0<134217728>>>0)){Ub=kb;break}tb=Ka+(Tb>>>3)|0;xb=(fe(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(Tb&7);if(vb){zb=kb;Fa=Tb;wb=xb}else{Ub=kb;break}}if((A|0)==186){Ub=d[1201688+Rb|0]|zb<<(Sb-1>>1)}c[l>>2]=Tb;Vb=Ub-1|0;Wb=Tb}else{wb=yb>>>24;Fa=(d[1201432+wb|0]|0)+Qb|0;Ab=Ma>>>0>Fa>>>0?Fa:Ma;c[l>>2]=Ab;Vb=d[1200920+wb|0]|0;Wb=Ab}Ab=Vb>>>0>65535>>>0;wb=Ab?Vb>>>16:Vb;Fa=Ab?16:0;if((wb&65280|0)==0){Xb=Fa;Yb=wb}else{Xb=Fa|8;Yb=wb>>>8}wb=Xb+1+(d[1191992+Yb|0]|0)|0;Fa=Ka+(Wb>>>3)|0;Ab=(fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Wb&7);b:do{if((Ab&-1434451968|0)==0){Fa=1;ta=Wb;Ga=Ab;while(1){kb=Ga>>>24;xb=a[1201432+kb|0]|0;vb=((xb&255)>>>0>8>>>0?8:xb&255)+ta|0;tb=Ma>>>0>vb>>>0;ub=tb?vb:Ma;if(!(xb<<24>>24==9)){Zb=ub;break b}xb=d[1201688+kb|0]|Fa<<4;if(!(xb>>>0<134217728>>>0)){Zb=ub;break b}kb=Ka+(ub>>>3)|0;vb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(ub&7);if(tb){Fa=xb;ta=ub;Ga=vb}else{Zb=ub;break}}}else{Ga=(d[1201432+(Ab>>>24)|0]|0)+Wb|0;Zb=Ma>>>0>Ga>>>0?Ga:Ma}}while(0);c[l>>2]=Zb;Ab=Ka+(Zb>>>3)|0;yb=(fe(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)|0)<<(Zb&7);c:do{if((yb&-1434451968|0)==0){Ab=1;zb=Zb;Ga=yb;while(1){ta=Ga>>>24;Fa=a[1201432+ta|0]|0;ub=((Fa&255)>>>0>8>>>0?8:Fa&255)+zb|0;vb=Ma>>>0>ub>>>0;xb=vb?ub:Ma;if(!(Fa<<24>>24==9)){_b=xb;break c}Fa=d[1201688+ta|0]|Ab<<4;if(!(Fa>>>0<134217728>>>0)){_b=xb;break c}ta=Ka+(xb>>>3)|0;ub=(fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(xb&7);if(vb){Ab=Fa;zb=xb;Ga=ub}else{_b=xb;break}}}else{Ga=(d[1201432+(yb>>>24)|0]|0)+Zb|0;_b=Ma>>>0>Ga>>>0?Ga:Ma}}while(0);c[l>>2]=_b;c[e+396>>2]=(Pb|0)!=0?1:2;Db=Pb;Eb=wb;Fb=qb}}while(0);Pb=a[Fb]|0;if(Pb<<24>>24==0){$b=Eb}else{Eb=(Pb&255)-1|0;Pb=d[588336+(Eb<<3)|0]|0;c[e+396>>2]=c[588340+(Eb<<3)>>2];$b=Pb}if($b>>>0>8>>>0){yDb(e,24,2054472,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}$b=c[1362272+(((Db|0)==0|0)*12|0)+(d[ma]<<2)>>2]|0;c[e+140>>2]=$b;_Ga($b,j,k);$b=g|0;do{if(((1<<c[j>>2])-1&c[$b>>2]|0)==0){ma=g+4|0;if(((1<<c[k>>2])-1&c[ma>>2]|0)!=0){break}Db=c[l>>2]|0;Pb=c[p>>2]|0;Eb=d[Pb+(Db>>>3)|0]|0;Fb=c[n>>2]|0;_b=((Db|0)<(Fb|0))+Db|0;c[l>>2]=_b;do{if((Eb&128>>>((Db&7)>>>0)|0)==0){Zb=d[g+23|0]|0;c[e+384>>2]=c[1362360+(Zb*12|0)>>2];c[e+392>>2]=c[1362364+(Zb*12|0)>>2];c[e+388>>2]=c[1362368+(Zb*12|0)>>2]}else{Zb=Pb+(_b>>>3)|0;Wb=(fe(d[Zb]|d[Zb+1|0]<<8|d[Zb+2|0]<<16|d[Zb+3|0]<<24|0)|0)<<(_b&7);if((Wb&-1434451968|0)==0){Zb=1;Yb=_b;Xb=Wb;while(1){ac=Xb>>>24;Vb=a[1201432+ac|0]|0;bc=Vb&255;Qb=((Vb&255)>>>0>8>>>0?8:bc)+Yb|0;Tb=Fb>>>0>Qb>>>0;cc=Tb?Qb:Fb;if(!(Vb<<24>>24==9)){A=214;break}Vb=d[1201688+ac|0]|Zb<<4;if(!(Vb>>>0<134217728>>>0)){dc=Vb;break}Qb=Pb+(cc>>>3)|0;Ub=(fe(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(cc&7);if(Tb){Zb=Vb;Yb=cc;Xb=Ub}else{dc=Vb;break}}if((A|0)==214){dc=d[1201688+ac|0]|Zb<<(bc-1>>1)}c[l>>2]=cc;ec=dc-1|0}else{Xb=Wb>>>24;Yb=(d[1201432+Xb|0]|0)+_b|0;c[l>>2]=Fb>>>0>Yb>>>0?Yb:Fb;ec=d[1200920+Xb|0]|0}Xb=g+23|0;a[Xb]=ec;Yb=ec&255;if(Yb>>>0>4>>>0){W=-1094995529;i=h;return W|0}Vb=e+384|0;c[Vb>>2]=c[1362360+(Yb*12|0)>>2];Ub=e+392|0;c[Ub>>2]=c[1362364+(Yb*12|0)>>2];Tb=e+388|0;c[Tb>>2]=c[1362368+(Yb*12|0)>>2];if((a[Xb]|0)!=0){break}Xb=c[l>>2]|0;Yb=c[p>>2]|0;Qb=d[Yb+(Xb>>>3)|0]|0;Sb=c[n>>2]|0;Rb=((Xb|0)<(Sb|0))+Xb|0;c[l>>2]=Rb;do{if((Qb&128>>>((Xb&7)>>>0)|0)==0){fc=Rb}else{Nb=Yb+(Rb>>>3)|0;Ob=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Rb&7);if((Ob&-1434451968|0)==0){Nb=1;Mb=Rb;Lb=Ob;while(1){gc=Lb>>>24;Kb=a[1201432+gc|0]|0;hc=Kb&255;bb=((Kb&255)>>>0>8>>>0?8:hc)+Mb|0;Bb=Sb>>>0>bb>>>0;ic=Bb?bb:Sb;if(!(Kb<<24>>24==9)){A=224;break}Kb=d[1201688+gc|0]|Nb<<4;if(!(Kb>>>0<134217728>>>0)){jc=Kb;break}bb=Yb+(ic>>>3)|0;Jb=(fe(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(ic&7);if(Bb){Nb=Kb;Mb=ic;Lb=Jb}else{jc=Kb;break}}if((A|0)==224){jc=d[1201688+gc|0]|Nb<<(hc-1>>1)}c[l>>2]=ic;kc=jc-1|0;lc=ic}else{Lb=Ob>>>24;Mb=(d[1201432+Lb|0]|0)+Rb|0;Kb=Sb>>>0>Mb>>>0?Mb:Sb;c[l>>2]=Kb;kc=d[1200920+Lb|0]|0;lc=Kb}if(!(kc>>>0<3>>>0)){fc=lc;break}c[Vb>>2]=c[1362208+(kc<<2)>>2];fc=lc}}while(0);Vb=d[Yb+(fc>>>3)|0]|0;Rb=((fc|0)<(Sb|0))+fc|0;c[l>>2]=Rb;do{if((Vb&128>>>((fc&7)>>>0)|0)==0){mc=Rb}else{Xb=Yb+(Rb>>>3)|0;Qb=(fe(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Rb&7);if((Qb&-1434451968|0)==0){Xb=1;Wb=Rb;Zb=Qb;while(1){nc=Zb>>>24;Kb=a[1201432+nc|0]|0;oc=Kb&255;Lb=((Kb&255)>>>0>8>>>0?8:oc)+Wb|0;Mb=Sb>>>0>Lb>>>0;pc=Mb?Lb:Sb;if(!(Kb<<24>>24==9)){A=234;break}Kb=d[1201688+nc|0]|Xb<<4;if(!(Kb>>>0<134217728>>>0)){qc=Kb;break}Lb=Yb+(pc>>>3)|0;Jb=(fe(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(pc&7);if(Mb){Xb=Kb;Wb=pc;Zb=Jb}else{qc=Kb;break}}if((A|0)==234){qc=d[1201688+nc|0]|Xb<<(oc-1>>1)}c[l>>2]=pc;rc=qc-1|0;sc=pc}else{Zb=Qb>>>24;Wb=(d[1201432+Zb|0]|0)+Rb|0;Ob=Sb>>>0>Wb>>>0?Wb:Sb;c[l>>2]=Ob;rc=d[1200920+Zb|0]|0;sc=Ob}if((rc|0)==0){c[Ub>>2]=1;mc=sc;break}else if((rc|0)==1){c[Ub>>2]=5;mc=sc;break}else{mc=sc;break}}}while(0);Ub=d[Yb+(mc>>>3)|0]|0;Rb=((mc|0)<(Sb|0))+mc|0;c[l>>2]=Rb;if((Ub&128>>>((mc&7)>>>0)|0)==0){break}Ub=Yb+(Rb>>>3)|0;Vb=(fe(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Rb&7);if((Vb&-1434451968|0)==0){Ub=1;Ob=Rb;Zb=Vb;while(1){tc=Zb>>>24;Wb=a[1201432+tc|0]|0;uc=Wb&255;Nb=((Wb&255)>>>0>8>>>0?8:uc)+Ob|0;Kb=Sb>>>0>Nb>>>0;vc=Kb?Nb:Sb;if(!(Wb<<24>>24==9)){A=245;break}Wb=d[1201688+tc|0]|Ub<<4;if(!(Wb>>>0<134217728>>>0)){wc=Wb;break}Nb=Yb+(vc>>>3)|0;Jb=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(vc&7);if(Kb){Ub=Wb;Ob=vc;Zb=Jb}else{wc=Wb;break}}if((A|0)==245){wc=d[1201688+tc|0]|Ub<<(uc-1>>1)}c[l>>2]=vc;xc=wc-1|0}else{Zb=Vb>>>24;Ob=(d[1201432+Zb|0]|0)+Rb|0;c[l>>2]=Sb>>>0>Ob>>>0?Ob:Sb;xc=d[1200920+Zb|0]|0}if((xc|0)!=0){break}c[Tb>>2]=1}}while(0);Fb=V$a(e,c[$b>>2]|0,c[ma>>2]|0)|0;if((Fb|0)<0){W=Fb;i=h;return W|0}Fb=c[l>>2]|0;_b=c[n>>2]|0;Pb=c[p>>2]|0;Db=Pb+(Fb>>>3)|0;Eb=(fe(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)|0)<<(Fb&7);if((Eb&-1434451968|0)==0){Db=1;qb=Fb;wb=Eb;while(1){yc=wb>>>24;Zb=a[1201432+yc|0]|0;zc=Zb&255;Ob=((Zb&255)>>>0>8>>>0?8:zc)+qb|0;Yb=_b>>>0>Ob>>>0;Ac=Yb?Ob:_b;if(!(Zb<<24>>24==9)){A=256;break}Zb=d[1201688+yc|0]|Db<<4;if(!(Zb>>>0<134217728>>>0)){Bc=Zb;break}Ob=Pb+(Ac>>>3)|0;Wb=(fe(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Ac&7);if(Yb){Db=Zb;qb=Ac;wb=Wb}else{Bc=Zb;break}}if((A|0)==256){Bc=d[1201688+yc|0]|Db<<(zc-1>>1)}c[l>>2]=Ac;Cc=Bc-1|0}else{wb=Eb>>>24;qb=(d[1201432+wb|0]|0)+Fb|0;c[l>>2]=_b>>>0>qb>>>0?qb:_b;Cc=d[1200920+wb|0]|0}if((Cc|0)==0){W=0;i=h;return W|0}yDb(e,16,2190496,(V=i,i=i+8|0,c[V>>2]=Cc,V)|0);i=V;W=-1094995529;i=h;return W|0}}while(0);yDb(e,16,2008640,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V;W=-1094995529;i=h;return W|0}function m1(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;j=b|0;k=c[j>>2]|0;c[f>>2]=0;c[g>>2]=0;a:do{if((c[b+176>>2]&1|0)==0){l=k;m=c[l>>2]|0;n=k+4|0;o=c[n>>2]|0;b:do{if((o|0)==0){p=0;q=m;while(1){if((p|0)>=(i|0)){r=q;s=0;t=14;break b}u=d[h+p|0]|q<<8;if((u|0)==1111638852){break}else{p=p+1|0;q=u}}c[n>>2]=1;c[k+12>>2]=9;q=k+8|0;c[q>>2]=p;v=-1;w=p;x=1;y=q;t=8}else{v=m;w=0;x=o;y=k+8|0;t=8}}while(0);c:do{if((t|0)==8){c[y>>2]=0;if((w|0)<(i|0)){z=v;A=w}else{r=v;s=x;t=14;break}while(1){if((z|0)==1111638852){break}o=d[h+A|0]|z<<8;m=A+1|0;if((m|0)<(i|0)){z=o;A=m}else{r=o;s=x;t=14;break c}}p=i-A|0;o=k+12|0;m=c[o>>2]|0;if((p|0)<(m|0)){c[o>>2]=9-p;r=1111638852;s=x;t=14;break}else{c[l>>2]=-1;B=m+A|0;C=x;break}}}while(0);if((t|0)==14){c[l>>2]=r;B=-1;C=s}m=(B|0)==-1;if((C|0)==0&m){D=i;return D|0}p=b+40|0;if((c[p>>2]|0)==0&(c[p+4>>2]|0)==(-2147483648|0)){o=b+48|0;E=(c[o>>2]|0)==0&(c[o+4>>2]|0)==(-2147483648|0)}else{E=0}o=c[j>>2]|0;n=o+16|0;q=c[n>>2]|0;do{if((q|0)==0){G=c[o+24>>2]|0;H=o+28|0}else{u=o+28|0;I=c[u>>2]|0;J=o+24|0;UGb(I|0,I+q|0,(c[J>>2]|0)-q|0)|0;I=(c[J>>2]|0)-(c[n>>2]|0)|0;c[J>>2]=I;c[n>>2]=0;if((i|0)!=0){G=I;H=u;break}J=c[u>>2]|0;if((a[J+4|0]|0)==16){K=B;L=I;M=J;break a}else{G=I;H=u}}}while(0);q=c[H>>2]|0;l=o+20|0;u=o+24|0;if(m){I=o+8|0;J=jEb(q,l,G+i-(c[I>>2]|0)|0)|0;c[H>>2]=J;N=c[I>>2]|0;UGb(J+(c[u>>2]|0)|0,h+N|0,i-N|0)|0;c[u>>2]=i-(c[I>>2]|0)+(c[u>>2]|0);D=i;return D|0}I=jEb(q,l,G+B|0)|0;c[H>>2]=I;UGb(I+(c[u>>2]|0)|0,h|0,B)|0;I=(c[u>>2]|0)+B|0;c[u>>2]=I;l=c[H>>2]|0;do{if((I-13|0)>=0){q=l+(I-4)|0;N=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=-13-N+I|0;if((q|0)<0){break}J=q+13|0;if((J|0)>(I|0)){break}O=l+(q+4)|0;P=a[O]|0;Q=l+(q+5)|0;R=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=fe(R|0)|0;if(((P<<24>>24==16&(R|0)==0?13:Q)|0)!=(N|0)){break}Q=(I|0)<0|0?-1:0;R=o+32|0;S=c[R>>2]|0;T=YGb(N,(N|0)<0|0?-1:0,13,0)|0;U=YGb(T,F,S,(S|0)<0|0?-1:0)|0;T=F;if((Q|0)<(T|0)|(Q|0)==(T|0)&I>>>0<U>>>0){break}U=l+(q-S)|0;c[o+36>>2]=U;c[R>>2]=S+N;if((P&8)==0){c[o+12>>2]=9;D=B;return D|0}do{if(E){P=l+J|0;N=fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=b+56|0;S=b+64|0;q=c[S>>2]|0;T=c[S+4>>2]|0;if((q|c[P>>2]|0)==0&(T|c[P+4>>2]|0)==0){P=N-1|0;S=P;Q=(P|0)<0|0?-1:0;P=b+48|0;c[P>>2]=S;c[P+4>>2]=Q;V=Q;W=S}else{S=YGb(q,T,1,0)|0;T=F;q=b+48|0;c[q>>2]=S;c[q+4>>2]=T;V=T;W=S}S=N;T=(N|0)<0|0?-1:0;c[p>>2]=S;c[p+4>>2]=T;N=e+176|0;if((c[N>>2]|0)!=0){X=T;Y=S;Z=V;_=W;t=41;break}if((a[O]&3)==0){break}c[N>>2]=1;X=T;Y=S;Z=V;_=W;t=41}else{if((c[e+176>>2]|0)==0){break}S=b+48|0;X=c[p+4>>2]|0;Y=c[p>>2]|0;Z=c[S+4>>2]|0;_=c[S>>2]|0;t=41}}while(0);do{if((t|0)==41){if(!((Y|0)==(_|0)&(X|0)==(Z|0))){break}c[b+32>>2]=3}}while(0);O=c[R>>2]|0;c[R>>2]=0;c[n>>2]=(c[u>>2]|0)-13;c[o+12>>2]=9;if((B|0)<0){D=O}else{K=B;L=O;M=U;break a}return D|0}}while(0);c[u>>2]=I-9;c[o+12>>2]=9;D=B-9|0;return D|0}else{c[f>>2]=h;c[g>>2]=i;K=i;L=i;M=h}}while(0);c[f>>2]=M;c[g>>2]=L;D=K;return D|0}function n1(a){a=a|0;var b=0;b=c[a>>2]|0;if((c[b+20>>2]|0)<=0){return}ZDb(c[b+28>>2]|0);return}function o1(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+1444>>2]=-1;Z3(b+4|0,a);B1(b+1248|0);a=b+7444|0;b=0;while(1){if((b|0)>=14){d=0;e=6;break}f=ICb()|0;c[a+(b*112|0)>>2]=f;if((f|0)==0){break}else{b=b+1|0}}if((e|0)==6){return d|0}if((b|0)>0){g=b}else{d=-12;return d|0}while(1){b=g-1|0;JCb(a+(b*112|0)|0);if((b|0)>0){g=b}else{d=-12;break}}return d|0}function p1(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0;k=i;i=i+440|0;l=k|0;m=k+8|0;n=k+16|0;o=k+80|0;p=k+424|0;q=f+60|0;r=c[q>>2]|0;s=r;t=c[j+24>>2]|0;u=c[j+28>>2]|0;j=r+7444|0;v=0;do{w=c[j+(v*112|0)>>2]|0;do{if((c[w>>2]|0)!=0){if((c[w+172>>2]|0)!=0){break}KCb(w);TGb(j+(v*112|0)+4|0,0,12)|0}}while(0);v=v+1|0;}while((v|0)<14);v=g;j=r+7372|0;c[j>>2]=0;c[h>>2]=0;if((u|0)==0){w=c[r+7420>>2]|0;x=c[r+7424>>2]|0;if((x|0)==0){y=w;z=0;A=w}else{B=w;w=1;C=0;D=x;do{x=(c[(c[D>>2]|0)+164>>2]|0)<(c[(c[B>>2]|0)+164>>2]|0);B=x?D:B;C=x?w:C;w=w+1|0;D=c[s+7420+(w<<2)>>2]|0;}while((D|0)!=0);y=B;z=C;A=c[s+7420+(C<<2)>>2]|0}if((A|0)!=0){A=z;C=s+7420+(z<<2)|0;while(1){z=A+1|0;B=s+7420+(z<<2)|0;c[C>>2]=c[B>>2];if((c[B>>2]|0)==0){break}else{A=z;C=B}}}do{if((y|0)!=0){C=c[y>>2]|0;A=C+172|0;c[A>>2]=c[A>>2]^4;c[h>>2]=1;A=MCb(v,C)|0;if((A|0)<0){E=A}else{break}i=k;return E|0}}while(0);E=0;i=k;return E|0}a:do{if((u|0)>13){y=f+140|0;A=f+120|0;C=f+124|0;s=n;B=p|0;z=p+4|0;D=p+8|0;w=r;x=0;b:while(1){F=x+1|0;do{if((a[t+x|0]|0)==66){if((a[t+F|0]|0)!=66){G=F;break}if((a[t+(x+2)|0]|0)!=67){G=F;break}if((a[t+(x+3)|0]|0)!=68){G=F;break}H=t+(x+5)|0;I=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=fe(I|0)|0;J=H+x|0;if(!((J|0)<=(u|0)&(I|0)!=0)){if((J|0)>(u|0)){yDb(c[w>>2]|0,16,2190408,(K=i,i=i+8|0,c[K>>2]=H,K)|0);i=K}G=x+4|0;break}I=c[q>>2]|0;L=I;M=a[t+(x+4)|0]|0;N=M&255;if((H|0)<13){break b}O=I+1396|0;P=O;Q=t+(x+13)|0;R=(H<<3)-104|0;H=R>>>0>2147483639>>>0|(Q|0)==0;S=H?0:Q;T=H?0:R;R=O;c[R>>2]=S;O=I+1408|0;c[O>>2]=T;H=I+1412|0;c[H>>2]=T+8;c[I+1400>>2]=S+(T>>3);T=I+1404|0;c[T>>2]=0;if((M<<24>>24|0)==32){if((a[Q]|0)!=1){G=J;break}Q=xd(t+(x+14)|0,2008616,(K=i,i=i+24|0,c[K>>2]=B,c[K+8>>2]=z,c[K+16>>2]=D,K)|0)|0;i=K;if(!((Q|0)==3&(c[B>>2]|0)==1&(c[z>>2]|0)==0)){G=J;break}if((c[D>>2]|0)>=8){G=J;break}c[I+4016>>2]=1;G=J;break}else if((M<<24>>24|0)==0){Q=I+1440|0;if((c[Q>>2]|0)!=0){G=J;break}S=I+1416|0;if((l1(f,P,S)|0)!=0){break b}P=I+3980|0;U=I+3984|0;_Ga(c[y>>2]|0,P,U);V=S;S=((c[V>>2]|0)+3|0)>>>2;W=I+1420|0;X=((c[W>>2]|0)+3|0)>>>2;Y=0;while(1){if((Y|0)>=3){break}if((Y|0)==0){Z=0;_=32;$=32;aa=c[V>>2]|0}else{ca=c[P>>2]|0;da=c[U>>2]|0;Z=da;_=32>>>(da>>>0);$=32>>>(ca>>>0);aa=(c[V>>2]|0)>>>(ca>>>0)}ca=(_|0)/2|0;da=(_|0)<64?32:ca;ea=(aa+31&-32|8)-1&-8;fa=L+1448+(Y*844|0)+28|0;c[fa>>2]=cEb(ba(ea+$<<1,da+ca+(((c[W>>2]|0)>>>(Z>>>0))+31&-32)|0)|0)|0;ca=WDb((ea<<1)+32|0)|0;c[L+1448+(Y*844|0)+32>>2]=ca;ga=c[fa>>2]|0;c[L+1448+(Y*844|0)+24>>2]=ga+((ba(da,ea)|0)<<1);if((ga|0)==0){break b}if((ca|0)==0){break b}else{Y=Y+1|0}}Y=c[V>>2]|0;U=c[W>>2]|0;P=ba(X,S)|0;ca=I+4216|0;c[ca>>2]=WDb(P)|0;ga=I+4220|0;c[ga>>2]=WDb(P*160|0)|0;P=(Y<<5)+2048|0;c[I+4240>>2]=WDb(P)|0;ea=I+4244|0;c[ea>>2]=WDb(ba((Y<<1)+192|0,U+32|0)|0)|0;U=WDb(P)|0;c[I+4248>>2]=U;if((c[ca>>2]|0)==0){break b}if((c[ga>>2]|0)==0){break b}if(!((U|0)!=0&(c[ea>>2]|0)!=0)){break b}c[Q>>2]=1;G=J;break}else if((M<<24>>24|0)==16){s1(L);c[I+1440>>2]=0;G=J;break}else{if((N&8|0)==0){G=J;break}if((c[I+1440>>2]|0)==0){ha=50;break b}ea=I+7444|0;U=I+7556|0;ga=I+7668|0;ca=I+7780|0;P=I+7892|0;Y=I+8004|0;da=I+8116|0;fa=I+8228|0;ia=I+8340|0;ja=I+8452|0;ka=I+8564|0;la=I+8676|0;ma=I+8788|0;na=I+8900|0;oa=(c[c[na>>2]>>2]|0)==0?na:(c[c[ma>>2]>>2]|0)==0?ma:(c[c[la>>2]>>2]|0)==0?la:(c[c[ka>>2]>>2]|0)==0?ka:(c[c[ja>>2]>>2]|0)==0?ja:(c[c[ia>>2]>>2]|0)==0?ia:(c[c[fa>>2]>>2]|0)==0?fa:(c[c[da>>2]>>2]|0)==0?da:(c[c[Y>>2]>>2]|0)==0?Y:(c[c[P>>2]>>2]|0)==0?P:(c[c[ca>>2]>>2]|0)==0?ca:(c[c[ga>>2]>>2]|0)==0?ga:(c[c[U>>2]>>2]|0)==0?U:(c[c[ea>>2]>>2]|0)==0?ea:0;if((oa|0)==0){ha=51;break b}ea=oa|0;KCb(c[ea>>2]|0);U=N&3;if((U|0)==3){ha=53;break b}ga=I+4004|0;c[ga>>2]=U;U=I+3992|0;c[U>>2]=(N&72|0)==8;ca=I+3996|0;c[ca>>2]=(N&136|0)==136;P=(N&12|0)==12|0;Y=c[ea>>2]|0;c[Y+172>>2]=P;c[Y+84>>2]=(c[ga>>2]|0)==0;c[Y+88>>2]=(c[ga>>2]|0)+1;_Ga(c[y>>2]|0,l,m);da=Y+68|0;c[da>>2]=(c[A>>2]|0)+32;fa=Y+72|0;c[fa>>2]=(c[C>>2]|0)+34;if((_$a(f,Y,P)|0)<0){break b}P=Y|0;ia=c[P>>2]|0;if((ia|0)!=0){ja=16>>>((c[m>>2]|0)>>>0);ka=0;la=P;P=ia;do{c[la>>2]=P+((ba((ka|0)!=0&(ka|0)<3?ja:16,c[Y+32+(ka<<2)>>2]|0)|0)+32);ka=ka+1|0;la=Y+(ka<<2)|0;P=c[la>>2]|0;}while((P|0)!=0)}c[da>>2]=c[A>>2];c[fa>>2]=c[C>>2];P=I+7372|0;c[P>>2]=oa;la=c[ea>>2]|0;c[I+1456>>2]=c[la+32>>2];c[I+2300>>2]=c[la+36>>2];c[I+3144>>2]=c[la+40>>2];if((t1(L)|0)!=0){break b}do{if((c[ca>>2]|0)==0){pa=I+3988|0}else{TGb(c[I+1472>>2]|0,0,ba(c[I+1468>>2]<<1,c[I+1464>>2]|0)|0)|0;TGb(c[I+2316>>2]|0,0,ba(c[I+2312>>2]<<1,c[I+2308>>2]|0)|0)|0;TGb(c[I+3160>>2]|0,0,ba(c[I+3156>>2]<<1,c[I+3152>>2]|0)|0)|0;la=I+3988|0;if((c[la>>2]|0)!=0){pa=la;break}ka=c[I>>2]|0;Y=I+4072|0;ja=I+4076|0;N=cEb(ba(c[Y>>2]<<5,c[ja>>2]|0)|0)|0;M=N;Q=c[T>>2]|0;S=-Q&7;if((S|0)==0){qa=Q}else{X=c[H>>2]|0;W=S+Q|0;Q=X>>>0>W>>>0?W:X;c[T>>2]=Q;qa=Q}Q=(c[O>>2]|0)-qa|0;c:do{if((Q|0)>0){X=c[ja>>2]|0;W=I+4080|0;S=I+4084|0;V=0;ia=Q;ma=(c[R>>2]|0)+((qa|0)/8|0)|0;na=0;while(1){if(!(V>>>0<X>>>0&(ia|0)>0)){ra=na;break c}sa=c[Y>>2]|0;ta=ia;ua=ma;va=0;wa=na;while(1){if(!(va>>>0<sa>>>0)){break}xa=wa+1|0;ya=c[W>>2]|0;za=ba(ya,xa)|0;Aa=c[S>>2]|0;Ba=((za|0)/(Aa|0)|0)-((ba(ya,wa)|0)/(Aa|0)|0)|0;c[M+(wa<<5)+28>>2]=Ba;c[M+(wa<<5)+20>>2]=va;c[M+(wa<<5)+24>>2]=V;Aa=ta>>>0>2147483639>>>0|(ua|0)==0;ya=Aa?0:ua;za=Aa?0:ta;c[M+(wa<<5)>>2]=ya;c[M+(wa<<5)+12>>2]=za;c[M+(wa<<5)+16>>2]=za+8;c[M+(wa<<5)+4>>2]=ya+(za+7>>3);c[M+(wa<<5)+8>>2]=0;za=ta-(Ba<<3)|0;if((za|0)>0){ta=za;ua=ua+Ba|0;va=va+1|0;wa=xa}else{ra=xa;break c}}if((ta|0)>0){V=V+1|0;ia=ta;ma=ua;na=wa}else{ra=wa;break}}}else{ra=0}}while(0);oe[c[ka+824>>2]&63](ka,548,N,0,ra,32)|0;M=c[I+1516>>2]|0;Y=c[I+1504>>2]|0;Q=(Y|0)>1;if(Q){ja=1;na=b[M>>1]|0;do{ma=M+(ja<<1)|0;na=(b[ma>>1]|0)+na&65535;b[ma>>1]=na;ja=ja+1|0;}while((ja|0)<(Y|0))}ja=c[I+1500>>2]|0;na=M+(ja<<1)|0;ka=c[I+1508>>2]|0;d:do{if((ka|0)>1){ma=-ja|0;if(Q){Ca=1;Da=na}else{ia=1;V=na;while(1){b[V>>1]=(b[V>>1]|0)+(b[V+(ma<<1)>>1]|0);S=ia+1|0;if((S|0)<(ka|0)){ia=S;V=V+(ja<<1)|0}else{break d}}}while(1){V=(b[Da>>1]|0)+(b[Da+(ma<<1)>>1]|0)&65535;b[Da>>1]=V;ia=1;S=V;do{V=ia-ja|0;W=Da+(ia<<1)|0;S=(((((b[Da+(V<<1)>>1]|0)+(S<<16>>16)+(b[Da+(V-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[W>>1]|0)&65535;b[W>>1]=S;ia=ia+1|0;}while((ia|0)<(Y|0));ia=Ca+1|0;if((ia|0)<(ka|0)){Ca=ia;Da=Da+(ja<<1)|0}else{break}}}}while(0);ja=c[I+2360>>2]|0;ka=c[I+2348>>2]|0;Y=(ka|0)>1;if(Y){na=1;Q=b[ja>>1]|0;do{M=ja+(na<<1)|0;Q=(b[M>>1]|0)+Q&65535;b[M>>1]=Q;na=na+1|0;}while((na|0)<(ka|0))}na=c[I+2344>>2]|0;Q=ja+(na<<1)|0;M=c[I+2352>>2]|0;e:do{if((M|0)>1){ma=-na|0;if(Y){Ea=1;Fa=Q}else{ia=1;S=Q;while(1){b[S>>1]=(b[S>>1]|0)+(b[S+(ma<<1)>>1]|0);wa=ia+1|0;if((wa|0)<(M|0)){ia=wa;S=S+(na<<1)|0}else{break e}}}while(1){S=(b[Fa>>1]|0)+(b[Fa+(ma<<1)>>1]|0)&65535;b[Fa>>1]=S;ia=1;wa=S;do{S=ia-na|0;ua=Fa+(ia<<1)|0;wa=(((((b[Fa+(S<<1)>>1]|0)+(wa<<16>>16)+(b[Fa+(S-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[ua>>1]|0)&65535;b[ua>>1]=wa;ia=ia+1|0;}while((ia|0)<(ka|0));ia=Ea+1|0;if((ia|0)<(M|0)){Ea=ia;Fa=Fa+(na<<1)|0}else{break}}}}while(0);na=c[I+3204>>2]|0;M=c[I+3192>>2]|0;ka=(M|0)>1;if(ka){Q=1;Y=b[na>>1]|0;do{ja=na+(Q<<1)|0;Y=(b[ja>>1]|0)+Y&65535;b[ja>>1]=Y;Q=Q+1|0;}while((Q|0)<(M|0))}Q=c[I+3188>>2]|0;Y=na+(Q<<1)|0;ja=c[I+3196>>2]|0;f:do{if((ja|0)>1){ma=-Q|0;if(ka){Ga=1;Ha=Y}else{ia=1;wa=Y;while(1){b[wa>>1]=(b[wa>>1]|0)+(b[wa+(ma<<1)>>1]|0);ua=ia+1|0;if((ua|0)<(ja|0)){ia=ua;wa=wa+(Q<<1)|0}else{break f}}}while(1){wa=(b[Ha>>1]|0)+(b[Ha+(ma<<1)>>1]|0)&65535;b[Ha>>1]=wa;ia=1;ua=wa;do{wa=ia-Q|0;S=Ha+(ia<<1)|0;ua=(((((b[Ha+(wa<<1)>>1]|0)+(ua<<16>>16)+(b[Ha+(wa-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[S>>1]|0)&65535;b[S>>1]=ua;ia=ia+1|0;}while((ia|0)<(M|0));ia=Ga+1|0;if((ia|0)<(ja|0)){Ga=ia;Ha=Ha+(Q<<1)|0}else{break}}}}while(0);ZDb(N);pa=la}}while(0);ea=I+4240|0;oa=I;fa=I+4008|0;da=I+4012|0;Q=I+7328|0;ja=I+7344|0;M=I+7360|0;Y=I+4196|0;ka=I+7364|0;na=I+7368|0;ma=I+4190|0;ia=I+4192|0;ua=I+4244|0;S=I+4204|0;wa=I+4220|0;ta=I+4200|0;W=I+4256|0;V=I+5280|0;X=I+6304|0;va=I+1356|0;sa=I+1208|0;xa=I+4188|0;Ba=I+1248|0;za=I+1348|0;ya=I+4224|0;Aa=I+4228|0;Ia=I+4232|0;Ja=I+4236|0;Ka=0;while(1){La=L+1448+(Ka*844|0)|0;Ma=c[(c[c[P>>2]>>2]|0)+(Ka<<2)>>2]|0;Na=La|0;Oa=c[ea>>2]|0;c[ya>>2]=Oa;c[Aa>>2]=Oa+((c[Na>>2]|0)+15&-16);c[Ia>>2]=Oa+((c[Na>>2]<<1)+30&-32);c[Ja>>2]=Oa+(((c[Na>>2]|0)+15&-16)*3|0);do{if((c[pa>>2]|0)==0){if((c[ca>>2]|0)!=0){break}TGb(c[L+1448+(Ka*844|0)+24>>2]|0,0,ba(c[L+1448+(Ka*844|0)+20>>2]<<1,c[L+1448+(Ka*844|0)+16>>2]|0)|0)|0;Oa=c[oa>>2]|0;if((c[fa>>2]|0)==0){Pa=0}else{Qa=Oa+824|0;Ra=0;Sa=0;while(1){Ta=(Ra|0)!=0|0;Ua=Sa;Va=Ta;while(1){Wa=Ua+1|0;c[n+(Ua<<2)>>2]=L+1448+(Ka*844|0)+44+(Ra*160|0)+(Va*40|0);Xa=c[T>>2]|0;Ya=-Xa&7;Za=c[H>>2]|0;if((Ya|0)==0){_a=Xa}else{$a=Ya+Xa|0;Xa=Za>>>0>$a>>>0?$a:Za;c[T>>2]=Xa;_a=Xa}Xa=c[R>>2]|0;$a=Xa+(_a>>>3)|0;Ya=(fe(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(_a&7);if((Ya&-1434451968|0)==0){$a=1;ab=_a;bb=Ya;while(1){cb=bb>>>24;db=a[1201432+cb|0]|0;eb=db&255;fb=((db&255)>>>0>8>>>0?8:eb)+ab|0;gb=Za>>>0>fb>>>0;hb=gb?fb:Za;if(!(db<<24>>24==9)){ha=110;break}db=d[1201688+cb|0]|$a<<4;if(!(db>>>0<134217728>>>0)){ib=db;break}fb=Xa+(hb>>>3)|0;jb=(fe(d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0)|0)<<(hb&7);if(gb){$a=db;ab=hb;bb=jb}else{ib=db;break}}if((ha|0)==110){ha=0;ib=d[1201688+cb|0]|$a<<(eb-1>>1)}c[T>>2]=hb;kb=ib-1|0}else{bb=Ya>>>24;ab=(d[1201432+bb|0]|0)+_a|0;c[T>>2]=Za>>>0>ab>>>0?ab:Za;kb=d[1200920+bb|0]|0}bb=L+1448+(Ka*844|0)+44+(Ra*160|0)+(Va*40|0)+32|0;c[bb>>2]=kb;if((kb|0)!=0){ab=c[T>>2]|0;Xa=c[H>>2]|0;db=c[R>>2]|0;jb=db+(ab>>>3)|0;gb=(fe(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(ab&7);if((gb&-1434451968|0)==0){jb=1;fb=ab;lb=gb;while(1){mb=lb>>>24;nb=a[1201432+mb|0]|0;ob=nb&255;pb=((nb&255)>>>0>8>>>0?8:ob)+fb|0;qb=Xa>>>0>pb>>>0;rb=qb?pb:Xa;if(!(nb<<24>>24==9)){ha=118;break}nb=d[1201688+mb|0]|jb<<4;if(!(nb>>>0<134217728>>>0)){sb=nb;break}pb=db+(rb>>>3)|0;tb=(fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(rb&7);if(qb){jb=nb;fb=rb;lb=tb}else{sb=nb;break}}if((ha|0)==118){ha=0;sb=d[1201688+mb|0]|jb<<(ob-1>>1)}c[T>>2]=rb;ub=sb-1|0}else{lb=gb>>>24;fb=(d[1201432+lb|0]|0)+ab|0;c[T>>2]=Xa>>>0>fb>>>0?fb:Xa;ub=d[1200920+lb|0]|0}c[L+1448+(Ka*844|0)+44+(Ra*160|0)+(Va*40|0)+20>>2]=ub;lb=c[T>>2]|0;fb=-lb&7;if((fb|0)==0){vb=lb}else{db=c[H>>2]|0;Za=fb+lb|0;lb=db>>>0>Za>>>0?Za:db;c[T>>2]=lb;vb=lb}c[L+1448+(Ka*844|0)+44+(Ra*160|0)+(Va*40|0)+36>>2]=(c[R>>2]|0)+((vb|0)/8|0);lb=c[bb>>2]|0;db=(c[O>>2]|0)-(c[T>>2]|0)|0;if((db|0)>7){Za=(db|0)/8|0;wb=lb>>>0<=Za>>>0?lb:Za}else{wb=0}c[bb>>2]=wb;Za=wb<<3;lb=c[T>>2]|0;db=-lb|0;fb=(c[H>>2]|0)-lb|0;if((Za|0)<(db|0)){xb=db}else{xb=(fb|0)<(Za|0)?fb:Za}c[T>>2]=xb+lb}lb=Va+1|0;if(lb>>>0<4>>>0){Ua=Wa;Va=lb}else{break}}Va=Sa+4-Ta|0;if((c[U>>2]|0)!=0){oe[c[Qa>>2]&63](Oa,138,L+1448+(Ka*844|0)+44+(Ra*160|0)+(Ta*40|0)|0,0,4-Ta|0,40)|0}Ua=Ra+1|0;if(Ua>>>0<(c[fa>>2]|0)>>>0){Ra=Ua;Sa=Va}else{Pa=Va;break}}}if((c[U>>2]|0)!=0){break}oe[c[Oa+824>>2]&63](Oa,712,s,0,Pa,4)|0}}while(0);la=L+1448+(Ka*844|0)+24|0;N=L+1448+(Ka*844|0)+20|0;if((ekb(o,c[la>>2]|0,c[L+1448+(Ka*844|0)+12>>2]|0,c[L+1448+(Ka*844|0)+16>>2]|0,c[N>>2]|0,(c[da>>2]|0)+2|0,c[fa>>2]|0,c[L+1448+(Ka*844|0)+32>>2]|0)|0)!=0){break b}Sa=c[ga>>2]|0;g:do{if((Sa|0)==0){Ra=L+1448+(Ka*844|0)+4|0;if((c[Ra>>2]|0)<=0){break}Qa=L+1448+(Ka*844|0)+8|0;Va=0;while(1){Ua=Va+16|0;Dkb(o,Ua);lb=c[Qa>>2]|0;Za=Ma+(ba(lb,Va)|0)|0;fb=c[N>>2]|0;db=(c[la>>2]|0)+((ba(fb,Va)|0)<<1)|0;Se[c[za>>2]&511](Za,lb,db,fb,c[Na>>2]|0,16);if((Ua|0)<(c[Ra>>2]|0)){Va=Ua}else{break}}}else{Va=L+1448+(Ka*844|0)+39|0;Ra=L+1448+(Ka*844|0)+8|0;Qa=ba(d[Va]|0,c[Ra>>2]|0)|0;Oa=L+1448+(Ka*844|0)+4|0;Ua=a[L+1448+(Ka*844|0)+36|0]|0;fb=(Ua&255)>>>0>16>>>0?2:(Ua&255)>>>0>8>>>0|0;Ua=L+1252+(fb<<4)|0;c[Q>>2]=c[Ua>>2];c[Q+4>>2]=c[Ua+4>>2];c[Q+8>>2]=c[Ua+8>>2];c[Q+12>>2]=c[Ua+12>>2];Ua=L+1300+(fb<<4)|0;c[ja>>2]=c[Ua>>2];c[ja+4>>2]=c[Ua+4>>2];c[ja+8>>2]=c[Ua+8>>2];c[ja+12>>2]=c[Ua+12>>2];c[M>>2]=c[L+1360+(fb<<2)>>2];do{if((c[Y>>2]|0)>>>0>1>>>0){ha=143}else{if((b[ma>>1]|0)!=1){ha=143;break}if((b[ia>>1]|0)!=1){ha=143;break}c[ka>>2]=0;yb=0}}while(0);if((ha|0)==143){ha=0;c[ka>>2]=c[L+1372+(fb<<2)>>2];yb=c[L+1384+(fb<<2)>>2]|0}c[na>>2]=yb;if((Sa|0)>0){Ua=0;do{db=c[L+7376+(Ua<<2)>>2]|0;lb=c[Na>>2]|0;Za=c[Oa>>2]|0;Ya=db|0;$a=c[(c[Ya>>2]|0)+(Ka<<2)>>2]|0;nb=db+16+(Ka<<4)|0;c[nb>>2]=$a;Ke[c[sa>>2]&1023]($a,c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,lb,Za,8,8,3);if((a[xa]|0)!=0){$a=Za+16|0;tb=db+64+(Ka<<4)+4|0;qb=c[tb>>2]|0;if((qb|0)==0){pb=WDb((ba(c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,$a)|0)+32|0)|0;c[tb>>2]=pb;zb=pb}else{zb=qb}qb=c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0;pb=db+16+(Ka<<4)+4|0;c[pb>>2]=zb+((qb<<3)+16);tb=db+64+(Ka<<4)+8|0;Ab=c[tb>>2]|0;if((Ab|0)==0){Bb=WDb((ba(qb,$a)|0)+32|0)|0;c[tb>>2]=Bb;Cb=Bb;Db=c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0}else{Cb=Ab;Db=qb}qb=db+16+(Ka<<4)+8|0;c[qb>>2]=Cb+((Db<<3)+16);Ab=db+64+(Ka<<4)+12|0;Bb=c[Ab>>2]|0;if((Bb|0)==0){tb=WDb((ba(Db,$a)|0)+32|0)|0;c[Ab>>2]=tb;Eb=tb;Fb=c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0}else{Eb=Bb;Fb=Db}Bb=Eb+((Fb<<3)+16)|0;tb=db+16+(Ka<<4)+12|0;c[tb>>2]=Bb;Ab=db+4+(Ka<<2)|0;if((c[Ab>>2]|0)==0){Ke[c[Ba>>2]&1023](c[pb>>2]|0,c[qb>>2]|0,Bb,c[nb>>2]|0,Fb,lb,Za);Ke[c[sa>>2]&1023](c[pb>>2]|0,c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,lb,Za,8,8,3);Ke[c[sa>>2]&1023](c[qb>>2]|0,c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,lb,Za,8,8,3);Ke[c[sa>>2]&1023](c[tb>>2]|0,c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,lb,Za,8,8,3)}c[Ab>>2]=1}Ua=Ua+1|0;}while((Ua|0)<(c[ga>>2]|0))}Ua=L+1448+(Ka*844|0)+41|0;TGb(c[ua>>2]|0,0,ba(d[Ua]<<2,c[Ra>>2]|0)|0)|0;fb=c[S>>2]|0;if((fb|0)<=0){break}Ab=Qa<<1;Za=L+1448+(Ka*844|0)+38|0;lb=L+1448+(Ka*844|0)+40|0;Ya=-(d[Ua]|0)|0;tb=0;qb=fb;while(1){fb=(Ya|0)>0?Ya:0;pb=c[ua>>2]|0;nb=ba(tb,Qa)|0;Bb=pb+(nb<<1)|0;db=c[wa>>2]|0;$a=ba(c[ta>>2]|0,tb)|0;Gb=db+($a*10|0)|0;Hb=(tb|0)==0|0;Ib=(qb-1|0)==(tb|0);Jb=Ib&1;if(Ib|tb>>>0<2>>>0){w1(La,W,1,0,Hb,Jb);w1(La,V,0,0,Hb,Jb);w1(La,X,0,1,Hb,Jb);Kb=c[S>>2]|0}else{Kb=qb}do{if((tb|0)==(Kb-1|0)){Lb=c[Oa>>2]|0;ha=164}else{Jb=d[Va]|0;Hb=c[Oa>>2]|0;if((Jb+fb|0)>(Hb|0)){Lb=Hb;ha=164;break}Mb=Ya-fb+Jb|0}}while(0);if((ha|0)==164){ha=0;Mb=Lb-fb|0}if((Mb|0)<0){break g}TGb(pb+((ba(d[Ua]<<1,c[Ra>>2]|0)|0)+nb<<1)|0,0,Ab|0)|0;Ta=d[lb]|0;Jb=(d[Za]|0)-Ta|0;u1(L,Gb,Bb,W,Ka,-Ta|0,Ya);Ta=pb+((d[Za]|0)+nb<<1)|0;Hb=db+(($a+1|0)*10|0)|0;if(((c[ta>>2]|0)-1|0)>1){Ib=Ta;Nb=1;Ob=Jb;Pb=Hb;while(1){u1(L,Pb,Ib,V,Ka,Ob,Ya);Qb=d[Za]|0;Rb=Qb+Ob|0;Sb=Ib+(Qb<<1)|0;Qb=Nb+1|0;Tb=db+((Qb+$a|0)*10|0)|0;if((Qb|0)<((c[ta>>2]|0)-1|0)){Ib=Sb;Nb=Qb;Ob=Rb;Pb=Tb}else{Ub=Sb;Vb=Rb;Wb=Tb;break}}}else{Ub=Ta;Vb=Jb;Wb=Hb}u1(L,Wb,Ub,X,Ka,Vb,Ya);Pb=ba(c[Ra>>2]|0,fb-Ya|0)|0;Ob=pb+(Pb+nb+(d[lb]|0)<<1)|0;Dkb(o,Mb+fb|0);Pb=c[Ra>>2]|0;Nb=Ma+(ba(Pb,fb)|0)|0;Ib=c[N>>2]|0;$a=(c[la>>2]|0)+((ba(Ib,fb)|0)<<1)|0;Ke[c[va>>2]&1023](Nb,Ob,Pb,$a,Ib,c[Na>>2]|0,Mb);Ib=tb+1|0;$a=c[S>>2]|0;if((Ib|0)<($a|0)){Ya=(d[Va]|0)+Ya|0;tb=Ib;qb=$a}else{break}}}}while(0);Na=Ka+1|0;if((Na|0)<3){Ka=Na}else{G=J;break}}}}else{G=F}}while(0);if((G+13|0)<(u|0)){x=G}else{Xb=G;break a}}if((ha|0)==50){yDb(f,48,1970352,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}else if((ha|0)==51){yDb(f,16,1941688,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}else if((ha|0)==53){yDb(f,16,1917520,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}yDb(c[w>>2]|0,16,2113008,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;E=-1;i=k;return E|0}else{Xb=0}}while(0);G=c[j>>2]|0;if((G|0)==0){E=u;i=k;return E|0}u=c[G>>2]|0;Mb=c[u+164>>2]|0;o=r+1444|0;Vb=c[o>>2]|0;do{if((Mb|0)>(Vb|0)){Ub=r+7420|0;Wb=Ub;Lb=Ub;Ub=c[Lb>>2]|0;do{if((Ub|0)==0){Yb=0;Zb=G;_b=u}else{Kb=0;Fb=0;Eb=-1;Db=Ub;do{Cb=(c[(c[Db>>2]|0)+164>>2]|0)==(Vb|0);Kb=Cb?Db:Kb;Eb=Cb?Fb:Eb;Fb=Fb+1|0;Db=c[Lb+(Fb<<2)>>2]|0;}while((Db|0)!=0);if((Kb|0)==0){Yb=0;Zb=G;_b=u;break}Db=Lb+(Eb<<2)|0;if((c[Db>>2]|0)==0){Yb=Kb;Zb=G;_b=u;break}else{$b=Eb;ac=Db}while(1){Db=$b+1|0;Fb=Lb+(Db<<2)|0;c[ac>>2]=c[Fb>>2];if((c[Fb>>2]|0)==0){break}else{$b=Db;ac=Fb}}Eb=c[j>>2]|0;Yb=Kb;Zb=Eb;_b=c[Eb>>2]|0}}while(0);Ub=_b+172|0;c[Ub>>2]=c[Ub>>2]|4;Ub=0;while(1){if((Ub|0)>=5){ha=184;break}bc=Lb+(Ub<<2)|0;if((c[bc>>2]|0)==0){ha=183;break}else{Ub=Ub+1|0}}h:do{if((ha|0)==183){c[bc>>2]=Zb;cc=Yb}else if((ha|0)==184){Ub=c[(c[c[Lb>>2]>>2]|0)+164>>2]|0;yDb(f,16,2054408,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;w=c[r+7424>>2]|0;if((w|0)==0){dc=Ub}else{Eb=1;Fb=Ub;Ub=w;while(1){w=c[(c[Ub>>2]|0)+164>>2]|0;Db=(w|0)<(Fb|0)?w:Fb;w=Eb+1|0;Cb=c[Wb+(w<<2)>>2]|0;if((Cb|0)==0){dc=Db;break}else{Eb=w;Fb=Db;Ub=Cb}}}Ub=c[Lb>>2]|0;do{if((Ub|0)==0){ec=0}else{Fb=0;Eb=0;Kb=-1;Cb=Ub;do{Db=(c[(c[Cb>>2]|0)+164>>2]|0)==(dc|0);Fb=Db?Cb:Fb;Kb=Db?Eb:Kb;Eb=Eb+1|0;Cb=c[Lb+(Eb<<2)>>2]|0;}while((Cb|0)!=0);if((Fb|0)==0){ec=0;break}Cb=Lb+(Kb<<2)|0;if((c[Cb>>2]|0)==0){ec=Fb;break}else{fc=Kb;gc=Cb}while(1){Cb=fc+1|0;Eb=Lb+(Cb<<2)|0;c[gc>>2]=c[Eb>>2];if((c[Eb>>2]|0)==0){ec=Fb;break}else{fc=Cb;gc=Eb}}}}while(0);Ub=c[j>>2]|0;Fb=0;while(1){if((Fb|0)>=5){cc=ec;break h}hc=Lb+(Fb<<2)|0;if((c[hc>>2]|0)==0){break}else{Fb=Fb+1|0}}c[hc>>2]=Ub;cc=ec}}while(0);if((cc|0)==0){ha=201;break}Lb=c[cc>>2]|0;Wb=Lb+172|0;c[Wb>>2]=c[Wb>>2]^4;Wb=MCb(v,Lb)|0;if((Wb|0)<0){E=Wb;i=k;return E|0}else{c[h>>2]=1;break}}else{if((Mb|0)!=(Vb|0)){ha=201;break}Wb=MCb(v,u)|0;if((Wb|0)<0){E=Wb;i=k;return E|0}else{c[h>>2]=1;break}}}while(0);do{if((ha|0)==201){if((c[h>>2]|0)==0){E=Xb}else{break}i=k;return E|0}}while(0);c[o>>2]=(c[g+164>>2]|0)+1;E=Xb;i=k;return E|0}function q1(a){a=a|0;var b=0;b=c[a+60>>2]|0;s1(b);c[b+1440>>2]=0;c[b+1444>>2]=-1;JCb(b+7444|0);JCb(b+7556|0);JCb(b+7668|0);JCb(b+7780|0);JCb(b+7892|0);JCb(b+8004|0);JCb(b+8116|0);JCb(b+8228|0);JCb(b+8340|0);JCb(b+8452|0);JCb(b+8564|0);JCb(b+8676|0);JCb(b+8788|0);JCb(b+8900|0);return 0}function r1(a){a=a|0;var b=0;b=c[a+60>>2]|0;s1(b);c[b+1440>>2]=0;c[b+1444>>2]=-1;return}function s1(a){a=a|0;var b=0,d=0;b=0;do{d=c[a+7444+(b*112|0)>>2]|0;if((c[d>>2]|0)!=0){KCb(d);TGb(a+7444+(b*112|0)+4|0,0,12)|0}$Db(a+7444+(b*112|0)+68|0);$Db(a+7444+(b*112|0)+72|0);$Db(a+7444+(b*112|0)+76|0);$Db(a+7444+(b*112|0)+84|0);$Db(a+7444+(b*112|0)+88|0);$Db(a+7444+(b*112|0)+92|0);$Db(a+7444+(b*112|0)+100|0);$Db(a+7444+(b*112|0)+104|0);$Db(a+7444+(b*112|0)+108|0);b=b+1|0;}while((b|0)<14);TGb(a+7384|0,0,60)|0;$Db(a+1476|0);$Db(a+1480|0);$Db(a+2320|0);$Db(a+2324|0);$Db(a+3164|0);$Db(a+3168|0);$Db(a+4216|0);$Db(a+4220|0);$Db(a+4240|0);$Db(a+4244|0);$Db(a+4248|0);return}function t1(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,ee=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0,$i=0,aj=0,bj=0,cj=0,dj=0,ej=0,fj=0,gj=0,hj=0,ij=0,jj=0,kj=0,lj=0,mj=0,nj=0,oj=0,pj=0,qj=0,rj=0,sj=0,tj=0,uj=0,vj=0,wj=0,xj=0,yj=0,zj=0,Aj=0,Bj=0,Cj=0,Dj=0,Ej=0,Fj=0,Gj=0,Hj=0,Ij=0,Jj=0,Kj=0,Lj=0,Mj=0,Nj=0,Oj=0,Pj=0;g=i;i=i+512|0;h=g|0;j=g+16|0;k=g+496|0;l=g+504|0;m=f+1396|0;n=f+1404|0;o=c[n>>2]|0;p=f+1412|0;q=c[p>>2]|0;r=m|0;s=c[r>>2]|0;t=s+(o>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(o&7)&-65536;t=o+16|0;o=q>>>0>t>>>0?t:q;c[n>>2]=o;t=s+(o>>>3)|0;s=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(o&7)>>>16;t=o+16|0;c[n>>2]=q>>>0>t>>>0?t:q;q=s|u;u=f+7372|0;c[(c[c[u>>2]>>2]|0)+164>>2]=q;s=f|0;yDb(c[s>>2]|0,48,2353872,(t=i,i=i+8|0,c[t>>2]=q,t)|0);i=t;o=f+1444|0;if((c[o>>2]|0)<0){c[o>>2]=q}c[f+7380>>2]=0;c[f+7376>>2]=0;o=f+4004|0;v=c[o>>2]|0;if((v|0)>0){w=0;while(1){x=c[n>>2]|0;y=c[p>>2]|0;z=c[r>>2]|0;A=z+(x>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(x&7);if((B&-1434451968|0)==0){A=1;C=x;D=B;while(1){E=D>>>24;F=a[1201432+E|0]|0;G=F&255;H=((F&255)>>>0>8>>>0?8:G)+C|0;I=y>>>0>H>>>0;J=I?H:y;if(!(F<<24>>24==9)){K=8;break}F=d[1201688+E|0]|A<<4;if(!(F>>>0<134217728>>>0)){L=F;break}H=z+(J>>>3)|0;M=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7);if(I){A=F;C=J;D=M}else{L=F;break}}if((K|0)==8){K=0;L=d[1201688+E|0]|A<<(G-1>>1)}c[n>>2]=J;N=L-1|0;O=J}else{D=B>>>24;C=(d[1201432+D|0]|0)+x|0;F=y>>>0>C>>>0?C:y;c[n>>2]=F;N=d[1200920+D|0]|0;O=F}if((N|0)==0){P=0}else{F=z+(O>>>3)|0;D=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(O&7)>>31;F=O+1|0;c[n>>2]=y>>>0>F>>>0?F:y;P=(D^N)-D|0}D=P+q|0;F=f+7376+(w<<2)|0;C=0;M=2147483647;while(1){I=f+7384+(C<<2)|0;H=c[I>>2]|0;do{if((H|0)==0){Q=M}else{R=(c[(c[H>>2]|0)+164>>2]|0)-D|0;if((((R|0)>-1?R:-R|0)|0)>=(M|0)){Q=M;break}c[F>>2]=H;R=(c[(c[c[I>>2]>>2]|0)+164>>2]|0)-D|0;Q=(R|0)>-1?R:-R|0}}while(0);I=C+1|0;S=(Q|0)==0;if((I|0)>7|S){break}else{C=I;M=Q}}M=c[F>>2]|0;if((M|0)!=0&S){T=M}else{yDb(c[s>>2]|0,48,2333840,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;T=c[F>>2]|0}a:do{if((T|0)==0){M=0;while(1){if((M|0)>=14){break a}U=f+7444+(M*112|0)|0;V=U|0;if((c[c[V>>2]>>2]|0)==0){break}else{M=M+1|0}}c[F>>2]=U;M=c[s>>2]|0;C=c[V>>2]|0;_Ga(c[M+140>>2]|0,k,l);D=M+120|0;y=C+68|0;c[y>>2]=(c[D>>2]|0)+32;z=M+124|0;x=C+72|0;c[x>>2]=(c[z>>2]|0)+34;if((_$a(M,C,1)|0)<0){break}M=C|0;B=c[M>>2]|0;if((B|0)!=0){A=16>>>((c[l>>2]|0)>>>0);I=0;H=M;M=B;do{c[H>>2]=M+((ba((I|0)!=0&(I|0)<3?A:16,c[C+32+(I<<2)>>2]|0)|0)+32);I=I+1|0;H=C+(I<<2)|0;M=c[H>>2]|0;}while((M|0)!=0)}c[y>>2]=c[D>>2];c[x>>2]=c[z>>2]}}while(0);F=w+1|0;M=c[o>>2]|0;if((F|0)<(M|0)){w=F}else{W=M;break}}}else{W=v}if((c[(c[c[u>>2]>>2]|0)+172>>2]|0)==0){X=W}else{W=c[n>>2]|0;v=c[p>>2]|0;w=c[r>>2]|0;l=w+(W>>>3)|0;k=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(W&7);if((k&-1434451968|0)==0){l=1;V=W;U=k;while(1){Y=U>>>24;T=a[1201432+Y|0]|0;Z=T&255;S=((T&255)>>>0>8>>>0?8:Z)+V|0;Q=v>>>0>S>>>0;_=Q?S:v;if(!(T<<24>>24==9)){K=34;break}T=d[1201688+Y|0]|l<<4;if(!(T>>>0<134217728>>>0)){$=T;break}S=w+(_>>>3)|0;P=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(_&7);if(Q){l=T;V=_;U=P}else{$=T;break}}if((K|0)==34){$=d[1201688+Y|0]|l<<(Z-1>>1)}c[n>>2]=_;aa=$-1|0;ca=_}else{_=k>>>24;k=(d[1201432+_|0]|0)+W|0;W=v>>>0>k>>>0?k:v;c[n>>2]=W;aa=d[1200920+_|0]|0;ca=W}b:do{if((aa|0)==0){da=f+7384|0}else{W=w+(ca>>>3)|0;_=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(ca&7);W=ca+1|0;c[n>>2]=v>>>0>W>>>0?W:v;W=(_>>>31)+q+(_>>31^aa)|0;_=f+7384|0;k=c[_>>2]|0;do{if((k|0)!=0){$=0;Z=0;l=-1;Y=k;do{U=(c[(c[Y>>2]|0)+164>>2]|0)==(W|0);$=U?Y:$;l=U?Z:l;Z=Z+1|0;Y=c[f+7384+(Z<<2)>>2]|0;}while((Y|0)!=0);if(($|0)==0){break}Y=f+7384+(l<<2)|0;if((c[Y>>2]|0)!=0){Z=l;z=Y;while(1){Y=Z+1|0;x=f+7384+(Y<<2)|0;c[z>>2]=c[x>>2];if((c[x>>2]|0)==0){break}else{Z=Y;z=x}}}z=(c[$>>2]|0)+172|0;c[z>>2]=c[z>>2]&4;da=_;break b}}while(0);yDb(c[s>>2]|0,48,2309160,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;da=_}}while(0);c:while(1){ea=c[u>>2]|0;aa=0;while(1){if((aa|0)>=8){break}fa=f+7384+(aa<<2)|0;if((c[fa>>2]|0)==0){break c}else{aa=aa+1|0}}yDb(c[s>>2]|0,16,2290440,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;aa=c[da>>2]|0;_=c[(c[aa>>2]|0)+164>>2]|0;q=0;v=0;ca=-1;w=aa;aa=_;while(1){W=(aa|0)==(_|0);ga=W?w:q;ha=W?v:ca;W=v+1|0;k=c[f+7384+(W<<2)>>2]|0;if((k|0)==0){break}q=ga;v=W;ca=ha;w=k;aa=c[(c[k>>2]|0)+164>>2]|0}aa=f+7384+(ha<<2)|0;if((c[aa>>2]|0)!=0){w=ha;ca=aa;while(1){aa=w+1|0;v=f+7384+(aa<<2)|0;c[ca>>2]=c[v>>2];if((c[v>>2]|0)==0){break}else{w=aa;ca=v}}}ca=(c[ga>>2]|0)+172|0;c[ca>>2]=c[ca>>2]&4}c[fa>>2]=ea;X=c[o>>2]|0}d:do{if((X|0)!=0){ea=c[n>>2]|0;fa=-ea&7;ga=c[p>>2]|0;if((fa|0)==0){ia=ea}else{ha=fa+ea|0;ea=ga>>>0>ha>>>0?ha:ga;c[n>>2]=ea;ia=ea}ea=f+1396|0;ha=c[ea>>2]|0;fa=ha+(ia>>>3)|0;da=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ia&7);if((da&-1434451968|0)==0){fa=1;u=ia;ca=da;while(1){ja=ca>>>24;w=a[1201432+ja|0]|0;ka=w&255;v=((w&255)>>>0>8>>>0?8:ka)+u|0;aa=ga>>>0>v>>>0;la=aa?v:ga;if(!(w<<24>>24==9)){K=64;break}w=d[1201688+ja|0]|fa<<4;if(!(w>>>0<134217728>>>0)){ma=w;break}v=ha+(la>>>3)|0;q=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(la&7);if(aa){fa=w;u=la;ca=q}else{ma=w;break}}if((K|0)==64){ma=d[1201688+ja|0]|fa<<(ka-1>>1)}c[n>>2]=la;na=ma-1|0;oa=la}else{ca=da>>>24;u=(d[1201432+ca|0]|0)+ia|0;w=ga>>>0>u>>>0?u:ga;c[n>>2]=w;na=d[1200920+ca|0]|0;oa=w}if(na>>>0>4>>>0){yDb(c[s>>2]|0,16,2176744,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}if((na|0)==0){w=ha+(oa>>>3)|0;ca=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(oa&7);if((ca&-1434451968|0)==0){w=1;u=oa;q=ca;while(1){qa=q>>>24;aa=a[1201432+qa|0]|0;ra=aa&255;v=((aa&255)>>>0>8>>>0?8:ra)+u|0;_=ga>>>0>v>>>0;sa=_?v:ga;if(!(aa<<24>>24==9)){K=74;break}aa=d[1201688+qa|0]|w<<4;if(!(aa>>>0<134217728>>>0)){ta=aa;break}v=ha+(sa>>>3)|0;k=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(sa&7);if(_){w=aa;u=sa;q=k}else{ta=aa;break}}if((K|0)==74){ta=d[1201688+qa|0]|w<<(ra-1>>1)}c[n>>2]=sa;ua=ta+255&255;va=sa}else{q=ca>>>24;u=(d[1201432+q|0]|0)+oa|0;da=ga>>>0>u>>>0?u:ga;c[n>>2]=da;ua=a[1200920+q|0]|0;va=da}a[f+1484|0]=ua;da=ha+(va>>>3)|0;q=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(va&7);if((q&-1434451968|0)==0){da=1;u=va;fa=q;while(1){wa=fa>>>24;aa=a[1201432+wa|0]|0;xa=aa&255;k=((aa&255)>>>0>8>>>0?8:xa)+u|0;_=ga>>>0>k>>>0;ya=_?k:ga;if(!(aa<<24>>24==9)){K=81;break}aa=d[1201688+wa|0]|da<<4;if(!(aa>>>0<134217728>>>0)){za=aa;break}k=ha+(ya>>>3)|0;v=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(ya&7);if(_){da=aa;u=ya;fa=v}else{za=aa;break}}if((K|0)==81){za=d[1201688+wa|0]|da<<(xa-1>>1)}c[n>>2]=ya;Aa=za+255&255;Ba=ya}else{fa=q>>>24;u=(d[1201432+fa|0]|0)+va|0;ca=ga>>>0>u>>>0?u:ga;c[n>>2]=ca;Aa=a[1200920+fa|0]|0;Ba=ca}a[f+1485|0]=Aa;ca=ha+(Ba>>>3)|0;fa=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(Ba&7);if((fa&-1434451968|0)==0){ca=1;u=Ba;w=fa;while(1){Ca=w>>>24;aa=a[1201432+Ca|0]|0;Da=aa&255;v=((aa&255)>>>0>8>>>0?8:Da)+u|0;_=ga>>>0>v>>>0;Ea=_?v:ga;if(!(aa<<24>>24==9)){K=88;break}aa=d[1201688+Ca|0]|ca<<4;if(!(aa>>>0<134217728>>>0)){Fa=aa;break}v=ha+(Ea>>>3)|0;k=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(Ea&7);if(_){ca=aa;u=Ea;w=k}else{Fa=aa;break}}if((K|0)==88){Fa=d[1201688+Ca|0]|ca<<(Da-1>>1)}c[n>>2]=Ea;Ga=Fa+255&255;Ha=Ea}else{w=fa>>>24;u=(d[1201432+w|0]|0)+Ba|0;q=ga>>>0>u>>>0?u:ga;c[n>>2]=q;Ga=a[1200920+w|0]|0;Ha=q}a[f+1486|0]=Ga;q=ha+(Ha>>>3)|0;w=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(Ha&7);if((w&-1434451968|0)==0){q=1;u=Ha;da=w;while(1){Ia=da>>>24;aa=a[1201432+Ia|0]|0;Ja=aa&255;k=((aa&255)>>>0>8>>>0?8:Ja)+u|0;_=ga>>>0>k>>>0;Ka=_?k:ga;if(!(aa<<24>>24==9)){K=95;break}aa=d[1201688+Ia|0]|q<<4;if(!(aa>>>0<134217728>>>0)){La=aa;break}k=ha+(Ka>>>3)|0;v=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Ka&7);if(_){q=aa;u=Ka;da=v}else{La=aa;break}}if((K|0)==95){La=d[1201688+Ia|0]|q<<(Ja-1>>1)}c[n>>2]=Ka;Ma=La+255&255;Na=Ka}else{da=w>>>24;u=(d[1201432+da|0]|0)+Ha|0;fa=ga>>>0>u>>>0?u:ga;c[n>>2]=fa;Ma=a[1200920+da|0]|0;Na=fa}a[f+1487|0]=Ma;Oa=Ga;Pa=Ma;Qa=ua;Ra=Aa;Sa=Na}else{fa=na-1|0;da=a[1361696+fa|0]|0;a[f+1484|0]=da;a[f+1485|0]=da;u=a[1361688+fa|0]|0;a[f+1486|0]=u;a[f+1487|0]=u;Oa=u;Pa=u;Qa=da;Ra=da;Sa=oa}do{if(!(Oa<<24>>24==0|Pa<<24>>24==0)){if((Oa&255)>>>0<(Qa&255)>>>1>>>0){break}if((Pa&255)>>>0<(Ra&255)>>>1>>>0){break}if((Oa&255)>>>0>(Qa&255)>>>0|(Pa&255)>>>0>(Ra&255)>>>0){yDb(c[s>>2]|0,16,2159400,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}if((((Qa&255)>>>0>(Ra&255)>>>0?Qa:Ra)&255)>>>0>32>>>0){yDb(c[s>>2]|0,16,2152416,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}da=ha+(Sa>>>3)|0;u=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Sa&7);if((u&-1434451968|0)==0){da=1;fa=Sa;ca=u;while(1){Ta=ca>>>24;aa=a[1201432+Ta|0]|0;Ua=aa&255;v=((aa&255)>>>0>8>>>0?8:Ua)+fa|0;_=ga>>>0>v>>>0;Va=_?v:ga;if(!(aa<<24>>24==9)){K=112;break}aa=d[1201688+Ta|0]|da<<4;if(!(aa>>>0<134217728>>>0)){Wa=aa;break}v=ha+(Va>>>3)|0;k=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(Va&7);if(_){da=aa;fa=Va;ca=k}else{Wa=aa;break}}if((K|0)==112){Wa=d[1201688+Ta|0]|da<<(Ua-1>>1)}c[n>>2]=Va;Xa=Wa-1|0;Ya=Va}else{ca=u>>>24;fa=(d[1201432+ca|0]|0)+Sa|0;$=ga>>>0>fa>>>0?fa:ga;c[n>>2]=$;Xa=d[1200920+ca|0]|0;Ya=$}a[f+4188|0]=Xa;if((Xa&252)>>>0>3>>>0){yDb(c[s>>2]|0,16,2145528,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}$=d[ha+(Ya>>>3)|0]<<(Ya&7)>>>7;ca=((Ya|0)<(ga|0))+Ya|0;c[n>>2]=ca;fa=$&1;$=f+4e3|0;c[$>>2]=fa;if((fa|0)==0){Za=ca;_a=ga;$a=ha;ab=X}else{TGb(f+4108|0,0,80)|0;fa=0;aa=ca;ca=ga;k=ha;while(1){_=d[k+(aa>>>3)|0]|0;v=((aa|0)<(ca|0))+aa|0;c[n>>2]=v;if((_&128>>>((aa&7)>>>0)|0)==0){bb=v;cb=ca;db=k}else{_=k+(v>>>3)|0;W=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(v&7);if((W&-1434451968|0)==0){_=1;z=v;Z=W;while(1){eb=Z>>>24;l=a[1201432+eb|0]|0;fb=l&255;x=((l&255)>>>0>8>>>0?8:fb)+z|0;Y=ca>>>0>x>>>0;gb=Y?x:ca;if(!(l<<24>>24==9)){K=124;break}l=d[1201688+eb|0]|_<<4;if(!(l>>>0<134217728>>>0)){hb=l;break}x=k+(gb>>>3)|0;D=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(gb&7);if(Y){_=l;z=gb;Z=D}else{hb=l;break}}if((K|0)==124){K=0;hb=d[1201688+eb|0]|_<<(fb-1>>1)}c[n>>2]=gb;ib=hb-1|0;jb=gb}else{Z=W>>>24;z=(d[1201432+Z|0]|0)+v|0;l=ca>>>0>z>>>0?z:ca;c[n>>2]=l;ib=d[1200920+Z|0]|0;jb=l}if((ib|0)==0){kb=0}else{l=k+(jb>>>3)|0;Z=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(jb&7)>>31;l=jb+1|0;c[n>>2]=ca>>>0>l>>>0?l:ca;kb=(Z^ib)-Z|0}c[f+4108+(fa*40|0)>>2]=kb;Z=c[n>>2]|0;l=c[p>>2]|0;z=c[ea>>2]|0;D=z+(Z>>>3)|0;Y=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(Z&7);if((Y&-1434451968|0)==0){D=1;x=Z;y=Y;while(1){lb=y>>>24;U=a[1201432+lb|0]|0;mb=U&255;V=((U&255)>>>0>8>>>0?8:mb)+x|0;T=l>>>0>V>>>0;nb=T?V:l;if(!(U<<24>>24==9)){K=133;break}U=d[1201688+lb|0]|D<<4;if(!(U>>>0<134217728>>>0)){ob=U;break}V=z+(nb>>>3)|0;P=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(nb&7);if(T){D=U;x=nb;y=P}else{ob=U;break}}if((K|0)==133){K=0;ob=d[1201688+lb|0]|D<<(mb-1>>1)}c[n>>2]=nb;pb=ob-1|0;qb=nb}else{y=Y>>>24;x=(d[1201432+y|0]|0)+Z|0;v=l>>>0>x>>>0?x:l;c[n>>2]=v;pb=d[1200920+y|0]|0;qb=v}if((pb|0)==0){rb=0;sb=qb}else{v=z+(qb>>>3)|0;y=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(qb&7)>>31;v=qb+1|0;x=l>>>0>v>>>0?v:l;c[n>>2]=x;rb=(y^pb)-y|0;sb=x}c[f+4108+(fa*40|0)+4>>2]=rb;bb=sb;cb=l;db=z}x=d[db+(bb>>>3)|0]|0;y=((bb|0)<(cb|0))+bb|0;c[n>>2]=y;if((x&128>>>((bb&7)>>>0)|0)==0){c[f+4108+(fa*40|0)+8>>2]=1;c[f+4108+(fa*40|0)+20>>2]=1;tb=c[n>>2]|0;ub=c[p>>2]|0;vb=c[ea>>2]|0}else{x=db+(y>>>3)|0;v=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7);if((v&-1434451968|0)==0){x=1;W=y;_=v;while(1){wb=_>>>24;U=a[1201432+wb|0]|0;xb=U&255;P=((U&255)>>>0>8>>>0?8:xb)+W|0;T=cb>>>0>P>>>0;yb=T?P:cb;if(!(U<<24>>24==9)){K=144;break}U=d[1201688+wb|0]|x<<4;if(!(U>>>0<134217728>>>0)){zb=U;break}P=db+(yb>>>3)|0;V=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(yb&7);if(T){x=U;W=yb;_=V}else{zb=U;break}}if((K|0)==144){K=0;zb=d[1201688+wb|0]|x<<(xb-1>>1)}c[n>>2]=yb;Ab=zb-1|0}else{_=v>>>24;W=(d[1201432+_|0]|0)+y|0;c[n>>2]=cb>>>0>W>>>0?W:cb;Ab=d[1200920+_|0]|0}c[f+4108+(fa*40|0)+32>>2]=Ab;_=c[n>>2]|0;W=c[p>>2]|0;z=c[ea>>2]|0;l=z+(_>>>3)|0;Z=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(_&7);if((Z&-1434451968|0)==0){l=1;Y=_;D=Z;while(1){Bb=D>>>24;U=a[1201432+Bb|0]|0;Cb=U&255;V=((U&255)>>>0>8>>>0?8:Cb)+Y|0;T=W>>>0>V>>>0;Db=T?V:W;if(!(U<<24>>24==9)){K=151;break}U=d[1201688+Bb|0]|l<<4;if(!(U>>>0<134217728>>>0)){Eb=U;break}V=z+(Db>>>3)|0;P=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Db&7);if(T){l=U;Y=Db;D=P}else{Eb=U;break}}if((K|0)==151){K=0;Eb=d[1201688+Bb|0]|l<<(Cb-1>>1)}c[n>>2]=Db;Fb=Eb-1|0;Gb=Db}else{D=Z>>>24;Y=(d[1201432+D|0]|0)+_|0;y=W>>>0>Y>>>0?Y:W;c[n>>2]=y;Fb=d[1200920+D|0]|0;Gb=y}if((Fb|0)==0){Hb=0}else{y=z+(Gb>>>3)|0;D=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(Gb&7)>>31;y=Gb+1|0;c[n>>2]=W>>>0>y>>>0?y:W;Hb=(D^Fb)-D|0}c[f+4108+(fa*40|0)+8>>2]=Hb;D=c[n>>2]|0;y=c[p>>2]|0;Y=c[ea>>2]|0;v=Y+(D>>>3)|0;x=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(D&7);if((x&-1434451968|0)==0){v=1;U=D;P=x;while(1){Ib=P>>>24;T=a[1201432+Ib|0]|0;Jb=T&255;V=((T&255)>>>0>8>>>0?8:Jb)+U|0;Q=y>>>0>V>>>0;Kb=Q?V:y;if(!(T<<24>>24==9)){K=160;break}T=d[1201688+Ib|0]|v<<4;if(!(T>>>0<134217728>>>0)){Lb=T;break}V=Y+(Kb>>>3)|0;S=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Kb&7);if(Q){v=T;U=Kb;P=S}else{Lb=T;break}}if((K|0)==160){K=0;Lb=d[1201688+Ib|0]|v<<(Jb-1>>1)}c[n>>2]=Kb;Mb=Lb-1|0;Nb=Kb}else{P=x>>>24;U=(d[1201432+P|0]|0)+D|0;W=y>>>0>U>>>0?U:y;c[n>>2]=W;Mb=d[1200920+P|0]|0;Nb=W}if((Mb|0)==0){Ob=0;Pb=Nb}else{W=Y+(Nb>>>3)|0;P=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Nb&7)>>31;W=Nb+1|0;U=y>>>0>W>>>0?W:y;c[n>>2]=U;Ob=(P^Mb)-P|0;Pb=U}c[f+4108+(fa*40|0)+12>>2]=Ob;U=Y+(Pb>>>3)|0;P=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(Pb&7);if((P&-1434451968|0)==0){U=1;W=Pb;z=P;while(1){Qb=z>>>24;_=a[1201432+Qb|0]|0;Rb=_&255;Z=((_&255)>>>0>8>>>0?8:Rb)+W|0;l=y>>>0>Z>>>0;Sb=l?Z:y;if(!(_<<24>>24==9)){K=169;break}_=d[1201688+Qb|0]|U<<4;if(!(_>>>0<134217728>>>0)){Tb=_;break}Z=Y+(Sb>>>3)|0;T=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(Sb&7);if(l){U=_;W=Sb;z=T}else{Tb=_;break}}if((K|0)==169){K=0;Tb=d[1201688+Qb|0]|U<<(Rb-1>>1)}c[n>>2]=Sb;Ub=Tb-1|0;Vb=Sb}else{z=P>>>24;W=(d[1201432+z|0]|0)+Pb|0;D=y>>>0>W>>>0?W:y;c[n>>2]=D;Ub=d[1200920+z|0]|0;Vb=D}if((Ub|0)==0){Wb=0}else{D=Y+(Vb>>>3)|0;z=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(Vb&7)>>31;D=Vb+1|0;c[n>>2]=y>>>0>D>>>0?D:y;Wb=(z^Ub)-z|0}c[f+4108+(fa*40|0)+16>>2]=Wb;z=c[n>>2]|0;D=c[p>>2]|0;W=c[ea>>2]|0;x=W+(z>>>3)|0;v=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7);if((v&-1434451968|0)==0){x=1;_=z;T=v;while(1){Xb=T>>>24;l=a[1201432+Xb|0]|0;Yb=l&255;Z=((l&255)>>>0>8>>>0?8:Yb)+_|0;S=D>>>0>Z>>>0;Zb=S?Z:D;if(!(l<<24>>24==9)){K=178;break}l=d[1201688+Xb|0]|x<<4;if(!(l>>>0<134217728>>>0)){_b=l;break}Z=W+(Zb>>>3)|0;Q=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(Zb&7);if(S){x=l;_=Zb;T=Q}else{_b=l;break}}if((K|0)==178){K=0;_b=d[1201688+Xb|0]|x<<(Yb-1>>1)}c[n>>2]=Zb;$b=_b-1|0;ac=Zb}else{T=v>>>24;_=(d[1201432+T|0]|0)+z|0;y=D>>>0>_>>>0?_:D;c[n>>2]=y;$b=d[1200920+T|0]|0;ac=y}if(($b|0)==0){bc=0;cc=ac}else{y=W+(ac>>>3)|0;T=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(ac&7)>>31;y=ac+1|0;_=D>>>0>y>>>0?y:D;c[n>>2]=_;bc=(T^$b)-T|0;cc=_}c[f+4108+(fa*40|0)+20>>2]=bc;tb=cc;ub=D;vb=W}_=d[vb+(tb>>>3)|0]|0;T=((tb|0)<(ub|0))+tb|0;c[n>>2]=T;if((_&128>>>((tb&7)>>>0)|0)==0){dc=T;ec=ub;fc=vb}else{_=vb+(T>>>3)|0;y=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(T&7);if((y&-1434451968|0)==0){_=1;Y=T;P=y;while(1){gc=P>>>24;U=a[1201432+gc|0]|0;hc=U&255;l=((U&255)>>>0>8>>>0?8:hc)+Y|0;Q=ub>>>0>l>>>0;ic=Q?l:ub;if(!(U<<24>>24==9)){K=190;break}U=d[1201688+gc|0]|_<<4;if(!(U>>>0<134217728>>>0)){jc=U;break}l=vb+(ic>>>3)|0;S=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(ic&7);if(Q){_=U;Y=ic;P=S}else{jc=U;break}}if((K|0)==190){K=0;jc=d[1201688+gc|0]|_<<(hc-1>>1)}c[n>>2]=ic;kc=jc-1|0;lc=ic}else{P=y>>>24;Y=(d[1201432+P|0]|0)+T|0;W=ub>>>0>Y>>>0?Y:ub;c[n>>2]=W;kc=d[1200920+P|0]|0;lc=W}c[f+4108+(fa*40|0)+36>>2]=kc;W=vb+(lc>>>3)|0;P=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(lc&7);if((P&-1434451968|0)==0){W=1;Y=lc;D=P;while(1){mc=D>>>24;z=a[1201432+mc|0]|0;nc=z&255;v=((z&255)>>>0>8>>>0?8:nc)+Y|0;x=ub>>>0>v>>>0;oc=x?v:ub;if(!(z<<24>>24==9)){K=197;break}z=d[1201688+mc|0]|W<<4;if(!(z>>>0<134217728>>>0)){pc=z;break}v=vb+(oc>>>3)|0;U=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(oc&7);if(x){W=z;Y=oc;D=U}else{pc=z;break}}if((K|0)==197){K=0;pc=d[1201688+mc|0]|W<<(nc-1>>1)}c[n>>2]=oc;qc=pc-1|0;rc=oc}else{D=P>>>24;Y=(d[1201432+D|0]|0)+lc|0;T=ub>>>0>Y>>>0?Y:ub;c[n>>2]=T;qc=d[1200920+D|0]|0;rc=T}if((qc|0)==0){sc=0}else{T=vb+(rc>>>3)|0;D=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(rc&7)>>31;T=rc+1|0;c[n>>2]=ub>>>0>T>>>0?T:ub;sc=(D^qc)-D|0}c[f+4108+(fa*40|0)+24>>2]=sc;D=c[n>>2]|0;T=c[p>>2]|0;Y=c[ea>>2]|0;y=Y+(D>>>3)|0;_=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(D&7);if((_&-1434451968|0)==0){y=1;z=D;U=_;while(1){tc=U>>>24;x=a[1201432+tc|0]|0;uc=x&255;v=((x&255)>>>0>8>>>0?8:uc)+z|0;S=T>>>0>v>>>0;vc=S?v:T;if(!(x<<24>>24==9)){K=206;break}x=d[1201688+tc|0]|y<<4;if(!(x>>>0<134217728>>>0)){wc=x;break}v=Y+(vc>>>3)|0;Q=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(vc&7);if(S){y=x;z=vc;U=Q}else{wc=x;break}}if((K|0)==206){K=0;wc=d[1201688+tc|0]|y<<(uc-1>>1)}c[n>>2]=vc;xc=wc-1|0;yc=vc}else{U=_>>>24;z=(d[1201432+U|0]|0)+D|0;P=T>>>0>z>>>0?z:T;c[n>>2]=P;xc=d[1200920+U|0]|0;yc=P}if((xc|0)==0){zc=0;Ac=yc}else{P=Y+(yc>>>3)|0;U=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(yc&7)>>31;P=yc+1|0;z=T>>>0>P>>>0?P:T;c[n>>2]=z;zc=(U^xc)-U|0;Ac=z}c[f+4108+(fa*40|0)+28>>2]=zc;dc=Ac;ec=T;fc=Y}z=fa+1|0;U=c[o>>2]|0;if(z>>>0<U>>>0){fa=z;aa=dc;ca=ec;k=fc}else{Za=dc;_a=ec;$a=fc;ab=U;break}}}k=$a+(Za>>>3)|0;ca=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Za&7);if((ca&-1434451968|0)==0){k=1;aa=Za;fa=ca;while(1){Bc=fa>>>24;u=a[1201432+Bc|0]|0;Cc=u&255;da=((u&255)>>>0>8>>>0?8:Cc)+aa|0;U=_a>>>0>da>>>0;Dc=U?da:_a;if(!(u<<24>>24==9)){K=217;break}u=d[1201688+Bc|0]|k<<4;if(!(u>>>0<134217728>>>0)){Ec=u;break}da=$a+(Dc>>>3)|0;z=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Dc&7);if(U){k=u;aa=Dc;fa=z}else{Ec=u;break}}if((K|0)==217){Ec=d[1201688+Bc|0]|k<<(Cc-1>>1)}c[n>>2]=Dc;Fc=Ec-1|0;Gc=Dc}else{fa=ca>>>24;aa=(d[1201432+fa|0]|0)+Za|0;u=_a>>>0>aa>>>0?aa:_a;c[n>>2]=u;Fc=d[1200920+fa|0]|0;Gc=u}if((Fc|0)!=0){yDb(c[s>>2]|0,16,2139528,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}u=f+4196|0;c[u>>2]=1;fa=f+4190|0;b[fa>>1]=1;aa=f+4192|0;b[aa>>1]=1;z=d[$a+(Gc>>>3)|0]|0;U=((Gc|0)<(_a|0))+Gc|0;c[n>>2]=U;do{if((z&128>>>((Gc&7)>>>0)|0)==0){Hc=U}else{da=$a+(U>>>3)|0;P=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(U&7);if((P&-1434451968|0)==0){da=1;W=U;x=P;while(1){Ic=x>>>24;Q=a[1201432+Ic|0]|0;Jc=Q&255;S=((Q&255)>>>0>8>>>0?8:Jc)+W|0;v=_a>>>0>S>>>0;Kc=v?S:_a;if(!(Q<<24>>24==9)){K=227;break}Q=d[1201688+Ic|0]|da<<4;if(!(Q>>>0<134217728>>>0)){Lc=Q;break}S=$a+(Kc>>>3)|0;l=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Kc&7);if(v){da=Q;W=Kc;x=l}else{Lc=Q;break}}if((K|0)==227){Lc=d[1201688+Ic|0]|da<<(Jc-1>>1)}c[n>>2]=Kc;Mc=Lc-1|0;Nc=Kc}else{x=P>>>24;W=(d[1201432+x|0]|0)+U|0;Y=_a>>>0>W>>>0?W:_a;c[n>>2]=Y;Mc=d[1200920+x|0]|0;Nc=Y}c[u>>2]=Mc;Y=$a+(Nc>>>3)|0;x=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(Nc&7);if((x&-1434451968|0)==0){Y=1;W=Nc;T=x;while(1){Oc=T>>>24;D=a[1201432+Oc|0]|0;Pc=D&255;_=((D&255)>>>0>8>>>0?8:Pc)+W|0;y=_a>>>0>_>>>0;Qc=y?_:_a;if(!(D<<24>>24==9)){K=234;break}D=d[1201688+Oc|0]|Y<<4;if(!(D>>>0<134217728>>>0)){Rc=D;break}_=$a+(Qc>>>3)|0;Q=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Qc&7);if(y){Y=D;W=Qc;T=Q}else{Rc=D;break}}if((K|0)==234){Rc=d[1201688+Oc|0]|Y<<(Pc-1>>1)}c[n>>2]=Qc;Sc=Rc-1|0;Tc=Qc}else{T=x>>>24;W=(d[1201432+T|0]|0)+Nc|0;P=_a>>>0>W>>>0?W:_a;c[n>>2]=P;Sc=d[1200920+T|0]|0;Tc=P}if((Sc|0)==0){Uc=0;Vc=Tc}else{P=$a+(Tc>>>3)|0;T=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Tc&7)>>31;P=Tc+1|0;W=_a>>>0>P>>>0?P:_a;c[n>>2]=W;Uc=(T^Sc)-T&65535;Vc=W}b[fa>>1]=Uc;if((ab|0)!=2){Hc=Vc;break}W=$a+(Vc>>>3)|0;T=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Vc&7);if((T&-1434451968|0)==0){W=1;P=Vc;da=T;while(1){Wc=da>>>24;D=a[1201432+Wc|0]|0;Xc=D&255;Q=((D&255)>>>0>8>>>0?8:Xc)+P|0;y=_a>>>0>Q>>>0;Yc=y?Q:_a;if(!(D<<24>>24==9)){K=244;break}D=d[1201688+Wc|0]|W<<4;if(!(D>>>0<134217728>>>0)){Zc=D;break}Q=$a+(Yc>>>3)|0;_=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(Yc&7);if(y){W=D;P=Yc;da=_}else{Zc=D;break}}if((K|0)==244){Zc=d[1201688+Wc|0]|W<<(Xc-1>>1)}c[n>>2]=Yc;_c=Zc-1|0;$c=Yc}else{da=T>>>24;P=(d[1201432+da|0]|0)+Vc|0;x=_a>>>0>P>>>0?P:_a;c[n>>2]=x;_c=d[1200920+da|0]|0;$c=x}if((_c|0)==0){ad=0;bd=$c}else{x=$a+($c>>>3)|0;da=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<($c&7)>>31;x=$c+1|0;P=_a>>>0>x>>>0?x:_a;c[n>>2]=P;ad=(da^_c)-da&65535;bd=P}b[aa>>1]=ad;Hc=bd}}while(0);aa=f+4216|0;fa=c[aa>>2]|0;u=-Hc&7;if((u|0)==0){cd=Hc}else{U=u+Hc|0;u=_a>>>0>U>>>0?U:_a;c[n>>2]=u;cd=u}u=d[f+1486|0]<<2;U=(((c[f+1416>>2]|0)-1+u|0)>>>0)/(u>>>0)|0;u=f+4208|0;c[u>>2]=U;z=d[f+1487|0]<<2;ca=(((c[f+1420>>2]|0)-1+z|0)>>>0)/(z>>>0)|0;z=f+4212|0;c[z>>2]=ca;k=f+4200|0;c[k>>2]=U<<2;c[f+4204>>2]=ca<<2;ca=j|0;U=$a+(cd>>>3)|0;P=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(cd&7);if((P&-1434451968|0)==0){U=1;da=cd;x=P;while(1){dd=x>>>24;Y=a[1201432+dd|0]|0;ed=Y&255;D=((Y&255)>>>0>8>>>0?8:ed)+da|0;_=_a>>>0>D>>>0;fd=_?D:_a;if(!(Y<<24>>24==9)){K=256;break}Y=d[1201688+dd|0]|U<<4;if(!(Y>>>0<134217728>>>0)){gd=Y;break}D=$a+(fd>>>3)|0;y=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(fd&7);if(_){U=Y;da=fd;x=y}else{gd=Y;break}}if((K|0)==256){gd=d[1201688+dd|0]|U<<(ed-1>>1)}c[n>>2]=fd;hd=gd-1|0}else{x=P>>>24;da=(d[1201432+x|0]|0)+cd|0;c[n>>2]=_a>>>0>da>>>0?da:_a;hd=d[1200920+x|0]|0}dkb(ca,m,hd);x=c[z>>2]|0;e:do{if((x|0)>0){da=j+30|0;Y=j|0;y=j+4|0;_=j+6|0;D=j+8|0;Q=j+12|0;l=j+16|0;v=0;S=fa;Z=c[u>>2]|0;V=x;f:while(1){if((Z|0)>0){N=(v|0)==0;O=0;J=Z;do{L=b[da>>1]|0;G=L&65535;E=c[Y>>2]|0;M=e[y>>1]|0;F=(ba(M,G)|0)>>>16;H=E>>>16>>>0>=F>>>0;if(H){id=E-(F<<16)|0;jd=M-F&65535}else{id=E;jd=F&65535}b[da>>1]=(b[7558224+(G>>>8<<2)+((H&1)<<1)>>1]|0)+L;c[Y>>2]=id;b[y>>1]=jd;L=b[_>>1]|0;if((jd&65535)>>>0<16385>>>0){G=id;F=jd;E=L;do{G=G<<1;F=F<<1;E=E+1&65535;}while((F&65535)>>>0<16385>>>0);c[Y>>2]=G;b[y>>1]=F;b[_>>1]=E;kd=G;ld=E;md=F}else{kd=id;ld=L;md=jd}M=ld<<16>>16;if(ld<<16>>16>-1){I=c[D>>2]|0;C=I+2|0;c[D>>2]=C;A=I;I=(de((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535;A=c[Q>>2]|0;if(C>>>0>A>>>0){c[D>>2]=A;nd=C>>>0>(A+1|0)>>>0?65535:I|255}else{nd=I}I=(nd<<M)+kd|0;c[Y>>2]=I;od=ld-16&65535;pd=I}else{od=ld;pd=kd}b[_>>1]=od;if(H){qd=0}else{I=7;M=1;A=pd;C=md;B=od;while(1){R=M<<1;rd=b[l>>1]|0;sd=rd&65535;td=C&65535;ud=(ba(sd,td)|0)>>>16;vd=A>>>16>>>0>=ud>>>0;wd=vd&1;if(vd){xd=A-(ud<<16)|0;yd=td-ud&65535}else{xd=A;yd=ud&65535}b[l>>1]=(b[7558224+(sd>>>8<<2)+(wd<<1)>>1]|0)+rd;c[Y>>2]=xd;b[y>>1]=yd;if((yd&65535)>>>0<16385>>>0){rd=xd;sd=yd;ud=B;do{rd=rd<<1;sd=sd<<1;ud=ud+1&65535;}while((sd&65535)>>>0<16385>>>0);c[Y>>2]=rd;b[y>>1]=sd;b[_>>1]=ud;zd=rd;Ad=ud;Bd=sd}else{zd=xd;Ad=B;Bd=yd}td=Ad<<16>>16;if(Ad<<16>>16>-1){vd=c[D>>2]|0;Cd=vd+2|0;c[D>>2]=Cd;Dd=vd;vd=(de((d[Dd]|d[Dd+1|0]<<8)<<16>>16|0)|0)&65535;Dd=c[Q>>2]|0;if(Cd>>>0>Dd>>>0){c[D>>2]=Dd;Ed=Cd>>>0>(Dd+1|0)>>>0?65535:vd|255}else{Ed=vd}vd=(Ed<<td)+zd|0;c[Y>>2]=vd;Fd=Ad-16&65535;Gd=vd}else{Fd=Ad;Gd=zd}b[_>>1]=Fd;Hd=wd|R;vd=d[1233616+I|0]|0;td=j+16+(vd<<1)|0;Dd=b[td>>1]|0;Cd=Dd&65535;Id=Bd&65535;Jd=(ba(Cd,Id)|0)>>>16;Kd=Gd>>>16>>>0>=Jd>>>0;if(Kd){Ld=Gd-(Jd<<16)|0;Md=Id-Jd&65535}else{Ld=Gd;Md=Jd&65535}b[td>>1]=(b[7558224+(Cd>>>8<<2)+((Kd&1)<<1)>>1]|0)+Dd;c[Y>>2]=Ld;b[y>>1]=Md;Dd=b[_>>1]|0;if((Md&65535)>>>0<16385>>>0){Cd=Ld;td=Md;Jd=Dd;do{Cd=Cd<<1;td=td<<1;Jd=Jd+1&65535;}while((td&65535)>>>0<16385>>>0);c[Y>>2]=Cd;b[y>>1]=td;b[_>>1]=Jd;Nd=Cd;Od=Jd;Pd=td}else{Nd=Ld;Od=Dd;Pd=Md}R=Od<<16>>16;if(Od<<16>>16>-1){wd=c[D>>2]|0;sd=wd+2|0;c[D>>2]=sd;ud=wd;wd=(de((d[ud]|d[ud+1|0]<<8)<<16>>16|0)|0)&65535;ud=c[Q>>2]|0;if(sd>>>0>ud>>>0){c[D>>2]=ud;Qd=sd>>>0>(ud+1|0)>>>0?65535:wd|255}else{Qd=wd}wd=(Qd<<R)+Nd|0;c[Y>>2]=wd;Rd=Od-16&65535;Sd=wd}else{Rd=Od;Sd=Nd}b[_>>1]=Rd;if(Kd){break}else{I=vd;M=Hd;A=Sd;C=Pd;B=Rd}}B=Hd-1|0;if(B>>>0>2>>>0){pa=-1;break f}else{qd=B}}B=S+O|0;do{if((O|v|0)==0){Td=0}else{if(N){Td=d[S+(O-1)|0]|0;break}if((O|0)==0){Td=d[S+(-J|0)|0]|0;break}else{Td=d[562288+((d[S+(O-J)|0]|0)+(d[S+(O-1)|0]|0)+(d[S+(O+~J)|0]|0))|0]|0;break}}}while(0);a[B]=((Td+qd|0)>>>0)%3|0;O=O+1|0;J=c[u>>2]|0;}while((O|0)<(J|0));Ud=J;Vd=c[z>>2]|0}else{Ud=Z;Vd=V}O=v+1|0;if((O|0)<(Vd|0)){v=O;S=S+Ud|0;Z=Ud;V=Vd}else{break e}}i=g;return pa|0}}while(0);x=c[n>>2]|0;fa=c[p>>2]|0;P=c[r>>2]|0;U=P+(x>>>3)|0;V=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(x&7);if((V&-1434451968|0)==0){U=1;Z=x;S=V;while(1){Wd=S>>>24;v=a[1201432+Wd|0]|0;Xd=v&255;_=((v&255)>>>0>8>>>0?8:Xd)+Z|0;Y=fa>>>0>_>>>0;Yd=Y?_:fa;if(!(v<<24>>24==9)){K=306;break}v=d[1201688+Wd|0]|U<<4;if(!(v>>>0<134217728>>>0)){Zd=v;break}_=P+(Yd>>>3)|0;D=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Yd&7);if(Y){U=v;Z=Yd;S=D}else{Zd=v;break}}if((K|0)==306){Zd=d[1201688+Wd|0]|U<<(Xd-1>>1)}c[n>>2]=Yd;_d=Zd-1|0}else{S=V>>>24;Z=(d[1201432+S|0]|0)+x|0;c[n>>2]=fa>>>0>Z>>>0?Z:fa;_d=d[1200920+S|0]|0}dkb(ca,m,_d);if((c[o>>2]|0)>0){S=0;while(1){Z=S<<1;P=j+((Z+4|0)*60|0)|0;v=c[n>>2]|0;D=c[p>>2]|0;Y=c[r>>2]|0;_=Y+(v>>>3)|0;Q=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(v&7);if((Q&-1434451968|0)==0){_=1;y=v;l=Q;while(1){$d=l>>>24;da=a[1201432+$d|0]|0;ae=da&255;T=((da&255)>>>0>8>>>0?8:ae)+y|0;W=D>>>0>T>>>0;be=W?T:D;if(!(da<<24>>24==9)){K=314;break}da=d[1201688+$d|0]|_<<4;if(!(da>>>0<134217728>>>0)){ce=da;break}T=Y+(be>>>3)|0;O=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(be&7);if(W){_=da;y=be;l=O}else{ce=da;break}}if((K|0)==314){K=0;ce=d[1201688+$d|0]|_<<(ae-1>>1)}c[n>>2]=be;ee=ce-1|0}else{l=Q>>>24;y=(d[1201432+l|0]|0)+v|0;c[n>>2]=D>>>0>y>>>0?y:D;ee=d[1200920+l|0]|0}dkb(P,m,ee);l=j+((Z+5|0)*60|0)|0;y=c[n>>2]|0;Y=c[p>>2]|0;da=c[r>>2]|0;O=da+(y>>>3)|0;W=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(y&7);if((W&-1434451968|0)==0){O=1;T=y;N=W;while(1){ge=N>>>24;C=a[1201432+ge|0]|0;he=C&255;A=((C&255)>>>0>8>>>0?8:he)+T|0;M=Y>>>0>A>>>0;ie=M?A:Y;if(!(C<<24>>24==9)){K=321;break}C=d[1201688+ge|0]|O<<4;if(!(C>>>0<134217728>>>0)){je=C;break}A=da+(ie>>>3)|0;I=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(ie&7);if(M){O=C;T=ie;N=I}else{je=C;break}}if((K|0)==321){K=0;je=d[1201688+ge|0]|O<<(he-1>>1)}c[n>>2]=ie;ke=je-1|0}else{N=W>>>24;T=(d[1201432+N|0]|0)+y|0;c[n>>2]=Y>>>0>T>>>0?T:Y;ke=d[1200920+N|0]|0}dkb(l,m,ke);N=S+1|0;if((N|0)<(c[o>>2]|0)){S=N}else{le=0;break}}}else{le=0}do{le=le+1|0;S=j+(le*60|0)|0;ca=c[n>>2]|0;fa=c[p>>2]|0;x=c[r>>2]|0;V=x+(ca>>>3)|0;U=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(ca&7);if((U&-1434451968|0)==0){V=1;N=ca;T=U;while(1){me=T>>>24;da=a[1201432+me|0]|0;ne=da&255;Z=((da&255)>>>0>8>>>0?8:ne)+N|0;P=fa>>>0>Z>>>0;oe=P?Z:fa;if(!(da<<24>>24==9)){K=331;break}da=d[1201688+me|0]|V<<4;if(!(da>>>0<134217728>>>0)){pe=da;break}Z=x+(oe>>>3)|0;D=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(oe&7);if(P){V=da;N=oe;T=D}else{pe=da;break}}if((K|0)==331){K=0;pe=d[1201688+me|0]|V<<(ne-1>>1)}c[n>>2]=oe;qe=pe-1|0}else{T=U>>>24;N=(d[1201432+T|0]|0)+ca|0;c[n>>2]=fa>>>0>N>>>0?N:fa;qe=d[1200920+T|0]|0}dkb(S,m,qe);}while((le|0)<3);T=c[z>>2]|0;if((T|0)<=0){break d}N=f+4220|0;x=j+16|0;l=j|0;Y=j+4|0;y=j+6|0;W=j+8|0;O=j+12|0;da=j+18|0;D=h|0;P=h+4|0;Z=h+8|0;v=j+20|0;Q=0;_=c[u>>2]|0;C=T;while(1){if((_|0)>0){T=Q<<2;I=0;M=_;while(1){A=(ba(M,Q)|0)+I|0;H=d[(c[aa>>2]|0)+A|0]|0;A=1<<H;L=4>>>(H>>>0);if((A|0)>0){H=I<<2;F=(L|0)>1;E=0;do{G=(ba(E,L)|0)+T|0;wd=(G|0)==0;R=0;do{ud=(ba(R,L)|0)+H|0;sd=c[k>>2]|0;rd=(ba(sd,G)|0)+ud|0;Id=c[N>>2]|0;re=Id+(rd*10|0)|0;se=(ud|G|0)==0;do{if(se){te=0}else{if(wd){te=a[Id+((rd-1|0)*10|0)+8|0]&1;break}if((ud|0)==0){te=a[Id+((rd-sd|0)*10|0)+8|0]&1;break}else{te=((a[Id+((rd-sd|0)*10|0)+8|0]&1)+(a[Id+((rd-1|0)*10|0)+8|0]&1)+(a[Id+((rd+~sd|0)*10|0)+8|0]&1)|0)>>>1&1;break}}}while(0);vd=Id+(rd*10|0)+8|0;a[vd]=te;Kd=b[x>>1]|0;Dd=Kd&65535;td=c[l>>2]|0;Jd=e[Y>>1]|0;Cd=(ba(Jd,Dd)|0)>>>16;ue=td>>>16>>>0>=Cd>>>0;ve=ue&1;if(ue){we=td-(Cd<<16)|0;xe=Jd-Cd&65535}else{we=td;xe=Cd&65535}b[x>>1]=(b[7558224+(Dd>>>8<<2)+(ve<<1)>>1]|0)+Kd;c[l>>2]=we;b[Y>>1]=xe;Kd=b[y>>1]|0;if((xe&65535)>>>0<16385>>>0){Dd=we;Cd=xe;td=Kd;do{Dd=Dd<<1;Cd=Cd<<1;td=td+1&65535;}while((Cd&65535)>>>0<16385>>>0);c[l>>2]=Dd;b[Y>>1]=Cd;b[y>>1]=td;ye=Dd;ze=td}else{ye=we;ze=Kd}Jd=ze<<16>>16;if(ze<<16>>16>-1){ue=c[W>>2]|0;Ae=ue+2|0;c[W>>2]=Ae;Be=ue;ue=(de((d[Be]|d[Be+1|0]<<8)<<16>>16|0)|0)&65535;Be=c[O>>2]|0;if(Ae>>>0>Be>>>0){c[W>>2]=Be;Ce=Ae>>>0>(Be+1|0)>>>0?65535:ue|255}else{Ce=ue}c[l>>2]=(Ce<<Jd)+ye;De=ze-16&65535}else{De=ze}b[y>>1]=De;Jd=d[vd]^ve;ue=Jd&255;a[vd]=ue;if((c[o>>2]|0)==2){do{if(se){Ee=0}else{if(wd){Ee=a[Id+((rd-1|0)*10|0)+8|0]&2;break}if((ud|0)==0){Ee=a[Id+((rd-sd|0)*10|0)+8|0]&2;break}else{Ee=((a[Id+((rd-sd|0)*10|0)+8|0]&2)+(a[Id+((rd-1|0)*10|0)+8|0]&2)+(a[Id+((rd+~sd|0)*10|0)+8|0]&2)|0)>>>1&2;break}}}while(0);a[vd]=Ee|Jd;ve=b[da>>1]|0;Kd=ve&65535;td=c[l>>2]|0;Dd=e[Y>>1]|0;Cd=(ba(Dd,Kd)|0)>>>16;Be=td>>>16>>>0>=Cd>>>0;Ae=Be&1;if(Be){Fe=td-(Cd<<16)|0;Ge=Dd-Cd&65535}else{Fe=td;Ge=Cd&65535}b[da>>1]=(b[7558224+(Kd>>>8<<2)+(Ae<<1)>>1]|0)+ve;c[l>>2]=Fe;b[Y>>1]=Ge;ve=b[y>>1]|0;if((Ge&65535)>>>0<16385>>>0){Kd=Fe;Cd=Ge;td=ve;do{Kd=Kd<<1;Cd=Cd<<1;td=td+1&65535;}while((Cd&65535)>>>0<16385>>>0);c[l>>2]=Kd;b[Y>>1]=Cd;b[y>>1]=td;He=Kd;Ie=td}else{He=Fe;Ie=ve}Jd=Ie<<16>>16;if(Ie<<16>>16>-1){Dd=c[W>>2]|0;Be=Dd+2|0;c[W>>2]=Be;Je=Dd;Dd=(de((d[Je]|d[Je+1|0]<<8)<<16>>16|0)|0)&65535;Je=c[O>>2]|0;if(Be>>>0>Je>>>0){c[W>>2]=Je;Ke=Be>>>0>(Je+1|0)>>>0?65535:Dd|255}else{Ke=Dd}c[l>>2]=(Ke<<Jd)+He;Le=Ie-16&65535}else{Le=Ie}b[y>>1]=Le;Jd=(d[vd]^Ae<<1)&255;a[vd]=Jd;Me=Jd}else{Me=ue}g:do{if(Me<<24>>24==0){TGb(re|0,0,6)|0;Jd=(ud|0)!=0;do{if(Jd){Dd=rd-1|0;if(!((a[Id+(Dd*10|0)+8|0]&3)==0)){Ne=0;Oe=0;Pe=0;Qe=0;break}Je=b[Id+(Dd*10|0)>>1]|0;b[re>>1]=Je;Be=b[Id+(Dd*10|0)+2>>1]|0;b[Id+(rd*10|0)+2>>1]=Be;Re=b[Id+(Dd*10|0)+4>>1]|0;b[Id+(rd*10|0)+4>>1]=Re;Ne=1;Oe=Je;Pe=Be;Qe=Re}else{Ne=0;Oe=0;Pe=0;Qe=0}}while(0);do{if(wd){Se=Ne;Te=Oe;Ue=Pe;Ve=Qe}else{Re=rd-sd|0;if((a[Id+(Re*10|0)+8|0]&3)==0){Be=(b[Id+(Re*10|0)>>1]|0)+Oe&65535;b[re>>1]=Be;Je=(b[Id+(Re*10|0)+2>>1]|0)+Pe&65535;b[Id+(rd*10|0)+2>>1]=Je;Dd=(b[Id+(Re*10|0)+4>>1]|0)+Qe&65535;b[Id+(rd*10|0)+4>>1]=Dd;We=Ne+1|0;Xe=Be;Ye=Je;Ze=Dd}else{We=Ne;Xe=Oe;Ye=Pe;Ze=Qe}if(!Jd){Se=We;Te=Xe;Ue=Ye;Ve=Ze;break}Dd=rd+~sd|0;if(!((a[Id+(Dd*10|0)+8|0]&3)==0)){Se=We;Te=Xe;Ue=Ye;Ve=Ze;break}Je=(b[Id+(Dd*10|0)>>1]|0)+Xe&65535;b[re>>1]=Je;Be=(b[Id+(Dd*10|0)+2>>1]|0)+Ye&65535;b[Id+(rd*10|0)+2>>1]=Be;Re=(b[Id+(Dd*10|0)+4>>1]|0)+Ze&65535;b[Id+(rd*10|0)+4>>1]=Re;Se=We+1|0;Te=Je;Ue=Be;Ve=Re}}while(0);if((Se|0)==3){b[re>>1]=(((Te<<16>>16)*21845|0)+32767|0)>>>16;b[Id+(rd*10|0)+2>>1]=(((Ue<<16>>16)*21845|0)+32767|0)>>>16;b[Id+(rd*10|0)+4>>1]=(((Ve<<16>>16)*21845|0)+32767|0)>>>16}else if((Se|0)==2){b[re>>1]=((Te<<16>>16)+1|0)>>>1;b[Id+(rd*10|0)+2>>1]=((Ue<<16>>16)+1|0)>>>1;b[Id+(rd*10|0)+4>>1]=((Ve<<16>>16)+1|0)>>>1}Jd=re;Re=0;while(1){Be=Re+1|0;Je=j+(Be*60|0)+30|0;Dd=b[Je>>1]|0;_e=Dd&65535;$e=j+(Be*60|0)|0;af=c[$e>>2]|0;bf=j+(Be*60|0)+4|0;cf=e[bf>>1]|0;df=(ba(cf,_e)|0)>>>16;ef=af>>>16>>>0>=df>>>0;if(ef){ff=af-(df<<16)|0;gf=cf-df&65535}else{ff=af;gf=df&65535}b[Je>>1]=(b[7558224+(_e>>>8<<2)+((ef&1)<<1)>>1]|0)+Dd;c[$e>>2]=ff;b[bf>>1]=gf;Dd=j+(Be*60|0)+6|0;_e=b[Dd>>1]|0;if((gf&65535)>>>0<16385>>>0){Je=ff;df=gf;af=_e;do{Je=Je<<1;df=df<<1;af=af+1&65535;}while((df&65535)>>>0<16385>>>0);c[$e>>2]=Je;b[bf>>1]=df;b[Dd>>1]=af;hf=Je;jf=af;kf=df}else{hf=ff;jf=_e;kf=gf}cf=jf<<16>>16;if(jf<<16>>16>-1){lf=j+(Be*60|0)+8|0;mf=c[lf>>2]|0;nf=mf+2|0;c[lf>>2]=nf;of=mf;mf=(de((d[of]|d[of+1|0]<<8)<<16>>16|0)|0)&65535;of=c[j+(Be*60|0)+12>>2]|0;if(nf>>>0>of>>>0){c[lf>>2]=of;pf=nf>>>0>(of+1|0)>>>0?65535:mf|255}else{pf=mf}mf=(pf<<cf)+hf|0;c[$e>>2]=mf;qf=jf-16&65535;rf=mf}else{qf=jf;rf=hf}b[Dd>>1]=qf;do{if(ef){sf=0}else{mf=j+(Be*60|0)+16|0;cf=j+(Be*60|0)+8|0;of=j+(Be*60|0)+12|0;nf=7;lf=1;tf=rf;uf=kf;vf=qf;while(1){wf=lf<<1;xf=b[mf>>1]|0;yf=xf&65535;zf=uf&65535;Af=(ba(yf,zf)|0)>>>16;Bf=tf>>>16>>>0>=Af>>>0;Cf=Bf&1;if(Bf){Df=tf-(Af<<16)|0;Ef=zf-Af&65535}else{Df=tf;Ef=Af&65535}b[mf>>1]=(b[7558224+(yf>>>8<<2)+(Cf<<1)>>1]|0)+xf;c[$e>>2]=Df;b[bf>>1]=Ef;if((Ef&65535)>>>0<16385>>>0){xf=Df;yf=Ef;Af=vf;do{xf=xf<<1;yf=yf<<1;Af=Af+1&65535;}while((yf&65535)>>>0<16385>>>0);c[$e>>2]=xf;b[bf>>1]=yf;b[Dd>>1]=Af;Ff=xf;Gf=Af;Hf=yf}else{Ff=Df;Gf=vf;Hf=Ef}zf=Gf<<16>>16;if(Gf<<16>>16>-1){Bf=c[cf>>2]|0;If=Bf+2|0;c[cf>>2]=If;Jf=Bf;Bf=(de((d[Jf]|d[Jf+1|0]<<8)<<16>>16|0)|0)&65535;Jf=c[of>>2]|0;if(If>>>0>Jf>>>0){c[cf>>2]=Jf;Kf=If>>>0>(Jf+1|0)>>>0?65535:Bf|255}else{Kf=Bf}Bf=(Kf<<zf)+Ff|0;c[$e>>2]=Bf;Lf=Gf-16&65535;Mf=Bf}else{Lf=Gf;Mf=Ff}b[Dd>>1]=Lf;Nf=Cf|wf;Bf=d[1233616+nf|0]|0;zf=j+(Be*60|0)+16+(Bf<<1)|0;Jf=b[zf>>1]|0;If=Jf&65535;Of=Hf&65535;Pf=(ba(If,Of)|0)>>>16;Qf=Mf>>>16>>>0>=Pf>>>0;if(Qf){Rf=Mf-(Pf<<16)|0;Sf=Of-Pf&65535}else{Rf=Mf;Sf=Pf&65535}b[zf>>1]=(b[7558224+(If>>>8<<2)+((Qf&1)<<1)>>1]|0)+Jf;c[$e>>2]=Rf;b[bf>>1]=Sf;Jf=b[Dd>>1]|0;if((Sf&65535)>>>0<16385>>>0){If=Rf;zf=Sf;Pf=Jf;do{If=If<<1;zf=zf<<1;Pf=Pf+1&65535;}while((zf&65535)>>>0<16385>>>0);c[$e>>2]=If;b[bf>>1]=zf;b[Dd>>1]=Pf;Tf=If;Uf=Pf;Vf=zf}else{Tf=Rf;Uf=Jf;Vf=Sf}wf=Uf<<16>>16;if(Uf<<16>>16>-1){Cf=c[cf>>2]|0;yf=Cf+2|0;c[cf>>2]=yf;Af=Cf;Cf=(de((d[Af]|d[Af+1|0]<<8)<<16>>16|0)|0)&65535;Af=c[of>>2]|0;if(yf>>>0>Af>>>0){c[cf>>2]=Af;Wf=yf>>>0>(Af+1|0)>>>0?65535:Cf|255}else{Wf=Cf}Cf=(Wf<<wf)+Tf|0;c[$e>>2]=Cf;Xf=Uf-16&65535;Yf=Cf}else{Xf=Uf;Yf=Tf}b[Dd>>1]=Xf;if(Qf){break}else{nf=Bf;lf=Nf;tf=Yf;uf=Vf;vf=Xf}}vf=Nf-1|0;if((vf|0)==0){sf=0;break}uf=j+(Be*60|0)+18|0;tf=b[uf>>1]|0;lf=tf&65535;nf=Vf&65535;mf=(ba(lf,nf)|0)>>>16;Cf=Yf>>>16>>>0>=mf>>>0;if(Cf){Zf=Yf-(mf<<16)|0;_f=nf-mf&65535}else{Zf=Yf;_f=mf&65535}b[uf>>1]=(b[7558224+(lf>>>8<<2)+((Cf&1)<<1)>>1]|0)+tf;c[$e>>2]=Zf;b[bf>>1]=_f;if((_f&65535)>>>0<16385>>>0){tf=Zf;lf=_f;uf=Xf;do{tf=tf<<1;lf=lf<<1;uf=uf+1&65535;}while((lf&65535)>>>0<16385>>>0);c[$e>>2]=tf;b[bf>>1]=lf;b[Dd>>1]=uf;$f=tf;ag=uf}else{$f=Zf;ag=Xf}mf=ag<<16>>16;if(ag<<16>>16>-1){nf=c[cf>>2]|0;wf=nf+2|0;c[cf>>2]=wf;Af=nf;nf=(de((d[Af]|d[Af+1|0]<<8)<<16>>16|0)|0)&65535;Af=c[of>>2]|0;if(wf>>>0>Af>>>0){c[cf>>2]=Af;bg=wf>>>0>(Af+1|0)>>>0?65535:nf|255}else{bg=nf}c[$e>>2]=(bg<<mf)+$f;cg=ag-16&65535}else{cg=ag}b[Dd>>1]=cg;sf=Cf?1-Nf|0:vf}}while(0);Dd=Jd+(Re<<1)|0;b[Dd>>1]=(e[Dd>>1]|0)+sf;if((Be|0)<3){Re=Be}else{break}}}else{if((c[$>>2]|0)==0){dg=Me}else{do{if(se){eg=0}else{if(wd){eg=a[Id+((rd-1|0)*10|0)+8|0]&4;break}if((ud|0)==0){eg=a[Id+((rd-sd|0)*10|0)+8|0]&4;break}else{eg=((a[Id+((rd-sd|0)*10|0)+8|0]&4)+(a[Id+((rd-1|0)*10|0)+8|0]&4)+(a[Id+((rd+~sd|0)*10|0)+8|0]&4)|0)>>>1&4;break}}}while(0);a[vd]=eg|Me&255;Re=b[v>>1]|0;Jd=Re&65535;Dd=c[l>>2]|0;$e=e[Y>>1]|0;bf=(ba($e,Jd)|0)>>>16;ef=Dd>>>16>>>0>=bf>>>0;_e=ef&1;if(ef){fg=Dd-(bf<<16)|0;gg=$e-bf&65535}else{fg=Dd;gg=bf&65535}b[v>>1]=(b[7558224+(Jd>>>8<<2)+(_e<<1)>>1]|0)+Re;c[l>>2]=fg;b[Y>>1]=gg;Re=b[y>>1]|0;if((gg&65535)>>>0<16385>>>0){Jd=fg;bf=gg;Dd=Re;do{Jd=Jd<<1;bf=bf<<1;Dd=Dd+1&65535;}while((bf&65535)>>>0<16385>>>0);c[l>>2]=Jd;b[Y>>1]=bf;b[y>>1]=Dd;hg=Jd;ig=Dd}else{hg=fg;ig=Re}$e=ig<<16>>16;if(ig<<16>>16>-1){ef=c[W>>2]|0;df=ef+2|0;c[W>>2]=df;af=ef;ef=(de((d[af]|d[af+1|0]<<8)<<16>>16|0)|0)&65535;af=c[O>>2]|0;if(df>>>0>af>>>0){c[W>>2]=af;jg=df>>>0>(af+1|0)>>>0?65535:ef|255}else{jg=ef}c[l>>2]=(jg<<$e)+hg;kg=ig-16&65535}else{kg=ig}b[y>>1]=kg;$e=(d[vd]^_e<<2)&255;a[vd]=$e;dg=$e}$e=c[o>>2]|0;if(($e|0)<=0){break}ef=(ud|0)!=0;af=rd-1|0;df=Id+(af*10|0)+8|0;Je=rd-sd|0;mf=Id+(Je*10|0)+8|0;nf=rd+~sd|0;Af=Id+(nf*10|0)+8|0;wf=0;yf=dg;while(1){xf=yf&255;Of=wf+1|0;do{if((Of&xf|0)!=0){if((xf&4|0)!=0){lg=c[f+4108+(wf*40|0)+32>>2]|0;mg=c[f+4108+(wf*40|0)+36>>2]|0;ng=ba(c[f+4108+(wf*40|0)+24>>2]|0,ud)|0;og=(1<<mg)-ng-(ba(c[f+4108+(wf*40|0)+28>>2]|0,G)|0)|0;ng=ba(c[f+4108+(wf*40|0)+8>>2]|0,ud)|0;pg=(ba(c[f+4108+(wf*40|0)+12>>2]|0,G)|0)+ng|0;ng=ba(pg+(c[f+4108+(wf*40|0)>>2]<<lg)|0,og)|0;pg=ba(c[f+4108+(wf*40|0)+16>>2]|0,ud)|0;qg=(ba(c[f+4108+(wf*40|0)+20>>2]|0,G)|0)+pg|0;pg=ba(qg+(c[f+4108+(wf*40|0)+4>>2]<<lg)|0,og)|0;og=mg+lg|0;lg=1<<og;b[Id+(rd*10|0)+(wf<<2)>>1]=ng+lg>>og;b[Id+(rd*10|0)+(wf<<2)+2>>1]=pg+lg>>og;break}og=Of|4;do{if(ef){if((d[df]&og|0)!=(Of|0)){rg=0;break}c[D>>2]=Id+(af*10|0)+(wf<<2);rg=1}else{rg=0}}while(0);do{if(wd){sg=rg}else{if((d[mf]&og|0)==(Of|0)){c[h+(rg<<2)>>2]=Id+(Je*10|0)+(wf<<2);tg=rg+1|0}else{tg=rg}if(!ef){sg=tg;break}if((d[Af]&og|0)!=(Of|0)){sg=tg;break}c[h+(tg<<2)>>2]=Id+(nf*10|0)+(wf<<2);sg=tg+1|0}}while(0);if((sg|0)==0){b[Id+(rd*10|0)+(wf<<2)>>1]=0;b[Id+(rd*10|0)+(wf<<2)+2>>1]=0}else if((sg|0)==1){og=c[D>>2]|0;b[Id+(rd*10|0)+(wf<<2)>>1]=b[og>>1]|0;b[Id+(rd*10|0)+(wf<<2)+2>>1]=b[og+2>>1]|0}else if((sg|0)==2){og=c[D>>2]|0;vf=c[P>>2]|0;b[Id+(rd*10|0)+(wf<<2)>>1]=((b[og>>1]|0)+1+(b[vf>>1]|0)|0)>>>1;b[Id+(rd*10|0)+(wf<<2)+2>>1]=((b[og+2>>1]|0)+1+(b[vf+2>>1]|0)|0)>>>1}else if((sg|0)==3){vf=c[D>>2]|0;og=b[vf>>1]|0;Cf=c[P>>2]|0;cf=b[Cf>>1]|0;of=c[Z>>2]|0;uf=b[of>>1]|0;do{if(og<<16>>16>cf<<16>>16){if(!(uf<<16>>16>cf<<16>>16)){ug=cf;break}ug=uf<<16>>16>og<<16>>16?og:uf}else{if(!(cf<<16>>16>uf<<16>>16)){ug=cf;break}ug=uf<<16>>16>og<<16>>16?uf:og}}while(0);b[Id+(rd*10|0)+(wf<<2)>>1]=ug;og=b[vf+2>>1]|0;uf=b[Cf+2>>1]|0;cf=b[of+2>>1]|0;do{if(og<<16>>16>uf<<16>>16){if(!(cf<<16>>16>uf<<16>>16)){vg=uf;break}vg=cf<<16>>16>og<<16>>16?og:cf}else{if(!(uf<<16>>16>cf<<16>>16)){vg=uf;break}vg=cf<<16>>16>og<<16>>16?cf:og}}while(0);b[Id+(rd*10|0)+(wf<<2)+2>>1]=vg}og=wf<<1;cf=og+4|0;uf=j+(cf*60|0)+24|0;of=b[uf>>1]|0;Cf=of&65535;vf=j+(cf*60|0)|0;tf=c[vf>>2]|0;lf=j+(cf*60|0)+4|0;lg=e[lf>>1]|0;pg=(ba(lg,Cf)|0)>>>16;ng=tf>>>16>>>0>=pg>>>0;if(ng){wg=tf-(pg<<16)|0;xg=lg-pg&65535}else{wg=tf;xg=pg&65535}b[uf>>1]=(b[7558224+(Cf>>>8<<2)+((ng&1)<<1)>>1]|0)+of;c[vf>>2]=wg;b[lf>>1]=xg;of=j+(cf*60|0)+6|0;Cf=b[of>>1]|0;if((xg&65535)>>>0<16385>>>0){uf=wg;pg=xg;tf=Cf;do{uf=uf<<1;pg=pg<<1;tf=tf+1&65535;}while((pg&65535)>>>0<16385>>>0);c[vf>>2]=uf;b[lf>>1]=pg;b[of>>1]=tf;yg=uf;zg=tf;Ag=pg}else{yg=wg;zg=Cf;Ag=xg}lg=zg<<16>>16;if(zg<<16>>16>-1){mg=j+(cf*60|0)+8|0;qg=c[mg>>2]|0;Bg=qg+2|0;c[mg>>2]=Bg;Cg=qg;qg=(de((d[Cg]|d[Cg+1|0]<<8)<<16>>16|0)|0)&65535;Cg=c[j+(cf*60|0)+12>>2]|0;if(Bg>>>0>Cg>>>0){c[mg>>2]=Cg;Dg=Bg>>>0>(Cg+1|0)>>>0?65535:qg|255}else{Dg=qg}qg=(Dg<<lg)+yg|0;c[vf>>2]=qg;Eg=zg-16&65535;Fg=qg}else{Eg=zg;Fg=yg}b[of>>1]=Eg;do{if(ng){Gg=0}else{qg=j+(cf*60|0)+16|0;lg=j+(cf*60|0)+8|0;Cg=j+(cf*60|0)+12|0;Bg=4;mg=1;Hg=Fg;Ig=Ag;Jg=Eg;while(1){Kg=mg<<1;Lg=b[qg>>1]|0;Mg=Lg&65535;Ng=Ig&65535;Og=(ba(Mg,Ng)|0)>>>16;Pg=Hg>>>16>>>0>=Og>>>0;Qg=Pg&1;if(Pg){Rg=Hg-(Og<<16)|0;Sg=Ng-Og&65535}else{Rg=Hg;Sg=Og&65535}b[qg>>1]=(b[7558224+(Mg>>>8<<2)+(Qg<<1)>>1]|0)+Lg;c[vf>>2]=Rg;b[lf>>1]=Sg;if((Sg&65535)>>>0<16385>>>0){Lg=Rg;Mg=Sg;Og=Jg;do{Lg=Lg<<1;Mg=Mg<<1;Og=Og+1&65535;}while((Mg&65535)>>>0<16385>>>0);c[vf>>2]=Lg;b[lf>>1]=Mg;b[of>>1]=Og;Tg=Lg;Ug=Og;Vg=Mg}else{Tg=Rg;Ug=Jg;Vg=Sg}Ng=Ug<<16>>16;if(Ug<<16>>16>-1){Pg=c[lg>>2]|0;Wg=Pg+2|0;c[lg>>2]=Wg;Xg=Pg;Pg=(de((d[Xg]|d[Xg+1|0]<<8)<<16>>16|0)|0)&65535;Xg=c[Cg>>2]|0;if(Wg>>>0>Xg>>>0){c[lg>>2]=Xg;Yg=Wg>>>0>(Xg+1|0)>>>0?65535:Pg|255}else{Yg=Pg}Pg=(Yg<<Ng)+Tg|0;c[vf>>2]=Pg;Zg=Ug-16&65535;_g=Pg}else{Zg=Ug;_g=Tg}b[of>>1]=Zg;$g=Qg|Kg;Pg=d[1233616+Bg|0]|0;Ng=j+(cf*60|0)+16+(Pg<<1)|0;Xg=b[Ng>>1]|0;Wg=Xg&65535;ah=Vg&65535;bh=(ba(Wg,ah)|0)>>>16;ch=_g>>>16>>>0>=bh>>>0;if(ch){dh=_g-(bh<<16)|0;eh=ah-bh&65535}else{dh=_g;eh=bh&65535}b[Ng>>1]=(b[7558224+(Wg>>>8<<2)+((ch&1)<<1)>>1]|0)+Xg;c[vf>>2]=dh;b[lf>>1]=eh;Xg=b[of>>1]|0;if((eh&65535)>>>0<16385>>>0){Wg=dh;Ng=eh;bh=Xg;do{Wg=Wg<<1;Ng=Ng<<1;bh=bh+1&65535;}while((Ng&65535)>>>0<16385>>>0);c[vf>>2]=Wg;b[lf>>1]=Ng;b[of>>1]=bh;fh=Wg;gh=bh;hh=Ng}else{fh=dh;gh=Xg;hh=eh}Kg=gh<<16>>16;if(gh<<16>>16>-1){Qg=c[lg>>2]|0;Mg=Qg+2|0;c[lg>>2]=Mg;Og=Qg;Qg=(de((d[Og]|d[Og+1|0]<<8)<<16>>16|0)|0)&65535;Og=c[Cg>>2]|0;if(Mg>>>0>Og>>>0){c[lg>>2]=Og;ih=Mg>>>0>(Og+1|0)>>>0?65535:Qg|255}else{ih=Qg}Qg=(ih<<Kg)+fh|0;c[vf>>2]=Qg;jh=gh-16&65535;kh=Qg}else{jh=gh;kh=fh}b[of>>1]=jh;if(ch){break}else{Bg=Pg;mg=$g;Hg=kh;Ig=hh;Jg=jh}}Jg=$g-1|0;if((Jg|0)==0){Gg=0;break}Ig=j+(cf*60|0)+18|0;Hg=b[Ig>>1]|0;mg=Hg&65535;Bg=hh&65535;qg=(ba(mg,Bg)|0)>>>16;Bf=kh>>>16>>>0>=qg>>>0;if(Bf){lh=kh-(qg<<16)|0;mh=Bg-qg&65535}else{lh=kh;mh=qg&65535}b[Ig>>1]=(b[7558224+(mg>>>8<<2)+((Bf&1)<<1)>>1]|0)+Hg;c[vf>>2]=lh;b[lf>>1]=mh;if((mh&65535)>>>0<16385>>>0){Hg=lh;mg=mh;Ig=jh;do{Hg=Hg<<1;mg=mg<<1;Ig=Ig+1&65535;}while((mg&65535)>>>0<16385>>>0);c[vf>>2]=Hg;b[lf>>1]=mg;b[of>>1]=Ig;nh=Hg;oh=Ig}else{nh=lh;oh=jh}qg=oh<<16>>16;if(oh<<16>>16>-1){Bg=c[lg>>2]|0;Qf=Bg+2|0;c[lg>>2]=Qf;Jf=Bg;Bg=(de((d[Jf]|d[Jf+1|0]<<8)<<16>>16|0)|0)&65535;Jf=c[Cg>>2]|0;if(Qf>>>0>Jf>>>0){c[lg>>2]=Jf;ph=Qf>>>0>(Jf+1|0)>>>0?65535:Bg|255}else{ph=Bg}c[vf>>2]=(ph<<qg)+nh;qh=oh-16&65535}else{qh=oh}b[of>>1]=qh;Gg=Bf?1-$g|0:Jg}}while(0);of=Id+(rd*10|0)+(wf<<2)|0;b[of>>1]=(e[of>>1]|0)+Gg;of=og+5|0;vf=j+(of*60|0)+24|0;lf=b[vf>>1]|0;cf=lf&65535;ng=j+(of*60|0)|0;Cf=c[ng>>2]|0;pg=j+(of*60|0)+4|0;tf=e[pg>>1]|0;uf=(ba(tf,cf)|0)>>>16;qg=Cf>>>16>>>0>=uf>>>0;if(qg){rh=Cf-(uf<<16)|0;sh=tf-uf&65535}else{rh=Cf;sh=uf&65535}b[vf>>1]=(b[7558224+(cf>>>8<<2)+((qg&1)<<1)>>1]|0)+lf;c[ng>>2]=rh;b[pg>>1]=sh;lf=j+(of*60|0)+6|0;cf=b[lf>>1]|0;if((sh&65535)>>>0<16385>>>0){vf=rh;uf=sh;Cf=cf;do{vf=vf<<1;uf=uf<<1;Cf=Cf+1&65535;}while((uf&65535)>>>0<16385>>>0);c[ng>>2]=vf;b[pg>>1]=uf;b[lf>>1]=Cf;th=vf;uh=Cf;vh=uf}else{th=rh;uh=cf;vh=sh}og=uh<<16>>16;if(uh<<16>>16>-1){tf=j+(of*60|0)+8|0;Bg=c[tf>>2]|0;Jf=Bg+2|0;c[tf>>2]=Jf;Qf=Bg;Bg=(de((d[Qf]|d[Qf+1|0]<<8)<<16>>16|0)|0)&65535;Qf=c[j+(of*60|0)+12>>2]|0;if(Jf>>>0>Qf>>>0){c[tf>>2]=Qf;wh=Jf>>>0>(Qf+1|0)>>>0?65535:Bg|255}else{wh=Bg}Bg=(wh<<og)+th|0;c[ng>>2]=Bg;xh=uh-16&65535;yh=Bg}else{xh=uh;yh=th}b[lf>>1]=xh;do{if(qg){zh=0}else{Bg=j+(of*60|0)+16|0;og=j+(of*60|0)+8|0;Qf=j+(of*60|0)+12|0;Jf=4;tf=1;zf=yh;Pf=vh;If=xh;while(1){Qg=tf<<1;Kg=b[Bg>>1]|0;Og=Kg&65535;Mg=Pf&65535;Lg=(ba(Og,Mg)|0)>>>16;ah=zf>>>16>>>0>=Lg>>>0;Ah=ah&1;if(ah){Bh=zf-(Lg<<16)|0;Ch=Mg-Lg&65535}else{Bh=zf;Ch=Lg&65535}b[Bg>>1]=(b[7558224+(Og>>>8<<2)+(Ah<<1)>>1]|0)+Kg;c[ng>>2]=Bh;b[pg>>1]=Ch;if((Ch&65535)>>>0<16385>>>0){Kg=Bh;Og=Ch;Lg=If;do{Kg=Kg<<1;Og=Og<<1;Lg=Lg+1&65535;}while((Og&65535)>>>0<16385>>>0);c[ng>>2]=Kg;b[pg>>1]=Og;b[lf>>1]=Lg;Dh=Kg;Eh=Lg;Fh=Og}else{Dh=Bh;Eh=If;Fh=Ch}Pg=Eh<<16>>16;if(Eh<<16>>16>-1){ch=c[og>>2]|0;Xg=ch+2|0;c[og>>2]=Xg;Ng=ch;ch=(de((d[Ng]|d[Ng+1|0]<<8)<<16>>16|0)|0)&65535;Ng=c[Qf>>2]|0;if(Xg>>>0>Ng>>>0){c[og>>2]=Ng;Gh=Xg>>>0>(Ng+1|0)>>>0?65535:ch|255}else{Gh=ch}ch=(Gh<<Pg)+Dh|0;c[ng>>2]=ch;Hh=Eh-16&65535;Ih=ch}else{Hh=Eh;Ih=Dh}b[lf>>1]=Hh;Jh=Ah|Qg;ch=d[1233616+Jf|0]|0;Pg=j+(of*60|0)+16+(ch<<1)|0;Ng=b[Pg>>1]|0;Xg=Ng&65535;bh=Fh&65535;Wg=(ba(Xg,bh)|0)>>>16;Mg=Ih>>>16>>>0>=Wg>>>0;if(Mg){Kh=Ih-(Wg<<16)|0;Lh=bh-Wg&65535}else{Kh=Ih;Lh=Wg&65535}b[Pg>>1]=(b[7558224+(Xg>>>8<<2)+((Mg&1)<<1)>>1]|0)+Ng;c[ng>>2]=Kh;b[pg>>1]=Lh;Ng=b[lf>>1]|0;if((Lh&65535)>>>0<16385>>>0){Xg=Kh;Pg=Lh;Wg=Ng;do{Xg=Xg<<1;Pg=Pg<<1;Wg=Wg+1&65535;}while((Pg&65535)>>>0<16385>>>0);c[ng>>2]=Xg;b[pg>>1]=Pg;b[lf>>1]=Wg;Mh=Xg;Nh=Wg;Oh=Pg}else{Mh=Kh;Nh=Ng;Oh=Lh}Qg=Nh<<16>>16;if(Nh<<16>>16>-1){Ah=c[og>>2]|0;Og=Ah+2|0;c[og>>2]=Og;Lg=Ah;Ah=(de((d[Lg]|d[Lg+1|0]<<8)<<16>>16|0)|0)&65535;Lg=c[Qf>>2]|0;if(Og>>>0>Lg>>>0){c[og>>2]=Lg;Ph=Og>>>0>(Lg+1|0)>>>0?65535:Ah|255}else{Ph=Ah}Ah=(Ph<<Qg)+Mh|0;c[ng>>2]=Ah;Qh=Nh-16&65535;Rh=Ah}else{Qh=Nh;Rh=Mh}b[lf>>1]=Qh;if(Mg){break}else{Jf=ch;tf=Jh;zf=Rh;Pf=Oh;If=Qh}}If=Jh-1|0;if((If|0)==0){zh=0;break}Pf=j+(of*60|0)+18|0;zf=b[Pf>>1]|0;tf=zf&65535;Jf=Oh&65535;Bg=(ba(tf,Jf)|0)>>>16;Jg=Rh>>>16>>>0>=Bg>>>0;if(Jg){Sh=Rh-(Bg<<16)|0;Th=Jf-Bg&65535}else{Sh=Rh;Th=Bg&65535}b[Pf>>1]=(b[7558224+(tf>>>8<<2)+((Jg&1)<<1)>>1]|0)+zf;c[ng>>2]=Sh;b[pg>>1]=Th;if((Th&65535)>>>0<16385>>>0){zf=Sh;tf=Th;Pf=Qh;do{zf=zf<<1;tf=tf<<1;Pf=Pf+1&65535;}while((tf&65535)>>>0<16385>>>0);c[ng>>2]=zf;b[pg>>1]=tf;b[lf>>1]=Pf;Uh=zf;Vh=Pf}else{Uh=Sh;Vh=Qh}Bg=Vh<<16>>16;if(Vh<<16>>16>-1){Jf=c[og>>2]|0;Bf=Jf+2|0;c[og>>2]=Bf;lg=Jf;Jf=(de((d[lg]|d[lg+1|0]<<8)<<16>>16|0)|0)&65535;lg=c[Qf>>2]|0;if(Bf>>>0>lg>>>0){c[og>>2]=lg;Wh=Bf>>>0>(lg+1|0)>>>0?65535:Jf|255}else{Wh=Jf}c[ng>>2]=(Wh<<Bg)+Uh;Xh=Vh-16&65535}else{Xh=Vh}b[lf>>1]=Xh;zh=Jg?1-Jh|0:If}}while(0);lf=Id+(rd*10|0)+(wf<<2)+2|0;b[lf>>1]=(e[lf>>1]|0)+zh}}while(0);if((Of|0)>=($e|0)){break g}wf=Of;yf=a[vd]|0}}}while(0);vd=c[k>>2]|0;if(F){ud=re;sd=1;while(1){se=Id+((sd+rd|0)*10|0)|0;b[se>>1]=b[ud>>1]|0;b[se+2>>1]=b[ud+2>>1]|0;b[se+4>>1]=b[ud+4>>1]|0;b[se+6>>1]=b[ud+6>>1]|0;b[se+8>>1]=b[ud+8>>1]|0;se=sd+1|0;if((se|0)<(L|0)){sd=se}else{Yh=1;Zh=re;break}}while(1){re=0;do{sd=Zh+((re+vd|0)*10|0)|0;b[sd>>1]=b[ud>>1]|0;b[sd+2>>1]=b[ud+2>>1]|0;b[sd+4>>1]=b[ud+4>>1]|0;b[sd+6>>1]=b[ud+6>>1]|0;b[sd+8>>1]=b[ud+8>>1]|0;re=re+1|0;}while((re|0)<(L|0));re=Yh+1|0;if((re|0)<(L|0)){Yh=re;Zh=Zh+(vd*10|0)|0}else{break}}}R=R+1|0;}while((R|0)<(A|0));E=E+1|0;}while((E|0)<(A|0));_h=c[u>>2]|0}else{_h=M}A=I+1|0;if((A|0)<(_h|0)){I=A;M=_h}else{break}}$h=_h;ai=c[z>>2]|0}else{$h=_;ai=C}M=Q+1|0;if((M|0)<(ai|0)){Q=M;_=$h;C=ai}else{break d}}}}while(0);yDb(c[s>>2]|0,16,2166096,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}}while(0);ai=c[n>>2]|0;$h=-ai&7;if(($h|0)==0){bi=ai}else{_h=c[p>>2]|0;Zh=$h+ai|0;ai=_h>>>0>Zh>>>0?Zh:_h;c[n>>2]=ai;bi=ai}do{if((c[o>>2]|0)==0){c[f+3988>>2]=0;ci=bi;di=c[p>>2]|0;ei=c[r>>2]|0;K=578}else{ai=c[r>>2]|0;_h=d[ai+(bi>>>3)|0]<<(bi&7)>>>7;Zh=c[p>>2]|0;$h=((bi|0)<(Zh|0))+bi|0;c[n>>2]=$h;Yh=_h&1;c[f+3988>>2]=Yh;if((Yh|0)==0){ci=$h;di=Zh;ei=ai;K=578;break}fi=f+4008|0}}while(0);h:do{if((K|0)==578){bi=ei+(ci>>>3)|0;o=(fe(d[bi]|d[bi+1|0]<<8|d[bi+2|0]<<16|d[bi+3|0]<<24|0)|0)<<(ci&7);if((o&-1434451968|0)==0){bi=1;ai=ci;Zh=o;while(1){gi=Zh>>>24;$h=a[1201432+gi|0]|0;hi=$h&255;Yh=(($h&255)>>>0>8>>>0?8:hi)+ai|0;_h=di>>>0>Yh>>>0;ii=_h?Yh:di;if(!($h<<24>>24==9)){K=581;break}$h=d[1201688+gi|0]|bi<<4;if(!($h>>>0<134217728>>>0)){ji=$h;break}Yh=ei+(ii>>>3)|0;zh=(fe(d[Yh]|d[Yh+1|0]<<8|d[Yh+2|0]<<16|d[Yh+3|0]<<24|0)|0)<<(ii&7);if(_h){bi=$h;ai=ii;Zh=zh}else{ji=$h;break}}if((K|0)==581){ji=d[1201688+gi|0]|bi<<(hi-1>>1)}c[n>>2]=ii;ki=ji-1|0;li=ii}else{Zh=o>>>24;ai=(d[1201432+Zh|0]|0)+ci|0;$h=di>>>0>ai>>>0?ai:di;c[n>>2]=$h;ki=d[1200920+Zh|0]|0;li=$h}if(ki>>>0>6>>>0){yDb(c[s>>2]|0,16,2274520,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}$h=f+4012|0;c[$h>>2]=ki;Zh=ei+(li>>>3)|0;ai=(fe(d[Zh]|d[Zh+1|0]<<8|d[Zh+2|0]<<16|d[Zh+3|0]<<24|0)|0)<<(li&7);if((ai&-1434451968|0)==0){Zh=1;zh=li;_h=ai;while(1){mi=_h>>>24;Yh=a[1201432+mi|0]|0;ni=Yh&255;Jh=((Yh&255)>>>0>8>>>0?8:ni)+zh|0;Xh=di>>>0>Jh>>>0;oi=Xh?Jh:di;if(!(Yh<<24>>24==9)){K=590;break}Yh=d[1201688+mi|0]|Zh<<4;if(!(Yh>>>0<134217728>>>0)){pi=Yh;break}Jh=ei+(oi>>>3)|0;Vh=(fe(d[Jh]|d[Jh+1|0]<<8|d[Jh+2|0]<<16|d[Jh+3|0]<<24|0)|0)<<(oi&7);if(Xh){Zh=Yh;zh=oi;_h=Vh}else{pi=Yh;break}}if((K|0)==590){pi=d[1201688+mi|0]|Zh<<(ni-1>>1)}c[n>>2]=oi;qi=pi-1|0;ri=oi}else{_h=ai>>>24;zh=(d[1201432+_h|0]|0)+li|0;o=di>>>0>zh>>>0?zh:di;c[n>>2]=o;qi=d[1200920+_h|0]|0;ri=o}if(qi>>>0>5>>>0|(qi|0)==0){yDb(c[s>>2]|0,16,2258720,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}o=f+4008|0;c[o>>2]=qi;_h=ei+(ri>>>3)|0;if((c[f+3996>>2]|0)==0){zh=d[_h]|0;bi=((ri|0)<(di|0))+ri|0;c[n>>2]=bi;if((zh&128>>>((ri&7)>>>0)|0)==0){zh=0;while(1){c[f+4024+(zh<<3)+4>>2]=1;c[f+4024+(zh<<3)>>2]=1;Yh=zh+1|0;if(Yh>>>0>(c[o>>2]|0)>>>0){fi=o;break h}else{zh=Yh}}}else{si=0;ti=qi;ui=bi;vi=di;wi=ei}while(1){zh=si>>>0>ti>>>0;ai=wi+(ui>>>3)|0;Zh=(fe(d[ai]|d[ai+1|0]<<8|d[ai+2|0]<<16|d[ai+3|0]<<24|0)|0)<<(ui&7);if((Zh&-1434451968|0)==0){ai=1;Yh=ui;Vh=Zh;while(1){xi=Vh>>>24;Xh=a[1201432+xi|0]|0;yi=Xh&255;Jh=((Xh&255)>>>0>8>>>0?8:yi)+Yh|0;Uh=vi>>>0>Jh>>>0;zi=Uh?Jh:vi;if(!(Xh<<24>>24==9)){K=601;break}Xh=d[1201688+xi|0]|ai<<4;if(!(Xh>>>0<134217728>>>0)){Ai=Xh;break}Jh=wi+(zi>>>3)|0;Wh=(fe(d[Jh]|d[Jh+1|0]<<8|d[Jh+2|0]<<16|d[Jh+3|0]<<24|0)|0)<<(zi&7);if(Uh){ai=Xh;Yh=zi;Vh=Wh}else{Ai=Xh;break}}if((K|0)==601){K=0;Ai=d[1201688+xi|0]|ai<<(yi-1>>1)}c[n>>2]=zi;Bi=Ai-1|0;Ci=zi}else{Vh=Zh>>>24;Yh=(d[1201432+Vh|0]|0)+ui|0;Xh=vi>>>0>Yh>>>0?Yh:vi;c[n>>2]=Xh;Bi=d[1200920+Vh|0]|0;Ci=Xh}if(zh){K=618;break}if((Bi|0)==0){K=607;break}c[f+4024+(si<<3)>>2]=Bi;Xh=wi+(Ci>>>3)|0;Vh=(fe(d[Xh]|d[Xh+1|0]<<8|d[Xh+2|0]<<16|d[Xh+3|0]<<24|0)|0)<<(Ci&7);if((Vh&-1434451968|0)==0){Xh=1;Yh=Ci;Wh=Vh;while(1){Di=Wh>>>24;Uh=a[1201432+Di|0]|0;Ei=Uh&255;Jh=((Uh&255)>>>0>8>>>0?8:Ei)+Yh|0;Qh=vi>>>0>Jh>>>0;Fi=Qh?Jh:vi;if(!(Uh<<24>>24==9)){K=611;break}Uh=d[1201688+Di|0]|Xh<<4;if(!(Uh>>>0<134217728>>>0)){Gi=Uh;break}Jh=wi+(Fi>>>3)|0;Sh=(fe(d[Jh]|d[Jh+1|0]<<8|d[Jh+2|0]<<16|d[Jh+3|0]<<24|0)|0)<<(Fi&7);if(Qh){Xh=Uh;Yh=Fi;Wh=Sh}else{Gi=Uh;break}}if((K|0)==611){K=0;Gi=d[1201688+Di|0]|Xh<<(Ei-1>>1)}c[n>>2]=Fi;Hi=Gi-1|0}else{Wh=Vh>>>24;Yh=(d[1201432+Wh|0]|0)+Ci|0;c[n>>2]=vi>>>0>Yh>>>0?Yh:vi;Hi=d[1200920+Wh|0]|0}if((Hi|0)==0){K=616;break}c[f+4024+(si<<3)+4>>2]=Hi;si=si+1|0;ti=c[o>>2]|0;ui=c[n>>2]|0;vi=c[p>>2]|0;wi=c[r>>2]|0}if((K|0)==607){yDb(c[s>>2]|0,16,2244352,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}else if((K|0)==616){yDb(c[s>>2]|0,16,2231920,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}else if((K|0)==618){if(!(Bi>>>0>1>>>0)){c[f+4020>>2]=Bi;fi=o;break}yDb(c[s>>2]|0,16,2219600,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}}bi=_h;Wh=(fe(d[bi]|d[bi+1|0]<<8|d[bi+2|0]<<16|d[bi+3|0]<<24|0)|0)<<(ri&7);if((Wh&-1434451968|0)==0){bi=1;Yh=ri;zh=Wh;while(1){Ii=zh>>>24;Zh=a[1201432+Ii|0]|0;Ji=Zh&255;ai=((Zh&255)>>>0>8>>>0?8:Ji)+Yh|0;Uh=di>>>0>ai>>>0;Ki=Uh?ai:di;if(!(Zh<<24>>24==9)){K=625;break}Zh=d[1201688+Ii|0]|bi<<4;if(!(Zh>>>0<134217728>>>0)){Li=Zh;break}ai=ei+(Ki>>>3)|0;Sh=(fe(d[ai]|d[ai+1|0]<<8|d[ai+2|0]<<16|d[ai+3|0]<<24|0)|0)<<(Ki&7);if(Uh){bi=Zh;Yh=Ki;zh=Sh}else{Li=Zh;break}}if((K|0)==625){Li=d[1201688+Ii|0]|bi<<(Ji-1>>1)}c[n>>2]=Ki;Mi=Li-1|0;Ni=Ki}else{zh=Wh>>>24;Yh=(d[1201432+zh|0]|0)+ri|0;_h=di>>>0>Yh>>>0?Yh:di;c[n>>2]=_h;Mi=d[1200920+zh|0]|0;Ni=_h}c[f+4072>>2]=Mi;_h=ei+(Ni>>>3)|0;zh=(fe(d[_h]|d[_h+1|0]<<8|d[_h+2|0]<<16|d[_h+3|0]<<24|0)|0)<<(Ni&7);if((zh&-1434451968|0)==0){_h=1;Yh=Ni;Zh=zh;while(1){Oi=Zh>>>24;Sh=a[1201432+Oi|0]|0;Pi=Sh&255;Uh=((Sh&255)>>>0>8>>>0?8:Pi)+Yh|0;ai=di>>>0>Uh>>>0;Qi=ai?Uh:di;if(!(Sh<<24>>24==9)){K=632;break}Sh=d[1201688+Oi|0]|_h<<4;if(!(Sh>>>0<134217728>>>0)){Ri=Sh;break}Uh=ei+(Qi>>>3)|0;Qh=(fe(d[Uh]|d[Uh+1|0]<<8|d[Uh+2|0]<<16|d[Uh+3|0]<<24|0)|0)<<(Qi&7);if(ai){_h=Sh;Yh=Qi;Zh=Qh}else{Ri=Sh;break}}if((K|0)==632){Ri=d[1201688+Oi|0]|_h<<(Pi-1>>1)}c[n>>2]=Qi;Si=Ri-1|0;Ti=Qi}else{Zh=zh>>>24;Yh=(d[1201432+Zh|0]|0)+Ni|0;Wh=di>>>0>Yh>>>0?Yh:di;c[n>>2]=Wh;Si=d[1200920+Zh|0]|0;Ti=Wh}c[f+4076>>2]=Si;Wh=ei+(Ti>>>3)|0;Zh=(fe(d[Wh]|d[Wh+1|0]<<8|d[Wh+2|0]<<16|d[Wh+3|0]<<24|0)|0)<<(Ti&7);if((Zh&-1434451968|0)==0){Wh=1;Yh=Ti;bi=Zh;while(1){Ui=bi>>>24;Sh=a[1201432+Ui|0]|0;Vi=Sh&255;Qh=((Sh&255)>>>0>8>>>0?8:Vi)+Yh|0;ai=di>>>0>Qh>>>0;Wi=ai?Qh:di;if(!(Sh<<24>>24==9)){K=639;break}Sh=d[1201688+Ui|0]|Wh<<4;if(!(Sh>>>0<134217728>>>0)){Xi=Sh;break}Qh=ei+(Wi>>>3)|0;Uh=(fe(d[Qh]|d[Qh+1|0]<<8|d[Qh+2|0]<<16|d[Qh+3|0]<<24|0)|0)<<(Wi&7);if(ai){Wh=Sh;Yh=Wi;bi=Uh}else{Xi=Sh;break}}if((K|0)==639){Xi=d[1201688+Ui|0]|Wh<<(Vi-1>>1)}c[n>>2]=Wi;Yi=Xi-1|0;Zi=Wi}else{bi=Zh>>>24;Yh=(d[1201432+bi|0]|0)+Ti|0;zh=di>>>0>Yh>>>0?Yh:di;c[n>>2]=zh;Yi=d[1200920+bi|0]|0;Zi=zh}c[f+4080>>2]=Yi;zh=ei+(Zi>>>3)|0;bi=(fe(d[zh]|d[zh+1|0]<<8|d[zh+2|0]<<16|d[zh+3|0]<<24|0)|0)<<(Zi&7);if((bi&-1434451968|0)==0){zh=1;Yh=Zi;_h=bi;while(1){_i=_h>>>24;Sh=a[1201432+_i|0]|0;$i=Sh&255;Uh=((Sh&255)>>>0>8>>>0?8:$i)+Yh|0;ai=di>>>0>Uh>>>0;aj=ai?Uh:di;if(!(Sh<<24>>24==9)){K=646;break}Sh=d[1201688+_i|0]|zh<<4;if(!(Sh>>>0<134217728>>>0)){bj=Sh;break}Uh=ei+(aj>>>3)|0;Qh=(fe(d[Uh]|d[Uh+1|0]<<8|d[Uh+2|0]<<16|d[Uh+3|0]<<24|0)|0)<<(aj&7);if(ai){zh=Sh;Yh=aj;_h=Qh}else{bj=Sh;break}}if((K|0)==646){bj=d[1201688+_i|0]|zh<<($i-1>>1)}c[n>>2]=aj;cj=bj-1|0;dj=aj}else{_h=bi>>>24;Yh=(d[1201432+_h|0]|0)+Zi|0;Zh=di>>>0>Yh>>>0?Yh:di;c[n>>2]=Zh;cj=d[1200920+_h|0]|0;dj=Zh}c[f+4084>>2]=cj;if((cj|0)<1){yDb(c[s>>2]|0,16,2210304,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}Zh=d[ei+(dj>>>3)|0]|0;c[n>>2]=((dj|0)<(di|0))+dj;if((Zh&128>>>((dj&7)>>>0)|0)==0){if(qi>>>0>4>>>0){yDb(c[s>>2]|0,16,2193280,(t=i,i=i+8|0,c[t>>2]=qi,t)|0);i=t;pa=-1;i=g;return pa|0}else{ej=0;fj=ki}while(1){Zh=63-ej|0;_h=a[1402160+(fj<<4)+(ej<<2)|0]|0;Yh=f+4088+(ej<<2)|0;a[Yh]=_h;Wh=c[$h>>2]|0;if((Wh|0)==3){a[Yh]=((c[o>>2]|0)+Zh<<2)+(_h&255);gj=c[$h>>2]|0}else{gj=Wh}Wh=a[1402160+(gj<<4)+(ej<<2)+1|0]|0;_h=f+4088+(ej<<2)+1|0;a[_h]=Wh;Yh=c[$h>>2]|0;if((Yh|0)==3){a[_h]=((c[o>>2]|0)+Zh<<2)+(Wh&255);hj=c[$h>>2]|0}else{hj=Yh}Yh=a[1402160+(hj<<4)+(ej<<2)+2|0]|0;Wh=f+4088+(ej<<2)+2|0;a[Wh]=Yh;_h=c[$h>>2]|0;if((_h|0)==3){a[Wh]=((c[o>>2]|0)+Zh<<2)+(Yh&255);ij=c[$h>>2]|0}else{ij=_h}_h=a[1402160+(ij<<4)+(ej<<2)+3|0]|0;Yh=f+4088+(ej<<2)+3|0;a[Yh]=_h;if((c[$h>>2]|0)==3){a[Yh]=((c[o>>2]|0)+Zh<<2)+(_h&255)}_h=ej+1|0;if(!(_h>>>0<(c[o>>2]|0)>>>0)){fi=o;break h}ej=_h;fj=c[$h>>2]|0}}yDb(c[s>>2]|0,48,2201552,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;$h=c[n>>2]|0;bi=c[p>>2]|0;zh=c[r>>2]|0;_h=zh+($h>>>3)|0;Zh=(fe(d[_h]|d[_h+1|0]<<8|d[_h+2|0]<<16|d[_h+3|0]<<24|0)|0)<<($h&7);if((Zh&-1434451968|0)==0){_h=1;Yh=$h;Wh=Zh;while(1){jj=Wh>>>24;Sh=a[1201432+jj|0]|0;kj=Sh&255;Qh=((Sh&255)>>>0>8>>>0?8:kj)+Yh|0;ai=bi>>>0>Qh>>>0;lj=ai?Qh:bi;if(!(Sh<<24>>24==9)){K=656;break}Sh=d[1201688+jj|0]|_h<<4;if(!(Sh>>>0<134217728>>>0)){mj=Sh;break}Qh=zh+(lj>>>3)|0;Uh=(fe(d[Qh]|d[Qh+1|0]<<8|d[Qh+2|0]<<16|d[Qh+3|0]<<24|0)|0)<<(lj&7);if(ai){_h=Sh;Yh=lj;Wh=Uh}else{mj=Sh;break}}if((K|0)==656){mj=d[1201688+jj|0]|_h<<(kj-1>>1)}c[n>>2]=lj;nj=mj+255&255;oj=lj}else{Wh=Zh>>>24;Yh=(d[1201432+Wh|0]|0)+$h|0;Sh=bi>>>0>Yh>>>0?Yh:bi;c[n>>2]=Sh;nj=a[1200920+Wh|0]|0;oj=Sh}a[f+4088|0]=nj;if((c[o>>2]|0)==0){fi=o;break}else{pj=0;qj=oj;rj=bi;sj=zh}while(1){Sh=sj+(qj>>>3)|0;Wh=(fe(d[Sh]|d[Sh+1|0]<<8|d[Sh+2|0]<<16|d[Sh+3|0]<<24|0)|0)<<(qj&7);if((Wh&-1434451968|0)==0){Sh=1;Yh=qj;Uh=Wh;while(1){tj=Uh>>>24;ai=a[1201432+tj|0]|0;uj=ai&255;Qh=((ai&255)>>>0>8>>>0?8:uj)+Yh|0;Jh=rj>>>0>Qh>>>0;vj=Jh?Qh:rj;if(!(ai<<24>>24==9)){K=664;break}ai=d[1201688+tj|0]|Sh<<4;if(!(ai>>>0<134217728>>>0)){wj=ai;break}Qh=sj+(vj>>>3)|0;Th=(fe(d[Qh]|d[Qh+1|0]<<8|d[Qh+2|0]<<16|d[Qh+3|0]<<24|0)|0)<<(vj&7);if(Jh){Sh=ai;Yh=vj;Uh=Th}else{wj=ai;break}}if((K|0)==664){K=0;wj=d[1201688+tj|0]|Sh<<(uj-1>>1)}c[n>>2]=vj;xj=wj+255&255}else{Uh=Wh>>>24;Yh=(d[1201432+Uh|0]|0)+qj|0;c[n>>2]=rj>>>0>Yh>>>0?Yh:rj;xj=a[1200920+Uh|0]|0}a[f+4088+(pj<<2)+1|0]=xj;Uh=c[n>>2]|0;Yh=c[p>>2]|0;Vh=c[r>>2]|0;Xh=Vh+(Uh>>>3)|0;ai=(fe(d[Xh]|d[Xh+1|0]<<8|d[Xh+2|0]<<16|d[Xh+3|0]<<24|0)|0)<<(Uh&7);if((ai&-1434451968|0)==0){Xh=1;Th=Uh;Jh=ai;while(1){yj=Jh>>>24;Qh=a[1201432+yj|0]|0;zj=Qh&255;Rh=((Qh&255)>>>0>8>>>0?8:zj)+Th|0;Oh=Yh>>>0>Rh>>>0;Aj=Oh?Rh:Yh;if(!(Qh<<24>>24==9)){K=671;break}Qh=d[1201688+yj|0]|Xh<<4;if(!(Qh>>>0<134217728>>>0)){Bj=Qh;break}Rh=Vh+(Aj>>>3)|0;j=(fe(d[Rh]|d[Rh+1|0]<<8|d[Rh+2|0]<<16|d[Rh+3|0]<<24|0)|0)<<(Aj&7);if(Oh){Xh=Qh;Th=Aj;Jh=j}else{Bj=Qh;break}}if((K|0)==671){K=0;Bj=d[1201688+yj|0]|Xh<<(zj-1>>1)}c[n>>2]=Aj;Cj=Bj+255&255}else{Jh=ai>>>24;Th=(d[1201432+Jh|0]|0)+Uh|0;c[n>>2]=Yh>>>0>Th>>>0?Th:Yh;Cj=a[1200920+Jh|0]|0}a[f+4088+(pj<<2)+2|0]=Cj;Jh=c[n>>2]|0;Th=c[p>>2]|0;Vh=c[r>>2]|0;Wh=Vh+(Jh>>>3)|0;Sh=(fe(d[Wh]|d[Wh+1|0]<<8|d[Wh+2|0]<<16|d[Wh+3|0]<<24|0)|0)<<(Jh&7);if((Sh&-1434451968|0)==0){Wh=1;Qh=Jh;j=Sh;while(1){Dj=j>>>24;Oh=a[1201432+Dj|0]|0;Ej=Oh&255;Rh=((Oh&255)>>>0>8>>>0?8:Ej)+Qh|0;Mh=Th>>>0>Rh>>>0;Fj=Mh?Rh:Th;if(!(Oh<<24>>24==9)){K=678;break}Oh=d[1201688+Dj|0]|Wh<<4;if(!(Oh>>>0<134217728>>>0)){Gj=Oh;break}Rh=Vh+(Fj>>>3)|0;Nh=(fe(d[Rh]|d[Rh+1|0]<<8|d[Rh+2|0]<<16|d[Rh+3|0]<<24|0)|0)<<(Fj&7);if(Mh){Wh=Oh;Qh=Fj;j=Nh}else{Gj=Oh;break}}if((K|0)==678){K=0;Gj=d[1201688+Dj|0]|Wh<<(Ej-1>>1)}c[n>>2]=Fj;Hj=Gj+255&255}else{j=Sh>>>24;Qh=(d[1201432+j|0]|0)+Jh|0;c[n>>2]=Th>>>0>Qh>>>0?Qh:Th;Hj=a[1200920+j|0]|0}a[f+4088+(pj<<2)+3|0]=Hj;j=pj+1|0;if(!(j>>>0<(c[o>>2]|0)>>>0)){fi=o;break h}pj=j;qj=c[n>>2]|0;rj=c[p>>2]|0;sj=c[r>>2]|0}}}while(0);r=f+1416|0;sj=f+1420|0;p=f+1484|0;rj=f+3980|0;n=f+1485|0;qj=f+3984|0;pj=f+1486|0;Hj=f+1487|0;Gj=f+1448|0;Fj=0;while(1){Ej=c[r>>2]|0;if((Fj|0)==0){c[Gj>>2]=Ej;Ij=0;Jj=Gj}else{Dj=f+1448+(Fj*844|0)|0;c[Dj>>2]=Ej>>>((c[rj>>2]|0)>>>0);Ij=c[qj>>2]|0;Jj=Dj}Dj=(c[sj>>2]|0)>>>(Ij>>>0);c[f+1448+(Fj*844|0)+4>>2]=Dj;Ej=c[fi>>2]|0;K=(c[Jj>>2]|0)-1+(1<<Ej)>>Ej<<Ej;c[f+1448+(Fj*844|0)+12>>2]=K;Ej=c[fi>>2]|0;Cj=Dj-1+(1<<Ej)>>Ej<<Ej;c[f+1448+(Fj*844|0)+16>>2]=Cj;Ej=f+1448+(Fj*844|0)+20|0;c[Ej>>2]=K+7&-8;Dj=c[fi>>2]|0;Bj=Dj-1|0;if((Bj|0)>-1){Aj=f+1448+(Fj*844|0)+24|0;zj=Cj;Cj=Dj;Dj=K;K=Bj;while(1){Bj=Dj>>1;yj=zj>>1;xj=(K|0)!=0;wj=xj&1;vj=Cj-2|0;if(xj){xj=wj;do{uj=c[Aj>>2]|0;tj=f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+24|0;c[tj>>2]=uj;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)>>2]=K;oj=c[Ej>>2]<<(c[fi>>2]|0)-K;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+8>>2]=oj;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+12>>2]=Bj;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+16>>2]=yj;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+4>>2]=xj;if((xj&1|0)==0){Kj=uj}else{nj=uj+(Bj<<1)|0;c[tj>>2]=nj;Kj=nj}if((xj|0)>1){c[tj>>2]=Kj+(oj>>1<<1)}c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+28>>2]=f+1448+(Fj*844|0)+44+(vj*160|0)+(xj*40|0);xj=xj+1|0;}while((xj|0)<4)}else{xj=wj;do{vj=c[Aj>>2]|0;Th=f+1448+(Fj*844|0)+44+(xj*40|0)+24|0;c[Th>>2]=vj;c[f+1448+(Fj*844|0)+44+(xj*40|0)>>2]=0;Jh=c[Ej>>2]<<c[fi>>2];c[f+1448+(Fj*844|0)+44+(xj*40|0)+8>>2]=Jh;c[f+1448+(Fj*844|0)+44+(xj*40|0)+12>>2]=Bj;c[f+1448+(Fj*844|0)+44+(xj*40|0)+16>>2]=yj;c[f+1448+(Fj*844|0)+44+(xj*40|0)+4>>2]=xj;if((xj&1|0)==0){Lj=vj}else{Sh=vj+(Bj<<1)|0;c[Th>>2]=Sh;Lj=Sh}if((xj|0)>1){c[Th>>2]=Lj+(Jh>>1<<1)}xj=xj+1|0;}while((xj|0)<4)}xj=K-1|0;if((xj|0)>-1){zj=yj;Cj=K;Dj=Bj;K=xj}else{break}}}if((Fj|0)>0){K=(d[p]|0)>>>((c[rj>>2]|0)>>>0)&255;a[f+1448+(Fj*844|0)+36|0]=K;Dj=(d[n]|0)>>>((c[qj>>2]|0)>>>0)&255;a[f+1448+(Fj*844|0)+37|0]=Dj;Cj=(d[pj]|0)>>>((c[rj>>2]|0)>>>0)&255;a[f+1448+(Fj*844|0)+38|0]=Cj;zj=(d[Hj]|0)>>>((c[qj>>2]|0)>>>0)&255;a[f+1448+(Fj*844|0)+39|0]=zj;Mj=K;Nj=Cj;Oj=Dj;Pj=zj}else{Mj=a[f+1448+(Fj*844|0)+36|0]|0;Nj=a[f+1448+(Fj*844|0)+38|0]|0;Oj=a[f+1448+(Fj*844|0)+37|0]|0;Pj=a[f+1448+(Fj*844|0)+39|0]|0}a[f+1448+(Fj*844|0)+40|0]=((Mj&255)-(Nj&255)|0)/2|0;a[f+1448+(Fj*844|0)+41|0]=((Oj&255)-(Pj&255)|0)/2|0;zj=Fj+1|0;if((zj|0)<3){Fj=zj}else{pa=0;break}}i=g;return pa|0}function u1(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;n=i;i=i+24|0;o=n|0;p=a[g+8|0]&3;do{if((p|0)==1|(p|0)==2){q=o|0;r=c[f+7328+((v1(f,g,q,l,m,p-1|0,k)|0)<<2)>>2]|0;s=f+4248|0;t=f+1448+(k*844|0)+8|0;u=f+1448+(k*844|0)+37|0;cf[r&1023](c[s>>2]|0,q,c[t>>2]|0,d[u]|0);q=c[f+7364>>2]|0;if((q|0)==0){v=s;w=t;x=u;break}le[q&1023](c[s>>2]|0,c[t>>2]|0,c[f+4196>>2]|0,(b[f+4192>>1]|0)+(b[f+4190>>1]|0)|0,d[u]|0);v=s;w=t;x=u}else if((p|0)==3){u=o|0;t=c[f+7328+((v1(f,g,u,l,m,0,k)|0)<<2)>>2]|0;s=f+4248|0;q=f+1448+(k*844|0)+8|0;r=f+1448+(k*844|0)+37|0;cf[t&1023](c[s>>2]|0,u,c[q>>2]|0,d[r]|0);t=v1(f,g,u,l,m,1,k)|0;y=f+7368|0;if((c[y>>2]|0)==0){cf[c[f+7344+(t<<2)>>2]&1023](c[s>>2]|0,u,c[q>>2]|0,d[r]|0);v=s;w=q;x=r;break}else{cf[c[f+7328+(t<<2)>>2]&1023]((c[s>>2]|0)+32|0,u,c[q>>2]|0,d[r]|0);u=c[s>>2]|0;Ke[c[y>>2]&1023](u,u+32|0,c[q>>2]|0,c[f+4196>>2]|0,b[f+4190>>1]|0,b[f+4192>>1]|0,d[r]|0);v=s;w=q;x=r;break}}else if((p|0)==0){r=c[f+1448+(k*844|0)+8>>2]|0;q=a[f+1448+(k*844|0)+36|0]|0;s=q&255;u=a[f+1448+(k*844|0)+37|0]|0;y=u&255;t=(b[g+(k<<1)>>1]|0)+128|0;if(u<<24>>24==0){i=n;return}u=q<<24>>24==0;q=j;z=h;A=0;while(1){if(!u){B=0;do{C=ba(d[q+B|0]|0,t)|0;D=z+(B<<1)|0;b[D>>1]=(e[D>>1]|0)+C;C=B|1;D=ba(d[q+C|0]|0,t)|0;E=z+(C<<1)|0;b[E>>1]=(e[E>>1]|0)+D;B=B+2|0;}while((B|0)<(s|0))}B=A+1|0;if((B|0)<(y|0)){q=q+32|0;z=z+(r<<1)|0;A=B}else{break}}i=n;return}else{v=f+4248|0;w=f+1448+(k*844|0)+8|0;x=f+1448+(k*844|0)+37|0}}while(0);le[c[f+7360>>2]&1023](h,c[v>>2]|0,c[w>>2]|0,j,d[x]|0);i=n;return}function v1(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=c[e+7376+(j<<2)>>2]|0;m=b[f+(j<<2)>>1]|0;n=b[f+(j<<2)+2>>1]|0;if((k|0)==0){o=m;p=n}else{o=m>>c[e+3980>>2];p=n>>c[e+3984>>2]}n=d[e+4188|0]|0;m=~(-1<<n);j=3-n|0;f=(o&m)<<j;q=(p&m)<<j;j=(o>>n)+h|0;h=(p>>n)+i|0;i=f|q;n=i&1;do{if((i&3|0)==0){p=c[e+1448+(k*844|0)+8>>2]|0;c[g>>2]=(c[l+16+(k<<4)+((q>>1)+(f>>2)<<2)>>2]|0)+((ba(p,h)|0)+j);r=j;s=h;t=1;u=p}else{p=c[e+1448+(k*844|0)+8>>2]|0;o=(ba(p,h)|0)+j|0;m=c[l+16+(k<<4)>>2]|0;v=m+o|0;c[g>>2]=v;w=c[l+16+(k<<4)+4>>2]|0;x=w+o|0;y=g+4|0;c[y>>2]=x;z=c[l+16+(k<<4)+8>>2]|0;A=z+o|0;B=g+8|0;c[B>>2]=A;C=(c[l+16+(k<<4)+12>>2]|0)+o|0;D=g+12|0;c[D>>2]=C;E=(f|0)>4;if(E){F=m+(o+1)|0;c[g>>2]=F;m=z+(o+1)|0;c[B>>2]=m;G=j+1|0;H=F;I=m}else{G=j;H=v;I=A}A=(q|0)>4;if(A){v=H+p|0;c[g>>2]=v;m=w+(o+p)|0;c[y>>2]=m;J=h+1|0;K=m;L=v}else{J=h;K=x;L=H}if((n|0)==0){if((f&3|0)==0){x=(f|0)!=0|0;c[g+((x^1)<<2)>>2]=c[g+((x|2)<<2)>>2];r=G;s=J;t=2;u=p;break}if((q&3|0)!=0){r=G;s=J;t=4;u=p;break}x=q>>1;c[g>>2]=c[g+(x<<2)>>2];c[y>>2]=c[g+(x+1<<2)>>2];r=G;s=J;t=2;u=p;break}if(E){c[y>>2]=L;c[g>>2]=K;c[D>>2]=I;c[B>>2]=C;M=C;N=K;O=I;P=L}else{M=I;N=L;O=C;P=K}if(A){c[B>>2]=N;c[g>>2]=M;c[D>>2]=P;c[y>>2]=O}c[g+16>>2]=1341736+((q&3)<<4)+((f&3)<<2);r=G;s=J;t=4;u=p}}while(0);J=e+1448+(k*844|0)+36|0;G=a[J]|0;f=e+1448+(k*844|0)|0;q=c[f>>2]|0;O=e+1448+(k*844|0)+37|0;do{if(((G&255)+r|0)>(q+8|0)){Q=e+1448+(k*844|0)+4|0}else{P=e+1448+(k*844|0)+4|0;if(((d[O]|0)+s|0)>((c[P>>2]|0)+8|0)|(r|0)<0|(s|0)<0){Q=P;break}R=t>>>1;S=R+n|0;return S|0}}while(0);P=e+1448+(k*844|0)+8|0;k=0;M=u;u=G;G=q;while(1){q=e+4224+(k<<2)|0;N=g+(k<<2)|0;R3a(c[q>>2]|0,c[N>>2]|0,M,M,u&255,d[O]|0,r,s,G+8|0,(c[Q>>2]|0)+8|0);c[N>>2]=c[q>>2];q=k+1|0;if((q|0)>=(t|0)){break}k=q;M=c[P>>2]|0;u=a[J]|0;G=c[f>>2]|0}R=t>>>1;S=R+n|0;return S|0}function w1(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;i=b+37|0;a:do{if((g|0)==0){j=0;k=c}else{l=b+36|0;m=(e|0)!=0;n=b+40|0;o=0;p=c;while(1){if((o|0)>=((d[i]|0)>>>1|0)){j=o;k=p;break a}q=a[l]|0;if(m&(q&255)>>>0>1>>>0){r=0;while(1){a[p+r|0]=64;s=r+1|0;t=a[l]|0;if((s|0)<((t&255)>>>1|0)){r=s}else{u=s;v=t;break}}}else{u=0;v=q}r=v&255;if((u|0)<(r>>>(f>>>0)|0)){t=u;s=r;while(1){r=a[n]|0;w=r&255;x=w<<1;do{if((x|0)>(t|0)){if(r<<24>>24==1){y=(t|0)!=0?5:3;break}else{y=(((t*6|0)-1+w|0)/(x-1|0)|0)+1|0;break}}else{z=s-1|0;if((z-x|0)>=(t|0)){y=8;break}if(r<<24>>24==1){y=(z|0)!=(t|0)?5:3;break}else{y=((w-1+((z-t|0)*6|0)|0)/(x-1|0)|0)+1|0;break}}}while(0);a[p+t|0]=y<<3;x=t+1|0;w=a[l]|0;r=w&255;if((x|0)<(r>>>(f>>>0)|0)){t=x;s=r}else{A=x;B=w;break}}}else{A=u;B=v}if((A|0)<(B&255|0)){s=A;while(1){a[p+s|0]=64;t=s+1|0;if((t|0)<(d[l]|0|0)){s=t}else{C=t;break}}}else{C=A}if((C|0)<32){TGb(p+C|0,0,32-C|0)|0}o=o+1|0;p=p+32|0}}}while(0);C=a[i]|0;A=C&255;if((j|0)<(A>>>(h>>>0)|0)){B=b+41|0;v=b+36|0;u=(e|0)==0;y=b+40|0;c=j;g=k;p=A;while(1){A=a[B]|0;o=A&255;l=o<<1;do{if((l|0)>(c|0)){if(A<<24>>24==1){D=(c|0)!=0?5:3;break}else{D=(((c*6|0)-1+o|0)/(l-1|0)|0)+1|0;break}}else{n=p-1|0;if((n-l|0)>=(c|0)){D=8;break}if(A<<24>>24==1){D=(n|0)!=(c|0)?5:3;break}else{D=((((n-c|0)*6|0)-1+o|0)/(l-1|0)|0)+1|0;break}}}while(0);do{if(u){E=0;F=a[v]|0}else{l=D<<3&255;o=a[v]|0;if((o&255)>>>0>1>>>0){G=0}else{E=0;F=o;break}while(1){a[g+G|0]=l;o=G+1|0;A=a[v]|0;if((o|0)<((A&255)>>>1|0)){G=o}else{E=o;F=A;break}}}}while(0);l=F&255;if((E|0)<(l>>>(f>>>0)|0)){A=E;o=l;while(1){l=a[y]|0;n=l&255;m=n<<1;do{if((m|0)>(A|0)){if(l<<24>>24==1){H=(A|0)!=0?5:3;break}else{H=(((A*6|0)-1+n|0)/(m-1|0)|0)+1|0;break}}else{s=o-1|0;if((s-m|0)>=(A|0)){H=8;break}if(l<<24>>24==1){H=(s|0)!=(A|0)?5:3;break}else{H=((n-1+((s-A|0)*6|0)|0)/(m-1|0)|0)+1|0;break}}}while(0);a[g+A|0]=ba(H,D)|0;m=A+1|0;n=a[v]|0;l=n&255;if((m|0)<(l>>>(f>>>0)|0)){A=m;o=l}else{I=m;J=n;break}}}else{I=E;J=F}if((I|0)<(J&255|0)){o=D<<3&255;A=I;while(1){a[g+A|0]=o;n=A+1|0;if((n|0)<(d[v]|0|0)){A=n}else{K=n;break}}}else{K=I}if((K|0)<32){TGb(g+K|0,0,32-K|0)|0}A=g+32|0;o=c+1|0;n=a[i]|0;m=n&255;if((o|0)<(m>>>(h>>>0)|0)){c=o;g=A;p=m}else{L=o;M=A;N=n;break}}}else{L=j;M=k;N=C}if((L|0)>=(N&255|0)){return}N=b+36|0;C=(e|0)!=0;e=b+40|0;b=L;L=M;while(1){M=a[N]|0;if(C&(M&255)>>>0>1>>>0){k=0;while(1){a[L+k|0]=64;j=k+1|0;p=a[N]|0;if((j|0)<((p&255)>>>1|0)){k=j}else{O=j;P=p;break}}}else{O=0;P=M}k=P&255;if((O|0)<(k>>>(f>>>0)|0)){p=O;j=k;while(1){k=a[e]|0;g=k&255;c=g<<1;do{if((c|0)>(p|0)){if(k<<24>>24==1){Q=(p|0)!=0?5:3;break}else{Q=(((p*6|0)-1+g|0)/(c-1|0)|0)+1|0;break}}else{h=j-1|0;if((h-c|0)>=(p|0)){Q=8;break}if(k<<24>>24==1){Q=(h|0)!=(p|0)?5:3;break}else{Q=((g-1+((h-p|0)*6|0)|0)/(c-1|0)|0)+1|0;break}}}while(0);a[L+p|0]=Q<<3;c=p+1|0;g=a[N]|0;k=g&255;if((c|0)<(k>>>(f>>>0)|0)){p=c;j=k}else{R=c;S=g;break}}}else{R=O;S=P}if((R|0)<(S&255|0)){j=R;while(1){a[L+j|0]=64;p=j+1|0;if((p|0)<(d[N]|0|0)){j=p}else{T=p;break}}}else{T=R}if((T|0)<32){TGb(L+T|0,0,32-T|0)|0}j=b+1|0;if((j|0)<(d[i]|0|0)){b=j;L=L+32|0}else{break}}return}function x1(a,f){a=a|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0;g=i;i=i+88|0;h=g|0;j=g+64|0;k=c[a+60>>2]|0;a=k;l=f+4|0;m=((c[l>>2]|0)!=0)+(c[f>>2]|0)|0;n=c[a+4024+(m<<3)>>2]|0;o=c[a+4024+(m<<3)+4>>2]|0;m=(o+n|0)==2;a=c[f+32>>2]|0;if((a|0)==0){i=g;return 0}p=c[f+36>>2]|0;q=a>>>0>268435455>>>0?-8:a<<3;r=q>>>0>2147483639>>>0|(p|0)==0;s=r?0:p;p=r?0:q;c[j>>2]=s;c[j+12>>2]=p;c[j+16>>2]=p+8;c[j+4>>2]=s+(p>>3);c[j+8>>2]=0;dkb(h,j,a);a:do{if((o|0)>0){a=f+16|0;j=(n|0)>0;p=f+12|0;s=k+4020|0;q=f+20|0;r=f+8|0;t=k+4004|0;u=f+24|0;v=f+28|0;w=h|0;x=h+4|0;y=h+6|0;z=h+8|0;A=h+12|0;B=h+44|0;C=k+4016|0;D=m^1;E=k;F=h+54|0;G=h+56|0;H=h+58|0;I=h+52|0;J=0;K=1;while(1){L=(ba(c[a>>2]|0,K)|0)/(o|0)|0;b:do{if(j){M=(J|0)<(L|0);N=0;O=1;while(1){P=(ba(c[p>>2]|0,O)|0)/(n|0)|0;if(m){Q=21}else{R=b[I>>1]|0;S=R&65535;T=c[w>>2]|0;U=e[x>>1]|0;V=(ba(U,S)|0)>>>16;W=T>>>16>>>0>=V>>>0;if(W){X=T-(V<<16)|0;Y=U-V&65535}else{X=T;Y=V&65535}b[I>>1]=(b[7558224+(S>>>8<<2)+((W&1)<<1)>>1]|0)+R;c[w>>2]=X;b[x>>1]=Y;R=b[y>>1]|0;if((Y&65535)>>>0<16385>>>0){S=X;V=Y;T=R;do{S=S<<1;V=V<<1;T=T+1&65535;}while((V&65535)>>>0<16385>>>0);c[w>>2]=S;b[x>>1]=V;b[y>>1]=T;Z=S;_=T}else{Z=X;_=R}U=_<<16>>16;if(_<<16>>16>-1){$=c[z>>2]|0;aa=$+2|0;c[z>>2]=aa;ca=$;$=(de((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0)&65535;ca=c[A>>2]|0;if(aa>>>0>ca>>>0){c[z>>2]=ca;da=aa>>>0>(ca+1|0)>>>0?65535:$|255}else{da=$}c[w>>2]=(da<<U)+Z;ea=_-16&65535}else{ea=_}b[y>>1]=ea;if(!W){Q=21}}c:do{if((Q|0)==21){Q=0;do{if((c[s>>2]|0)!=0){if(!((c[C>>2]|0)==0|D)){break}U=c[q>>2]|0;$=b[F>>1]|0;ca=$&65535;aa=c[w>>2]|0;fa=e[x>>1]|0;ga=(ba(fa,ca)|0)>>>16;ha=aa>>>16>>>0>=ga>>>0;if(ha){ia=aa-(ga<<16)|0;ja=fa-ga&65535}else{ia=aa;ja=ga&65535}b[F>>1]=(b[7558224+(ca>>>8<<2)+((ha&1)<<1)>>1]|0)+$;c[w>>2]=ia;b[x>>1]=ja;$=b[y>>1]|0;if((ja&65535)>>>0<16385>>>0){ca=ia;ga=ja;aa=$;do{ca=ca<<1;ga=ga<<1;aa=aa+1&65535;}while((ga&65535)>>>0<16385>>>0);c[w>>2]=ca;b[x>>1]=ga;b[y>>1]=aa;ka=ca;la=aa;ma=ga}else{ka=ia;la=$;ma=ja}fa=la<<16>>16;if(la<<16>>16>-1){na=c[z>>2]|0;oa=na+2|0;c[z>>2]=oa;pa=na;na=(de((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535;pa=c[A>>2]|0;if(oa>>>0>pa>>>0){c[z>>2]=pa;qa=oa>>>0>(pa+1|0)>>>0?65535:na|255}else{qa=na}na=(qa<<fa)+ka|0;c[w>>2]=na;ra=la-16&65535;sa=na}else{ra=la;sa=ka}b[y>>1]=ra;do{if(ha){ta=0}else{na=19;fa=2;pa=sa;oa=ma;ua=ra;while(1){va=b[G>>1]|0;wa=va&65535;xa=oa&65535;ya=(ba(wa,xa)|0)>>>16;za=pa>>>16>>>0>=ya>>>0;Aa=za&1;if(za){Ba=pa-(ya<<16)|0;Ca=xa-ya&65535}else{Ba=pa;Ca=ya&65535}b[G>>1]=(b[7558224+(wa>>>8<<2)+(Aa<<1)>>1]|0)+va;c[w>>2]=Ba;b[x>>1]=Ca;if((Ca&65535)>>>0<16385>>>0){va=Ba;wa=Ca;ya=ua;do{va=va<<1;wa=wa<<1;ya=ya+1&65535;}while((wa&65535)>>>0<16385>>>0);c[w>>2]=va;b[x>>1]=wa;b[y>>1]=ya;Da=va;Ea=ya;Fa=wa}else{Da=Ba;Ea=ua;Fa=Ca}xa=Ea<<16>>16;if(Ea<<16>>16>-1){za=c[z>>2]|0;Ga=za+2|0;c[z>>2]=Ga;Ha=za;za=(de((d[Ha]|d[Ha+1|0]<<8)<<16>>16|0)|0)&65535;Ha=c[A>>2]|0;if(Ga>>>0>Ha>>>0){c[z>>2]=Ha;Ia=Ga>>>0>(Ha+1|0)>>>0?65535:za|255}else{Ia=za}za=(Ia<<xa)+Da|0;c[w>>2]=za;Ja=Ea-16&65535;Ka=za}else{Ja=Ea;Ka=Da}b[y>>1]=Ja;La=Aa|fa;za=d[1233616+na|0]|0;xa=h+16+(za<<1)|0;Ha=b[xa>>1]|0;Ga=Ha&65535;Ma=Fa&65535;Na=(ba(Ga,Ma)|0)>>>16;Oa=Ka>>>16>>>0>=Na>>>0;if(Oa){Pa=Ka-(Na<<16)|0;Qa=Ma-Na&65535}else{Pa=Ka;Qa=Na&65535}b[xa>>1]=(b[7558224+(Ga>>>8<<2)+((Oa&1)<<1)>>1]|0)+Ha;c[w>>2]=Pa;b[x>>1]=Qa;Ha=b[y>>1]|0;if((Qa&65535)>>>0<16385>>>0){Ga=Pa;xa=Qa;Na=Ha;do{Ga=Ga<<1;xa=xa<<1;Na=Na+1&65535;}while((xa&65535)>>>0<16385>>>0);c[w>>2]=Ga;b[x>>1]=xa;b[y>>1]=Na;Ra=Ga;Sa=Na;Ta=xa}else{Ra=Pa;Sa=Ha;Ta=Qa}Aa=Sa<<16>>16;if(Sa<<16>>16>-1){wa=c[z>>2]|0;ya=wa+2|0;c[z>>2]=ya;va=wa;wa=(de((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)&65535;va=c[A>>2]|0;if(ya>>>0>va>>>0){c[z>>2]=va;Ua=ya>>>0>(va+1|0)>>>0?65535:wa|255}else{Ua=wa}wa=(Ua<<Aa)+Ra|0;c[w>>2]=wa;Va=Sa-16&65535;Wa=wa}else{Va=Sa;Wa=Ra}b[y>>1]=Va;if(Oa){break}else{na=za;fa=La<<1;pa=Wa;oa=Ta;ua=Va}}ua=La-1|0;if((ua|0)==0){ta=0;break}oa=b[H>>1]|0;pa=oa&65535;fa=Ta&65535;na=(ba(pa,fa)|0)>>>16;wa=Wa>>>16>>>0>=na>>>0;if(wa){Xa=Wa-(na<<16)|0;Ya=fa-na&65535}else{Xa=Wa;Ya=na&65535}b[H>>1]=(b[7558224+(pa>>>8<<2)+((wa&1)<<1)>>1]|0)+oa;c[w>>2]=Xa;b[x>>1]=Ya;if((Ya&65535)>>>0<16385>>>0){oa=Xa;pa=Ya;na=Va;do{oa=oa<<1;pa=pa<<1;na=na+1&65535;}while((pa&65535)>>>0<16385>>>0);c[w>>2]=oa;b[x>>1]=pa;b[y>>1]=na;Za=oa;_a=na}else{Za=Xa;_a=Va}fa=_a<<16>>16;if(_a<<16>>16>-1){Aa=c[z>>2]|0;va=Aa+2|0;c[z>>2]=va;ya=Aa;Aa=(de((d[ya]|d[ya+1|0]<<8)<<16>>16|0)|0)&65535;ya=c[A>>2]|0;if(va>>>0>ya>>>0){c[z>>2]=ya;$a=va>>>0>(ya+1|0)>>>0?65535:Aa|255}else{$a=Aa}c[w>>2]=($a<<fa)+Za;ab=_a-16&65535}else{ab=_a}b[y>>1]=ab;ta=wa?1-La|0:ua}}while(0);ha=ta+U|0;if((ha|0)<0){yDb(c[E>>2]|0,16,1896704,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;break c}else{c[q>>2]=ha;break}}}while(0);ha=c[q>>2]|0;$=(ha|0)>68?68:ha;c[q>>2]=$;ha=c[555320+($<<2)>>2]|0;if(!M){break}ga=c[r>>2]|0;aa=ba(ga,J)|0;ca=(N|0)<(P|0);fa=(c[((c[t>>2]|0)==0?555792:556072)+($<<2)>>2]|0)+2|0;$=-ga|0;Aa=~ga;ya=J;va=(c[u>>2]|0)+(aa<<1)|0;while(1){if(ca){aa=ya>>1;Ma=va+($<<1)|0;bb=c[v>>2]|0;cb=N;do{db=va+(cb<<1)|0;if((bb|0)==0){eb=0}else{fb=(ba(c[bb+8>>2]|0,aa)|0)+(cb>>1)|0;eb=((b[(c[bb+24>>2]|0)+(fb<<1)>>1]|0)!=0)<<1}fb=c[l>>2]|0;if((fb|0)==1){gb=b[va+(cb-ga<<1)>>1]|0}else{gb=0}do{if((cb|0)==0){hb=(b[Ma>>1]|0)==0|eb;ib=gb}else{jb=b[va+(cb-1<<1)>>1]|0;kb=(b[va+(cb-ga<<1)>>1]|jb|b[va+(cb+Aa<<1)>>1])<<16>>16==0|eb;if((fb|0)!=2){hb=kb;ib=gb;break}hb=kb;ib=jb<<16>>16}}while(0);fb=h+16+(hb<<1)|0;ua=b[fb>>1]|0;wa=ua&65535;na=c[w>>2]|0;oa=e[x>>1]|0;pa=(ba(oa,wa)|0)>>>16;jb=na>>>16>>>0>=pa>>>0;if(jb){lb=na-(pa<<16)|0;mb=oa-pa&65535}else{lb=na;mb=pa&65535}b[fb>>1]=(b[7558224+(wa>>>8<<2)+((jb&1)<<1)>>1]|0)+ua;c[w>>2]=lb;b[x>>1]=mb;ua=b[y>>1]|0;if((mb&65535)>>>0<16385>>>0){wa=lb;fb=mb;pa=ua;do{wa=wa<<1;fb=fb<<1;pa=pa+1&65535;}while((fb&65535)>>>0<16385>>>0);c[w>>2]=wa;b[x>>1]=fb;b[y>>1]=pa;nb=wa;ob=pa;pb=fb}else{nb=lb;ob=ua;pb=mb}na=ob<<16>>16;if(ob<<16>>16>-1){oa=c[z>>2]|0;kb=oa+2|0;c[z>>2]=kb;qb=oa;oa=(de((d[qb]|d[qb+1|0]<<8)<<16>>16|0)|0)&65535;qb=c[A>>2]|0;if(kb>>>0>qb>>>0){c[z>>2]=qb;rb=kb>>>0>(qb+1|0)>>>0?65535:oa|255}else{rb=oa}oa=(rb<<na)+nb|0;c[w>>2]=oa;sb=ob-16&65535;tb=oa}else{sb=ob;tb=nb}b[y>>1]=sb;do{if(jb){ub=0}else{oa=hb;na=1;qb=tb;kb=pb;vb=sb;while(1){wb=na<<1;xb=b[B>>1]|0;yb=xb&65535;zb=kb&65535;Ab=(ba(yb,zb)|0)>>>16;Bb=qb>>>16>>>0>=Ab>>>0;Cb=Bb&1;if(Bb){Db=qb-(Ab<<16)|0;Eb=zb-Ab&65535}else{Db=qb;Eb=Ab&65535}b[B>>1]=(b[7558224+(yb>>>8<<2)+(Cb<<1)>>1]|0)+xb;c[w>>2]=Db;b[x>>1]=Eb;if((Eb&65535)>>>0<16385>>>0){xb=Db;yb=Eb;Ab=vb;do{xb=xb<<1;yb=yb<<1;Ab=Ab+1&65535;}while((yb&65535)>>>0<16385>>>0);c[w>>2]=xb;b[x>>1]=yb;b[y>>1]=Ab;Fb=xb;Gb=Ab;Hb=yb}else{Fb=Db;Gb=vb;Hb=Eb}zb=Gb<<16>>16;if(Gb<<16>>16>-1){Bb=c[z>>2]|0;Ib=Bb+2|0;c[z>>2]=Ib;Jb=Bb;Bb=(de((d[Jb]|d[Jb+1|0]<<8)<<16>>16|0)|0)&65535;Jb=c[A>>2]|0;if(Ib>>>0>Jb>>>0){c[z>>2]=Jb;Kb=Ib>>>0>(Jb+1|0)>>>0?65535:Bb|255}else{Kb=Bb}Bb=(Kb<<zb)+Fb|0;c[w>>2]=Bb;Lb=Gb-16&65535;Mb=Bb}else{Lb=Gb;Mb=Fb}b[y>>1]=Lb;Nb=Cb|wb;Bb=d[1233616+oa|0]|0;zb=h+16+(Bb<<1)|0;Jb=b[zb>>1]|0;Ib=Jb&65535;Ob=Hb&65535;Pb=(ba(Ib,Ob)|0)>>>16;Qb=Mb>>>16>>>0>=Pb>>>0;if(Qb){Rb=Mb-(Pb<<16)|0;Sb=Ob-Pb&65535}else{Rb=Mb;Sb=Pb&65535}b[zb>>1]=(b[7558224+(Ib>>>8<<2)+((Qb&1)<<1)>>1]|0)+Jb;c[w>>2]=Rb;b[x>>1]=Sb;Jb=b[y>>1]|0;if((Sb&65535)>>>0<16385>>>0){Ib=Rb;zb=Sb;Pb=Jb;do{Ib=Ib<<1;zb=zb<<1;Pb=Pb+1&65535;}while((zb&65535)>>>0<16385>>>0);c[w>>2]=Ib;b[x>>1]=zb;b[y>>1]=Pb;Tb=Ib;Ub=Pb;Vb=zb}else{Tb=Rb;Ub=Jb;Vb=Sb}wb=Ub<<16>>16;if(Ub<<16>>16>-1){Cb=c[z>>2]|0;yb=Cb+2|0;c[z>>2]=yb;Ab=Cb;Cb=(de((d[Ab]|d[Ab+1|0]<<8)<<16>>16|0)|0)&65535;Ab=c[A>>2]|0;if(yb>>>0>Ab>>>0){c[z>>2]=Ab;Wb=yb>>>0>(Ab+1|0)>>>0?65535:Cb|255}else{Wb=Cb}Cb=(Wb<<wb)+Tb|0;c[w>>2]=Cb;Xb=Ub-16&65535;Yb=Cb}else{Xb=Ub;Yb=Tb}b[y>>1]=Xb;if(Qb){break}else{oa=Bb;na=Nb;qb=Yb;kb=Vb;vb=Xb}}vb=Nb-1|0;if((vb|0)==0){ub=vb&65535;break}kb=(fa+(ba(vb,ha)|0)|0)>>>2;vb=h+16+(((ib|0)>0|16)-(ib>>>31)<<1)|0;qb=b[vb>>1]|0;na=qb&65535;oa=Vb&65535;za=(ba(na,oa)|0)>>>16;Oa=Yb>>>16>>>0>=za>>>0;Ha=Oa&1;if(Oa){Zb=Yb-(za<<16)|0;_b=oa-za&65535}else{Zb=Yb;_b=za&65535}b[vb>>1]=(b[7558224+(na>>>8<<2)+(Ha<<1)>>1]|0)+qb;c[w>>2]=Zb;b[x>>1]=_b;qb=b[y>>1]|0;if((_b&65535)>>>0<16385>>>0){na=Zb;vb=_b;za=qb;do{na=na<<1;vb=vb<<1;za=za+1&65535;}while((vb&65535)>>>0<16385>>>0);c[w>>2]=na;b[x>>1]=vb;b[y>>1]=za;$b=na;ac=za}else{$b=Zb;ac=qb}oa=ac<<16>>16;if(ac<<16>>16>-1){Oa=c[z>>2]|0;xa=Oa+2|0;c[z>>2]=xa;Na=Oa;Oa=(de((d[Na]|d[Na+1|0]<<8)<<16>>16|0)|0)&65535;Na=c[A>>2]|0;if(xa>>>0>Na>>>0){c[z>>2]=Na;bc=xa>>>0>(Na+1|0)>>>0?65535:Oa|255}else{bc=Oa}c[w>>2]=(bc<<oa)+$b;cc=ac-16&65535}else{cc=ac}b[y>>1]=cc;ub=(kb^-Ha)+Ha&65535}}while(0);b[db>>1]=ub;cb=cb+1|0;}while((cb|0)<(P|0))}cb=ya+1|0;if((cb|0)<(L|0)){ya=cb;va=va+(ga<<1)|0}else{break}}}}while(0);if((O|0)>=(n|0)){break b}N=P;O=O+1|0}}}while(0);if((K|0)>=(o|0)){break a}J=L;K=K+1|0}}}while(0);if((c[l>>2]|0)!=0){i=g;return 0}if((c[k+4004>>2]|0)!=0){i=g;return 0}k=c[f+24>>2]|0;l=c[f+12>>2]|0;o=(l|0)>1;if(o){n=1;ub=b[k>>1]|0;do{cc=k+(n<<1)|0;ub=(b[cc>>1]|0)+ub&65535;b[cc>>1]=ub;n=n+1|0;}while((n|0)<(l|0))}n=c[f+8>>2]|0;ub=k+(n<<1)|0;k=c[f+16>>2]|0;if((k|0)<=1){i=g;return 0}f=-n|0;if(o){dc=1;ec=ub}else{o=1;cc=ub;while(1){b[cc>>1]=(b[cc>>1]|0)+(b[cc+(f<<1)>>1]|0);ub=o+1|0;if((ub|0)<(k|0)){o=ub;cc=cc+(n<<1)|0}else{break}}i=g;return 0}while(1){cc=(b[ec>>1]|0)+(b[ec+(f<<1)>>1]|0)&65535;b[ec>>1]=cc;o=1;ub=cc;do{cc=o-n|0;ac=ec+(o<<1)|0;ub=(((((b[ec+(cc<<1)>>1]|0)+(ub<<16>>16)+(b[ec+(cc-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[ac>>1]|0)&65535;b[ac>>1]=ub;o=o+1|0;}while((o|0)<(l|0));o=dc+1|0;if((o|0)<(k|0)){dc=o;ec=ec+(n<<1)|0}else{break}}i=g;return 0}function y1(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;h=i;j=c[f+60>>2]|0;f=j;k=c[g>>2]|0;g=k+4|0;l=c[g>>2]|0;m=((l|0)!=0)+(c[k>>2]|0)|0;n=c[f+4024+(m<<3)>>2]|0;o=c[f+4024+(m<<3)+4>>2]|0;m=(o+n|0)==2;f=c[k+32>>2]|0;if((f|0)==0){i=h;return 0}p=c[k+36>>2]|0;q=f>>>0>268435455>>>0?-8:f<<3;f=q>>>0>2147483639>>>0|(p|0)==0;r=f?0:p;p=f?8:q+8|0;if((o|0)>0){q=k+16|0;f=(n|0)>0;s=k+12|0;t=j+4020|0;u=k+20|0;v=k+8|0;w=j+4004|0;x=k+24|0;y=j+4016|0;z=m^1;A=j;B=0;C=1;D=0;while(1){E=(ba(c[q>>2]|0,C)|0)/(o|0)|0;a:do{if(f){F=(B|0)<(E|0);G=0;H=1;I=D;while(1){J=(ba(c[s>>2]|0,H)|0)/(n|0)|0;if(m){K=I;L=12}else{M=((I|0)<(p|0))+I|0;if((d[r+(I>>>3)|0]&128>>>((I&7)>>>0)|0)==0){K=M;L=12}else{N=M}}b:do{if((L|0)==12){L=0;do{if((c[t>>2]|0)==0){O=K}else{if(!((c[y>>2]|0)==0|z)){O=K;break}M=c[u>>2]|0;P=r+(K>>>3)|0;Q=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(K&7);if((Q&-1434451968|0)==0){P=1;R=K;S=Q;while(1){T=S>>>24;U=a[1201432+T|0]|0;V=U&255;W=((U&255)>>>0>8>>>0?8:V)+R|0;X=p>>>0>W>>>0;Y=X?W:p;if(!(U<<24>>24==9)){L=17;break}U=d[1201688+T|0]|P<<4;if(!(U>>>0<134217728>>>0)){Z=U;break}W=r+(Y>>>3)|0;_=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Y&7);if(X){P=U;R=Y;S=_}else{Z=U;break}}if((L|0)==17){L=0;Z=d[1201688+T|0]|P<<(V-1>>1)}$=Z-1|0;aa=Y}else{S=Q>>>24;R=(d[1201432+S|0]|0)+K|0;$=d[1200920+S|0]|0;aa=p>>>0>R>>>0?R:p}if(($|0)==0){ca=0;da=aa}else{R=r+(aa>>>3)|0;S=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(aa&7)>>31;R=aa+1|0;ca=(S^$)-S|0;da=p>>>0>R>>>0?R:p}R=ca+M|0;if((R|0)<0){yDb(c[A>>2]|0,16,1896704,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;N=da;break b}else{c[u>>2]=R;O=da;break}}}while(0);R=c[u>>2]|0;S=(R|0)>68?68:R;c[u>>2]=S;R=c[555320+(S<<2)>>2]|0;if(!F){N=O;break}U=c[v>>2]|0;_=ba(U,B)|0;X=(G|0)<(J|0);W=(c[((c[w>>2]|0)==0?555792:556072)+(S<<2)>>2]|0)+2|0;S=B;ea=(c[x>>2]|0)+(_<<1)|0;_=O;while(1){if(X){fa=G;ga=_;while(1){ha=r+(ga>>>3)|0;ia=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ga&7);if((ia&-1434451968|0)==0){ha=1;ja=ga;ka=ia;while(1){la=ka>>>24;ma=a[1201432+la|0]|0;na=ma&255;oa=((ma&255)>>>0>8>>>0?8:na)+ja|0;pa=p>>>0>oa>>>0;qa=pa?oa:p;if(!(ma<<24>>24==9)){L=32;break}ma=d[1201688+la|0]|ha<<4;if(!(ma>>>0<134217728>>>0)){ra=ma;break}oa=r+(qa>>>3)|0;sa=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(qa&7);if(pa){ha=ma;ja=qa;ka=sa}else{ra=ma;break}}if((L|0)==32){L=0;ra=d[1201688+la|0]|ha<<(na-1>>1)}ta=ra-1|0;ua=qa}else{ka=ia>>>24;ja=(d[1201432+ka|0]|0)+ga|0;ta=d[1200920+ka|0]|0;ua=p>>>0>ja>>>0?ja:p}if((ta|0)==0){va=0;wa=ua}else{ja=(W+(ba(ta,R)|0)|0)>>>2;ka=d[r+(ua>>>3)|0]<<(ua&7)>>>7&1;va=(ja^-ka)+ka&65535;wa=((ua|0)<(p|0))+ua|0}b[ea+(fa<<1)>>1]=va;ka=fa+1|0;if((ka|0)<(J|0)){fa=ka;ga=wa}else{xa=wa;break}}}else{xa=_}ga=S+1|0;if((ga|0)<(E|0)){S=ga;ea=ea+(U<<1)|0;_=xa}else{N=xa;break}}}}while(0);if((H|0)>=(n|0)){ya=N;break a}G=J;H=H+1|0;I=N}}else{ya=D}}while(0);if((C|0)>=(o|0)){break}B=E;C=C+1|0;D=ya}za=c[g>>2]|0}else{za=l}if((za|0)!=0){i=h;return 0}if((c[j+4004>>2]|0)!=0){i=h;return 0}j=c[k+24>>2]|0;za=c[k+12>>2]|0;l=(za|0)>1;if(l){g=1;ya=b[j>>1]|0;do{D=j+(g<<1)|0;ya=(b[D>>1]|0)+ya&65535;b[D>>1]=ya;g=g+1|0;}while((g|0)<(za|0))}g=c[k+8>>2]|0;ya=j+(g<<1)|0;j=c[k+16>>2]|0;if((j|0)<=1){i=h;return 0}k=-g|0;if(l){Aa=1;Ba=ya}else{l=1;D=ya;while(1){b[D>>1]=(b[D>>1]|0)+(b[D+(k<<1)>>1]|0);ya=l+1|0;if((ya|0)<(j|0)){l=ya;D=D+(g<<1)|0}else{break}}i=h;return 0}while(1){D=(b[Ba>>1]|0)+(b[Ba+(k<<1)>>1]|0)&65535;b[Ba>>1]=D;l=1;ya=D;do{D=l-g|0;C=Ba+(l<<1)|0;ya=(((((b[Ba+(D<<1)>>1]|0)+(ya<<16>>16)+(b[Ba+(D-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[C>>1]|0)&65535;b[C>>1]=ya;l=l+1|0;}while((l|0)<(za|0));l=Aa+1|0;if((l|0)<(j|0)){Aa=l;Ba=Ba+(g<<1)|0}else{break}}i=h;return 0}function z1(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=c[a+60>>2]|0;a=b;f=b+8|0;g=c[f>>2]|0;h=b+16|0;i=c[h>>2]|0;j=c[b>>2]|0;k=j+(g>>>3)|0;l=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(g&7)>>>25;k=g+7|0;g=i>>>0>k>>>0?k:i;c[f>>2]=g;k=b+28|0;m=c[k>>2]|0;n=m<<3;o=n>>>0>65535>>>0;p=o?m>>>13&65535:n;n=o?16:0;if((p&65280|0)==0){q=n;r=p}else{q=n|8;r=p>>>8}p=(d[1191992+r|0]|0)+q|0;q=p+1|0;do{if((q|0)==0){s=0;t=g}else{r=j+(g>>>3)|0;n=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(g&7);if((q|0)<26){r=g+q|0;o=i>>>0>r>>>0?r:i;c[f>>2]=o;s=n>>>((31-p|0)>>>0);t=o;break}else{o=g+16|0;r=i>>>0>o>>>0?o:i;c[f>>2]=r;o=p-15|0;m=j+(r>>>3)|0;u=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(r&7)>>>((47-p|0)>>>0);m=r+o|0;r=i>>>0>m>>>0?m:i;c[f>>2]=r;s=u|n>>>16<<o;t=r;break}}}while(0);j=b+12|0;g=(c[j>>2]|0)-t|0;q=((s|0)>(g|0)?g:s)+t|0;g=e+4008|0;if((c[g>>2]|0)==0){v=t;w=i}else{i=e+4088|0;t=b+20|0;r=b+24|0;o=e+1492|0;n=e+4072|0;u=e+4076|0;m=0;do{x=(m|0)!=0|0;do{y=l-(d[i+(m<<2)+x|0]|0)|0;A1(c[n>>2]|0,c[u>>2]|0,a,(y|0)>0?y:0,c[t>>2]|0,c[r>>2]|0,q,o+(m*160|0)+(x*40|0)|0,0);x=x+1|0;}while(x>>>0<4>>>0);m=m+1|0;}while(m>>>0<(c[g>>2]|0)>>>0);v=c[f>>2]|0;w=c[h>>2]|0}h=v-q|0;q=-v|0;m=w-v|0;if((h|0)<(q|0)){z=q}else{z=(m|0)<(h|0)?m:h}h=z+v|0;c[f>>2]=h;f=-8-p-s+(c[k>>2]<<3)|0;k=(c[j>>2]|0)-h|0;j=((f|0)>(k|0)?k:f)+h|0;if((c[g>>2]|0)==0){return 0}h=e+4088|0;f=b+20|0;k=b+24|0;b=e+2336|0;s=e+3180|0;p=e+4072|0;v=e+4076|0;e=0;do{z=(e|0)!=0|0;do{m=l-(d[h+(e<<2)+z|0]|0)|0;A1(c[p>>2]|0,c[v>>2]|0,a,(m|0)>0?m:0,c[f>>2]|0,c[k>>2]|0,j,b+(e*160|0)+(z*40|0)|0,s+(e*160|0)+(z*40|0)|0);z=z+1|0;}while(z>>>0<4>>>0);e=e+1|0;}while(e>>>0<(c[g>>2]|0)>>>0);return 0}function A1(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;n=c[l+12>>2]|0;o=((ba(n,i)|0)>>>0)/(e>>>0)|0;p=((ba(n,i+1|0)|0)>>>0)/(e>>>0)|0;e=c[l+16>>2]|0;i=((ba(e,j)|0)>>>0)/(f>>>0)|0;n=((ba(e,j+1|0)|0)>>>0)/(f>>>0)|0;f=(h|0)>68?68:h;h=c[555320+(f<<2)>>2]|0;j=l+8|0;e=c[j>>2]|0;q=(c[l+24>>2]|0)+((ba(e,i)|0)<<1)|0;if((m|0)==0){r=0}else{r=(c[m+24>>2]|0)+((ba(c[m+8>>2]|0,i)|0)<<1)|0}l=g+8|0;s=c[l>>2]|0;if(!((s|0)<(k|0)&(i|0)<(n|0))){return}t=(o|0)<(p|0);u=m+8|0;m=g+16|0;v=g|0;g=(c[555792+(f<<2)>>2]|0)+2|0;f=q;q=r;r=i;i=e;e=s;a:while(1){if(t){s=(q|0)==0;w=c[m>>2]|0;x=c[v>>2]|0;y=o;z=e;while(1){A=x+(z>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7);if((B&-1434451968|0)==0){A=1;C=z;D=B;while(1){E=D>>>24;F=a[1201432+E|0]|0;G=F&255;H=((F&255)>>>0>8>>>0?8:G)+C|0;I=w>>>0>H>>>0;J=I?H:w;if(!(F<<24>>24==9)){K=10;break}F=d[1201688+E|0]|0|A<<4;if(!(F>>>0<134217728>>>0)){L=F;break}H=x+(J>>>3)|0;M=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7);if(I){A=F;C=J;D=M}else{L=F;break}}if((K|0)==10){K=0;L=d[1201688+E|0]|0|A<<(G-1>>1)}c[l>>2]=J;N=L-1|0;O=J}else{D=B>>>24;C=(d[1201432+D|0]|0)+z|0;F=w>>>0>C>>>0?C:w;c[l>>2]=F;N=d[1200920+D|0]|0;O=F}if((N|0)==0){P=0;Q=O}else{F=(g+(ba(N,h)|0)|0)>>>2;D=(d[x+(O>>>3)|0]|0)<<(O&7)>>>7;C=((O|0)<(w|0))+O|0;c[l>>2]=C;M=D&1;P=(F^-M)+M&65535;Q=C}b[f+(y<<1)>>1]=P;if((Q|0)>=(k|0)){K=33;break a}if(s){R=Q}else{C=x+(Q>>>3)|0;M=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(Q&7);if((M&-1434451968|0)==0){C=1;F=Q;D=M;while(1){S=D>>>24;I=a[1201432+S|0]|0;T=I&255;H=((I&255)>>>0>8>>>0?8:T)+F|0;U=w>>>0>H>>>0;V=U?H:w;if(!(I<<24>>24==9)){K=21;break}I=d[1201688+S|0]|0|C<<4;if(!(I>>>0<134217728>>>0)){W=I;break}H=x+(V>>>3)|0;X=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(V&7);if(U){C=I;F=V;D=X}else{W=I;break}}if((K|0)==21){K=0;W=d[1201688+S|0]|0|C<<(T-1>>1)}c[l>>2]=V;Y=W-1|0;Z=V}else{D=M>>>24;F=(d[1201432+D|0]|0)+Q|0;B=w>>>0>F>>>0?F:w;c[l>>2]=B;Y=d[1200920+D|0]|0;Z=B}if((Y|0)==0){_=0;$=Z}else{B=(g+(ba(Y,h)|0)|0)>>>2;D=(d[x+(Z>>>3)|0]|0)<<(Z&7)>>>7;F=((Z|0)<(w|0))+Z|0;c[l>>2]=F;A=D&1;_=(B^-A)+A&65535;$=F}b[q+(y<<1)>>1]=_;if(($|0)<(k|0)){R=$}else{K=33;break a}}F=y+1|0;if((F|0)<(p|0)){y=F;z=R}else{break}}aa=c[j>>2]|0;ca=R}else{aa=i;ca=e}if((q|0)==0){da=0}else{da=q+(c[u>>2]<<1)|0}z=r+1|0;if((z|0)<(n|0)){f=f+(aa<<1)|0;q=da;r=z;i=aa;e=ca}else{K=33;break}}if((K|0)==33){return}}function B1(a){a=a|0;c[a>>2]=248;c[a+108>>2]=456;c[a+100>>2]=102;c[a+112>>2]=226;c[a+116>>2]=92;c[a+120>>2]=328;c[a+124>>2]=350;c[a+128>>2]=106;c[a+132>>2]=420;c[a+136>>2]=82;c[a+140>>2]=12;c[a+144>>2]=296;c[a+4>>2]=60;c[a+8>>2]=96;c[a+12>>2]=226;c[a+16>>2]=344;c[a+20>>2]=802;c[a+24>>2]=666;c[a+28>>2]=160;c[a+32>>2]=296;c[a+36>>2]=280;c[a+40>>2]=680;c[a+44>>2]=446;c[a+48>>2]=454;c[a+52>>2]=76;c[a+56>>2]=460;c[a+60>>2]=704;c[a+64>>2]=80;c[a+68>>2]=54;c[a+72>>2]=352;c[a+76>>2]=146;c[a+80>>2]=134;c[a+84>>2]=518;c[a+88>>2]=432;c[a+92>>2]=660;c[a+96>>2]=556;return}function C1(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;if((i|0)<=0){return}j=h+5|0;k=(h|0)>0;l=g<<1;m=g*-2|0;n=g*3|0;o=g*-3|0;p=g<<2;if((j|0)>-3){q=f;r=e;s=c;t=b;u=0}else{v=f;f=e;e=c;c=b;b=0;while(1){do{if(k){w=0;while(1){x=w+1|0;y=(((d[e+x|0]|0)+(d[e+w|0]|0)|0)*21|0)+16+(((d[e+(w+2)|0]|0)+(d[e+(w-1)|0]|0)|0)*-7|0)-(d[e+(w-3)|0]|0)+(((d[e+(w+3)|0]|0)+(d[e+(w-2)|0]|0)|0)*3|0)-(d[e+(w+4)|0]|0)>>5;if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}a[f+w|0]=z;if((x|0)<(h|0)){w=x}else{break}}if(k){A=0}else{break}while(1){w=A+1|0;x=(((d[v+w|0]|0)+(d[v+A|0]|0)|0)*21|0)+16+(((d[v+(A+2)|0]|0)+(d[v+(A-1)|0]|0)|0)*-7|0)-(d[v+(A-3)|0]|0)+(((d[v+(A+3)|0]|0)+(d[v+(A-2)|0]|0)|0)*3|0)-(d[v+(A+4)|0]|0)>>5;if(x>>>0>255>>>0){B=-x>>31&255}else{B=x&255}a[c+A|0]=B;if((w|0)<(h|0)){A=w}else{break}}}}while(0);w=b+1|0;if((w|0)<(i|0)){v=v+g|0;f=f+g|0;e=e+g|0;c=c+g|0;b=w}else{break}}return}while(1){b=-3;do{c=(((d[q+(b+g)|0]|0)+(d[q+b|0]|0)|0)*21|0)+16+(((d[q+(b+l)|0]|0)+(d[q+(b-g)|0]|0)|0)*-7|0)-(d[q+(b+o)|0]|0)+(((d[q+(b+n)|0]|0)+(d[q+(b+m)|0]|0)|0)*3|0)-(d[q+(b+p)|0]|0)>>5;if(c>>>0>255>>>0){C=-c>>31&255}else{C=c&255}a[s+b|0]=C;b=b+1|0;}while((b|0)<(j|0));do{if(k){b=0;while(1){c=b+1|0;e=(((d[s+c|0]|0)+(d[s+b|0]|0)|0)*21|0)+16+(((d[s+(b+2)|0]|0)+(d[s+(b-1)|0]|0)|0)*-7|0)-(d[s+(b-3)|0]|0)+(((d[s+(b+3)|0]|0)+(d[s+(b-2)|0]|0)|0)*3|0)-(d[s+(b+4)|0]|0)>>5;if(e>>>0>255>>>0){D=-e>>31&255}else{D=e&255}a[r+b|0]=D;if((c|0)<(h|0)){b=c}else{break}}if(k){E=0}else{break}while(1){b=E+1|0;c=(((d[q+b|0]|0)+(d[q+E|0]|0)|0)*21|0)+16+(((d[q+(E+2)|0]|0)+(d[q+(E-1)|0]|0)|0)*-7|0)-(d[q+(E-3)|0]|0)+(((d[q+(E+3)|0]|0)+(d[q+(E-2)|0]|0)|0)*3|0)-(d[q+(E+4)|0]|0)>>5;if(c>>>0>255>>>0){F=-c>>31&255}else{F=c&255}a[t+E|0]=F;if((b|0)<(h|0)){E=b}else{break}}}}while(0);b=u+1|0;if((b|0)<(i|0)){q=q+g|0;r=r+g|0;s=s+g|0;t=t+g|0;u=b}else{break}}return}function D1(c,d,f,g,h,i,j){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((j|0)<=0){return}k=(i|0)>0;l=g;g=d;d=c;c=0;while(1){if(k){m=0;do{n=(((e[g+(m<<1)>>1]|0)+32|0)>>>6)+(b[l+(m<<1)>>1]|0)|0;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[d+m|0]=o;n=m|1;p=(((e[g+(n<<1)>>1]|0)+32|0)>>>6)+(b[l+(n<<1)>>1]|0)|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[d+n|0]=q;m=m+2|0;}while((m|0)<(i|0))}m=c+1|0;if((m|0)<(j|0)){l=l+(h<<1)|0;g=g+(f<<1)|0;d=d+f|0;c=m}else{break}}return}function E1(c,d,e,f,g,h){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((h|0)<=0){return}i=(g|0)>0;j=e;e=c;c=0;while(1){if(i){k=0;do{l=b[j+(k<<1)>>1]|0;m=l+128|0;if(m>>>0>255>>>0){n=-128-l>>31&255}else{n=m&255}a[e+k|0]=n;m=k|1;l=b[j+(m<<1)>>1]|0;o=l+128|0;if(o>>>0>255>>>0){p=-128-l>>31&255}else{p=o&255}a[e+m|0]=p;m=k|2;o=b[j+(m<<1)>>1]|0;l=o+128|0;if(l>>>0>255>>>0){q=-128-o>>31&255}else{q=l&255}a[e+m|0]=q;m=k|3;l=b[j+(m<<1)>>1]|0;o=l+128|0;if(o>>>0>255>>>0){r=-128-l>>31&255}else{r=o&255}a[e+m|0]=r;k=k+4|0;}while((k|0)<(g|0))}k=c+1|0;if((k|0)<(h|0)){j=j+(f<<1)|0;e=e+d|0;c=k}else{break}}return}function F1(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=c;i=a;j=f;k=g}while(1){g=ba(d[j]|0,d[h]|0)|0;b[i>>1]=g+(b[i>>1]|0);g=ba(d[j+1|0]|0,d[h+1|0]|0)|0;f=i+2|0;b[f>>1]=g+(b[f>>1]|0);f=ba(d[j+2|0]|0,d[h+2|0]|0)|0;g=i+4|0;b[g>>1]=f+(b[g>>1]|0);g=ba(d[j+3|0]|0,d[h+3|0]|0)|0;f=i+6|0;b[f>>1]=g+(b[f>>1]|0);f=ba(d[j+4|0]|0,d[h+4|0]|0)|0;g=i+8|0;b[g>>1]=f+(b[g>>1]|0);g=ba(d[j+5|0]|0,d[h+5|0]|0)|0;f=i+10|0;b[f>>1]=g+(b[f>>1]|0);f=ba(d[j+6|0]|0,d[h+6|0]|0)|0;g=i+12|0;b[g>>1]=f+(b[g>>1]|0);g=ba(d[j+7|0]|0,d[h+7|0]|0)|0;f=i+14|0;b[f>>1]=g+(b[f>>1]|0);f=k-1|0;if((f|0)==0){break}else{h=h+e|0;i=i+(e<<1)|0;j=j+32|0;k=f}}return}function G1(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=c;i=a;j=f;k=g}while(1){g=0;do{f=ba(d[j+g|0]|0,d[h+g|0]|0)|0;a=i+(g<<1)|0;b[a>>1]=f+(b[a>>1]|0);a=g|1;f=ba(d[j+a|0]|0,d[h+a|0]|0)|0;c=i+(a<<1)|0;b[c>>1]=f+(b[c>>1]|0);g=g+2|0;}while((g|0)<16);g=k-1|0;if((g|0)==0){break}else{h=h+e|0;i=i+(e<<1)|0;j=j+32|0;k=g}}return}function H1(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=c;i=a;j=f;k=g}while(1){g=0;do{f=ba(d[j+g|0]|0,d[h+g|0]|0)|0;a=i+(g<<1)|0;b[a>>1]=f+(b[a>>1]|0);a=g|1;f=ba(d[j+a|0]|0,d[h+a|0]|0)|0;c=i+(a<<1)|0;b[c>>1]=f+(b[c>>1]|0);g=g+2|0;}while((g|0)<32);g=k-1|0;if((g|0)==0){break}else{h=h+e|0;i=i+(e<<1)|0;j=j+32|0;k=g}}return}function I1(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((g|0)==0){return}h=1<<e-1;i=b;b=g;while(1){g=0;j=a[i]|0;while(1){k=(ba(j&255,f)|0)+h>>e;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i+g|0]=l;k=g+1|0;m=i+k|0;n=(ba(d[m]|0,f)|0)+h>>e;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[m]=o;if((k|0)<8){g=k;j=o}else{break}}j=b-1|0;if((j|0)==0){break}else{i=i+c|0;b=j}}return}function J1(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((g|0)==0){return}h=1<<e-1;i=b;b=g;while(1){g=0;j=a[i]|0;while(1){k=(ba(j&255,f)|0)+h>>e;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i+g|0]=l;k=g+1|0;m=i+k|0;n=(ba(d[m]|0,f)|0)+h>>e;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[m]=o;if((k|0)<16){g=k;j=o}else{break}}j=b-1|0;if((j|0)==0){break}else{i=i+c|0;b=j}}return}function K1(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((g|0)==0){return}h=1<<e-1;i=b;b=g;while(1){g=0;j=a[i]|0;while(1){k=(ba(j&255,f)|0)+h>>e;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i+g|0]=l;k=g+1|0;m=i+k|0;n=(ba(d[m]|0,f)|0)+h>>e;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[m]=o;if((k|0)<32){g=k;j=o}else{break}}j=b-1|0;if((j|0)==0){break}else{i=i+c|0;b=j}}return}function L1(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((i|0)==0){return}j=1<<f-1;k=c;c=b;b=i;while(1){i=0;l=a[c]|0;while(1){m=(ba(d[k+i|0]|0,h)|0)+j+(ba(l&255,g)|0)>>f;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[c+i|0]=n;m=i+1|0;o=ba(d[k+m|0]|0,h)|0;p=c+m|0;q=o+j+(ba(d[p]|0,g)|0)>>f;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[p]=r;if((m|0)<8){i=m;l=r}else{break}}l=b-1|0;if((l|0)==0){break}else{k=k+e|0;c=c+e|0;b=l}}return}function M1(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((i|0)==0){return}j=1<<f-1;k=c;c=b;b=i;while(1){i=0;l=a[c]|0;while(1){m=(ba(d[k+i|0]|0,h)|0)+j+(ba(l&255,g)|0)>>f;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[c+i|0]=n;m=i+1|0;o=ba(d[k+m|0]|0,h)|0;p=c+m|0;q=o+j+(ba(d[p]|0,g)|0)>>f;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[p]=r;if((m|0)<16){i=m;l=r}else{break}}l=b-1|0;if((l|0)==0){break}else{k=k+e|0;c=c+e|0;b=l}}return}function N1(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((i|0)==0){return}j=1<<f-1;k=c;c=b;b=i;while(1){i=0;l=a[c]|0;while(1){m=(ba(d[k+i|0]|0,h)|0)+j+(ba(l&255,g)|0)>>f;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[c+i|0]=n;m=i+1|0;o=ba(d[k+m|0]|0,h)|0;p=c+m|0;q=o+j+(ba(d[p]|0,g)|0)>>f;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[p]=r;if((m|0)<32){i=m;l=r}else{break}}l=b-1|0;if((l|0)==0){break}else{k=k+e|0;c=c+e|0;b=l}}return}function O1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=ba(d[h]|0,d[l+g|0]|0)|0;q=ba(d[i]|0,d[m+g|0]|0)|0;r=ba(d[j]|0,d[n+g|0]|0)|0;a[e+g|0]=(p+8+q+r+(ba(d[k]|0,d[o+g|0]|0)|0)|0)>>>4;g=g+1|0;}while((g|0)<8);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function P1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=ba(d[h]|0,d[l+g|0]|0)|0;q=ba(d[i]|0,d[m+g|0]|0)|0;r=ba(d[j]|0,d[n+g|0]|0)|0;a[e+g|0]=(p+8+q+r+(ba(d[k]|0,d[o+g|0]|0)|0)|0)>>>4;g=g+1|0;}while((g|0)<16);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function Q1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=ba(d[h]|0,d[l+g|0]|0)|0;q=ba(d[i]|0,d[m+g|0]|0)|0;r=ba(d[j]|0,d[n+g|0]|0)|0;a[e+g|0]=(p+8+q+r+(ba(d[k]|0,d[o+g|0]|0)|0)|0)>>>4;g=g+1|0;}while((g|0)<32);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function R1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=e+g|0;q=ba(d[h]|0,d[l+g|0]|0)|0;r=ba(d[i]|0,d[m+g|0]|0)|0;s=ba(d[j]|0,d[n+g|0]|0)|0;a[p]=((d[p]|0)+1+((q+8+r+s+(ba(d[k]|0,d[o+g|0]|0)|0)|0)>>>4)|0)>>>1;g=g+1|0;}while((g|0)<8);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function S1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=e+g|0;q=ba(d[h]|0,d[l+g|0]|0)|0;r=ba(d[i]|0,d[m+g|0]|0)|0;s=ba(d[j]|0,d[n+g|0]|0)|0;a[p]=((d[p]|0)+1+((q+8+r+s+(ba(d[k]|0,d[o+g|0]|0)|0)|0)>>>4)|0)>>>1;g=g+1|0;}while((g|0)<16);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function T1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=e+g|0;q=ba(d[h]|0,d[l+g|0]|0)|0;r=ba(d[i]|0,d[m+g|0]|0)|0;s=ba(d[j]|0,d[n+g|0]|0)|0;a[p]=((d[p]|0)+1+((q+8+r+s+(ba(d[k]|0,d[o+g|0]|0)|0)|0)>>>4)|0)>>>1;g=g+1|0;}while((g|0)<32);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function U1(a){a=a|0;var b=0,d=0,e=0;b=0;while(1){if(!(b>>>0<11>>>0)){d=-1;e=4;break}if((c[1231136+(b*140|0)>>2]|0)==(a|0)){d=b;e=4;break}else{b=b+1|0}}if((e|0)==4){return d|0}return 0}function V1(a){a=a|0;var b=0,d=0,e=0;b=0;while(1){if(!(b>>>0<11>>>0)){d=-1;e=6;break}if((c[1231136+(b*140|0)>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==6){return d|0}if((b|0)<0){d=b;return d|0}d=c[1231152+(b*140|0)>>2]|0;return d|0}function W1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+72>>2]|0;e=(d|0)/1e6|0;if(!((d+999999|0)>>>0>1999998>>>0)){f=0;return f|0}d=c[a+120>>2]|0;g=a+124|0;h=a+88|0;a=0;a:while(1){b:do{if((c[1231140+(a*140|0)>>2]|0)==(d|0)){if((c[1231144+(a*140|0)>>2]|0)!=(c[g>>2]|0)){break}if((c[1231148+(a*140|0)>>2]|0)!=((c[h>>2]|0)>>>18&1|0)){break}if((c[1231164+(a*140|0)>>2]|0)==(b|0)){i=0}else{break}while(1){if(!(i>>>0<5>>>0)){break b}if((c[1231216+(a*140|0)+(i<<2)>>2]|0)==(e|0)){break a}else{i=i+1|0}}}}while(0);j=a+1|0;if(j>>>0<11>>>0){a=j}else{f=0;k=11;break}}if((k|0)==11){return f|0}f=c[1231136+(a*140|0)>>2]|0;return f|0}function X1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a;a=0;do{f=(a-3|0)>>>0<3>>>0?105:112;g=(1097>>>(a>>>0)&1|0)!=0?2327848:2190296;h=c[1231216+(a*140|0)>>2]|0;j=c[1231140+(a*140|0)>>2]|0;k=c[1231144+(a*140|0)>>2]|0;l=c[1231236+(a*140|0)>>2]|0;m=c[1231240+(a*140|0)>>2]|0;yDb(e,b,2306800,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=h,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=m,n)|0);i=n;m=c[1231220+(a*140|0)>>2]|0;l=c[1231244+(a*140|0)>>2]|0;h=c[1231248+(a*140|0)>>2]|0;yDb(e,b,2306800,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=m,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=h,n)|0);i=n;do{if(!((a-3|0)>>>0<3>>>0)){h=c[1231224+(a*140|0)>>2]|0;l=c[1231252+(a*140|0)>>2]|0;m=c[1231256+(a*140|0)>>2]|0;yDb(e,b,2306800,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=h,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=m,n)|0);i=n;if((a-3|0)>>>0<3>>>0){break}m=c[1231228+(a*140|0)>>2]|0;l=c[1231260+(a*140|0)>>2]|0;h=c[1231264+(a*140|0)>>2]|0;yDb(e,b,2306800,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=m,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=h,n)|0);i=n;if((121>>>(a>>>0)&1|0)!=0){break}h=c[1231232+(a*140|0)>>2]|0;l=c[1231268+(a*140|0)>>2]|0;m=c[1231272+(a*140|0)>>2]|0;yDb(e,b,2306800,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=h,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=m,n)|0);i=n}}while(0);a=a+1|0;}while(a>>>0<11>>>0);i=d;return}function Y1(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;a=b+24|0;c[a>>2]=-1;c[a+4>>2]=-1;return 0}function Z1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;h=i;i=i+16|0;j=h|0;k=c[g+24>>2]|0;l=g+28|0;g=c[l>>2]|0;m=c[b+60>>2]|0;n=m;o=e;c[j>>2]=o;c[j+4>>2]=0;c[j+8>>2]=0;if((g|0)<640){p=-1094995529;i=h;return p|0}q=m+36|0;r=m+32|0;s=m+3324|0;t=m;u=m+3320|0;v=m+396|0;w=m+3328|0;x=m+24|0;y=m+3316|0;z=m+40|0;A=m+44|0;B=e+296|0;C=b+120|0;D=b+124|0;E=e+88|0;G=e+84|0;H=b;I=m+324|0;J=m+344|0;K=m+364|0;L=m+1524|0;M=m+3184|0;N=m+320|0;m=e+300|0;e=g;g=k;k=1;a:while(1){if((PGb(g,1349984,5)|0)!=0){if((PGb(g,1349976,5)|0)!=0){O=5;break}}P=g+5|0;Q=d[P]|0;if((Q&2|0)!=0){c[N>>2]=Q&1;c[B>>2]=1;c[m>>2]=c[N>>2]^k;Q=c[N>>2]|0;yDb(c[t>>2]|0,48,2054304,(R=i,i=i+16|0,c[R>>2]=a[P]&3,c[R+8>>2]=Q,R)|0);i=R}Q=g+24|0;c[q>>2]=(de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535;Q=g+26|0;c[r>>2]=(de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535;c[s>>2]=0;do{if((a[g+4|0]|0)==2){Q=c[t>>2]|0;c[Q+140>>2]=78;c[Q+796>>2]=10;if((c[u>>2]|0)!=10){Z3(v,Q);c[u>>2]=10;c[w>>2]=242}c[s>>2]=1}else{Q=c[t>>2]|0;P=Q+140|0;if((a[g+33|0]&64)==0){c[P>>2]=4;c[Q+796>>2]=8;if((c[u>>2]|0)==8){break}Z3(v,Q);c[u>>2]=8;c[w>>2]=664;break}else{c[P>>2]=74;c[Q+796>>2]=10;if((c[u>>2]|0)==10){break}Z3(v,Q);c[u>>2]=10;c[w>>2]=2;break}}}while(0);Q=g+40|0;S=fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Q=S;P=0;if(!((Q|0)==(c[x>>2]|0)&(P|0)==(c[x+4>>2]|0))){T=U1(S)|0;if((T|0)<0){O=19;break}U=c[1231164+(T*140|0)>>2]|0;V=c[u>>2]|0;if((U|0)!=(V|0)){O=21;break}c[y>>2]=1231136+(T*140|0);Q_(I);Q_(J);Q_(K);T=c[y>>2]|0;N_(I,9,257,c[T+56>>2]|0,1,1,c[T+52>>2]|0,2,2,0,0,0,0)|0;T=c[y>>2]|0;N_(J,7,(c[u>>2]|0)+4|0,c[T+48>>2]|0,1,1,c[T+44>>2]|0,1,1,0,0,0,0)|0;T=c[y>>2]|0;N_(K,9,62,c[T+72>>2]|0,1,1,c[T+68>>2]|0,2,2,0,0,0,0)|0;x2(L,M,1075976);c[x>>2]=Q;c[x+4>>2]=P}if((c[(c[y>>2]|0)+20>>2]|0)>>>0>e>>>0){O=24;break}c[z>>2]=(c[r>>2]|0)>>>4;P=a[g+365|0]|0;W=P&255;c[A>>2]=W;Q=c[q>>2]|0;do{if(((Q+15|0)>>>4|0)==(W|0)){if((c[B>>2]|0)==0){X=Q;break}T=Q<<1;c[q>>2]=T;X=T}else{X=Q}}while(0);if((P&255)>>>0>68>>>0){O=31;break}if(W<<c[B>>2]>>>0>(X+15|0)>>>4>>>0){O=31;break}Q=e;T=(e|0)<0|0?-1:0;if(!(P<<24>>24==0)){Y=0;do{Z=g+((Y<<2)+368)|0;_=fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0;c[n+48+(Y<<2)>>2]=_;Z=YGb(_,0,640,0)|0;_=F;if((T|0)<(_|0)|(T|0)==(_|0)&Q>>>0<Z>>>0){O=34;break a}Y=Y+1|0;}while(Y>>>0<(c[A>>2]|0)>>>0)}Y=c[C>>2]|0;if((Y|0)==0){if((c[D>>2]|0)==0){$=k}else{O=37}}else{O=37}do{if((O|0)==37){O=0;Q=c[r>>2]|0;if((Q|0)==(Y|0)){T=c[q>>2]|0;P=c[D>>2]|0;if((T|0)==(P|0)){$=k;break}else{aa=P;ba=T}}else{aa=c[D>>2]|0;ba=c[q>>2]|0}yDb(H,24,2190168,(R=i,i=i+32|0,c[R>>2]=Y,c[R+8>>2]=aa,c[R+16>>2]=Q,c[R+24>>2]=ba,R)|0);i=R;$=1}}while(0);Y=V$a(b,c[r>>2]|0,c[q>>2]|0)|0;if((Y|0)<0){p=Y;O=48;break}if(($|0)==0){O=46;break}Y=W0a(b,j,0)|0;if((Y|0)<0){p=Y;O=48;break}c[E>>2]=1;c[G>>2]=1;$1(n,o,g+640|0,e-640|0);if((c[B>>2]|0)==0){break}Y=c[(c[y>>2]|0)+20>>2]|0;Q=e-Y|0;if((Q|0)<640){p=-1094995529;O=48;break}else{e=Q;g=g+Y|0;k=0}}if((O|0)==5){yDb(c[t>>2]|0,16,2112920,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==19){yDb(c[t>>2]|0,16,1917496,(R=i,i=i+8|0,c[R>>2]=S,R)|0);i=R;p=-38;i=h;return p|0}else if((O|0)==21){yDb(c[t>>2]|0,16,1896672,(R=i,i=i+16|0,c[R>>2]=U,c[R+8>>2]=V,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==24){yDb(c[t>>2]|0,16,2008480,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==31){yDb(c[t>>2]|0,16,1970296,(R=i,i=i+8|0,c[R>>2]=W,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==34){yDb(c[t>>2]|0,16,1941640,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==46){$1(n,o,g+640|0,e-640|0)}else if((O|0)==48){i=h;return p|0}c[f>>2]=1;p=c[l>>2]|0;i=h;return p|0}function _1(a){a=a|0;var b=0;b=c[a+60>>2]|0;Q_(b+324|0);Q_(b+344|0);Q_(b+364|0);return 0}function $1(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;g=a+44|0;h=c[g>>2]|0;if((h|0)==0){return}i=a+3320|0;j=a+392|0;k=a+388|0;l=a+384|0;m=a+4|0;n=a+16|0;o=a+20|0;p=a+8|0;q=a+12|0;r=a+40|0;s=b+32|0;t=b+36|0;u=a+3332|0;v=a+432|0;w=a+3328|0;x=a+1648|0;y=a+1776|0;z=a+1904|0;A=a+2032|0;B=a+2160|0;C=a+2288|0;D=a+2416|0;E=a+2544|0;F=a+3324|0;G=b+296|0;H=b|0;I=b+4|0;J=b+8|0;K=a+320|0;L=a+1516|0;M=a|0;N=a+2672|0;O=a+2800|0;P=a+2928|0;Q=a+3056|0;R=b+40|0;b=a+3316|0;S=0;T=c[r>>2]|0;U=h;while(1){h=c[i>>2]|0;V=1<<h+2;c[j>>2]=V;c[k>>2]=V;c[l>>2]=V;V=c[a+48+(S<<2)>>2]|0;W=e+V|0;X=f-V<<3;V=X>>>0>2147483639>>>0|(W|0)==0;Y=V?0:W;W=V?0:X;c[m>>2]=Y;c[n>>2]=W;X=W+8|0;c[o>>2]=X;c[p>>2]=Y+(W>>3);c[q>>2]=0;if((T|0)==0){Z=0;_=U}else{W=S<<4;V=0;$=h;h=0;aa=X;X=Y;while(1){Y=($|0)==10;ca=Y&1;da=c[s>>2]|0;ea=c[t>>2]|0;fa=X+(h>>>3)|0;ga=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(h&7)>>>21;fa=h+11|0;ha=(aa>>>0>fa>>>0?fa:aa)+1|0;c[q>>2]=aa>>>0>ha>>>0?ha:aa;if((ga|0)!=(c[u>>2]|0)){ha=0;do{c[a+3336+(ha<<2)>>2]=ba(d[(c[(c[b>>2]|0)+36>>2]|0)+ha|0]|0,ga)|0;c[a+3592+(ha<<2)>>2]=ba(d[(c[(c[b>>2]|0)+40>>2]|0)+ha|0]|0,ga)|0;ha=ha+1|0;}while((ha|0)<64);c[u>>2]=ga}me[c[v>>2]&511](x);cf[c[w>>2]&1023](a,x,0,ga);me[c[v>>2]&511](y);cf[c[w>>2]&1023](a,y,1,ga);me[c[v>>2]&511](z);cf[c[w>>2]&1023](a,z,2,ga);me[c[v>>2]&511](A);cf[c[w>>2]&1023](a,A,3,ga);me[c[v>>2]&511](B);cf[c[w>>2]&1023](a,B,4,ga);me[c[v>>2]&511](C);cf[c[w>>2]&1023](a,C,5,ga);me[c[v>>2]&511](D);cf[c[w>>2]&1023](a,D,6,ga);me[c[v>>2]&511](E);cf[c[w>>2]&1023](a,E,7,ga);if((c[F>>2]|0)!=0){me[c[v>>2]&511](N);cf[c[w>>2]&1023](a,N,8,ga);me[c[v>>2]&511](O);cf[c[w>>2]&1023](a,O,9,ga);me[c[v>>2]&511](P);cf[c[w>>2]&1023](a,P,10,ga);me[c[v>>2]&511](Q);cf[c[w>>2]&1023](a,Q,11,ga)}if((c[G>>2]|0)==0){ia=da;ja=ea}else{ia=da<<1;ja=ea<<1}ha=c[H>>2]|0;fa=(ba(ia,W)|0)+(V<<(ca|4))|0;ka=c[I>>2]|0;la=ba(ja,W)|0;ma=c[F>>2]|0;na=(V<<ma+(Y?4:3))+la|0;la=c[J>>2]|0;if((c[K>>2]|0)==0){oa=na;pa=na;qa=fa}else{oa=(c[R>>2]|0)+na|0;pa=(c[t>>2]|0)+na|0;qa=(c[s>>2]|0)+fa|0}fa=la+oa|0;na=ka+pa|0;ra=ia<<3;sa=8<<ca;Xe[c[L>>2]&4095](ha+qa|0,ia,x);Xe[c[L>>2]&4095](ha+(qa+sa)|0,ia,y);ta=c[L>>2]|0;ua=ha+(qa+ra)|0;do{if((ma|0)==0){Xe[ta&4095](ua,ia,B);Xe[c[L>>2]&4095](ha+(ra+sa+qa)|0,ia,C);if((c[(c[M>>2]|0)+88>>2]&8192|0)!=0){break}va=ja<<3;Xe[c[L>>2]&4095](na,ja,z);Xe[c[L>>2]&4095](fa,ja,A);Xe[c[L>>2]&4095](ka+(pa+va)|0,ja,D);Xe[c[L>>2]&4095](la+(oa+va)|0,ja,E)}else{Xe[ta&4095](ua,ia,D);Xe[c[L>>2]&4095](ha+(ra+sa+qa)|0,ia,E);if((c[(c[M>>2]|0)+88>>2]&8192|0)!=0){break}va=ja<<3;Xe[c[L>>2]&4095](na,ja,z);Xe[c[L>>2]&4095](ka+(pa+sa)|0,ja,A);Xe[c[L>>2]&4095](ka+(pa+va)|0,ja,N);wa=va+sa|0;Xe[c[L>>2]&4095](ka+(pa+wa)|0,ja,O);Xe[c[L>>2]&4095](fa,ja,B);Xe[c[L>>2]&4095](la+(oa+sa)|0,ja,C);Xe[c[L>>2]&4095](la+(oa+va)|0,ja,P);Xe[c[L>>2]&4095](la+(oa+wa)|0,ja,Q)}}while(0);la=V+1|0;xa=c[r>>2]|0;if(!(la>>>0<xa>>>0)){break}V=la;$=c[i>>2]|0;h=c[q>>2]|0;aa=c[o>>2]|0;X=c[m>>2]|0}Z=xa;_=c[g>>2]|0}X=S+1|0;if(X>>>0<_>>>0){S=X;T=Z;U=_}else{break}}return}function a2(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;j=e+3316|0;k=c[j>>2]|0;l=c[k+60>>2]|0;m=c[k+64>>2]|0;n=c[k+32>>2]|0;o=e+12|0;p=c[o>>2]|0;q=c[e+20>>2]|0;do{if((c[e+3324>>2]|0)==0){if((g&2|0)==0){r=0;s=e+3336|0;t=k+36|0;break}else{r=(g&1)+1|0;s=e+3592|0;t=k+40|0;break}}else{u=(g>>1|0)%3|0;if((u|0)==0){r=0;s=e+3336|0;t=k+36|0;break}else{r=u;s=e+3592|0;t=k+40|0;break}}}while(0);k=c[t>>2]|0;t=e+4|0;u=c[t>>2]|0;v=u+(p>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(p&7);v=w>>>25;x=c[e+348>>2]|0;y=b[x+(v<<2)>>1]|0;z=y<<16>>16;A=b[x+(v<<2)+2>>1]|0;v=w<<A;w=A+p|0;p=q>>>0>w>>>0?w:q;if(y<<16>>16==0){B=p;C=u;D=c[e+384+(r<<2)>>2]&65535}else{u=p+z|0;p=v^-2147483648;y=p>>31;w=e+384+(r<<2)|0;r=((y^v)>>>((32-z|0)>>>0)^y)+(p>>>31)+(c[w>>2]|0)|0;c[w>>2]=r;B=q>>>0>u>>>0?u:q;C=c[t>>2]|0;D=r&65535}b[f>>1]=D;D=C+(B>>>3)|0;r=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7);D=r>>>23;t=c[e+328>>2]|0;u=b[t+(D<<2)>>1]|0;w=b[t+(D<<2)+2>>1]|0;D=w<<16>>16;if(w<<16>>16<0){w=B+9|0;p=q>>>0>w>>>0?w:q;w=C+(p>>>3)|0;y=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(p&7);w=(y>>>((D+32|0)>>>0))+u|0;E=b[t+(w<<2)>>1]|0;F=b[t+(w<<2)+2>>1]|0;G=y;H=p}else{E=u;F=D;G=r;H=B}B=F+H|0;H=q>>>0>B>>>0?B:q;if((E|0)==(n|0)){I=H;c[o>>2]=I;i=h;return}B=e+368|0;r=H;H=G<<F;F=E;E=0;while(1){G=d[l+F|0]|0;D=d[m+F|0]|0;u=H>>31;p=r+1|0;y=q>>>0>p>>>0?p:q;if((D&1|0)==0){J=G;K=y}else{p=y+6|0;J=G+(H>>>25<<7&8064)|0;K=q>>>0>p>>>0?p:q}if((D&2|0)==0){L=E;M=K}else{D=C+(K>>>3)|0;p=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(K&7)>>>23;D=c[B>>2]|0;G=b[D+(p<<2)>>1]|0;y=b[D+(p<<2)+2>>1]|0;p=y<<16>>16;if(y<<16>>16<0){y=K+9|0;w=q>>>0>y>>>0?y:q;y=C+(w>>>3)|0;z=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>((p+32|0)>>>0))+G|0;N=b[D+(z<<2)+2>>1]|0;O=b[D+(z<<2)>>1]|0;P=w}else{N=p;O=G;P=K}G=N+P|0;L=(d[(c[(c[j>>2]|0)+76>>2]|0)+O|0]|0)+E|0;M=q>>>0>G>>>0?G:q}Q=L+1|0;if((Q|0)>63){break}G=ba(c[s+(Q<<2)>>2]|0,J)|0;b[f+(d[e+3188+Q|0]<<1)>>1]=((((a[k+Q|0]|0)==32?0:32)+G|0)>>>6^u)-u;u=C+(M>>>3)|0;G=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(M&7);u=G>>>23;p=b[t+(u<<2)>>1]|0;w=b[t+(u<<2)+2>>1]|0;u=w<<16>>16;if(w<<16>>16<0){w=M+9|0;z=q>>>0>w>>>0?w:q;w=C+(z>>>3)|0;D=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(z&7);w=(D>>>((u+32|0)>>>0))+p|0;R=b[t+(w<<2)+2>>1]|0;S=b[t+(w<<2)>>1]|0;T=D;U=z}else{R=u;S=p;T=G;U=M}G=R+U|0;p=q>>>0>G>>>0?G:q;if((S|0)==(n|0)){I=p;V=26;break}else{r=p;H=T<<R;F=S;E=Q}}if((V|0)==26){c[o>>2]=I;i=h;return}yDb(c[e>>2]|0,16,2353848,(e=i,i=i+16|0,c[e>>2]=g,c[e+8>>2]=Q,e)|0);i=e;I=M;c[o>>2]=I;i=h;return}function b2(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;h=a+3316|0;j=c[h>>2]|0;k=c[j+60>>2]|0;l=c[j+64>>2]|0;m=c[j+32>>2]|0;j=a+12|0;n=c[j>>2]|0;o=c[a+20>>2]|0;do{if((c[a+3324>>2]|0)==0){if((f&2|0)==0){p=0;q=a+3336|0;break}else{p=(f&1)+1|0;q=a+3592|0;break}}else{r=(f>>1|0)%3|0;if((r|0)==0){p=0;q=a+3336|0;break}else{p=r;q=a+3592|0;break}}}while(0);r=a+4|0;s=c[r>>2]|0;t=s+(n>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(n&7);t=u>>>25;v=c[a+348>>2]|0;w=b[v+(t<<2)>>1]|0;x=w<<16>>16;y=b[v+(t<<2)+2>>1]|0;t=u<<y;u=y+n|0;n=o>>>0>u>>>0?u:o;if(w<<16>>16==0){z=n;A=s;B=c[a+384+(p<<2)>>2]&65535}else{s=n+x|0;n=t^-2147483648;w=n>>31;u=a+384+(p<<2)|0;p=((w^t)>>>((32-x|0)>>>0)^w)+(n>>>31)+(c[u>>2]|0)|0;c[u>>2]=p;z=o>>>0>s>>>0?s:o;A=c[r>>2]|0;B=p&65535}b[e>>1]=B;B=A+(z>>>3)|0;p=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7);B=p>>>23;r=c[a+328>>2]|0;s=b[r+(B<<2)>>1]|0;u=b[r+(B<<2)+2>>1]|0;B=u<<16>>16;if(u<<16>>16<0){u=z+9|0;n=o>>>0>u>>>0?u:o;u=A+(n>>>3)|0;w=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(n&7);u=(w>>>((B+32|0)>>>0))+s|0;C=b[r+(u<<2)>>1]|0;D=b[r+(u<<2)+2>>1]|0;E=w;F=n}else{C=s;D=B;E=p;F=z}z=D+F|0;F=o>>>0>z>>>0?z:o;if((C|0)==(m|0)){G=F;c[j>>2]=G;i=g;return}z=a+368|0;p=F;F=E<<D;D=C;C=0;while(1){E=d[k+D|0]|0;B=d[l+D|0]|0;s=F>>31;n=p+1|0;w=o>>>0>n>>>0?n:o;if((B&1|0)==0){H=E;I=w}else{n=w+6|0;H=E+(F>>>25<<7&8064)|0;I=o>>>0>n>>>0?n:o}if((B&2|0)==0){J=C;K=I}else{B=A+(I>>>3)|0;n=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>23;B=c[z>>2]|0;E=b[B+(n<<2)>>1]|0;w=b[B+(n<<2)+2>>1]|0;n=w<<16>>16;if(w<<16>>16<0){w=I+9|0;u=o>>>0>w>>>0?w:o;w=A+(u>>>3)|0;x=((fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>((n+32|0)>>>0))+E|0;L=b[B+(x<<2)+2>>1]|0;M=b[B+(x<<2)>>1]|0;N=u}else{L=n;M=E;N=I}E=L+N|0;J=(d[(c[(c[h>>2]|0)+76>>2]|0)+M|0]|0)+C|0;K=o>>>0>E>>>0?E:o}O=J+1|0;if((O|0)>63){break}b[e+(d[a+3188+O|0]<<1)>>1]=(((ba(c[q+(O<<2)>>2]|0,H)|0)+8|0)>>>4^s)-s;s=A+(K>>>3)|0;E=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(K&7);s=E>>>23;n=b[r+(s<<2)>>1]|0;u=b[r+(s<<2)+2>>1]|0;s=u<<16>>16;if(u<<16>>16<0){u=K+9|0;x=o>>>0>u>>>0?u:o;u=A+(x>>>3)|0;B=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(x&7);u=(B>>>((s+32|0)>>>0))+n|0;P=b[r+(u<<2)+2>>1]|0;Q=b[r+(u<<2)>>1]|0;R=B;S=x}else{P=s;Q=n;R=E;S=K}E=P+S|0;n=o>>>0>E>>>0?E:o;if((Q|0)==(m|0)){G=n;T=26;break}else{p=n;F=R<<P;D=Q;C=O}}if((T|0)==26){c[j>>2]=G;i=g;return}yDb(c[a>>2]|0,16,2353848,(a=i,i=i+16|0,c[a>>2]=f,c[a+8>>2]=O,a)|0);i=a;G=K;c[j>>2]=G;i=g;return}function c2(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;j=e+3316|0;k=c[j>>2]|0;l=c[k+60>>2]|0;m=c[k+64>>2]|0;n=c[k+32>>2]|0;o=e+12|0;p=c[o>>2]|0;q=c[e+20>>2]|0;do{if((c[e+3324>>2]|0)==0){if((g&2|0)==0){r=0;s=e+3336|0;t=k+36|0;break}else{r=(g&1)+1|0;s=e+3592|0;t=k+40|0;break}}else{u=(g>>1|0)%3|0;if((u|0)==0){r=0;s=e+3336|0;t=k+36|0;break}else{r=u;s=e+3592|0;t=k+40|0;break}}}while(0);k=c[t>>2]|0;t=e+4|0;u=c[t>>2]|0;v=u+(p>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(p&7);v=w>>>25;x=c[e+348>>2]|0;y=b[x+(v<<2)>>1]|0;z=y<<16>>16;A=b[x+(v<<2)+2>>1]|0;v=w<<A;w=A+p|0;p=q>>>0>w>>>0?w:q;if(y<<16>>16==0){B=p;C=u;D=c[e+384+(r<<2)>>2]&65535}else{u=p+z|0;p=v^-2147483648;y=p>>31;w=e+384+(r<<2)|0;r=((y^v)>>>((32-z|0)>>>0)^y)+(p>>>31)+(c[w>>2]|0)|0;c[w>>2]=r;B=q>>>0>u>>>0?u:q;C=c[t>>2]|0;D=r&65535}b[f>>1]=D;D=C+(B>>>3)|0;r=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7);D=r>>>23;t=c[e+328>>2]|0;u=b[t+(D<<2)>>1]|0;w=b[t+(D<<2)+2>>1]|0;D=w<<16>>16;if(w<<16>>16<0){w=B+9|0;p=q>>>0>w>>>0?w:q;w=C+(p>>>3)|0;y=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(p&7);w=(y>>>((D+32|0)>>>0))+u|0;E=b[t+(w<<2)>>1]|0;F=b[t+(w<<2)+2>>1]|0;G=y;H=p}else{E=u;F=D;G=r;H=B}B=F+H|0;H=q>>>0>B>>>0?B:q;if((E|0)==(n|0)){I=H;c[o>>2]=I;i=h;return}B=e+368|0;r=H;H=G<<F;F=E;E=0;while(1){G=d[l+F|0]|0;D=d[m+F|0]|0;u=H>>31;p=r+1|0;y=q>>>0>p>>>0?p:q;if((D&1|0)==0){J=G;K=y}else{p=y+4|0;J=G+(H>>>27<<7&1920)|0;K=q>>>0>p>>>0?p:q}if((D&2|0)==0){L=E;M=K}else{D=C+(K>>>3)|0;p=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(K&7)>>>23;D=c[B>>2]|0;G=b[D+(p<<2)>>1]|0;y=b[D+(p<<2)+2>>1]|0;p=y<<16>>16;if(y<<16>>16<0){y=K+9|0;w=q>>>0>y>>>0?y:q;y=C+(w>>>3)|0;z=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>((p+32|0)>>>0))+G|0;N=b[D+(z<<2)+2>>1]|0;O=b[D+(z<<2)>>1]|0;P=w}else{N=p;O=G;P=K}G=N+P|0;L=(d[(c[(c[j>>2]|0)+76>>2]|0)+O|0]|0)+E|0;M=q>>>0>G>>>0?G:q}Q=L+1|0;if((Q|0)>63){break}G=ba(c[s+(Q<<2)>>2]|0,J)|0;b[f+(d[e+3188+Q|0]<<1)>>1]=((((a[k+Q|0]|0)==32?0:32)+G|0)>>>6^u)-u;u=C+(M>>>3)|0;G=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(M&7);u=G>>>23;p=b[t+(u<<2)>>1]|0;w=b[t+(u<<2)+2>>1]|0;u=w<<16>>16;if(w<<16>>16<0){w=M+9|0;z=q>>>0>w>>>0?w:q;w=C+(z>>>3)|0;D=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(z&7);w=(D>>>((u+32|0)>>>0))+p|0;R=b[t+(w<<2)+2>>1]|0;S=b[t+(w<<2)>>1]|0;T=D;U=z}else{R=u;S=p;T=G;U=M}G=R+U|0;p=q>>>0>G>>>0?G:q;if((S|0)==(n|0)){I=p;V=26;break}else{r=p;H=T<<R;F=S;E=Q}}if((V|0)==26){c[o>>2]=I;i=h;return}yDb(c[e>>2]|0,16,2353848,(e=i,i=i+16|0,c[e>>2]=g,c[e+8>>2]=Q,e)|0);i=e;I=M;c[o>>2]=I;i=h;return}



function Emb(a,f,h,j,k,l,m){a=a|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0;n=i;i=i+19208|0;o=n|0;c[(n|0)>>2]=0;c[(n|0)+4>>2]=0;p=c[a+12232>>2]|0;q=c[a+124>>2]|0;r=(ba(c[(a+12480|0)>>2]|0,q)|0)+(c[a+12476>>2]|0)|0;s=c[(a+12220|0)>>2]|0;t=c[(a+12264|0)>>2]|0;u=c[(a+12272|0)>>2]|0;v=c[(a+12268|0)>>2]|0;x=c[(a+12276|0)>>2]|0;y=c[(a+12464|0)>>2]|0;z=c[(a+12280|0)>>2]|0;A=c[(a+12284|0)>>2]|0;B=c[a+12244>>2]|0;C=c[(a+12216|0)>>2]|0;F=(B&1)+1|0;G=c[(a+10468|0)>>2]|0;H=c[(a+10472|0)>>2]|0;I=(c[(a+12224|0)>>2]|0)+4194304|0;c[(a+12224|0)>>2]=I;if((I|0)==0){c[(a+12224|0)>>2]=4194304;TGb(C|0,0,256)|0;J=c[(a+12224|0)>>2]|0}else{J=I}do{I=1;if(I){I=0;if((c[a+14084>>2]|0)==0){K=c[(j+76|0)>>2]>>F;L=c[(j+72|0)>>2]>>F;M=L+J+(K<<11)|0;do{if((c[(C+(((K<<3)+L&63)<<2)|0)>>2]|0)==(M|0)){N=1e6;O=0;P=0}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;R=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ba(Q,K)|0)+L)|0;T=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){U=T;break}S=c[a+12208>>2]|0;V=(ba(R,K>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&1023](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+V|0,R,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&1023](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+V|0,R,4);V=(Pe[H&255](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,R,4)|0)+T|0;U=V+(Pe[H&255](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,R,4)|0)|0}else{R=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){U=536870912;break}if((L<<F|0)>(c[(a+12268|0)>>2]<<F|0)){U=536870912;break}if((c[(a+12272|0)>>2]|0)>(K|0)){U=536870912;break}if((K<<F|0)>(c[(a+12276|0)>>2]<<F|0)){U=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;V=(B&1)<<1|1;a:do{if((c[a+11740>>2]|0)==1){if((L<<F|0)==0){T=0;while(1){W=c[a+12160+(T<<3)>>2]|0;X=(c[a+12160+(T<<3)+4>>2]|0)+(K<<F)|0;Y=((ba(c[a+12128+(T<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((T&1)<<(B&1|4))|0;Z=c[a+12128+(T<<3)+4>>2]|0;if((K<<F|0)==0){_=T>>1;$=((ba(Z,S-Q|0)|0)/(Q|0)|0)+(_<<(B&1|4))|0;aa=_}else{$=X-Z|0;aa=T>>1}Z=(($&V)<<F)+(Y&V)|0;_=(c[(a+12208|0)>>2]|0)+((ba(aa,R<<3)|0)+(T<<3&8))|0;if((B&1|0)==0){ca=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,R)|0)+(W>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((X&V)<<F)+(W&V)|0)<<2)>>2]&1023](_,ca,R,8);ca=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>1,R)|0)+(Y>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Z<<2)>>2]&1023](_,ca,R,8)}else{ca=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>2,R)|0)+(W>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&V)<<F)+(W&V)|0)<<2)>>2]&4095](_,ca,R);ca=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>2,R)|0)+(Y>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095](_,ca,R)}T=T+1|0;if((T|0)>=4){break a}}}if((K<<F|0)==0){T=0;do{ca=(c[a+12160+(T<<3)>>2]|0)+(L<<F)|0;_=c[a+12160+(T<<3)+4>>2]|0;Z=ca-(c[a+12128+(T<<3)>>2]|0)|0;Y=T>>1;W=((ba(c[a+12128+(T<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(Y<<(B&1|4))|0;X=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ba(Y,R<<3)|0))|0;if((B&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>1,R)|0)+(ca>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((_&V)<<F)+(ca&V)|0)<<2)>>2]&1023](X,Y,R,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>1,R)|0)+(Z>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((W&V)<<F)+(Z&V)|0)<<2)>>2]&1023](X,Y,R,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>2,R)|0)+(ca>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<F)+(ca&V)|0)<<2)>>2]&4095](X,Y,R);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>2,R)|0)+(Z>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((W&V)<<F)+(Z&V)|0)<<2)>>2]&4095](X,Y,R)}T=T+1|0;}while((T|0)<4)}else{T=0;do{Y=(c[a+12160+(T<<3)>>2]|0)+(L<<F)|0;X=(c[a+12160+(T<<3)+4>>2]|0)+(K<<F)|0;Z=Y-(c[a+12128+(T<<3)>>2]|0)|0;W=X-(c[a+12128+(T<<3)+4>>2]|0)|0;ca=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ba(T>>1,R<<3)|0))|0;if((B&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,R)|0)+(Y>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((X&V)<<F)+(Y&V)|0)<<2)>>2]&1023](ca,_,R,8);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>1,R)|0)+(Z>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((W&V)<<F)+(Z&V)|0)<<2)>>2]&1023](ca,_,R,8)}else{_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>2,R)|0)+(Y>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&V)<<F)+(Y&V)|0)<<2)>>2]&4095](ca,_,R);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>2,R)|0)+(Z>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((W&V)<<F)+(Z&V)|0)<<2)>>2]&4095](ca,_,R)}T=T+1|0;}while((T|0)<4)}}else{T=(c[a+12160>>2]|0)+(L<<F)|0;_=(c[a+12164>>2]|0)+(K<<F)|0;ca=c[a+12128>>2]|0;if((L<<F|0)==0){da=(ba(ca,S-Q|0)|0)/(Q|0)|0}else{da=T-ca|0}ca=c[a+12132>>2]|0;if((K<<F|0)==0){ea=(ba(ca,S-Q|0)|0)/(Q|0)|0}else{ea=_-ca|0}ca=((ea&V)<<F)+(da&V)|0;if((B&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>1,R)|0)+(T>>1))|0;cf[c[(c[a+12444>>2]|0)+((((_&V)<<F)+(T&V)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Z,R,16);Z=(c[a+12352+(l<<4)+32>>2]|0)+((ba(ea>>1,R)|0)+(da>>1))|0;cf[c[(c[a+12448>>2]|0)+(ca<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Z,R,16);break}else{Z=(ba(_>>2,R)|0)+(T>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<F)+(T&V)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Z|0,R);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<F)+(T&V)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Z+8|0)|0,R);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<F)+(T&V)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(R<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Z+(R<<3))|0,R);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<F)+(T&V)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Z+8|0)+(R<<3))|0,R);Z=(ba(ea>>2,R)|0)+(da>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ca<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Z|0,R);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ca<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Z+8|0)|0,R);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ca<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(R<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Z+(R<<3))|0,R);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ca<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Z+8|0)+(R<<3))|0,R);break}}}while(0);U=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,R,16)|0}}while(0);c[(C+(((K<<3)+L&63)<<2)|0)>>2]=M;c[s+(((K<<3)+L&63)<<2)>>2]=U;V=c[(j+72|0)>>2]>>F;Q=c[(j+76|0)>>2]>>F;S=(ba((d[y+((Q<<F)-A)|0]|0)+(d[y+((V<<F)-z)|0]|0)|0,p)|0)+U|0;if((S|0)>=1e6){N=1e6;O=0;P=0;break}c[(n|0)>>2]=V;c[o+4>>2]=Q;N=S;O=V;P=Q}}while(0);L=c[(j+36|0)>>2]>>F;K=c[(j+32|0)>>2]>>F;M=K+J+(L<<11)|0;do{if((c[(C+(((L<<3)+K&63)<<2)|0)>>2]|0)==(M|0)){fa=N;ga=O;ha=P}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;V=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ba(Q,L)|0)+K)|0;Z=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){ia=Z;break}S=c[a+12208>>2]|0;ca=(ba(V,L>>1)|0)+(K>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((L<<1&2|K&1)<<2)>>2]&1023](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ca|0,V,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((L<<1&2|K&1)<<2)>>2]&1023](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ca|0,V,4);ca=(Pe[H&255](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,V,4)|0)+Z|0;ia=ca+(Pe[H&255](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,V,4)|0)|0}else{V=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(K|0)){ia=536870912;break}if((K<<F|0)>(c[(a+12268|0)>>2]<<F|0)){ia=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){ia=536870912;break}if((L<<F|0)>(c[(a+12276|0)>>2]<<F|0)){ia=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;ca=(B&1)<<1|1;b:do{if((c[a+11740>>2]|0)==1){if((K<<F|0)==0){Z=0;while(1){T=c[a+12160+(Z<<3)>>2]|0;_=(c[a+12160+(Z<<3)+4>>2]|0)+(L<<F)|0;W=((ba(c[a+12128+(Z<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((Z&1)<<(B&1|4))|0;Y=c[a+12128+(Z<<3)+4>>2]|0;if((L<<F|0)==0){X=Z>>1;ja=((ba(Y,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;ka=X}else{ja=_-Y|0;ka=Z>>1}Y=((ja&ca)<<F)+(W&ca)|0;X=(c[(a+12208|0)>>2]|0)+((ba(ka,V<<3)|0)+(Z<<3&8))|0;if((B&1|0)==0){la=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>1,V)|0)+(T>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((_&ca)<<F)+(T&ca)|0)<<2)>>2]&1023](X,la,V,8);la=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ja>>1,V)|0)+(W>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Y<<2)>>2]&1023](X,la,V,8)}else{la=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>2,V)|0)+(T>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_&ca)<<F)+(T&ca)|0)<<2)>>2]&4095](X,la,V);la=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ja>>2,V)|0)+(W>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Y<<2)>>2]&4095](X,la,V)}Z=Z+1|0;if((Z|0)>=4){break b}}}if((L<<F|0)==0){Z=0;do{la=(c[a+12160+(Z<<3)>>2]|0)+(K<<F)|0;X=c[a+12160+(Z<<3)+4>>2]|0;Y=la-(c[a+12128+(Z<<3)>>2]|0)|0;W=Z>>1;T=((ba(c[a+12128+(Z<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(W<<(B&1|4))|0;_=(c[(a+12208|0)>>2]|0)+((Z<<3&8)+(ba(W,V<<3)|0))|0;if((B&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,V)|0)+(la>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((X&ca)<<F)+(la&ca)|0)<<2)>>2]&1023](_,W,V,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(T>>1,V)|0)+(Y>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((T&ca)<<F)+(Y&ca)|0)<<2)>>2]&1023](_,W,V,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>2,V)|0)+(la>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ca)<<F)+(la&ca)|0)<<2)>>2]&4095](_,W,V);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(T>>2,V)|0)+(Y>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((T&ca)<<F)+(Y&ca)|0)<<2)>>2]&4095](_,W,V)}Z=Z+1|0;}while((Z|0)<4)}else{Z=0;do{W=(c[a+12160+(Z<<3)>>2]|0)+(K<<F)|0;_=(c[a+12160+(Z<<3)+4>>2]|0)+(L<<F)|0;Y=W-(c[a+12128+(Z<<3)>>2]|0)|0;T=_-(c[a+12128+(Z<<3)+4>>2]|0)|0;la=(c[(a+12208|0)>>2]|0)+((Z<<3&8)+(ba(Z>>1,V<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>1,V)|0)+(W>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((_&ca)<<F)+(W&ca)|0)<<2)>>2]&1023](la,X,V,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(T>>1,V)|0)+(Y>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((T&ca)<<F)+(Y&ca)|0)<<2)>>2]&1023](la,X,V,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>2,V)|0)+(W>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_&ca)<<F)+(W&ca)|0)<<2)>>2]&4095](la,X,V);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(T>>2,V)|0)+(Y>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((T&ca)<<F)+(Y&ca)|0)<<2)>>2]&4095](la,X,V)}Z=Z+1|0;}while((Z|0)<4)}}else{Z=(c[a+12160>>2]|0)+(K<<F)|0;X=(c[a+12164>>2]|0)+(L<<F)|0;la=c[a+12128>>2]|0;if((K<<F|0)==0){ma=(ba(la,S-Q|0)|0)/(Q|0)|0}else{ma=Z-la|0}la=c[a+12132>>2]|0;if((L<<F|0)==0){na=(ba(la,S-Q|0)|0)/(Q|0)|0}else{na=X-la|0}la=((na&ca)<<F)+(ma&ca)|0;if((B&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,V)|0)+(Z>>1))|0;cf[c[(c[a+12444>>2]|0)+((((X&ca)<<F)+(Z&ca)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Y,V,16);Y=(c[a+12352+(l<<4)+32>>2]|0)+((ba(na>>1,V)|0)+(ma>>1))|0;cf[c[(c[a+12448>>2]|0)+(la<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Y,V,16);break}else{Y=(ba(X>>2,V)|0)+(Z>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ca)<<F)+(Z&ca)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Y|0,V);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ca)<<F)+(Z&ca)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Y+8|0)|0,V);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ca)<<F)+(Z&ca)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(V<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Y+(V<<3))|0,V);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ca)<<F)+(Z&ca)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Y+8|0)+(V<<3))|0,V);Y=(ba(na>>2,V)|0)+(ma>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Y|0,V);Xe[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Y+8|0)|0,V);Xe[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(V<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Y+(V<<3))|0,V);Xe[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Y+8|0)+(V<<3))|0,V);break}}}while(0);ia=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,V,16)|0}}while(0);c[(C+(((L<<3)+K&63)<<2)|0)>>2]=M;c[s+(((L<<3)+K&63)<<2)>>2]=ia;ca=c[(j+32|0)>>2]>>F;Q=c[(j+36|0)>>2]>>F;S=(ba((d[y+((Q<<F)-A)|0]|0)+(d[y+((ca<<F)-z)|0]|0)|0,p)|0)+ia|0;if((S|0)>=(N|0)){fa=N;ga=O;ha=P;break}c[(n|0)>>2]=ca;c[o+4>>2]=Q;fa=S;ga=ca;ha=Q}}while(0);K=c[(j+12|0)>>2]>>F;L=c[(j+8|0)>>2]>>F;M=L+J+(K<<11)|0;do{if((c[(C+(((K<<3)+L&63)<<2)|0)>>2]|0)==(M|0)){oa=fa;pa=ga;qa=ha}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;ca=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ba(Q,K)|0)+L)|0;R=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){ra=R;break}S=c[a+12208>>2]|0;Y=(ba(ca,K>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&1023](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+Y|0,ca,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&1023](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+Y|0,ca,4);Y=(Pe[H&255](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ca,4)|0)+R|0;ra=Y+(Pe[H&255](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ca,4)|0)|0}else{ca=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){ra=536870912;break}if((L<<F|0)>(c[(a+12268|0)>>2]<<F|0)){ra=536870912;break}if((c[(a+12272|0)>>2]|0)>(K|0)){ra=536870912;break}if((K<<F|0)>(c[(a+12276|0)>>2]<<F|0)){ra=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;Y=(B&1)<<1|1;c:do{if((c[a+11740>>2]|0)==1){if((L<<F|0)==0){R=0;while(1){la=c[a+12160+(R<<3)>>2]|0;Z=(c[a+12160+(R<<3)+4>>2]|0)+(K<<F)|0;X=((ba(c[a+12128+(R<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((R&1)<<(B&1|4))|0;T=c[a+12128+(R<<3)+4>>2]|0;if((K<<F|0)==0){W=R>>1;sa=((ba(T,S-Q|0)|0)/(Q|0)|0)+(W<<(B&1|4))|0;ta=W}else{sa=Z-T|0;ta=R>>1}T=((sa&Y)<<F)+(X&Y)|0;W=(c[(a+12208|0)>>2]|0)+((ba(ta,ca<<3)|0)+(R<<3&8))|0;if((B&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>1,ca)|0)+(la>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&Y)<<F)+(la&Y)|0)<<2)>>2]&1023](W,_,ca,8);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(sa>>1,ca)|0)+(X>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(T<<2)>>2]&1023](W,_,ca,8)}else{_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>2,ca)|0)+(la>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Z&Y)<<F)+(la&Y)|0)<<2)>>2]&4095](W,_,ca);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(sa>>2,ca)|0)+(X>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095](W,_,ca)}R=R+1|0;if((R|0)>=4){break c}}}if((K<<F|0)==0){R=0;do{_=(c[a+12160+(R<<3)>>2]|0)+(L<<F)|0;W=c[a+12160+(R<<3)+4>>2]|0;T=_-(c[a+12128+(R<<3)>>2]|0)|0;X=R>>1;la=((ba(c[a+12128+(R<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;Z=(c[(a+12208|0)>>2]|0)+((R<<3&8)+(ba(X,ca<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,ca)|0)+(_>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((W&Y)<<F)+(_&Y)|0)<<2)>>2]&1023](Z,X,ca,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(la>>1,ca)|0)+(T>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((la&Y)<<F)+(T&Y)|0)<<2)>>2]&1023](Z,X,ca,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>2,ca)|0)+(_>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<F)+(_&Y)|0)<<2)>>2]&4095](Z,X,ca);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(la>>2,ca)|0)+(T>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((la&Y)<<F)+(T&Y)|0)<<2)>>2]&4095](Z,X,ca)}R=R+1|0;}while((R|0)<4)}else{R=0;do{X=(c[a+12160+(R<<3)>>2]|0)+(L<<F)|0;Z=(c[a+12160+(R<<3)+4>>2]|0)+(K<<F)|0;T=X-(c[a+12128+(R<<3)>>2]|0)|0;la=Z-(c[a+12128+(R<<3)+4>>2]|0)|0;_=(c[(a+12208|0)>>2]|0)+((R<<3&8)+(ba(R>>1,ca<<3)|0))|0;if((B&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>1,ca)|0)+(X>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&Y)<<F)+(X&Y)|0)<<2)>>2]&1023](_,W,ca,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(la>>1,ca)|0)+(T>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((la&Y)<<F)+(T&Y)|0)<<2)>>2]&1023](_,W,ca,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>2,ca)|0)+(X>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Z&Y)<<F)+(X&Y)|0)<<2)>>2]&4095](_,W,ca);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(la>>2,ca)|0)+(T>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((la&Y)<<F)+(T&Y)|0)<<2)>>2]&4095](_,W,ca)}R=R+1|0;}while((R|0)<4)}}else{R=(c[a+12160>>2]|0)+(L<<F)|0;W=(c[a+12164>>2]|0)+(K<<F)|0;_=c[a+12128>>2]|0;if((L<<F|0)==0){ua=(ba(_,S-Q|0)|0)/(Q|0)|0}else{ua=R-_|0}_=c[a+12132>>2]|0;if((K<<F|0)==0){va=(ba(_,S-Q|0)|0)/(Q|0)|0}else{va=W-_|0}_=((va&Y)<<F)+(ua&Y)|0;if((B&1|0)==0){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,ca)|0)+(R>>1))|0;cf[c[(c[a+12444>>2]|0)+((((W&Y)<<F)+(R&Y)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,T,ca,16);T=(c[a+12352+(l<<4)+32>>2]|0)+((ba(va>>1,ca)|0)+(ua>>1))|0;cf[c[(c[a+12448>>2]|0)+(_<<2)>>2]&1023](c[(a+12208|0)>>2]|0,T,ca,16);break}else{T=(ba(W>>2,ca)|0)+(R>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<F)+(R&Y)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+T|0,ca);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<F)+(R&Y)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(T+8|0)|0,ca);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<F)+(R&Y)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ca<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(T+(ca<<3))|0,ca);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<F)+(R&Y)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ca<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((T+8|0)+(ca<<3))|0,ca);T=(ba(va>>2,ca)|0)+(ua>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+T|0,ca);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(T+8|0)|0,ca);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ca<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(T+(ca<<3))|0,ca);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ca<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((T+8|0)+(ca<<3))|0,ca);break}}}while(0);ra=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ca,16)|0}}while(0);c[(C+(((K<<3)+L&63)<<2)|0)>>2]=M;c[s+(((K<<3)+L&63)<<2)>>2]=ra;Y=c[(j+8|0)>>2]>>F;Q=c[(j+12|0)>>2]>>F;S=(ba((d[y+((Q<<F)-A)|0]|0)+(d[y+((Y<<F)-z)|0]|0)|0,p)|0)+ra|0;if((S|0)>=(fa|0)){oa=fa;pa=ga;qa=ha;break}c[(n|0)>>2]=Y;c[o+4>>2]=Q;oa=S;pa=Y;qa=Q}}while(0);L=c[(j+20|0)>>2]>>F;K=c[(j+16|0)>>2]>>F;M=K+J+(L<<11)|0;do{if((c[(C+(((L<<3)+K&63)<<2)|0)>>2]|0)==(M|0)){wa=oa;xa=pa;ya=qa}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;Y=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ba(Q,L)|0)+K)|0;V=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){za=V;break}S=c[a+12208>>2]|0;T=(ba(Y,L>>1)|0)+(K>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((L<<1&2|K&1)<<2)>>2]&1023](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+T|0,Y,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((L<<1&2|K&1)<<2)>>2]&1023](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+T|0,Y,4);T=(Pe[H&255](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,Y,4)|0)+V|0;za=T+(Pe[H&255](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,Y,4)|0)|0}else{Y=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(K|0)){za=536870912;break}if((K<<F|0)>(c[(a+12268|0)>>2]<<F|0)){za=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){za=536870912;break}if((L<<F|0)>(c[(a+12276|0)>>2]<<F|0)){za=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;T=(B&1)<<1|1;d:do{if((c[a+11740>>2]|0)==1){if((K<<F|0)==0){V=0;while(1){_=c[a+12160+(V<<3)>>2]|0;R=(c[a+12160+(V<<3)+4>>2]|0)+(L<<F)|0;W=((ba(c[a+12128+(V<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((V&1)<<(B&1|4))|0;la=c[a+12128+(V<<3)+4>>2]|0;if((L<<F|0)==0){X=V>>1;Aa=((ba(la,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;Ba=X}else{Aa=R-la|0;Ba=V>>1}la=((Aa&T)<<F)+(W&T)|0;X=(c[(a+12208|0)>>2]|0)+((ba(Ba,Y<<3)|0)+(V<<3&8))|0;if((B&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>1,Y)|0)+(_>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((R&T)<<F)+(_&T)|0)<<2)>>2]&1023](X,Z,Y,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Aa>>1,Y)|0)+(W>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(la<<2)>>2]&1023](X,Z,Y,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>2,Y)|0)+(_>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((R&T)<<F)+(_&T)|0)<<2)>>2]&4095](X,Z,Y);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Aa>>2,Y)|0)+(W>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](X,Z,Y)}V=V+1|0;if((V|0)>=4){break d}}}if((L<<F|0)==0){V=0;do{Z=(c[a+12160+(V<<3)>>2]|0)+(K<<F)|0;X=c[a+12160+(V<<3)+4>>2]|0;la=Z-(c[a+12128+(V<<3)>>2]|0)|0;W=V>>1;_=((ba(c[a+12128+(V<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(W<<(B&1|4))|0;R=(c[(a+12208|0)>>2]|0)+((V<<3&8)+(ba(W,Y<<3)|0))|0;if((B&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,Y)|0)+(Z>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((X&T)<<F)+(Z&T)|0)<<2)>>2]&1023](R,W,Y,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>1,Y)|0)+(la>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((_&T)<<F)+(la&T)|0)<<2)>>2]&1023](R,W,Y,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>2,Y)|0)+(Z>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<F)+(Z&T)|0)<<2)>>2]&4095](R,W,Y);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>2,Y)|0)+(la>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((_&T)<<F)+(la&T)|0)<<2)>>2]&4095](R,W,Y)}V=V+1|0;}while((V|0)<4)}else{V=0;do{W=(c[a+12160+(V<<3)>>2]|0)+(K<<F)|0;R=(c[a+12160+(V<<3)+4>>2]|0)+(L<<F)|0;la=W-(c[a+12128+(V<<3)>>2]|0)|0;_=R-(c[a+12128+(V<<3)+4>>2]|0)|0;Z=(c[(a+12208|0)>>2]|0)+((V<<3&8)+(ba(V>>1,Y<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>1,Y)|0)+(W>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((R&T)<<F)+(W&T)|0)<<2)>>2]&1023](Z,X,Y,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>1,Y)|0)+(la>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((_&T)<<F)+(la&T)|0)<<2)>>2]&1023](Z,X,Y,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>2,Y)|0)+(W>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((R&T)<<F)+(W&T)|0)<<2)>>2]&4095](Z,X,Y);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>2,Y)|0)+(la>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((_&T)<<F)+(la&T)|0)<<2)>>2]&4095](Z,X,Y)}V=V+1|0;}while((V|0)<4)}}else{V=(c[a+12160>>2]|0)+(K<<F)|0;X=(c[a+12164>>2]|0)+(L<<F)|0;Z=c[a+12128>>2]|0;if((K<<F|0)==0){Ca=(ba(Z,S-Q|0)|0)/(Q|0)|0}else{Ca=V-Z|0}Z=c[a+12132>>2]|0;if((L<<F|0)==0){Da=(ba(Z,S-Q|0)|0)/(Q|0)|0}else{Da=X-Z|0}Z=((Da&T)<<F)+(Ca&T)|0;if((B&1|0)==0){la=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,Y)|0)+(V>>1))|0;cf[c[(c[a+12444>>2]|0)+((((X&T)<<F)+(V&T)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,la,Y,16);la=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Da>>1,Y)|0)+(Ca>>1))|0;cf[c[(c[a+12448>>2]|0)+(Z<<2)>>2]&1023](c[(a+12208|0)>>2]|0,la,Y,16);break}else{la=(ba(X>>2,Y)|0)+(V>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<F)+(V&T)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+la|0,Y);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<F)+(V&T)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(la+8|0)|0,Y);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<F)+(V&T)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Y<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(la+(Y<<3))|0,Y);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<F)+(V&T)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Y<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((la+8|0)+(Y<<3))|0,Y);la=(ba(Da>>2,Y)|0)+(Ca>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+la|0,Y);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(la+8|0)|0,Y);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Y<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(la+(Y<<3))|0,Y);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Y<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((la+8|0)+(Y<<3))|0,Y);break}}}while(0);za=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,Y,16)|0}}while(0);c[(C+(((L<<3)+K&63)<<2)|0)>>2]=M;c[s+(((L<<3)+K&63)<<2)>>2]=za;T=c[(j+16|0)>>2]>>F;Q=c[(j+20|0)>>2]>>F;S=(ba((d[y+((Q<<F)-A)|0]|0)+(d[y+((T<<F)-z)|0]|0)|0,p)|0)+za|0;if((S|0)>=(oa|0)){wa=oa;xa=pa;ya=qa;break}c[(n|0)>>2]=T;c[o+4>>2]=Q;wa=S;xa=T;ya=Q}}while(0);K=c[(j+28|0)>>2]>>F;L=c[(j+24|0)>>2]>>F;M=L+J+(K<<11)|0;do{if((c[(C+(((K<<3)+L&63)<<2)|0)>>2]|0)==(M|0)){Ea=wa;Fa=xa;Ga=ya}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;T=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ba(Q,K)|0)+L)|0;ca=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){Ha=ca;break}S=c[a+12208>>2]|0;la=(ba(T,K>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&1023](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+la|0,T,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&1023](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+la|0,T,4);la=(Pe[H&255](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,T,4)|0)+ca|0;Ha=la+(Pe[H&255](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,T,4)|0)|0}else{T=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Ha=536870912;break}if((L<<F|0)>(c[(a+12268|0)>>2]<<F|0)){Ha=536870912;break}if((c[(a+12272|0)>>2]|0)>(K|0)){Ha=536870912;break}if((K<<F|0)>(c[(a+12276|0)>>2]<<F|0)){Ha=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;la=(B&1)<<1|1;e:do{if((c[a+11740>>2]|0)==1){if((L<<F|0)==0){ca=0;while(1){Z=c[a+12160+(ca<<3)>>2]|0;V=(c[a+12160+(ca<<3)+4>>2]|0)+(K<<F)|0;X=((ba(c[a+12128+(ca<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((ca&1)<<(B&1|4))|0;_=c[a+12128+(ca<<3)+4>>2]|0;if((K<<F|0)==0){W=ca>>1;Ia=((ba(_,S-Q|0)|0)/(Q|0)|0)+(W<<(B&1|4))|0;Ja=W}else{Ia=V-_|0;Ja=ca>>1}_=((Ia&la)<<F)+(X&la)|0;W=(c[(a+12208|0)>>2]|0)+((ba(Ja,T<<3)|0)+(ca<<3&8))|0;if((B&1|0)==0){R=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>1,T)|0)+(Z>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((V&la)<<F)+(Z&la)|0)<<2)>>2]&1023](W,R,T,8);R=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ia>>1,T)|0)+(X>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(_<<2)>>2]&1023](W,R,T,8)}else{R=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>2,T)|0)+(Z>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<F)+(Z&la)|0)<<2)>>2]&4095](W,R,T);R=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ia>>2,T)|0)+(X>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](W,R,T)}ca=ca+1|0;if((ca|0)>=4){break e}}}if((K<<F|0)==0){ca=0;do{R=(c[a+12160+(ca<<3)>>2]|0)+(L<<F)|0;W=c[a+12160+(ca<<3)+4>>2]|0;_=R-(c[a+12128+(ca<<3)>>2]|0)|0;X=ca>>1;Z=((ba(c[a+12128+(ca<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;V=(c[(a+12208|0)>>2]|0)+((ca<<3&8)+(ba(X,T<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,T)|0)+(R>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((W&la)<<F)+(R&la)|0)<<2)>>2]&1023](V,X,T,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Z>>1,T)|0)+(_>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((Z&la)<<F)+(_&la)|0)<<2)>>2]&1023](V,X,T,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>2,T)|0)+(R>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<F)+(R&la)|0)<<2)>>2]&4095](V,X,T);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Z>>2,T)|0)+(_>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((Z&la)<<F)+(_&la)|0)<<2)>>2]&4095](V,X,T)}ca=ca+1|0;}while((ca|0)<4)}else{ca=0;do{X=(c[a+12160+(ca<<3)>>2]|0)+(L<<F)|0;V=(c[a+12160+(ca<<3)+4>>2]|0)+(K<<F)|0;_=X-(c[a+12128+(ca<<3)>>2]|0)|0;Z=V-(c[a+12128+(ca<<3)+4>>2]|0)|0;R=(c[(a+12208|0)>>2]|0)+((ca<<3&8)+(ba(ca>>1,T<<3)|0))|0;if((B&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>1,T)|0)+(X>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((V&la)<<F)+(X&la)|0)<<2)>>2]&1023](R,W,T,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Z>>1,T)|0)+(_>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((Z&la)<<F)+(_&la)|0)<<2)>>2]&1023](R,W,T,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>2,T)|0)+(X>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<F)+(X&la)|0)<<2)>>2]&4095](R,W,T);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Z>>2,T)|0)+(_>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((Z&la)<<F)+(_&la)|0)<<2)>>2]&4095](R,W,T)}ca=ca+1|0;}while((ca|0)<4)}}else{ca=(c[a+12160>>2]|0)+(L<<F)|0;W=(c[a+12164>>2]|0)+(K<<F)|0;R=c[a+12128>>2]|0;if((L<<F|0)==0){Ka=(ba(R,S-Q|0)|0)/(Q|0)|0}else{Ka=ca-R|0}R=c[a+12132>>2]|0;if((K<<F|0)==0){La=(ba(R,S-Q|0)|0)/(Q|0)|0}else{La=W-R|0}R=((La&la)<<F)+(Ka&la)|0;if((B&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,T)|0)+(ca>>1))|0;cf[c[(c[a+12444>>2]|0)+((((W&la)<<F)+(ca&la)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,_,T,16);_=(c[a+12352+(l<<4)+32>>2]|0)+((ba(La>>1,T)|0)+(Ka>>1))|0;cf[c[(c[a+12448>>2]|0)+(R<<2)>>2]&1023](c[(a+12208|0)>>2]|0,_,T,16);break}else{_=(ba(W>>2,T)|0)+(ca>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<F)+(ca&la)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+_|0,T);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<F)+(ca&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_+8|0)|0,T);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<F)+(ca&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(T<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_+(T<<3))|0,T);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<F)+(ca&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((_+8|0)+(T<<3))|0,T);_=(ba(La>>2,T)|0)+(Ka>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(R<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+_|0,T);Xe[c[(c[(a+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_+8|0)|0,T);Xe[c[(c[(a+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(T<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_+(T<<3))|0,T);Xe[c[(c[(a+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((_+8|0)+(T<<3))|0,T);break}}}while(0);Ha=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,T,16)|0}}while(0);c[(C+(((K<<3)+L&63)<<2)|0)>>2]=M;c[s+(((K<<3)+L&63)<<2)>>2]=Ha;la=c[(j+24|0)>>2]>>F;Q=c[(j+28|0)>>2]>>F;S=(ba((d[y+((Q<<F)-A)|0]|0)+(d[y+((la<<F)-z)|0]|0)|0,p)|0)+Ha|0;if((S|0)>=(wa|0)){Ea=wa;Fa=xa;Ga=ya;break}c[(n|0)>>2]=la;c[o+4>>2]=Q;Ea=S;Fa=la;Ga=Q}}while(0);L=(b[m+(r<<2)>>1]<<15)+32768>>16;K=(b[m+(r<<2)+2>>1]<<15)+32768>>16;M=(L|0)>(v|0)?v:L;L=(t|0)>(M|0)?t:M;M=(K|0)>(x|0)?x:K;K=(u|0)>(M|0)?u:M;M=L+J+(K<<11)|0;if((c[(C+(((K<<3)+L&63)<<2)|0)>>2]|0)==(M|0)){Ma=Ea;Na=Fa;Oa=Ga;break}do{if((B&4|0)==0){Q=c[a+12416>>2]|0;la=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ba(Q,K)|0)+L)|0;Y=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){Pa=Y;break}S=c[a+12208>>2]|0;_=(ba(la,K>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&1023](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+_|0,la,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&1023](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+_|0,la,4);_=(Pe[H&255](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,la,4)|0)+Y|0;Pa=_+(Pe[H&255](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,la,4)|0)|0}else{la=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Pa=536870912;break}if((L<<F|0)>(c[(a+12268|0)>>2]<<F|0)){Pa=536870912;break}if((c[(a+12272|0)>>2]|0)>(K|0)){Pa=536870912;break}if((K<<F|0)>(c[(a+12276|0)>>2]<<F|0)){Pa=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;_=(B&1)<<1|1;f:do{if((c[a+11740>>2]|0)==1){if((L<<F|0)==0){Y=0;while(1){R=c[a+12160+(Y<<3)>>2]|0;ca=(c[a+12160+(Y<<3)+4>>2]|0)+(K<<F)|0;W=((ba(c[a+12128+(Y<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((Y&1)<<(B&1|4))|0;Z=c[a+12128+(Y<<3)+4>>2]|0;if((K<<F|0)==0){X=Y>>1;Qa=((ba(Z,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;Ra=X}else{Qa=ca-Z|0;Ra=Y>>1}Z=((Qa&_)<<F)+(W&_)|0;X=(c[(a+12208|0)>>2]|0)+((ba(Ra,la<<3)|0)+(Y<<3&8))|0;if((B&1|0)==0){V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ca>>1,la)|0)+(R>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ca&_)<<F)+(R&_)|0)<<2)>>2]&1023](X,V,la,8);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Qa>>1,la)|0)+(W>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Z<<2)>>2]&1023](X,V,la,8)}else{V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ca>>2,la)|0)+(R>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ca&_)<<F)+(R&_)|0)<<2)>>2]&4095](X,V,la);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Qa>>2,la)|0)+(W>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095](X,V,la)}Y=Y+1|0;if((Y|0)>=4){break f}}}if((K<<F|0)==0){Y=0;do{T=(c[a+12160+(Y<<3)>>2]|0)+(L<<F)|0;V=c[a+12160+(Y<<3)+4>>2]|0;X=T-(c[a+12128+(Y<<3)>>2]|0)|0;Z=Y>>1;W=((ba(c[a+12128+(Y<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(Z<<(B&1|4))|0;R=(c[(a+12208|0)>>2]|0)+((Y<<3&8)+(ba(Z,la<<3)|0))|0;if((B&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>1,la)|0)+(T>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((V&_)<<F)+(T&_)|0)<<2)>>2]&1023](R,Z,la,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>1,la)|0)+(X>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((W&_)<<F)+(X&_)|0)<<2)>>2]&1023](R,Z,la,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>2,la)|0)+(T>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<F)+(T&_)|0)<<2)>>2]&4095](R,Z,la);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>2,la)|0)+(X>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((W&_)<<F)+(X&_)|0)<<2)>>2]&4095](R,Z,la)}Y=Y+1|0;}while((Y|0)<4)}else{Y=0;do{Z=(c[a+12160+(Y<<3)>>2]|0)+(L<<F)|0;R=(c[a+12160+(Y<<3)+4>>2]|0)+(K<<F)|0;X=Z-(c[a+12128+(Y<<3)>>2]|0)|0;W=R-(c[a+12128+(Y<<3)+4>>2]|0)|0;T=(c[(a+12208|0)>>2]|0)+((Y<<3&8)+(ba(Y>>1,la<<3)|0))|0;if((B&1|0)==0){V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>1,la)|0)+(Z>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((R&_)<<F)+(Z&_)|0)<<2)>>2]&1023](T,V,la,8);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>1,la)|0)+(X>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((W&_)<<F)+(X&_)|0)<<2)>>2]&1023](T,V,la,8)}else{V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>2,la)|0)+(Z>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((R&_)<<F)+(Z&_)|0)<<2)>>2]&4095](T,V,la);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>2,la)|0)+(X>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((W&_)<<F)+(X&_)|0)<<2)>>2]&4095](T,V,la)}Y=Y+1|0;}while((Y|0)<4)}}else{Y=(c[a+12160>>2]|0)+(L<<F)|0;V=(c[a+12164>>2]|0)+(K<<F)|0;T=c[a+12128>>2]|0;if((L<<F|0)==0){Sa=(ba(T,S-Q|0)|0)/(Q|0)|0}else{Sa=Y-T|0}T=c[a+12132>>2]|0;if((K<<F|0)==0){Ta=(ba(T,S-Q|0)|0)/(Q|0)|0}else{Ta=V-T|0}T=((Ta&_)<<F)+(Sa&_)|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>1,la)|0)+(Y>>1))|0;cf[c[(c[a+12444>>2]|0)+((((V&_)<<F)+(Y&_)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,X,la,16);X=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Ta>>1,la)|0)+(Sa>>1))|0;cf[c[(c[a+12448>>2]|0)+(T<<2)>>2]&1023](c[(a+12208|0)>>2]|0,X,la,16);break}else{X=(ba(V>>2,la)|0)+(Y>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<F)+(Y&_)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+X|0,la);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<F)+(Y&_)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(X+8|0)|0,la);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<F)+(Y&_)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(la<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(X+(la<<3))|0,la);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<F)+(Y&_)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((la<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((X+8|0)+(la<<3))|0,la);X=(ba(Ta>>2,la)|0)+(Sa>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+X|0,la);Xe[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(X+8|0)|0,la);Xe[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(la<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(X+(la<<3))|0,la);Xe[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((la<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((X+8|0)+(la<<3))|0,la);break}}}while(0);Pa=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,la,16)|0}}while(0);c[(C+(((K<<3)+L&63)<<2)|0)>>2]=M;c[s+(((K<<3)+L&63)<<2)>>2]=Pa;_=(ba((d[y+((K<<F)-A)|0]|0)+(d[y+((L<<F)-z)|0]|0)|0,p)|0)+Pa|0;if((_|0)>=(Ea|0)){Ma=Ea;Na=Fa;Oa=Ga;break}c[(n|0)>>2]=L;c[o+4>>2]=K;Ma=_;Na=L;Oa=K}else{I=1}}if(I){I=0;if(1){_=c[(j+12|0)>>2]>>F;Q=c[(j+8|0)>>2]>>F;S=Q+J+(_<<11)|0;do{if((c[(C+(((_<<3)+Q&63)<<2)|0)>>2]|0)==(S|0)){Ua=1e6;Va=0;Wa=0}else{do{if((B&4|0)==0){X=c[a+12416>>2]|0;T=c[a+12420>>2]|0;Y=(c[a+12352+(l<<4)>>2]|0)+((ba(X,_)|0)+Q)|0;V=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,Y,X,8)|0;if((B&2|0)==0){Xa=V;break}Y=c[a+12208>>2]|0;W=(ba(T,_>>1)|0)+(Q>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&1023](Y+(X<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+W|0,T,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&1023](Y+(X<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+W|0,T,4);W=(Pe[H&255](a,Y+(X<<4)|0,c[a+12288+(k<<4)+4>>2]|0,T,4)|0)+V|0;Xa=W+(Pe[H&255](a,Y+(X<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,T,4)|0)|0}else{T=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Q|0)){Xa=536870912;break}if((Q<<F|0)>(c[(a+12268|0)>>2]<<F|0)){Xa=536870912;break}if((c[(a+12272|0)>>2]|0)>(_|0)){Xa=536870912;break}if((_<<F|0)>(c[(a+12276|0)>>2]<<F|0)){Xa=536870912;break}X=e[a+13872>>1]|0;Y=e[a+13874>>1]|0;W=(B&1)<<1|1;g:do{if((c[a+11740>>2]|0)==1){if((Q<<F|0)==0){V=0;while(1){Z=c[a+12160+(V<<3)>>2]|0;R=(c[a+12160+(V<<3)+4>>2]|0)+(_<<F)|0;ca=((ba(c[a+12128+(V<<3)>>2]|0,Y-X|0)|0)/(X|0)|0)+((V&1)<<(B&1|4))|0;Ya=c[a+12128+(V<<3)+4>>2]|0;if((_<<F|0)==0){Za=V>>1;_a=((ba(Ya,Y-X|0)|0)/(X|0)|0)+(Za<<(B&1|4))|0;$a=Za}else{_a=R-Ya|0;$a=V>>1}Ya=((_a&W)<<F)+(ca&W)|0;Za=(c[(a+12208|0)>>2]|0)+((ba($a,T<<3)|0)+(V<<3&8))|0;if((B&1|0)==0){ab=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>1,T)|0)+(Z>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((R&W)<<F)+(Z&W)|0)<<2)>>2]&1023](Za,ab,T,8);ab=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_a>>1,T)|0)+(ca>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Ya<<2)>>2]&1023](Za,ab,T,8)}else{ab=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>2,T)|0)+(Z>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((R&W)<<F)+(Z&W)|0)<<2)>>2]&4095](Za,ab,T);ab=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_a>>2,T)|0)+(ca>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095](Za,ab,T)}V=V+1|0;if((V|0)>=4){break g}}}if((_<<F|0)==0){V=0;do{ab=(c[a+12160+(V<<3)>>2]|0)+(Q<<F)|0;Za=c[a+12160+(V<<3)+4>>2]|0;Ya=ab-(c[a+12128+(V<<3)>>2]|0)|0;ca=V>>1;Z=((ba(c[a+12128+(V<<3)+4>>2]|0,Y-X|0)|0)/(X|0)|0)+(ca<<(B&1|4))|0;R=(c[(a+12208|0)>>2]|0)+((V<<3&8)+(ba(ca,T<<3)|0))|0;if((B&1|0)==0){ca=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Za>>1,T)|0)+(ab>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Za&W)<<F)+(ab&W)|0)<<2)>>2]&1023](R,ca,T,8);ca=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Z>>1,T)|0)+(Ya>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((Z&W)<<F)+(Ya&W)|0)<<2)>>2]&1023](R,ca,T,8)}else{ca=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Za>>2,T)|0)+(ab>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<F)+(ab&W)|0)<<2)>>2]&4095](R,ca,T);ca=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Z>>2,T)|0)+(Ya>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((Z&W)<<F)+(Ya&W)|0)<<2)>>2]&4095](R,ca,T)}V=V+1|0;}while((V|0)<4)}else{V=0;do{ca=(c[a+12160+(V<<3)>>2]|0)+(Q<<F)|0;R=(c[a+12160+(V<<3)+4>>2]|0)+(_<<F)|0;Ya=ca-(c[a+12128+(V<<3)>>2]|0)|0;Z=R-(c[a+12128+(V<<3)+4>>2]|0)|0;ab=(c[(a+12208|0)>>2]|0)+((V<<3&8)+(ba(V>>1,T<<3)|0))|0;if((B&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>1,T)|0)+(ca>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((R&W)<<F)+(ca&W)|0)<<2)>>2]&1023](ab,Za,T,8);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Z>>1,T)|0)+(Ya>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((Z&W)<<F)+(Ya&W)|0)<<2)>>2]&1023](ab,Za,T,8)}else{Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(R>>2,T)|0)+(ca>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((R&W)<<F)+(ca&W)|0)<<2)>>2]&4095](ab,Za,T);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Z>>2,T)|0)+(Ya>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((Z&W)<<F)+(Ya&W)|0)<<2)>>2]&4095](ab,Za,T)}V=V+1|0;}while((V|0)<4)}}else{V=(c[a+12160>>2]|0)+(Q<<F)|0;Za=(c[a+12164>>2]|0)+(_<<F)|0;ab=c[a+12128>>2]|0;if((Q<<F|0)==0){bb=(ba(ab,Y-X|0)|0)/(X|0)|0}else{bb=V-ab|0}ab=c[a+12132>>2]|0;if((_<<F|0)==0){cb=(ba(ab,Y-X|0)|0)/(X|0)|0}else{cb=Za-ab|0}ab=((cb&W)<<F)+(bb&W)|0;if((B&1|0)==0){Ya=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Za>>1,T)|0)+(V>>1))|0;cf[c[(c[a+12444>>2]|0)+((((Za&W)<<F)+(V&W)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Ya,T,16);Ya=(c[a+12352+(l<<4)+32>>2]|0)+((ba(cb>>1,T)|0)+(bb>>1))|0;cf[c[(c[a+12448>>2]|0)+(ab<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Ya,T,16);break}else{Ya=(ba(Za>>2,T)|0)+(V>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<F)+(V&W)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Ya|0,T);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<F)+(V&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ya+8|0)|0,T);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<F)+(V&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(T<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ya+(T<<3))|0,T);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<F)+(V&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Ya+8|0)+(T<<3))|0,T);Ya=(ba(cb>>2,T)|0)+(bb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Ya|0,T);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ya+8|0)|0,T);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(T<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ya+(T<<3))|0,T);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Ya+8|0)+(T<<3))|0,T);break}}}while(0);Xa=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,T,16)|0}}while(0);c[(C+(((_<<3)+Q&63)<<2)|0)>>2]=S;c[s+(((_<<3)+Q&63)<<2)>>2]=Xa;la=c[(j+8|0)>>2]>>F;W=c[(j+12|0)>>2]>>F;X=(ba((d[y+((W<<F)-A)|0]|0)+(d[y+((la<<F)-z)|0]|0)|0,p)|0)+Xa|0;if((X|0)>=1e6){Ua=1e6;Va=0;Wa=0;break}c[(n|0)>>2]=la;c[o+4>>2]=W;Ua=X;Va=la;Wa=W}}while(0);Q=(b[m+(r<<2)>>1]<<15)+32768>>16;_=(b[m+(r<<2)+2>>1]<<15)+32768>>16;S=(Q|0)>(v|0)?v:Q;Q=(t|0)>(S|0)?t:S;S=(_|0)>(x|0)?x:_;_=(u|0)>(S|0)?u:S;S=Q+J+(_<<11)|0;do{if((c[(C+(((_<<3)+Q&63)<<2)|0)>>2]|0)==(S|0)){db=Ua;eb=Va;fb=Wa}else{do{if((B&4|0)==0){K=c[a+12416>>2]|0;L=c[a+12420>>2]|0;M=(c[a+12352+(l<<4)>>2]|0)+((ba(K,_)|0)+Q)|0;W=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,M,K,8)|0;if((B&2|0)==0){gb=W;break}M=c[a+12208>>2]|0;la=(ba(L,_>>1)|0)+(Q>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&1023](M+(K<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+la|0,L,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&1023](M+(K<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+la|0,L,4);la=(Pe[H&255](a,M+(K<<4)|0,c[a+12288+(k<<4)+4>>2]|0,L,4)|0)+W|0;gb=la+(Pe[H&255](a,M+(K<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,L,4)|0)|0}else{L=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Q|0)){gb=536870912;break}if((Q<<F|0)>(c[(a+12268|0)>>2]<<F|0)){gb=536870912;break}if((c[(a+12272|0)>>2]|0)>(_|0)){gb=536870912;break}if((_<<F|0)>(c[(a+12276|0)>>2]<<F|0)){gb=536870912;break}K=e[a+13872>>1]|0;M=e[a+13874>>1]|0;la=(B&1)<<1|1;h:do{if((c[a+11740>>2]|0)==1){if((Q<<F|0)==0){W=0;while(1){X=c[a+12160+(W<<3)>>2]|0;Y=(c[a+12160+(W<<3)+4>>2]|0)+(_<<F)|0;Ya=((ba(c[a+12128+(W<<3)>>2]|0,M-K|0)|0)/(K|0)|0)+((W&1)<<(B&1|4))|0;ab=c[a+12128+(W<<3)+4>>2]|0;if((_<<F|0)==0){V=W>>1;hb=((ba(ab,M-K|0)|0)/(K|0)|0)+(V<<(B&1|4))|0;ib=V}else{hb=Y-ab|0;ib=W>>1}ab=((hb&la)<<F)+(Ya&la)|0;V=(c[(a+12208|0)>>2]|0)+((ba(ib,L<<3)|0)+(W<<3&8))|0;if((B&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,L)|0)+(X>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&la)<<F)+(X&la)|0)<<2)>>2]&1023](V,Za,L,8);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(hb>>1,L)|0)+(Ya>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(ab<<2)>>2]&1023](V,Za,L,8)}else{Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>2,L)|0)+(X>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&la)<<F)+(X&la)|0)<<2)>>2]&4095](V,Za,L);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(hb>>2,L)|0)+(Ya>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095](V,Za,L)}W=W+1|0;if((W|0)>=4){break h}}}if((_<<F|0)==0){W=0;do{Za=(c[a+12160+(W<<3)>>2]|0)+(Q<<F)|0;V=c[a+12160+(W<<3)+4>>2]|0;ab=Za-(c[a+12128+(W<<3)>>2]|0)|0;Ya=W>>1;X=((ba(c[a+12128+(W<<3)+4>>2]|0,M-K|0)|0)/(K|0)|0)+(Ya<<(B&1|4))|0;Y=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ba(Ya,L<<3)|0))|0;if((B&1|0)==0){Ya=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>1,L)|0)+(Za>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((V&la)<<F)+(Za&la)|0)<<2)>>2]&1023](Y,Ya,L,8);Ya=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>1,L)|0)+(ab>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((X&la)<<F)+(ab&la)|0)<<2)>>2]&1023](Y,Ya,L,8)}else{Ya=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>2,L)|0)+(Za>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<F)+(Za&la)|0)<<2)>>2]&4095](Y,Ya,L);Ya=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>2,L)|0)+(ab>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((X&la)<<F)+(ab&la)|0)<<2)>>2]&4095](Y,Ya,L)}W=W+1|0;}while((W|0)<4)}else{W=0;do{Ya=(c[a+12160+(W<<3)>>2]|0)+(Q<<F)|0;Y=(c[a+12160+(W<<3)+4>>2]|0)+(_<<F)|0;ab=Ya-(c[a+12128+(W<<3)>>2]|0)|0;X=Y-(c[a+12128+(W<<3)+4>>2]|0)|0;Za=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ba(W>>1,L<<3)|0))|0;if((B&1|0)==0){V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,L)|0)+(Ya>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&la)<<F)+(Ya&la)|0)<<2)>>2]&1023](Za,V,L,8);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>1,L)|0)+(ab>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((X&la)<<F)+(ab&la)|0)<<2)>>2]&1023](Za,V,L,8)}else{V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>2,L)|0)+(Ya>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&la)<<F)+(Ya&la)|0)<<2)>>2]&4095](Za,V,L);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>2,L)|0)+(ab>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((X&la)<<F)+(ab&la)|0)<<2)>>2]&4095](Za,V,L)}W=W+1|0;}while((W|0)<4)}}else{W=(c[a+12160>>2]|0)+(Q<<F)|0;V=(c[a+12164>>2]|0)+(_<<F)|0;Za=c[a+12128>>2]|0;if((Q<<F|0)==0){jb=(ba(Za,M-K|0)|0)/(K|0)|0}else{jb=W-Za|0}Za=c[a+12132>>2]|0;if((_<<F|0)==0){kb=(ba(Za,M-K|0)|0)/(K|0)|0}else{kb=V-Za|0}Za=((kb&la)<<F)+(jb&la)|0;if((B&1|0)==0){ab=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V>>1,L)|0)+(W>>1))|0;cf[c[(c[a+12444>>2]|0)+((((V&la)<<F)+(W&la)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ab,L,16);ab=(c[a+12352+(l<<4)+32>>2]|0)+((ba(kb>>1,L)|0)+(jb>>1))|0;cf[c[(c[a+12448>>2]|0)+(Za<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ab,L,16);break}else{ab=(ba(V>>2,L)|0)+(W>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<F)+(W&la)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ab|0,L);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<F)+(W&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ab+8|0)|0,L);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<F)+(W&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ab+(L<<3))|0,L);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<F)+(W&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ab+8|0)+(L<<3))|0,L);ab=(ba(kb>>2,L)|0)+(jb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ab|0,L);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ab+8|0)|0,L);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ab+(L<<3))|0,L);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ab+8|0)+(L<<3))|0,L);break}}}while(0);gb=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,L,16)|0}}while(0);c[(C+(((_<<3)+Q&63)<<2)|0)>>2]=S;c[s+(((_<<3)+Q&63)<<2)>>2]=gb;la=(ba((d[y+((_<<F)-A)|0]|0)+(d[y+((Q<<F)-z)|0]|0)|0,p)|0)+gb|0;if((la|0)>=(Ua|0)){db=Ua;eb=Va;fb=Wa;break}c[(n|0)>>2]=Q;c[o+4>>2]=_;db=la;eb=Q;fb=_}}while(0);_=c[(j+76|0)>>2]>>F;Q=c[(j+72|0)>>2]>>F;S=Q+J+(_<<11)|0;if((c[(C+(((_<<3)+Q&63)<<2)|0)>>2]|0)==(S|0)){Ma=db;Na=eb;Oa=fb;break}do{if((B&4|0)==0){la=c[a+12416>>2]|0;K=c[a+12420>>2]|0;M=(c[a+12352+(l<<4)>>2]|0)+((ba(la,_)|0)+Q)|0;T=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,M,la,8)|0;if((B&2|0)==0){lb=T;break}M=c[a+12208>>2]|0;ab=(ba(K,_>>1)|0)+(Q>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&1023](M+(la<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ab|0,K,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&1023](M+(la<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ab|0,K,4);ab=(Pe[H&255](a,M+(la<<4)|0,c[a+12288+(k<<4)+4>>2]|0,K,4)|0)+T|0;lb=ab+(Pe[H&255](a,M+(la<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,K,4)|0)|0}else{K=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Q|0)){lb=536870912;break}if((Q<<F|0)>(c[(a+12268|0)>>2]<<F|0)){lb=536870912;break}if((c[(a+12272|0)>>2]|0)>(_|0)){lb=536870912;break}if((_<<F|0)>(c[(a+12276|0)>>2]<<F|0)){lb=536870912;break}la=e[a+13872>>1]|0;M=e[a+13874>>1]|0;ab=(B&1)<<1|1;i:do{if((c[a+11740>>2]|0)==1){if((Q<<F|0)==0){T=0;while(1){Za=c[a+12160+(T<<3)>>2]|0;W=(c[a+12160+(T<<3)+4>>2]|0)+(_<<F)|0;V=((ba(c[a+12128+(T<<3)>>2]|0,M-la|0)|0)/(la|0)|0)+((T&1)<<(B&1|4))|0;X=c[a+12128+(T<<3)+4>>2]|0;if((_<<F|0)==0){Ya=T>>1;mb=((ba(X,M-la|0)|0)/(la|0)|0)+(Ya<<(B&1|4))|0;nb=Ya}else{mb=W-X|0;nb=T>>1}X=((mb&ab)<<F)+(V&ab)|0;Ya=(c[(a+12208|0)>>2]|0)+((ba(nb,K<<3)|0)+(T<<3&8))|0;if((B&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,K)|0)+(Za>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((W&ab)<<F)+(Za&ab)|0)<<2)>>2]&1023](Ya,Y,K,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(mb>>1,K)|0)+(V>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(X<<2)>>2]&1023](Ya,Y,K,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>2,K)|0)+(Za>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&ab)<<F)+(Za&ab)|0)<<2)>>2]&4095](Ya,Y,K);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(mb>>2,K)|0)+(V>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(X<<2)>>2]&4095](Ya,Y,K)}T=T+1|0;if((T|0)>=4){break i}}}if((_<<F|0)==0){T=0;do{L=(c[a+12160+(T<<3)>>2]|0)+(Q<<F)|0;Y=c[a+12160+(T<<3)+4>>2]|0;Ya=L-(c[a+12128+(T<<3)>>2]|0)|0;X=T>>1;V=((ba(c[a+12128+(T<<3)+4>>2]|0,M-la|0)|0)/(la|0)|0)+(X<<(B&1|4))|0;Za=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ba(X,K<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,K)|0)+(L>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&ab)<<F)+(L&ab)|0)<<2)>>2]&1023](Za,X,K,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(V>>1,K)|0)+(Ya>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((V&ab)<<F)+(Ya&ab)|0)<<2)>>2]&1023](Za,X,K,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>2,K)|0)+(L>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<F)+(L&ab)|0)<<2)>>2]&4095](Za,X,K);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(V>>2,K)|0)+(Ya>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((V&ab)<<F)+(Ya&ab)|0)<<2)>>2]&4095](Za,X,K)}T=T+1|0;}while((T|0)<4)}else{T=0;do{X=(c[a+12160+(T<<3)>>2]|0)+(Q<<F)|0;Za=(c[a+12160+(T<<3)+4>>2]|0)+(_<<F)|0;Ya=X-(c[a+12128+(T<<3)>>2]|0)|0;V=Za-(c[a+12128+(T<<3)+4>>2]|0)|0;L=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ba(T>>1,K<<3)|0))|0;if((B&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Za>>1,K)|0)+(X>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Za&ab)<<F)+(X&ab)|0)<<2)>>2]&1023](L,Y,K,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(V>>1,K)|0)+(Ya>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((V&ab)<<F)+(Ya&ab)|0)<<2)>>2]&1023](L,Y,K,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Za>>2,K)|0)+(X>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Za&ab)<<F)+(X&ab)|0)<<2)>>2]&4095](L,Y,K);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(V>>2,K)|0)+(Ya>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((V&ab)<<F)+(Ya&ab)|0)<<2)>>2]&4095](L,Y,K)}T=T+1|0;}while((T|0)<4)}}else{T=(c[a+12160>>2]|0)+(Q<<F)|0;Y=(c[a+12164>>2]|0)+(_<<F)|0;L=c[a+12128>>2]|0;if((Q<<F|0)==0){ob=(ba(L,M-la|0)|0)/(la|0)|0}else{ob=T-L|0}L=c[a+12132>>2]|0;if((_<<F|0)==0){pb=(ba(L,M-la|0)|0)/(la|0)|0}else{pb=Y-L|0}L=((pb&ab)<<F)+(ob&ab)|0;if((B&1|0)==0){Ya=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,K)|0)+(T>>1))|0;cf[c[(c[a+12444>>2]|0)+((((Y&ab)<<F)+(T&ab)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Ya,K,16);Ya=(c[a+12352+(l<<4)+32>>2]|0)+((ba(pb>>1,K)|0)+(ob>>1))|0;cf[c[(c[a+12448>>2]|0)+(L<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Ya,K,16);break}else{Ya=(ba(Y>>2,K)|0)+(T>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<F)+(T&ab)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Ya|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<F)+(T&ab)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ya+8|0)|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<F)+(T&ab)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ya+(K<<3))|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<F)+(T&ab)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Ya+8|0)+(K<<3))|0,K);Ya=(ba(pb>>2,K)|0)+(ob>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(L<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Ya|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(L<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ya+8|0)|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(L<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ya+(K<<3))|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(L<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Ya+8|0)+(K<<3))|0,K);break}}}while(0);lb=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(C+(((_<<3)+Q&63)<<2)|0)>>2]=S;c[s+(((_<<3)+Q&63)<<2)>>2]=lb;ab=c[(j+72|0)>>2]>>F;la=c[(j+76|0)>>2]>>F;M=(ba((d[y+((la<<F)-A)|0]|0)+(d[y+((ab<<F)-z)|0]|0)|0,p)|0)+lb|0;if((M|0)>=(db|0)){Ma=db;Na=eb;Oa=fb;break}c[(n|0)>>2]=ab;c[o+4>>2]=la;Ma=M;Na=ab;Oa=la}else{I=1}}}while(0);do{if((Ma|0)>256){fb=(b[m+((r+1|0)<<2)>>1]<<15)+32768>>16;eb=(b[m+((r+1|0)<<2)+2>>1]<<15)+32768>>16;db=(fb|0)>(v|0)?v:fb;fb=(t|0)>(db|0)?t:db;db=(eb|0)>(x|0)?x:eb;eb=(u|0)>(db|0)?u:db;db=fb+J+(eb<<11)|0;do{if((c[(C+(((eb<<3)+fb&63)<<2)|0)>>2]|0)==(db|0)){qb=Ma;rb=Na;sb=Oa}else{do{if((B&4|0)==0){lb=c[a+12416>>2]|0;j=c[a+12420>>2]|0;ob=(c[a+12352+(l<<4)>>2]|0)+((ba(lb,eb)|0)+fb)|0;pb=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,ob,lb,8)|0;if((B&2|0)==0){tb=pb;break}ob=c[a+12208>>2]|0;mb=(ba(j,eb>>1)|0)+(fb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((eb<<1&2|fb&1)<<2)>>2]&1023](ob+(lb<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+mb|0,j,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((eb<<1&2|fb&1)<<2)>>2]&1023](ob+(lb<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+mb|0,j,4);mb=(Pe[H&255](a,ob+(lb<<4)|0,c[a+12288+(k<<4)+4>>2]|0,j,4)|0)+pb|0;tb=mb+(Pe[H&255](a,ob+(lb<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,j,4)|0)|0}else{j=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(fb|0)){tb=536870912;break}if((fb<<F|0)>(c[(a+12268|0)>>2]<<F|0)){tb=536870912;break}if((c[(a+12272|0)>>2]|0)>(eb|0)){tb=536870912;break}if((eb<<F|0)>(c[(a+12276|0)>>2]<<F|0)){tb=536870912;break}lb=e[a+13872>>1]|0;ob=e[a+13874>>1]|0;mb=(B&1)<<1|1;j:do{if((c[a+11740>>2]|0)==1){if((fb<<F|0)==0){pb=0;while(1){nb=c[a+12160+(pb<<3)>>2]|0;Wa=(c[a+12160+(pb<<3)+4>>2]|0)+(eb<<F)|0;Va=((ba(c[a+12128+(pb<<3)>>2]|0,ob-lb|0)|0)/(lb|0)|0)+((pb&1)<<(B&1|4))|0;Ua=c[a+12128+(pb<<3)+4>>2]|0;if((eb<<F|0)==0){gb=pb>>1;ub=((ba(Ua,ob-lb|0)|0)/(lb|0)|0)+(gb<<(B&1|4))|0;vb=gb}else{ub=Wa-Ua|0;vb=pb>>1}Ua=((ub&mb)<<F)+(Va&mb)|0;gb=(c[(a+12208|0)>>2]|0)+((ba(vb,j<<3)|0)+(pb<<3&8))|0;if((B&1|0)==0){jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Wa>>1,j)|0)+(nb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Wa&mb)<<F)+(nb&mb)|0)<<2)>>2]&1023](gb,jb,j,8);jb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ub>>1,j)|0)+(Va>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Ua<<2)>>2]&1023](gb,jb,j,8)}else{jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Wa>>2,j)|0)+(nb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Wa&mb)<<F)+(nb&mb)|0)<<2)>>2]&4095](gb,jb,j);jb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ub>>2,j)|0)+(Va>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Ua<<2)>>2]&4095](gb,jb,j)}pb=pb+1|0;if((pb|0)>=4){break j}}}if((eb<<F|0)==0){pb=0;do{jb=(c[a+12160+(pb<<3)>>2]|0)+(fb<<F)|0;gb=c[a+12160+(pb<<3)+4>>2]|0;Ua=jb-(c[a+12128+(pb<<3)>>2]|0)|0;Va=pb>>1;nb=((ba(c[a+12128+(pb<<3)+4>>2]|0,ob-lb|0)|0)/(lb|0)|0)+(Va<<(B&1|4))|0;Wa=(c[(a+12208|0)>>2]|0)+((pb<<3&8)+(ba(Va,j<<3)|0))|0;if((B&1|0)==0){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(gb>>1,j)|0)+(jb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((gb&mb)<<F)+(jb&mb)|0)<<2)>>2]&1023](Wa,Va,j,8);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(nb>>1,j)|0)+(Ua>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((nb&mb)<<F)+(Ua&mb)|0)<<2)>>2]&1023](Wa,Va,j,8)}else{Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(gb>>2,j)|0)+(jb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<F)+(jb&mb)|0)<<2)>>2]&4095](Wa,Va,j);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(nb>>2,j)|0)+(Ua>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((nb&mb)<<F)+(Ua&mb)|0)<<2)>>2]&4095](Wa,Va,j)}pb=pb+1|0;}while((pb|0)<4)}else{pb=0;do{Va=(c[a+12160+(pb<<3)>>2]|0)+(fb<<F)|0;Wa=(c[a+12160+(pb<<3)+4>>2]|0)+(eb<<F)|0;Ua=Va-(c[a+12128+(pb<<3)>>2]|0)|0;nb=Wa-(c[a+12128+(pb<<3)+4>>2]|0)|0;jb=(c[(a+12208|0)>>2]|0)+((pb<<3&8)+(ba(pb>>1,j<<3)|0))|0;if((B&1|0)==0){gb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Wa>>1,j)|0)+(Va>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Wa&mb)<<F)+(Va&mb)|0)<<2)>>2]&1023](jb,gb,j,8);gb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(nb>>1,j)|0)+(Ua>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((nb&mb)<<F)+(Ua&mb)|0)<<2)>>2]&1023](jb,gb,j,8)}else{gb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Wa>>2,j)|0)+(Va>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Wa&mb)<<F)+(Va&mb)|0)<<2)>>2]&4095](jb,gb,j);gb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(nb>>2,j)|0)+(Ua>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((nb&mb)<<F)+(Ua&mb)|0)<<2)>>2]&4095](jb,gb,j)}pb=pb+1|0;}while((pb|0)<4)}}else{pb=(c[a+12160>>2]|0)+(fb<<F)|0;gb=(c[a+12164>>2]|0)+(eb<<F)|0;jb=c[a+12128>>2]|0;if((fb<<F|0)==0){wb=(ba(jb,ob-lb|0)|0)/(lb|0)|0}else{wb=pb-jb|0}jb=c[a+12132>>2]|0;if((eb<<F|0)==0){xb=(ba(jb,ob-lb|0)|0)/(lb|0)|0}else{xb=gb-jb|0}jb=((xb&mb)<<F)+(wb&mb)|0;if((B&1|0)==0){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(gb>>1,j)|0)+(pb>>1))|0;cf[c[(c[a+12444>>2]|0)+((((gb&mb)<<F)+(pb&mb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Ua,j,16);Ua=(c[a+12352+(l<<4)+32>>2]|0)+((ba(xb>>1,j)|0)+(wb>>1))|0;cf[c[(c[a+12448>>2]|0)+(jb<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Ua,j,16);break}else{Ua=(ba(gb>>2,j)|0)+(pb>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<F)+(pb&mb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Ua|0,j);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<F)+(pb&mb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ua+8|0)|0,j);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<F)+(pb&mb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(j<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ua+(j<<3))|0,j);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<F)+(pb&mb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((j<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Ua+8|0)+(j<<3))|0,j);Ua=(ba(xb>>2,j)|0)+(wb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Ua|0,j);Xe[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ua+8|0)|0,j);Xe[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(j<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ua+(j<<3))|0,j);Xe[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((j<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Ua+8|0)+(j<<3))|0,j);break}}}while(0);tb=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,j,16)|0}}while(0);c[(C+(((eb<<3)+fb&63)<<2)|0)>>2]=db;c[s+(((eb<<3)+fb&63)<<2)>>2]=tb;K=(ba((d[y+((eb<<F)-A)|0]|0)+(d[y+((fb<<F)-z)|0]|0)|0,p)|0)+tb|0;if((K|0)>=(Ma|0)){qb=Ma;rb=Na;sb=Oa;break}c[(n|0)>>2]=fb;c[o+4>>2]=eb;qb=K;rb=fb;sb=eb}}while(0);if(((c[(a+12480|0)>>2]|0)+1|0)>=(c[a+812>>2]|0)){yb=qb;zb=rb;Ab=sb;break}eb=(b[m+((r+q|0)<<2)>>1]<<15)+32768>>16;fb=(b[m+((r+q|0)<<2)+2>>1]<<15)+32768>>16;db=(eb|0)>(v|0)?v:eb;eb=(t|0)>(db|0)?t:db;db=(fb|0)>(x|0)?x:fb;fb=(u|0)>(db|0)?u:db;db=eb+J+(fb<<11)|0;if((c[(C+(((fb<<3)+eb&63)<<2)|0)>>2]|0)==(db|0)){yb=qb;zb=rb;Ab=sb;break}do{if((B&4|0)==0){I=c[a+12416>>2]|0;Q=c[a+12420>>2]|0;_=(c[a+12352+(l<<4)>>2]|0)+((ba(I,fb)|0)+eb)|0;S=Pe[G&255](a,c[a+12288+(k<<4)>>2]|0,_,I,8)|0;if((B&2|0)==0){Bb=S;break}_=c[a+12208>>2]|0;K=(ba(Q,fb>>1)|0)+(eb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((fb<<1&2|eb&1)<<2)>>2]&1023](_+(I<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+K|0,Q,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((fb<<1&2|eb&1)<<2)>>2]&1023](_+(I<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+K|0,Q,4);K=(Pe[H&255](a,_+(I<<4)|0,c[a+12288+(k<<4)+4>>2]|0,Q,4)|0)+S|0;Bb=K+(Pe[H&255](a,_+(I<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,Q,4)|0)|0}else{Q=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(eb|0)){Bb=536870912;break}if((eb<<F|0)>(c[(a+12268|0)>>2]<<F|0)){Bb=536870912;break}if((c[(a+12272|0)>>2]|0)>(fb|0)){Bb=536870912;break}if((fb<<F|0)>(c[(a+12276|0)>>2]<<F|0)){Bb=536870912;break}I=e[a+13872>>1]|0;_=e[a+13874>>1]|0;K=(B&1)<<1|1;k:do{if((c[a+11740>>2]|0)==1){if((eb<<F|0)==0){S=0;while(1){mb=c[a+12160+(S<<3)>>2]|0;lb=(c[a+12160+(S<<3)+4>>2]|0)+(fb<<F)|0;ob=((ba(c[a+12128+(S<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((S&1)<<(B&1|4))|0;Ua=c[a+12128+(S<<3)+4>>2]|0;if((fb<<F|0)==0){jb=S>>1;Cb=((ba(Ua,_-I|0)|0)/(I|0)|0)+(jb<<(B&1|4))|0;Db=jb}else{Cb=lb-Ua|0;Db=S>>1}Ua=((Cb&K)<<F)+(ob&K)|0;jb=(c[(a+12208|0)>>2]|0)+((ba(Db,Q<<3)|0)+(S<<3&8))|0;if((B&1|0)==0){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(lb>>1,Q)|0)+(mb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((lb&K)<<F)+(mb&K)|0)<<2)>>2]&1023](jb,pb,Q,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Cb>>1,Q)|0)+(ob>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Ua<<2)>>2]&1023](jb,pb,Q,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(lb>>2,Q)|0)+(mb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((lb&K)<<F)+(mb&K)|0)<<2)>>2]&4095](jb,pb,Q);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Cb>>2,Q)|0)+(ob>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Ua<<2)>>2]&4095](jb,pb,Q)}S=S+1|0;if((S|0)>=4){break k}}}if((fb<<F|0)==0){S=0;do{j=(c[a+12160+(S<<3)>>2]|0)+(eb<<F)|0;pb=c[a+12160+(S<<3)+4>>2]|0;jb=j-(c[a+12128+(S<<3)>>2]|0)|0;Ua=S>>1;ob=((ba(c[a+12128+(S<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(Ua<<(B&1|4))|0;mb=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ba(Ua,Q<<3)|0))|0;if((B&1|0)==0){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,Q)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&K)<<F)+(j&K)|0)<<2)>>2]&1023](mb,Ua,Q,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>1,Q)|0)+(jb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&K)<<F)+(jb&K)|0)<<2)>>2]&1023](mb,Ua,Q,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>2,Q)|0)+(j>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<F)+(j&K)|0)<<2)>>2]&4095](mb,Ua,Q);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>2,Q)|0)+(jb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ob&K)<<F)+(jb&K)|0)<<2)>>2]&4095](mb,Ua,Q)}S=S+1|0;}while((S|0)<4)}else{S=0;do{Ua=(c[a+12160+(S<<3)>>2]|0)+(eb<<F)|0;mb=(c[a+12160+(S<<3)+4>>2]|0)+(fb<<F)|0;jb=Ua-(c[a+12128+(S<<3)>>2]|0)|0;ob=mb-(c[a+12128+(S<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ba(S>>1,Q<<3)|0))|0;if((B&1|0)==0){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mb>>1,Q)|0)+(Ua>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((mb&K)<<F)+(Ua&K)|0)<<2)>>2]&1023](j,pb,Q,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>1,Q)|0)+(jb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&K)<<F)+(jb&K)|0)<<2)>>2]&1023](j,pb,Q,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mb>>2,Q)|0)+(Ua>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((mb&K)<<F)+(Ua&K)|0)<<2)>>2]&4095](j,pb,Q);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>2,Q)|0)+(jb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ob&K)<<F)+(jb&K)|0)<<2)>>2]&4095](j,pb,Q)}S=S+1|0;}while((S|0)<4)}}else{S=(c[a+12160>>2]|0)+(eb<<F)|0;pb=(c[a+12164>>2]|0)+(fb<<F)|0;j=c[a+12128>>2]|0;if((eb<<F|0)==0){Eb=(ba(j,_-I|0)|0)/(I|0)|0}else{Eb=S-j|0}j=c[a+12132>>2]|0;if((fb<<F|0)==0){Fb=(ba(j,_-I|0)|0)/(I|0)|0}else{Fb=pb-j|0}j=((Fb&K)<<F)+(Eb&K)|0;if((B&1|0)==0){jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,Q)|0)+(S>>1))|0;cf[c[(c[a+12444>>2]|0)+((((pb&K)<<F)+(S&K)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,jb,Q,16);jb=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Fb>>1,Q)|0)+(Eb>>1))|0;cf[c[(c[a+12448>>2]|0)+(j<<2)>>2]&1023](c[(a+12208|0)>>2]|0,jb,Q,16);break}else{jb=(ba(pb>>2,Q)|0)+(S>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<F)+(S&K)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+jb|0,Q);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<F)+(S&K)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+8|0)|0,Q);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<F)+(S&K)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Q<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+(Q<<3))|0,Q);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<F)+(S&K)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Q<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((jb+8|0)+(Q<<3))|0,Q);jb=(ba(Fb>>2,Q)|0)+(Eb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+jb|0,Q);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+8|0)|0,Q);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Q<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+(Q<<3))|0,Q);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Q<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((jb+8|0)+(Q<<3))|0,Q);break}}}while(0);Bb=Pe[G&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,Q,16)|0}}while(0);c[(C+(((fb<<3)+eb&63)<<2)|0)>>2]=db;c[s+(((fb<<3)+eb&63)<<2)>>2]=Bb;K=(ba((d[y+((fb<<F)-A)|0]|0)+(d[y+((eb<<F)-z)|0]|0)|0,p)|0)+Bb|0;if((K|0)>=(qb|0)){yb=qb;zb=rb;Ab=sb;break}c[(n|0)>>2]=eb;c[o+4>>2]=fb;yb=K;zb=eb;Ab=fb}else{yb=Ma;zb=Na;Ab=Oa}}while(0);Oa=n|0;Na=c[(a+12260|0)>>2]|0;if((Na|0)==-1){Ma=c[(a+12220|0)>>2]|0;sb=c[(a+12264|0)>>2]|0;rb=c[(a+12272|0)>>2]|0;qb=c[(a+12268|0)>>2]|0;Bb=c[(a+12276|0)>>2]|0;z=c[(a+12464|0)>>2]|0;y=c[(a+12280|0)>>2]|0;A=c[(a+12284|0)>>2]|0;s=c[(a+12216|0)>>2]|0;C=c[(a+12224|0)>>2]|0;G=c[(a+10468|0)>>2]|0;Eb=c[(a+10472|0)>>2]|0;Fb=(B&1)<<1|1;Cb=B&1|4;Db=(B&1|0)==0;H=yb;J=zb;u=Ab;x=zb;l:while(1){t=1;v=H;q=u;r=x;while(1){do{if((t-1&t|0)==0){m=t+J|0;if((m|0)>(qb|0)){Gb=v;Hb=q;Ib=r;break}tb=J-t|0;if((tb|0)<(sb|0)){Gb=v;Hb=q;Ib=r;break}wb=t+u|0;if((wb|0)>(Bb|0)){Gb=v;Hb=q;Ib=r;break}xb=u-t|0;if((xb|0)<(rb|0)){Gb=v;Hb=q;Ib=r;break}else{Jb=0;Kb=v;Lb=q;Mb=r}while(1){ub=wb-Jb|0;vb=Jb+J|0;do{if((c[(s+(((ub<<3)+vb&63)<<2)|0)>>2]|0)==(vb+C+(ub<<11)|0|0)){Nb=Kb;Ob=Lb;Pb=Mb}else{K=c[(a+12416|0)>>2]|0;do{if((B&4|0)==0){I=c[(a+12420|0)>>2]|0;_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(K,ub)|0)+vb)|0;jb=Pe[G&255](a,c[(a+12288+(k<<4)|0)>>2]|0,_,K,8)|0;if((B&2|0)==0){Qb=jb;break}_=c[(a+12208|0)>>2]|0;j=(ba(I,ub>>1)|0)+(vb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((ub<<1&2|vb&1)<<2)>>2]&1023](_+(K<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+j|0,I,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((ub<<1&2|vb&1)<<2)>>2]&1023](_+(K<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+j|0,I,4);j=(Pe[Eb&255](a,_+(K<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,I,4)|0)+jb|0;Qb=j+(Pe[Eb&255](a,_+(K<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,I,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(vb|0)){Qb=536870912;break}if((vb<<F|0)>(c[(a+12268|0)>>2]<<F|0)){Qb=536870912;break}if((c[(a+12272|0)>>2]|0)>(ub|0)){Qb=536870912;break}if((ub<<F|0)>(c[(a+12276|0)>>2]<<F|0)){Qb=536870912;break}I=e[(a+13872|0)>>1]|0;_=e[(a+13874|0)>>1]|0;m:do{if((c[(a+11740|0)>>2]|0)==1){if((vb<<F|0)==0){j=0;while(1){jb=c[a+12160+(j<<3)>>2]|0;S=(c[a+12160+(j<<3)+4>>2]|0)+(ub<<F)|0;pb=((ba(c[a+12128+(j<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((j&1)<<Cb)|0;ob=c[a+12128+(j<<3)+4>>2]|0;if((ub<<F|0)==0){Ua=j>>1;Rb=((ba(ob,_-I|0)|0)/(I|0)|0)+(Ua<<Cb)|0;Sb=Ua}else{Rb=S-ob|0;Sb=j>>1}ob=((Rb&Fb)<<F)+(pb&Fb)|0;Ua=(c[(a+12208|0)>>2]|0)+((ba(Sb,K<<3)|0)+(j<<3&8))|0;if(Db){mb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>1,K)|0)+(jb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((S&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&1023](Ua,mb,K,8);mb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Rb>>1,K)|0)+(pb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(ob<<2)>>2]&1023](Ua,mb,K,8)}else{mb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>2,K)|0)+(jb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((S&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&4095](Ua,mb,K);mb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Rb>>2,K)|0)+(pb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ob<<2)>>2]&4095](Ua,mb,K)}j=j+1|0;if((j|0)>=4){break m}}}if((ub<<F|0)==0){j=0;do{mb=(c[a+12160+(j<<3)>>2]|0)+(vb<<F)|0;Ua=c[a+12160+(j<<3)+4>>2]|0;ob=mb-(c[a+12128+(j<<3)>>2]|0)|0;pb=j>>1;jb=((ba(c[a+12128+(j<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(pb<<Cb)|0;S=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ba(pb,K<<3)|0))|0;if(Db){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ua>>1,K)|0)+(mb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Ua&Fb)<<F)+(mb&Fb)|0)<<2)>>2]&1023](S,pb,K,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(jb>>1,K)|0)+(ob>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((jb&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&1023](S,pb,K,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ua>>2,K)|0)+(mb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(mb&Fb)|0)<<2)>>2]&4095](S,pb,K);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(jb>>2,K)|0)+(ob>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((jb&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&4095](S,pb,K)}j=j+1|0;}while((j|0)<4)}else{j=0;do{pb=(c[a+12160+(j<<3)>>2]|0)+(vb<<F)|0;S=(c[a+12160+(j<<3)+4>>2]|0)+(ub<<F)|0;ob=pb-(c[a+12128+(j<<3)>>2]|0)|0;jb=S-(c[a+12128+(j<<3)+4>>2]|0)|0;mb=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ba(j>>1,K<<3)|0))|0;if(Db){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>1,K)|0)+(pb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((S&Fb)<<F)+(pb&Fb)|0)<<2)>>2]&1023](mb,Ua,K,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(jb>>1,K)|0)+(ob>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((jb&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&1023](mb,Ua,K,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>2,K)|0)+(pb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((S&Fb)<<F)+(pb&Fb)|0)<<2)>>2]&4095](mb,Ua,K);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(jb>>2,K)|0)+(ob>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((jb&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&4095](mb,Ua,K)}j=j+1|0;}while((j|0)<4)}}else{j=(c[(a+12160|0)>>2]|0)+(vb<<F)|0;Ua=(c[(a+12164|0)>>2]|0)+(ub<<F)|0;mb=c[(a+12128|0)>>2]|0;if((vb<<F|0)==0){Tb=(ba(mb,_-I|0)|0)/(I|0)|0}else{Tb=j-mb|0}mb=c[(a+12132|0)>>2]|0;if((ub<<F|0)==0){Ub=(ba(mb,_-I|0)|0)/(I|0)|0}else{Ub=Ua-mb|0}mb=((Ub&Fb)<<F)+(Tb&Fb)|0;if(Db){ob=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ua>>1,K)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+((((Ua&Fb)<<F)+(j&Fb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ob,K,16);ob=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ub>>1,K)|0)+(Tb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+(mb<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ob,K,16);break}else{ob=(ba(Ua>>2,K)|0)+(j>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(j&Fb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ob|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ob+8|0)|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ob+(K<<3))|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ob+8|0)+(K<<3))|0,K);ob=(ba(Ub>>2,K)|0)+(Tb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ob|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ob+8|0)|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ob+(K<<3))|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ob+8|0)+(K<<3))|0,K);break}}}while(0);Qb=Pe[G&255](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(s+(((ub<<3)+vb&63)<<2)|0)>>2]=vb+C+(ub<<11)|0;c[Ma+(((ub<<3)+vb&63)<<2)>>2]=Qb;K=(ba((d[z+((ub<<F)-A)|0]|0)+(d[z+((vb<<F)-y)|0]|0)|0,p)|0)+Qb|0;if((K|0)>=(Kb|0)){Nb=Kb;Ob=Lb;Pb=Mb;break}c[Oa>>2]=vb;c[(Oa+4|0)>>2]=ub;Nb=K;Ob=ub;Pb=vb}}while(0);vb=u-Jb|0;ub=m-Jb|0;do{if((c[(s+(((vb<<3)+ub&63)<<2)|0)>>2]|0)==(ub+C+(vb<<11)|0|0)){Vb=Nb;Wb=Ob;Xb=Pb}else{K=c[(a+12416|0)>>2]|0;do{if((B&4|0)==0){I=c[(a+12420|0)>>2]|0;_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(K,vb)|0)+ub)|0;ob=Pe[G&255](a,c[(a+12288+(k<<4)|0)>>2]|0,_,K,8)|0;if((B&2|0)==0){Yb=ob;break}_=c[(a+12208|0)>>2]|0;mb=(ba(I,vb>>1)|0)+(ub>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((vb<<1&2|ub&1)<<2)>>2]&1023](_+(K<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+mb|0,I,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((vb<<1&2|ub&1)<<2)>>2]&1023](_+(K<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+mb|0,I,4);mb=(Pe[Eb&255](a,_+(K<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,I,4)|0)+ob|0;Yb=mb+(Pe[Eb&255](a,_+(K<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,I,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(ub|0)){Yb=536870912;break}if((ub<<F|0)>(c[(a+12268|0)>>2]<<F|0)){Yb=536870912;break}if((c[(a+12272|0)>>2]|0)>(vb|0)){Yb=536870912;break}if((vb<<F|0)>(c[(a+12276|0)>>2]<<F|0)){Yb=536870912;break}I=e[(a+13872|0)>>1]|0;_=e[(a+13874|0)>>1]|0;n:do{if((c[(a+11740|0)>>2]|0)==1){if((ub<<F|0)==0){mb=0;while(1){ob=c[a+12160+(mb<<3)>>2]|0;j=(c[a+12160+(mb<<3)+4>>2]|0)+(vb<<F)|0;Ua=((ba(c[a+12128+(mb<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((mb&1)<<Cb)|0;jb=c[a+12128+(mb<<3)+4>>2]|0;if((vb<<F|0)==0){pb=mb>>1;Zb=((ba(jb,_-I|0)|0)/(I|0)|0)+(pb<<Cb)|0;_b=pb}else{Zb=j-jb|0;_b=mb>>1}jb=((Zb&Fb)<<F)+(Ua&Fb)|0;pb=(c[(a+12208|0)>>2]|0)+((ba(_b,K<<3)|0)+(mb<<3&8))|0;if(Db){S=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>1,K)|0)+(ob>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&1023](pb,S,K,8);S=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Zb>>1,K)|0)+(Ua>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(jb<<2)>>2]&1023](pb,S,K,8)}else{S=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>2,K)|0)+(ob>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((j&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&4095](pb,S,K);S=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Zb>>2,K)|0)+(Ua>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095](pb,S,K)}mb=mb+1|0;if((mb|0)>=4){break n}}}if((vb<<F|0)==0){mb=0;do{S=(c[a+12160+(mb<<3)>>2]|0)+(ub<<F)|0;pb=c[a+12160+(mb<<3)+4>>2]|0;jb=S-(c[a+12128+(mb<<3)>>2]|0)|0;Ua=mb>>1;ob=((ba(c[a+12128+(mb<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(Ua<<Cb)|0;j=(c[(a+12208|0)>>2]|0)+((mb<<3&8)+(ba(Ua,K<<3)|0))|0;if(Db){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,K)|0)+(S>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&Fb)<<F)+(S&Fb)|0)<<2)>>2]&1023](j,Ua,K,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>1,K)|0)+(jb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&1023](j,Ua,K,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>2,K)|0)+(S>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(S&Fb)|0)<<2)>>2]&4095](j,Ua,K);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>2,K)|0)+(jb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ob&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&4095](j,Ua,K)}mb=mb+1|0;}while((mb|0)<4)}else{mb=0;do{Ua=(c[a+12160+(mb<<3)>>2]|0)+(ub<<F)|0;j=(c[a+12160+(mb<<3)+4>>2]|0)+(vb<<F)|0;jb=Ua-(c[a+12128+(mb<<3)>>2]|0)|0;ob=j-(c[a+12128+(mb<<3)+4>>2]|0)|0;S=(c[(a+12208|0)>>2]|0)+((mb<<3&8)+(ba(mb>>1,K<<3)|0))|0;if(Db){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>1,K)|0)+(Ua>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Fb)<<F)+(Ua&Fb)|0)<<2)>>2]&1023](S,pb,K,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>1,K)|0)+(jb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&1023](S,pb,K,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>2,K)|0)+(Ua>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((j&Fb)<<F)+(Ua&Fb)|0)<<2)>>2]&4095](S,pb,K);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>2,K)|0)+(jb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ob&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&4095](S,pb,K)}mb=mb+1|0;}while((mb|0)<4)}}else{mb=(c[(a+12160|0)>>2]|0)+(ub<<F)|0;pb=(c[(a+12164|0)>>2]|0)+(vb<<F)|0;S=c[(a+12128|0)>>2]|0;if((ub<<F|0)==0){$b=(ba(S,_-I|0)|0)/(I|0)|0}else{$b=mb-S|0}S=c[(a+12132|0)>>2]|0;if((vb<<F|0)==0){ac=(ba(S,_-I|0)|0)/(I|0)|0}else{ac=pb-S|0}S=((ac&Fb)<<F)+($b&Fb)|0;if(Db){jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,K)|0)+(mb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+((((pb&Fb)<<F)+(mb&Fb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,jb,K,16);jb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ac>>1,K)|0)+($b>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+(S<<2)>>2]&1023](c[(a+12208|0)>>2]|0,jb,K,16);break}else{jb=(ba(pb>>2,K)|0)+(mb>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(mb&Fb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+jb|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(mb&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+8|0)|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(mb&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+(K<<3))|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(mb&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((jb+8|0)+(K<<3))|0,K);jb=(ba(ac>>2,K)|0)+($b>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+jb|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+8|0)|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+(K<<3))|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((jb+8|0)+(K<<3))|0,K);break}}}while(0);Yb=Pe[G&255](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(s+(((vb<<3)+ub&63)<<2)|0)>>2]=ub+C+(vb<<11)|0;c[Ma+(((vb<<3)+ub&63)<<2)>>2]=Yb;K=(ba((d[z+((vb<<F)-A)|0]|0)+(d[z+((ub<<F)-y)|0]|0)|0,p)|0)+Yb|0;if((K|0)>=(Nb|0)){Vb=Nb;Wb=Ob;Xb=Pb;break}c[Oa>>2]=ub;c[(Oa+4|0)>>2]=vb;Vb=K;Wb=vb;Xb=ub}}while(0);ub=Jb+xb|0;vb=J-Jb|0;do{if((c[(s+(((ub<<3)+vb&63)<<2)|0)>>2]|0)==(vb+C+(ub<<11)|0|0)){bc=Vb;cc=Wb;dc=Xb}else{K=c[(a+12416|0)>>2]|0;do{if((B&4|0)==0){I=c[(a+12420|0)>>2]|0;_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(K,ub)|0)+vb)|0;jb=Pe[G&255](a,c[(a+12288+(k<<4)|0)>>2]|0,_,K,8)|0;if((B&2|0)==0){ec=jb;break}_=c[(a+12208|0)>>2]|0;S=(ba(I,ub>>1)|0)+(vb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((ub<<1&2|vb&1)<<2)>>2]&1023](_+(K<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+S|0,I,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((ub<<1&2|vb&1)<<2)>>2]&1023](_+(K<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+S|0,I,4);S=(Pe[Eb&255](a,_+(K<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,I,4)|0)+jb|0;ec=S+(Pe[Eb&255](a,_+(K<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,I,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(vb|0)){ec=536870912;break}if((vb<<F|0)>(c[(a+12268|0)>>2]<<F|0)){ec=536870912;break}if((c[(a+12272|0)>>2]|0)>(ub|0)){ec=536870912;break}if((ub<<F|0)>(c[(a+12276|0)>>2]<<F|0)){ec=536870912;break}I=e[(a+13872|0)>>1]|0;_=e[(a+13874|0)>>1]|0;o:do{if((c[(a+11740|0)>>2]|0)==1){if((vb<<F|0)==0){S=0;while(1){jb=c[a+12160+(S<<3)>>2]|0;mb=(c[a+12160+(S<<3)+4>>2]|0)+(ub<<F)|0;pb=((ba(c[a+12128+(S<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((S&1)<<Cb)|0;ob=c[a+12128+(S<<3)+4>>2]|0;if((ub<<F|0)==0){Ua=S>>1;fc=((ba(ob,_-I|0)|0)/(I|0)|0)+(Ua<<Cb)|0;gc=Ua}else{fc=mb-ob|0;gc=S>>1}ob=((fc&Fb)<<F)+(pb&Fb)|0;Ua=(c[(a+12208|0)>>2]|0)+((ba(gc,K<<3)|0)+(S<<3&8))|0;if(Db){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mb>>1,K)|0)+(jb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((mb&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&1023](Ua,j,K,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(fc>>1,K)|0)+(pb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(ob<<2)>>2]&1023](Ua,j,K,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mb>>2,K)|0)+(jb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((mb&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&4095](Ua,j,K);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(fc>>2,K)|0)+(pb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ob<<2)>>2]&4095](Ua,j,K)}S=S+1|0;if((S|0)>=4){break o}}}if((ub<<F|0)==0){S=0;do{j=(c[a+12160+(S<<3)>>2]|0)+(vb<<F)|0;Ua=c[a+12160+(S<<3)+4>>2]|0;ob=j-(c[a+12128+(S<<3)>>2]|0)|0;pb=S>>1;jb=((ba(c[a+12128+(S<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(pb<<Cb)|0;mb=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ba(pb,K<<3)|0))|0;if(Db){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ua>>1,K)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Ua&Fb)<<F)+(j&Fb)|0)<<2)>>2]&1023](mb,pb,K,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(jb>>1,K)|0)+(ob>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((jb&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&1023](mb,pb,K,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ua>>2,K)|0)+(j>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(j&Fb)|0)<<2)>>2]&4095](mb,pb,K);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(jb>>2,K)|0)+(ob>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((jb&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&4095](mb,pb,K)}S=S+1|0;}while((S|0)<4)}else{S=0;do{pb=(c[a+12160+(S<<3)>>2]|0)+(vb<<F)|0;mb=(c[a+12160+(S<<3)+4>>2]|0)+(ub<<F)|0;ob=pb-(c[a+12128+(S<<3)>>2]|0)|0;jb=mb-(c[a+12128+(S<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ba(S>>1,K<<3)|0))|0;if(Db){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mb>>1,K)|0)+(pb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((mb&Fb)<<F)+(pb&Fb)|0)<<2)>>2]&1023](j,Ua,K,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(jb>>1,K)|0)+(ob>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((jb&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&1023](j,Ua,K,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mb>>2,K)|0)+(pb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((mb&Fb)<<F)+(pb&Fb)|0)<<2)>>2]&4095](j,Ua,K);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(jb>>2,K)|0)+(ob>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((jb&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&4095](j,Ua,K)}S=S+1|0;}while((S|0)<4)}}else{S=(c[(a+12160|0)>>2]|0)+(vb<<F)|0;Ua=(c[(a+12164|0)>>2]|0)+(ub<<F)|0;j=c[(a+12128|0)>>2]|0;if((vb<<F|0)==0){hc=(ba(j,_-I|0)|0)/(I|0)|0}else{hc=S-j|0}j=c[(a+12132|0)>>2]|0;if((ub<<F|0)==0){ic=(ba(j,_-I|0)|0)/(I|0)|0}else{ic=Ua-j|0}j=((ic&Fb)<<F)+(hc&Fb)|0;if(Db){ob=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ua>>1,K)|0)+(S>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+((((Ua&Fb)<<F)+(S&Fb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ob,K,16);ob=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ic>>1,K)|0)+(hc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+(j<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ob,K,16);break}else{ob=(ba(Ua>>2,K)|0)+(S>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(S&Fb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ob|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(S&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ob+8|0)|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(S&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ob+(K<<3))|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<F)+(S&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ob+8|0)+(K<<3))|0,K);ob=(ba(ic>>2,K)|0)+(hc>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ob|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ob+8|0)|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ob+(K<<3))|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ob+8|0)+(K<<3))|0,K);break}}}while(0);ec=Pe[G&255](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(s+(((ub<<3)+vb&63)<<2)|0)>>2]=vb+C+(ub<<11)|0;c[Ma+(((ub<<3)+vb&63)<<2)>>2]=ec;K=(ba((d[z+((ub<<F)-A)|0]|0)+(d[z+((vb<<F)-y)|0]|0)|0,p)|0)+ec|0;if((K|0)>=(Vb|0)){bc=Vb;cc=Wb;dc=Xb;break}c[Oa>>2]=vb;c[(Oa+4|0)>>2]=ub;bc=K;cc=ub;dc=vb}}while(0);vb=Jb+u|0;ub=Jb+tb|0;do{if((c[(s+(((vb<<3)+ub&63)<<2)|0)>>2]|0)==(ub+C+(vb<<11)|0|0)){jc=bc;kc=cc;lc=dc}else{K=c[(a+12416|0)>>2]|0;do{if((B&4|0)==0){I=c[(a+12420|0)>>2]|0;_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(K,vb)|0)+ub)|0;ob=Pe[G&255](a,c[(a+12288+(k<<4)|0)>>2]|0,_,K,8)|0;if((B&2|0)==0){mc=ob;break}_=c[(a+12208|0)>>2]|0;j=(ba(I,vb>>1)|0)+(ub>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((vb<<1&2|ub&1)<<2)>>2]&1023](_+(K<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+j|0,I,4);cf[c[(c[(a+12444|0)>>2]|0)+16+((vb<<1&2|ub&1)<<2)>>2]&1023](_+(K<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+j|0,I,4);j=(Pe[Eb&255](a,_+(K<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,I,4)|0)+ob|0;mc=j+(Pe[Eb&255](a,_+(K<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,I,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(ub|0)){mc=536870912;break}if((ub<<F|0)>(c[(a+12268|0)>>2]<<F|0)){mc=536870912;break}if((c[(a+12272|0)>>2]|0)>(vb|0)){mc=536870912;break}if((vb<<F|0)>(c[(a+12276|0)>>2]<<F|0)){mc=536870912;break}I=e[(a+13872|0)>>1]|0;_=e[(a+13874|0)>>1]|0;p:do{if((c[(a+11740|0)>>2]|0)==1){if((ub<<F|0)==0){j=0;while(1){ob=c[a+12160+(j<<3)>>2]|0;S=(c[a+12160+(j<<3)+4>>2]|0)+(vb<<F)|0;Ua=((ba(c[a+12128+(j<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((j&1)<<Cb)|0;jb=c[a+12128+(j<<3)+4>>2]|0;if((vb<<F|0)==0){pb=j>>1;nc=((ba(jb,_-I|0)|0)/(I|0)|0)+(pb<<Cb)|0;oc=pb}else{nc=S-jb|0;oc=j>>1}jb=((nc&Fb)<<F)+(Ua&Fb)|0;pb=(c[(a+12208|0)>>2]|0)+((ba(oc,K<<3)|0)+(j<<3&8))|0;if(Db){mb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>1,K)|0)+(ob>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((S&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&1023](pb,mb,K,8);mb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(nc>>1,K)|0)+(Ua>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(jb<<2)>>2]&1023](pb,mb,K,8)}else{mb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>2,K)|0)+(ob>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((S&Fb)<<F)+(ob&Fb)|0)<<2)>>2]&4095](pb,mb,K);mb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(nc>>2,K)|0)+(Ua>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095](pb,mb,K)}j=j+1|0;if((j|0)>=4){break p}}}if((vb<<F|0)==0){j=0;do{mb=(c[a+12160+(j<<3)>>2]|0)+(ub<<F)|0;pb=c[a+12160+(j<<3)+4>>2]|0;jb=mb-(c[a+12128+(j<<3)>>2]|0)|0;Ua=j>>1;ob=((ba(c[a+12128+(j<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(Ua<<Cb)|0;S=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ba(Ua,K<<3)|0))|0;if(Db){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,K)|0)+(mb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&Fb)<<F)+(mb&Fb)|0)<<2)>>2]&1023](S,Ua,K,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>1,K)|0)+(jb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&1023](S,Ua,K,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>2,K)|0)+(mb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(mb&Fb)|0)<<2)>>2]&4095](S,Ua,K);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>2,K)|0)+(jb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ob&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&4095](S,Ua,K)}j=j+1|0;}while((j|0)<4)}else{j=0;do{Ua=(c[a+12160+(j<<3)>>2]|0)+(ub<<F)|0;S=(c[a+12160+(j<<3)+4>>2]|0)+(vb<<F)|0;jb=Ua-(c[a+12128+(j<<3)>>2]|0)|0;ob=S-(c[a+12128+(j<<3)+4>>2]|0)|0;mb=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ba(j>>1,K<<3)|0))|0;if(Db){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>1,K)|0)+(Ua>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((S&Fb)<<F)+(Ua&Fb)|0)<<2)>>2]&1023](mb,pb,K,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>1,K)|0)+(jb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&1023](mb,pb,K,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>2,K)|0)+(Ua>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((S&Fb)<<F)+(Ua&Fb)|0)<<2)>>2]&4095](mb,pb,K);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>2,K)|0)+(jb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ob&Fb)<<F)+(jb&Fb)|0)<<2)>>2]&4095](mb,pb,K)}j=j+1|0;}while((j|0)<4)}}else{j=(c[(a+12160|0)>>2]|0)+(ub<<F)|0;pb=(c[(a+12164|0)>>2]|0)+(vb<<F)|0;mb=c[(a+12128|0)>>2]|0;if((ub<<F|0)==0){pc=(ba(mb,_-I|0)|0)/(I|0)|0}else{pc=j-mb|0}mb=c[(a+12132|0)>>2]|0;if((vb<<F|0)==0){qc=(ba(mb,_-I|0)|0)/(I|0)|0}else{qc=pb-mb|0}mb=((qc&Fb)<<F)+(pc&Fb)|0;if(Db){jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,K)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+((((pb&Fb)<<F)+(j&Fb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,jb,K,16);jb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(qc>>1,K)|0)+(pc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+(mb<<2)>>2]&1023](c[(a+12208|0)>>2]|0,jb,K,16);break}else{jb=(ba(pb>>2,K)|0)+(j>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(j&Fb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+jb|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+8|0)|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+(K<<3))|0,K);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<F)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((jb+8|0)+(K<<3))|0,K);jb=(ba(qc>>2,K)|0)+(pc>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+jb|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+8|0)|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+(K<<3))|0,K);Xe[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((jb+8|0)+(K<<3))|0,K);break}}}while(0);mc=Pe[G&255](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(s+(((vb<<3)+ub&63)<<2)|0)>>2]=ub+C+(vb<<11)|0;c[Ma+(((vb<<3)+ub&63)<<2)>>2]=mc;K=(ba((d[z+((vb<<F)-A)|0]|0)+(d[z+((ub<<F)-y)|0]|0)|0,p)|0)+mc|0;if((K|0)>=(bc|0)){jc=bc;kc=cc;lc=dc;break}c[Oa>>2]=ub;c[(Oa+4|0)>>2]=vb;jc=K;kc=vb;lc=ub}}while(0);ub=Jb+2|0;if((ub|0)<(t|0)){Jb=ub;Kb=jc;Lb=kc;Mb=lc}else{break}}if((J|0)!=(lc|0)){H=jc;J=lc;u=kc;x=lc;continue l}if((u|0)==(kc|0)){Gb=jc;Hb=u;Ib=J}else{H=jc;J=J;u=kc;x=lc;continue l}}else{Gb=v;Hb=q;Ib=r}}while(0);Q=t+1|0;if((Q|0)<5){t=Q;v=Gb;q=Hb;r=Ib}else{rc=Gb;break l}}}sc=c[Oa>>2]|0;c[f>>2]=sc;tc=o+4|0;uc=c[tc>>2]|0;c[h>>2]=uc;i=n;return rc|0}if((Na|0)<-1){rc=Fmb(a,Oa,k,l,p,0,8,B)|0;sc=c[Oa>>2]|0;c[f>>2]=sc;tc=o+4|0;uc=c[tc>>2]|0;c[h>>2]=uc;i=n;return rc|0}c[n+16>>2]=a;c[n+24>>2]=f;c[n+32>>2]=h;c[n+48>>2]=k;c[n+56>>2]=l;c[n+72>>2]=o;c[n+80>>2]=p;c[n+168>>2]=B;c[n+184>>2]=F;c[n+6136>>2]=Ab;c[n+6144>>2]=zb;c[n+6152>>2]=yb;c[n+6160>>2]=Oa;c[n+6168>>2]=Na;c[n+19096>>2]=rc;c[n+19104>>2]=sc;c[n+19112>>2]=tc;c[n+19120>>2]=uc;c[n+19144>>2]=0;c[n+19148>>2]=0;_epzs_motion_search2$0(n);rc=c[n+19096>>2]|0;sc=c[n+19104>>2]|0;tc=c[n+19112>>2]|0;uc=c[n+19120>>2]|0;D=c[n+19144>>2]|0;w=c[n+19148>>2]|0;E=+g[n+19148>>2];c[n+19144>>2]=0;c[n+19148>>2]=0;if((D|0)==6){return w|0}return 0|0;return 0}function Fmb(a,b,f,g,h,j,k,l){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0;m=i;i=i+1024|0;n=m|0;o=c[a+12260>>2]|0;p=-o|0;q=c[a+12220>>2]|0;r=a+12264|0;s=c[r>>2]|0;t=a+12272|0;u=c[t>>2]|0;v=a+12268|0;w=c[v>>2]|0;x=a+12276|0;y=c[x>>2]|0;z=c[a+12464>>2]|0;A=c[a+12280>>2]|0;B=c[a+12284>>2]|0;C=c[a+12216>>2]|0;D=l&1;E=D+1|0;F=c[a+12224>>2]|0;G=c[a+10468+(j<<2)>>2]|0;H=j+1|0;j=c[a+10468+(H<<2)>>2]|0;I=0;J=0;while(1){K=(c[C+(J<<2)>>2]|0)+2098176|0;do{if((K&-4194304|0)==(F|0)){L=c[q+(J<<2)>>2]|0;M=n+(I<<4)|0;c[M>>2]=L;N=(K&2047)-1024|0;c[n+(I<<4)+4>>2]=N;O=(K>>>11&2047)-1024|0;c[n+(I<<4)+8>>2]=O;if((N|0)>(w|0)|(N|0)<(s|0)|(O|0)>(y|0)|(O|0)<(u|0)){P=I;break}c[n+(I<<4)+12>>2]=0;if((N|O|0)!=0){c[M>>2]=(ba((d[z+((O<<E)-B)|0]|0)+(d[z+((N<<E)-A)|0]|0)|0,h)|0)+L}P=I+1|0}else{P=I}}while(0);K=J+1|0;if((K|0)<64&(P|0)<64){I=P;J=K}else{break}}J=(o|0)>-1?o:p;Yc(n|0,P|0,16,818);if((P|0)<(J|0)){p=P;do{c[n+(p<<4)>>2]=1073741824;c[n+(p<<4)+12>>2]=0;c[n+(p<<4)+8>>2]=0;c[n+(p<<4)+4>>2]=0;p=p+1|0;}while((p|0)<(J|0))}if((J|0)>0){p=(l&4|0)==0;P=a+12416|0;o=a+12420|0;I=a+12352+(g<<4)|0;K=a+12288+(f<<4)|0;L=a;N=(l&2|0)==0;O=a+12208|0;M=a+12444|0;Q=a+12352+(g<<4)+4|0;R=k>>1;S=a+12352+(g<<4)+8|0;T=a+12288+(f<<4)+4|0;U=a+12288+(f<<4)+8|0;V=n+(J-1<<4)|0;W=a+13872|0;X=a+13874|0;Y=D<<1|1;Z=a+11740|0;_=D|4;$=(D|0)==0;aa=a+12448|0;ca=a+12352+(g<<4)+32|0;da=a+12452|0;ea=a+12456|0;fa=a+12160|0;ga=a+12164|0;ha=a+12128|0;ia=a+12132|0;ja=0;do{ka=c[n+(ja<<4)+4>>2]|0;la=c[n+(ja<<4)+8>>2]|0;ma=n+(ja<<4)+12|0;a:do{if((c[ma>>2]|0)==0&(ka|0)<(w|0)&(ka|0)>(s|0)&(la|0)<(y|0)&(la|0)>(u|0)){na=la<<11;oa=ka-1|0;pa=oa+F+na|0;qa=la<<3;ra=qa+oa&63;sa=C+(ra<<2)|0;do{if((c[sa>>2]|0)!=(pa|0)){ta=c[P>>2]|0;do{if(p){ua=c[o>>2]|0;va=(c[I>>2]|0)+((ba(ta,la)|0)+oa)|0;wa=Pe[G&255](L,c[K>>2]|0,va,ta,k)|0;if(N){xa=wa;break}va=la<<1&2|oa&1;ya=c[O>>2]|0;za=ta<<4;Aa=ya+za|0;Ba=(ba(ua,la>>1)|0)+(oa>>1)|0;cf[c[(c[M>>2]|0)+(H<<4)+(va<<2)>>2]&1023](Aa,(c[Q>>2]|0)+Ba|0,ua,R);Ca=ya+(za|8)|0;cf[c[(c[M>>2]|0)+(H<<4)+(va<<2)>>2]&1023](Ca,(c[S>>2]|0)+Ba|0,ua,R);Ba=(Pe[j&255](L,Aa,c[T>>2]|0,ua,R)|0)+wa|0;xa=Ba+(Pe[j&255](L,Ca,c[U>>2]|0,ua,R)|0)|0}else{ua=oa<<E;Ca=la<<E;if((c[r>>2]|0)>(oa|0)){xa=536870912;break}if((ua|0)>(c[v>>2]<<E|0)){xa=536870912;break}if((c[t>>2]|0)>(la|0)){xa=536870912;break}if((Ca|0)>(c[x>>2]<<E|0)){xa=536870912;break}Ba=e[W>>1]|0;wa=e[X>>1]|0;b:do{if((c[Z>>2]|0)==1){Aa=wa-Ba|0;va=(Ca|0)==0;za=ta<<3;if((ua|0)==0){ya=0;while(1){Da=c[a+12160+(ya<<3)>>2]|0;Ea=(c[a+12160+(ya<<3)+4>>2]|0)+Ca|0;Fa=((ba(c[a+12128+(ya<<3)>>2]|0,Aa)|0)/(Ba|0)|0)+((ya&1)<<_)|0;Ga=c[a+12128+(ya<<3)+4>>2]|0;if(va){Ha=ya>>1;Ia=((ba(Ga,Aa)|0)/(Ba|0)|0)+(Ha<<_)|0;Ja=Ha}else{Ia=Ea-Ga|0;Ja=ya>>1}Ga=((Ea&Y)<<E)+(Da&Y)|0;Ha=((Ia&Y)<<E)+(Fa&Y)|0;Ka=(c[O>>2]|0)+((ba(Ja,za)|0)+(ya<<3&8))|0;if($){La=(c[I>>2]|0)+((ba(Ea>>1,ta)|0)+(Da>>1))|0;cf[c[(c[M>>2]|0)+16+(Ga<<2)>>2]&1023](Ka,La,ta,8);La=(c[ca>>2]|0)+((ba(Ia>>1,ta)|0)+(Fa>>1))|0;cf[c[(c[aa>>2]|0)+16+(Ha<<2)>>2]&1023](Ka,La,ta,8)}else{La=(c[I>>2]|0)+((ba(Ea>>2,ta)|0)+(Da>>2))|0;Xe[c[(c[da>>2]|0)+64+(Ga<<2)>>2]&4095](Ka,La,ta);La=(c[ca>>2]|0)+((ba(Ia>>2,ta)|0)+(Fa>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Ha<<2)>>2]&4095](Ka,La,ta)}ya=ya+1|0;if((ya|0)>=4){break b}}}if(va){ya=0;do{La=(c[a+12160+(ya<<3)>>2]|0)+ua|0;Ka=c[a+12160+(ya<<3)+4>>2]|0;Ha=La-(c[a+12128+(ya<<3)>>2]|0)|0;Fa=ya>>1;Ga=((ba(c[a+12128+(ya<<3)+4>>2]|0,Aa)|0)/(Ba|0)|0)+(Fa<<_)|0;Da=((Ka&Y)<<E)+(La&Y)|0;Ea=((Ga&Y)<<E)+(Ha&Y)|0;Ma=(c[O>>2]|0)+((ya<<3&8)+(ba(Fa,za)|0))|0;if($){Fa=(c[I>>2]|0)+((ba(Ka>>1,ta)|0)+(La>>1))|0;cf[c[(c[M>>2]|0)+16+(Da<<2)>>2]&1023](Ma,Fa,ta,8);Fa=(c[ca>>2]|0)+((ba(Ga>>1,ta)|0)+(Ha>>1))|0;cf[c[(c[aa>>2]|0)+16+(Ea<<2)>>2]&1023](Ma,Fa,ta,8)}else{Fa=(c[I>>2]|0)+((ba(Ka>>2,ta)|0)+(La>>2))|0;Xe[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095](Ma,Fa,ta);Fa=(c[ca>>2]|0)+((ba(Ga>>2,ta)|0)+(Ha>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Ea<<2)>>2]&4095](Ma,Fa,ta)}ya=ya+1|0;}while((ya|0)<4)}else{ya=0;do{Aa=(c[a+12160+(ya<<3)>>2]|0)+ua|0;va=(c[a+12160+(ya<<3)+4>>2]|0)+Ca|0;Fa=Aa-(c[a+12128+(ya<<3)>>2]|0)|0;Ma=va-(c[a+12128+(ya<<3)+4>>2]|0)|0;Ea=((va&Y)<<E)+(Aa&Y)|0;Ha=((Ma&Y)<<E)+(Fa&Y)|0;Ga=(c[O>>2]|0)+((ya<<3&8)+(ba(ya>>1,za)|0))|0;if($){Da=(c[I>>2]|0)+((ba(va>>1,ta)|0)+(Aa>>1))|0;cf[c[(c[M>>2]|0)+16+(Ea<<2)>>2]&1023](Ga,Da,ta,8);Da=(c[ca>>2]|0)+((ba(Ma>>1,ta)|0)+(Fa>>1))|0;cf[c[(c[aa>>2]|0)+16+(Ha<<2)>>2]&1023](Ga,Da,ta,8)}else{Da=(c[I>>2]|0)+((ba(va>>2,ta)|0)+(Aa>>2))|0;Xe[c[(c[da>>2]|0)+64+(Ea<<2)>>2]&4095](Ga,Da,ta);Da=(c[ca>>2]|0)+((ba(Ma>>2,ta)|0)+(Fa>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Ha<<2)>>2]&4095](Ga,Da,ta)}ya=ya+1|0;}while((ya|0)<4)}}else{ya=(c[fa>>2]|0)+ua|0;za=(c[ga>>2]|0)+Ca|0;Da=c[ha>>2]|0;if((ua|0)==0){Na=(ba(Da,wa-Ba|0)|0)/(Ba|0)|0}else{Na=ya-Da|0}Da=c[ia>>2]|0;if((Ca|0)==0){Oa=(ba(Da,wa-Ba|0)|0)/(Ba|0)|0}else{Oa=za-Da|0}Da=((za&Y)<<E)+(ya&Y)|0;Ga=((Oa&Y)<<E)+(Na&Y)|0;if($){Ha=(c[I>>2]|0)+((ba(za>>1,ta)|0)+(ya>>1))|0;cf[c[(c[M>>2]|0)+(Da<<2)>>2]&1023](c[O>>2]|0,Ha,ta,16);Ha=(c[ca>>2]|0)+((ba(Oa>>1,ta)|0)+(Na>>1))|0;cf[c[(c[aa>>2]|0)+(Ga<<2)>>2]&1023](c[O>>2]|0,Ha,ta,16);break}else{Ha=(ba(za>>2,ta)|0)+(ya>>2)|0;Xe[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095](c[O>>2]|0,(c[I>>2]|0)+Ha|0,ta);ya=Ha+8|0;Xe[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[I>>2]|0)+ya|0,ta);za=ta<<3;Xe[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095]((c[O>>2]|0)+za|0,(c[I>>2]|0)+(Ha+za)|0,ta);Ha=za+8|0;Xe[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095]((c[O>>2]|0)+Ha|0,(c[I>>2]|0)+(ya+za)|0,ta);ya=(ba(Oa>>2,ta)|0)+(Na>>2)|0;Xe[c[(c[ea>>2]|0)+64+(Ga<<2)>>2]&4095](c[O>>2]|0,(c[ca>>2]|0)+ya|0,ta);Da=ya+8|0;Xe[c[(c[ea>>2]|0)+64+(Ga<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[ca>>2]|0)+Da|0,ta);Xe[c[(c[ea>>2]|0)+64+(Ga<<2)>>2]&4095]((c[O>>2]|0)+za|0,(c[ca>>2]|0)+(ya+za)|0,ta);Xe[c[(c[ea>>2]|0)+64+(Ga<<2)>>2]&4095]((c[O>>2]|0)+Ha|0,(c[ca>>2]|0)+(Da+za)|0,ta);break}}}while(0);xa=Pe[G&255](L,c[O>>2]|0,c[K>>2]|0,ta,16)|0}}while(0);c[sa>>2]=pa;c[q+(ra<<2)>>2]=xa;ta=(ba((d[z+((la<<E)-B)|0]|0)+(d[z+((oa<<E)-A)|0]|0)|0,h)|0)+xa|0;if((ta|0)<(c[V>>2]|0)){Pa=0}else{break}while(1){Qa=n+(Pa<<4)|0;Ra=Qa|0;Sa=Pa+1|0;if((ta|0)<(c[Ra>>2]|0)){break}else{Pa=Sa}}VGb(n+(Sa<<4)|0,Qa|0,(J-Pa<<4)-16|0)|0;c[n+(Pa<<4)+12>>2]=0;c[Ra>>2]=ta;c[n+(Pa<<4)+4>>2]=oa;c[n+(Pa<<4)+8>>2]=la;Ta=-1;break a}}while(0);oa=ka+1|0;ra=oa+F+na|0;pa=qa+oa&63;sa=C+(pa<<2)|0;do{if((c[sa>>2]|0)!=(ra|0)){Ba=c[P>>2]|0;do{if(p){wa=c[o>>2]|0;Ca=(c[I>>2]|0)+((ba(Ba,la)|0)+oa)|0;ua=Pe[G&255](L,c[K>>2]|0,Ca,Ba,k)|0;if(N){Ua=ua;break}Ca=la<<1&2|oa&1;za=c[O>>2]|0;Da=Ba<<4;Ha=za+Da|0;Ga=(ba(wa,la>>1)|0)+(oa>>1)|0;cf[c[(c[M>>2]|0)+(H<<4)+(Ca<<2)>>2]&1023](Ha,(c[Q>>2]|0)+Ga|0,wa,R);ya=za+(Da|8)|0;cf[c[(c[M>>2]|0)+(H<<4)+(Ca<<2)>>2]&1023](ya,(c[S>>2]|0)+Ga|0,wa,R);Ga=(Pe[j&255](L,Ha,c[T>>2]|0,wa,R)|0)+ua|0;Ua=Ga+(Pe[j&255](L,ya,c[U>>2]|0,wa,R)|0)|0}else{wa=oa<<E;ya=la<<E;if((c[r>>2]|0)>(oa|0)){Ua=536870912;break}if((wa|0)>(c[v>>2]<<E|0)){Ua=536870912;break}if((c[t>>2]|0)>(la|0)){Ua=536870912;break}if((ya|0)>(c[x>>2]<<E|0)){Ua=536870912;break}Ga=e[W>>1]|0;ua=e[X>>1]|0;c:do{if((c[Z>>2]|0)==1){Ha=ua-Ga|0;Ca=(ya|0)==0;Da=Ba<<3;if((wa|0)==0){za=0;while(1){Fa=c[a+12160+(za<<3)>>2]|0;Ma=(c[a+12160+(za<<3)+4>>2]|0)+ya|0;Ea=((ba(c[a+12128+(za<<3)>>2]|0,Ha)|0)/(Ga|0)|0)+((za&1)<<_)|0;Aa=c[a+12128+(za<<3)+4>>2]|0;if(Ca){va=za>>1;Va=((ba(Aa,Ha)|0)/(Ga|0)|0)+(va<<_)|0;Wa=va}else{Va=Ma-Aa|0;Wa=za>>1}Aa=((Ma&Y)<<E)+(Fa&Y)|0;va=((Va&Y)<<E)+(Ea&Y)|0;La=(c[O>>2]|0)+((ba(Wa,Da)|0)+(za<<3&8))|0;if($){Ka=(c[I>>2]|0)+((ba(Ma>>1,Ba)|0)+(Fa>>1))|0;cf[c[(c[M>>2]|0)+16+(Aa<<2)>>2]&1023](La,Ka,Ba,8);Ka=(c[ca>>2]|0)+((ba(Va>>1,Ba)|0)+(Ea>>1))|0;cf[c[(c[aa>>2]|0)+16+(va<<2)>>2]&1023](La,Ka,Ba,8)}else{Ka=(c[I>>2]|0)+((ba(Ma>>2,Ba)|0)+(Fa>>2))|0;Xe[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095](La,Ka,Ba);Ka=(c[ca>>2]|0)+((ba(Va>>2,Ba)|0)+(Ea>>2))|0;Xe[c[(c[ea>>2]|0)+64+(va<<2)>>2]&4095](La,Ka,Ba)}za=za+1|0;if((za|0)>=4){break c}}}if(Ca){za=0;do{Ka=(c[a+12160+(za<<3)>>2]|0)+wa|0;La=c[a+12160+(za<<3)+4>>2]|0;va=Ka-(c[a+12128+(za<<3)>>2]|0)|0;Ea=za>>1;Aa=((ba(c[a+12128+(za<<3)+4>>2]|0,Ha)|0)/(Ga|0)|0)+(Ea<<_)|0;Fa=((La&Y)<<E)+(Ka&Y)|0;Ma=((Aa&Y)<<E)+(va&Y)|0;Xa=(c[O>>2]|0)+((za<<3&8)+(ba(Ea,Da)|0))|0;if($){Ea=(c[I>>2]|0)+((ba(La>>1,Ba)|0)+(Ka>>1))|0;cf[c[(c[M>>2]|0)+16+(Fa<<2)>>2]&1023](Xa,Ea,Ba,8);Ea=(c[ca>>2]|0)+((ba(Aa>>1,Ba)|0)+(va>>1))|0;cf[c[(c[aa>>2]|0)+16+(Ma<<2)>>2]&1023](Xa,Ea,Ba,8)}else{Ea=(c[I>>2]|0)+((ba(La>>2,Ba)|0)+(Ka>>2))|0;Xe[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095](Xa,Ea,Ba);Ea=(c[ca>>2]|0)+((ba(Aa>>2,Ba)|0)+(va>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Ma<<2)>>2]&4095](Xa,Ea,Ba)}za=za+1|0;}while((za|0)<4)}else{za=0;do{Ha=(c[a+12160+(za<<3)>>2]|0)+wa|0;Ca=(c[a+12160+(za<<3)+4>>2]|0)+ya|0;Ea=Ha-(c[a+12128+(za<<3)>>2]|0)|0;Xa=Ca-(c[a+12128+(za<<3)+4>>2]|0)|0;Ma=((Ca&Y)<<E)+(Ha&Y)|0;va=((Xa&Y)<<E)+(Ea&Y)|0;Aa=(c[O>>2]|0)+((za<<3&8)+(ba(za>>1,Da)|0))|0;if($){Fa=(c[I>>2]|0)+((ba(Ca>>1,Ba)|0)+(Ha>>1))|0;cf[c[(c[M>>2]|0)+16+(Ma<<2)>>2]&1023](Aa,Fa,Ba,8);Fa=(c[ca>>2]|0)+((ba(Xa>>1,Ba)|0)+(Ea>>1))|0;cf[c[(c[aa>>2]|0)+16+(va<<2)>>2]&1023](Aa,Fa,Ba,8)}else{Fa=(c[I>>2]|0)+((ba(Ca>>2,Ba)|0)+(Ha>>2))|0;Xe[c[(c[da>>2]|0)+64+(Ma<<2)>>2]&4095](Aa,Fa,Ba);Fa=(c[ca>>2]|0)+((ba(Xa>>2,Ba)|0)+(Ea>>2))|0;Xe[c[(c[ea>>2]|0)+64+(va<<2)>>2]&4095](Aa,Fa,Ba)}za=za+1|0;}while((za|0)<4)}}else{za=(c[fa>>2]|0)+wa|0;Da=(c[ga>>2]|0)+ya|0;Fa=c[ha>>2]|0;if((wa|0)==0){Ya=(ba(Fa,ua-Ga|0)|0)/(Ga|0)|0}else{Ya=za-Fa|0}Fa=c[ia>>2]|0;if((ya|0)==0){Za=(ba(Fa,ua-Ga|0)|0)/(Ga|0)|0}else{Za=Da-Fa|0}Fa=((Da&Y)<<E)+(za&Y)|0;Aa=((Za&Y)<<E)+(Ya&Y)|0;if($){va=(c[I>>2]|0)+((ba(Da>>1,Ba)|0)+(za>>1))|0;cf[c[(c[M>>2]|0)+(Fa<<2)>>2]&1023](c[O>>2]|0,va,Ba,16);va=(c[ca>>2]|0)+((ba(Za>>1,Ba)|0)+(Ya>>1))|0;cf[c[(c[aa>>2]|0)+(Aa<<2)>>2]&1023](c[O>>2]|0,va,Ba,16);break}else{va=(ba(Da>>2,Ba)|0)+(za>>2)|0;Xe[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095](c[O>>2]|0,(c[I>>2]|0)+va|0,Ba);za=va+8|0;Xe[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[I>>2]|0)+za|0,Ba);Da=Ba<<3;Xe[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095]((c[O>>2]|0)+Da|0,(c[I>>2]|0)+(va+Da)|0,Ba);va=Da+8|0;Xe[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095]((c[O>>2]|0)+va|0,(c[I>>2]|0)+(za+Da)|0,Ba);za=(ba(Za>>2,Ba)|0)+(Ya>>2)|0;Xe[c[(c[ea>>2]|0)+64+(Aa<<2)>>2]&4095](c[O>>2]|0,(c[ca>>2]|0)+za|0,Ba);Fa=za+8|0;Xe[c[(c[ea>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[ca>>2]|0)+Fa|0,Ba);Xe[c[(c[ea>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+Da|0,(c[ca>>2]|0)+(za+Da)|0,Ba);Xe[c[(c[ea>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+va|0,(c[ca>>2]|0)+(Fa+Da)|0,Ba);break}}}while(0);Ua=Pe[G&255](L,c[O>>2]|0,c[K>>2]|0,Ba,16)|0}}while(0);c[sa>>2]=ra;c[q+(pa<<2)>>2]=Ua;Ba=(ba((d[z+((la<<E)-B)|0]|0)+(d[z+((oa<<E)-A)|0]|0)|0,h)|0)+Ua|0;if((Ba|0)<(c[V>>2]|0)){_a=0}else{break}while(1){$a=n+(_a<<4)|0;ab=$a|0;bb=_a+1|0;if((Ba|0)<(c[ab>>2]|0)){break}else{_a=bb}}VGb(n+(bb<<4)|0,$a|0,(J-_a<<4)-16|0)|0;c[n+(_a<<4)+12>>2]=0;c[ab>>2]=Ba;c[n+(_a<<4)+4>>2]=oa;c[n+(_a<<4)+8>>2]=la;Ta=-1;break a}}while(0);oa=la-1|0;pa=ka+F|0;ra=pa+(oa<<11)|0;sa=(oa<<3)+ka&63;qa=C+(sa<<2)|0;do{if((c[qa>>2]|0)!=(ra|0)){na=c[P>>2]|0;do{if(p){ta=c[o>>2]|0;Ga=(c[I>>2]|0)+((ba(na,oa)|0)+ka)|0;ua=Pe[G&255](L,c[K>>2]|0,Ga,na,k)|0;if(N){cb=ua;break}Ga=oa<<1&2|ka&1;ya=c[O>>2]|0;wa=na<<4;Da=ya+wa|0;Fa=(ba(ta,oa>>1)|0)+(ka>>1)|0;cf[c[(c[M>>2]|0)+(H<<4)+(Ga<<2)>>2]&1023](Da,(c[Q>>2]|0)+Fa|0,ta,R);va=ya+(wa|8)|0;cf[c[(c[M>>2]|0)+(H<<4)+(Ga<<2)>>2]&1023](va,(c[S>>2]|0)+Fa|0,ta,R);Fa=(Pe[j&255](L,Da,c[T>>2]|0,ta,R)|0)+ua|0;cb=Fa+(Pe[j&255](L,va,c[U>>2]|0,ta,R)|0)|0}else{ta=ka<<E;va=oa<<E;if((c[r>>2]|0)>(ka|0)){cb=536870912;break}if((ta|0)>(c[v>>2]<<E|0)){cb=536870912;break}if((c[t>>2]|0)>(oa|0)){cb=536870912;break}if((va|0)>(c[x>>2]<<E|0)){cb=536870912;break}Fa=e[W>>1]|0;ua=e[X>>1]|0;d:do{if((c[Z>>2]|0)==1){Da=ua-Fa|0;Ga=(va|0)==0;wa=na<<3;if((ta|0)==0){ya=0;while(1){Aa=c[a+12160+(ya<<3)>>2]|0;za=(c[a+12160+(ya<<3)+4>>2]|0)+va|0;Ea=((ba(c[a+12128+(ya<<3)>>2]|0,Da)|0)/(Fa|0)|0)+((ya&1)<<_)|0;Xa=c[a+12128+(ya<<3)+4>>2]|0;if(Ga){Ma=ya>>1;db=((ba(Xa,Da)|0)/(Fa|0)|0)+(Ma<<_)|0;eb=Ma}else{db=za-Xa|0;eb=ya>>1}Xa=((za&Y)<<E)+(Aa&Y)|0;Ma=((db&Y)<<E)+(Ea&Y)|0;Ha=(c[O>>2]|0)+((ba(eb,wa)|0)+(ya<<3&8))|0;if($){Ca=(c[I>>2]|0)+((ba(za>>1,na)|0)+(Aa>>1))|0;cf[c[(c[M>>2]|0)+16+(Xa<<2)>>2]&1023](Ha,Ca,na,8);Ca=(c[ca>>2]|0)+((ba(db>>1,na)|0)+(Ea>>1))|0;cf[c[(c[aa>>2]|0)+16+(Ma<<2)>>2]&1023](Ha,Ca,na,8)}else{Ca=(c[I>>2]|0)+((ba(za>>2,na)|0)+(Aa>>2))|0;Xe[c[(c[da>>2]|0)+64+(Xa<<2)>>2]&4095](Ha,Ca,na);Ca=(c[ca>>2]|0)+((ba(db>>2,na)|0)+(Ea>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Ma<<2)>>2]&4095](Ha,Ca,na)}ya=ya+1|0;if((ya|0)>=4){break d}}}if(Ga){ya=0;do{Ca=(c[a+12160+(ya<<3)>>2]|0)+ta|0;Ha=c[a+12160+(ya<<3)+4>>2]|0;Ma=Ca-(c[a+12128+(ya<<3)>>2]|0)|0;Ea=ya>>1;Xa=((ba(c[a+12128+(ya<<3)+4>>2]|0,Da)|0)/(Fa|0)|0)+(Ea<<_)|0;Aa=((Ha&Y)<<E)+(Ca&Y)|0;za=((Xa&Y)<<E)+(Ma&Y)|0;Ka=(c[O>>2]|0)+((ya<<3&8)+(ba(Ea,wa)|0))|0;if($){Ea=(c[I>>2]|0)+((ba(Ha>>1,na)|0)+(Ca>>1))|0;cf[c[(c[M>>2]|0)+16+(Aa<<2)>>2]&1023](Ka,Ea,na,8);Ea=(c[ca>>2]|0)+((ba(Xa>>1,na)|0)+(Ma>>1))|0;cf[c[(c[aa>>2]|0)+16+(za<<2)>>2]&1023](Ka,Ea,na,8)}else{Ea=(c[I>>2]|0)+((ba(Ha>>2,na)|0)+(Ca>>2))|0;Xe[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095](Ka,Ea,na);Ea=(c[ca>>2]|0)+((ba(Xa>>2,na)|0)+(Ma>>2))|0;Xe[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095](Ka,Ea,na)}ya=ya+1|0;}while((ya|0)<4)}else{ya=0;do{Da=(c[a+12160+(ya<<3)>>2]|0)+ta|0;Ga=(c[a+12160+(ya<<3)+4>>2]|0)+va|0;Ea=Da-(c[a+12128+(ya<<3)>>2]|0)|0;Ka=Ga-(c[a+12128+(ya<<3)+4>>2]|0)|0;za=((Ga&Y)<<E)+(Da&Y)|0;Ma=((Ka&Y)<<E)+(Ea&Y)|0;Xa=(c[O>>2]|0)+((ya<<3&8)+(ba(ya>>1,wa)|0))|0;if($){Aa=(c[I>>2]|0)+((ba(Ga>>1,na)|0)+(Da>>1))|0;cf[c[(c[M>>2]|0)+16+(za<<2)>>2]&1023](Xa,Aa,na,8);Aa=(c[ca>>2]|0)+((ba(Ka>>1,na)|0)+(Ea>>1))|0;cf[c[(c[aa>>2]|0)+16+(Ma<<2)>>2]&1023](Xa,Aa,na,8)}else{Aa=(c[I>>2]|0)+((ba(Ga>>2,na)|0)+(Da>>2))|0;Xe[c[(c[da>>2]|0)+64+(za<<2)>>2]&4095](Xa,Aa,na);Aa=(c[ca>>2]|0)+((ba(Ka>>2,na)|0)+(Ea>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Ma<<2)>>2]&4095](Xa,Aa,na)}ya=ya+1|0;}while((ya|0)<4)}}else{ya=(c[fa>>2]|0)+ta|0;wa=(c[ga>>2]|0)+va|0;Aa=c[ha>>2]|0;if((ta|0)==0){fb=(ba(Aa,ua-Fa|0)|0)/(Fa|0)|0}else{fb=ya-Aa|0}Aa=c[ia>>2]|0;if((va|0)==0){gb=(ba(Aa,ua-Fa|0)|0)/(Fa|0)|0}else{gb=wa-Aa|0}Aa=((wa&Y)<<E)+(ya&Y)|0;Xa=((gb&Y)<<E)+(fb&Y)|0;if($){Ma=(c[I>>2]|0)+((ba(wa>>1,na)|0)+(ya>>1))|0;cf[c[(c[M>>2]|0)+(Aa<<2)>>2]&1023](c[O>>2]|0,Ma,na,16);Ma=(c[ca>>2]|0)+((ba(gb>>1,na)|0)+(fb>>1))|0;cf[c[(c[aa>>2]|0)+(Xa<<2)>>2]&1023](c[O>>2]|0,Ma,na,16);break}else{Ma=(ba(wa>>2,na)|0)+(ya>>2)|0;Xe[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095](c[O>>2]|0,(c[I>>2]|0)+Ma|0,na);ya=Ma+8|0;Xe[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[I>>2]|0)+ya|0,na);wa=na<<3;Xe[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+wa|0,(c[I>>2]|0)+(Ma+wa)|0,na);Ma=wa+8|0;Xe[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+Ma|0,(c[I>>2]|0)+(ya+wa)|0,na);ya=(ba(gb>>2,na)|0)+(fb>>2)|0;Xe[c[(c[ea>>2]|0)+64+(Xa<<2)>>2]&4095](c[O>>2]|0,(c[ca>>2]|0)+ya|0,na);Aa=ya+8|0;Xe[c[(c[ea>>2]|0)+64+(Xa<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[ca>>2]|0)+Aa|0,na);Xe[c[(c[ea>>2]|0)+64+(Xa<<2)>>2]&4095]((c[O>>2]|0)+wa|0,(c[ca>>2]|0)+(ya+wa)|0,na);Xe[c[(c[ea>>2]|0)+64+(Xa<<2)>>2]&4095]((c[O>>2]|0)+Ma|0,(c[ca>>2]|0)+(Aa+wa)|0,na);break}}}while(0);cb=Pe[G&255](L,c[O>>2]|0,c[K>>2]|0,na,16)|0}}while(0);c[qa>>2]=ra;c[q+(sa<<2)>>2]=cb;na=(ba((d[z+((oa<<E)-B)|0]|0)+(d[z+((ka<<E)-A)|0]|0)|0,h)|0)+cb|0;if((na|0)<(c[V>>2]|0)){hb=0}else{break}while(1){ib=n+(hb<<4)|0;jb=ib|0;kb=hb+1|0;if((na|0)<(c[jb>>2]|0)){break}else{hb=kb}}VGb(n+(kb<<4)|0,ib|0,(J-hb<<4)-16|0)|0;c[n+(hb<<4)+12>>2]=0;c[jb>>2]=na;c[n+(hb<<4)+4>>2]=ka;c[n+(hb<<4)+8>>2]=oa;Ta=-1;break a}}while(0);oa=la+1|0;sa=pa+(oa<<11)|0;ra=(oa<<3)+ka&63;qa=C+(ra<<2)|0;do{if((c[qa>>2]|0)!=(sa|0)){Ba=c[P>>2]|0;do{if(p){Fa=c[o>>2]|0;ua=(c[I>>2]|0)+((ba(Ba,oa)|0)+ka)|0;va=Pe[G&255](L,c[K>>2]|0,ua,Ba,k)|0;if(N){lb=va;break}ua=oa<<1&2|ka&1;ta=c[O>>2]|0;wa=Ba<<4;Aa=ta+wa|0;Ma=(ba(Fa,oa>>1)|0)+(ka>>1)|0;cf[c[(c[M>>2]|0)+(H<<4)+(ua<<2)>>2]&1023](Aa,(c[Q>>2]|0)+Ma|0,Fa,R);Xa=ta+(wa|8)|0;cf[c[(c[M>>2]|0)+(H<<4)+(ua<<2)>>2]&1023](Xa,(c[S>>2]|0)+Ma|0,Fa,R);Ma=(Pe[j&255](L,Aa,c[T>>2]|0,Fa,R)|0)+va|0;lb=Ma+(Pe[j&255](L,Xa,c[U>>2]|0,Fa,R)|0)|0}else{Fa=ka<<E;Xa=oa<<E;if((c[r>>2]|0)>(ka|0)){lb=536870912;break}if((Fa|0)>(c[v>>2]<<E|0)){lb=536870912;break}if((c[t>>2]|0)>(oa|0)){lb=536870912;break}if((Xa|0)>(c[x>>2]<<E|0)){lb=536870912;break}Ma=e[W>>1]|0;va=e[X>>1]|0;e:do{if((c[Z>>2]|0)==1){Aa=va-Ma|0;ua=(Xa|0)==0;wa=Ba<<3;if((Fa|0)==0){ta=0;while(1){ya=c[a+12160+(ta<<3)>>2]|0;Ea=(c[a+12160+(ta<<3)+4>>2]|0)+Xa|0;Ka=((ba(c[a+12128+(ta<<3)>>2]|0,Aa)|0)/(Ma|0)|0)+((ta&1)<<_)|0;za=c[a+12128+(ta<<3)+4>>2]|0;if(ua){Da=ta>>1;mb=((ba(za,Aa)|0)/(Ma|0)|0)+(Da<<_)|0;nb=Da}else{mb=Ea-za|0;nb=ta>>1}za=((Ea&Y)<<E)+(ya&Y)|0;Da=((mb&Y)<<E)+(Ka&Y)|0;Ga=(c[O>>2]|0)+((ba(nb,wa)|0)+(ta<<3&8))|0;if($){Ca=(c[I>>2]|0)+((ba(Ea>>1,Ba)|0)+(ya>>1))|0;cf[c[(c[M>>2]|0)+16+(za<<2)>>2]&1023](Ga,Ca,Ba,8);Ca=(c[ca>>2]|0)+((ba(mb>>1,Ba)|0)+(Ka>>1))|0;cf[c[(c[aa>>2]|0)+16+(Da<<2)>>2]&1023](Ga,Ca,Ba,8)}else{Ca=(c[I>>2]|0)+((ba(Ea>>2,Ba)|0)+(ya>>2))|0;Xe[c[(c[da>>2]|0)+64+(za<<2)>>2]&4095](Ga,Ca,Ba);Ca=(c[ca>>2]|0)+((ba(mb>>2,Ba)|0)+(Ka>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Da<<2)>>2]&4095](Ga,Ca,Ba)}ta=ta+1|0;if((ta|0)>=4){break e}}}if(ua){ta=0;do{Ca=(c[a+12160+(ta<<3)>>2]|0)+Fa|0;Ga=c[a+12160+(ta<<3)+4>>2]|0;Da=Ca-(c[a+12128+(ta<<3)>>2]|0)|0;Ka=ta>>1;za=((ba(c[a+12128+(ta<<3)+4>>2]|0,Aa)|0)/(Ma|0)|0)+(Ka<<_)|0;ya=((Ga&Y)<<E)+(Ca&Y)|0;Ea=((za&Y)<<E)+(Da&Y)|0;Ha=(c[O>>2]|0)+((ta<<3&8)+(ba(Ka,wa)|0))|0;if($){Ka=(c[I>>2]|0)+((ba(Ga>>1,Ba)|0)+(Ca>>1))|0;cf[c[(c[M>>2]|0)+16+(ya<<2)>>2]&1023](Ha,Ka,Ba,8);Ka=(c[ca>>2]|0)+((ba(za>>1,Ba)|0)+(Da>>1))|0;cf[c[(c[aa>>2]|0)+16+(Ea<<2)>>2]&1023](Ha,Ka,Ba,8)}else{Ka=(c[I>>2]|0)+((ba(Ga>>2,Ba)|0)+(Ca>>2))|0;Xe[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095](Ha,Ka,Ba);Ka=(c[ca>>2]|0)+((ba(za>>2,Ba)|0)+(Da>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Ea<<2)>>2]&4095](Ha,Ka,Ba)}ta=ta+1|0;}while((ta|0)<4)}else{ta=0;do{Aa=(c[a+12160+(ta<<3)>>2]|0)+Fa|0;ua=(c[a+12160+(ta<<3)+4>>2]|0)+Xa|0;Ka=Aa-(c[a+12128+(ta<<3)>>2]|0)|0;Ha=ua-(c[a+12128+(ta<<3)+4>>2]|0)|0;Ea=((ua&Y)<<E)+(Aa&Y)|0;Da=((Ha&Y)<<E)+(Ka&Y)|0;za=(c[O>>2]|0)+((ta<<3&8)+(ba(ta>>1,wa)|0))|0;if($){ya=(c[I>>2]|0)+((ba(ua>>1,Ba)|0)+(Aa>>1))|0;cf[c[(c[M>>2]|0)+16+(Ea<<2)>>2]&1023](za,ya,Ba,8);ya=(c[ca>>2]|0)+((ba(Ha>>1,Ba)|0)+(Ka>>1))|0;cf[c[(c[aa>>2]|0)+16+(Da<<2)>>2]&1023](za,ya,Ba,8)}else{ya=(c[I>>2]|0)+((ba(ua>>2,Ba)|0)+(Aa>>2))|0;Xe[c[(c[da>>2]|0)+64+(Ea<<2)>>2]&4095](za,ya,Ba);ya=(c[ca>>2]|0)+((ba(Ha>>2,Ba)|0)+(Ka>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Da<<2)>>2]&4095](za,ya,Ba)}ta=ta+1|0;}while((ta|0)<4)}}else{ta=(c[fa>>2]|0)+Fa|0;wa=(c[ga>>2]|0)+Xa|0;ya=c[ha>>2]|0;if((Fa|0)==0){ob=(ba(ya,va-Ma|0)|0)/(Ma|0)|0}else{ob=ta-ya|0}ya=c[ia>>2]|0;if((Xa|0)==0){pb=(ba(ya,va-Ma|0)|0)/(Ma|0)|0}else{pb=wa-ya|0}ya=((wa&Y)<<E)+(ta&Y)|0;za=((pb&Y)<<E)+(ob&Y)|0;if($){Da=(c[I>>2]|0)+((ba(wa>>1,Ba)|0)+(ta>>1))|0;cf[c[(c[M>>2]|0)+(ya<<2)>>2]&1023](c[O>>2]|0,Da,Ba,16);Da=(c[ca>>2]|0)+((ba(pb>>1,Ba)|0)+(ob>>1))|0;cf[c[(c[aa>>2]|0)+(za<<2)>>2]&1023](c[O>>2]|0,Da,Ba,16);break}else{Da=(ba(wa>>2,Ba)|0)+(ta>>2)|0;Xe[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095](c[O>>2]|0,(c[I>>2]|0)+Da|0,Ba);ta=Da+8|0;Xe[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[I>>2]|0)+ta|0,Ba);wa=Ba<<3;Xe[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095]((c[O>>2]|0)+wa|0,(c[I>>2]|0)+(Da+wa)|0,Ba);Da=wa+8|0;Xe[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095]((c[O>>2]|0)+Da|0,(c[I>>2]|0)+(ta+wa)|0,Ba);ta=(ba(pb>>2,Ba)|0)+(ob>>2)|0;Xe[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095](c[O>>2]|0,(c[ca>>2]|0)+ta|0,Ba);ya=ta+8|0;Xe[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[ca>>2]|0)+ya|0,Ba);Xe[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095]((c[O>>2]|0)+wa|0,(c[ca>>2]|0)+(ta+wa)|0,Ba);Xe[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095]((c[O>>2]|0)+Da|0,(c[ca>>2]|0)+(ya+wa)|0,Ba);break}}}while(0);lb=Pe[G&255](L,c[O>>2]|0,c[K>>2]|0,Ba,16)|0}}while(0);c[qa>>2]=sa;c[q+(ra<<2)>>2]=lb;Ba=(ba((d[z+((oa<<E)-B)|0]|0)+(d[z+((ka<<E)-A)|0]|0)|0,h)|0)+lb|0;if((Ba|0)<(c[V>>2]|0)){qb=0}else{break}while(1){rb=n+(qb<<4)|0;sb=rb|0;tb=qb+1|0;if((Ba|0)<(c[sb>>2]|0)){break}else{qb=tb}}VGb(n+(tb<<4)|0,rb|0,(J-qb<<4)-16|0)|0;c[n+(qb<<4)+12>>2]=0;c[sb>>2]=Ba;c[n+(qb<<4)+4>>2]=ka;c[n+(qb<<4)+8>>2]=oa;Ta=-1;break a}}while(0);c[ma>>2]=1;Ta=ja}else{Ta=ja}}while(0);ja=Ta+1|0;}while((ja|0)<(J|0))}J=c[n+4>>2]|0;c[b>>2]=J;ja=c[n+8>>2]|0;Ta=b+4|0;c[Ta>>2]=ja;qb=c[n>>2]|0;if(!((J|0)<(w|0)&(J|0)>(s|0)&(ja|0)<(y|0)&(ja|0)>(u|0))){ub=qb;i=m;return ub|0}u=J-1|0;y=(ja<<11)+F+u|0;s=u+(ja<<3)&63;w=C+(s<<2)|0;do{if((c[w>>2]|0)==(y|0)){vb=qb;wb=ja;xb=J}else{do{if((l&4|0)==0){n=c[a+12416>>2]|0;sb=c[a+12420>>2]|0;rb=a;tb=(c[a+12352+(g<<4)>>2]|0)+((ba(n,ja)|0)+u)|0;V=Pe[G&255](rb,c[a+12288+(f<<4)>>2]|0,tb,n,k)|0;if((l&2|0)==0){yb=V;break}tb=u&1|ja<<1&2;lb=c[a+12208>>2]|0;K=n<<4;n=lb+K|0;O=a+12444|0;L=(ba(sb,ja>>1)|0)+(u>>1)|0;ca=k>>1;cf[c[(c[O>>2]|0)+(H<<4)+(tb<<2)>>2]&1023](n,(c[a+12352+(g<<4)+4>>2]|0)+L|0,sb,ca);ea=lb+(K|8)|0;cf[c[(c[O>>2]|0)+(H<<4)+(tb<<2)>>2]&1023](ea,(c[a+12352+(g<<4)+8>>2]|0)+L|0,sb,ca);L=(Pe[j&255](rb,n,c[a+12288+(f<<4)+4>>2]|0,sb,ca)|0)+V|0;yb=L+(Pe[j&255](rb,ea,c[a+12288+(f<<4)+8>>2]|0,sb,ca)|0)|0}else{ca=c[a+12416>>2]|0;sb=u<<E;ea=ja<<E;rb=a+12352+(g<<4)|0;L=a+12288+(f<<4)|0;if((c[r>>2]|0)>(u|0)){yb=536870912;break}if((sb|0)>(c[v>>2]<<E|0)){yb=536870912;break}if((c[t>>2]|0)>(ja|0)){yb=536870912;break}if((ea|0)>(c[x>>2]<<E|0)){yb=536870912;break}V=e[a+13872>>1]|0;n=e[a+13874>>1]|0;tb=D<<1|1;f:do{if((c[a+11740>>2]|0)==1){O=n-V|0;K=D|4;lb=(ea|0)==0;ob=a+12208|0;pb=ca<<3;I=(D|0)==0;da=a+12444|0;aa=a+12448|0;M=a+12352+(g<<4)+32|0;$=a+12452|0;Y=a+12456|0;if((sb|0)==0){ia=0;while(1){ha=c[a+12160+(ia<<3)>>2]|0;ga=(c[a+12160+(ia<<3)+4>>2]|0)+ea|0;fa=((ba(c[a+12128+(ia<<3)>>2]|0,O)|0)/(V|0)|0)+((ia&1)<<K)|0;_=c[a+12128+(ia<<3)+4>>2]|0;if(lb){mb=ia>>1;zb=((ba(_,O)|0)/(V|0)|0)+(mb<<K)|0;Ab=mb}else{zb=ga-_|0;Ab=ia>>1}_=((ga&tb)<<E)+(ha&tb)|0;mb=((zb&tb)<<E)+(fa&tb)|0;nb=(c[ob>>2]|0)+((ba(Ab,pb)|0)+(ia<<3&8))|0;if(I){Z=(c[rb>>2]|0)+((ba(ga>>1,ca)|0)+(ha>>1))|0;cf[c[(c[da>>2]|0)+16+(_<<2)>>2]&1023](nb,Z,ca,8);Z=(c[M>>2]|0)+((ba(zb>>1,ca)|0)+(fa>>1))|0;cf[c[(c[aa>>2]|0)+16+(mb<<2)>>2]&1023](nb,Z,ca,8)}else{Z=(c[rb>>2]|0)+((ba(ga>>2,ca)|0)+(ha>>2))|0;Xe[c[(c[$>>2]|0)+64+(_<<2)>>2]&4095](nb,Z,ca);Z=(c[M>>2]|0)+((ba(zb>>2,ca)|0)+(fa>>2))|0;Xe[c[(c[Y>>2]|0)+64+(mb<<2)>>2]&4095](nb,Z,ca)}ia=ia+1|0;if((ia|0)>=4){break f}}}if(lb){ia=0;do{Ba=(c[a+12160+(ia<<3)>>2]|0)+sb|0;Z=c[a+12160+(ia<<3)+4>>2]|0;nb=Ba-(c[a+12128+(ia<<3)>>2]|0)|0;mb=ia>>1;fa=((ba(c[a+12128+(ia<<3)+4>>2]|0,O)|0)/(V|0)|0)+(mb<<K)|0;_=((Z&tb)<<E)+(Ba&tb)|0;ha=((fa&tb)<<E)+(nb&tb)|0;ga=(c[ob>>2]|0)+((ia<<3&8)+(ba(mb,pb)|0))|0;if(I){mb=(c[rb>>2]|0)+((ba(Z>>1,ca)|0)+(Ba>>1))|0;cf[c[(c[da>>2]|0)+16+(_<<2)>>2]&1023](ga,mb,ca,8);mb=(c[M>>2]|0)+((ba(fa>>1,ca)|0)+(nb>>1))|0;cf[c[(c[aa>>2]|0)+16+(ha<<2)>>2]&1023](ga,mb,ca,8)}else{mb=(c[rb>>2]|0)+((ba(Z>>2,ca)|0)+(Ba>>2))|0;Xe[c[(c[$>>2]|0)+64+(_<<2)>>2]&4095](ga,mb,ca);mb=(c[M>>2]|0)+((ba(fa>>2,ca)|0)+(nb>>2))|0;Xe[c[(c[Y>>2]|0)+64+(ha<<2)>>2]&4095](ga,mb,ca)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{K=(c[a+12160+(ia<<3)>>2]|0)+sb|0;O=(c[a+12160+(ia<<3)+4>>2]|0)+ea|0;lb=K-(c[a+12128+(ia<<3)>>2]|0)|0;mb=O-(c[a+12128+(ia<<3)+4>>2]|0)|0;ga=((O&tb)<<E)+(K&tb)|0;ha=((mb&tb)<<E)+(lb&tb)|0;nb=(c[ob>>2]|0)+((ia<<3&8)+(ba(ia>>1,pb)|0))|0;if(I){fa=(c[rb>>2]|0)+((ba(O>>1,ca)|0)+(K>>1))|0;cf[c[(c[da>>2]|0)+16+(ga<<2)>>2]&1023](nb,fa,ca,8);fa=(c[M>>2]|0)+((ba(mb>>1,ca)|0)+(lb>>1))|0;cf[c[(c[aa>>2]|0)+16+(ha<<2)>>2]&1023](nb,fa,ca,8)}else{fa=(c[rb>>2]|0)+((ba(O>>2,ca)|0)+(K>>2))|0;Xe[c[(c[$>>2]|0)+64+(ga<<2)>>2]&4095](nb,fa,ca);fa=(c[M>>2]|0)+((ba(mb>>2,ca)|0)+(lb>>2))|0;Xe[c[(c[Y>>2]|0)+64+(ha<<2)>>2]&4095](nb,fa,ca)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[a+12160>>2]|0)+sb|0;Y=(c[a+12164>>2]|0)+ea|0;M=c[a+12128>>2]|0;if((sb|0)==0){Bb=(ba(M,n-V|0)|0)/(V|0)|0}else{Bb=ia-M|0}M=c[a+12132>>2]|0;if((ea|0)==0){Cb=(ba(M,n-V|0)|0)/(V|0)|0}else{Cb=Y-M|0}M=((Y&tb)<<E)+(ia&tb)|0;$=((Cb&tb)<<E)+(Bb&tb)|0;if((D|0)==0){aa=a+12208|0;da=(c[rb>>2]|0)+((ba(Y>>1,ca)|0)+(ia>>1))|0;cf[c[(c[a+12444>>2]|0)+(M<<2)>>2]&1023](c[aa>>2]|0,da,ca,16);da=(c[a+12352+(g<<4)+32>>2]|0)+((ba(Cb>>1,ca)|0)+(Bb>>1))|0;cf[c[(c[a+12448>>2]|0)+($<<2)>>2]&1023](c[aa>>2]|0,da,ca,16);break}else{da=a+12452|0;aa=a+12208|0;I=(ba(Y>>2,ca)|0)+(ia>>2)|0;Xe[c[(c[da>>2]|0)+64+(M<<2)>>2]&4095](c[aa>>2]|0,(c[rb>>2]|0)+I|0,ca);ia=I+8|0;Xe[c[(c[da>>2]|0)+64+(M<<2)>>2]&4095]((c[aa>>2]|0)+8|0,(c[rb>>2]|0)+ia|0,ca);Y=ca<<3;Xe[c[(c[da>>2]|0)+64+(M<<2)>>2]&4095]((c[aa>>2]|0)+Y|0,(c[rb>>2]|0)+(I+Y)|0,ca);I=Y+8|0;Xe[c[(c[da>>2]|0)+64+(M<<2)>>2]&4095]((c[aa>>2]|0)+I|0,(c[rb>>2]|0)+(ia+Y)|0,ca);ia=a+12456|0;M=a+12352+(g<<4)+32|0;da=(ba(Cb>>2,ca)|0)+(Bb>>2)|0;Xe[c[(c[ia>>2]|0)+64+($<<2)>>2]&4095](c[aa>>2]|0,(c[M>>2]|0)+da|0,ca);pb=da+8|0;Xe[c[(c[ia>>2]|0)+64+($<<2)>>2]&4095]((c[aa>>2]|0)+8|0,(c[M>>2]|0)+pb|0,ca);Xe[c[(c[ia>>2]|0)+64+($<<2)>>2]&4095]((c[aa>>2]|0)+Y|0,(c[M>>2]|0)+(da+Y)|0,ca);Xe[c[(c[ia>>2]|0)+64+($<<2)>>2]&4095]((c[aa>>2]|0)+I|0,(c[M>>2]|0)+(pb+Y)|0,ca);break}}}while(0);yb=Pe[G&255](a,c[a+12208>>2]|0,c[L>>2]|0,ca,16)|0}}while(0);c[w>>2]=y;c[q+(s<<2)>>2]=yb;rb=c[b>>2]|0;tb=rb-1|0;V=c[Ta>>2]|0;n=(ba((d[z+((V<<E)-B)|0]|0)+(d[z+((tb<<E)-A)|0]|0)|0,h)|0)+yb|0;if((n|0)>=(qb|0)){vb=qb;wb=V;xb=rb;break}c[b>>2]=tb;vb=n;wb=V;xb=tb}}while(0);qb=xb+1|0;yb=(wb<<11)+F+qb|0;s=qb+(wb<<3)&63;y=C+(s<<2)|0;do{if((c[y>>2]|0)==(yb|0)){Db=vb;Eb=wb;Fb=xb}else{do{if((l&4|0)==0){w=c[a+12416>>2]|0;Bb=c[a+12420>>2]|0;Cb=a;zb=(c[a+12352+(g<<4)>>2]|0)+((ba(w,wb)|0)+qb)|0;Ab=Pe[G&255](Cb,c[a+12288+(f<<4)>>2]|0,zb,w,k)|0;if((l&2|0)==0){Gb=Ab;break}zb=qb&1|wb<<1&2;ja=c[a+12208>>2]|0;u=w<<4;w=ja+u|0;J=a+12444|0;tb=(ba(Bb,wb>>1)|0)+(qb>>1)|0;V=k>>1;cf[c[(c[J>>2]|0)+(H<<4)+(zb<<2)>>2]&1023](w,(c[a+12352+(g<<4)+4>>2]|0)+tb|0,Bb,V);n=ja+(u|8)|0;cf[c[(c[J>>2]|0)+(H<<4)+(zb<<2)>>2]&1023](n,(c[a+12352+(g<<4)+8>>2]|0)+tb|0,Bb,V);tb=(Pe[j&255](Cb,w,c[a+12288+(f<<4)+4>>2]|0,Bb,V)|0)+Ab|0;Gb=tb+(Pe[j&255](Cb,n,c[a+12288+(f<<4)+8>>2]|0,Bb,V)|0)|0}else{V=c[a+12416>>2]|0;Bb=qb<<E;n=wb<<E;Cb=a+12352+(g<<4)|0;tb=a+12288+(f<<4)|0;if((c[r>>2]|0)>(qb|0)){Gb=536870912;break}if((Bb|0)>(c[v>>2]<<E|0)){Gb=536870912;break}if((c[t>>2]|0)>(wb|0)){Gb=536870912;break}if((n|0)>(c[x>>2]<<E|0)){Gb=536870912;break}Ab=e[a+13872>>1]|0;w=e[a+13874>>1]|0;zb=D<<1|1;g:do{if((c[a+11740>>2]|0)==1){J=w-Ab|0;u=D|4;ja=(n|0)==0;rb=a+12208|0;ea=V<<3;sb=(D|0)==0;Y=a+12444|0;pb=a+12448|0;M=a+12352+(g<<4)+32|0;I=a+12452|0;aa=a+12456|0;if((Bb|0)==0){$=0;while(1){ia=c[a+12160+($<<3)>>2]|0;da=(c[a+12160+($<<3)+4>>2]|0)+n|0;ob=((ba(c[a+12128+($<<3)>>2]|0,J)|0)/(Ab|0)|0)+(($&1)<<u)|0;fa=c[a+12128+($<<3)+4>>2]|0;if(ja){nb=$>>1;Hb=((ba(fa,J)|0)/(Ab|0)|0)+(nb<<u)|0;Ib=nb}else{Hb=da-fa|0;Ib=$>>1}fa=((da&zb)<<E)+(ia&zb)|0;nb=((Hb&zb)<<E)+(ob&zb)|0;ha=(c[rb>>2]|0)+((ba(Ib,ea)|0)+($<<3&8))|0;if(sb){lb=(c[Cb>>2]|0)+((ba(da>>1,V)|0)+(ia>>1))|0;cf[c[(c[Y>>2]|0)+16+(fa<<2)>>2]&1023](ha,lb,V,8);lb=(c[M>>2]|0)+((ba(Hb>>1,V)|0)+(ob>>1))|0;cf[c[(c[pb>>2]|0)+16+(nb<<2)>>2]&1023](ha,lb,V,8)}else{lb=(c[Cb>>2]|0)+((ba(da>>2,V)|0)+(ia>>2))|0;Xe[c[(c[I>>2]|0)+64+(fa<<2)>>2]&4095](ha,lb,V);lb=(c[M>>2]|0)+((ba(Hb>>2,V)|0)+(ob>>2))|0;Xe[c[(c[aa>>2]|0)+64+(nb<<2)>>2]&4095](ha,lb,V)}$=$+1|0;if(($|0)>=4){break g}}}if(ja){$=0;do{lb=(c[a+12160+($<<3)>>2]|0)+Bb|0;ha=c[a+12160+($<<3)+4>>2]|0;nb=lb-(c[a+12128+($<<3)>>2]|0)|0;ob=$>>1;fa=((ba(c[a+12128+($<<3)+4>>2]|0,J)|0)/(Ab|0)|0)+(ob<<u)|0;ia=((ha&zb)<<E)+(lb&zb)|0;da=((fa&zb)<<E)+(nb&zb)|0;mb=(c[rb>>2]|0)+(($<<3&8)+(ba(ob,ea)|0))|0;if(sb){ob=(c[Cb>>2]|0)+((ba(ha>>1,V)|0)+(lb>>1))|0;cf[c[(c[Y>>2]|0)+16+(ia<<2)>>2]&1023](mb,ob,V,8);ob=(c[M>>2]|0)+((ba(fa>>1,V)|0)+(nb>>1))|0;cf[c[(c[pb>>2]|0)+16+(da<<2)>>2]&1023](mb,ob,V,8)}else{ob=(c[Cb>>2]|0)+((ba(ha>>2,V)|0)+(lb>>2))|0;Xe[c[(c[I>>2]|0)+64+(ia<<2)>>2]&4095](mb,ob,V);ob=(c[M>>2]|0)+((ba(fa>>2,V)|0)+(nb>>2))|0;Xe[c[(c[aa>>2]|0)+64+(da<<2)>>2]&4095](mb,ob,V)}$=$+1|0;}while(($|0)<4)}else{$=0;do{u=(c[a+12160+($<<3)>>2]|0)+Bb|0;J=(c[a+12160+($<<3)+4>>2]|0)+n|0;ja=u-(c[a+12128+($<<3)>>2]|0)|0;ob=J-(c[a+12128+($<<3)+4>>2]|0)|0;mb=((J&zb)<<E)+(u&zb)|0;da=((ob&zb)<<E)+(ja&zb)|0;nb=(c[rb>>2]|0)+(($<<3&8)+(ba($>>1,ea)|0))|0;if(sb){fa=(c[Cb>>2]|0)+((ba(J>>1,V)|0)+(u>>1))|0;cf[c[(c[Y>>2]|0)+16+(mb<<2)>>2]&1023](nb,fa,V,8);fa=(c[M>>2]|0)+((ba(ob>>1,V)|0)+(ja>>1))|0;cf[c[(c[pb>>2]|0)+16+(da<<2)>>2]&1023](nb,fa,V,8)}else{fa=(c[Cb>>2]|0)+((ba(J>>2,V)|0)+(u>>2))|0;Xe[c[(c[I>>2]|0)+64+(mb<<2)>>2]&4095](nb,fa,V);fa=(c[M>>2]|0)+((ba(ob>>2,V)|0)+(ja>>2))|0;Xe[c[(c[aa>>2]|0)+64+(da<<2)>>2]&4095](nb,fa,V)}$=$+1|0;}while(($|0)<4)}}else{$=(c[a+12160>>2]|0)+Bb|0;aa=(c[a+12164>>2]|0)+n|0;M=c[a+12128>>2]|0;if((Bb|0)==0){Jb=(ba(M,w-Ab|0)|0)/(Ab|0)|0}else{Jb=$-M|0}M=c[a+12132>>2]|0;if((n|0)==0){Kb=(ba(M,w-Ab|0)|0)/(Ab|0)|0}else{Kb=aa-M|0}M=((aa&zb)<<E)+($&zb)|0;I=((Kb&zb)<<E)+(Jb&zb)|0;if((D|0)==0){pb=a+12208|0;Y=(c[Cb>>2]|0)+((ba(aa>>1,V)|0)+($>>1))|0;cf[c[(c[a+12444>>2]|0)+(M<<2)>>2]&1023](c[pb>>2]|0,Y,V,16);Y=(c[a+12352+(g<<4)+32>>2]|0)+((ba(Kb>>1,V)|0)+(Jb>>1))|0;cf[c[(c[a+12448>>2]|0)+(I<<2)>>2]&1023](c[pb>>2]|0,Y,V,16);break}else{Y=a+12452|0;pb=a+12208|0;sb=(ba(aa>>2,V)|0)+($>>2)|0;Xe[c[(c[Y>>2]|0)+64+(M<<2)>>2]&4095](c[pb>>2]|0,(c[Cb>>2]|0)+sb|0,V);$=sb+8|0;Xe[c[(c[Y>>2]|0)+64+(M<<2)>>2]&4095]((c[pb>>2]|0)+8|0,(c[Cb>>2]|0)+$|0,V);aa=V<<3;Xe[c[(c[Y>>2]|0)+64+(M<<2)>>2]&4095]((c[pb>>2]|0)+aa|0,(c[Cb>>2]|0)+(sb+aa)|0,V);sb=aa+8|0;Xe[c[(c[Y>>2]|0)+64+(M<<2)>>2]&4095]((c[pb>>2]|0)+sb|0,(c[Cb>>2]|0)+($+aa)|0,V);$=a+12456|0;M=a+12352+(g<<4)+32|0;Y=(ba(Kb>>2,V)|0)+(Jb>>2)|0;Xe[c[(c[$>>2]|0)+64+(I<<2)>>2]&4095](c[pb>>2]|0,(c[M>>2]|0)+Y|0,V);ea=Y+8|0;Xe[c[(c[$>>2]|0)+64+(I<<2)>>2]&4095]((c[pb>>2]|0)+8|0,(c[M>>2]|0)+ea|0,V);Xe[c[(c[$>>2]|0)+64+(I<<2)>>2]&4095]((c[pb>>2]|0)+aa|0,(c[M>>2]|0)+(Y+aa)|0,V);Xe[c[(c[$>>2]|0)+64+(I<<2)>>2]&4095]((c[pb>>2]|0)+sb|0,(c[M>>2]|0)+(ea+aa)|0,V);break}}}while(0);Gb=Pe[G&255](a,c[a+12208>>2]|0,c[tb>>2]|0,V,16)|0}}while(0);c[y>>2]=yb;c[q+(s<<2)>>2]=Gb;Cb=c[b>>2]|0;zb=Cb+1|0;Ab=c[Ta>>2]|0;w=(ba((d[z+((Ab<<E)-B)|0]|0)+(d[z+((zb<<E)-A)|0]|0)|0,h)|0)+Gb|0;if((w|0)>=(vb|0)){Db=vb;Eb=Ab;Fb=Cb;break}c[b>>2]=zb;Db=w;Eb=Ab;Fb=zb}}while(0);vb=Eb-1|0;Gb=Fb+F+(vb<<11)|0;s=(vb<<3)+Fb&63;yb=C+(s<<2)|0;do{if((c[yb>>2]|0)==(Gb|0)){Lb=Db;Mb=Eb;Nb=Fb}else{do{if((l&4|0)==0){y=c[a+12416>>2]|0;Jb=c[a+12420>>2]|0;Kb=a;Hb=(c[a+12352+(g<<4)>>2]|0)+((ba(y,vb)|0)+Fb)|0;Ib=Pe[G&255](Kb,c[a+12288+(f<<4)>>2]|0,Hb,y,k)|0;if((l&2|0)==0){Ob=Ib;break}Hb=vb<<1&2|Fb&1;wb=c[a+12208>>2]|0;qb=y<<4;y=wb+qb|0;xb=a+12444|0;zb=(ba(Jb,vb>>1)|0)+(Fb>>1)|0;Ab=k>>1;cf[c[(c[xb>>2]|0)+(H<<4)+(Hb<<2)>>2]&1023](y,(c[a+12352+(g<<4)+4>>2]|0)+zb|0,Jb,Ab);w=wb+(qb|8)|0;cf[c[(c[xb>>2]|0)+(H<<4)+(Hb<<2)>>2]&1023](w,(c[a+12352+(g<<4)+8>>2]|0)+zb|0,Jb,Ab);zb=(Pe[j&255](Kb,y,c[a+12288+(f<<4)+4>>2]|0,Jb,Ab)|0)+Ib|0;Ob=zb+(Pe[j&255](Kb,w,c[a+12288+(f<<4)+8>>2]|0,Jb,Ab)|0)|0}else{Ab=c[a+12416>>2]|0;Jb=Fb<<E;w=vb<<E;Kb=a+12352+(g<<4)|0;zb=a+12288+(f<<4)|0;if((c[r>>2]|0)>(Fb|0)){Ob=536870912;break}if((Jb|0)>(c[v>>2]<<E|0)){Ob=536870912;break}if((c[t>>2]|0)>(vb|0)){Ob=536870912;break}if((w|0)>(c[x>>2]<<E|0)){Ob=536870912;break}Ib=e[a+13872>>1]|0;y=e[a+13874>>1]|0;Hb=D<<1|1;h:do{if((c[a+11740>>2]|0)==1){xb=y-Ib|0;qb=D|4;wb=(w|0)==0;Cb=a+12208|0;n=Ab<<3;Bb=(D|0)==0;ca=a+12444|0;L=a+12448|0;aa=a+12352+(g<<4)+32|0;ea=a+12452|0;M=a+12456|0;if((Jb|0)==0){sb=0;while(1){pb=c[a+12160+(sb<<3)>>2]|0;I=(c[a+12160+(sb<<3)+4>>2]|0)+w|0;$=((ba(c[a+12128+(sb<<3)>>2]|0,xb)|0)/(Ib|0)|0)+((sb&1)<<qb)|0;Y=c[a+12128+(sb<<3)+4>>2]|0;if(wb){rb=sb>>1;Pb=((ba(Y,xb)|0)/(Ib|0)|0)+(rb<<qb)|0;Qb=rb}else{Pb=I-Y|0;Qb=sb>>1}Y=((I&Hb)<<E)+(pb&Hb)|0;rb=((Pb&Hb)<<E)+($&Hb)|0;fa=(c[Cb>>2]|0)+((ba(Qb,n)|0)+(sb<<3&8))|0;if(Bb){nb=(c[Kb>>2]|0)+((ba(I>>1,Ab)|0)+(pb>>1))|0;cf[c[(c[ca>>2]|0)+16+(Y<<2)>>2]&1023](fa,nb,Ab,8);nb=(c[aa>>2]|0)+((ba(Pb>>1,Ab)|0)+($>>1))|0;cf[c[(c[L>>2]|0)+16+(rb<<2)>>2]&1023](fa,nb,Ab,8)}else{nb=(c[Kb>>2]|0)+((ba(I>>2,Ab)|0)+(pb>>2))|0;Xe[c[(c[ea>>2]|0)+64+(Y<<2)>>2]&4095](fa,nb,Ab);nb=(c[aa>>2]|0)+((ba(Pb>>2,Ab)|0)+($>>2))|0;Xe[c[(c[M>>2]|0)+64+(rb<<2)>>2]&4095](fa,nb,Ab)}sb=sb+1|0;if((sb|0)>=4){break h}}}if(wb){sb=0;do{nb=(c[a+12160+(sb<<3)>>2]|0)+Jb|0;fa=c[a+12160+(sb<<3)+4>>2]|0;rb=nb-(c[a+12128+(sb<<3)>>2]|0)|0;$=sb>>1;Y=((ba(c[a+12128+(sb<<3)+4>>2]|0,xb)|0)/(Ib|0)|0)+($<<qb)|0;pb=((fa&Hb)<<E)+(nb&Hb)|0;I=((Y&Hb)<<E)+(rb&Hb)|0;da=(c[Cb>>2]|0)+((sb<<3&8)+(ba($,n)|0))|0;if(Bb){$=(c[Kb>>2]|0)+((ba(fa>>1,Ab)|0)+(nb>>1))|0;cf[c[(c[ca>>2]|0)+16+(pb<<2)>>2]&1023](da,$,Ab,8);$=(c[aa>>2]|0)+((ba(Y>>1,Ab)|0)+(rb>>1))|0;cf[c[(c[L>>2]|0)+16+(I<<2)>>2]&1023](da,$,Ab,8)}else{$=(c[Kb>>2]|0)+((ba(fa>>2,Ab)|0)+(nb>>2))|0;Xe[c[(c[ea>>2]|0)+64+(pb<<2)>>2]&4095](da,$,Ab);$=(c[aa>>2]|0)+((ba(Y>>2,Ab)|0)+(rb>>2))|0;Xe[c[(c[M>>2]|0)+64+(I<<2)>>2]&4095](da,$,Ab)}sb=sb+1|0;}while((sb|0)<4)}else{sb=0;do{qb=(c[a+12160+(sb<<3)>>2]|0)+Jb|0;xb=(c[a+12160+(sb<<3)+4>>2]|0)+w|0;wb=qb-(c[a+12128+(sb<<3)>>2]|0)|0;$=xb-(c[a+12128+(sb<<3)+4>>2]|0)|0;da=((xb&Hb)<<E)+(qb&Hb)|0;I=(($&Hb)<<E)+(wb&Hb)|0;rb=(c[Cb>>2]|0)+((sb<<3&8)+(ba(sb>>1,n)|0))|0;if(Bb){Y=(c[Kb>>2]|0)+((ba(xb>>1,Ab)|0)+(qb>>1))|0;cf[c[(c[ca>>2]|0)+16+(da<<2)>>2]&1023](rb,Y,Ab,8);Y=(c[aa>>2]|0)+((ba($>>1,Ab)|0)+(wb>>1))|0;cf[c[(c[L>>2]|0)+16+(I<<2)>>2]&1023](rb,Y,Ab,8)}else{Y=(c[Kb>>2]|0)+((ba(xb>>2,Ab)|0)+(qb>>2))|0;Xe[c[(c[ea>>2]|0)+64+(da<<2)>>2]&4095](rb,Y,Ab);Y=(c[aa>>2]|0)+((ba($>>2,Ab)|0)+(wb>>2))|0;Xe[c[(c[M>>2]|0)+64+(I<<2)>>2]&4095](rb,Y,Ab)}sb=sb+1|0;}while((sb|0)<4)}}else{sb=(c[a+12160>>2]|0)+Jb|0;M=(c[a+12164>>2]|0)+w|0;aa=c[a+12128>>2]|0;if((Jb|0)==0){Rb=(ba(aa,y-Ib|0)|0)/(Ib|0)|0}else{Rb=sb-aa|0}aa=c[a+12132>>2]|0;if((w|0)==0){Sb=(ba(aa,y-Ib|0)|0)/(Ib|0)|0}else{Sb=M-aa|0}aa=((M&Hb)<<E)+(sb&Hb)|0;ea=((Sb&Hb)<<E)+(Rb&Hb)|0;if((D|0)==0){L=a+12208|0;ca=(c[Kb>>2]|0)+((ba(M>>1,Ab)|0)+(sb>>1))|0;cf[c[(c[a+12444>>2]|0)+(aa<<2)>>2]&1023](c[L>>2]|0,ca,Ab,16);ca=(c[a+12352+(g<<4)+32>>2]|0)+((ba(Sb>>1,Ab)|0)+(Rb>>1))|0;cf[c[(c[a+12448>>2]|0)+(ea<<2)>>2]&1023](c[L>>2]|0,ca,Ab,16);break}else{ca=a+12452|0;L=a+12208|0;Bb=(ba(M>>2,Ab)|0)+(sb>>2)|0;Xe[c[(c[ca>>2]|0)+64+(aa<<2)>>2]&4095](c[L>>2]|0,(c[Kb>>2]|0)+Bb|0,Ab);sb=Bb+8|0;Xe[c[(c[ca>>2]|0)+64+(aa<<2)>>2]&4095]((c[L>>2]|0)+8|0,(c[Kb>>2]|0)+sb|0,Ab);M=Ab<<3;Xe[c[(c[ca>>2]|0)+64+(aa<<2)>>2]&4095]((c[L>>2]|0)+M|0,(c[Kb>>2]|0)+(Bb+M)|0,Ab);Bb=M+8|0;Xe[c[(c[ca>>2]|0)+64+(aa<<2)>>2]&4095]((c[L>>2]|0)+Bb|0,(c[Kb>>2]|0)+(sb+M)|0,Ab);sb=a+12456|0;aa=a+12352+(g<<4)+32|0;ca=(ba(Sb>>2,Ab)|0)+(Rb>>2)|0;Xe[c[(c[sb>>2]|0)+64+(ea<<2)>>2]&4095](c[L>>2]|0,(c[aa>>2]|0)+ca|0,Ab);n=ca+8|0;Xe[c[(c[sb>>2]|0)+64+(ea<<2)>>2]&4095]((c[L>>2]|0)+8|0,(c[aa>>2]|0)+n|0,Ab);Xe[c[(c[sb>>2]|0)+64+(ea<<2)>>2]&4095]((c[L>>2]|0)+M|0,(c[aa>>2]|0)+(ca+M)|0,Ab);Xe[c[(c[sb>>2]|0)+64+(ea<<2)>>2]&4095]((c[L>>2]|0)+Bb|0,(c[aa>>2]|0)+(n+M)|0,Ab);break}}}while(0);Ob=Pe[G&255](a,c[a+12208>>2]|0,c[zb>>2]|0,Ab,16)|0}}while(0);c[yb>>2]=Gb;c[q+(s<<2)>>2]=Ob;Kb=c[b>>2]|0;Hb=c[Ta>>2]|0;Ib=Hb-1|0;y=(ba((d[z+((Ib<<E)-B)|0]|0)+(d[z+((Kb<<E)-A)|0]|0)|0,h)|0)+Ob|0;if((y|0)>=(Db|0)){Lb=Db;Mb=Hb;Nb=Kb;break}c[b>>2]=Kb;c[Ta>>2]=Ib;Lb=y;Mb=Ib;Nb=Kb}}while(0);Db=Mb+1|0;Mb=Nb+F+(Db<<11)|0;F=(Db<<3)+Nb&63;Ob=C+(F<<2)|0;if((c[Ob>>2]|0)==(Mb|0)){ub=Lb;i=m;return ub|0}do{if((l&4|0)==0){C=c[a+12416>>2]|0;s=c[a+12420>>2]|0;Gb=a;yb=(c[a+12352+(g<<4)>>2]|0)+((ba(C,Db)|0)+Nb)|0;Rb=Pe[G&255](Gb,c[a+12288+(f<<4)>>2]|0,yb,C,k)|0;if((l&2|0)==0){Tb=Rb;break}yb=Db<<1&2|Nb&1;Sb=c[a+12208>>2]|0;Pb=C<<4;C=Sb+Pb|0;Qb=a+12444|0;vb=(ba(s,Db>>1)|0)+(Nb>>1)|0;Fb=k>>1;cf[c[(c[Qb>>2]|0)+(H<<4)+(yb<<2)>>2]&1023](C,(c[a+12352+(g<<4)+4>>2]|0)+vb|0,s,Fb);Eb=Sb+(Pb|8)|0;cf[c[(c[Qb>>2]|0)+(H<<4)+(yb<<2)>>2]&1023](Eb,(c[a+12352+(g<<4)+8>>2]|0)+vb|0,s,Fb);vb=(Pe[j&255](Gb,C,c[a+12288+(f<<4)+4>>2]|0,s,Fb)|0)+Rb|0;Tb=vb+(Pe[j&255](Gb,Eb,c[a+12288+(f<<4)+8>>2]|0,s,Fb)|0)|0}else{Fb=c[a+12416>>2]|0;s=Nb<<E;Eb=Db<<E;Gb=a+12352+(g<<4)|0;vb=a+12288+(f<<4)|0;if((c[r>>2]|0)>(Nb|0)){Tb=536870912;break}if((s|0)>(c[v>>2]<<E|0)){Tb=536870912;break}if((c[t>>2]|0)>(Db|0)){Tb=536870912;break}if((Eb|0)>(c[x>>2]<<E|0)){Tb=536870912;break}Rb=e[a+13872>>1]|0;C=e[a+13874>>1]|0;yb=D<<1|1;i:do{if((c[a+11740>>2]|0)==1){Qb=C-Rb|0;Pb=D|4;Sb=(Eb|0)==0;Kb=a+12208|0;Ib=Fb<<3;y=(D|0)==0;Hb=a+12444|0;w=a+12448|0;Jb=a+12352+(g<<4)+32|0;V=a+12452|0;tb=a+12456|0;if((s|0)==0){M=0;while(1){n=c[a+12160+(M<<3)>>2]|0;aa=(c[a+12160+(M<<3)+4>>2]|0)+Eb|0;Bb=((ba(c[a+12128+(M<<3)>>2]|0,Qb)|0)/(Rb|0)|0)+((M&1)<<Pb)|0;L=c[a+12128+(M<<3)+4>>2]|0;if(Sb){ea=M>>1;Ub=((ba(L,Qb)|0)/(Rb|0)|0)+(ea<<Pb)|0;Vb=ea}else{Ub=aa-L|0;Vb=M>>1}L=((aa&yb)<<E)+(n&yb)|0;ea=((Ub&yb)<<E)+(Bb&yb)|0;sb=(c[Kb>>2]|0)+((ba(Vb,Ib)|0)+(M<<3&8))|0;if(y){ca=(c[Gb>>2]|0)+((ba(aa>>1,Fb)|0)+(n>>1))|0;cf[c[(c[Hb>>2]|0)+16+(L<<2)>>2]&1023](sb,ca,Fb,8);ca=(c[Jb>>2]|0)+((ba(Ub>>1,Fb)|0)+(Bb>>1))|0;cf[c[(c[w>>2]|0)+16+(ea<<2)>>2]&1023](sb,ca,Fb,8)}else{ca=(c[Gb>>2]|0)+((ba(aa>>2,Fb)|0)+(n>>2))|0;Xe[c[(c[V>>2]|0)+64+(L<<2)>>2]&4095](sb,ca,Fb);ca=(c[Jb>>2]|0)+((ba(Ub>>2,Fb)|0)+(Bb>>2))|0;Xe[c[(c[tb>>2]|0)+64+(ea<<2)>>2]&4095](sb,ca,Fb)}M=M+1|0;if((M|0)>=4){break i}}}if(Sb){M=0;do{Ab=(c[a+12160+(M<<3)>>2]|0)+s|0;zb=c[a+12160+(M<<3)+4>>2]|0;ca=Ab-(c[a+12128+(M<<3)>>2]|0)|0;sb=M>>1;ea=((ba(c[a+12128+(M<<3)+4>>2]|0,Qb)|0)/(Rb|0)|0)+(sb<<Pb)|0;Bb=((zb&yb)<<E)+(Ab&yb)|0;L=((ea&yb)<<E)+(ca&yb)|0;n=(c[Kb>>2]|0)+((M<<3&8)+(ba(sb,Ib)|0))|0;if(y){sb=(c[Gb>>2]|0)+((ba(zb>>1,Fb)|0)+(Ab>>1))|0;cf[c[(c[Hb>>2]|0)+16+(Bb<<2)>>2]&1023](n,sb,Fb,8);sb=(c[Jb>>2]|0)+((ba(ea>>1,Fb)|0)+(ca>>1))|0;cf[c[(c[w>>2]|0)+16+(L<<2)>>2]&1023](n,sb,Fb,8)}else{sb=(c[Gb>>2]|0)+((ba(zb>>2,Fb)|0)+(Ab>>2))|0;Xe[c[(c[V>>2]|0)+64+(Bb<<2)>>2]&4095](n,sb,Fb);sb=(c[Jb>>2]|0)+((ba(ea>>2,Fb)|0)+(ca>>2))|0;Xe[c[(c[tb>>2]|0)+64+(L<<2)>>2]&4095](n,sb,Fb)}M=M+1|0;}while((M|0)<4)}else{M=0;do{Pb=(c[a+12160+(M<<3)>>2]|0)+s|0;Qb=(c[a+12160+(M<<3)+4>>2]|0)+Eb|0;Sb=Pb-(c[a+12128+(M<<3)>>2]|0)|0;sb=Qb-(c[a+12128+(M<<3)+4>>2]|0)|0;n=((Qb&yb)<<E)+(Pb&yb)|0;L=((sb&yb)<<E)+(Sb&yb)|0;ca=(c[Kb>>2]|0)+((M<<3&8)+(ba(M>>1,Ib)|0))|0;if(y){ea=(c[Gb>>2]|0)+((ba(Qb>>1,Fb)|0)+(Pb>>1))|0;cf[c[(c[Hb>>2]|0)+16+(n<<2)>>2]&1023](ca,ea,Fb,8);ea=(c[Jb>>2]|0)+((ba(sb>>1,Fb)|0)+(Sb>>1))|0;cf[c[(c[w>>2]|0)+16+(L<<2)>>2]&1023](ca,ea,Fb,8)}else{ea=(c[Gb>>2]|0)+((ba(Qb>>2,Fb)|0)+(Pb>>2))|0;Xe[c[(c[V>>2]|0)+64+(n<<2)>>2]&4095](ca,ea,Fb);ea=(c[Jb>>2]|0)+((ba(sb>>2,Fb)|0)+(Sb>>2))|0;Xe[c[(c[tb>>2]|0)+64+(L<<2)>>2]&4095](ca,ea,Fb)}M=M+1|0;}while((M|0)<4)}}else{M=(c[a+12160>>2]|0)+s|0;tb=(c[a+12164>>2]|0)+Eb|0;Jb=c[a+12128>>2]|0;if((s|0)==0){Wb=(ba(Jb,C-Rb|0)|0)/(Rb|0)|0}else{Wb=M-Jb|0}Jb=c[a+12132>>2]|0;if((Eb|0)==0){Xb=(ba(Jb,C-Rb|0)|0)/(Rb|0)|0}else{Xb=tb-Jb|0}Jb=((tb&yb)<<E)+(M&yb)|0;V=((Xb&yb)<<E)+(Wb&yb)|0;if((D|0)==0){w=a+12208|0;Hb=(c[Gb>>2]|0)+((ba(tb>>1,Fb)|0)+(M>>1))|0;cf[c[(c[a+12444>>2]|0)+(Jb<<2)>>2]&1023](c[w>>2]|0,Hb,Fb,16);Hb=(c[a+12352+(g<<4)+32>>2]|0)+((ba(Xb>>1,Fb)|0)+(Wb>>1))|0;cf[c[(c[a+12448>>2]|0)+(V<<2)>>2]&1023](c[w>>2]|0,Hb,Fb,16);break}else{Hb=a+12452|0;w=a+12208|0;y=(ba(tb>>2,Fb)|0)+(M>>2)|0;Xe[c[(c[Hb>>2]|0)+64+(Jb<<2)>>2]&4095](c[w>>2]|0,(c[Gb>>2]|0)+y|0,Fb);M=y+8|0;Xe[c[(c[Hb>>2]|0)+64+(Jb<<2)>>2]&4095]((c[w>>2]|0)+8|0,(c[Gb>>2]|0)+M|0,Fb);tb=Fb<<3;Xe[c[(c[Hb>>2]|0)+64+(Jb<<2)>>2]&4095]((c[w>>2]|0)+tb|0,(c[Gb>>2]|0)+(y+tb)|0,Fb);y=tb+8|0;Xe[c[(c[Hb>>2]|0)+64+(Jb<<2)>>2]&4095]((c[w>>2]|0)+y|0,(c[Gb>>2]|0)+(M+tb)|0,Fb);M=a+12456|0;Jb=a+12352+(g<<4)+32|0;Hb=(ba(Xb>>2,Fb)|0)+(Wb>>2)|0;Xe[c[(c[M>>2]|0)+64+(V<<2)>>2]&4095](c[w>>2]|0,(c[Jb>>2]|0)+Hb|0,Fb);Ib=Hb+8|0;Xe[c[(c[M>>2]|0)+64+(V<<2)>>2]&4095]((c[w>>2]|0)+8|0,(c[Jb>>2]|0)+Ib|0,Fb);Xe[c[(c[M>>2]|0)+64+(V<<2)>>2]&4095]((c[w>>2]|0)+tb|0,(c[Jb>>2]|0)+(Hb+tb)|0,Fb);Xe[c[(c[M>>2]|0)+64+(V<<2)>>2]&4095]((c[w>>2]|0)+y|0,(c[Jb>>2]|0)+(Ib+tb)|0,Fb);break}}}while(0);Tb=Pe[G&255](a,c[a+12208>>2]|0,c[vb>>2]|0,Fb,16)|0}}while(0);c[Ob>>2]=Mb;c[q+(F<<2)>>2]=Tb;F=c[b>>2]|0;q=(c[Ta>>2]|0)+1|0;Mb=(ba((d[z+((q<<E)-B)|0]|0)+(d[z+((F<<E)-A)|0]|0)|0,h)|0)+Tb|0;if((Mb|0)>=(Lb|0)){ub=Lb;i=m;return ub|0}c[b>>2]=F;c[Ta>>2]=q;ub=Mb;i=m;return ub|0}function Gmb(a,b,f,g,h,i,j,k,l){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0;m=c[a+12220>>2]|0;n=a+12264|0;o=c[n>>2]|0;p=a+12272|0;q=c[p>>2]|0;r=a+12268|0;s=c[r>>2]|0;t=a+12276|0;u=c[t>>2]|0;v=c[a+12464>>2]|0;w=c[a+12280>>2]|0;x=c[a+12284>>2]|0;y=c[a+12216>>2]|0;z=l&1;A=z+1|0;B=c[a+12224>>2]|0;C=c[a+12260>>2]&255;D=c[a+10468+(j<<2)>>2]|0;E=j+1|0;j=c[a+10468+(E<<2)>>2]|0;F=-C|0;G=(q|0)<(F|0)?F:q;H=(C|0)>(u|0)?u:C;if((G|0)>(H|0)){I=f;J=b+4|0}else{K=(o|0)<(F|0)?F:o;F=(C|0)>(s|0)?s:C;C=(K|0)>(F|0);L=(l&4|0)==0;M=a+12416|0;N=a+12420|0;O=a+12352+(h<<4)|0;P=a+12288+(g<<4)|0;Q=a;R=(l&2|0)==0;S=a+12208|0;T=a+12444|0;U=a+12352+(h<<4)+4|0;V=k>>1;W=a+12352+(h<<4)+8|0;X=a+12288+(g<<4)+4|0;Y=a+12288+(g<<4)+8|0;Z=b+4|0;_=a+13872|0;$=a+13874|0;aa=z<<1|1;ca=a+11740|0;da=z|4;ea=(z|0)==0;fa=a+12448|0;ga=a+12352+(h<<4)+32|0;ha=a+12452|0;ia=a+12456|0;ja=a+12160|0;ka=a+12164|0;la=a+12128|0;ma=a+12132|0;na=G;G=f;while(1){if(C){oa=G}else{f=(na<<11)+B|0;pa=na<<3;qa=na<<1&2;ra=na>>1;sa=na<<A;ta=v+(sa-x)|0;ua=(sa|0)==0;va=K;wa=G;while(1){xa=f+va|0;ya=va+pa&63;za=y+(ya<<2)|0;do{if((c[za>>2]|0)==(xa|0)){Aa=wa}else{Ba=c[M>>2]|0;do{if(L){Ca=c[N>>2]|0;Da=(c[O>>2]|0)+((ba(Ba,na)|0)+va)|0;Ea=Pe[D&255](Q,c[P>>2]|0,Da,Ba,k)|0;if(R){Fa=Ea;break}Da=va&1|qa;Ga=c[S>>2]|0;Ha=Ba<<4;Ia=Ga+Ha|0;Ja=(ba(Ca,ra)|0)+(va>>1)|0;cf[c[(c[T>>2]|0)+(E<<4)+(Da<<2)>>2]&1023](Ia,(c[U>>2]|0)+Ja|0,Ca,V);Ka=Ga+(Ha|8)|0;cf[c[(c[T>>2]|0)+(E<<4)+(Da<<2)>>2]&1023](Ka,(c[W>>2]|0)+Ja|0,Ca,V);Ja=(Pe[j&255](Q,Ia,c[X>>2]|0,Ca,V)|0)+Ea|0;Fa=Ja+(Pe[j&255](Q,Ka,c[Y>>2]|0,Ca,V)|0)|0}else{Ca=va<<A;if((c[n>>2]|0)>(va|0)){Fa=536870912;break}if((Ca|0)>(c[r>>2]<<A|0)){Fa=536870912;break}if((c[p>>2]|0)>(na|0)){Fa=536870912;break}if((sa|0)>(c[t>>2]<<A|0)){Fa=536870912;break}Ka=e[_>>1]|0;Ja=e[$>>1]|0;a:do{if((c[ca>>2]|0)==1){Ea=Ja-Ka|0;Ia=Ba<<3;if((Ca|0)==0){Da=0;while(1){Ha=c[a+12160+(Da<<3)>>2]|0;Ga=(c[a+12160+(Da<<3)+4>>2]|0)+sa|0;La=((ba(c[a+12128+(Da<<3)>>2]|0,Ea)|0)/(Ka|0)|0)+((Da&1)<<da)|0;Ma=c[a+12128+(Da<<3)+4>>2]|0;if(ua){Na=Da>>1;Oa=((ba(Ma,Ea)|0)/(Ka|0)|0)+(Na<<da)|0;Pa=Na}else{Oa=Ga-Ma|0;Pa=Da>>1}Ma=((Ga&aa)<<A)+(Ha&aa)|0;Na=((Oa&aa)<<A)+(La&aa)|0;Qa=(c[S>>2]|0)+((ba(Pa,Ia)|0)+(Da<<3&8))|0;if(ea){Ra=(c[O>>2]|0)+((ba(Ga>>1,Ba)|0)+(Ha>>1))|0;cf[c[(c[T>>2]|0)+16+(Ma<<2)>>2]&1023](Qa,Ra,Ba,8);Ra=(c[ga>>2]|0)+((ba(Oa>>1,Ba)|0)+(La>>1))|0;cf[c[(c[fa>>2]|0)+16+(Na<<2)>>2]&1023](Qa,Ra,Ba,8)}else{Ra=(c[O>>2]|0)+((ba(Ga>>2,Ba)|0)+(Ha>>2))|0;Xe[c[(c[ha>>2]|0)+64+(Ma<<2)>>2]&4095](Qa,Ra,Ba);Ra=(c[ga>>2]|0)+((ba(Oa>>2,Ba)|0)+(La>>2))|0;Xe[c[(c[ia>>2]|0)+64+(Na<<2)>>2]&4095](Qa,Ra,Ba)}Da=Da+1|0;if((Da|0)>=4){break a}}}if(ua){Da=0;do{Ra=(c[a+12160+(Da<<3)>>2]|0)+Ca|0;Qa=c[a+12160+(Da<<3)+4>>2]|0;Na=Ra-(c[a+12128+(Da<<3)>>2]|0)|0;La=Da>>1;Ma=((ba(c[a+12128+(Da<<3)+4>>2]|0,Ea)|0)/(Ka|0)|0)+(La<<da)|0;Ha=((Qa&aa)<<A)+(Ra&aa)|0;Ga=((Ma&aa)<<A)+(Na&aa)|0;Sa=(c[S>>2]|0)+((Da<<3&8)+(ba(La,Ia)|0))|0;if(ea){La=(c[O>>2]|0)+((ba(Qa>>1,Ba)|0)+(Ra>>1))|0;cf[c[(c[T>>2]|0)+16+(Ha<<2)>>2]&1023](Sa,La,Ba,8);La=(c[ga>>2]|0)+((ba(Ma>>1,Ba)|0)+(Na>>1))|0;cf[c[(c[fa>>2]|0)+16+(Ga<<2)>>2]&1023](Sa,La,Ba,8)}else{La=(c[O>>2]|0)+((ba(Qa>>2,Ba)|0)+(Ra>>2))|0;Xe[c[(c[ha>>2]|0)+64+(Ha<<2)>>2]&4095](Sa,La,Ba);La=(c[ga>>2]|0)+((ba(Ma>>2,Ba)|0)+(Na>>2))|0;Xe[c[(c[ia>>2]|0)+64+(Ga<<2)>>2]&4095](Sa,La,Ba)}Da=Da+1|0;}while((Da|0)<4)}else{Da=0;do{Ea=(c[a+12160+(Da<<3)>>2]|0)+Ca|0;La=(c[a+12160+(Da<<3)+4>>2]|0)+sa|0;Sa=Ea-(c[a+12128+(Da<<3)>>2]|0)|0;Ga=La-(c[a+12128+(Da<<3)+4>>2]|0)|0;Na=((La&aa)<<A)+(Ea&aa)|0;Ma=((Ga&aa)<<A)+(Sa&aa)|0;Ha=(c[S>>2]|0)+((Da<<3&8)+(ba(Da>>1,Ia)|0))|0;if(ea){Ra=(c[O>>2]|0)+((ba(La>>1,Ba)|0)+(Ea>>1))|0;cf[c[(c[T>>2]|0)+16+(Na<<2)>>2]&1023](Ha,Ra,Ba,8);Ra=(c[ga>>2]|0)+((ba(Ga>>1,Ba)|0)+(Sa>>1))|0;cf[c[(c[fa>>2]|0)+16+(Ma<<2)>>2]&1023](Ha,Ra,Ba,8)}else{Ra=(c[O>>2]|0)+((ba(La>>2,Ba)|0)+(Ea>>2))|0;Xe[c[(c[ha>>2]|0)+64+(Na<<2)>>2]&4095](Ha,Ra,Ba);Ra=(c[ga>>2]|0)+((ba(Ga>>2,Ba)|0)+(Sa>>2))|0;Xe[c[(c[ia>>2]|0)+64+(Ma<<2)>>2]&4095](Ha,Ra,Ba)}Da=Da+1|0;}while((Da|0)<4)}}else{Da=(c[ja>>2]|0)+Ca|0;Ia=(c[ka>>2]|0)+sa|0;Ra=c[la>>2]|0;if((Ca|0)==0){Ta=(ba(Ra,Ja-Ka|0)|0)/(Ka|0)|0}else{Ta=Da-Ra|0}Ra=c[ma>>2]|0;if(ua){Ua=(ba(Ra,Ja-Ka|0)|0)/(Ka|0)|0}else{Ua=Ia-Ra|0}Ra=((Ia&aa)<<A)+(Da&aa)|0;Ha=((Ua&aa)<<A)+(Ta&aa)|0;if(ea){Ma=(c[O>>2]|0)+((ba(Ia>>1,Ba)|0)+(Da>>1))|0;cf[c[(c[T>>2]|0)+(Ra<<2)>>2]&1023](c[S>>2]|0,Ma,Ba,16);Ma=(c[ga>>2]|0)+((ba(Ua>>1,Ba)|0)+(Ta>>1))|0;cf[c[(c[fa>>2]|0)+(Ha<<2)>>2]&1023](c[S>>2]|0,Ma,Ba,16);break}else{Ma=(ba(Ia>>2,Ba)|0)+(Da>>2)|0;Xe[c[(c[ha>>2]|0)+64+(Ra<<2)>>2]&4095](c[S>>2]|0,(c[O>>2]|0)+Ma|0,Ba);Da=Ma+8|0;Xe[c[(c[ha>>2]|0)+64+(Ra<<2)>>2]&4095]((c[S>>2]|0)+8|0,(c[O>>2]|0)+Da|0,Ba);Ia=Ba<<3;Xe[c[(c[ha>>2]|0)+64+(Ra<<2)>>2]&4095]((c[S>>2]|0)+Ia|0,(c[O>>2]|0)+(Ma+Ia)|0,Ba);Ma=Ia+8|0;Xe[c[(c[ha>>2]|0)+64+(Ra<<2)>>2]&4095]((c[S>>2]|0)+Ma|0,(c[O>>2]|0)+(Da+Ia)|0,Ba);Da=(ba(Ua>>2,Ba)|0)+(Ta>>2)|0;Xe[c[(c[ia>>2]|0)+64+(Ha<<2)>>2]&4095](c[S>>2]|0,(c[ga>>2]|0)+Da|0,Ba);Ra=Da+8|0;Xe[c[(c[ia>>2]|0)+64+(Ha<<2)>>2]&4095]((c[S>>2]|0)+8|0,(c[ga>>2]|0)+Ra|0,Ba);Xe[c[(c[ia>>2]|0)+64+(Ha<<2)>>2]&4095]((c[S>>2]|0)+Ia|0,(c[ga>>2]|0)+(Da+Ia)|0,Ba);Xe[c[(c[ia>>2]|0)+64+(Ha<<2)>>2]&4095]((c[S>>2]|0)+Ma|0,(c[ga>>2]|0)+(Ra+Ia)|0,Ba);break}}}while(0);Fa=Pe[D&255](Q,c[S>>2]|0,c[P>>2]|0,Ba,16)|0}}while(0);c[za>>2]=xa;c[m+(ya<<2)>>2]=Fa;Ba=(ba((d[ta]|0)+(d[v+((va<<A)-w)|0]|0)|0,i)|0)+Fa|0;if((Ba|0)>=(wa|0)){Aa=wa;break}c[b>>2]=va;c[Z>>2]=na;Aa=Ba}}while(0);ya=va+1|0;if((ya|0)>(F|0)){oa=Aa;break}else{va=ya;wa=Aa}}}wa=na+1|0;if((wa|0)>(H|0)){I=oa;J=Z;break}else{na=wa;G=oa}}}oa=c[b>>2]|0;G=c[J>>2]|0;na=(oa|0)>(s|0)?s:oa;Z=(o|0)>(na|0)?o:na;na=(G|0)>(u|0)?u:G;H=(q|0)>(na|0)?q:na;na=H<<11;Aa=Z+B|0;F=Aa+na|0;Fa=H<<3;P=Fa+Z&63;S=y+(P<<2)|0;do{if((c[S>>2]|0)==(F|0)){Va=I;Wa=I}else{do{if((l&4|0)==0){Q=c[a+12416>>2]|0;ga=c[a+12420>>2]|0;ia=a;Ta=(c[a+12352+(h<<4)>>2]|0)+((ba(Q,H)|0)+Z)|0;Ua=Pe[D&255](ia,c[a+12288+(g<<4)>>2]|0,Ta,Q,k)|0;if((l&2|0)==0){Xa=Ua;break}Ta=H<<1&2|Z&1;O=c[a+12208>>2]|0;ha=Q<<4;Q=O+ha|0;fa=a+12444|0;T=(ba(ga,H>>1)|0)+(Z>>1)|0;ea=k>>1;cf[c[(c[fa>>2]|0)+(E<<4)+(Ta<<2)>>2]&1023](Q,(c[a+12352+(h<<4)+4>>2]|0)+T|0,ga,ea);aa=O+(ha|8)|0;cf[c[(c[fa>>2]|0)+(E<<4)+(Ta<<2)>>2]&1023](aa,(c[a+12352+(h<<4)+8>>2]|0)+T|0,ga,ea);T=(Pe[j&255](ia,Q,c[a+12288+(g<<4)+4>>2]|0,ga,ea)|0)+Ua|0;Xa=T+(Pe[j&255](ia,aa,c[a+12288+(g<<4)+8>>2]|0,ga,ea)|0)|0}else{ea=c[a+12416>>2]|0;ga=Z<<A;aa=H<<A;ia=a+12352+(h<<4)|0;T=a+12288+(g<<4)|0;if((c[n>>2]|0)>(Z|0)){Xa=536870912;break}if((ga|0)>(c[r>>2]<<A|0)){Xa=536870912;break}if((c[p>>2]|0)>(H|0)){Xa=536870912;break}if((aa|0)>(c[t>>2]<<A|0)){Xa=536870912;break}Ua=e[a+13872>>1]|0;Q=e[a+13874>>1]|0;Ta=z<<1|1;b:do{if((c[a+11740>>2]|0)==1){fa=Q-Ua|0;ha=z|4;O=(aa|0)==0;ma=a+12208|0;la=ea<<3;ka=(z|0)==0;ja=a+12444|0;da=a+12448|0;Oa=a+12352+(h<<4)+32|0;Pa=a+12452|0;ca=a+12456|0;if((ga|0)==0){$=0;while(1){_=c[a+12160+($<<3)>>2]|0;V=(c[a+12160+($<<3)+4>>2]|0)+aa|0;Y=((ba(c[a+12128+($<<3)>>2]|0,fa)|0)/(Ua|0)|0)+(($&1)<<ha)|0;X=c[a+12128+($<<3)+4>>2]|0;if(O){W=$>>1;Ya=((ba(X,fa)|0)/(Ua|0)|0)+(W<<ha)|0;Za=W}else{Ya=V-X|0;Za=$>>1}X=((V&Ta)<<A)+(_&Ta)|0;W=((Ya&Ta)<<A)+(Y&Ta)|0;U=(c[ma>>2]|0)+((ba(Za,la)|0)+($<<3&8))|0;if(ka){R=(c[ia>>2]|0)+((ba(V>>1,ea)|0)+(_>>1))|0;cf[c[(c[ja>>2]|0)+16+(X<<2)>>2]&1023](U,R,ea,8);R=(c[Oa>>2]|0)+((ba(Ya>>1,ea)|0)+(Y>>1))|0;cf[c[(c[da>>2]|0)+16+(W<<2)>>2]&1023](U,R,ea,8)}else{R=(c[ia>>2]|0)+((ba(V>>2,ea)|0)+(_>>2))|0;Xe[c[(c[Pa>>2]|0)+64+(X<<2)>>2]&4095](U,R,ea);R=(c[Oa>>2]|0)+((ba(Ya>>2,ea)|0)+(Y>>2))|0;Xe[c[(c[ca>>2]|0)+64+(W<<2)>>2]&4095](U,R,ea)}$=$+1|0;if(($|0)>=4){break b}}}if(O){$=0;do{R=(c[a+12160+($<<3)>>2]|0)+ga|0;U=c[a+12160+($<<3)+4>>2]|0;W=R-(c[a+12128+($<<3)>>2]|0)|0;Y=$>>1;X=((ba(c[a+12128+($<<3)+4>>2]|0,fa)|0)/(Ua|0)|0)+(Y<<ha)|0;_=((U&Ta)<<A)+(R&Ta)|0;V=((X&Ta)<<A)+(W&Ta)|0;N=(c[ma>>2]|0)+(($<<3&8)+(ba(Y,la)|0))|0;if(ka){Y=(c[ia>>2]|0)+((ba(U>>1,ea)|0)+(R>>1))|0;cf[c[(c[ja>>2]|0)+16+(_<<2)>>2]&1023](N,Y,ea,8);Y=(c[Oa>>2]|0)+((ba(X>>1,ea)|0)+(W>>1))|0;cf[c[(c[da>>2]|0)+16+(V<<2)>>2]&1023](N,Y,ea,8)}else{Y=(c[ia>>2]|0)+((ba(U>>2,ea)|0)+(R>>2))|0;Xe[c[(c[Pa>>2]|0)+64+(_<<2)>>2]&4095](N,Y,ea);Y=(c[Oa>>2]|0)+((ba(X>>2,ea)|0)+(W>>2))|0;Xe[c[(c[ca>>2]|0)+64+(V<<2)>>2]&4095](N,Y,ea)}$=$+1|0;}while(($|0)<4)}else{$=0;do{ha=(c[a+12160+($<<3)>>2]|0)+ga|0;fa=(c[a+12160+($<<3)+4>>2]|0)+aa|0;O=ha-(c[a+12128+($<<3)>>2]|0)|0;Y=fa-(c[a+12128+($<<3)+4>>2]|0)|0;N=((fa&Ta)<<A)+(ha&Ta)|0;V=((Y&Ta)<<A)+(O&Ta)|0;W=(c[ma>>2]|0)+(($<<3&8)+(ba($>>1,la)|0))|0;if(ka){X=(c[ia>>2]|0)+((ba(fa>>1,ea)|0)+(ha>>1))|0;cf[c[(c[ja>>2]|0)+16+(N<<2)>>2]&1023](W,X,ea,8);X=(c[Oa>>2]|0)+((ba(Y>>1,ea)|0)+(O>>1))|0;cf[c[(c[da>>2]|0)+16+(V<<2)>>2]&1023](W,X,ea,8)}else{X=(c[ia>>2]|0)+((ba(fa>>2,ea)|0)+(ha>>2))|0;Xe[c[(c[Pa>>2]|0)+64+(N<<2)>>2]&4095](W,X,ea);X=(c[Oa>>2]|0)+((ba(Y>>2,ea)|0)+(O>>2))|0;Xe[c[(c[ca>>2]|0)+64+(V<<2)>>2]&4095](W,X,ea)}$=$+1|0;}while(($|0)<4)}}else{$=(c[a+12160>>2]|0)+ga|0;ca=(c[a+12164>>2]|0)+aa|0;Oa=c[a+12128>>2]|0;if((ga|0)==0){_a=(ba(Oa,Q-Ua|0)|0)/(Ua|0)|0}else{_a=$-Oa|0}Oa=c[a+12132>>2]|0;if((aa|0)==0){$a=(ba(Oa,Q-Ua|0)|0)/(Ua|0)|0}else{$a=ca-Oa|0}Oa=((ca&Ta)<<A)+($&Ta)|0;Pa=(($a&Ta)<<A)+(_a&Ta)|0;if((z|0)==0){da=a+12208|0;ja=(c[ia>>2]|0)+((ba(ca>>1,ea)|0)+($>>1))|0;cf[c[(c[a+12444>>2]|0)+(Oa<<2)>>2]&1023](c[da>>2]|0,ja,ea,16);ja=(c[a+12352+(h<<4)+32>>2]|0)+((ba($a>>1,ea)|0)+(_a>>1))|0;cf[c[(c[a+12448>>2]|0)+(Pa<<2)>>2]&1023](c[da>>2]|0,ja,ea,16);break}else{ja=a+12452|0;da=a+12208|0;ka=(ba(ca>>2,ea)|0)+($>>2)|0;Xe[c[(c[ja>>2]|0)+64+(Oa<<2)>>2]&4095](c[da>>2]|0,(c[ia>>2]|0)+ka|0,ea);$=ka+8|0;Xe[c[(c[ja>>2]|0)+64+(Oa<<2)>>2]&4095]((c[da>>2]|0)+8|0,(c[ia>>2]|0)+$|0,ea);ca=ea<<3;Xe[c[(c[ja>>2]|0)+64+(Oa<<2)>>2]&4095]((c[da>>2]|0)+ca|0,(c[ia>>2]|0)+(ka+ca)|0,ea);ka=ca+8|0;Xe[c[(c[ja>>2]|0)+64+(Oa<<2)>>2]&4095]((c[da>>2]|0)+ka|0,(c[ia>>2]|0)+($+ca)|0,ea);$=a+12456|0;Oa=a+12352+(h<<4)+32|0;ja=(ba($a>>2,ea)|0)+(_a>>2)|0;Xe[c[(c[$>>2]|0)+64+(Pa<<2)>>2]&4095](c[da>>2]|0,(c[Oa>>2]|0)+ja|0,ea);la=ja+8|0;Xe[c[(c[$>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+8|0,(c[Oa>>2]|0)+la|0,ea);Xe[c[(c[$>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+ca|0,(c[Oa>>2]|0)+(ja+ca)|0,ea);Xe[c[(c[$>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+ka|0,(c[Oa>>2]|0)+(la+ca)|0,ea);break}}}while(0);Xa=Pe[D&255](a,c[a+12208>>2]|0,c[T>>2]|0,ea,16)|0}}while(0);c[S>>2]=F;c[m+(P<<2)>>2]=Xa;ia=(ba((d[v+((H<<A)-x)|0]|0)+(d[v+((Z<<A)-w)|0]|0)|0,i)|0)+Xa|0;if((ia|0)>=(I|0)){Va=I;Wa=ia;break}c[b>>2]=Z;c[J>>2]=H;Va=ia;Wa=ia}}while(0);I=oa+1|0;Xa=(I|0)>(s|0)?s:I;I=(o|0)>(Xa|0)?o:Xa;Xa=I+B+na|0;P=Fa+I&63;F=y+(P<<2)|0;do{if((c[F>>2]|0)==(Xa|0)){ab=Va;bb=Wa}else{do{if((l&4|0)==0){S=c[a+12416>>2]|0;_a=c[a+12420>>2]|0;$a=a;Ya=(c[a+12352+(h<<4)>>2]|0)+((ba(S,H)|0)+I)|0;Za=Pe[D&255]($a,c[a+12288+(g<<4)>>2]|0,Ya,S,k)|0;if((l&2|0)==0){cb=Za;break}Ya=H<<1&2|I&1;ia=c[a+12208>>2]|0;Ta=S<<4;S=ia+Ta|0;Ua=a+12444|0;Q=(ba(_a,H>>1)|0)+(I>>1)|0;aa=k>>1;cf[c[(c[Ua>>2]|0)+(E<<4)+(Ya<<2)>>2]&1023](S,(c[a+12352+(h<<4)+4>>2]|0)+Q|0,_a,aa);ga=ia+(Ta|8)|0;cf[c[(c[Ua>>2]|0)+(E<<4)+(Ya<<2)>>2]&1023](ga,(c[a+12352+(h<<4)+8>>2]|0)+Q|0,_a,aa);Q=(Pe[j&255]($a,S,c[a+12288+(g<<4)+4>>2]|0,_a,aa)|0)+Za|0;cb=Q+(Pe[j&255]($a,ga,c[a+12288+(g<<4)+8>>2]|0,_a,aa)|0)|0}else{aa=c[a+12416>>2]|0;_a=I<<A;ga=H<<A;$a=a+12352+(h<<4)|0;Q=a+12288+(g<<4)|0;if((c[n>>2]|0)>(I|0)){cb=536870912;break}if((_a|0)>(c[r>>2]<<A|0)){cb=536870912;break}if((c[p>>2]|0)>(H|0)){cb=536870912;break}if((ga|0)>(c[t>>2]<<A|0)){cb=536870912;break}Za=e[a+13872>>1]|0;S=e[a+13874>>1]|0;Ya=z<<1|1;c:do{if((c[a+11740>>2]|0)==1){Ua=S-Za|0;Ta=z|4;ia=(ga|0)==0;ca=a+12208|0;la=aa<<3;Oa=(z|0)==0;ka=a+12444|0;da=a+12448|0;Pa=a+12352+(h<<4)+32|0;$=a+12452|0;ja=a+12456|0;if((_a|0)==0){ma=0;while(1){X=c[a+12160+(ma<<3)>>2]|0;W=(c[a+12160+(ma<<3)+4>>2]|0)+ga|0;V=((ba(c[a+12128+(ma<<3)>>2]|0,Ua)|0)/(Za|0)|0)+((ma&1)<<Ta)|0;O=c[a+12128+(ma<<3)+4>>2]|0;if(ia){Y=ma>>1;db=((ba(O,Ua)|0)/(Za|0)|0)+(Y<<Ta)|0;eb=Y}else{db=W-O|0;eb=ma>>1}O=((W&Ya)<<A)+(X&Ya)|0;Y=((db&Ya)<<A)+(V&Ya)|0;N=(c[ca>>2]|0)+((ba(eb,la)|0)+(ma<<3&8))|0;if(Oa){ha=(c[$a>>2]|0)+((ba(W>>1,aa)|0)+(X>>1))|0;cf[c[(c[ka>>2]|0)+16+(O<<2)>>2]&1023](N,ha,aa,8);ha=(c[Pa>>2]|0)+((ba(db>>1,aa)|0)+(V>>1))|0;cf[c[(c[da>>2]|0)+16+(Y<<2)>>2]&1023](N,ha,aa,8)}else{ha=(c[$a>>2]|0)+((ba(W>>2,aa)|0)+(X>>2))|0;Xe[c[(c[$>>2]|0)+64+(O<<2)>>2]&4095](N,ha,aa);ha=(c[Pa>>2]|0)+((ba(db>>2,aa)|0)+(V>>2))|0;Xe[c[(c[ja>>2]|0)+64+(Y<<2)>>2]&4095](N,ha,aa)}ma=ma+1|0;if((ma|0)>=4){break c}}}if(ia){ma=0;do{ha=(c[a+12160+(ma<<3)>>2]|0)+_a|0;N=c[a+12160+(ma<<3)+4>>2]|0;Y=ha-(c[a+12128+(ma<<3)>>2]|0)|0;V=ma>>1;O=((ba(c[a+12128+(ma<<3)+4>>2]|0,Ua)|0)/(Za|0)|0)+(V<<Ta)|0;X=((N&Ya)<<A)+(ha&Ya)|0;W=((O&Ya)<<A)+(Y&Ya)|0;fa=(c[ca>>2]|0)+((ma<<3&8)+(ba(V,la)|0))|0;if(Oa){V=(c[$a>>2]|0)+((ba(N>>1,aa)|0)+(ha>>1))|0;cf[c[(c[ka>>2]|0)+16+(X<<2)>>2]&1023](fa,V,aa,8);V=(c[Pa>>2]|0)+((ba(O>>1,aa)|0)+(Y>>1))|0;cf[c[(c[da>>2]|0)+16+(W<<2)>>2]&1023](fa,V,aa,8)}else{V=(c[$a>>2]|0)+((ba(N>>2,aa)|0)+(ha>>2))|0;Xe[c[(c[$>>2]|0)+64+(X<<2)>>2]&4095](fa,V,aa);V=(c[Pa>>2]|0)+((ba(O>>2,aa)|0)+(Y>>2))|0;Xe[c[(c[ja>>2]|0)+64+(W<<2)>>2]&4095](fa,V,aa)}ma=ma+1|0;}while((ma|0)<4)}else{ma=0;do{Ta=(c[a+12160+(ma<<3)>>2]|0)+_a|0;Ua=(c[a+12160+(ma<<3)+4>>2]|0)+ga|0;ia=Ta-(c[a+12128+(ma<<3)>>2]|0)|0;V=Ua-(c[a+12128+(ma<<3)+4>>2]|0)|0;fa=((Ua&Ya)<<A)+(Ta&Ya)|0;W=((V&Ya)<<A)+(ia&Ya)|0;Y=(c[ca>>2]|0)+((ma<<3&8)+(ba(ma>>1,la)|0))|0;if(Oa){O=(c[$a>>2]|0)+((ba(Ua>>1,aa)|0)+(Ta>>1))|0;cf[c[(c[ka>>2]|0)+16+(fa<<2)>>2]&1023](Y,O,aa,8);O=(c[Pa>>2]|0)+((ba(V>>1,aa)|0)+(ia>>1))|0;cf[c[(c[da>>2]|0)+16+(W<<2)>>2]&1023](Y,O,aa,8)}else{O=(c[$a>>2]|0)+((ba(Ua>>2,aa)|0)+(Ta>>2))|0;Xe[c[(c[$>>2]|0)+64+(fa<<2)>>2]&4095](Y,O,aa);O=(c[Pa>>2]|0)+((ba(V>>2,aa)|0)+(ia>>2))|0;Xe[c[(c[ja>>2]|0)+64+(W<<2)>>2]&4095](Y,O,aa)}ma=ma+1|0;}while((ma|0)<4)}}else{ma=(c[a+12160>>2]|0)+_a|0;ja=(c[a+12164>>2]|0)+ga|0;Pa=c[a+12128>>2]|0;if((_a|0)==0){fb=(ba(Pa,S-Za|0)|0)/(Za|0)|0}else{fb=ma-Pa|0}Pa=c[a+12132>>2]|0;if((ga|0)==0){gb=(ba(Pa,S-Za|0)|0)/(Za|0)|0}else{gb=ja-Pa|0}Pa=((ja&Ya)<<A)+(ma&Ya)|0;$=((gb&Ya)<<A)+(fb&Ya)|0;if((z|0)==0){da=a+12208|0;ka=(c[$a>>2]|0)+((ba(ja>>1,aa)|0)+(ma>>1))|0;cf[c[(c[a+12444>>2]|0)+(Pa<<2)>>2]&1023](c[da>>2]|0,ka,aa,16);ka=(c[a+12352+(h<<4)+32>>2]|0)+((ba(gb>>1,aa)|0)+(fb>>1))|0;cf[c[(c[a+12448>>2]|0)+($<<2)>>2]&1023](c[da>>2]|0,ka,aa,16);break}else{ka=a+12452|0;da=a+12208|0;Oa=(ba(ja>>2,aa)|0)+(ma>>2)|0;Xe[c[(c[ka>>2]|0)+64+(Pa<<2)>>2]&4095](c[da>>2]|0,(c[$a>>2]|0)+Oa|0,aa);ma=Oa+8|0;Xe[c[(c[ka>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+8|0,(c[$a>>2]|0)+ma|0,aa);ja=aa<<3;Xe[c[(c[ka>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+ja|0,(c[$a>>2]|0)+(Oa+ja)|0,aa);Oa=ja+8|0;Xe[c[(c[ka>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+Oa|0,(c[$a>>2]|0)+(ma+ja)|0,aa);ma=a+12456|0;Pa=a+12352+(h<<4)+32|0;ka=(ba(gb>>2,aa)|0)+(fb>>2)|0;Xe[c[(c[ma>>2]|0)+64+($<<2)>>2]&4095](c[da>>2]|0,(c[Pa>>2]|0)+ka|0,aa);la=ka+8|0;Xe[c[(c[ma>>2]|0)+64+($<<2)>>2]&4095]((c[da>>2]|0)+8|0,(c[Pa>>2]|0)+la|0,aa);Xe[c[(c[ma>>2]|0)+64+($<<2)>>2]&4095]((c[da>>2]|0)+ja|0,(c[Pa>>2]|0)+(ka+ja)|0,aa);Xe[c[(c[ma>>2]|0)+64+($<<2)>>2]&4095]((c[da>>2]|0)+Oa|0,(c[Pa>>2]|0)+(la+ja)|0,aa);break}}}while(0);cb=Pe[D&255](a,c[a+12208>>2]|0,c[Q>>2]|0,aa,16)|0}}while(0);c[F>>2]=Xa;c[m+(P<<2)>>2]=cb;$a=(ba((d[v+((H<<A)-x)|0]|0)+(d[v+((I<<A)-w)|0]|0)|0,i)|0)+cb|0;if(($a|0)>=(Va|0)){ab=Va;bb=$a;break}c[b>>2]=I;c[J>>2]=H;ab=$a;bb=$a}}while(0);I=G+1|0;Va=(I|0)>(u|0)?u:I;I=(q|0)>(Va|0)?q:Va;Va=Aa+(I<<11)|0;cb=(I<<3)+Z&63;P=y+(cb<<2)|0;do{if((c[P>>2]|0)==(Va|0)){hb=ab;ib=bb}else{do{if((l&4|0)==0){Xa=c[a+12416>>2]|0;F=c[a+12420>>2]|0;fb=a;gb=(c[a+12352+(h<<4)>>2]|0)+((ba(Xa,I)|0)+Z)|0;db=Pe[D&255](fb,c[a+12288+(g<<4)>>2]|0,gb,Xa,k)|0;if((l&2|0)==0){jb=db;break}gb=I<<1&2|Z&1;eb=c[a+12208>>2]|0;Wa=Xa<<4;Xa=eb+Wa|0;$a=a+12444|0;Ya=(ba(F,I>>1)|0)+(Z>>1)|0;Za=k>>1;cf[c[(c[$a>>2]|0)+(E<<4)+(gb<<2)>>2]&1023](Xa,(c[a+12352+(h<<4)+4>>2]|0)+Ya|0,F,Za);S=eb+(Wa|8)|0;cf[c[(c[$a>>2]|0)+(E<<4)+(gb<<2)>>2]&1023](S,(c[a+12352+(h<<4)+8>>2]|0)+Ya|0,F,Za);Ya=(Pe[j&255](fb,Xa,c[a+12288+(g<<4)+4>>2]|0,F,Za)|0)+db|0;jb=Ya+(Pe[j&255](fb,S,c[a+12288+(g<<4)+8>>2]|0,F,Za)|0)|0}else{Za=c[a+12416>>2]|0;F=Z<<A;S=I<<A;fb=a+12352+(h<<4)|0;Ya=a+12288+(g<<4)|0;if((c[n>>2]|0)>(Z|0)){jb=536870912;break}if((F|0)>(c[r>>2]<<A|0)){jb=536870912;break}if((c[p>>2]|0)>(I|0)){jb=536870912;break}if((S|0)>(c[t>>2]<<A|0)){jb=536870912;break}db=e[a+13872>>1]|0;Xa=e[a+13874>>1]|0;gb=z<<1|1;d:do{if((c[a+11740>>2]|0)==1){$a=Xa-db|0;Wa=z|4;eb=(S|0)==0;ga=a+12208|0;_a=Za<<3;ea=(z|0)==0;T=a+12444|0;ja=a+12448|0;la=a+12352+(h<<4)+32|0;Pa=a+12452|0;Oa=a+12456|0;if((F|0)==0){da=0;while(1){$=c[a+12160+(da<<3)>>2]|0;ma=(c[a+12160+(da<<3)+4>>2]|0)+S|0;ka=((ba(c[a+12128+(da<<3)>>2]|0,$a)|0)/(db|0)|0)+((da&1)<<Wa)|0;ca=c[a+12128+(da<<3)+4>>2]|0;if(eb){O=da>>1;kb=((ba(ca,$a)|0)/(db|0)|0)+(O<<Wa)|0;lb=O}else{kb=ma-ca|0;lb=da>>1}ca=((ma&gb)<<A)+($&gb)|0;O=((kb&gb)<<A)+(ka&gb)|0;Y=(c[ga>>2]|0)+((ba(lb,_a)|0)+(da<<3&8))|0;if(ea){W=(c[fb>>2]|0)+((ba(ma>>1,Za)|0)+($>>1))|0;cf[c[(c[T>>2]|0)+16+(ca<<2)>>2]&1023](Y,W,Za,8);W=(c[la>>2]|0)+((ba(kb>>1,Za)|0)+(ka>>1))|0;cf[c[(c[ja>>2]|0)+16+(O<<2)>>2]&1023](Y,W,Za,8)}else{W=(c[fb>>2]|0)+((ba(ma>>2,Za)|0)+($>>2))|0;Xe[c[(c[Pa>>2]|0)+64+(ca<<2)>>2]&4095](Y,W,Za);W=(c[la>>2]|0)+((ba(kb>>2,Za)|0)+(ka>>2))|0;Xe[c[(c[Oa>>2]|0)+64+(O<<2)>>2]&4095](Y,W,Za)}da=da+1|0;if((da|0)>=4){break d}}}if(eb){da=0;do{W=(c[a+12160+(da<<3)>>2]|0)+F|0;Y=c[a+12160+(da<<3)+4>>2]|0;O=W-(c[a+12128+(da<<3)>>2]|0)|0;ka=da>>1;ca=((ba(c[a+12128+(da<<3)+4>>2]|0,$a)|0)/(db|0)|0)+(ka<<Wa)|0;$=((Y&gb)<<A)+(W&gb)|0;ma=((ca&gb)<<A)+(O&gb)|0;ia=(c[ga>>2]|0)+((da<<3&8)+(ba(ka,_a)|0))|0;if(ea){ka=(c[fb>>2]|0)+((ba(Y>>1,Za)|0)+(W>>1))|0;cf[c[(c[T>>2]|0)+16+($<<2)>>2]&1023](ia,ka,Za,8);ka=(c[la>>2]|0)+((ba(ca>>1,Za)|0)+(O>>1))|0;cf[c[(c[ja>>2]|0)+16+(ma<<2)>>2]&1023](ia,ka,Za,8)}else{ka=(c[fb>>2]|0)+((ba(Y>>2,Za)|0)+(W>>2))|0;Xe[c[(c[Pa>>2]|0)+64+($<<2)>>2]&4095](ia,ka,Za);ka=(c[la>>2]|0)+((ba(ca>>2,Za)|0)+(O>>2))|0;Xe[c[(c[Oa>>2]|0)+64+(ma<<2)>>2]&4095](ia,ka,Za)}da=da+1|0;}while((da|0)<4)}else{da=0;do{Wa=(c[a+12160+(da<<3)>>2]|0)+F|0;$a=(c[a+12160+(da<<3)+4>>2]|0)+S|0;eb=Wa-(c[a+12128+(da<<3)>>2]|0)|0;ka=$a-(c[a+12128+(da<<3)+4>>2]|0)|0;ia=(($a&gb)<<A)+(Wa&gb)|0;ma=((ka&gb)<<A)+(eb&gb)|0;O=(c[ga>>2]|0)+((da<<3&8)+(ba(da>>1,_a)|0))|0;if(ea){ca=(c[fb>>2]|0)+((ba($a>>1,Za)|0)+(Wa>>1))|0;cf[c[(c[T>>2]|0)+16+(ia<<2)>>2]&1023](O,ca,Za,8);ca=(c[la>>2]|0)+((ba(ka>>1,Za)|0)+(eb>>1))|0;cf[c[(c[ja>>2]|0)+16+(ma<<2)>>2]&1023](O,ca,Za,8)}else{ca=(c[fb>>2]|0)+((ba($a>>2,Za)|0)+(Wa>>2))|0;Xe[c[(c[Pa>>2]|0)+64+(ia<<2)>>2]&4095](O,ca,Za);ca=(c[la>>2]|0)+((ba(ka>>2,Za)|0)+(eb>>2))|0;Xe[c[(c[Oa>>2]|0)+64+(ma<<2)>>2]&4095](O,ca,Za)}da=da+1|0;}while((da|0)<4)}}else{da=(c[a+12160>>2]|0)+F|0;Oa=(c[a+12164>>2]|0)+S|0;la=c[a+12128>>2]|0;if((F|0)==0){mb=(ba(la,Xa-db|0)|0)/(db|0)|0}else{mb=da-la|0}la=c[a+12132>>2]|0;if((S|0)==0){nb=(ba(la,Xa-db|0)|0)/(db|0)|0}else{nb=Oa-la|0}la=((Oa&gb)<<A)+(da&gb)|0;Pa=((nb&gb)<<A)+(mb&gb)|0;if((z|0)==0){ja=a+12208|0;T=(c[fb>>2]|0)+((ba(Oa>>1,Za)|0)+(da>>1))|0;cf[c[(c[a+12444>>2]|0)+(la<<2)>>2]&1023](c[ja>>2]|0,T,Za,16);T=(c[a+12352+(h<<4)+32>>2]|0)+((ba(nb>>1,Za)|0)+(mb>>1))|0;cf[c[(c[a+12448>>2]|0)+(Pa<<2)>>2]&1023](c[ja>>2]|0,T,Za,16);break}else{T=a+12452|0;ja=a+12208|0;ea=(ba(Oa>>2,Za)|0)+(da>>2)|0;Xe[c[(c[T>>2]|0)+64+(la<<2)>>2]&4095](c[ja>>2]|0,(c[fb>>2]|0)+ea|0,Za);da=ea+8|0;Xe[c[(c[T>>2]|0)+64+(la<<2)>>2]&4095]((c[ja>>2]|0)+8|0,(c[fb>>2]|0)+da|0,Za);Oa=Za<<3;Xe[c[(c[T>>2]|0)+64+(la<<2)>>2]&4095]((c[ja>>2]|0)+Oa|0,(c[fb>>2]|0)+(ea+Oa)|0,Za);ea=Oa+8|0;Xe[c[(c[T>>2]|0)+64+(la<<2)>>2]&4095]((c[ja>>2]|0)+ea|0,(c[fb>>2]|0)+(da+Oa)|0,Za);da=a+12456|0;la=a+12352+(h<<4)+32|0;T=(ba(nb>>2,Za)|0)+(mb>>2)|0;Xe[c[(c[da>>2]|0)+64+(Pa<<2)>>2]&4095](c[ja>>2]|0,(c[la>>2]|0)+T|0,Za);_a=T+8|0;Xe[c[(c[da>>2]|0)+64+(Pa<<2)>>2]&4095]((c[ja>>2]|0)+8|0,(c[la>>2]|0)+_a|0,Za);Xe[c[(c[da>>2]|0)+64+(Pa<<2)>>2]&4095]((c[ja>>2]|0)+Oa|0,(c[la>>2]|0)+(T+Oa)|0,Za);Xe[c[(c[da>>2]|0)+64+(Pa<<2)>>2]&4095]((c[ja>>2]|0)+ea|0,(c[la>>2]|0)+(_a+Oa)|0,Za);break}}}while(0);jb=Pe[D&255](a,c[a+12208>>2]|0,c[Ya>>2]|0,Za,16)|0}}while(0);c[P>>2]=Va;c[m+(cb<<2)>>2]=jb;fb=(ba((d[v+((I<<A)-x)|0]|0)+(d[v+((Z<<A)-w)|0]|0)|0,i)|0)+jb|0;if((fb|0)>=(ab|0)){hb=ab;ib=fb;break}c[b>>2]=Z;c[J>>2]=I;hb=fb;ib=fb}}while(0);I=oa-1|0;ab=(I|0)>(s|0)?s:I;I=(o|0)>(ab|0)?o:ab;ab=I+B+na|0;na=Fa+I&63;Fa=y+(na<<2)|0;do{if((c[Fa>>2]|0)==(ab|0)){ob=hb;pb=ib}else{do{if((l&4|0)==0){B=c[a+12416>>2]|0;o=c[a+12420>>2]|0;s=a;jb=(c[a+12352+(h<<4)>>2]|0)+((ba(B,H)|0)+I)|0;cb=Pe[D&255](s,c[a+12288+(g<<4)>>2]|0,jb,B,k)|0;if((l&2|0)==0){qb=cb;break}jb=H<<1&2|I&1;Va=c[a+12208>>2]|0;P=B<<4;B=Va+P|0;mb=a+12444|0;nb=(ba(o,H>>1)|0)+(I>>1)|0;kb=k>>1;cf[c[(c[mb>>2]|0)+(E<<4)+(jb<<2)>>2]&1023](B,(c[a+12352+(h<<4)+4>>2]|0)+nb|0,o,kb);lb=Va+(P|8)|0;cf[c[(c[mb>>2]|0)+(E<<4)+(jb<<2)>>2]&1023](lb,(c[a+12352+(h<<4)+8>>2]|0)+nb|0,o,kb);nb=(Pe[j&255](s,B,c[a+12288+(g<<4)+4>>2]|0,o,kb)|0)+cb|0;qb=nb+(Pe[j&255](s,lb,c[a+12288+(g<<4)+8>>2]|0,o,kb)|0)|0}else{kb=c[a+12416>>2]|0;o=I<<A;lb=H<<A;s=a+12352+(h<<4)|0;nb=a+12288+(g<<4)|0;if((c[n>>2]|0)>(I|0)){qb=536870912;break}if((o|0)>(c[r>>2]<<A|0)){qb=536870912;break}if((c[p>>2]|0)>(H|0)){qb=536870912;break}if((lb|0)>(c[t>>2]<<A|0)){qb=536870912;break}cb=e[a+13872>>1]|0;B=e[a+13874>>1]|0;jb=z<<1|1;e:do{if((c[a+11740>>2]|0)==1){mb=B-cb|0;P=z|4;Va=(lb|0)==0;bb=a+12208|0;fb=kb<<3;gb=(z|0)==0;db=a+12444|0;Xa=a+12448|0;S=a+12352+(h<<4)+32|0;F=a+12452|0;aa=a+12456|0;if((o|0)==0){Q=0;while(1){Oa=c[a+12160+(Q<<3)>>2]|0;_a=(c[a+12160+(Q<<3)+4>>2]|0)+lb|0;la=((ba(c[a+12128+(Q<<3)>>2]|0,mb)|0)/(cb|0)|0)+((Q&1)<<P)|0;ea=c[a+12128+(Q<<3)+4>>2]|0;if(Va){ja=Q>>1;rb=((ba(ea,mb)|0)/(cb|0)|0)+(ja<<P)|0;sb=ja}else{rb=_a-ea|0;sb=Q>>1}ea=((_a&jb)<<A)+(Oa&jb)|0;ja=((rb&jb)<<A)+(la&jb)|0;Pa=(c[bb>>2]|0)+((ba(sb,fb)|0)+(Q<<3&8))|0;if(gb){da=(c[s>>2]|0)+((ba(_a>>1,kb)|0)+(Oa>>1))|0;cf[c[(c[db>>2]|0)+16+(ea<<2)>>2]&1023](Pa,da,kb,8);da=(c[S>>2]|0)+((ba(rb>>1,kb)|0)+(la>>1))|0;cf[c[(c[Xa>>2]|0)+16+(ja<<2)>>2]&1023](Pa,da,kb,8)}else{da=(c[s>>2]|0)+((ba(_a>>2,kb)|0)+(Oa>>2))|0;Xe[c[(c[F>>2]|0)+64+(ea<<2)>>2]&4095](Pa,da,kb);da=(c[S>>2]|0)+((ba(rb>>2,kb)|0)+(la>>2))|0;Xe[c[(c[aa>>2]|0)+64+(ja<<2)>>2]&4095](Pa,da,kb)}Q=Q+1|0;if((Q|0)>=4){break e}}}if(Va){Q=0;do{da=(c[a+12160+(Q<<3)>>2]|0)+o|0;Pa=c[a+12160+(Q<<3)+4>>2]|0;ja=da-(c[a+12128+(Q<<3)>>2]|0)|0;la=Q>>1;ea=((ba(c[a+12128+(Q<<3)+4>>2]|0,mb)|0)/(cb|0)|0)+(la<<P)|0;Oa=((Pa&jb)<<A)+(da&jb)|0;_a=((ea&jb)<<A)+(ja&jb)|0;T=(c[bb>>2]|0)+((Q<<3&8)+(ba(la,fb)|0))|0;if(gb){la=(c[s>>2]|0)+((ba(Pa>>1,kb)|0)+(da>>1))|0;cf[c[(c[db>>2]|0)+16+(Oa<<2)>>2]&1023](T,la,kb,8);la=(c[S>>2]|0)+((ba(ea>>1,kb)|0)+(ja>>1))|0;cf[c[(c[Xa>>2]|0)+16+(_a<<2)>>2]&1023](T,la,kb,8)}else{la=(c[s>>2]|0)+((ba(Pa>>2,kb)|0)+(da>>2))|0;Xe[c[(c[F>>2]|0)+64+(Oa<<2)>>2]&4095](T,la,kb);la=(c[S>>2]|0)+((ba(ea>>2,kb)|0)+(ja>>2))|0;Xe[c[(c[aa>>2]|0)+64+(_a<<2)>>2]&4095](T,la,kb)}Q=Q+1|0;}while((Q|0)<4)}else{Q=0;do{P=(c[a+12160+(Q<<3)>>2]|0)+o|0;mb=(c[a+12160+(Q<<3)+4>>2]|0)+lb|0;Va=P-(c[a+12128+(Q<<3)>>2]|0)|0;la=mb-(c[a+12128+(Q<<3)+4>>2]|0)|0;T=((mb&jb)<<A)+(P&jb)|0;_a=((la&jb)<<A)+(Va&jb)|0;ja=(c[bb>>2]|0)+((Q<<3&8)+(ba(Q>>1,fb)|0))|0;if(gb){ea=(c[s>>2]|0)+((ba(mb>>1,kb)|0)+(P>>1))|0;cf[c[(c[db>>2]|0)+16+(T<<2)>>2]&1023](ja,ea,kb,8);ea=(c[S>>2]|0)+((ba(la>>1,kb)|0)+(Va>>1))|0;cf[c[(c[Xa>>2]|0)+16+(_a<<2)>>2]&1023](ja,ea,kb,8)}else{ea=(c[s>>2]|0)+((ba(mb>>2,kb)|0)+(P>>2))|0;Xe[c[(c[F>>2]|0)+64+(T<<2)>>2]&4095](ja,ea,kb);ea=(c[S>>2]|0)+((ba(la>>2,kb)|0)+(Va>>2))|0;Xe[c[(c[aa>>2]|0)+64+(_a<<2)>>2]&4095](ja,ea,kb)}Q=Q+1|0;}while((Q|0)<4)}}else{Q=(c[a+12160>>2]|0)+o|0;aa=(c[a+12164>>2]|0)+lb|0;S=c[a+12128>>2]|0;if((o|0)==0){tb=(ba(S,B-cb|0)|0)/(cb|0)|0}else{tb=Q-S|0}S=c[a+12132>>2]|0;if((lb|0)==0){ub=(ba(S,B-cb|0)|0)/(cb|0)|0}else{ub=aa-S|0}S=((aa&jb)<<A)+(Q&jb)|0;F=((ub&jb)<<A)+(tb&jb)|0;if((z|0)==0){Xa=a+12208|0;db=(c[s>>2]|0)+((ba(aa>>1,kb)|0)+(Q>>1))|0;cf[c[(c[a+12444>>2]|0)+(S<<2)>>2]&1023](c[Xa>>2]|0,db,kb,16);db=(c[a+12352+(h<<4)+32>>2]|0)+((ba(ub>>1,kb)|0)+(tb>>1))|0;cf[c[(c[a+12448>>2]|0)+(F<<2)>>2]&1023](c[Xa>>2]|0,db,kb,16);break}else{db=a+12452|0;Xa=a+12208|0;gb=(ba(aa>>2,kb)|0)+(Q>>2)|0;Xe[c[(c[db>>2]|0)+64+(S<<2)>>2]&4095](c[Xa>>2]|0,(c[s>>2]|0)+gb|0,kb);Q=gb+8|0;Xe[c[(c[db>>2]|0)+64+(S<<2)>>2]&4095]((c[Xa>>2]|0)+8|0,(c[s>>2]|0)+Q|0,kb);aa=kb<<3;Xe[c[(c[db>>2]|0)+64+(S<<2)>>2]&4095]((c[Xa>>2]|0)+aa|0,(c[s>>2]|0)+(gb+aa)|0,kb);gb=aa+8|0;Xe[c[(c[db>>2]|0)+64+(S<<2)>>2]&4095]((c[Xa>>2]|0)+gb|0,(c[s>>2]|0)+(Q+aa)|0,kb);Q=a+12456|0;S=a+12352+(h<<4)+32|0;db=(ba(ub>>2,kb)|0)+(tb>>2)|0;Xe[c[(c[Q>>2]|0)+64+(F<<2)>>2]&4095](c[Xa>>2]|0,(c[S>>2]|0)+db|0,kb);fb=db+8|0;Xe[c[(c[Q>>2]|0)+64+(F<<2)>>2]&4095]((c[Xa>>2]|0)+8|0,(c[S>>2]|0)+fb|0,kb);Xe[c[(c[Q>>2]|0)+64+(F<<2)>>2]&4095]((c[Xa>>2]|0)+aa|0,(c[S>>2]|0)+(db+aa)|0,kb);Xe[c[(c[Q>>2]|0)+64+(F<<2)>>2]&4095]((c[Xa>>2]|0)+gb|0,(c[S>>2]|0)+(fb+aa)|0,kb);break}}}while(0);qb=Pe[D&255](a,c[a+12208>>2]|0,c[nb>>2]|0,kb,16)|0}}while(0);c[Fa>>2]=ab;c[m+(na<<2)>>2]=qb;s=(ba((d[v+((H<<A)-x)|0]|0)+(d[v+((I<<A)-w)|0]|0)|0,i)|0)+qb|0;if((s|0)>=(hb|0)){ob=hb;pb=s;break}c[b>>2]=I;c[J>>2]=H;ob=s;pb=s}}while(0);H=G-1|0;I=(H|0)>(u|0)?u:H;H=(q|0)>(I|0)?q:I;I=Aa+(H<<11)|0;Aa=(H<<3)+Z&63;q=y+(Aa<<2)|0;if((c[q>>2]|0)==(I|0)){vb=pb;c[b>>2]=oa;c[J>>2]=G;return vb|0}do{if((l&4|0)==0){pb=c[a+12416>>2]|0;y=c[a+12420>>2]|0;u=a;hb=(c[a+12352+(h<<4)>>2]|0)+((ba(pb,H)|0)+Z)|0;qb=Pe[D&255](u,c[a+12288+(g<<4)>>2]|0,hb,pb,k)|0;if((l&2|0)==0){wb=qb;break}hb=H<<1&2|Z&1;na=c[a+12208>>2]|0;ab=pb<<4;pb=na+ab|0;Fa=a+12444|0;tb=(ba(y,H>>1)|0)+(Z>>1)|0;ub=k>>1;cf[c[(c[Fa>>2]|0)+(E<<4)+(hb<<2)>>2]&1023](pb,(c[a+12352+(h<<4)+4>>2]|0)+tb|0,y,ub);rb=na+(ab|8)|0;cf[c[(c[Fa>>2]|0)+(E<<4)+(hb<<2)>>2]&1023](rb,(c[a+12352+(h<<4)+8>>2]|0)+tb|0,y,ub);tb=(Pe[j&255](u,pb,c[a+12288+(g<<4)+4>>2]|0,y,ub)|0)+qb|0;wb=tb+(Pe[j&255](u,rb,c[a+12288+(g<<4)+8>>2]|0,y,ub)|0)|0}else{ub=c[a+12416>>2]|0;y=Z<<A;rb=H<<A;u=a+12352+(h<<4)|0;tb=a+12288+(g<<4)|0;if((c[n>>2]|0)>(Z|0)){wb=536870912;break}if((y|0)>(c[r>>2]<<A|0)){wb=536870912;break}if((c[p>>2]|0)>(H|0)){wb=536870912;break}if((rb|0)>(c[t>>2]<<A|0)){wb=536870912;break}qb=e[a+13872>>1]|0;pb=e[a+13874>>1]|0;hb=z<<1|1;f:do{if((c[a+11740>>2]|0)==1){Fa=pb-qb|0;ab=z|4;na=(rb|0)==0;sb=a+12208|0;ib=ub<<3;s=(z|0)==0;jb=a+12444|0;cb=a+12448|0;B=a+12352+(h<<4)+32|0;lb=a+12452|0;o=a+12456|0;if((y|0)==0){Za=0;while(1){Ya=c[a+12160+(Za<<3)>>2]|0;aa=(c[a+12160+(Za<<3)+4>>2]|0)+rb|0;fb=((ba(c[a+12128+(Za<<3)>>2]|0,Fa)|0)/(qb|0)|0)+((Za&1)<<ab)|0;S=c[a+12128+(Za<<3)+4>>2]|0;if(na){gb=Za>>1;xb=((ba(S,Fa)|0)/(qb|0)|0)+(gb<<ab)|0;yb=gb}else{xb=aa-S|0;yb=Za>>1}S=((aa&hb)<<A)+(Ya&hb)|0;gb=((xb&hb)<<A)+(fb&hb)|0;Xa=(c[sb>>2]|0)+((ba(yb,ib)|0)+(Za<<3&8))|0;if(s){F=(c[u>>2]|0)+((ba(aa>>1,ub)|0)+(Ya>>1))|0;cf[c[(c[jb>>2]|0)+16+(S<<2)>>2]&1023](Xa,F,ub,8);F=(c[B>>2]|0)+((ba(xb>>1,ub)|0)+(fb>>1))|0;cf[c[(c[cb>>2]|0)+16+(gb<<2)>>2]&1023](Xa,F,ub,8)}else{F=(c[u>>2]|0)+((ba(aa>>2,ub)|0)+(Ya>>2))|0;Xe[c[(c[lb>>2]|0)+64+(S<<2)>>2]&4095](Xa,F,ub);F=(c[B>>2]|0)+((ba(xb>>2,ub)|0)+(fb>>2))|0;Xe[c[(c[o>>2]|0)+64+(gb<<2)>>2]&4095](Xa,F,ub)}Za=Za+1|0;if((Za|0)>=4){break f}}}if(na){Za=0;do{kb=(c[a+12160+(Za<<3)>>2]|0)+y|0;nb=c[a+12160+(Za<<3)+4>>2]|0;F=kb-(c[a+12128+(Za<<3)>>2]|0)|0;Xa=Za>>1;gb=((ba(c[a+12128+(Za<<3)+4>>2]|0,Fa)|0)/(qb|0)|0)+(Xa<<ab)|0;fb=((nb&hb)<<A)+(kb&hb)|0;S=((gb&hb)<<A)+(F&hb)|0;Ya=(c[sb>>2]|0)+((Za<<3&8)+(ba(Xa,ib)|0))|0;if(s){Xa=(c[u>>2]|0)+((ba(nb>>1,ub)|0)+(kb>>1))|0;cf[c[(c[jb>>2]|0)+16+(fb<<2)>>2]&1023](Ya,Xa,ub,8);Xa=(c[B>>2]|0)+((ba(gb>>1,ub)|0)+(F>>1))|0;cf[c[(c[cb>>2]|0)+16+(S<<2)>>2]&1023](Ya,Xa,ub,8)}else{Xa=(c[u>>2]|0)+((ba(nb>>2,ub)|0)+(kb>>2))|0;Xe[c[(c[lb>>2]|0)+64+(fb<<2)>>2]&4095](Ya,Xa,ub);Xa=(c[B>>2]|0)+((ba(gb>>2,ub)|0)+(F>>2))|0;Xe[c[(c[o>>2]|0)+64+(S<<2)>>2]&4095](Ya,Xa,ub)}Za=Za+1|0;}while((Za|0)<4)}else{Za=0;do{ab=(c[a+12160+(Za<<3)>>2]|0)+y|0;Fa=(c[a+12160+(Za<<3)+4>>2]|0)+rb|0;na=ab-(c[a+12128+(Za<<3)>>2]|0)|0;Xa=Fa-(c[a+12128+(Za<<3)+4>>2]|0)|0;Ya=((Fa&hb)<<A)+(ab&hb)|0;S=((Xa&hb)<<A)+(na&hb)|0;F=(c[sb>>2]|0)+((Za<<3&8)+(ba(Za>>1,ib)|0))|0;if(s){gb=(c[u>>2]|0)+((ba(Fa>>1,ub)|0)+(ab>>1))|0;cf[c[(c[jb>>2]|0)+16+(Ya<<2)>>2]&1023](F,gb,ub,8);gb=(c[B>>2]|0)+((ba(Xa>>1,ub)|0)+(na>>1))|0;cf[c[(c[cb>>2]|0)+16+(S<<2)>>2]&1023](F,gb,ub,8)}else{gb=(c[u>>2]|0)+((ba(Fa>>2,ub)|0)+(ab>>2))|0;Xe[c[(c[lb>>2]|0)+64+(Ya<<2)>>2]&4095](F,gb,ub);gb=(c[B>>2]|0)+((ba(Xa>>2,ub)|0)+(na>>2))|0;Xe[c[(c[o>>2]|0)+64+(S<<2)>>2]&4095](F,gb,ub)}Za=Za+1|0;}while((Za|0)<4)}}else{Za=(c[a+12160>>2]|0)+y|0;o=(c[a+12164>>2]|0)+rb|0;B=c[a+12128>>2]|0;if((y|0)==0){zb=(ba(B,pb-qb|0)|0)/(qb|0)|0}else{zb=Za-B|0}B=c[a+12132>>2]|0;if((rb|0)==0){Ab=(ba(B,pb-qb|0)|0)/(qb|0)|0}else{Ab=o-B|0}B=((o&hb)<<A)+(Za&hb)|0;lb=((Ab&hb)<<A)+(zb&hb)|0;if((z|0)==0){cb=a+12208|0;jb=(c[u>>2]|0)+((ba(o>>1,ub)|0)+(Za>>1))|0;cf[c[(c[a+12444>>2]|0)+(B<<2)>>2]&1023](c[cb>>2]|0,jb,ub,16);jb=(c[a+12352+(h<<4)+32>>2]|0)+((ba(Ab>>1,ub)|0)+(zb>>1))|0;cf[c[(c[a+12448>>2]|0)+(lb<<2)>>2]&1023](c[cb>>2]|0,jb,ub,16);break}else{jb=a+12452|0;cb=a+12208|0;s=(ba(o>>2,ub)|0)+(Za>>2)|0;Xe[c[(c[jb>>2]|0)+64+(B<<2)>>2]&4095](c[cb>>2]|0,(c[u>>2]|0)+s|0,ub);Za=s+8|0;Xe[c[(c[jb>>2]|0)+64+(B<<2)>>2]&4095]((c[cb>>2]|0)+8|0,(c[u>>2]|0)+Za|0,ub);o=ub<<3;Xe[c[(c[jb>>2]|0)+64+(B<<2)>>2]&4095]((c[cb>>2]|0)+o|0,(c[u>>2]|0)+(s+o)|0,ub);s=o+8|0;Xe[c[(c[jb>>2]|0)+64+(B<<2)>>2]&4095]((c[cb>>2]|0)+s|0,(c[u>>2]|0)+(Za+o)|0,ub);Za=a+12456|0;B=a+12352+(h<<4)+32|0;jb=(ba(Ab>>2,ub)|0)+(zb>>2)|0;Xe[c[(c[Za>>2]|0)+64+(lb<<2)>>2]&4095](c[cb>>2]|0,(c[B>>2]|0)+jb|0,ub);ib=jb+8|0;Xe[c[(c[Za>>2]|0)+64+(lb<<2)>>2]&4095]((c[cb>>2]|0)+8|0,(c[B>>2]|0)+ib|0,ub);Xe[c[(c[Za>>2]|0)+64+(lb<<2)>>2]&4095]((c[cb>>2]|0)+o|0,(c[B>>2]|0)+(jb+o)|0,ub);Xe[c[(c[Za>>2]|0)+64+(lb<<2)>>2]&4095]((c[cb>>2]|0)+s|0,(c[B>>2]|0)+(ib+o)|0,ub);break}}}while(0);wb=Pe[D&255](a,c[a+12208>>2]|0,c[tb>>2]|0,ub,16)|0}}while(0);c[q>>2]=I;c[m+(Aa<<2)>>2]=wb;Aa=(ba((d[v+((H<<A)-x)|0]|0)+(d[v+((Z<<A)-w)|0]|0)|0,i)|0)+wb|0;if((Aa|0)>=(ob|0)){vb=Aa;c[b>>2]=oa;c[J>>2]=G;return vb|0}c[b>>2]=Z;c[J>>2]=H;vb=Aa;c[b>>2]=oa;c[J>>2]=G;return vb|0}function Hmb(a,b,f,g,h,i,j,k,l,m){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0;n=c[a+12220>>2]|0;o=a+12264|0;p=c[o>>2]|0;q=a+12272|0;r=c[q>>2]|0;s=a+12268|0;t=c[s>>2]|0;u=a+12276|0;v=c[u>>2]|0;w=c[a+12464>>2]|0;x=c[a+12280>>2]|0;y=c[a+12284>>2]|0;z=c[a+12216>>2]|0;A=l&1;B=A+1|0;C=c[a+12224>>2]|0;D=c[a+10468+(j<<2)>>2]|0;E=j+1|0;j=c[a+10468+(E<<2)>>2]|0;if((m|0)==0){F=f;return F|0}G=b+4|0;H=(l&4|0)==0;I=a+12416|0;J=a+12420|0;K=a+12352+(h<<4)|0;L=a+12288+(g<<4)|0;M=a;N=(l&2|0)==0;l=a+12208|0;O=a+12444|0;P=a+12352+(h<<4)+4|0;Q=k>>1;R=a+12352+(h<<4)+8|0;S=a+12288+(g<<4)+4|0;T=a+12288+(g<<4)+8|0;g=a+13872|0;U=a+13874|0;V=A<<1|1;W=a+11740|0;X=A|4;Y=(A|0)==0;A=a+12448|0;Z=a+12352+(h<<4)+32|0;h=a+12452|0;_=a+12456|0;$=a+12160|0;aa=a+12164|0;ca=a+12128|0;da=a+12132|0;ea=(m-1&m|0)!=0;fa=m;m=f;f=c[b>>2]|0;while(1){ga=fa>>1;ha=(fa|0)>1;ia=-fa>>1;ja=m;ka=f;while(1){la=c[G>>2]|0;ma=ka-fa|0;na=(ma|0)>(t|0)?t:ma;ma=(p|0)>(na|0)?p:na;na=(la|0)>(v|0)?v:la;oa=(r|0)>(na|0)?r:na;na=oa<<11;pa=ma+C+na|0;qa=oa<<3;ra=qa+ma&63;sa=z+(ra<<2)|0;do{if((c[sa>>2]|0)==(pa|0)){ta=ja}else{ua=c[I>>2]|0;do{if(H){va=c[J>>2]|0;wa=(c[K>>2]|0)+((ba(ua,oa)|0)+ma)|0;xa=Pe[D&255](M,c[L>>2]|0,wa,ua,k)|0;if(N){ya=xa;break}wa=oa<<1&2|ma&1;za=c[l>>2]|0;Aa=ua<<4;Ba=za+Aa|0;Ca=(ba(va,oa>>1)|0)+(ma>>1)|0;cf[c[(c[O>>2]|0)+(E<<4)+(wa<<2)>>2]&1023](Ba,(c[P>>2]|0)+Ca|0,va,Q);Da=za+(Aa|8)|0;cf[c[(c[O>>2]|0)+(E<<4)+(wa<<2)>>2]&1023](Da,(c[R>>2]|0)+Ca|0,va,Q);Ca=(Pe[j&255](M,Ba,c[S>>2]|0,va,Q)|0)+xa|0;ya=Ca+(Pe[j&255](M,Da,c[T>>2]|0,va,Q)|0)|0}else{va=ma<<B;Da=oa<<B;if((c[o>>2]|0)>(ma|0)){ya=536870912;break}if((va|0)>(c[s>>2]<<B|0)){ya=536870912;break}if((c[q>>2]|0)>(oa|0)){ya=536870912;break}if((Da|0)>(c[u>>2]<<B|0)){ya=536870912;break}Ca=e[g>>1]|0;xa=e[U>>1]|0;a:do{if((c[W>>2]|0)==1){Ba=xa-Ca|0;wa=(Da|0)==0;Aa=ua<<3;if((va|0)==0){za=0;while(1){Ea=c[a+12160+(za<<3)>>2]|0;Fa=(c[a+12160+(za<<3)+4>>2]|0)+Da|0;Ga=((ba(c[a+12128+(za<<3)>>2]|0,Ba)|0)/(Ca|0)|0)+((za&1)<<X)|0;Ha=c[a+12128+(za<<3)+4>>2]|0;if(wa){Ia=za>>1;Ja=((ba(Ha,Ba)|0)/(Ca|0)|0)+(Ia<<X)|0;Ka=Ia}else{Ja=Fa-Ha|0;Ka=za>>1}Ha=((Fa&V)<<B)+(Ea&V)|0;Ia=((Ja&V)<<B)+(Ga&V)|0;La=(c[l>>2]|0)+((ba(Ka,Aa)|0)+(za<<3&8))|0;if(Y){Ma=(c[K>>2]|0)+((ba(Fa>>1,ua)|0)+(Ea>>1))|0;cf[c[(c[O>>2]|0)+16+(Ha<<2)>>2]&1023](La,Ma,ua,8);Ma=(c[Z>>2]|0)+((ba(Ja>>1,ua)|0)+(Ga>>1))|0;cf[c[(c[A>>2]|0)+16+(Ia<<2)>>2]&1023](La,Ma,ua,8)}else{Ma=(c[K>>2]|0)+((ba(Fa>>2,ua)|0)+(Ea>>2))|0;Xe[c[(c[h>>2]|0)+64+(Ha<<2)>>2]&4095](La,Ma,ua);Ma=(c[Z>>2]|0)+((ba(Ja>>2,ua)|0)+(Ga>>2))|0;Xe[c[(c[_>>2]|0)+64+(Ia<<2)>>2]&4095](La,Ma,ua)}za=za+1|0;if((za|0)>=4){break a}}}if(wa){za=0;do{Ma=(c[a+12160+(za<<3)>>2]|0)+va|0;La=c[a+12160+(za<<3)+4>>2]|0;Ia=Ma-(c[a+12128+(za<<3)>>2]|0)|0;Ga=za>>1;Ha=((ba(c[a+12128+(za<<3)+4>>2]|0,Ba)|0)/(Ca|0)|0)+(Ga<<X)|0;Ea=((La&V)<<B)+(Ma&V)|0;Fa=((Ha&V)<<B)+(Ia&V)|0;Na=(c[l>>2]|0)+((za<<3&8)+(ba(Ga,Aa)|0))|0;if(Y){Ga=(c[K>>2]|0)+((ba(La>>1,ua)|0)+(Ma>>1))|0;cf[c[(c[O>>2]|0)+16+(Ea<<2)>>2]&1023](Na,Ga,ua,8);Ga=(c[Z>>2]|0)+((ba(Ha>>1,ua)|0)+(Ia>>1))|0;cf[c[(c[A>>2]|0)+16+(Fa<<2)>>2]&1023](Na,Ga,ua,8)}else{Ga=(c[K>>2]|0)+((ba(La>>2,ua)|0)+(Ma>>2))|0;Xe[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095](Na,Ga,ua);Ga=(c[Z>>2]|0)+((ba(Ha>>2,ua)|0)+(Ia>>2))|0;Xe[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095](Na,Ga,ua)}za=za+1|0;}while((za|0)<4)}else{za=0;do{Ba=(c[a+12160+(za<<3)>>2]|0)+va|0;wa=(c[a+12160+(za<<3)+4>>2]|0)+Da|0;Ga=Ba-(c[a+12128+(za<<3)>>2]|0)|0;Na=wa-(c[a+12128+(za<<3)+4>>2]|0)|0;Fa=((wa&V)<<B)+(Ba&V)|0;Ia=((Na&V)<<B)+(Ga&V)|0;Ha=(c[l>>2]|0)+((za<<3&8)+(ba(za>>1,Aa)|0))|0;if(Y){Ea=(c[K>>2]|0)+((ba(wa>>1,ua)|0)+(Ba>>1))|0;cf[c[(c[O>>2]|0)+16+(Fa<<2)>>2]&1023](Ha,Ea,ua,8);Ea=(c[Z>>2]|0)+((ba(Na>>1,ua)|0)+(Ga>>1))|0;cf[c[(c[A>>2]|0)+16+(Ia<<2)>>2]&1023](Ha,Ea,ua,8)}else{Ea=(c[K>>2]|0)+((ba(wa>>2,ua)|0)+(Ba>>2))|0;Xe[c[(c[h>>2]|0)+64+(Fa<<2)>>2]&4095](Ha,Ea,ua);Ea=(c[Z>>2]|0)+((ba(Na>>2,ua)|0)+(Ga>>2))|0;Xe[c[(c[_>>2]|0)+64+(Ia<<2)>>2]&4095](Ha,Ea,ua)}za=za+1|0;}while((za|0)<4)}}else{za=(c[$>>2]|0)+va|0;Aa=(c[aa>>2]|0)+Da|0;Ea=c[ca>>2]|0;if((va|0)==0){Oa=(ba(Ea,xa-Ca|0)|0)/(Ca|0)|0}else{Oa=za-Ea|0}Ea=c[da>>2]|0;if((Da|0)==0){Pa=(ba(Ea,xa-Ca|0)|0)/(Ca|0)|0}else{Pa=Aa-Ea|0}Ea=((Aa&V)<<B)+(za&V)|0;Ha=((Pa&V)<<B)+(Oa&V)|0;if(Y){Ia=(c[K>>2]|0)+((ba(Aa>>1,ua)|0)+(za>>1))|0;cf[c[(c[O>>2]|0)+(Ea<<2)>>2]&1023](c[l>>2]|0,Ia,ua,16);Ia=(c[Z>>2]|0)+((ba(Pa>>1,ua)|0)+(Oa>>1))|0;cf[c[(c[A>>2]|0)+(Ha<<2)>>2]&1023](c[l>>2]|0,Ia,ua,16);break}else{Ia=(ba(Aa>>2,ua)|0)+(za>>2)|0;Xe[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+Ia|0,ua);za=Ia+8|0;Xe[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+za|0,ua);Aa=ua<<3;Xe[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[K>>2]|0)+(Ia+Aa)|0,ua);Ia=Aa+8|0;Xe[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+Ia|0,(c[K>>2]|0)+(za+Aa)|0,ua);za=(ba(Pa>>2,ua)|0)+(Oa>>2)|0;Xe[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+za|0,ua);Ea=za+8|0;Xe[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+Ea|0,ua);Xe[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[Z>>2]|0)+(za+Aa)|0,ua);Xe[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+Ia|0,(c[Z>>2]|0)+(Ea+Aa)|0,ua);break}}}while(0);ya=Pe[D&255](M,c[l>>2]|0,c[L>>2]|0,ua,16)|0}}while(0);c[sa>>2]=pa;c[n+(ra<<2)>>2]=ya;ua=(ba((d[w+((oa<<B)-y)|0]|0)+(d[w+((ma<<B)-x)|0]|0)|0,i)|0)+ya|0;if((ua|0)>=(ja|0)){ta=ja;break}c[b>>2]=ma;c[G>>2]=oa;ta=ua}}while(0);ma=ka+fa|0;ra=(ma|0)>(t|0)?t:ma;ma=(p|0)>(ra|0)?p:ra;ra=ma+C+na|0;pa=qa+ma&63;sa=z+(pa<<2)|0;do{if((c[sa>>2]|0)==(ra|0)){Qa=ta}else{ua=c[I>>2]|0;do{if(H){Ca=c[J>>2]|0;xa=(c[K>>2]|0)+((ba(ua,oa)|0)+ma)|0;Da=Pe[D&255](M,c[L>>2]|0,xa,ua,k)|0;if(N){Ra=Da;break}xa=oa<<1&2|ma&1;va=c[l>>2]|0;Aa=ua<<4;Ea=va+Aa|0;Ia=(ba(Ca,oa>>1)|0)+(ma>>1)|0;cf[c[(c[O>>2]|0)+(E<<4)+(xa<<2)>>2]&1023](Ea,(c[P>>2]|0)+Ia|0,Ca,Q);Ha=va+(Aa|8)|0;cf[c[(c[O>>2]|0)+(E<<4)+(xa<<2)>>2]&1023](Ha,(c[R>>2]|0)+Ia|0,Ca,Q);Ia=(Pe[j&255](M,Ea,c[S>>2]|0,Ca,Q)|0)+Da|0;Ra=Ia+(Pe[j&255](M,Ha,c[T>>2]|0,Ca,Q)|0)|0}else{Ca=ma<<B;Ha=oa<<B;if((c[o>>2]|0)>(ma|0)){Ra=536870912;break}if((Ca|0)>(c[s>>2]<<B|0)){Ra=536870912;break}if((c[q>>2]|0)>(oa|0)){Ra=536870912;break}if((Ha|0)>(c[u>>2]<<B|0)){Ra=536870912;break}Ia=e[g>>1]|0;Da=e[U>>1]|0;b:do{if((c[W>>2]|0)==1){Ea=Da-Ia|0;xa=(Ha|0)==0;Aa=ua<<3;if((Ca|0)==0){va=0;while(1){za=c[a+12160+(va<<3)>>2]|0;Ga=(c[a+12160+(va<<3)+4>>2]|0)+Ha|0;Na=((ba(c[a+12128+(va<<3)>>2]|0,Ea)|0)/(Ia|0)|0)+((va&1)<<X)|0;Fa=c[a+12128+(va<<3)+4>>2]|0;if(xa){Ba=va>>1;Sa=((ba(Fa,Ea)|0)/(Ia|0)|0)+(Ba<<X)|0;Ta=Ba}else{Sa=Ga-Fa|0;Ta=va>>1}Fa=((Ga&V)<<B)+(za&V)|0;Ba=((Sa&V)<<B)+(Na&V)|0;wa=(c[l>>2]|0)+((ba(Ta,Aa)|0)+(va<<3&8))|0;if(Y){Ma=(c[K>>2]|0)+((ba(Ga>>1,ua)|0)+(za>>1))|0;cf[c[(c[O>>2]|0)+16+(Fa<<2)>>2]&1023](wa,Ma,ua,8);Ma=(c[Z>>2]|0)+((ba(Sa>>1,ua)|0)+(Na>>1))|0;cf[c[(c[A>>2]|0)+16+(Ba<<2)>>2]&1023](wa,Ma,ua,8)}else{Ma=(c[K>>2]|0)+((ba(Ga>>2,ua)|0)+(za>>2))|0;Xe[c[(c[h>>2]|0)+64+(Fa<<2)>>2]&4095](wa,Ma,ua);Ma=(c[Z>>2]|0)+((ba(Sa>>2,ua)|0)+(Na>>2))|0;Xe[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095](wa,Ma,ua)}va=va+1|0;if((va|0)>=4){break b}}}if(xa){va=0;do{Ma=(c[a+12160+(va<<3)>>2]|0)+Ca|0;wa=c[a+12160+(va<<3)+4>>2]|0;Ba=Ma-(c[a+12128+(va<<3)>>2]|0)|0;Na=va>>1;Fa=((ba(c[a+12128+(va<<3)+4>>2]|0,Ea)|0)/(Ia|0)|0)+(Na<<X)|0;za=((wa&V)<<B)+(Ma&V)|0;Ga=((Fa&V)<<B)+(Ba&V)|0;La=(c[l>>2]|0)+((va<<3&8)+(ba(Na,Aa)|0))|0;if(Y){Na=(c[K>>2]|0)+((ba(wa>>1,ua)|0)+(Ma>>1))|0;cf[c[(c[O>>2]|0)+16+(za<<2)>>2]&1023](La,Na,ua,8);Na=(c[Z>>2]|0)+((ba(Fa>>1,ua)|0)+(Ba>>1))|0;cf[c[(c[A>>2]|0)+16+(Ga<<2)>>2]&1023](La,Na,ua,8)}else{Na=(c[K>>2]|0)+((ba(wa>>2,ua)|0)+(Ma>>2))|0;Xe[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095](La,Na,ua);Na=(c[Z>>2]|0)+((ba(Fa>>2,ua)|0)+(Ba>>2))|0;Xe[c[(c[_>>2]|0)+64+(Ga<<2)>>2]&4095](La,Na,ua)}va=va+1|0;}while((va|0)<4)}else{va=0;do{Ea=(c[a+12160+(va<<3)>>2]|0)+Ca|0;xa=(c[a+12160+(va<<3)+4>>2]|0)+Ha|0;Na=Ea-(c[a+12128+(va<<3)>>2]|0)|0;La=xa-(c[a+12128+(va<<3)+4>>2]|0)|0;Ga=((xa&V)<<B)+(Ea&V)|0;Ba=((La&V)<<B)+(Na&V)|0;Fa=(c[l>>2]|0)+((va<<3&8)+(ba(va>>1,Aa)|0))|0;if(Y){za=(c[K>>2]|0)+((ba(xa>>1,ua)|0)+(Ea>>1))|0;cf[c[(c[O>>2]|0)+16+(Ga<<2)>>2]&1023](Fa,za,ua,8);za=(c[Z>>2]|0)+((ba(La>>1,ua)|0)+(Na>>1))|0;cf[c[(c[A>>2]|0)+16+(Ba<<2)>>2]&1023](Fa,za,ua,8)}else{za=(c[K>>2]|0)+((ba(xa>>2,ua)|0)+(Ea>>2))|0;Xe[c[(c[h>>2]|0)+64+(Ga<<2)>>2]&4095](Fa,za,ua);za=(c[Z>>2]|0)+((ba(La>>2,ua)|0)+(Na>>2))|0;Xe[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095](Fa,za,ua)}va=va+1|0;}while((va|0)<4)}}else{va=(c[$>>2]|0)+Ca|0;Aa=(c[aa>>2]|0)+Ha|0;za=c[ca>>2]|0;if((Ca|0)==0){Ua=(ba(za,Da-Ia|0)|0)/(Ia|0)|0}else{Ua=va-za|0}za=c[da>>2]|0;if((Ha|0)==0){Va=(ba(za,Da-Ia|0)|0)/(Ia|0)|0}else{Va=Aa-za|0}za=((Aa&V)<<B)+(va&V)|0;Fa=((Va&V)<<B)+(Ua&V)|0;if(Y){Ba=(c[K>>2]|0)+((ba(Aa>>1,ua)|0)+(va>>1))|0;cf[c[(c[O>>2]|0)+(za<<2)>>2]&1023](c[l>>2]|0,Ba,ua,16);Ba=(c[Z>>2]|0)+((ba(Va>>1,ua)|0)+(Ua>>1))|0;cf[c[(c[A>>2]|0)+(Fa<<2)>>2]&1023](c[l>>2]|0,Ba,ua,16);break}else{Ba=(ba(Aa>>2,ua)|0)+(va>>2)|0;Xe[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+Ba|0,ua);va=Ba+8|0;Xe[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+va|0,ua);Aa=ua<<3;Xe[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[K>>2]|0)+(Ba+Aa)|0,ua);Ba=Aa+8|0;Xe[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095]((c[l>>2]|0)+Ba|0,(c[K>>2]|0)+(va+Aa)|0,ua);va=(ba(Va>>2,ua)|0)+(Ua>>2)|0;Xe[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+va|0,ua);za=va+8|0;Xe[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+za|0,ua);Xe[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[Z>>2]|0)+(va+Aa)|0,ua);Xe[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095]((c[l>>2]|0)+Ba|0,(c[Z>>2]|0)+(za+Aa)|0,ua);break}}}while(0);Ra=Pe[D&255](M,c[l>>2]|0,c[L>>2]|0,ua,16)|0}}while(0);c[sa>>2]=ra;c[n+(pa<<2)>>2]=Ra;ua=(ba((d[w+((oa<<B)-y)|0]|0)+(d[w+((ma<<B)-x)|0]|0)|0,i)|0)+Ra|0;if((ua|0)>=(ta|0)){Qa=ta;break}c[b>>2]=ma;c[G>>2]=oa;Qa=ua}}while(0);oa=ka+ga|0;ma=la+fa|0;pa=(oa|0)>(t|0)?t:oa;oa=(p|0)>(pa|0)?p:pa;pa=(ma|0)>(v|0)?v:ma;ma=(r|0)>(pa|0)?r:pa;pa=ma<<11;ra=oa+C|0;sa=ra+pa|0;qa=ma<<3;na=qa+oa&63;ua=z+(na<<2)|0;do{if((c[ua>>2]|0)==(sa|0)){Wa=Qa}else{Ia=c[I>>2]|0;do{if(H){Da=c[J>>2]|0;Ha=(c[K>>2]|0)+((ba(Ia,ma)|0)+oa)|0;Ca=Pe[D&255](M,c[L>>2]|0,Ha,Ia,k)|0;if(N){Xa=Ca;break}Ha=ma<<1&2|oa&1;Aa=c[l>>2]|0;za=Ia<<4;Ba=Aa+za|0;Fa=(ba(Da,ma>>1)|0)+(oa>>1)|0;cf[c[(c[O>>2]|0)+(E<<4)+(Ha<<2)>>2]&1023](Ba,(c[P>>2]|0)+Fa|0,Da,Q);va=Aa+(za|8)|0;cf[c[(c[O>>2]|0)+(E<<4)+(Ha<<2)>>2]&1023](va,(c[R>>2]|0)+Fa|0,Da,Q);Fa=(Pe[j&255](M,Ba,c[S>>2]|0,Da,Q)|0)+Ca|0;Xa=Fa+(Pe[j&255](M,va,c[T>>2]|0,Da,Q)|0)|0}else{Da=oa<<B;va=ma<<B;if((c[o>>2]|0)>(oa|0)){Xa=536870912;break}if((Da|0)>(c[s>>2]<<B|0)){Xa=536870912;break}if((c[q>>2]|0)>(ma|0)){Xa=536870912;break}if((va|0)>(c[u>>2]<<B|0)){Xa=536870912;break}Fa=e[g>>1]|0;Ca=e[U>>1]|0;c:do{if((c[W>>2]|0)==1){Ba=Ca-Fa|0;Ha=(va|0)==0;za=Ia<<3;if((Da|0)==0){Aa=0;while(1){Na=c[a+12160+(Aa<<3)>>2]|0;La=(c[a+12160+(Aa<<3)+4>>2]|0)+va|0;Ga=((ba(c[a+12128+(Aa<<3)>>2]|0,Ba)|0)/(Fa|0)|0)+((Aa&1)<<X)|0;Ea=c[a+12128+(Aa<<3)+4>>2]|0;if(Ha){xa=Aa>>1;Ya=((ba(Ea,Ba)|0)/(Fa|0)|0)+(xa<<X)|0;Za=xa}else{Ya=La-Ea|0;Za=Aa>>1}Ea=((La&V)<<B)+(Na&V)|0;xa=((Ya&V)<<B)+(Ga&V)|0;Ma=(c[l>>2]|0)+((ba(Za,za)|0)+(Aa<<3&8))|0;if(Y){wa=(c[K>>2]|0)+((ba(La>>1,Ia)|0)+(Na>>1))|0;cf[c[(c[O>>2]|0)+16+(Ea<<2)>>2]&1023](Ma,wa,Ia,8);wa=(c[Z>>2]|0)+((ba(Ya>>1,Ia)|0)+(Ga>>1))|0;cf[c[(c[A>>2]|0)+16+(xa<<2)>>2]&1023](Ma,wa,Ia,8)}else{wa=(c[K>>2]|0)+((ba(La>>2,Ia)|0)+(Na>>2))|0;Xe[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095](Ma,wa,Ia);wa=(c[Z>>2]|0)+((ba(Ya>>2,Ia)|0)+(Ga>>2))|0;Xe[c[(c[_>>2]|0)+64+(xa<<2)>>2]&4095](Ma,wa,Ia)}Aa=Aa+1|0;if((Aa|0)>=4){break c}}}if(Ha){Aa=0;do{wa=(c[a+12160+(Aa<<3)>>2]|0)+Da|0;Ma=c[a+12160+(Aa<<3)+4>>2]|0;xa=wa-(c[a+12128+(Aa<<3)>>2]|0)|0;Ga=Aa>>1;Ea=((ba(c[a+12128+(Aa<<3)+4>>2]|0,Ba)|0)/(Fa|0)|0)+(Ga<<X)|0;Na=((Ma&V)<<B)+(wa&V)|0;La=((Ea&V)<<B)+(xa&V)|0;_a=(c[l>>2]|0)+((Aa<<3&8)+(ba(Ga,za)|0))|0;if(Y){Ga=(c[K>>2]|0)+((ba(Ma>>1,Ia)|0)+(wa>>1))|0;cf[c[(c[O>>2]|0)+16+(Na<<2)>>2]&1023](_a,Ga,Ia,8);Ga=(c[Z>>2]|0)+((ba(Ea>>1,Ia)|0)+(xa>>1))|0;cf[c[(c[A>>2]|0)+16+(La<<2)>>2]&1023](_a,Ga,Ia,8)}else{Ga=(c[K>>2]|0)+((ba(Ma>>2,Ia)|0)+(wa>>2))|0;Xe[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095](_a,Ga,Ia);Ga=(c[Z>>2]|0)+((ba(Ea>>2,Ia)|0)+(xa>>2))|0;Xe[c[(c[_>>2]|0)+64+(La<<2)>>2]&4095](_a,Ga,Ia)}Aa=Aa+1|0;}while((Aa|0)<4)}else{Aa=0;do{Ba=(c[a+12160+(Aa<<3)>>2]|0)+Da|0;Ha=(c[a+12160+(Aa<<3)+4>>2]|0)+va|0;Ga=Ba-(c[a+12128+(Aa<<3)>>2]|0)|0;_a=Ha-(c[a+12128+(Aa<<3)+4>>2]|0)|0;La=((Ha&V)<<B)+(Ba&V)|0;xa=((_a&V)<<B)+(Ga&V)|0;Ea=(c[l>>2]|0)+((Aa<<3&8)+(ba(Aa>>1,za)|0))|0;if(Y){Na=(c[K>>2]|0)+((ba(Ha>>1,Ia)|0)+(Ba>>1))|0;cf[c[(c[O>>2]|0)+16+(La<<2)>>2]&1023](Ea,Na,Ia,8);Na=(c[Z>>2]|0)+((ba(_a>>1,Ia)|0)+(Ga>>1))|0;cf[c[(c[A>>2]|0)+16+(xa<<2)>>2]&1023](Ea,Na,Ia,8)}else{Na=(c[K>>2]|0)+((ba(Ha>>2,Ia)|0)+(Ba>>2))|0;Xe[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095](Ea,Na,Ia);Na=(c[Z>>2]|0)+((ba(_a>>2,Ia)|0)+(Ga>>2))|0;Xe[c[(c[_>>2]|0)+64+(xa<<2)>>2]&4095](Ea,Na,Ia)}Aa=Aa+1|0;}while((Aa|0)<4)}}else{Aa=(c[$>>2]|0)+Da|0;za=(c[aa>>2]|0)+va|0;Na=c[ca>>2]|0;if((Da|0)==0){$a=(ba(Na,Ca-Fa|0)|0)/(Fa|0)|0}else{$a=Aa-Na|0}Na=c[da>>2]|0;if((va|0)==0){ab=(ba(Na,Ca-Fa|0)|0)/(Fa|0)|0}else{ab=za-Na|0}Na=((za&V)<<B)+(Aa&V)|0;Ea=((ab&V)<<B)+($a&V)|0;if(Y){xa=(c[K>>2]|0)+((ba(za>>1,Ia)|0)+(Aa>>1))|0;cf[c[(c[O>>2]|0)+(Na<<2)>>2]&1023](c[l>>2]|0,xa,Ia,16);xa=(c[Z>>2]|0)+((ba(ab>>1,Ia)|0)+($a>>1))|0;cf[c[(c[A>>2]|0)+(Ea<<2)>>2]&1023](c[l>>2]|0,xa,Ia,16);break}else{xa=(ba(za>>2,Ia)|0)+(Aa>>2)|0;Xe[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+xa|0,Ia);Aa=xa+8|0;Xe[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+Aa|0,Ia);za=Ia<<3;Xe[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095]((c[l>>2]|0)+za|0,(c[K>>2]|0)+(xa+za)|0,Ia);xa=za+8|0;Xe[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095]((c[l>>2]|0)+xa|0,(c[K>>2]|0)+(Aa+za)|0,Ia);Aa=(ba(ab>>2,Ia)|0)+($a>>2)|0;Xe[c[(c[_>>2]|0)+64+(Ea<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+Aa|0,Ia);Na=Aa+8|0;Xe[c[(c[_>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+Na|0,Ia);Xe[c[(c[_>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+za|0,(c[Z>>2]|0)+(Aa+za)|0,Ia);Xe[c[(c[_>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+xa|0,(c[Z>>2]|0)+(Na+za)|0,Ia);break}}}while(0);Xa=Pe[D&255](M,c[l>>2]|0,c[L>>2]|0,Ia,16)|0}}while(0);c[ua>>2]=sa;c[n+(na<<2)>>2]=Xa;Ia=(ba((d[w+((ma<<B)-y)|0]|0)+(d[w+((oa<<B)-x)|0]|0)|0,i)|0)+Xa|0;if((Ia|0)>=(Qa|0)){Wa=Qa;break}c[b>>2]=oa;c[G>>2]=ma;Wa=Ia}}while(0);na=la-fa|0;sa=(na|0)>(v|0)?v:na;na=(r|0)>(sa|0)?r:sa;sa=na<<11;ua=ra+sa|0;Ia=na<<3;Fa=Ia+oa&63;Ca=z+(Fa<<2)|0;do{if((c[Ca>>2]|0)==(ua|0)){bb=Wa}else{va=c[I>>2]|0;do{if(H){Da=c[J>>2]|0;za=(c[K>>2]|0)+((ba(va,na)|0)+oa)|0;Na=Pe[D&255](M,c[L>>2]|0,za,va,k)|0;if(N){cb=Na;break}za=na<<1&2|oa&1;xa=c[l>>2]|0;Ea=va<<4;Aa=xa+Ea|0;Ga=(ba(Da,na>>1)|0)+(oa>>1)|0;cf[c[(c[O>>2]|0)+(E<<4)+(za<<2)>>2]&1023](Aa,(c[P>>2]|0)+Ga|0,Da,Q);_a=xa+(Ea|8)|0;cf[c[(c[O>>2]|0)+(E<<4)+(za<<2)>>2]&1023](_a,(c[R>>2]|0)+Ga|0,Da,Q);Ga=(Pe[j&255](M,Aa,c[S>>2]|0,Da,Q)|0)+Na|0;cb=Ga+(Pe[j&255](M,_a,c[T>>2]|0,Da,Q)|0)|0}else{Da=oa<<B;_a=na<<B;if((c[o>>2]|0)>(oa|0)){cb=536870912;break}if((Da|0)>(c[s>>2]<<B|0)){cb=536870912;break}if((c[q>>2]|0)>(na|0)){cb=536870912;break}if((_a|0)>(c[u>>2]<<B|0)){cb=536870912;break}Ga=e[g>>1]|0;Na=e[U>>1]|0;d:do{if((c[W>>2]|0)==1){Aa=Na-Ga|0;za=(_a|0)==0;Ea=va<<3;if((Da|0)==0){xa=0;while(1){La=c[a+12160+(xa<<3)>>2]|0;Ba=(c[a+12160+(xa<<3)+4>>2]|0)+_a|0;Ha=((ba(c[a+12128+(xa<<3)>>2]|0,Aa)|0)/(Ga|0)|0)+((xa&1)<<X)|0;wa=c[a+12128+(xa<<3)+4>>2]|0;if(za){Ma=xa>>1;db=((ba(wa,Aa)|0)/(Ga|0)|0)+(Ma<<X)|0;eb=Ma}else{db=Ba-wa|0;eb=xa>>1}wa=((Ba&V)<<B)+(La&V)|0;Ma=((db&V)<<B)+(Ha&V)|0;fb=(c[l>>2]|0)+((ba(eb,Ea)|0)+(xa<<3&8))|0;if(Y){gb=(c[K>>2]|0)+((ba(Ba>>1,va)|0)+(La>>1))|0;cf[c[(c[O>>2]|0)+16+(wa<<2)>>2]&1023](fb,gb,va,8);gb=(c[Z>>2]|0)+((ba(db>>1,va)|0)+(Ha>>1))|0;cf[c[(c[A>>2]|0)+16+(Ma<<2)>>2]&1023](fb,gb,va,8)}else{gb=(c[K>>2]|0)+((ba(Ba>>2,va)|0)+(La>>2))|0;Xe[c[(c[h>>2]|0)+64+(wa<<2)>>2]&4095](fb,gb,va);gb=(c[Z>>2]|0)+((ba(db>>2,va)|0)+(Ha>>2))|0;Xe[c[(c[_>>2]|0)+64+(Ma<<2)>>2]&4095](fb,gb,va)}xa=xa+1|0;if((xa|0)>=4){break d}}}if(za){xa=0;do{gb=(c[a+12160+(xa<<3)>>2]|0)+Da|0;fb=c[a+12160+(xa<<3)+4>>2]|0;Ma=gb-(c[a+12128+(xa<<3)>>2]|0)|0;Ha=xa>>1;wa=((ba(c[a+12128+(xa<<3)+4>>2]|0,Aa)|0)/(Ga|0)|0)+(Ha<<X)|0;La=((fb&V)<<B)+(gb&V)|0;Ba=((wa&V)<<B)+(Ma&V)|0;hb=(c[l>>2]|0)+((xa<<3&8)+(ba(Ha,Ea)|0))|0;if(Y){Ha=(c[K>>2]|0)+((ba(fb>>1,va)|0)+(gb>>1))|0;cf[c[(c[O>>2]|0)+16+(La<<2)>>2]&1023](hb,Ha,va,8);Ha=(c[Z>>2]|0)+((ba(wa>>1,va)|0)+(Ma>>1))|0;cf[c[(c[A>>2]|0)+16+(Ba<<2)>>2]&1023](hb,Ha,va,8)}else{Ha=(c[K>>2]|0)+((ba(fb>>2,va)|0)+(gb>>2))|0;Xe[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095](hb,Ha,va);Ha=(c[Z>>2]|0)+((ba(wa>>2,va)|0)+(Ma>>2))|0;Xe[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095](hb,Ha,va)}xa=xa+1|0;}while((xa|0)<4)}else{xa=0;do{Aa=(c[a+12160+(xa<<3)>>2]|0)+Da|0;za=(c[a+12160+(xa<<3)+4>>2]|0)+_a|0;Ha=Aa-(c[a+12128+(xa<<3)>>2]|0)|0;hb=za-(c[a+12128+(xa<<3)+4>>2]|0)|0;Ba=((za&V)<<B)+(Aa&V)|0;Ma=((hb&V)<<B)+(Ha&V)|0;wa=(c[l>>2]|0)+((xa<<3&8)+(ba(xa>>1,Ea)|0))|0;if(Y){La=(c[K>>2]|0)+((ba(za>>1,va)|0)+(Aa>>1))|0;cf[c[(c[O>>2]|0)+16+(Ba<<2)>>2]&1023](wa,La,va,8);La=(c[Z>>2]|0)+((ba(hb>>1,va)|0)+(Ha>>1))|0;cf[c[(c[A>>2]|0)+16+(Ma<<2)>>2]&1023](wa,La,va,8)}else{La=(c[K>>2]|0)+((ba(za>>2,va)|0)+(Aa>>2))|0;Xe[c[(c[h>>2]|0)+64+(Ba<<2)>>2]&4095](wa,La,va);La=(c[Z>>2]|0)+((ba(hb>>2,va)|0)+(Ha>>2))|0;Xe[c[(c[_>>2]|0)+64+(Ma<<2)>>2]&4095](wa,La,va)}xa=xa+1|0;}while((xa|0)<4)}}else{xa=(c[$>>2]|0)+Da|0;Ea=(c[aa>>2]|0)+_a|0;La=c[ca>>2]|0;if((Da|0)==0){ib=(ba(La,Na-Ga|0)|0)/(Ga|0)|0}else{ib=xa-La|0}La=c[da>>2]|0;if((_a|0)==0){jb=(ba(La,Na-Ga|0)|0)/(Ga|0)|0}else{jb=Ea-La|0}La=((Ea&V)<<B)+(xa&V)|0;wa=((jb&V)<<B)+(ib&V)|0;if(Y){Ma=(c[K>>2]|0)+((ba(Ea>>1,va)|0)+(xa>>1))|0;cf[c[(c[O>>2]|0)+(La<<2)>>2]&1023](c[l>>2]|0,Ma,va,16);Ma=(c[Z>>2]|0)+((ba(jb>>1,va)|0)+(ib>>1))|0;cf[c[(c[A>>2]|0)+(wa<<2)>>2]&1023](c[l>>2]|0,Ma,va,16);break}else{Ma=(ba(Ea>>2,va)|0)+(xa>>2)|0;Xe[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+Ma|0,va);xa=Ma+8|0;Xe[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+xa|0,va);Ea=va<<3;Xe[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[K>>2]|0)+(Ma+Ea)|0,va);Ma=Ea+8|0;Xe[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095]((c[l>>2]|0)+Ma|0,(c[K>>2]|0)+(xa+Ea)|0,va);xa=(ba(jb>>2,va)|0)+(ib>>2)|0;Xe[c[(c[_>>2]|0)+64+(wa<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+xa|0,va);La=xa+8|0;Xe[c[(c[_>>2]|0)+64+(wa<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+La|0,va);Xe[c[(c[_>>2]|0)+64+(wa<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[Z>>2]|0)+(xa+Ea)|0,va);Xe[c[(c[_>>2]|0)+64+(wa<<2)>>2]&4095]((c[l>>2]|0)+Ma|0,(c[Z>>2]|0)+(La+Ea)|0,va);break}}}while(0);cb=Pe[D&255](M,c[l>>2]|0,c[L>>2]|0,va,16)|0}}while(0);c[Ca>>2]=ua;c[n+(Fa<<2)>>2]=cb;va=(ba((d[w+((na<<B)-y)|0]|0)+(d[w+((oa<<B)-x)|0]|0)|0,i)|0)+cb|0;if((va|0)>=(Wa|0)){bb=Wa;break}c[b>>2]=oa;c[G>>2]=na;bb=va}}while(0);do{if(ha){oa=ka+ia|0;Fa=(oa|0)>(t|0)?t:oa;oa=(p|0)>(Fa|0)?p:Fa;Fa=oa+C|0;ua=Fa+pa|0;Ca=qa+oa&63;ra=z+(Ca<<2)|0;do{if((c[ra>>2]|0)==(ua|0)){kb=bb}else{va=c[I>>2]|0;do{if(H){Ga=c[J>>2]|0;Na=(c[K>>2]|0)+((ba(va,ma)|0)+oa)|0;_a=Pe[D&255](M,c[L>>2]|0,Na,va,k)|0;if(N){lb=_a;break}Na=ma<<1&2|oa&1;Da=c[l>>2]|0;Ea=va<<4;La=Da+Ea|0;Ma=(ba(Ga,ma>>1)|0)+(oa>>1)|0;cf[c[(c[O>>2]|0)+(E<<4)+(Na<<2)>>2]&1023](La,(c[P>>2]|0)+Ma|0,Ga,Q);wa=Da+(Ea|8)|0;cf[c[(c[O>>2]|0)+(E<<4)+(Na<<2)>>2]&1023](wa,(c[R>>2]|0)+Ma|0,Ga,Q);Ma=(Pe[j&255](M,La,c[S>>2]|0,Ga,Q)|0)+_a|0;lb=Ma+(Pe[j&255](M,wa,c[T>>2]|0,Ga,Q)|0)|0}else{Ga=oa<<B;wa=ma<<B;if((c[o>>2]|0)>(oa|0)){lb=536870912;break}if((Ga|0)>(c[s>>2]<<B|0)){lb=536870912;break}if((c[q>>2]|0)>(ma|0)){lb=536870912;break}if((wa|0)>(c[u>>2]<<B|0)){lb=536870912;break}Ma=e[g>>1]|0;_a=e[U>>1]|0;e:do{if((c[W>>2]|0)==1){La=_a-Ma|0;Na=(wa|0)==0;Ea=va<<3;if((Ga|0)==0){Da=0;while(1){xa=c[a+12160+(Da<<3)>>2]|0;Ha=(c[a+12160+(Da<<3)+4>>2]|0)+wa|0;hb=((ba(c[a+12128+(Da<<3)>>2]|0,La)|0)/(Ma|0)|0)+((Da&1)<<X)|0;Ba=c[a+12128+(Da<<3)+4>>2]|0;if(Na){Aa=Da>>1;mb=((ba(Ba,La)|0)/(Ma|0)|0)+(Aa<<X)|0;nb=Aa}else{mb=Ha-Ba|0;nb=Da>>1}Ba=((Ha&V)<<B)+(xa&V)|0;Aa=((mb&V)<<B)+(hb&V)|0;za=(c[l>>2]|0)+((ba(nb,Ea)|0)+(Da<<3&8))|0;if(Y){gb=(c[K>>2]|0)+((ba(Ha>>1,va)|0)+(xa>>1))|0;cf[c[(c[O>>2]|0)+16+(Ba<<2)>>2]&1023](za,gb,va,8);gb=(c[Z>>2]|0)+((ba(mb>>1,va)|0)+(hb>>1))|0;cf[c[(c[A>>2]|0)+16+(Aa<<2)>>2]&1023](za,gb,va,8)}else{gb=(c[K>>2]|0)+((ba(Ha>>2,va)|0)+(xa>>2))|0;Xe[c[(c[h>>2]|0)+64+(Ba<<2)>>2]&4095](za,gb,va);gb=(c[Z>>2]|0)+((ba(mb>>2,va)|0)+(hb>>2))|0;Xe[c[(c[_>>2]|0)+64+(Aa<<2)>>2]&4095](za,gb,va)}Da=Da+1|0;if((Da|0)>=4){break e}}}if(Na){Da=0;do{gb=(c[a+12160+(Da<<3)>>2]|0)+Ga|0;za=c[a+12160+(Da<<3)+4>>2]|0;Aa=gb-(c[a+12128+(Da<<3)>>2]|0)|0;hb=Da>>1;Ba=((ba(c[a+12128+(Da<<3)+4>>2]|0,La)|0)/(Ma|0)|0)+(hb<<X)|0;xa=((za&V)<<B)+(gb&V)|0;Ha=((Ba&V)<<B)+(Aa&V)|0;fb=(c[l>>2]|0)+((Da<<3&8)+(ba(hb,Ea)|0))|0;if(Y){hb=(c[K>>2]|0)+((ba(za>>1,va)|0)+(gb>>1))|0;cf[c[(c[O>>2]|0)+16+(xa<<2)>>2]&1023](fb,hb,va,8);hb=(c[Z>>2]|0)+((ba(Ba>>1,va)|0)+(Aa>>1))|0;cf[c[(c[A>>2]|0)+16+(Ha<<2)>>2]&1023](fb,hb,va,8)}else{hb=(c[K>>2]|0)+((ba(za>>2,va)|0)+(gb>>2))|0;Xe[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095](fb,hb,va);hb=(c[Z>>2]|0)+((ba(Ba>>2,va)|0)+(Aa>>2))|0;Xe[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095](fb,hb,va)}Da=Da+1|0;}while((Da|0)<4)}else{Da=0;do{La=(c[a+12160+(Da<<3)>>2]|0)+Ga|0;Na=(c[a+12160+(Da<<3)+4>>2]|0)+wa|0;hb=La-(c[a+12128+(Da<<3)>>2]|0)|0;fb=Na-(c[a+12128+(Da<<3)+4>>2]|0)|0;Ha=((Na&V)<<B)+(La&V)|0;Aa=((fb&V)<<B)+(hb&V)|0;Ba=(c[l>>2]|0)+((Da<<3&8)+(ba(Da>>1,Ea)|0))|0;if(Y){xa=(c[K>>2]|0)+((ba(Na>>1,va)|0)+(La>>1))|0;cf[c[(c[O>>2]|0)+16+(Ha<<2)>>2]&1023](Ba,xa,va,8);xa=(c[Z>>2]|0)+((ba(fb>>1,va)|0)+(hb>>1))|0;cf[c[(c[A>>2]|0)+16+(Aa<<2)>>2]&1023](Ba,xa,va,8)}else{xa=(c[K>>2]|0)+((ba(Na>>2,va)|0)+(La>>2))|0;Xe[c[(c[h>>2]|0)+64+(Ha<<2)>>2]&4095](Ba,xa,va);xa=(c[Z>>2]|0)+((ba(fb>>2,va)|0)+(hb>>2))|0;Xe[c[(c[_>>2]|0)+64+(Aa<<2)>>2]&4095](Ba,xa,va)}Da=Da+1|0;}while((Da|0)<4)}}else{Da=(c[$>>2]|0)+Ga|0;Ea=(c[aa>>2]|0)+wa|0;xa=c[ca>>2]|0;if((Ga|0)==0){ob=(ba(xa,_a-Ma|0)|0)/(Ma|0)|0}else{ob=Da-xa|0}xa=c[da>>2]|0;if((wa|0)==0){pb=(ba(xa,_a-Ma|0)|0)/(Ma|0)|0}else{pb=Ea-xa|0}xa=((Ea&V)<<B)+(Da&V)|0;Ba=((pb&V)<<B)+(ob&V)|0;if(Y){Aa=(c[K>>2]|0)+((ba(Ea>>1,va)|0)+(Da>>1))|0;cf[c[(c[O>>2]|0)+(xa<<2)>>2]&1023](c[l>>2]|0,Aa,va,16);Aa=(c[Z>>2]|0)+((ba(pb>>1,va)|0)+(ob>>1))|0;cf[c[(c[A>>2]|0)+(Ba<<2)>>2]&1023](c[l>>2]|0,Aa,va,16);break}else{Aa=(ba(Ea>>2,va)|0)+(Da>>2)|0;Xe[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+Aa|0,va);Da=Aa+8|0;Xe[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+Da|0,va);Ea=va<<3;Xe[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[K>>2]|0)+(Aa+Ea)|0,va);Aa=Ea+8|0;Xe[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[K>>2]|0)+(Da+Ea)|0,va);Da=(ba(pb>>2,va)|0)+(ob>>2)|0;Xe[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+Da|0,va);xa=Da+8|0;Xe[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+xa|0,va);Xe[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[Z>>2]|0)+(Da+Ea)|0,va);Xe[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[Z>>2]|0)+(xa+Ea)|0,va);break}}}while(0);lb=Pe[D&255](M,c[l>>2]|0,c[L>>2]|0,va,16)|0}}while(0);c[ra>>2]=ua;c[n+(Ca<<2)>>2]=lb;va=(ba((d[w+((ma<<B)-y)|0]|0)+(d[w+((oa<<B)-x)|0]|0)|0,i)|0)+lb|0;if((va|0)>=(bb|0)){kb=bb;break}c[b>>2]=oa;c[G>>2]=ma;kb=va}}while(0);Ca=Fa+sa|0;ua=Ia+oa&63;ra=z+(ua<<2)|0;if((c[ra>>2]|0)==(Ca|0)){qb=kb;break}va=c[I>>2]|0;do{if(H){Ma=c[J>>2]|0;_a=(c[K>>2]|0)+((ba(va,na)|0)+oa)|0;wa=Pe[D&255](M,c[L>>2]|0,_a,va,k)|0;if(N){rb=wa;break}_a=na<<1&2|oa&1;Ga=c[l>>2]|0;Ea=va<<4;xa=Ga+Ea|0;Aa=(ba(Ma,na>>1)|0)+(oa>>1)|0;cf[c[(c[O>>2]|0)+(E<<4)+(_a<<2)>>2]&1023](xa,(c[P>>2]|0)+Aa|0,Ma,Q);Ba=Ga+(Ea|8)|0;cf[c[(c[O>>2]|0)+(E<<4)+(_a<<2)>>2]&1023](Ba,(c[R>>2]|0)+Aa|0,Ma,Q);Aa=(Pe[j&255](M,xa,c[S>>2]|0,Ma,Q)|0)+wa|0;rb=Aa+(Pe[j&255](M,Ba,c[T>>2]|0,Ma,Q)|0)|0}else{Ma=oa<<B;Ba=na<<B;if((c[o>>2]|0)>(oa|0)){rb=536870912;break}if((Ma|0)>(c[s>>2]<<B|0)){rb=536870912;break}if((c[q>>2]|0)>(na|0)){rb=536870912;break}if((Ba|0)>(c[u>>2]<<B|0)){rb=536870912;break}Aa=e[g>>1]|0;wa=e[U>>1]|0;f:do{if((c[W>>2]|0)==1){xa=wa-Aa|0;_a=(Ba|0)==0;Ea=va<<3;if((Ma|0)==0){Ga=0;while(1){Da=c[a+12160+(Ga<<3)>>2]|0;hb=(c[a+12160+(Ga<<3)+4>>2]|0)+Ba|0;fb=((ba(c[a+12128+(Ga<<3)>>2]|0,xa)|0)/(Aa|0)|0)+((Ga&1)<<X)|0;Ha=c[a+12128+(Ga<<3)+4>>2]|0;if(_a){La=Ga>>1;sb=((ba(Ha,xa)|0)/(Aa|0)|0)+(La<<X)|0;tb=La}else{sb=hb-Ha|0;tb=Ga>>1}Ha=((hb&V)<<B)+(Da&V)|0;La=((sb&V)<<B)+(fb&V)|0;Na=(c[l>>2]|0)+((ba(tb,Ea)|0)+(Ga<<3&8))|0;if(Y){gb=(c[K>>2]|0)+((ba(hb>>1,va)|0)+(Da>>1))|0;cf[c[(c[O>>2]|0)+16+(Ha<<2)>>2]&1023](Na,gb,va,8);gb=(c[Z>>2]|0)+((ba(sb>>1,va)|0)+(fb>>1))|0;cf[c[(c[A>>2]|0)+16+(La<<2)>>2]&1023](Na,gb,va,8)}else{gb=(c[K>>2]|0)+((ba(hb>>2,va)|0)+(Da>>2))|0;Xe[c[(c[h>>2]|0)+64+(Ha<<2)>>2]&4095](Na,gb,va);gb=(c[Z>>2]|0)+((ba(sb>>2,va)|0)+(fb>>2))|0;Xe[c[(c[_>>2]|0)+64+(La<<2)>>2]&4095](Na,gb,va)}Ga=Ga+1|0;if((Ga|0)>=4){break f}}}if(_a){Ga=0;do{gb=(c[a+12160+(Ga<<3)>>2]|0)+Ma|0;Na=c[a+12160+(Ga<<3)+4>>2]|0;La=gb-(c[a+12128+(Ga<<3)>>2]|0)|0;fb=Ga>>1;Ha=((ba(c[a+12128+(Ga<<3)+4>>2]|0,xa)|0)/(Aa|0)|0)+(fb<<X)|0;Da=((Na&V)<<B)+(gb&V)|0;hb=((Ha&V)<<B)+(La&V)|0;za=(c[l>>2]|0)+((Ga<<3&8)+(ba(fb,Ea)|0))|0;if(Y){fb=(c[K>>2]|0)+((ba(Na>>1,va)|0)+(gb>>1))|0;cf[c[(c[O>>2]|0)+16+(Da<<2)>>2]&1023](za,fb,va,8);fb=(c[Z>>2]|0)+((ba(Ha>>1,va)|0)+(La>>1))|0;cf[c[(c[A>>2]|0)+16+(hb<<2)>>2]&1023](za,fb,va,8)}else{fb=(c[K>>2]|0)+((ba(Na>>2,va)|0)+(gb>>2))|0;Xe[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095](za,fb,va);fb=(c[Z>>2]|0)+((ba(Ha>>2,va)|0)+(La>>2))|0;Xe[c[(c[_>>2]|0)+64+(hb<<2)>>2]&4095](za,fb,va)}Ga=Ga+1|0;}while((Ga|0)<4)}else{Ga=0;do{xa=(c[a+12160+(Ga<<3)>>2]|0)+Ma|0;_a=(c[a+12160+(Ga<<3)+4>>2]|0)+Ba|0;fb=xa-(c[a+12128+(Ga<<3)>>2]|0)|0;za=_a-(c[a+12128+(Ga<<3)+4>>2]|0)|0;hb=((_a&V)<<B)+(xa&V)|0;La=((za&V)<<B)+(fb&V)|0;Ha=(c[l>>2]|0)+((Ga<<3&8)+(ba(Ga>>1,Ea)|0))|0;if(Y){Da=(c[K>>2]|0)+((ba(_a>>1,va)|0)+(xa>>1))|0;cf[c[(c[O>>2]|0)+16+(hb<<2)>>2]&1023](Ha,Da,va,8);Da=(c[Z>>2]|0)+((ba(za>>1,va)|0)+(fb>>1))|0;cf[c[(c[A>>2]|0)+16+(La<<2)>>2]&1023](Ha,Da,va,8)}else{Da=(c[K>>2]|0)+((ba(_a>>2,va)|0)+(xa>>2))|0;Xe[c[(c[h>>2]|0)+64+(hb<<2)>>2]&4095](Ha,Da,va);Da=(c[Z>>2]|0)+((ba(za>>2,va)|0)+(fb>>2))|0;Xe[c[(c[_>>2]|0)+64+(La<<2)>>2]&4095](Ha,Da,va)}Ga=Ga+1|0;}while((Ga|0)<4)}}else{Ga=(c[$>>2]|0)+Ma|0;Ea=(c[aa>>2]|0)+Ba|0;Da=c[ca>>2]|0;if((Ma|0)==0){ub=(ba(Da,wa-Aa|0)|0)/(Aa|0)|0}else{ub=Ga-Da|0}Da=c[da>>2]|0;if((Ba|0)==0){vb=(ba(Da,wa-Aa|0)|0)/(Aa|0)|0}else{vb=Ea-Da|0}Da=((Ea&V)<<B)+(Ga&V)|0;Ha=((vb&V)<<B)+(ub&V)|0;if(Y){La=(c[K>>2]|0)+((ba(Ea>>1,va)|0)+(Ga>>1))|0;cf[c[(c[O>>2]|0)+(Da<<2)>>2]&1023](c[l>>2]|0,La,va,16);La=(c[Z>>2]|0)+((ba(vb>>1,va)|0)+(ub>>1))|0;cf[c[(c[A>>2]|0)+(Ha<<2)>>2]&1023](c[l>>2]|0,La,va,16);break}else{La=(ba(Ea>>2,va)|0)+(Ga>>2)|0;Xe[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+La|0,va);Ga=La+8|0;Xe[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+Ga|0,va);Ea=va<<3;Xe[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[K>>2]|0)+(La+Ea)|0,va);La=Ea+8|0;Xe[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095]((c[l>>2]|0)+La|0,(c[K>>2]|0)+(Ga+Ea)|0,va);Ga=(ba(vb>>2,va)|0)+(ub>>2)|0;Xe[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+Ga|0,va);Da=Ga+8|0;Xe[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+Da|0,va);Xe[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[Z>>2]|0)+(Ga+Ea)|0,va);Xe[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+La|0,(c[Z>>2]|0)+(Da+Ea)|0,va);break}}}while(0);rb=Pe[D&255](M,c[l>>2]|0,c[L>>2]|0,va,16)|0}}while(0);c[ra>>2]=Ca;c[n+(ua<<2)>>2]=rb;va=(ba((d[w+((na<<B)-y)|0]|0)+(d[w+((oa<<B)-x)|0]|0)|0,i)|0)+rb|0;if((va|0)>=(kb|0)){qb=kb;break}c[b>>2]=oa;c[G>>2]=na;qb=va}else{qb=bb}}while(0);na=c[b>>2]|0;if((na|0)!=(ka|0)){ja=qb;ka=na;continue}if((c[G>>2]|0)==(la|0)){break}else{ja=qb;ka=na}}ja=ea?fa-1|0:ga;if((ja|0)==0){F=qb;break}else{fa=ja;m=qb;f=ka}}return F|0}function Imb(a,b){a=a|0;b=b|0;return(c[a>>2]|0)-(c[b>>2]|0)|0}function Jmb(a,f,h,j,k,l,m,n){a=a|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0;o=i;i=i+19216|0;p=o|0;c[(o|0)>>2]=0;c[(o|0)+4>>2]=0;q=c[a+12232>>2]|0;r=c[a+124>>2]|0;s=(ba(c[(a+12480|0)>>2]|0,r)|0)+(c[a+12476>>2]|0)|0;t=c[(a+12220|0)>>2]|0;u=c[(a+12264|0)>>2]|0;v=c[(a+12272|0)>>2]|0;x=c[(a+12268|0)>>2]|0;y=c[(a+12276|0)>>2]|0;z=c[(a+12464|0)>>2]|0;A=c[(a+12280|0)>>2]|0;B=c[(a+12284|0)>>2]|0;C=c[a+12244>>2]|0;F=c[(a+12216|0)>>2]|0;G=(C&1)+1|0;H=c[(a+10472|0)>>2]|0;I=c[(a+10476|0)>>2]|0;J=(c[(a+12224|0)>>2]|0)+4194304|0;c[(a+12224|0)>>2]=J;if((J|0)==0){c[(a+12224|0)>>2]=4194304;TGb(F|0,0,256)|0;K=c[(a+12224|0)>>2]|0}else{K=J}do{J=1;if(J){J=0;if((c[a+14084>>2]|0)==0){L=c[(j+76|0)>>2]>>G;M=c[(j+72|0)>>2]>>G;N=M+K+(L<<11)|0;do{if((c[(F+(((L<<3)+M&63)<<2)|0)>>2]|0)==(N|0)){O=1e6;P=0;Q=0}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;S=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ba(R,L)|0)+M)|0;U=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){V=U;break}T=c[a+12208>>2]|0;W=(ba(S,L>>1)|0)+(M>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&1023](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+W|0,S,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&1023](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+W|0,S,4);W=(Pe[I&255](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,S,4)|0)+U|0;V=W+(Pe[I&255](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,S,4)|0)|0}else{S=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(M|0)){V=536870912;break}if((M<<G|0)>(c[(a+12268|0)>>2]<<G|0)){V=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){V=536870912;break}if((L<<G|0)>(c[(a+12276|0)>>2]<<G|0)){V=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;W=(C&1)<<1|1;a:do{if((c[a+11740>>2]|0)==1){if((M<<G|0)==0){U=0;while(1){X=c[a+12160+(U<<3)>>2]|0;Y=(c[a+12160+(U<<3)+4>>2]|0)+(L<<G)|0;Z=((ba(c[a+12128+(U<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((U&1)<<(C&1|4))|0;_=c[a+12128+(U<<3)+4>>2]|0;if((L<<G|0)==0){$=U>>1;aa=((ba(_,T-R|0)|0)/(R|0)|0)+($<<(C&1|4))|0;ca=$}else{aa=Y-_|0;ca=U>>1}_=((aa&W)<<G)+(Z&W)|0;$=(c[(a+12208|0)>>2]|0)+((ba(ca,S<<3)|0)+(U<<3&8))|0;if((C&1|0)==0){da=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,S)|0)+(X>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&W)<<G)+(X&W)|0)<<2)>>2]&1023]($,da,S,8);da=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(aa>>1,S)|0)+(Z>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(_<<2)>>2]&1023]($,da,S,8)}else{da=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>2,S)|0)+(X>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&W)<<G)+(X&W)|0)<<2)>>2]&4095]($,da,S);da=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(aa>>2,S)|0)+(Z>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]($,da,S)}U=U+1|0;if((U|0)>=4){break a}}}if((L<<G|0)==0){U=0;do{da=(c[a+12160+(U<<3)>>2]|0)+(M<<G)|0;$=c[a+12160+(U<<3)+4>>2]|0;_=da-(c[a+12128+(U<<3)>>2]|0)|0;Z=U>>1;X=((ba(c[a+12128+(U<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(Z<<(C&1|4))|0;Y=(c[(a+12208|0)>>2]|0)+((U<<3&8)+(ba(Z,S<<3)|0))|0;if((C&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba($>>1,S)|0)+(da>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+(((($&W)<<G)+(da&W)|0)<<2)>>2]&1023](Y,Z,S,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>1,S)|0)+(_>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((X&W)<<G)+(_&W)|0)<<2)>>2]&1023](Y,Z,S,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba($>>2,S)|0)+(da>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(da&W)|0)<<2)>>2]&4095](Y,Z,S);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>2,S)|0)+(_>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((X&W)<<G)+(_&W)|0)<<2)>>2]&4095](Y,Z,S)}U=U+1|0;}while((U|0)<4)}else{U=0;do{Z=(c[a+12160+(U<<3)>>2]|0)+(M<<G)|0;Y=(c[a+12160+(U<<3)+4>>2]|0)+(L<<G)|0;_=Z-(c[a+12128+(U<<3)>>2]|0)|0;X=Y-(c[a+12128+(U<<3)+4>>2]|0)|0;da=(c[(a+12208|0)>>2]|0)+((U<<3&8)+(ba(U>>1,S<<3)|0))|0;if((C&1|0)==0){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,S)|0)+(Z>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&W)<<G)+(Z&W)|0)<<2)>>2]&1023](da,$,S,8);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>1,S)|0)+(_>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((X&W)<<G)+(_&W)|0)<<2)>>2]&1023](da,$,S,8)}else{$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>2,S)|0)+(Z>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&W)<<G)+(Z&W)|0)<<2)>>2]&4095](da,$,S);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>2,S)|0)+(_>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((X&W)<<G)+(_&W)|0)<<2)>>2]&4095](da,$,S)}U=U+1|0;}while((U|0)<4)}}else{U=(c[a+12160>>2]|0)+(M<<G)|0;$=(c[a+12164>>2]|0)+(L<<G)|0;da=c[a+12128>>2]|0;if((M<<G|0)==0){ea=(ba(da,T-R|0)|0)/(R|0)|0}else{ea=U-da|0}da=c[a+12132>>2]|0;if((L<<G|0)==0){fa=(ba(da,T-R|0)|0)/(R|0)|0}else{fa=$-da|0}da=((fa&W)<<G)+(ea&W)|0;if((C&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba($>>1,S)|0)+(U>>1))|0;cf[c[(c[a+12444>>2]|0)+(((($&W)<<G)+(U&W)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,_,S,16);_=(c[a+12352+(l<<4)+32>>2]|0)+((ba(fa>>1,S)|0)+(ea>>1))|0;cf[c[(c[a+12448>>2]|0)+(da<<2)>>2]&1023](c[(a+12208|0)>>2]|0,_,S,16);break}else{_=(ba($>>2,S)|0)+(U>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(U&W)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+_|0,S);Xe[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(U&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_+8|0)|0,S);Xe[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(U&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(S<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_+(S<<3))|0,S);Xe[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(U&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((S<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((_+8|0)+(S<<3))|0,S);_=(ba(fa>>2,S)|0)+(ea>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(da<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+_|0,S);Xe[c[(c[(a+12456|0)>>2]|0)+64+(da<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_+8|0)|0,S);Xe[c[(c[(a+12456|0)>>2]|0)+64+(da<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(S<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_+(S<<3))|0,S);Xe[c[(c[(a+12456|0)>>2]|0)+64+(da<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((S<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((_+8|0)+(S<<3))|0,S);break}}}while(0);V=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,S,16)|0}}while(0);c[(F+(((L<<3)+M&63)<<2)|0)>>2]=N;c[t+(((L<<3)+M&63)<<2)>>2]=V;W=c[(j+72|0)>>2]>>G;R=c[(j+76|0)>>2]>>G;T=(ba((d[z+((R<<G)-B)|0]|0)+(d[z+((W<<G)-A)|0]|0)|0,q)|0)+V|0;if((T|0)>=1e6){O=1e6;P=0;Q=0;break}c[(o|0)>>2]=W;c[p+4>>2]=R;O=T;P=W;Q=R}}while(0);M=c[(j+36|0)>>2]>>G;L=c[(j+32|0)>>2]>>G;N=L+K+(M<<11)|0;do{if((c[(F+(((M<<3)+L&63)<<2)|0)>>2]|0)==(N|0)){ga=O;ha=P;ia=Q}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;W=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ba(R,M)|0)+L)|0;_=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){ja=_;break}T=c[a+12208>>2]|0;da=(ba(W,M>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((M<<1&2|L&1)<<2)>>2]&1023](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+da|0,W,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((M<<1&2|L&1)<<2)>>2]&1023](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+da|0,W,4);da=(Pe[I&255](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,W,4)|0)+_|0;ja=da+(Pe[I&255](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,W,4)|0)|0}else{W=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){ja=536870912;break}if((L<<G|0)>(c[(a+12268|0)>>2]<<G|0)){ja=536870912;break}if((c[(a+12272|0)>>2]|0)>(M|0)){ja=536870912;break}if((M<<G|0)>(c[(a+12276|0)>>2]<<G|0)){ja=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;da=(C&1)<<1|1;b:do{if((c[a+11740>>2]|0)==1){if((L<<G|0)==0){_=0;while(1){U=c[a+12160+(_<<3)>>2]|0;$=(c[a+12160+(_<<3)+4>>2]|0)+(M<<G)|0;X=((ba(c[a+12128+(_<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((_&1)<<(C&1|4))|0;Z=c[a+12128+(_<<3)+4>>2]|0;if((M<<G|0)==0){Y=_>>1;ka=((ba(Z,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;la=Y}else{ka=$-Z|0;la=_>>1}Z=((ka&da)<<G)+(X&da)|0;Y=(c[(a+12208|0)>>2]|0)+((ba(la,W<<3)|0)+(_<<3&8))|0;if((C&1|0)==0){ma=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba($>>1,W)|0)+(U>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+(((($&da)<<G)+(U&da)|0)<<2)>>2]&1023](Y,ma,W,8);ma=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ka>>1,W)|0)+(X>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Z<<2)>>2]&1023](Y,ma,W,8)}else{ma=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba($>>2,W)|0)+(U>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+(((($&da)<<G)+(U&da)|0)<<2)>>2]&4095](Y,ma,W);ma=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ka>>2,W)|0)+(X>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095](Y,ma,W)}_=_+1|0;if((_|0)>=4){break b}}}if((M<<G|0)==0){_=0;do{ma=(c[a+12160+(_<<3)>>2]|0)+(L<<G)|0;Y=c[a+12160+(_<<3)+4>>2]|0;Z=ma-(c[a+12128+(_<<3)>>2]|0)|0;X=_>>1;U=((ba(c[a+12128+(_<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(X<<(C&1|4))|0;$=(c[(a+12208|0)>>2]|0)+((_<<3&8)+(ba(X,W<<3)|0))|0;if((C&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,W)|0)+(ma>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&da)<<G)+(ma&da)|0)<<2)>>2]&1023]($,X,W,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(U>>1,W)|0)+(Z>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((U&da)<<G)+(Z&da)|0)<<2)>>2]&1023]($,X,W,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>2,W)|0)+(ma>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(ma&da)|0)<<2)>>2]&4095]($,X,W);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(U>>2,W)|0)+(Z>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((U&da)<<G)+(Z&da)|0)<<2)>>2]&4095]($,X,W)}_=_+1|0;}while((_|0)<4)}else{_=0;do{X=(c[a+12160+(_<<3)>>2]|0)+(L<<G)|0;$=(c[a+12160+(_<<3)+4>>2]|0)+(M<<G)|0;Z=X-(c[a+12128+(_<<3)>>2]|0)|0;U=$-(c[a+12128+(_<<3)+4>>2]|0)|0;ma=(c[(a+12208|0)>>2]|0)+((_<<3&8)+(ba(_>>1,W<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba($>>1,W)|0)+(X>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+(((($&da)<<G)+(X&da)|0)<<2)>>2]&1023](ma,Y,W,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(U>>1,W)|0)+(Z>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((U&da)<<G)+(Z&da)|0)<<2)>>2]&1023](ma,Y,W,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba($>>2,W)|0)+(X>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+(((($&da)<<G)+(X&da)|0)<<2)>>2]&4095](ma,Y,W);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(U>>2,W)|0)+(Z>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((U&da)<<G)+(Z&da)|0)<<2)>>2]&4095](ma,Y,W)}_=_+1|0;}while((_|0)<4)}}else{_=(c[a+12160>>2]|0)+(L<<G)|0;Y=(c[a+12164>>2]|0)+(M<<G)|0;ma=c[a+12128>>2]|0;if((L<<G|0)==0){na=(ba(ma,T-R|0)|0)/(R|0)|0}else{na=_-ma|0}ma=c[a+12132>>2]|0;if((M<<G|0)==0){oa=(ba(ma,T-R|0)|0)/(R|0)|0}else{oa=Y-ma|0}ma=((oa&da)<<G)+(na&da)|0;if((C&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,W)|0)+(_>>1))|0;cf[c[(c[a+12444>>2]|0)+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Z,W,16);Z=(c[a+12352+(l<<4)+32>>2]|0)+((ba(oa>>1,W)|0)+(na>>1))|0;cf[c[(c[a+12448>>2]|0)+(ma<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Z,W,16);break}else{Z=(ba(Y>>2,W)|0)+(_>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Z|0,W);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Z+8|0)|0,W);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(W<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Z+(W<<3))|0,W);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((W<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Z+8|0)+(W<<3))|0,W);Z=(ba(oa>>2,W)|0)+(na>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Z|0,W);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Z+8|0)|0,W);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(W<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Z+(W<<3))|0,W);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((W<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Z+8|0)+(W<<3))|0,W);break}}}while(0);ja=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,W,16)|0}}while(0);c[(F+(((M<<3)+L&63)<<2)|0)>>2]=N;c[t+(((M<<3)+L&63)<<2)>>2]=ja;da=c[(j+32|0)>>2]>>G;R=c[(j+36|0)>>2]>>G;T=(ba((d[z+((R<<G)-B)|0]|0)+(d[z+((da<<G)-A)|0]|0)|0,q)|0)+ja|0;if((T|0)>=(O|0)){ga=O;ha=P;ia=Q;break}c[(o|0)>>2]=da;c[p+4>>2]=R;ga=T;ha=da;ia=R}}while(0);L=c[(j+12|0)>>2]>>G;M=c[(j+8|0)>>2]>>G;N=M+K+(L<<11)|0;do{if((c[(F+(((L<<3)+M&63)<<2)|0)>>2]|0)==(N|0)){pa=ga;qa=ha;ra=ia}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;da=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ba(R,L)|0)+M)|0;S=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){sa=S;break}T=c[a+12208>>2]|0;Z=(ba(da,L>>1)|0)+(M>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&1023](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+Z|0,da,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&1023](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+Z|0,da,4);Z=(Pe[I&255](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,da,4)|0)+S|0;sa=Z+(Pe[I&255](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,da,4)|0)|0}else{da=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(M|0)){sa=536870912;break}if((M<<G|0)>(c[(a+12268|0)>>2]<<G|0)){sa=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){sa=536870912;break}if((L<<G|0)>(c[(a+12276|0)>>2]<<G|0)){sa=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;Z=(C&1)<<1|1;c:do{if((c[a+11740>>2]|0)==1){if((M<<G|0)==0){S=0;while(1){ma=c[a+12160+(S<<3)>>2]|0;_=(c[a+12160+(S<<3)+4>>2]|0)+(L<<G)|0;Y=((ba(c[a+12128+(S<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((S&1)<<(C&1|4))|0;U=c[a+12128+(S<<3)+4>>2]|0;if((L<<G|0)==0){X=S>>1;ta=((ba(U,T-R|0)|0)/(R|0)|0)+(X<<(C&1|4))|0;ua=X}else{ta=_-U|0;ua=S>>1}U=((ta&Z)<<G)+(Y&Z)|0;X=(c[(a+12208|0)>>2]|0)+((ba(ua,da<<3)|0)+(S<<3&8))|0;if((C&1|0)==0){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>1,da)|0)+(ma>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((_&Z)<<G)+(ma&Z)|0)<<2)>>2]&1023](X,$,da,8);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ta>>1,da)|0)+(Y>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(U<<2)>>2]&1023](X,$,da,8)}else{$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>2,da)|0)+(ma>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_&Z)<<G)+(ma&Z)|0)<<2)>>2]&4095](X,$,da);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ta>>2,da)|0)+(Y>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](X,$,da)}S=S+1|0;if((S|0)>=4){break c}}}if((L<<G|0)==0){S=0;do{$=(c[a+12160+(S<<3)>>2]|0)+(M<<G)|0;X=c[a+12160+(S<<3)+4>>2]|0;U=$-(c[a+12128+(S<<3)>>2]|0)|0;Y=S>>1;ma=((ba(c[a+12128+(S<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;_=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ba(Y,da<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,da)|0)+($>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((X&Z)<<G)+($&Z)|0)<<2)>>2]&1023](_,Y,da,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ma>>1,da)|0)+(U>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ma&Z)<<G)+(U&Z)|0)<<2)>>2]&1023](_,Y,da,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>2,da)|0)+($>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+($&Z)|0)<<2)>>2]&4095](_,Y,da);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ma>>2,da)|0)+(U>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ma&Z)<<G)+(U&Z)|0)<<2)>>2]&4095](_,Y,da)}S=S+1|0;}while((S|0)<4)}else{S=0;do{Y=(c[a+12160+(S<<3)>>2]|0)+(M<<G)|0;_=(c[a+12160+(S<<3)+4>>2]|0)+(L<<G)|0;U=Y-(c[a+12128+(S<<3)>>2]|0)|0;ma=_-(c[a+12128+(S<<3)+4>>2]|0)|0;$=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ba(S>>1,da<<3)|0))|0;if((C&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>1,da)|0)+(Y>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((_&Z)<<G)+(Y&Z)|0)<<2)>>2]&1023]($,X,da,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ma>>1,da)|0)+(U>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ma&Z)<<G)+(U&Z)|0)<<2)>>2]&1023]($,X,da,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_>>2,da)|0)+(Y>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_&Z)<<G)+(Y&Z)|0)<<2)>>2]&4095]($,X,da);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ma>>2,da)|0)+(U>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ma&Z)<<G)+(U&Z)|0)<<2)>>2]&4095]($,X,da)}S=S+1|0;}while((S|0)<4)}}else{S=(c[a+12160>>2]|0)+(M<<G)|0;X=(c[a+12164>>2]|0)+(L<<G)|0;$=c[a+12128>>2]|0;if((M<<G|0)==0){va=(ba($,T-R|0)|0)/(R|0)|0}else{va=S-$|0}$=c[a+12132>>2]|0;if((L<<G|0)==0){wa=(ba($,T-R|0)|0)/(R|0)|0}else{wa=X-$|0}$=((wa&Z)<<G)+(va&Z)|0;if((C&1|0)==0){U=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,da)|0)+(S>>1))|0;cf[c[(c[a+12444>>2]|0)+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,U,da,16);U=(c[a+12352+(l<<4)+32>>2]|0)+((ba(wa>>1,da)|0)+(va>>1))|0;cf[c[(c[a+12448>>2]|0)+($<<2)>>2]&1023](c[(a+12208|0)>>2]|0,U,da,16);break}else{U=(ba(X>>2,da)|0)+(S>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+U|0,da);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(U+8|0)|0,da);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(da<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(U+(da<<3))|0,da);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((da<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((U+8|0)+(da<<3))|0,da);U=(ba(wa>>2,da)|0)+(va>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+U|0,da);Xe[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(U+8|0)|0,da);Xe[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(da<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(U+(da<<3))|0,da);Xe[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((da<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((U+8|0)+(da<<3))|0,da);break}}}while(0);sa=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,da,16)|0}}while(0);c[(F+(((L<<3)+M&63)<<2)|0)>>2]=N;c[t+(((L<<3)+M&63)<<2)>>2]=sa;Z=c[(j+8|0)>>2]>>G;R=c[(j+12|0)>>2]>>G;T=(ba((d[z+((R<<G)-B)|0]|0)+(d[z+((Z<<G)-A)|0]|0)|0,q)|0)+sa|0;if((T|0)>=(ga|0)){pa=ga;qa=ha;ra=ia;break}c[(o|0)>>2]=Z;c[p+4>>2]=R;pa=T;qa=Z;ra=R}}while(0);M=c[(j+20|0)>>2]>>G;L=c[(j+16|0)>>2]>>G;N=L+K+(M<<11)|0;do{if((c[(F+(((M<<3)+L&63)<<2)|0)>>2]|0)==(N|0)){xa=pa;ya=qa;za=ra}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;Z=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ba(R,M)|0)+L)|0;W=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){Aa=W;break}T=c[a+12208>>2]|0;U=(ba(Z,M>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((M<<1&2|L&1)<<2)>>2]&1023](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+U|0,Z,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((M<<1&2|L&1)<<2)>>2]&1023](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+U|0,Z,4);U=(Pe[I&255](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,Z,4)|0)+W|0;Aa=U+(Pe[I&255](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,Z,4)|0)|0}else{Z=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Aa=536870912;break}if((L<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Aa=536870912;break}if((c[(a+12272|0)>>2]|0)>(M|0)){Aa=536870912;break}if((M<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Aa=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;U=(C&1)<<1|1;d:do{if((c[a+11740>>2]|0)==1){if((L<<G|0)==0){W=0;while(1){$=c[a+12160+(W<<3)>>2]|0;S=(c[a+12160+(W<<3)+4>>2]|0)+(M<<G)|0;X=((ba(c[a+12128+(W<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((W&1)<<(C&1|4))|0;ma=c[a+12128+(W<<3)+4>>2]|0;if((M<<G|0)==0){Y=W>>1;Ba=((ba(ma,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;Ca=Y}else{Ba=S-ma|0;Ca=W>>1}ma=((Ba&U)<<G)+(X&U)|0;Y=(c[(a+12208|0)>>2]|0)+((ba(Ca,Z<<3)|0)+(W<<3&8))|0;if((C&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>1,Z)|0)+($>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((S&U)<<G)+($&U)|0)<<2)>>2]&1023](Y,_,Z,8);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ba>>1,Z)|0)+(X>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(ma<<2)>>2]&1023](Y,_,Z,8)}else{_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>2,Z)|0)+($>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((S&U)<<G)+($&U)|0)<<2)>>2]&4095](Y,_,Z);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ba>>2,Z)|0)+(X>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](Y,_,Z)}W=W+1|0;if((W|0)>=4){break d}}}if((M<<G|0)==0){W=0;do{_=(c[a+12160+(W<<3)>>2]|0)+(L<<G)|0;Y=c[a+12160+(W<<3)+4>>2]|0;ma=_-(c[a+12128+(W<<3)>>2]|0)|0;X=W>>1;$=((ba(c[a+12128+(W<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(X<<(C&1|4))|0;S=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ba(X,Z<<3)|0))|0;if((C&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,Z)|0)+(_>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&U)<<G)+(_&U)|0)<<2)>>2]&1023](S,X,Z,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>1,Z)|0)+(ma>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(((($&U)<<G)+(ma&U)|0)<<2)>>2]&1023](S,X,Z,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>2,Z)|0)+(_>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(_&U)|0)<<2)>>2]&4095](S,X,Z);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>2,Z)|0)+(ma>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(((($&U)<<G)+(ma&U)|0)<<2)>>2]&4095](S,X,Z)}W=W+1|0;}while((W|0)<4)}else{W=0;do{X=(c[a+12160+(W<<3)>>2]|0)+(L<<G)|0;S=(c[a+12160+(W<<3)+4>>2]|0)+(M<<G)|0;ma=X-(c[a+12128+(W<<3)>>2]|0)|0;$=S-(c[a+12128+(W<<3)+4>>2]|0)|0;_=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ba(W>>1,Z<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>1,Z)|0)+(X>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((S&U)<<G)+(X&U)|0)<<2)>>2]&1023](_,Y,Z,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>1,Z)|0)+(ma>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(((($&U)<<G)+(ma&U)|0)<<2)>>2]&1023](_,Y,Z,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>2,Z)|0)+(X>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((S&U)<<G)+(X&U)|0)<<2)>>2]&4095](_,Y,Z);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>2,Z)|0)+(ma>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(((($&U)<<G)+(ma&U)|0)<<2)>>2]&4095](_,Y,Z)}W=W+1|0;}while((W|0)<4)}}else{W=(c[a+12160>>2]|0)+(L<<G)|0;Y=(c[a+12164>>2]|0)+(M<<G)|0;_=c[a+12128>>2]|0;if((L<<G|0)==0){Da=(ba(_,T-R|0)|0)/(R|0)|0}else{Da=W-_|0}_=c[a+12132>>2]|0;if((M<<G|0)==0){Ea=(ba(_,T-R|0)|0)/(R|0)|0}else{Ea=Y-_|0}_=((Ea&U)<<G)+(Da&U)|0;if((C&1|0)==0){ma=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y>>1,Z)|0)+(W>>1))|0;cf[c[(c[a+12444>>2]|0)+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ma,Z,16);ma=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Ea>>1,Z)|0)+(Da>>1))|0;cf[c[(c[a+12448>>2]|0)+(_<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ma,Z,16);break}else{ma=(ba(Y>>2,Z)|0)+(W>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ma|0,Z);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ma+8|0)|0,Z);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Z<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ma+(Z<<3))|0,Z);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Z<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ma+8|0)+(Z<<3))|0,Z);ma=(ba(Ea>>2,Z)|0)+(Da>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ma|0,Z);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ma+8|0)|0,Z);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Z<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ma+(Z<<3))|0,Z);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Z<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ma+8|0)+(Z<<3))|0,Z);break}}}while(0);Aa=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,Z,16)|0}}while(0);c[(F+(((M<<3)+L&63)<<2)|0)>>2]=N;c[t+(((M<<3)+L&63)<<2)>>2]=Aa;U=c[(j+16|0)>>2]>>G;R=c[(j+20|0)>>2]>>G;T=(ba((d[z+((R<<G)-B)|0]|0)+(d[z+((U<<G)-A)|0]|0)|0,q)|0)+Aa|0;if((T|0)>=(pa|0)){xa=pa;ya=qa;za=ra;break}c[(o|0)>>2]=U;c[p+4>>2]=R;xa=T;ya=U;za=R}}while(0);L=c[(j+28|0)>>2]>>G;M=c[(j+24|0)>>2]>>G;N=M+K+(L<<11)|0;do{if((c[(F+(((L<<3)+M&63)<<2)|0)>>2]|0)==(N|0)){Fa=xa;Ga=ya;Ha=za}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;U=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ba(R,L)|0)+M)|0;da=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){Ia=da;break}T=c[a+12208>>2]|0;ma=(ba(U,L>>1)|0)+(M>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&1023](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ma|0,U,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&1023](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ma|0,U,4);ma=(Pe[I&255](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,U,4)|0)+da|0;Ia=ma+(Pe[I&255](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,U,4)|0)|0}else{U=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(M|0)){Ia=536870912;break}if((M<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Ia=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Ia=536870912;break}if((L<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Ia=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;ma=(C&1)<<1|1;e:do{if((c[a+11740>>2]|0)==1){if((M<<G|0)==0){da=0;while(1){_=c[a+12160+(da<<3)>>2]|0;W=(c[a+12160+(da<<3)+4>>2]|0)+(L<<G)|0;Y=((ba(c[a+12128+(da<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((da&1)<<(C&1|4))|0;$=c[a+12128+(da<<3)+4>>2]|0;if((L<<G|0)==0){X=da>>1;Ja=((ba($,T-R|0)|0)/(R|0)|0)+(X<<(C&1|4))|0;Ka=X}else{Ja=W-$|0;Ka=da>>1}$=((Ja&ma)<<G)+(Y&ma)|0;X=(c[(a+12208|0)>>2]|0)+((ba(Ka,U<<3)|0)+(da<<3&8))|0;if((C&1|0)==0){S=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,U)|0)+(_>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((W&ma)<<G)+(_&ma)|0)<<2)>>2]&1023](X,S,U,8);S=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ja>>1,U)|0)+(Y>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+($<<2)>>2]&1023](X,S,U,8)}else{S=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>2,U)|0)+(_>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(_&ma)|0)<<2)>>2]&4095](X,S,U);S=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ja>>2,U)|0)+(Y>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095](X,S,U)}da=da+1|0;if((da|0)>=4){break e}}}if((L<<G|0)==0){da=0;do{S=(c[a+12160+(da<<3)>>2]|0)+(M<<G)|0;X=c[a+12160+(da<<3)+4>>2]|0;$=S-(c[a+12128+(da<<3)>>2]|0)|0;Y=da>>1;_=((ba(c[a+12128+(da<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;W=(c[(a+12208|0)>>2]|0)+((da<<3&8)+(ba(Y,U<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,U)|0)+(S>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((X&ma)<<G)+(S&ma)|0)<<2)>>2]&1023](W,Y,U,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>1,U)|0)+($>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((_&ma)<<G)+($&ma)|0)<<2)>>2]&1023](W,Y,U,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>2,U)|0)+(S>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(S&ma)|0)<<2)>>2]&4095](W,Y,U);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>2,U)|0)+($>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((_&ma)<<G)+($&ma)|0)<<2)>>2]&4095](W,Y,U)}da=da+1|0;}while((da|0)<4)}else{da=0;do{Y=(c[a+12160+(da<<3)>>2]|0)+(M<<G)|0;W=(c[a+12160+(da<<3)+4>>2]|0)+(L<<G)|0;$=Y-(c[a+12128+(da<<3)>>2]|0)|0;_=W-(c[a+12128+(da<<3)+4>>2]|0)|0;S=(c[(a+12208|0)>>2]|0)+((da<<3&8)+(ba(da>>1,U<<3)|0))|0;if((C&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,U)|0)+(Y>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((W&ma)<<G)+(Y&ma)|0)<<2)>>2]&1023](S,X,U,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>1,U)|0)+($>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((_&ma)<<G)+($&ma)|0)<<2)>>2]&1023](S,X,U,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>2,U)|0)+(Y>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(Y&ma)|0)<<2)>>2]&4095](S,X,U);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>2,U)|0)+($>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((_&ma)<<G)+($&ma)|0)<<2)>>2]&4095](S,X,U)}da=da+1|0;}while((da|0)<4)}}else{da=(c[a+12160>>2]|0)+(M<<G)|0;X=(c[a+12164>>2]|0)+(L<<G)|0;S=c[a+12128>>2]|0;if((M<<G|0)==0){La=(ba(S,T-R|0)|0)/(R|0)|0}else{La=da-S|0}S=c[a+12132>>2]|0;if((L<<G|0)==0){Ma=(ba(S,T-R|0)|0)/(R|0)|0}else{Ma=X-S|0}S=((Ma&ma)<<G)+(La&ma)|0;if((C&1|0)==0){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,U)|0)+(da>>1))|0;cf[c[(c[a+12444>>2]|0)+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,$,U,16);$=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Ma>>1,U)|0)+(La>>1))|0;cf[c[(c[a+12448>>2]|0)+(S<<2)>>2]&1023](c[(a+12208|0)>>2]|0,$,U,16);break}else{$=(ba(X>>2,U)|0)+(da>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+$|0,U);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+8|0)|0,U);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(U<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+(U<<3))|0,U);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((U<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(($+8|0)+(U<<3))|0,U);$=(ba(Ma>>2,U)|0)+(La>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+$|0,U);Xe[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+8|0)|0,U);Xe[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(U<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+(U<<3))|0,U);Xe[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((U<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(($+8|0)+(U<<3))|0,U);break}}}while(0);Ia=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,U,16)|0}}while(0);c[(F+(((L<<3)+M&63)<<2)|0)>>2]=N;c[t+(((L<<3)+M&63)<<2)>>2]=Ia;ma=c[(j+24|0)>>2]>>G;R=c[(j+28|0)>>2]>>G;T=(ba((d[z+((R<<G)-B)|0]|0)+(d[z+((ma<<G)-A)|0]|0)|0,q)|0)+Ia|0;if((T|0)>=(xa|0)){Fa=xa;Ga=ya;Ha=za;break}c[(o|0)>>2]=ma;c[p+4>>2]=R;Fa=T;Ga=ma;Ha=R}}while(0);M=(ba(b[m+(s<<2)>>1]|0,n)|0)+32768>>16;L=(ba(b[m+(s<<2)+2>>1]|0,n)|0)+32768>>16;N=(M|0)>(x|0)?x:M;M=(u|0)>(N|0)?u:N;N=(L|0)>(y|0)?y:L;L=(v|0)>(N|0)?v:N;N=M+K+(L<<11)|0;if((c[(F+(((L<<3)+M&63)<<2)|0)>>2]|0)==(N|0)){Na=Fa;Oa=Ga;Pa=Ha;break}do{if((C&4|0)==0){R=c[a+12416>>2]|0;ma=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ba(R,L)|0)+M)|0;Z=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){Qa=Z;break}T=c[a+12208>>2]|0;$=(ba(ma,L>>1)|0)+(M>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&1023](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+$|0,ma,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&1023](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+$|0,ma,4);$=(Pe[I&255](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ma,4)|0)+Z|0;Qa=$+(Pe[I&255](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ma,4)|0)|0}else{ma=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(M|0)){Qa=536870912;break}if((M<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Qa=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Qa=536870912;break}if((L<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Qa=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;$=(C&1)<<1|1;f:do{if((c[a+11740>>2]|0)==1){if((M<<G|0)==0){Z=0;while(1){S=c[a+12160+(Z<<3)>>2]|0;da=(c[a+12160+(Z<<3)+4>>2]|0)+(L<<G)|0;X=((ba(c[a+12128+(Z<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((Z&1)<<(C&1|4))|0;_=c[a+12128+(Z<<3)+4>>2]|0;if((L<<G|0)==0){Y=Z>>1;Ra=((ba(_,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;Sa=Y}else{Ra=da-_|0;Sa=Z>>1}_=((Ra&$)<<G)+(X&$)|0;Y=(c[(a+12208|0)>>2]|0)+((ba(Sa,ma<<3)|0)+(Z<<3&8))|0;if((C&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(da>>1,ma)|0)+(S>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((da&$)<<G)+(S&$)|0)<<2)>>2]&1023](Y,W,ma,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ra>>1,ma)|0)+(X>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(_<<2)>>2]&1023](Y,W,ma,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(da>>2,ma)|0)+(S>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((da&$)<<G)+(S&$)|0)<<2)>>2]&4095](Y,W,ma);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ra>>2,ma)|0)+(X>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](Y,W,ma)}Z=Z+1|0;if((Z|0)>=4){break f}}}if((L<<G|0)==0){Z=0;do{U=(c[a+12160+(Z<<3)>>2]|0)+(M<<G)|0;W=c[a+12160+(Z<<3)+4>>2]|0;Y=U-(c[a+12128+(Z<<3)>>2]|0)|0;_=Z>>1;X=((ba(c[a+12128+(Z<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(_<<(C&1|4))|0;S=(c[(a+12208|0)>>2]|0)+((Z<<3&8)+(ba(_,ma<<3)|0))|0;if((C&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,ma)|0)+(U>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((W&$)<<G)+(U&$)|0)<<2)>>2]&1023](S,_,ma,8);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>1,ma)|0)+(Y>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((X&$)<<G)+(Y&$)|0)<<2)>>2]&1023](S,_,ma,8)}else{_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>2,ma)|0)+(U>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(U&$)|0)<<2)>>2]&4095](S,_,ma);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>2,ma)|0)+(Y>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((X&$)<<G)+(Y&$)|0)<<2)>>2]&4095](S,_,ma)}Z=Z+1|0;}while((Z|0)<4)}else{Z=0;do{_=(c[a+12160+(Z<<3)>>2]|0)+(M<<G)|0;S=(c[a+12160+(Z<<3)+4>>2]|0)+(L<<G)|0;Y=_-(c[a+12128+(Z<<3)>>2]|0)|0;X=S-(c[a+12128+(Z<<3)+4>>2]|0)|0;U=(c[(a+12208|0)>>2]|0)+((Z<<3&8)+(ba(Z>>1,ma<<3)|0))|0;if((C&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>1,ma)|0)+(_>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((S&$)<<G)+(_&$)|0)<<2)>>2]&1023](U,W,ma,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>1,ma)|0)+(Y>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((X&$)<<G)+(Y&$)|0)<<2)>>2]&1023](U,W,ma,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>2,ma)|0)+(_>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((S&$)<<G)+(_&$)|0)<<2)>>2]&4095](U,W,ma);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(X>>2,ma)|0)+(Y>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((X&$)<<G)+(Y&$)|0)<<2)>>2]&4095](U,W,ma)}Z=Z+1|0;}while((Z|0)<4)}}else{Z=(c[a+12160>>2]|0)+(M<<G)|0;W=(c[a+12164>>2]|0)+(L<<G)|0;U=c[a+12128>>2]|0;if((M<<G|0)==0){Ta=(ba(U,T-R|0)|0)/(R|0)|0}else{Ta=Z-U|0}U=c[a+12132>>2]|0;if((L<<G|0)==0){Ua=(ba(U,T-R|0)|0)/(R|0)|0}else{Ua=W-U|0}U=((Ua&$)<<G)+(Ta&$)|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,ma)|0)+(Z>>1))|0;cf[c[(c[a+12444>>2]|0)+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Y,ma,16);Y=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Ua>>1,ma)|0)+(Ta>>1))|0;cf[c[(c[a+12448>>2]|0)+(U<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Y,ma,16);break}else{Y=(ba(W>>2,ma)|0)+(Z>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Y|0,ma);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Y+8|0)|0,ma);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ma<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Y+(ma<<3))|0,ma);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Y+8|0)+(ma<<3))|0,ma);Y=(ba(Ua>>2,ma)|0)+(Ta>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Y|0,ma);Xe[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Y+8|0)|0,ma);Xe[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ma<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Y+(ma<<3))|0,ma);Xe[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Y+8|0)+(ma<<3))|0,ma);break}}}while(0);Qa=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(F+(((L<<3)+M&63)<<2)|0)>>2]=N;c[t+(((L<<3)+M&63)<<2)>>2]=Qa;$=(ba((d[z+((L<<G)-B)|0]|0)+(d[z+((M<<G)-A)|0]|0)|0,q)|0)+Qa|0;if(($|0)>=(Fa|0)){Na=Fa;Oa=Ga;Pa=Ha;break}c[(o|0)>>2]=M;c[p+4>>2]=L;Na=$;Oa=M;Pa=L}else{J=1}}if(J){J=0;if(1){$=c[(j+12|0)>>2]>>G;R=c[(j+8|0)>>2]>>G;T=R+K+($<<11)|0;do{if((c[(F+((($<<3)+R&63)<<2)|0)>>2]|0)==(T|0)){Va=1e6;Wa=0;Xa=0}else{do{if((C&4|0)==0){Y=c[a+12416>>2]|0;U=c[a+12420>>2]|0;Z=(c[a+12352+(l<<4)>>2]|0)+((ba(Y,$)|0)+R)|0;W=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,Z,Y,8)|0;if((C&2|0)==0){Ya=W;break}Z=c[a+12208>>2]|0;X=(ba(U,$>>1)|0)+(R>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&1023](Z+(Y<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+X|0,U,4);cf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&1023](Z+(Y<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+X|0,U,4);X=(Pe[I&255](a,Z+(Y<<4)|0,c[a+12288+(k<<4)+4>>2]|0,U,4)|0)+W|0;Ya=X+(Pe[I&255](a,Z+(Y<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,U,4)|0)|0}else{U=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(R|0)){Ya=536870912;break}if((R<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Ya=536870912;break}if((c[(a+12272|0)>>2]|0)>($|0)){Ya=536870912;break}if(($<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Ya=536870912;break}Y=e[a+13872>>1]|0;Z=e[a+13874>>1]|0;X=(C&1)<<1|1;g:do{if((c[a+11740>>2]|0)==1){if((R<<G|0)==0){W=0;while(1){_=c[a+12160+(W<<3)>>2]|0;S=(c[a+12160+(W<<3)+4>>2]|0)+($<<G)|0;da=((ba(c[a+12128+(W<<3)>>2]|0,Z-Y|0)|0)/(Y|0)|0)+((W&1)<<(C&1|4))|0;Za=c[a+12128+(W<<3)+4>>2]|0;if(($<<G|0)==0){_a=W>>1;$a=((ba(Za,Z-Y|0)|0)/(Y|0)|0)+(_a<<(C&1|4))|0;ab=_a}else{$a=S-Za|0;ab=W>>1}Za=(($a&X)<<G)+(da&X)|0;_a=(c[(a+12208|0)>>2]|0)+((ba(ab,U<<3)|0)+(W<<3&8))|0;if((C&1|0)==0){bb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>1,U)|0)+(_>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((S&X)<<G)+(_&X)|0)<<2)>>2]&1023](_a,bb,U,8);bb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($a>>1,U)|0)+(da>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Za<<2)>>2]&1023](_a,bb,U,8)}else{bb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>2,U)|0)+(_>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((S&X)<<G)+(_&X)|0)<<2)>>2]&4095](_a,bb,U);bb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($a>>2,U)|0)+(da>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095](_a,bb,U)}W=W+1|0;if((W|0)>=4){break g}}}if(($<<G|0)==0){W=0;do{bb=(c[a+12160+(W<<3)>>2]|0)+(R<<G)|0;_a=c[a+12160+(W<<3)+4>>2]|0;Za=bb-(c[a+12128+(W<<3)>>2]|0)|0;da=W>>1;_=((ba(c[a+12128+(W<<3)+4>>2]|0,Z-Y|0)|0)/(Y|0)|0)+(da<<(C&1|4))|0;S=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ba(da,U<<3)|0))|0;if((C&1|0)==0){da=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_a>>1,U)|0)+(bb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((_a&X)<<G)+(bb&X)|0)<<2)>>2]&1023](S,da,U,8);da=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>1,U)|0)+(Za>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((_&X)<<G)+(Za&X)|0)<<2)>>2]&1023](S,da,U,8)}else{da=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_a>>2,U)|0)+(bb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(bb&X)|0)<<2)>>2]&4095](S,da,U);da=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>2,U)|0)+(Za>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((_&X)<<G)+(Za&X)|0)<<2)>>2]&4095](S,da,U)}W=W+1|0;}while((W|0)<4)}else{W=0;do{da=(c[a+12160+(W<<3)>>2]|0)+(R<<G)|0;S=(c[a+12160+(W<<3)+4>>2]|0)+($<<G)|0;Za=da-(c[a+12128+(W<<3)>>2]|0)|0;_=S-(c[a+12128+(W<<3)+4>>2]|0)|0;bb=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ba(W>>1,U<<3)|0))|0;if((C&1|0)==0){_a=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>1,U)|0)+(da>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((S&X)<<G)+(da&X)|0)<<2)>>2]&1023](bb,_a,U,8);_a=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>1,U)|0)+(Za>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((_&X)<<G)+(Za&X)|0)<<2)>>2]&1023](bb,_a,U,8)}else{_a=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(S>>2,U)|0)+(da>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((S&X)<<G)+(da&X)|0)<<2)>>2]&4095](bb,_a,U);_a=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_>>2,U)|0)+(Za>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((_&X)<<G)+(Za&X)|0)<<2)>>2]&4095](bb,_a,U)}W=W+1|0;}while((W|0)<4)}}else{W=(c[a+12160>>2]|0)+(R<<G)|0;_a=(c[a+12164>>2]|0)+($<<G)|0;bb=c[a+12128>>2]|0;if((R<<G|0)==0){cb=(ba(bb,Z-Y|0)|0)/(Y|0)|0}else{cb=W-bb|0}bb=c[a+12132>>2]|0;if(($<<G|0)==0){db=(ba(bb,Z-Y|0)|0)/(Y|0)|0}else{db=_a-bb|0}bb=((db&X)<<G)+(cb&X)|0;if((C&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_a>>1,U)|0)+(W>>1))|0;cf[c[(c[a+12444>>2]|0)+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Za,U,16);Za=(c[a+12352+(l<<4)+32>>2]|0)+((ba(db>>1,U)|0)+(cb>>1))|0;cf[c[(c[a+12448>>2]|0)+(bb<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Za,U,16);break}else{Za=(ba(_a>>2,U)|0)+(W>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Za|0,U);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Za+8|0)|0,U);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(U<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Za+(U<<3))|0,U);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((U<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Za+8|0)+(U<<3))|0,U);Za=(ba(db>>2,U)|0)+(cb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Za|0,U);Xe[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Za+8|0)|0,U);Xe[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(U<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Za+(U<<3))|0,U);Xe[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((U<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Za+8|0)+(U<<3))|0,U);break}}}while(0);Ya=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,U,16)|0}}while(0);c[(F+((($<<3)+R&63)<<2)|0)>>2]=T;c[t+((($<<3)+R&63)<<2)>>2]=Ya;ma=c[(j+8|0)>>2]>>G;X=c[(j+12|0)>>2]>>G;Y=(ba((d[z+((X<<G)-B)|0]|0)+(d[z+((ma<<G)-A)|0]|0)|0,q)|0)+Ya|0;if((Y|0)>=1e6){Va=1e6;Wa=0;Xa=0;break}c[(o|0)>>2]=ma;c[p+4>>2]=X;Va=Y;Wa=ma;Xa=X}}while(0);R=(ba(b[m+(s<<2)>>1]|0,n)|0)+32768>>16;$=(ba(b[m+(s<<2)+2>>1]|0,n)|0)+32768>>16;T=(R|0)>(x|0)?x:R;R=(u|0)>(T|0)?u:T;T=($|0)>(y|0)?y:$;$=(v|0)>(T|0)?v:T;T=R+K+($<<11)|0;do{if((c[(F+((($<<3)+R&63)<<2)|0)>>2]|0)==(T|0)){eb=Va;fb=Wa;gb=Xa}else{do{if((C&4|0)==0){L=c[a+12416>>2]|0;M=c[a+12420>>2]|0;N=(c[a+12352+(l<<4)>>2]|0)+((ba(L,$)|0)+R)|0;X=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,N,L,8)|0;if((C&2|0)==0){hb=X;break}N=c[a+12208>>2]|0;ma=(ba(M,$>>1)|0)+(R>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&1023](N+(L<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ma|0,M,4);cf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&1023](N+(L<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ma|0,M,4);ma=(Pe[I&255](a,N+(L<<4)|0,c[a+12288+(k<<4)+4>>2]|0,M,4)|0)+X|0;hb=ma+(Pe[I&255](a,N+(L<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,M,4)|0)|0}else{M=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(R|0)){hb=536870912;break}if((R<<G|0)>(c[(a+12268|0)>>2]<<G|0)){hb=536870912;break}if((c[(a+12272|0)>>2]|0)>($|0)){hb=536870912;break}if(($<<G|0)>(c[(a+12276|0)>>2]<<G|0)){hb=536870912;break}L=e[a+13872>>1]|0;N=e[a+13874>>1]|0;ma=(C&1)<<1|1;h:do{if((c[a+11740>>2]|0)==1){if((R<<G|0)==0){X=0;while(1){Y=c[a+12160+(X<<3)>>2]|0;Z=(c[a+12160+(X<<3)+4>>2]|0)+($<<G)|0;Za=((ba(c[a+12128+(X<<3)>>2]|0,N-L|0)|0)/(L|0)|0)+((X&1)<<(C&1|4))|0;bb=c[a+12128+(X<<3)+4>>2]|0;if(($<<G|0)==0){W=X>>1;ib=((ba(bb,N-L|0)|0)/(L|0)|0)+(W<<(C&1|4))|0;jb=W}else{ib=Z-bb|0;jb=X>>1}bb=((ib&ma)<<G)+(Za&ma)|0;W=(c[(a+12208|0)>>2]|0)+((ba(jb,M<<3)|0)+(X<<3&8))|0;if((C&1|0)==0){_a=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>1,M)|0)+(Y>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&ma)<<G)+(Y&ma)|0)<<2)>>2]&1023](W,_a,M,8);_a=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ib>>1,M)|0)+(Za>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(bb<<2)>>2]&1023](W,_a,M,8)}else{_a=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>2,M)|0)+(Y>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Z&ma)<<G)+(Y&ma)|0)<<2)>>2]&4095](W,_a,M);_a=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ib>>2,M)|0)+(Za>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095](W,_a,M)}X=X+1|0;if((X|0)>=4){break h}}}if(($<<G|0)==0){X=0;do{_a=(c[a+12160+(X<<3)>>2]|0)+(R<<G)|0;W=c[a+12160+(X<<3)+4>>2]|0;bb=_a-(c[a+12128+(X<<3)>>2]|0)|0;Za=X>>1;Y=((ba(c[a+12128+(X<<3)+4>>2]|0,N-L|0)|0)/(L|0)|0)+(Za<<(C&1|4))|0;Z=(c[(a+12208|0)>>2]|0)+((X<<3&8)+(ba(Za,M<<3)|0))|0;if((C&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,M)|0)+(_a>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((W&ma)<<G)+(_a&ma)|0)<<2)>>2]&1023](Z,Za,M,8);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Y>>1,M)|0)+(bb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((Y&ma)<<G)+(bb&ma)|0)<<2)>>2]&1023](Z,Za,M,8)}else{Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>2,M)|0)+(_a>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(_a&ma)|0)<<2)>>2]&4095](Z,Za,M);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Y>>2,M)|0)+(bb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((Y&ma)<<G)+(bb&ma)|0)<<2)>>2]&4095](Z,Za,M)}X=X+1|0;}while((X|0)<4)}else{X=0;do{Za=(c[a+12160+(X<<3)>>2]|0)+(R<<G)|0;Z=(c[a+12160+(X<<3)+4>>2]|0)+($<<G)|0;bb=Za-(c[a+12128+(X<<3)>>2]|0)|0;Y=Z-(c[a+12128+(X<<3)+4>>2]|0)|0;_a=(c[(a+12208|0)>>2]|0)+((X<<3&8)+(ba(X>>1,M<<3)|0))|0;if((C&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>1,M)|0)+(Za>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&ma)<<G)+(Za&ma)|0)<<2)>>2]&1023](_a,W,M,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Y>>1,M)|0)+(bb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((Y&ma)<<G)+(bb&ma)|0)<<2)>>2]&1023](_a,W,M,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>2,M)|0)+(Za>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Z&ma)<<G)+(Za&ma)|0)<<2)>>2]&4095](_a,W,M);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Y>>2,M)|0)+(bb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((Y&ma)<<G)+(bb&ma)|0)<<2)>>2]&4095](_a,W,M)}X=X+1|0;}while((X|0)<4)}}else{X=(c[a+12160>>2]|0)+(R<<G)|0;W=(c[a+12164>>2]|0)+($<<G)|0;_a=c[a+12128>>2]|0;if((R<<G|0)==0){kb=(ba(_a,N-L|0)|0)/(L|0)|0}else{kb=X-_a|0}_a=c[a+12132>>2]|0;if(($<<G|0)==0){lb=(ba(_a,N-L|0)|0)/(L|0)|0}else{lb=W-_a|0}_a=((lb&ma)<<G)+(kb&ma)|0;if((C&1|0)==0){bb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W>>1,M)|0)+(X>>1))|0;cf[c[(c[a+12444>>2]|0)+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,bb,M,16);bb=(c[a+12352+(l<<4)+32>>2]|0)+((ba(lb>>1,M)|0)+(kb>>1))|0;cf[c[(c[a+12448>>2]|0)+(_a<<2)>>2]&1023](c[(a+12208|0)>>2]|0,bb,M,16);break}else{bb=(ba(W>>2,M)|0)+(X>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+bb|0,M);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(bb+8|0)|0,M);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(M<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(bb+(M<<3))|0,M);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((bb+8|0)+(M<<3))|0,M);bb=(ba(lb>>2,M)|0)+(kb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(_a<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+bb|0,M);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_a<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(bb+8|0)|0,M);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_a<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(M<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(bb+(M<<3))|0,M);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_a<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((bb+8|0)+(M<<3))|0,M);break}}}while(0);hb=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,M,16)|0}}while(0);c[(F+((($<<3)+R&63)<<2)|0)>>2]=T;c[t+((($<<3)+R&63)<<2)>>2]=hb;ma=(ba((d[z+(($<<G)-B)|0]|0)+(d[z+((R<<G)-A)|0]|0)|0,q)|0)+hb|0;if((ma|0)>=(Va|0)){eb=Va;fb=Wa;gb=Xa;break}c[(o|0)>>2]=R;c[p+4>>2]=$;eb=ma;fb=R;gb=$}}while(0);$=c[(j+76|0)>>2]>>G;R=c[(j+72|0)>>2]>>G;T=R+K+($<<11)|0;if((c[(F+((($<<3)+R&63)<<2)|0)>>2]|0)==(T|0)){Na=eb;Oa=fb;Pa=gb;break}do{if((C&4|0)==0){ma=c[a+12416>>2]|0;L=c[a+12420>>2]|0;N=(c[a+12352+(l<<4)>>2]|0)+((ba(ma,$)|0)+R)|0;U=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,N,ma,8)|0;if((C&2|0)==0){mb=U;break}N=c[a+12208>>2]|0;bb=(ba(L,$>>1)|0)+(R>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&1023](N+(ma<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+bb|0,L,4);cf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&1023](N+(ma<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+bb|0,L,4);bb=(Pe[I&255](a,N+(ma<<4)|0,c[a+12288+(k<<4)+4>>2]|0,L,4)|0)+U|0;mb=bb+(Pe[I&255](a,N+(ma<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,L,4)|0)|0}else{L=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(R|0)){mb=536870912;break}if((R<<G|0)>(c[(a+12268|0)>>2]<<G|0)){mb=536870912;break}if((c[(a+12272|0)>>2]|0)>($|0)){mb=536870912;break}if(($<<G|0)>(c[(a+12276|0)>>2]<<G|0)){mb=536870912;break}ma=e[a+13872>>1]|0;N=e[a+13874>>1]|0;bb=(C&1)<<1|1;i:do{if((c[a+11740>>2]|0)==1){if((R<<G|0)==0){U=0;while(1){_a=c[a+12160+(U<<3)>>2]|0;X=(c[a+12160+(U<<3)+4>>2]|0)+($<<G)|0;W=((ba(c[a+12128+(U<<3)>>2]|0,N-ma|0)|0)/(ma|0)|0)+((U&1)<<(C&1|4))|0;Y=c[a+12128+(U<<3)+4>>2]|0;if(($<<G|0)==0){Za=U>>1;nb=((ba(Y,N-ma|0)|0)/(ma|0)|0)+(Za<<(C&1|4))|0;ob=Za}else{nb=X-Y|0;ob=U>>1}Y=((nb&bb)<<G)+(W&bb)|0;Za=(c[(a+12208|0)>>2]|0)+((ba(ob,L<<3)|0)+(U<<3&8))|0;if((C&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>1,L)|0)+(_a>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((X&bb)<<G)+(_a&bb)|0)<<2)>>2]&1023](Za,Z,L,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(nb>>1,L)|0)+(W>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Y<<2)>>2]&1023](Za,Z,L,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(X>>2,L)|0)+(_a>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((X&bb)<<G)+(_a&bb)|0)<<2)>>2]&4095](Za,Z,L);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(nb>>2,L)|0)+(W>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Y<<2)>>2]&4095](Za,Z,L)}U=U+1|0;if((U|0)>=4){break i}}}if(($<<G|0)==0){U=0;do{M=(c[a+12160+(U<<3)>>2]|0)+(R<<G)|0;Z=c[a+12160+(U<<3)+4>>2]|0;Za=M-(c[a+12128+(U<<3)>>2]|0)|0;Y=U>>1;W=((ba(c[a+12128+(U<<3)+4>>2]|0,N-ma|0)|0)/(ma|0)|0)+(Y<<(C&1|4))|0;_a=(c[(a+12208|0)>>2]|0)+((U<<3&8)+(ba(Y,L<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>1,L)|0)+(M>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&bb)<<G)+(M&bb)|0)<<2)>>2]&1023](_a,Y,L,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>1,L)|0)+(Za>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((W&bb)<<G)+(Za&bb)|0)<<2)>>2]&1023](_a,Y,L,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>2,L)|0)+(M>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(M&bb)|0)<<2)>>2]&4095](_a,Y,L);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>2,L)|0)+(Za>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((W&bb)<<G)+(Za&bb)|0)<<2)>>2]&4095](_a,Y,L)}U=U+1|0;}while((U|0)<4)}else{U=0;do{Y=(c[a+12160+(U<<3)>>2]|0)+(R<<G)|0;_a=(c[a+12160+(U<<3)+4>>2]|0)+($<<G)|0;Za=Y-(c[a+12128+(U<<3)>>2]|0)|0;W=_a-(c[a+12128+(U<<3)+4>>2]|0)|0;M=(c[(a+12208|0)>>2]|0)+((U<<3&8)+(ba(U>>1,L<<3)|0))|0;if((C&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_a>>1,L)|0)+(Y>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((_a&bb)<<G)+(Y&bb)|0)<<2)>>2]&1023](M,Z,L,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>1,L)|0)+(Za>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((W&bb)<<G)+(Za&bb)|0)<<2)>>2]&1023](M,Z,L,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_a>>2,L)|0)+(Y>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_a&bb)<<G)+(Y&bb)|0)<<2)>>2]&4095](M,Z,L);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(W>>2,L)|0)+(Za>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((W&bb)<<G)+(Za&bb)|0)<<2)>>2]&4095](M,Z,L)}U=U+1|0;}while((U|0)<4)}}else{U=(c[a+12160>>2]|0)+(R<<G)|0;Z=(c[a+12164>>2]|0)+($<<G)|0;M=c[a+12128>>2]|0;if((R<<G|0)==0){pb=(ba(M,N-ma|0)|0)/(ma|0)|0}else{pb=U-M|0}M=c[a+12132>>2]|0;if(($<<G|0)==0){qb=(ba(M,N-ma|0)|0)/(ma|0)|0}else{qb=Z-M|0}M=((qb&bb)<<G)+(pb&bb)|0;if((C&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Z>>1,L)|0)+(U>>1))|0;cf[c[(c[a+12444>>2]|0)+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Za,L,16);Za=(c[a+12352+(l<<4)+32>>2]|0)+((ba(qb>>1,L)|0)+(pb>>1))|0;cf[c[(c[a+12448>>2]|0)+(M<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Za,L,16);break}else{Za=(ba(Z>>2,L)|0)+(U>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Za|0,L);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Za+8|0)|0,L);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Za+(L<<3))|0,L);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Za+8|0)+(L<<3))|0,L);Za=(ba(qb>>2,L)|0)+(pb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(M<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Za|0,L);Xe[c[(c[(a+12456|0)>>2]|0)+64+(M<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Za+8|0)|0,L);Xe[c[(c[(a+12456|0)>>2]|0)+64+(M<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Za+(L<<3))|0,L);Xe[c[(c[(a+12456|0)>>2]|0)+64+(M<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Za+8|0)+(L<<3))|0,L);break}}}while(0);mb=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,L,16)|0}}while(0);c[(F+((($<<3)+R&63)<<2)|0)>>2]=T;c[t+((($<<3)+R&63)<<2)>>2]=mb;bb=c[(j+72|0)>>2]>>G;ma=c[(j+76|0)>>2]>>G;N=(ba((d[z+((ma<<G)-B)|0]|0)+(d[z+((bb<<G)-A)|0]|0)|0,q)|0)+mb|0;if((N|0)>=(eb|0)){Na=eb;Oa=fb;Pa=gb;break}c[(o|0)>>2]=bb;c[p+4>>2]=ma;Na=N;Oa=bb;Pa=ma}else{J=1}}}while(0);do{if((Na|0)>256){gb=(ba(b[m+((s+1|0)<<2)>>1]|0,n)|0)+32768>>16;fb=(ba(b[m+((s+1|0)<<2)+2>>1]|0,n)|0)+32768>>16;eb=(gb|0)>(x|0)?x:gb;gb=(u|0)>(eb|0)?u:eb;eb=(fb|0)>(y|0)?y:fb;fb=(v|0)>(eb|0)?v:eb;eb=gb+K+(fb<<11)|0;do{if((c[(F+(((fb<<3)+gb&63)<<2)|0)>>2]|0)==(eb|0)){rb=Na;sb=Oa;tb=Pa}else{do{if((C&4|0)==0){mb=c[a+12416>>2]|0;j=c[a+12420>>2]|0;pb=(c[a+12352+(l<<4)>>2]|0)+((ba(mb,fb)|0)+gb)|0;qb=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,pb,mb,8)|0;if((C&2|0)==0){ub=qb;break}pb=c[a+12208>>2]|0;nb=(ba(j,fb>>1)|0)+(gb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((fb<<1&2|gb&1)<<2)>>2]&1023](pb+(mb<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+nb|0,j,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((fb<<1&2|gb&1)<<2)>>2]&1023](pb+(mb<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+nb|0,j,4);nb=(Pe[I&255](a,pb+(mb<<4)|0,c[a+12288+(k<<4)+4>>2]|0,j,4)|0)+qb|0;ub=nb+(Pe[I&255](a,pb+(mb<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,j,4)|0)|0}else{j=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(gb|0)){ub=536870912;break}if((gb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){ub=536870912;break}if((c[(a+12272|0)>>2]|0)>(fb|0)){ub=536870912;break}if((fb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){ub=536870912;break}mb=e[a+13872>>1]|0;pb=e[a+13874>>1]|0;nb=(C&1)<<1|1;j:do{if((c[a+11740>>2]|0)==1){if((gb<<G|0)==0){qb=0;while(1){ob=c[a+12160+(qb<<3)>>2]|0;Xa=(c[a+12160+(qb<<3)+4>>2]|0)+(fb<<G)|0;Wa=((ba(c[a+12128+(qb<<3)>>2]|0,pb-mb|0)|0)/(mb|0)|0)+((qb&1)<<(C&1|4))|0;Va=c[a+12128+(qb<<3)+4>>2]|0;if((fb<<G|0)==0){hb=qb>>1;vb=((ba(Va,pb-mb|0)|0)/(mb|0)|0)+(hb<<(C&1|4))|0;wb=hb}else{vb=Xa-Va|0;wb=qb>>1}Va=((vb&nb)<<G)+(Wa&nb)|0;hb=(c[(a+12208|0)>>2]|0)+((ba(wb,j<<3)|0)+(qb<<3&8))|0;if((C&1|0)==0){kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Xa>>1,j)|0)+(ob>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Xa&nb)<<G)+(ob&nb)|0)<<2)>>2]&1023](hb,kb,j,8);kb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(vb>>1,j)|0)+(Wa>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Va<<2)>>2]&1023](hb,kb,j,8)}else{kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Xa>>2,j)|0)+(ob>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Xa&nb)<<G)+(ob&nb)|0)<<2)>>2]&4095](hb,kb,j);kb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(vb>>2,j)|0)+(Wa>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](hb,kb,j)}qb=qb+1|0;if((qb|0)>=4){break j}}}if((fb<<G|0)==0){qb=0;do{kb=(c[a+12160+(qb<<3)>>2]|0)+(gb<<G)|0;hb=c[a+12160+(qb<<3)+4>>2]|0;Va=kb-(c[a+12128+(qb<<3)>>2]|0)|0;Wa=qb>>1;ob=((ba(c[a+12128+(qb<<3)+4>>2]|0,pb-mb|0)|0)/(mb|0)|0)+(Wa<<(C&1|4))|0;Xa=(c[(a+12208|0)>>2]|0)+((qb<<3&8)+(ba(Wa,j<<3)|0))|0;if((C&1|0)==0){Wa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hb>>1,j)|0)+(kb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((hb&nb)<<G)+(kb&nb)|0)<<2)>>2]&1023](Xa,Wa,j,8);Wa=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>1,j)|0)+(Va>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&nb)<<G)+(Va&nb)|0)<<2)>>2]&1023](Xa,Wa,j,8)}else{Wa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hb>>2,j)|0)+(kb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(kb&nb)|0)<<2)>>2]&4095](Xa,Wa,j);Wa=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>2,j)|0)+(Va>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ob&nb)<<G)+(Va&nb)|0)<<2)>>2]&4095](Xa,Wa,j)}qb=qb+1|0;}while((qb|0)<4)}else{qb=0;do{Wa=(c[a+12160+(qb<<3)>>2]|0)+(gb<<G)|0;Xa=(c[a+12160+(qb<<3)+4>>2]|0)+(fb<<G)|0;Va=Wa-(c[a+12128+(qb<<3)>>2]|0)|0;ob=Xa-(c[a+12128+(qb<<3)+4>>2]|0)|0;kb=(c[(a+12208|0)>>2]|0)+((qb<<3&8)+(ba(qb>>1,j<<3)|0))|0;if((C&1|0)==0){hb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Xa>>1,j)|0)+(Wa>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Xa&nb)<<G)+(Wa&nb)|0)<<2)>>2]&1023](kb,hb,j,8);hb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>1,j)|0)+(Va>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&nb)<<G)+(Va&nb)|0)<<2)>>2]&1023](kb,hb,j,8)}else{hb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Xa>>2,j)|0)+(Wa>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Xa&nb)<<G)+(Wa&nb)|0)<<2)>>2]&4095](kb,hb,j);hb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ob>>2,j)|0)+(Va>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ob&nb)<<G)+(Va&nb)|0)<<2)>>2]&4095](kb,hb,j)}qb=qb+1|0;}while((qb|0)<4)}}else{qb=(c[a+12160>>2]|0)+(gb<<G)|0;hb=(c[a+12164>>2]|0)+(fb<<G)|0;kb=c[a+12128>>2]|0;if((gb<<G|0)==0){xb=(ba(kb,pb-mb|0)|0)/(mb|0)|0}else{xb=qb-kb|0}kb=c[a+12132>>2]|0;if((fb<<G|0)==0){yb=(ba(kb,pb-mb|0)|0)/(mb|0)|0}else{yb=hb-kb|0}kb=((yb&nb)<<G)+(xb&nb)|0;if((C&1|0)==0){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hb>>1,j)|0)+(qb>>1))|0;cf[c[(c[a+12444>>2]|0)+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Va,j,16);Va=(c[a+12352+(l<<4)+32>>2]|0)+((ba(yb>>1,j)|0)+(xb>>1))|0;cf[c[(c[a+12448>>2]|0)+(kb<<2)>>2]&1023](c[(a+12208|0)>>2]|0,Va,j,16);break}else{Va=(ba(hb>>2,j)|0)+(qb>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Va|0,j);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Va+8|0)|0,j);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(j<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Va+(j<<3))|0,j);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((j<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Va+8|0)+(j<<3))|0,j);Va=(ba(yb>>2,j)|0)+(xb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Va|0,j);Xe[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Va+8|0)|0,j);Xe[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(j<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Va+(j<<3))|0,j);Xe[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((j<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Va+8|0)+(j<<3))|0,j);break}}}while(0);ub=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,j,16)|0}}while(0);c[(F+(((fb<<3)+gb&63)<<2)|0)>>2]=eb;c[t+(((fb<<3)+gb&63)<<2)>>2]=ub;L=(ba((d[z+((fb<<G)-B)|0]|0)+(d[z+((gb<<G)-A)|0]|0)|0,q)|0)+ub|0;if((L|0)>=(Na|0)){rb=Na;sb=Oa;tb=Pa;break}c[(o|0)>>2]=gb;c[p+4>>2]=fb;rb=L;sb=gb;tb=fb}}while(0);if(((c[(a+12480|0)>>2]|0)+1|0)>=(c[a+812>>2]|0)){zb=rb;Ab=sb;Bb=tb;break}fb=(ba(b[m+((s+r|0)<<2)>>1]|0,n)|0)+32768>>16;gb=(ba(b[m+((s+r|0)<<2)+2>>1]|0,n)|0)+32768>>16;eb=(fb|0)>(x|0)?x:fb;fb=(u|0)>(eb|0)?u:eb;eb=(gb|0)>(y|0)?y:gb;gb=(v|0)>(eb|0)?v:eb;eb=fb+K+(gb<<11)|0;if((c[(F+(((gb<<3)+fb&63)<<2)|0)>>2]|0)==(eb|0)){zb=rb;Ab=sb;Bb=tb;break}do{if((C&4|0)==0){J=c[a+12416>>2]|0;R=c[a+12420>>2]|0;$=(c[a+12352+(l<<4)>>2]|0)+((ba(J,gb)|0)+fb)|0;T=Pe[H&255](a,c[a+12288+(k<<4)>>2]|0,$,J,8)|0;if((C&2|0)==0){Cb=T;break}$=c[a+12208>>2]|0;L=(ba(R,gb>>1)|0)+(fb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((gb<<1&2|fb&1)<<2)>>2]&1023]($+(J<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+L|0,R,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((gb<<1&2|fb&1)<<2)>>2]&1023]($+(J<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+L|0,R,4);L=(Pe[I&255](a,$+(J<<4)|0,c[a+12288+(k<<4)+4>>2]|0,R,4)|0)+T|0;Cb=L+(Pe[I&255](a,$+(J<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,R,4)|0)|0}else{R=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(fb|0)){Cb=536870912;break}if((fb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Cb=536870912;break}if((c[(a+12272|0)>>2]|0)>(gb|0)){Cb=536870912;break}if((gb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Cb=536870912;break}J=e[a+13872>>1]|0;$=e[a+13874>>1]|0;L=(C&1)<<1|1;k:do{if((c[a+11740>>2]|0)==1){if((fb<<G|0)==0){T=0;while(1){nb=c[a+12160+(T<<3)>>2]|0;mb=(c[a+12160+(T<<3)+4>>2]|0)+(gb<<G)|0;pb=((ba(c[a+12128+(T<<3)>>2]|0,$-J|0)|0)/(J|0)|0)+((T&1)<<(C&1|4))|0;Va=c[a+12128+(T<<3)+4>>2]|0;if((gb<<G|0)==0){kb=T>>1;Db=((ba(Va,$-J|0)|0)/(J|0)|0)+(kb<<(C&1|4))|0;Eb=kb}else{Db=mb-Va|0;Eb=T>>1}Va=((Db&L)<<G)+(pb&L)|0;kb=(c[(a+12208|0)>>2]|0)+((ba(Eb,R<<3)|0)+(T<<3&8))|0;if((C&1|0)==0){qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mb>>1,R)|0)+(nb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((mb&L)<<G)+(nb&L)|0)<<2)>>2]&1023](kb,qb,R,8);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Db>>1,R)|0)+(pb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Va<<2)>>2]&1023](kb,qb,R,8)}else{qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mb>>2,R)|0)+(nb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((mb&L)<<G)+(nb&L)|0)<<2)>>2]&4095](kb,qb,R);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Db>>2,R)|0)+(pb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](kb,qb,R)}T=T+1|0;if((T|0)>=4){break k}}}if((gb<<G|0)==0){T=0;do{j=(c[a+12160+(T<<3)>>2]|0)+(fb<<G)|0;qb=c[a+12160+(T<<3)+4>>2]|0;kb=j-(c[a+12128+(T<<3)>>2]|0)|0;Va=T>>1;pb=((ba(c[a+12128+(T<<3)+4>>2]|0,$-J|0)|0)/(J|0)|0)+(Va<<(C&1|4))|0;nb=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ba(Va,R<<3)|0))|0;if((C&1|0)==0){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(qb>>1,R)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((qb&L)<<G)+(j&L)|0)<<2)>>2]&1023](nb,Va,R,8);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(pb>>1,R)|0)+(kb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((pb&L)<<G)+(kb&L)|0)<<2)>>2]&1023](nb,Va,R,8)}else{Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(qb>>2,R)|0)+(j>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(j&L)|0)<<2)>>2]&4095](nb,Va,R);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(pb>>2,R)|0)+(kb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((pb&L)<<G)+(kb&L)|0)<<2)>>2]&4095](nb,Va,R)}T=T+1|0;}while((T|0)<4)}else{T=0;do{Va=(c[a+12160+(T<<3)>>2]|0)+(fb<<G)|0;nb=(c[a+12160+(T<<3)+4>>2]|0)+(gb<<G)|0;kb=Va-(c[a+12128+(T<<3)>>2]|0)|0;pb=nb-(c[a+12128+(T<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ba(T>>1,R<<3)|0))|0;if((C&1|0)==0){qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(nb>>1,R)|0)+(Va>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((nb&L)<<G)+(Va&L)|0)<<2)>>2]&1023](j,qb,R,8);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(pb>>1,R)|0)+(kb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((pb&L)<<G)+(kb&L)|0)<<2)>>2]&1023](j,qb,R,8)}else{qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(nb>>2,R)|0)+(Va>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((nb&L)<<G)+(Va&L)|0)<<2)>>2]&4095](j,qb,R);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(pb>>2,R)|0)+(kb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((pb&L)<<G)+(kb&L)|0)<<2)>>2]&4095](j,qb,R)}T=T+1|0;}while((T|0)<4)}}else{T=(c[a+12160>>2]|0)+(fb<<G)|0;qb=(c[a+12164>>2]|0)+(gb<<G)|0;j=c[a+12128>>2]|0;if((fb<<G|0)==0){Fb=(ba(j,$-J|0)|0)/(J|0)|0}else{Fb=T-j|0}j=c[a+12132>>2]|0;if((gb<<G|0)==0){Gb=(ba(j,$-J|0)|0)/(J|0)|0}else{Gb=qb-j|0}j=((Gb&L)<<G)+(Fb&L)|0;if((C&1|0)==0){kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(qb>>1,R)|0)+(T>>1))|0;cf[c[(c[a+12444>>2]|0)+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,kb,R,16);kb=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Gb>>1,R)|0)+(Fb>>1))|0;cf[c[(c[a+12448>>2]|0)+(j<<2)>>2]&1023](c[(a+12208|0)>>2]|0,kb,R,16);break}else{kb=(ba(qb>>2,R)|0)+(T>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+kb|0,R);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kb+8|0)|0,R);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(R<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kb+(R<<3))|0,R);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((kb+8|0)+(R<<3))|0,R);kb=(ba(Gb>>2,R)|0)+(Fb>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+kb|0,R);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kb+8|0)|0,R);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(R<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kb+(R<<3))|0,R);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((kb+8|0)+(R<<3))|0,R);break}}}while(0);Cb=Pe[H&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,R,16)|0}}while(0);c[(F+(((gb<<3)+fb&63)<<2)|0)>>2]=eb;c[t+(((gb<<3)+fb&63)<<2)>>2]=Cb;L=(ba((d[z+((gb<<G)-B)|0]|0)+(d[z+((fb<<G)-A)|0]|0)|0,q)|0)+Cb|0;if((L|0)>=(rb|0)){zb=rb;Ab=sb;Bb=tb;break}c[(o|0)>>2]=fb;c[p+4>>2]=gb;zb=L;Ab=fb;Bb=gb}else{zb=Na;Ab=Oa;Bb=Pa}}while(0);Pa=o|0;Oa=c[(a+12260|0)>>2]|0;if((Oa|0)==-1){Na=c[(a+12220|0)>>2]|0;tb=c[(a+12264|0)>>2]|0;sb=c[(a+12272|0)>>2]|0;rb=c[(a+12268|0)>>2]|0;Cb=c[(a+12276|0)>>2]|0;A=c[(a+12464|0)>>2]|0;z=c[(a+12280|0)>>2]|0;B=c[(a+12284|0)>>2]|0;t=c[(a+12216|0)>>2]|0;F=c[(a+12224|0)>>2]|0;H=c[(a+10472|0)>>2]|0;Fb=c[(a+10476|0)>>2]|0;Gb=(C&1)<<1|1;Db=C&1|4;Eb=(C&1|0)==0;I=zb;K=Ab;v=Bb;y=Ab;l:while(1){u=1;x=I;n=v;r=y;while(1){do{if((u-1&u|0)==0){s=u+K|0;if((s|0)>(rb|0)){Hb=x;Ib=n;Jb=r;break}m=K-u|0;if((m|0)<(tb|0)){Hb=x;Ib=n;Jb=r;break}ub=u+v|0;if((ub|0)>(Cb|0)){Hb=x;Ib=n;Jb=r;break}xb=v-u|0;if((xb|0)<(sb|0)){Hb=x;Ib=n;Jb=r;break}else{Kb=0;Lb=x;Mb=n;Nb=r}while(1){yb=ub-Kb|0;vb=Kb+K|0;do{if((c[(t+(((yb<<3)+vb&63)<<2)|0)>>2]|0)==(vb+F+(yb<<11)|0|0)){Ob=Lb;Pb=Mb;Qb=Nb}else{wb=c[(a+12416|0)>>2]|0;do{if((C&4|0)==0){L=c[(a+12420|0)>>2]|0;J=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(wb,yb)|0)+vb)|0;$=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,J,wb,8)|0;if((C&2|0)==0){Rb=$;break}J=c[(a+12208|0)>>2]|0;kb=(ba(L,yb>>1)|0)+(vb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((yb<<1&2|vb&1)<<2)>>2]&1023](J+(wb<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+kb|0,L,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((yb<<1&2|vb&1)<<2)>>2]&1023](J+(wb<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+kb|0,L,4);kb=(Pe[Fb&255](a,J+(wb<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,L,4)|0)+$|0;Rb=kb+(Pe[Fb&255](a,J+(wb<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,L,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(vb|0)){Rb=536870912;break}if((vb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Rb=536870912;break}if((c[(a+12272|0)>>2]|0)>(yb|0)){Rb=536870912;break}if((yb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Rb=536870912;break}L=e[(a+13872|0)>>1]|0;J=e[(a+13874|0)>>1]|0;m:do{if((c[(a+11740|0)>>2]|0)==1){if((vb<<G|0)==0){kb=0;while(1){$=c[a+12160+(kb<<3)>>2]|0;j=(c[a+12160+(kb<<3)+4>>2]|0)+(yb<<G)|0;T=((ba(c[a+12128+(kb<<3)>>2]|0,J-L|0)|0)/(L|0)|0)+((kb&1)<<Db)|0;qb=c[a+12128+(kb<<3)+4>>2]|0;if((yb<<G|0)==0){pb=kb>>1;Sb=((ba(qb,J-L|0)|0)/(L|0)|0)+(pb<<Db)|0;Tb=pb}else{Sb=j-qb|0;Tb=kb>>1}qb=((Sb&Gb)<<G)+(T&Gb)|0;pb=(c[(a+12208|0)>>2]|0)+((ba(Tb,wb<<3)|0)+(kb<<3&8))|0;if(Eb){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>1,wb)|0)+($>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Gb)<<G)+($&Gb)|0)<<2)>>2]&1023](pb,Va,wb,8);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Sb>>1,wb)|0)+(T>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(qb<<2)>>2]&1023](pb,Va,wb,8)}else{Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>2,wb)|0)+($>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((j&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](pb,Va,wb);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Sb>>2,wb)|0)+(T>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(qb<<2)>>2]&4095](pb,Va,wb)}kb=kb+1|0;if((kb|0)>=4){break m}}}if((yb<<G|0)==0){kb=0;do{Va=(c[a+12160+(kb<<3)>>2]|0)+(vb<<G)|0;pb=c[a+12160+(kb<<3)+4>>2]|0;qb=Va-(c[a+12128+(kb<<3)>>2]|0)|0;T=kb>>1;$=((ba(c[a+12128+(kb<<3)+4>>2]|0,J-L|0)|0)/(L|0)|0)+(T<<Db)|0;j=(c[(a+12208|0)>>2]|0)+((kb<<3&8)+(ba(T,wb<<3)|0))|0;if(Eb){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,wb)|0)+(Va>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&1023](j,T,wb,8);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>1,wb)|0)+(qb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&1023](j,T,wb,8)}else{T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>2,wb)|0)+(Va>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095](j,T,wb);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>2,wb)|0)+(qb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](j,T,wb)}kb=kb+1|0;}while((kb|0)<4)}else{kb=0;do{T=(c[a+12160+(kb<<3)>>2]|0)+(vb<<G)|0;j=(c[a+12160+(kb<<3)+4>>2]|0)+(yb<<G)|0;qb=T-(c[a+12128+(kb<<3)>>2]|0)|0;$=j-(c[a+12128+(kb<<3)+4>>2]|0)|0;Va=(c[(a+12208|0)>>2]|0)+((kb<<3&8)+(ba(kb>>1,wb<<3)|0))|0;if(Eb){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>1,wb)|0)+(T>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Gb)<<G)+(T&Gb)|0)<<2)>>2]&1023](Va,pb,wb,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>1,wb)|0)+(qb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&1023](Va,pb,wb,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>2,wb)|0)+(T>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((j&Gb)<<G)+(T&Gb)|0)<<2)>>2]&4095](Va,pb,wb);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>2,wb)|0)+(qb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](Va,pb,wb)}kb=kb+1|0;}while((kb|0)<4)}}else{kb=(c[(a+12160|0)>>2]|0)+(vb<<G)|0;pb=(c[(a+12164|0)>>2]|0)+(yb<<G)|0;Va=c[(a+12128|0)>>2]|0;if((vb<<G|0)==0){Ub=(ba(Va,J-L|0)|0)/(L|0)|0}else{Ub=kb-Va|0}Va=c[(a+12132|0)>>2]|0;if((yb<<G|0)==0){Vb=(ba(Va,J-L|0)|0)/(L|0)|0}else{Vb=pb-Va|0}Va=((Vb&Gb)<<G)+(Ub&Gb)|0;if(Eb){qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,wb)|0)+(kb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,qb,wb,16);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Vb>>1,wb)|0)+(Ub>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+(Va<<2)>>2]&1023](c[(a+12208|0)>>2]|0,qb,wb,16);break}else{qb=(ba(pb>>2,wb)|0)+(kb>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+qb|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(qb+8|0)|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(qb+(wb<<3))|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((qb+8|0)+(wb<<3))|0,wb);qb=(ba(Vb>>2,wb)|0)+(Ub>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+qb|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(qb+8|0)|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(qb+(wb<<3))|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((qb+8|0)+(wb<<3))|0,wb);break}}}while(0);Rb=Pe[H&255](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,wb,16)|0}}while(0);c[(t+(((yb<<3)+vb&63)<<2)|0)>>2]=vb+F+(yb<<11)|0;c[Na+(((yb<<3)+vb&63)<<2)>>2]=Rb;wb=(ba((d[A+((yb<<G)-B)|0]|0)+(d[A+((vb<<G)-z)|0]|0)|0,q)|0)+Rb|0;if((wb|0)>=(Lb|0)){Ob=Lb;Pb=Mb;Qb=Nb;break}c[Pa>>2]=vb;c[(Pa+4|0)>>2]=yb;Ob=wb;Pb=yb;Qb=vb}}while(0);vb=v-Kb|0;yb=s-Kb|0;do{if((c[(t+(((vb<<3)+yb&63)<<2)|0)>>2]|0)==(yb+F+(vb<<11)|0|0)){Wb=Ob;Xb=Pb;Yb=Qb}else{wb=c[(a+12416|0)>>2]|0;do{if((C&4|0)==0){L=c[(a+12420|0)>>2]|0;J=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(wb,vb)|0)+yb)|0;qb=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,J,wb,8)|0;if((C&2|0)==0){Zb=qb;break}J=c[(a+12208|0)>>2]|0;Va=(ba(L,vb>>1)|0)+(yb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((vb<<1&2|yb&1)<<2)>>2]&1023](J+(wb<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+Va|0,L,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((vb<<1&2|yb&1)<<2)>>2]&1023](J+(wb<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+Va|0,L,4);Va=(Pe[Fb&255](a,J+(wb<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,L,4)|0)+qb|0;Zb=Va+(Pe[Fb&255](a,J+(wb<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,L,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(yb|0)){Zb=536870912;break}if((yb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Zb=536870912;break}if((c[(a+12272|0)>>2]|0)>(vb|0)){Zb=536870912;break}if((vb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Zb=536870912;break}L=e[(a+13872|0)>>1]|0;J=e[(a+13874|0)>>1]|0;n:do{if((c[(a+11740|0)>>2]|0)==1){if((yb<<G|0)==0){Va=0;while(1){qb=c[a+12160+(Va<<3)>>2]|0;kb=(c[a+12160+(Va<<3)+4>>2]|0)+(vb<<G)|0;pb=((ba(c[a+12128+(Va<<3)>>2]|0,J-L|0)|0)/(L|0)|0)+((Va&1)<<Db)|0;$=c[a+12128+(Va<<3)+4>>2]|0;if((vb<<G|0)==0){T=Va>>1;_b=((ba($,J-L|0)|0)/(L|0)|0)+(T<<Db)|0;$b=T}else{_b=kb-$|0;$b=Va>>1}$=((_b&Gb)<<G)+(pb&Gb)|0;T=(c[(a+12208|0)>>2]|0)+((ba($b,wb<<3)|0)+(Va<<3&8))|0;if(Eb){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kb>>1,wb)|0)+(qb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((kb&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&1023](T,j,wb,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_b>>1,wb)|0)+(pb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+($<<2)>>2]&1023](T,j,wb,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kb>>2,wb)|0)+(qb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((kb&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](T,j,wb);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_b>>2,wb)|0)+(pb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095](T,j,wb)}Va=Va+1|0;if((Va|0)>=4){break n}}}if((vb<<G|0)==0){Va=0;do{j=(c[a+12160+(Va<<3)>>2]|0)+(yb<<G)|0;T=c[a+12160+(Va<<3)+4>>2]|0;$=j-(c[a+12128+(Va<<3)>>2]|0)|0;pb=Va>>1;qb=((ba(c[a+12128+(Va<<3)+4>>2]|0,J-L|0)|0)/(L|0)|0)+(pb<<Db)|0;kb=(c[(a+12208|0)>>2]|0)+((Va<<3&8)+(ba(pb,wb<<3)|0))|0;if(Eb){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(T>>1,wb)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((T&Gb)<<G)+(j&Gb)|0)<<2)>>2]&1023](kb,pb,wb,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(qb>>1,wb)|0)+($>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&1023](kb,pb,wb,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(T>>2,wb)|0)+(j>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095](kb,pb,wb);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(qb>>2,wb)|0)+($>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](kb,pb,wb)}Va=Va+1|0;}while((Va|0)<4)}else{Va=0;do{pb=(c[a+12160+(Va<<3)>>2]|0)+(yb<<G)|0;kb=(c[a+12160+(Va<<3)+4>>2]|0)+(vb<<G)|0;$=pb-(c[a+12128+(Va<<3)>>2]|0)|0;qb=kb-(c[a+12128+(Va<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((Va<<3&8)+(ba(Va>>1,wb<<3)|0))|0;if(Eb){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kb>>1,wb)|0)+(pb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((kb&Gb)<<G)+(pb&Gb)|0)<<2)>>2]&1023](j,T,wb,8);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(qb>>1,wb)|0)+($>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&1023](j,T,wb,8)}else{T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kb>>2,wb)|0)+(pb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((kb&Gb)<<G)+(pb&Gb)|0)<<2)>>2]&4095](j,T,wb);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(qb>>2,wb)|0)+($>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](j,T,wb)}Va=Va+1|0;}while((Va|0)<4)}}else{Va=(c[(a+12160|0)>>2]|0)+(yb<<G)|0;T=(c[(a+12164|0)>>2]|0)+(vb<<G)|0;j=c[(a+12128|0)>>2]|0;if((yb<<G|0)==0){ac=(ba(j,J-L|0)|0)/(L|0)|0}else{ac=Va-j|0}j=c[(a+12132|0)>>2]|0;if((vb<<G|0)==0){bc=(ba(j,J-L|0)|0)/(L|0)|0}else{bc=T-j|0}j=((bc&Gb)<<G)+(ac&Gb)|0;if(Eb){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(T>>1,wb)|0)+(Va>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,$,wb,16);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(bc>>1,wb)|0)+(ac>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+(j<<2)>>2]&1023](c[(a+12208|0)>>2]|0,$,wb,16);break}else{$=(ba(T>>2,wb)|0)+(Va>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+$|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+8|0)|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+(wb<<3))|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(($+8|0)+(wb<<3))|0,wb);$=(ba(bc>>2,wb)|0)+(ac>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+$|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+8|0)|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+(wb<<3))|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(($+8|0)+(wb<<3))|0,wb);break}}}while(0);Zb=Pe[H&255](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,wb,16)|0}}while(0);c[(t+(((vb<<3)+yb&63)<<2)|0)>>2]=yb+F+(vb<<11)|0;c[Na+(((vb<<3)+yb&63)<<2)>>2]=Zb;wb=(ba((d[A+((vb<<G)-B)|0]|0)+(d[A+((yb<<G)-z)|0]|0)|0,q)|0)+Zb|0;if((wb|0)>=(Ob|0)){Wb=Ob;Xb=Pb;Yb=Qb;break}c[Pa>>2]=yb;c[(Pa+4|0)>>2]=vb;Wb=wb;Xb=vb;Yb=yb}}while(0);yb=Kb+xb|0;vb=K-Kb|0;do{if((c[(t+(((yb<<3)+vb&63)<<2)|0)>>2]|0)==(vb+F+(yb<<11)|0|0)){cc=Wb;dc=Xb;ec=Yb}else{wb=c[(a+12416|0)>>2]|0;do{if((C&4|0)==0){L=c[(a+12420|0)>>2]|0;J=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(wb,yb)|0)+vb)|0;$=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,J,wb,8)|0;if((C&2|0)==0){fc=$;break}J=c[(a+12208|0)>>2]|0;j=(ba(L,yb>>1)|0)+(vb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((yb<<1&2|vb&1)<<2)>>2]&1023](J+(wb<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+j|0,L,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((yb<<1&2|vb&1)<<2)>>2]&1023](J+(wb<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+j|0,L,4);j=(Pe[Fb&255](a,J+(wb<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,L,4)|0)+$|0;fc=j+(Pe[Fb&255](a,J+(wb<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,L,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(vb|0)){fc=536870912;break}if((vb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){fc=536870912;break}if((c[(a+12272|0)>>2]|0)>(yb|0)){fc=536870912;break}if((yb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){fc=536870912;break}L=e[(a+13872|0)>>1]|0;J=e[(a+13874|0)>>1]|0;o:do{if((c[(a+11740|0)>>2]|0)==1){if((vb<<G|0)==0){j=0;while(1){$=c[a+12160+(j<<3)>>2]|0;Va=(c[a+12160+(j<<3)+4>>2]|0)+(yb<<G)|0;T=((ba(c[a+12128+(j<<3)>>2]|0,J-L|0)|0)/(L|0)|0)+((j&1)<<Db)|0;qb=c[a+12128+(j<<3)+4>>2]|0;if((yb<<G|0)==0){pb=j>>1;gc=((ba(qb,J-L|0)|0)/(L|0)|0)+(pb<<Db)|0;hc=pb}else{gc=Va-qb|0;hc=j>>1}qb=((gc&Gb)<<G)+(T&Gb)|0;pb=(c[(a+12208|0)>>2]|0)+((ba(hc,wb<<3)|0)+(j<<3&8))|0;if(Eb){kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Va>>1,wb)|0)+($>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Va&Gb)<<G)+($&Gb)|0)<<2)>>2]&1023](pb,kb,wb,8);kb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(gc>>1,wb)|0)+(T>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(qb<<2)>>2]&1023](pb,kb,wb,8)}else{kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Va>>2,wb)|0)+($>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Va&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](pb,kb,wb);kb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(gc>>2,wb)|0)+(T>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(qb<<2)>>2]&4095](pb,kb,wb)}j=j+1|0;if((j|0)>=4){break o}}}if((yb<<G|0)==0){j=0;do{kb=(c[a+12160+(j<<3)>>2]|0)+(vb<<G)|0;pb=c[a+12160+(j<<3)+4>>2]|0;qb=kb-(c[a+12128+(j<<3)>>2]|0)|0;T=j>>1;$=((ba(c[a+12128+(j<<3)+4>>2]|0,J-L|0)|0)/(L|0)|0)+(T<<Db)|0;Va=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ba(T,wb<<3)|0))|0;if(Eb){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,wb)|0)+(kb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&1023](Va,T,wb,8);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>1,wb)|0)+(qb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&1023](Va,T,wb,8)}else{T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>2,wb)|0)+(kb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095](Va,T,wb);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>2,wb)|0)+(qb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](Va,T,wb)}j=j+1|0;}while((j|0)<4)}else{j=0;do{T=(c[a+12160+(j<<3)>>2]|0)+(vb<<G)|0;Va=(c[a+12160+(j<<3)+4>>2]|0)+(yb<<G)|0;qb=T-(c[a+12128+(j<<3)>>2]|0)|0;$=Va-(c[a+12128+(j<<3)+4>>2]|0)|0;kb=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ba(j>>1,wb<<3)|0))|0;if(Eb){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Va>>1,wb)|0)+(T>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Va&Gb)<<G)+(T&Gb)|0)<<2)>>2]&1023](kb,pb,wb,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>1,wb)|0)+(qb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&1023](kb,pb,wb,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Va>>2,wb)|0)+(T>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Va&Gb)<<G)+(T&Gb)|0)<<2)>>2]&4095](kb,pb,wb);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($>>2,wb)|0)+(qb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](kb,pb,wb)}j=j+1|0;}while((j|0)<4)}}else{j=(c[(a+12160|0)>>2]|0)+(vb<<G)|0;pb=(c[(a+12164|0)>>2]|0)+(yb<<G)|0;kb=c[(a+12128|0)>>2]|0;if((vb<<G|0)==0){ic=(ba(kb,J-L|0)|0)/(L|0)|0}else{ic=j-kb|0}kb=c[(a+12132|0)>>2]|0;if((yb<<G|0)==0){jc=(ba(kb,J-L|0)|0)/(L|0)|0}else{jc=pb-kb|0}kb=((jc&Gb)<<G)+(ic&Gb)|0;if(Eb){qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(pb>>1,wb)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,qb,wb,16);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(jc>>1,wb)|0)+(ic>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+(kb<<2)>>2]&1023](c[(a+12208|0)>>2]|0,qb,wb,16);break}else{qb=(ba(pb>>2,wb)|0)+(j>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+qb|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(qb+8|0)|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(qb+(wb<<3))|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((qb+8|0)+(wb<<3))|0,wb);qb=(ba(jc>>2,wb)|0)+(ic>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+qb|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(qb+8|0)|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(qb+(wb<<3))|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((qb+8|0)+(wb<<3))|0,wb);break}}}while(0);fc=Pe[H&255](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,wb,16)|0}}while(0);c[(t+(((yb<<3)+vb&63)<<2)|0)>>2]=vb+F+(yb<<11)|0;c[Na+(((yb<<3)+vb&63)<<2)>>2]=fc;wb=(ba((d[A+((yb<<G)-B)|0]|0)+(d[A+((vb<<G)-z)|0]|0)|0,q)|0)+fc|0;if((wb|0)>=(Wb|0)){cc=Wb;dc=Xb;ec=Yb;break}c[Pa>>2]=vb;c[(Pa+4|0)>>2]=yb;cc=wb;dc=yb;ec=vb}}while(0);vb=Kb+v|0;yb=Kb+m|0;do{if((c[(t+(((vb<<3)+yb&63)<<2)|0)>>2]|0)==(yb+F+(vb<<11)|0|0)){kc=cc;lc=dc;mc=ec}else{wb=c[(a+12416|0)>>2]|0;do{if((C&4|0)==0){L=c[(a+12420|0)>>2]|0;J=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(wb,vb)|0)+yb)|0;qb=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,J,wb,8)|0;if((C&2|0)==0){nc=qb;break}J=c[(a+12208|0)>>2]|0;kb=(ba(L,vb>>1)|0)+(yb>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+32+((vb<<1&2|yb&1)<<2)>>2]&1023](J+(wb<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+kb|0,L,4);cf[c[(c[(a+12444|0)>>2]|0)+32+((vb<<1&2|yb&1)<<2)>>2]&1023](J+(wb<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+kb|0,L,4);kb=(Pe[Fb&255](a,J+(wb<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,L,4)|0)+qb|0;nc=kb+(Pe[Fb&255](a,J+(wb<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,L,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(yb|0)){nc=536870912;break}if((yb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){nc=536870912;break}if((c[(a+12272|0)>>2]|0)>(vb|0)){nc=536870912;break}if((vb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){nc=536870912;break}L=e[(a+13872|0)>>1]|0;J=e[(a+13874|0)>>1]|0;p:do{if((c[(a+11740|0)>>2]|0)==1){if((yb<<G|0)==0){kb=0;while(1){qb=c[a+12160+(kb<<3)>>2]|0;j=(c[a+12160+(kb<<3)+4>>2]|0)+(vb<<G)|0;pb=((ba(c[a+12128+(kb<<3)>>2]|0,J-L|0)|0)/(L|0)|0)+((kb&1)<<Db)|0;$=c[a+12128+(kb<<3)+4>>2]|0;if((vb<<G|0)==0){T=kb>>1;oc=((ba($,J-L|0)|0)/(L|0)|0)+(T<<Db)|0;pc=T}else{oc=j-$|0;pc=kb>>1}$=((oc&Gb)<<G)+(pb&Gb)|0;T=(c[(a+12208|0)>>2]|0)+((ba(pc,wb<<3)|0)+(kb<<3&8))|0;if(Eb){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>1,wb)|0)+(qb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&1023](T,Va,wb,8);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(oc>>1,wb)|0)+(pb>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+($<<2)>>2]&1023](T,Va,wb,8)}else{Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>2,wb)|0)+(qb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((j&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](T,Va,wb);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(oc>>2,wb)|0)+(pb>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095](T,Va,wb)}kb=kb+1|0;if((kb|0)>=4){break p}}}if((vb<<G|0)==0){kb=0;do{Va=(c[a+12160+(kb<<3)>>2]|0)+(yb<<G)|0;T=c[a+12160+(kb<<3)+4>>2]|0;$=Va-(c[a+12128+(kb<<3)>>2]|0)|0;pb=kb>>1;qb=((ba(c[a+12128+(kb<<3)+4>>2]|0,J-L|0)|0)/(L|0)|0)+(pb<<Db)|0;j=(c[(a+12208|0)>>2]|0)+((kb<<3&8)+(ba(pb,wb<<3)|0))|0;if(Eb){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(T>>1,wb)|0)+(Va>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&1023](j,pb,wb,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(qb>>1,wb)|0)+($>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&1023](j,pb,wb,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(T>>2,wb)|0)+(Va>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095](j,pb,wb);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(qb>>2,wb)|0)+($>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](j,pb,wb)}kb=kb+1|0;}while((kb|0)<4)}else{kb=0;do{pb=(c[a+12160+(kb<<3)>>2]|0)+(yb<<G)|0;j=(c[a+12160+(kb<<3)+4>>2]|0)+(vb<<G)|0;$=pb-(c[a+12128+(kb<<3)>>2]|0)|0;qb=j-(c[a+12128+(kb<<3)+4>>2]|0)|0;Va=(c[(a+12208|0)>>2]|0)+((kb<<3&8)+(ba(kb>>1,wb<<3)|0))|0;if(Eb){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>1,wb)|0)+(pb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Gb)<<G)+(pb&Gb)|0)<<2)>>2]&1023](Va,T,wb,8);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(qb>>1,wb)|0)+($>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&1023](Va,T,wb,8)}else{T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(j>>2,wb)|0)+(pb>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((j&Gb)<<G)+(pb&Gb)|0)<<2)>>2]&4095](Va,T,wb);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(qb>>2,wb)|0)+($>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](Va,T,wb)}kb=kb+1|0;}while((kb|0)<4)}}else{kb=(c[(a+12160|0)>>2]|0)+(yb<<G)|0;T=(c[(a+12164|0)>>2]|0)+(vb<<G)|0;Va=c[(a+12128|0)>>2]|0;if((yb<<G|0)==0){qc=(ba(Va,J-L|0)|0)/(L|0)|0}else{qc=kb-Va|0}Va=c[(a+12132|0)>>2]|0;if((vb<<G|0)==0){rc=(ba(Va,J-L|0)|0)/(L|0)|0}else{rc=T-Va|0}Va=((rc&Gb)<<G)+(qc&Gb)|0;if(Eb){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(T>>1,wb)|0)+(kb>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,$,wb,16);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(rc>>1,wb)|0)+(qc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+(Va<<2)>>2]&1023](c[(a+12208|0)>>2]|0,$,wb,16);break}else{$=(ba(T>>2,wb)|0)+(kb>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+$|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+8|0)|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+(wb<<3))|0,wb);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(($+8|0)+(wb<<3))|0,wb);$=(ba(rc>>2,wb)|0)+(qc>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+$|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+8|0)|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+(wb<<3))|0,wb);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(($+8|0)+(wb<<3))|0,wb);break}}}while(0);nc=Pe[H&255](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,wb,16)|0}}while(0);c[(t+(((vb<<3)+yb&63)<<2)|0)>>2]=yb+F+(vb<<11)|0;c[Na+(((vb<<3)+yb&63)<<2)>>2]=nc;wb=(ba((d[A+((vb<<G)-B)|0]|0)+(d[A+((yb<<G)-z)|0]|0)|0,q)|0)+nc|0;if((wb|0)>=(cc|0)){kc=cc;lc=dc;mc=ec;break}c[Pa>>2]=yb;c[(Pa+4|0)>>2]=vb;kc=wb;lc=vb;mc=yb}}while(0);yb=Kb+2|0;if((yb|0)<(u|0)){Kb=yb;Lb=kc;Mb=lc;Nb=mc}else{break}}if((K|0)!=(mc|0)){I=kc;K=mc;v=lc;y=mc;continue l}if((v|0)==(lc|0)){Hb=kc;Ib=v;Jb=K}else{I=kc;K=K;v=lc;y=mc;continue l}}else{Hb=x;Ib=n;Jb=r}}while(0);R=u+1|0;if((R|0)<5){u=R;x=Hb;n=Ib;r=Jb}else{sc=Hb;break l}}}tc=c[Pa>>2]|0;c[f>>2]=tc;uc=p+4|0;vc=c[uc>>2]|0;c[h>>2]=vc;i=o;return sc|0}if((Oa|0)<-1){sc=Fmb(a,Pa,k,l,q,1,8,C)|0;tc=c[Pa>>2]|0;c[f>>2]=tc;uc=p+4|0;vc=c[uc>>2]|0;c[h>>2]=vc;i=o;return sc|0}c[o+16>>2]=a;c[o+24>>2]=f;c[o+32>>2]=h;c[o+48>>2]=k;c[o+56>>2]=l;c[o+80>>2]=p;c[o+88>>2]=q;c[o+176>>2]=C;c[o+192>>2]=G;c[o+6144>>2]=Bb;c[o+6152>>2]=Ab;c[o+6160>>2]=zb;c[o+6168>>2]=Pa;c[o+6176>>2]=Oa;c[o+19104>>2]=sc;c[o+19112>>2]=tc;c[o+19120>>2]=uc;c[o+19128>>2]=vc;c[o+19152>>2]=0;c[o+19156>>2]=0;_epzs_motion_search4$0(o);sc=c[o+19104>>2]|0;tc=c[o+19112>>2]|0;uc=c[o+19120>>2]|0;vc=c[o+19128>>2]|0;D=c[o+19152>>2]|0;w=c[o+19156>>2]|0;E=+g[o+19156>>2];c[o+19152>>2]=0;c[o+19156>>2]=0;if((D|0)==6){return w|0}return 0|0;return 0}function Kmb(a,b,d,f,g,h,i,j,k,l,m,n){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;if((n&4|0)==0){o=n&2;n=c[a+12416>>2]|0;p=c[a+12420>>2]|0;q=(g<<1)+f|0;r=d<<1;s=a+12352+(j<<4)|0;t=a+12288+(k<<4)|0;do{if((q|0)==0){u=(c[s>>2]|0)+((ba(n,d)|0)+b)|0;v=Pe[l&255](a,c[t>>2]|0,u,n,i)|0;if((o|0)==0){w=v;return w|0}else{x=v;y=r&2|b&1;break}}else{v=a+12208|0;u=(c[s>>2]|0)+((ba(n,d)|0)+b)|0;cf[c[(c[a+12444>>2]|0)+(h<<4)+(q<<2)>>2]&1023](c[v>>2]|0,u,n,i);if((o|0)==0){z=0}else{z=r&2|b&1|q}x=Pe[l&255](a,c[v>>2]|0,c[t>>2]|0,n,i)|0;y=z}}while(0);if((o|0)==0){w=x;return w|0}o=c[a+12208>>2]|0;z=n<<4;n=o+z|0;t=h+1|0;h=a+12444|0;q=(ba(p,d>>1)|0)+(b>>1)|0;r=i>>1;cf[c[(c[h>>2]|0)+(t<<4)+(y<<2)>>2]&1023](n,(c[a+12352+(j<<4)+4>>2]|0)+q|0,p,r);i=o+(z|8)|0;cf[c[(c[h>>2]|0)+(t<<4)+(y<<2)>>2]&1023](i,(c[a+12352+(j<<4)+8>>2]|0)+q|0,p,r);q=a;y=(Pe[m&255](q,n,c[a+12288+(k<<4)+4>>2]|0,p,r)|0)+x|0;w=y+(Pe[m&255](q,i,c[a+12288+(k<<4)+8>>2]|0,p,r)|0)|0;return w|0}r=c[a+12416>>2]|0;p=(b<<1)+f|0;f=(d<<1)+g|0;g=a+12352+(j<<4)|0;i=a+12288+(k<<4)|0;if((c[a+12264>>2]|0)>(b|0)){w=536870912;return w|0}if((p|0)>(c[a+12268>>2]<<1|0)){w=536870912;return w|0}if((c[a+12272>>2]|0)>(d|0)){w=536870912;return w|0}if((f|0)>(c[a+12276>>2]<<1|0)){w=536870912;return w|0}d=e[a+13872>>1]|0;b=e[a+13874>>1]|0;a:do{if((c[a+11740>>2]|0)==1){k=b-d|0;q=(f|0)==0;m=a+12208|0;y=r<<3;x=a+12444|0;n=a+12448|0;t=a+12352+(j<<4)+32|0;if((p|0)==0){A=0}else{if(q){h=0;while(1){z=(c[a+12160+(h<<3)>>2]|0)+p|0;o=c[a+12160+(h<<3)+4>>2]|0;s=z-(c[a+12128+(h<<3)>>2]|0)|0;v=h>>1;u=((ba(c[a+12128+(h<<3)+4>>2]|0,k)|0)/(d|0)|0)+(v<<4)|0;B=(c[m>>2]|0)+((h<<3&8)+(ba(v,y)|0))|0;v=(c[g>>2]|0)+((ba(o>>1,r)|0)+(z>>1))|0;cf[c[(c[x>>2]|0)+16+((o<<1&2|z&1)<<2)>>2]&1023](B,v,r,8);v=(c[t>>2]|0)+((ba(u>>1,r)|0)+(s>>1))|0;cf[c[(c[n>>2]|0)+16+((u<<1&2|s&1)<<2)>>2]&1023](B,v,r,8);h=h+1|0;if((h|0)>=4){break a}}}else{h=0;while(1){v=(c[a+12160+(h<<3)>>2]|0)+p|0;B=(c[a+12160+(h<<3)+4>>2]|0)+f|0;s=v-(c[a+12128+(h<<3)>>2]|0)|0;u=B-(c[a+12128+(h<<3)+4>>2]|0)|0;z=(c[m>>2]|0)+((h<<3&8)+(ba(h>>1,y)|0))|0;o=(c[g>>2]|0)+((ba(B>>1,r)|0)+(v>>1))|0;cf[c[(c[x>>2]|0)+16+((B<<1&2|v&1)<<2)>>2]&1023](z,o,r,8);o=(c[t>>2]|0)+((ba(u>>1,r)|0)+(s>>1))|0;cf[c[(c[n>>2]|0)+16+((u<<1&2|s&1)<<2)>>2]&1023](z,o,r,8);h=h+1|0;if((h|0)>=4){break a}}}}do{h=c[a+12160+(A<<3)>>2]|0;o=(c[a+12160+(A<<3)+4>>2]|0)+f|0;z=((ba(c[a+12128+(A<<3)>>2]|0,k)|0)/(d|0)|0)+(A<<4&16)|0;s=c[a+12128+(A<<3)+4>>2]|0;if(q){u=A>>1;C=((ba(s,k)|0)/(d|0)|0)+(u<<4)|0;D=u}else{C=o-s|0;D=A>>1}s=(c[m>>2]|0)+((ba(D,y)|0)+(A<<3&8))|0;u=(c[g>>2]|0)+((ba(o>>1,r)|0)+(h>>1))|0;cf[c[(c[x>>2]|0)+16+((o<<1&2|h&1)<<2)>>2]&1023](s,u,r,8);u=(c[t>>2]|0)+((ba(C>>1,r)|0)+(z>>1))|0;cf[c[(c[n>>2]|0)+16+((C<<1&2|z&1)<<2)>>2]&1023](s,u,r,8);A=A+1|0;}while((A|0)<4)}else{n=(c[a+12160>>2]|0)+p|0;t=(c[a+12164>>2]|0)+f|0;x=c[a+12128>>2]|0;if((p|0)==0){E=(ba(x,b-d|0)|0)/(d|0)|0}else{E=n-x|0}x=c[a+12132>>2]|0;if((f|0)==0){F=(ba(x,b-d|0)|0)/(d|0)|0}else{F=t-x|0}x=a+12208|0;y=(c[g>>2]|0)+((ba(t>>1,r)|0)+(n>>1))|0;cf[c[(c[a+12444>>2]|0)+((t<<1&2|n&1)<<2)>>2]&1023](c[x>>2]|0,y,r,16);y=(c[a+12352+(j<<4)+32>>2]|0)+((ba(F>>1,r)|0)+(E>>1))|0;cf[c[(c[a+12448>>2]|0)+((F<<1&2|E&1)<<2)>>2]&1023](c[x>>2]|0,y,r,16)}}while(0);w=Pe[l&255](a,c[a+12208>>2]|0,c[i>>2]|0,r,16)|0;return w|0}function Lmb(){eOa(6870480);return}function Mmb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0;f=i;i=i+8|0;h=f|0;TGb(a+20944|0,0,9216)|0;if((b|0)>=0){j=0;k=0;while(1){l=0;do{m=a+1572+(k*52|0)+4+(l<<2)|0;n=c[m>>2]|0;if((n|0)!=0){o=+g[649688+(n+1<<2)>>2]*+g[648664+((c[a+1572+(k*52|0)+20+(l*12|0)>>2]&255)<<2)>>2];c[a+20944+(l*4608|0)+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j<<2)>>2]|0));c[a+20944+(l*4608|0)+128+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+((j|1)<<2)>>2]|0));c[a+20944+(l*4608|0)+256+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+((j|2)<<2)>>2]|0));c[a+20944+(l*4608|0)+384+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+((j|3)<<2)>>2]|0));c[a+20944+(l*4608|0)+512+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+4<<2)>>2]|0));c[a+20944+(l*4608|0)+640+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+5<<2)>>2]|0));c[a+20944+(l*4608|0)+768+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+6<<2)>>2]|0));c[a+20944+(l*4608|0)+896+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+7<<2)>>2]|0));c[a+20944+(l*4608|0)+1024+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+8<<2)>>2]|0));c[a+20944+(l*4608|0)+1152+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+9<<2)>>2]|0));c[a+20944+(l*4608|0)+1280+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+10<<2)>>2]|0));c[a+20944+(l*4608|0)+1408+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+11<<2)>>2]|0));o=+g[649688+((c[m>>2]|0)+1<<2)>>2]*+g[648664+((c[a+1572+(k*52|0)+20+(l*12|0)+4>>2]&255)<<2)>>2];c[a+20944+(l*4608|0)+1536+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+12<<2)>>2]|0));c[a+20944+(l*4608|0)+1664+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+13<<2)>>2]|0));c[a+20944+(l*4608|0)+1792+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+14<<2)>>2]|0));c[a+20944+(l*4608|0)+1920+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+15<<2)>>2]|0));c[a+20944+(l*4608|0)+2048+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+16<<2)>>2]|0));c[a+20944+(l*4608|0)+2176+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+17<<2)>>2]|0));c[a+20944+(l*4608|0)+2304+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+18<<2)>>2]|0));c[a+20944+(l*4608|0)+2432+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+19<<2)>>2]|0));c[a+20944+(l*4608|0)+2560+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+20<<2)>>2]|0));c[a+20944+(l*4608|0)+2688+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+21<<2)>>2]|0));c[a+20944+(l*4608|0)+2816+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+22<<2)>>2]|0));c[a+20944+(l*4608|0)+2944+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+23<<2)>>2]|0));o=+g[649688+((c[m>>2]|0)+1<<2)>>2]*+g[648664+((c[a+1572+(k*52|0)+20+(l*12|0)+8>>2]&255)<<2)>>2];m=24;do{c[a+20944+(l*4608|0)+(m<<7)+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(m+j<<2)>>2]|0));m=m+1|0;}while((m|0)<36)}l=l+1|0;}while((l|0)<2);if((c[a+1572+(k*52|0)>>2]|0)!=0){l=0;do{m=a+20944+(l<<7)+(k<<2)|0;n=c[m>>2]|0;p=a+25552+(l<<7)+(k<<2)|0;q=c[p>>2]|0;c[m>>2]=q+n;c[p>>2]=n-q;l=l+1|0;}while((l|0)<36)}l=k+1|0;if((l|0)>(b|0)){break}else{j=j+36|0;k=l}}}c[h>>2]=0;if((e|0)<=0){i=f;return}k=a+1244|0;j=0;do{b=a+12736+(j<<12)|0;l=a+20928+(j<<2)|0;q=d+(j<<2)|0;n=0;do{dOa(k,b,l,6870480,h,(c[q>>2]|0)+(n<<5<<1)|0,1,a+20944+(j*4608|0)+(n<<7)|0);n=n+1|0;}while((n|0)<36);j=j+1|0;}while((j|0)<(e|0));i=f;return}function Nmb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=(a|0)/(b|0)|0;if((d|0)!=0){f=4;return f|0}if((c|0)==48e3&(e|0)>55|(e-56|0)>>>0<25>>>0){f=0;return f|0}if((c|0)!=48e3&(e|0)>95){f=1;return f|0}else{return((c|0)!=32e3&(e|0)<49?2:3)|0}return 0}function Omb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a+14092>>2]|0;a:do{switch(b|0){case 3:{e=a+9888|0;if((c[a+84>>2]|0)==0){c[e>>2]=1175896;c[a+9892>>2]=1177264;break a}else{c[e>>2]=1167280;c[a+9892>>2]=1080960;f=8;break a}break};case 1:case 2:{c[a+9892>>2]=1179688;c[a+9888>>2]=1179688;break};case 4:case 5:{c[a+9888>>2]=1080464;c[a+9892>>2]=1080960;f=9;break};case 6:{c[a+9888>>2]=1080032;c[a+9892>>2]=1080032;f=9;break};default:{f=8}}}while(0);if((f|0)==8){if((b|0)>3){f=9}}if((f|0)==9){f=a+11184|0;x2(f,a+364|0,1080560);x2(f,a+496|0,1080624);x2(f,a+628|0,1080688);x2(f,a+232|0,1080496)}if((c[1349151]|0)==0){g=-256}else{return}do{a=-g|0;f=(g|0)>-1?g:a;if((f|0)==0){h=0}else{b=0;e=f;while(1){f=e>>1;i=b+1|0;if((f|0)==0){h=i;break}else{b=i;e=f}}}if((g|0)<0){j=(1<<h)-1^a}else{j=g}e=d[1177297+(h<<1)|0]|0;b=(1<<e)-1^(d[1177296+(h<<1)|0]|0);f=(h|0)>0;do{if(f){i=b<<h|j;k=e+h|0;if((h|0)<=8){l=k;m=i;break}l=k+1|0;m=i<<1|1}else{l=e;m=b}}while(0);b=g+256|0;c[5388416+(b<<3)>>2]=m;c[5388420+(b<<3)>>2]=l;e=d[1177329+(h<<1)|0]|0;a=(1<<e)-1^(d[1177328+(h<<1)|0]|0);do{if(f){i=a<<h|j;k=e+h|0;if((h|0)<=8){n=k;o=i;break}n=k+1|0;o=i<<1|1}else{n=e;o=a}}while(0);c[5392512+(b<<3)>>2]=o;c[5392516+(b<<3)>>2]=n;g=g+1|0;}while((g|0)<256);return}function Pmb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[b+12496+(d<<2)>>2]|0;d=c[b+128>>2]|0;g=f-1|0;h=c[b+9904>>2]|0;b=a[h+(f-d)|0]|0;if((a[h+(g-d)|0]|0)==b<<24>>24){i=a[h+g|0]|0}else{i=b}c[e>>2]=h+f;return i&255|0}function Qmb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=(e|0)<4;i=c[(h?a+168|0:a+172|0)>>2]|0;j=c[a+12520+(e<<2)>>2]|0;k=c[a+9876>>2]|0;l=c[a+12496+(e<<2)>>2]|0;m=k+(l<<1)|0;n=b[k+(l-1<<1)>>1]|0;o=b[k+(l+~j<<1)>>1]|0;p=b[k+(l-j<<1)>>1]|0;do{if((c[a+14084>>2]|0)==0){q=o;r=p}else{if((e&2|0)!=0){q=o;r=p;break}j=(c[a+14092>>2]|0)<4;q=j?1024:o;r=j?1024:p}}while(0);if((i|0)==8){s=(n+4|0)/8|0;t=(q+4|0)/8|0;u=(r+4|0)/8|0}else{p=i>>1;o=n+p|0;n=c[1199552+(i<<2)>>2]|0;j=0;gHb(n,j,o,(o|0)<0|0?-1:0)|0;o=F;l=q+p|0;gHb(n,j,l,(l|0)<0|0?-1:0)|0;l=F;q=r+p|0;gHb(n,j,q,(q|0)<0|0?-1:0)|0;s=o;t=l;u=F}if((c[a+14092>>2]|0)<=3){l=s-t|0;o=t-u|0;if((((l|0)>-1?l:-l|0)|0)>(((o|0)>-1?o:-o|0)|0)){c[g>>2]=0;v=s;c[f>>2]=m;return v|0}else{c[g>>2]=1;v=u;c[f>>2]=m;return v|0}}if((c[a+14112>>2]|0)==0){o=s-t|0;l=t-u|0;if((((o|0)>-1?o:-o|0)|0)<(((l|0)>-1?l:-l|0)|0)){c[g>>2]=1;v=u;c[f>>2]=m;return v|0}else{c[g>>2]=0;v=s;c[f>>2]=m;return v|0}}if((e|0)==1){c[g>>2]=0;v=s;c[f>>2]=m;return v|0}else if((e|0)==2){c[g>>2]=1;v=u;c[f>>2]=m;return v|0}else if((e|0)==3){l=s-t|0;o=t-u|0;if((((l|0)>-1?l:-l|0)|0)<(((o|0)>-1?o:-o|0)|0)){c[g>>2]=1;v=u;c[f>>2]=m;return v|0}else{c[g>>2]=0;v=s;c[f>>2]=m;return v|0}}else{s=c[(c[a+4>>2]|0)+800>>2]|0;u=8>>>(s>>>0);if(h){h=c[a+148>>2]|0;o=c[a+12480>>2]|0;l=ba((o<<1)+(e>>1)|0,h)|0;t=c[a+12476>>2]|0;w=h;x=(c[a+7624>>2]|0)+(ba((t<<1|e&1)+l|0,u)|0)|0;y=t;z=o}else{o=c[a+152>>2]|0;t=c[a+12480>>2]|0;l=ba(t,o)|0;h=c[a+12476>>2]|0;w=o;x=(c[a+7624+(e-3<<2)>>2]|0)+(ba(h+l|0,u)|0)|0;y=h;z=t}if((y|0)==0){A=((i>>1)+1024|0)/(i|0)|0}else{y=i<<3>>(s<<1);if((u|0)>0){t=0;h=0;while(1){l=(ba(t,w)|0)-u|0;o=h;q=0;do{o=(d[x+(l+q)|0]|0)+o|0;q=q+1|0;}while((q|0)<(u|0));q=t+1|0;if((q|0)<(u|0)){t=q;h=o}else{B=o;break}}}else{B=0}h=B+(y>>1)|0;gHb(c[1199552+(y<<2)>>2]|0,0,h,(h|0)<0|0?-1:0)|0;A=F}if((z|0)==0){C=((i>>1)+1024|0)/(i|0)|0}else{z=i<<3>>(s<<1);if((u|0)>0){s=0;i=0;while(1){h=ba(s-u|0,w)|0;y=i;B=0;do{y=(d[x+(h+B)|0]|0)+y|0;B=B+1|0;}while((B|0)<(u|0));B=s+1|0;if((B|0)<(u|0)){s=B;i=y}else{D=y;break}}}else{D=0}i=D+(z>>1)|0;gHb(c[1199552+(z<<2)>>2]|0,0,i,(i|0)<0|0?-1:0)|0;C=F}i=c[a+13820>>2]|0;if((i|0)==0){c[g>>2]=0;v=A;c[f>>2]=m;return v|0}else if((i|0)==1){if((e|0)==0){c[g>>2]=1;v=C;c[f>>2]=m;return v|0}else{c[g>>2]=0;v=A;c[f>>2]=m;return v|0}}else if((i|0)==2){if((e|0)==0){c[g>>2]=0;v=A;c[f>>2]=m;return v|0}else{c[g>>2]=1;v=C;c[f>>2]=m;return v|0}}else{c[g>>2]=1;v=C;c[f>>2]=m;return v|0}}return 0}function Rmb(a,e){a=a|0;e=e|0;var f=0,h=0,j=0,k=0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;f=i;i=i+256|0;h=f|0;j=0;k=0;do{l=+(j|0);m=+g[a+(k<<2)>>2];j=~~(l>m?l:m);k=k+1|0;}while((k|0)<124);do{if((j|0)==0){n=15;o=15;p=7}else{k=(j|0)>-1?j:-j|0;q=k>>>0>65535>>>0;r=q?k>>>16:k;k=q?16:0;if((r&65280|0)==0){s=k;t=r}else{s=k|8;t=r>>>8}r=65550-s-(d[1191992+t|0]|0)&65535;k=r<<16>>16;q=-k|0;if(r<<16>>16>0){n=r;o=k;p=7;break}else{u=0;v=0}while(1){k=((~~+g[a+(v<<2)>>2]>>q<<16>>16)*3|0)>>>2&65535;b[h+(v<<1)>>1]=k;w=(k<<16>>16)+u|0;k=v+1|0;if((k|0)<124){u=w;v=k}else{x=w;y=r;break}}}}while(0);if((p|0)==7){p=0;v=0;while(1){u=((~~+g[a+(v<<2)>>2]<<o<<16>>16)*3|0)>>>2&65535;b[h+(v<<1)>>1]=u;t=(u<<16>>16)+p|0;u=v+1|0;if((u|0)<124){p=t;v=u}else{x=t;y=n;break}}}n=(y+11&65535)<<16>>16;v=198<<n;p=x-v|0;if((x|0)==(v|0)){z=31;A=0}else{v=(p|0)>-1?p:-p|0;x=v>>>0>65535>>>0;o=x?v>>>16:v;v=x?16:0;if((o&65280|0)==0){B=v;C=o}else{B=v|8;C=o>>>8}o=30-B-(d[1191992+C|0]|0)|0;z=o;A=((p<<o>>16)*4228|0)>>15}o=-65524-z<<16;z=o>>16;if((o|0)>0){D=A<<z}else{D=A>>-z}z=D<<16>>16;A=n-1|0;n=0;o=0;do{p=((b[h+(o<<1)>>1]|0)-z>>A)+1>>1;if((p|0)<0){E=0}else{E=(p|0)>6?6:p}n=E+n|0;o=o+1|0;}while((o|0)<124);if((n|0)==198){F=D;G=198}else{o=n-198|0;if((((o|0)>-1?o:198-n|0)|0)<16384){E=0;z=o;while(1){p=z<<1;C=E+1&65535;if((((p|0)>-1?p:-p|0)|0)<16384){E=C;z=p}else{H=C;I=p;break}}}else{H=0;I=o}o=(I*4228|0)>>15;I=(y+7&65535)-H&65535;H=I<<16>>16;if(I<<16>>16>0){J=o<<H}else{J=o>>-H}H=D;D=0;o=0;I=n;n=1;while(1){K=(n|0)<20;if(!K){L=H;M=D;N=o;O=I;break}y=H+J|0;z=y<<16>>16;E=0;p=0;do{C=((b[h+(p<<1)>>1]|0)-z>>A)+1>>1;if((C|0)<0){P=0}else{P=(C|0)>6?6:C}E=P+E|0;p=p+1|0;}while((p|0)<124);if((ba(E-198|0,I-198|0)|0)<1){L=y;M=H;N=I;O=E;break}else{D=H;H=y;o=I;I=E;n=n+1|0}}I=(O|0)>198;o=I?N:O;H=I?O:N;N=I?L:M;D=I?M:L;if((O|0)!=198&K){K=n;n=o;O=H;L=N;M=D;while(1){I=M+L>>1;P=I<<16>>16;J=0;p=0;do{z=((b[h+(p<<1)>>1]|0)-P>>A)+1>>1;if((z|0)<0){Q=0}else{Q=(z|0)>6?6:z}J=Q+J|0;p=p+1|0;}while((p|0)<124);p=(J|0)>198;P=p?n:J;E=p?J:O;y=p?I:L;z=p?M:I;p=K+1|0;if((J|0)!=198&(p|0)<20){K=p;n=P;O=E;L=y;M=z}else{R=P;S=E;T=y;U=z;break}}}else{R=o;S=H;T=N;U=D}D=S-198|0;N=R-198|0;H=(((D|0)>-1?D:198-S|0)|0)<(((N|0)>-1?N:198-R|0)|0);F=H?T:U;G=H?S:R}R=0;do{S=((b[h+(R<<1)>>1]|0)-F>>A)+1>>1;if((S|0)<0){V=0}else{V=(S|0)>6?6:S}c[e+(R<<2)>>2]=V;R=R+1|0;}while((R|0)<124);if((G|0)>198){W=0;X=0}else{i=f;return}while(1){Y=e+(W<<2)|0;Z=c[Y>>2]|0;_=Z+X|0;$=W+1|0;if((_|0)<198){W=$;X=_}else{break}}c[Y>>2]=198-_+Z;if(($|0)>=124){i=f;return}TGb(e+($<<2)|0,0,(W*-4|0)+492|0)|0;i=f;return}function Smb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;do{if((c|0)==0){d=0}else{if(!((2147483647/(c>>>0)|0)>>>0>b>>>0)){d=0;break}d=cEb(ba(c,b)|0)|0}}while(0);return d|0}function Tmb(a,b){a=a|0;b=b|0;ZDb(b);return}function Umb(a){a=a|0;return((a&3|0)==2?3:1)+(a>>>2&1)|0}function Vmb(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;e=d[1155568+a|0]|0;if((e|0)>=(c|0)){f=0;return f|0}g=d[1155560+a|0]|0;f=(ba(c-1-e+(1<<g)>>g,b)|0)+7>>3;return f|0}function Wmb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;f=i;i=i+64|0;g=f|0;h=f+32|0;j=g|0;k=e|0;l=c[k>>2]|0;m=e+8|0;n=c[m>>2]|0;a:do{if(l>>>0<n>>>0){o=l;while(1){p=o+1|0;c[k>>2]=p;q=a[o]|0;r=q&255;b:do{if(q<<24>>24==35){s=r;t=p;while(1){if(!(t>>>0<n>>>0)){u=s;v=t;break b}w=t+1|0;c[k>>2]=w;x=a[t]|0;if(x<<24>>24==10){u=10;v=w;break}else{s=x&255;t=w}}}else{if((r|0)==32|(r|0)==13|(r|0)==10){u=r;v=p;break}if(q<<24>>24==9){u=r;v=p}else{y=r;z=p;break a}}}while(0);if(v>>>0<n>>>0){o=v}else{y=u;z=v;break}}}else{y=0;z=l}}while(0);c:do{if(z>>>0<n>>>0){l=g;v=j;u=y;o=z;p=n;while(1){if((u|0)==32|(u|0)==13|(u|0)==10|(u|0)==9){A=v;break c}if((v-l|0)<31){a[v]=u;B=v+1|0;C=c[k>>2]|0;D=c[m>>2]|0}else{B=v;C=o;D=p}r=C+1|0;c[k>>2]=r;if(r>>>0<D>>>0){v=B;u=d[C]|0;o=r;p=D}else{A=B;break}}}else{A=j}}while(0);a[A]=0;A=a[g+1|0]|0;c[e+16>>2]=A-48;if((a[j]|0)!=80){E=-1094995529;i=f;return E|0}d:do{switch(A|0){case 49:case 52:{c[b+140>>2]=9;break};case 50:case 53:{B=b+140|0;if((c[b+48>>2]|0)==66){c[B>>2]=0;break d}else{c[B>>2]=8;break d}break};case 51:case 54:{c[b+140>>2]=2;break};case 55:{B=h|0;a[B]=0;D=g;C=h;n=-1;z=-1;y=-1;p=-1;e:while(1){o=n;u=z;F=y;f:while(1){v=o;G=u;g:while(1){H=v;h:while(1){while(1){l=c[k>>2]|0;r=c[m>>2]|0;i:do{if(l>>>0<r>>>0){q=l;while(1){t=q+1|0;c[k>>2]=t;s=a[q]|0;w=s&255;j:do{if(s<<24>>24==35){x=w;I=t;while(1){if(!(I>>>0<r>>>0)){J=x;K=I;break j}L=I+1|0;c[k>>2]=L;M=a[I]|0;if(M<<24>>24==10){J=10;K=L;break}else{x=M&255;I=L}}}else{if((w|0)==32|(w|0)==13|(w|0)==10){J=w;K=t;break}if(s<<24>>24==9){J=w;K=t}else{N=w;O=t;break i}}}while(0);if(K>>>0<r>>>0){q=K}else{N=J;O=K;break}}}else{N=0;O=l}}while(0);k:do{if(O>>>0<r>>>0){l=j;q=N;t=O;w=r;while(1){if((q|0)==32|(q|0)==13|(q|0)==10|(q|0)==9){P=l;break k}if((l-D|0)<31){a[l]=q;Q=l+1|0;R=c[k>>2]|0;S=c[m>>2]|0}else{Q=l;R=t;S=w}s=R+1|0;c[k>>2]=s;if(s>>>0<S>>>0){l=Q;q=d[R]|0;t=s;w=S}else{P=Q;break}}}else{P=j}}while(0);a[P]=0;if((QGb(j,2171720)|0)==0){break g}if((QGb(j,2302952)|0)==0){break f}if((QGb(j,2172960)|0)==0){break h}if((QGb(j,2098448)|0)==0){break}if((QGb(j,2043280)|0)!=0){if((QGb(j,1998112)|0)!=0){break e}}r=c[k>>2]|0;w=c[m>>2]|0;l:do{if(r>>>0<w>>>0){t=r;while(1){q=t+1|0;c[k>>2]=q;l=a[t]|0;s=l&255;m:do{if(l<<24>>24==35){I=s;x=q;while(1){if(!(x>>>0<w>>>0)){T=I;U=x;break m}L=x+1|0;c[k>>2]=L;M=a[x]|0;if(M<<24>>24==10){T=10;U=L;break}else{I=M&255;x=L}}}else{if((s|0)==32|(s|0)==13|(s|0)==10){T=s;U=q;break}if(l<<24>>24==9){T=s;U=q}else{V=s;W=q;break l}}}while(0);if(U>>>0<w>>>0){t=U}else{V=T;W=U;break}}}else{V=0;W=r}}while(0);n:do{if(W>>>0<w>>>0){r=B;t=V;q=W;s=w;while(1){if((t|0)==32|(t|0)==13|(t|0)==10|(t|0)==9){X=r;break n}if((r-C|0)<31){a[r]=t;Y=r+1|0;Z=c[k>>2]|0;_=c[m>>2]|0}else{Y=r;Z=q;_=s}l=Z+1|0;c[k>>2]=l;if(l>>>0<_>>>0){r=Y;t=d[Z]|0;q=l;s=_}else{X=Y;break}}}else{X=B}}while(0);a[X]=0}w=c[k>>2]|0;s=c[m>>2]|0;o:do{if(w>>>0<s>>>0){q=w;while(1){t=q+1|0;c[k>>2]=t;r=a[q]|0;l=r&255;p:do{if(r<<24>>24==35){x=l;I=t;while(1){if(!(I>>>0<s>>>0)){$=x;aa=I;break p}L=I+1|0;c[k>>2]=L;M=a[I]|0;if(M<<24>>24==10){$=10;aa=L;break}else{x=M&255;I=L}}}else{if((l|0)==32|(l|0)==13|(l|0)==10){$=l;aa=t;break}if(r<<24>>24==9){$=l;aa=t}else{ba=l;ca=t;break o}}}while(0);if(aa>>>0<s>>>0){q=aa}else{ba=$;ca=aa;break}}}else{ba=0;ca=w}}while(0);q:do{if(ca>>>0<s>>>0){w=j;q=ba;t=ca;l=s;while(1){if((q|0)==32|(q|0)==13|(q|0)==10|(q|0)==9){da=w;break q}if((w-D|0)<31){a[w]=q;ea=w+1|0;fa=c[k>>2]|0;ga=c[m>>2]|0}else{ea=w;fa=t;ga=l}r=fa+1|0;c[k>>2]=r;if(r>>>0<ga>>>0){w=ea;q=d[fa]|0;t=r;l=ga}else{da=ea;break}}}else{da=j}}while(0);a[da]=0;H=kb(j|0,0,10)|0}s=c[k>>2]|0;l=c[m>>2]|0;r:do{if(s>>>0<l>>>0){t=s;while(1){q=t+1|0;c[k>>2]=q;w=a[t]|0;r=w&255;s:do{if(w<<24>>24==35){I=r;x=q;while(1){if(!(x>>>0<l>>>0)){ha=I;ia=x;break s}L=x+1|0;c[k>>2]=L;M=a[x]|0;if(M<<24>>24==10){ha=10;ia=L;break}else{I=M&255;x=L}}}else{if((r|0)==32|(r|0)==13|(r|0)==10){ha=r;ia=q;break}if(w<<24>>24==9){ha=r;ia=q}else{ja=r;ka=q;break r}}}while(0);if(ia>>>0<l>>>0){t=ia}else{ja=ha;ka=ia;break}}}else{ja=0;ka=s}}while(0);t:do{if(ka>>>0<l>>>0){s=j;t=ja;q=ka;r=l;while(1){if((t|0)==32|(t|0)==13|(t|0)==10|(t|0)==9){la=s;break t}if((s-D|0)<31){a[s]=t;ma=s+1|0;na=c[k>>2]|0;oa=c[m>>2]|0}else{ma=s;na=q;oa=r}w=na+1|0;c[k>>2]=w;if(w>>>0<oa>>>0){s=ma;t=d[na]|0;q=w;r=oa}else{la=ma;break}}}else{la=j}}while(0);a[la]=0;v=H;G=kb(j|0,0,10)|0}v=c[k>>2]|0;l=c[m>>2]|0;u:do{if(v>>>0<l>>>0){r=v;while(1){q=r+1|0;c[k>>2]=q;t=a[r]|0;s=t&255;v:do{if(t<<24>>24==35){w=s;x=q;while(1){if(!(x>>>0<l>>>0)){pa=w;qa=x;break v}I=x+1|0;c[k>>2]=I;L=a[x]|0;if(L<<24>>24==10){pa=10;qa=I;break}else{w=L&255;x=I}}}else{if((s|0)==32|(s|0)==13|(s|0)==10){pa=s;qa=q;break}if(t<<24>>24==9){pa=s;qa=q}else{ra=s;sa=q;break u}}}while(0);if(qa>>>0<l>>>0){r=qa}else{ra=pa;sa=qa;break}}}else{ra=0;sa=v}}while(0);w:do{if(sa>>>0<l>>>0){v=j;r=ra;q=sa;s=l;while(1){if((r|0)==32|(r|0)==13|(r|0)==10|(r|0)==9){ta=v;break w}if((v-D|0)<31){a[v]=r;ua=v+1|0;va=c[k>>2]|0;wa=c[m>>2]|0}else{ua=v;va=q;wa=s}t=va+1|0;c[k>>2]=t;if(t>>>0<wa>>>0){v=ua;r=d[va]|0;q=t;s=wa}else{ta=ua;break}}}else{ta=j}}while(0);a[ta]=0;o=H;u=G;F=kb(j|0,0,10)|0}u=c[k>>2]|0;o=c[m>>2]|0;x:do{if(u>>>0<o>>>0){l=u;while(1){s=l+1|0;c[k>>2]=s;q=a[l]|0;r=q&255;y:do{if(q<<24>>24==35){v=r;t=s;while(1){if(!(t>>>0<o>>>0)){xa=v;ya=t;break y}x=t+1|0;c[k>>2]=x;w=a[t]|0;if(w<<24>>24==10){xa=10;ya=x;break}else{v=w&255;t=x}}}else{if((r|0)==32|(r|0)==13|(r|0)==10){xa=r;ya=s;break}if(q<<24>>24==9){xa=r;ya=s}else{za=r;Aa=s;break x}}}while(0);if(ya>>>0<o>>>0){l=ya}else{za=xa;Aa=ya;break}}}else{za=0;Aa=u}}while(0);z:do{if(Aa>>>0<o>>>0){u=j;l=za;s=Aa;r=o;while(1){if((l|0)==32|(l|0)==13|(l|0)==10|(l|0)==9){Ba=u;break z}if((u-D|0)<31){a[u]=l;Ca=u+1|0;Da=c[k>>2]|0;Ea=c[m>>2]|0}else{Ca=u;Da=s;Ea=r}q=Da+1|0;c[k>>2]=q;if(q>>>0<Ea>>>0){u=Ca;l=d[Da]|0;s=q;r=Ea}else{Ba=Ca;break}}}else{Ba=j}}while(0);a[Ba]=0;n=H;z=G;y=F;p=kb(j|0,0,10)|0}if((QGb(j,1961416)|0)!=0){E=-1094995529;i=f;return E|0}if((F|0)<1|(p|0)<1|(H|0)<1|(G|0)<1){E=-1094995529;i=f;return E|0}if((a[B]|0)==0){E=-1094995529;i=f;return E|0}if((hDb(F,p,0,b)|0)!=0){E=-1094995529;i=f;return E|0}if(!((c[k>>2]|0)>>>0<(c[m>>2]|0)>>>0)){E=-1094995529;i=f;return E|0}c[b+120>>2]=F;c[b+124>>2]=p;c[e+12>>2]=H;if((G|0)==1){if((H|0)==1){c[b+140>>2]=10;E=0;i=f;return E|0}y=b+140|0;if((H|0)<256){c[y>>2]=8;E=0;i=f;return E|0}else{c[y>>2]=32;E=0;i=f;return E|0}}else if((G|0)==2){if((H|0)!=255){E=0;i=f;return E|0}c[b+140>>2]=66;E=0;i=f;return E|0}else if((G|0)==3){y=b+140|0;if((H|0)<256){c[y>>2]=2;E=0;i=f;return E|0}else{c[y>>2]=42;E=0;i=f;return E|0}}else if((G|0)==4){y=b+140|0;if((H|0)<256){c[y>>2]=28;E=0;i=f;return E|0}else{c[y>>2]=292;E=0;i=f;return E|0}}else{E=-1094995529;i=f;return E|0}break};default:{E=-1094995529;i=f;return E|0}}}while(0);H=c[k>>2]|0;G=c[m>>2]|0;A:do{if(H>>>0<G>>>0){F=H;while(1){Ba=F+1|0;c[k>>2]=Ba;Ca=a[F]|0;Ea=Ca&255;B:do{if(Ca<<24>>24==35){Da=Ea;Aa=Ba;while(1){if(!(Aa>>>0<G>>>0)){Fa=Da;Ga=Aa;break B}za=Aa+1|0;c[k>>2]=za;ya=a[Aa]|0;if(ya<<24>>24==10){Fa=10;Ga=za;break}else{Da=ya&255;Aa=za}}}else{if((Ea|0)==32|(Ea|0)==13|(Ea|0)==10){Fa=Ea;Ga=Ba;break}if(Ca<<24>>24==9){Fa=Ea;Ga=Ba}else{Ha=Ea;Ia=Ba;break A}}}while(0);if(Ga>>>0<G>>>0){F=Ga}else{Ha=Fa;Ia=Ga;break}}}else{Ha=0;Ia=H}}while(0);C:do{if(Ia>>>0<G>>>0){H=g;Ga=j;Fa=Ha;F=Ia;p=G;while(1){if((Fa|0)==32|(Fa|0)==13|(Fa|0)==10|(Fa|0)==9){Ja=Ga;break C}if((Ga-H|0)<31){a[Ga]=Fa;Ka=Ga+1|0;La=c[k>>2]|0;Ma=c[m>>2]|0}else{Ka=Ga;La=F;Ma=p}B=La+1|0;c[k>>2]=B;if(B>>>0<Ma>>>0){Ga=Ka;Fa=d[La]|0;F=B;p=Ma}else{Ja=Ka;break}}}else{Ja=j}}while(0);a[Ja]=0;Ja=gd(j|0)|0;Ka=c[k>>2]|0;Ma=c[m>>2]|0;D:do{if(Ka>>>0<Ma>>>0){La=Ka;while(1){G=La+1|0;c[k>>2]=G;Ia=a[La]|0;Ha=Ia&255;E:do{if(Ia<<24>>24==35){p=Ha;F=G;while(1){if(!(F>>>0<Ma>>>0)){Na=p;Oa=F;break E}Fa=F+1|0;c[k>>2]=Fa;Ga=a[F]|0;if(Ga<<24>>24==10){Na=10;Oa=Fa;break}else{p=Ga&255;F=Fa}}}else{if((Ha|0)==32|(Ha|0)==13|(Ha|0)==10){Na=Ha;Oa=G;break}if(Ia<<24>>24==9){Na=Ha;Oa=G}else{Pa=Ha;Qa=G;break D}}}while(0);if(Oa>>>0<Ma>>>0){La=Oa}else{Pa=Na;Qa=Oa;break}}}else{Pa=0;Qa=Ka}}while(0);F:do{if(Qa>>>0<Ma>>>0){Ka=g;Oa=j;Na=Pa;La=Qa;G=Ma;while(1){if((Na|0)==32|(Na|0)==13|(Na|0)==10|(Na|0)==9){Ra=Oa;break F}if((Oa-Ka|0)<31){a[Oa]=Na;Sa=Oa+1|0;Ta=c[k>>2]|0;Ua=c[m>>2]|0}else{Sa=Oa;Ta=La;Ua=G}Ha=Ta+1|0;c[k>>2]=Ha;if(Ha>>>0<Ua>>>0){Oa=Sa;Na=d[Ta]|0;La=Ha;G=Ua}else{Ra=Sa;break}}}else{Ra=j}}while(0);a[Ra]=0;Ra=gd(j|0)|0;if((Ja|0)<1|(Ra|0)<1){E=-1094995529;i=f;return E|0}Sa=b;if((hDb(Ja,Ra,0,Sa)|0)!=0){E=-1094995529;i=f;return E|0}Ua=c[k>>2]|0;Ta=c[m>>2]|0;if(!(Ua>>>0<Ta>>>0)){E=-1094995529;i=f;return E|0}Ma=b+120|0;c[Ma>>2]=Ja;Ja=b+124|0;c[Ja>>2]=Ra;Ra=b+140|0;G:do{if(((c[Ra>>2]|0)-9|0)>>>0<2>>>0){c[e+12>>2]=1}else{b=Ua;H:while(1){Qa=b+1|0;c[k>>2]=Qa;Pa=a[b]|0;G=Pa&255;I:do{if(Pa<<24>>24==35){La=G;Na=Qa;while(1){if(!(Na>>>0<Ta>>>0)){Va=La;Wa=Na;break I}Oa=Na+1|0;c[k>>2]=Oa;Ka=a[Na]|0;if(Ka<<24>>24==10){Va=10;Wa=Oa;break}else{La=Ka&255;Na=Oa}}}else{if((G|0)==32|(G|0)==13|(G|0)==10){Va=G;Wa=Qa;break}if(Pa<<24>>24==9){Va=G;Wa=Qa}else{Xa=G;Ya=Qa;break H}}}while(0);if(Wa>>>0<Ta>>>0){b=Wa}else{Xa=Va;Ya=Wa;break}}J:do{if(Ya>>>0<Ta>>>0){b=g;Qa=j;G=Xa;Pa=Ya;Na=Ta;while(1){if((G|0)==32|(G|0)==13|(G|0)==10|(G|0)==9){Za=Qa;break J}if((Qa-b|0)<31){a[Qa]=G;_a=Qa+1|0;$a=c[k>>2]|0;ab=c[m>>2]|0}else{_a=Qa;$a=Pa;ab=Na}La=$a+1|0;c[k>>2]=La;if(La>>>0<ab>>>0){Qa=_a;G=d[$a]|0;Pa=La;Na=ab}else{Za=_a;break}}}else{Za=j}}while(0);a[Za]=0;Na=gd(j|0)|0;Pa=e+12|0;c[Pa>>2]=Na;if((Na|0)<1){yDb(Sa,16,1933552,(bb=i,i=i+8|0,c[bb>>2]=Na,bb)|0);i=bb;c[Pa>>2]=255;break}if((Na|0)<=255){break}Pa=c[Ra>>2]|0;do{if((Pa|0)==8){c[Ra>>2]=32;break G}else if((Pa|0)==2){c[Ra>>2]=42;break G}else if((Pa|0)==0){if((Na|0)>=65536){break}if((Na|0)<512){c[Ra>>2]=70;break G}if((Na|0)<1024){c[Ra>>2]=72;break G}else{c[Ra>>2]=54;break G}}}while(0);yDb(Sa,16,1910696,(bb=i,i=i+1|0,i=i+7&-8,c[bb>>2]=0,bb)|0);i=bb;c[Ra>>2]=-1;E=-1094995529;i=f;return E|0}}while(0);if((a[(bFb(c[Ra>>2]|0)|0)+7|0]&16)==0){E=0;i=f;return E|0}if((c[Ma>>2]&1|0)!=0){E=-1094995529;i=f;return E|0}Ma=c[Ja>>2]<<1;if(((Ma|0)%3|0|0)!=0){E=-1094995529;i=f;return E|0}c[Ja>>2]=(Ma|0)/3|0;E=0;i=f;return E|0}function Xmb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=b|0;c[k>>2]=e;l=b+8|0;c[l>>2]=cEb((c[e+416>>2]|0)*5128|0)|0;e=b+12|0;c[e>>2]=cEb(i*212|0)|0;m=f<<2;f=b+20|0;c[f>>2]=WDb(m)|0;n=b+24|0;c[n>>2]=WDb(m)|0;UGb(c[f>>2]|0,g|0,m)|0;UGb(c[n>>2]|0,h|0,m)|0;if((i|0)>0){m=0;h=0;n=c[e>>2]|0;while(1){a[n+(m*212|0)+80|0]=(a[j+m|0]|0)+1;g=c[e>>2]|0;if((a[g+(m*212|0)+80|0]|0)==0){o=h;p=g}else{f=0;q=h;r=g;while(1){g=q+1|0;c[r+(m*212|0)+(f<<2)>>2]=(c[l>>2]|0)+(q*2564|0);s=f+1|0;t=c[e>>2]|0;if((s|0)<(d[t+(m*212|0)+80|0]<<1|0)){f=s;q=g;r=t}else{o=g;p=t;break}}}r=m+1|0;if((r|0)<(i|0)){m=r;h=o;n=p}else{break}}}p=b+4|0;if((c[(c[k>>2]|0)+48>>2]|0)==86018){c[p>>2]=1277752;u=1277752}else{u=c[p>>2]|0}p=c[u+4>>2]|0;if((p|0)==0){v=0;return v|0}v=re[p&4095](b)|0;return v|0}function Ymb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[a+12>>2]|0;if((b|0)<0){f=-1;g=e+(f*212|0)|0;return g|0}else{h=0;i=0}while(1){a=(d[e+(h*212|0)+80|0]|0)+i|0;if((a|0)>(b|0)){f=h;break}else{h=h+1|0;i=a}}g=e+(f*212|0)|0;return g|0}function Zmb(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;do{if((b|0)!=0){d=c[b+16>>2]|0;if((d|0)==0){break}me[d&511](a)}}while(0);$Db(a+20|0);$Db(a+24|0);$Db(a+12|0);$Db(a+8|0);return}function _mb(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0.0,h=0.0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=cEb(20)|0;d=b;c[b>>2]=a;e=c[a+436>>2]|0;if((e|0)>0){f=+(e|0)*2.0/+(c[a+412>>2]|0);if(f!=0.0){g=f}else{h=f;i=3}}else{h=0.0;i=3}do{if((i|0)==3){if((c[a+48>>2]|0)!=86018){g=h;break}e=c[a+72>>2]|0;if((e|0)==0){j=c[a+412>>2]|0;k=(j|0)/2|0;l=j}else{j=((e|0)/8|0)+4e3|0;m=((e|0)/32|0)+12e3|0;e=(j|0)>(m|0)?m:j;j=c[a+412>>2]|0;m=(j|0)/2|0;k=(e|0)>(m|0)?m:e;l=j}g=+(k|0)*2.0/+(l|0)}}while(0);if(g!=0.0&g<.98){l=nqb(a,2,0,4,g,0.0,0.0)|0;c[b+8>>2]=l;n=l}else{n=c[b+8>>2]|0}if((n|0)==0){o=b+16|0;p=o;sqb(p);return d|0}n=a+416|0;a=b+12|0;c[a>>2]=cEb(c[n>>2]<<2)|0;if((c[n>>2]|0)>0){q=0}else{o=b+16|0;p=o;sqb(p);return d|0}do{l=pqb(4)|0;c[(c[a>>2]|0)+(q<<2)>>2]=l;q=q+1|0;}while((q|0)<(c[n>>2]|0));o=b+16|0;p=o;sqb(p);return d|0}function $mb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[(c[a>>2]|0)+424>>2]|0;f=a+12|0;g=c[f>>2]|0;if(!((g|0)!=0&(d|0)>0)){return}h=a+16|0;i=a+8|0;a=0;j=g;while(1){g=(c[b+(a<<2)>>2]|0)+(e<<2)|0;Ke[c[h>>2]&1023](c[i>>2]|0,c[j+(a<<2)>>2]|0,e,g,1,g,1);g=a+1|0;if((g|0)>=(d|0)){break}a=g;j=c[f>>2]|0}return}function anb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;oqb(c[a+8>>2]|0);b=a+12|0;d=c[b>>2]|0;a:do{if((d|0)!=0){e=a|0;if((c[(c[e>>2]|0)+416>>2]|0)>0){f=0;g=d}else{break}while(1){rqb(c[g+(f<<2)>>2]|0);h=f+1|0;if((h|0)>=(c[(c[e>>2]|0)+416>>2]|0)){break a}f=h;g=c[b>>2]|0}}}while(0);$Db(b);ZDb(a);return}function bnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+(146-c<<1)|0;b=(c|0)<40;UGb(a|0,d|0,b?c<<1:80)|0;if(!b){return}UGb(a+(c<<1)|0,d|0,40-c<<1)|0;return}function cnb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+80|0;g=f+40|0;h=g|0;c[h>>2]=b[d>>1]|0;c[g+4>>2]=b[d+2>>1]|0;c[g+8>>2]=b[d+4>>1]|0;c[g+12>>2]=b[d+6>>1]|0;c[g+16>>2]=b[d+8>>1]|0;c[g+20>>2]=b[d+10>>1]|0;c[g+24>>2]=b[d+12>>1]|0;c[g+28>>2]=b[d+14>>1]|0;c[g+32>>2]=b[d+16>>1]|0;j=b[d+18>>1]|0;c[g+36>>2]=j;c[a+36>>2]=j;if((j+4096|0)>>>0>8191>>>0){yDb(e,16,2171344,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;k=1;i=f;return k|0}e=8;g=f|0;d=h;h=j;while(1){j=e+1|0;l=c[d+(j<<2)>>2]|0;m=(ba(l,l)|0)>>>12;l=16777216/(((m|0)==4096?-2:4096-m|0)|0)|0;m=a+(j<<2)|0;j=0;n=h;while(1){c[g+(j<<2)>>2]=(ba((c[d+(j<<2)>>2]|0)-((ba(c[d+(e-j<<2)>>2]|0,n)|0)>>12)|0,l)|0)>>12;o=j+1|0;if((o|0)>(e|0)){break}j=o;n=c[m>>2]|0}m=c[g+(e<<2)>>2]|0;if((m+4096|0)>>>0>8191>>>0){k=1;p=9;break}c[a+(e<<2)>>2]=m;if((e|0)>0){n=g;g=d;e=e-1|0;h=m;d=n}else{k=0;p=9;break}}if((p|0)==9){i=f;return k|0}return 0}function dnb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+40|0;e=a;f=0;g=d|0;while(1){h=b+(f<<2)|0;c[g+(f<<2)>>2]=c[h>>2]<<4;if((f|0)>0){j=f-1|0;k=0;do{l=(ba(c[e+(j-k<<2)>>2]|0,c[h>>2]|0)|0)>>12;c[g+(k<<2)>>2]=l+(c[e+(k<<2)>>2]|0);k=k+1|0;}while((k|0)<(f|0))}k=f+1|0;if((k|0)<10){h=e;e=g;f=k;g=h}else{break}}c[a>>2]=c[a>>2]>>4;g=a+4|0;c[g>>2]=c[g>>2]>>4;g=a+8|0;c[g>>2]=c[g>>2]>>4;g=a+12|0;c[g>>2]=c[g>>2]>>4;g=a+16|0;c[g>>2]=c[g>>2]>>4;g=a+20|0;c[g>>2]=c[g>>2]>>4;g=a+24|0;c[g>>2]=c[g>>2]>>4;g=a+28|0;c[g>>2]=c[g>>2]>>4;g=a+32|0;c[g>>2]=c[g>>2]>>4;g=a+36|0;c[g>>2]=c[g>>2]>>4;i=d;return}function enb(a,d){a=a|0;d=d|0;b[a>>1]=c[d>>2];b[a+2>>1]=c[d+4>>2];b[a+4>>1]=c[d+8>>2];b[a+6>>1]=c[d+12>>2];b[a+8>>1]=c[d+16>>2];b[a+10>>1]=c[d+20>>2];b[a+12>>1]=c[d+24>>2];b[a+14>>1]=c[d+28>>2];b[a+16>>1]=c[d+32>>2];b[a+18>>1]=c[d+36>>2];return}function fnb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(a>>>0>4095>>>0){b=a;e=2;while(1){f=e+1|0;g=b>>>2;if(b>>>0>16383>>>0){b=g;e=f}else{h=g;i=f;break}}}else{h=a;i=2}a=h<<20;if(a>>>0<255>>>0){j=(d[1135648+(a|1)|0]|0)-1>>4;k=j<<i;return k|0}do{if(a>>>0<4096>>>0){l=(d[1135648+(h<<16&268369920)|0]|0)>>>2}else{if(a>>>0<16384>>>0){l=(d[1135648+(h<<14&67092480)|0]|0)>>>1;break}if(a>>>0<65536>>>0){l=d[1135648+(h<<12&16773120)|0]|0;break}else{e=h<<4;b=(e&65280|0)==0;f=((d[1191992+(b?e&65520:h>>>4&255)|0]|0)+(b?0:8)|0)>>>1;b=a>>>((f+2|0)>>>0);e=d[1135648+(b>>>((f+8|0)>>>0))|0]|0;gHb(b,0,c[1199552+(e<<2)>>2]|0,0)|0;l=F+(e<<f)|0;break}}}while(0);j=l-((ba(l,l)|0)>>>0>a>>>0)|0;k=j<<i;return k|0}function gnb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=0;d=65536;e=10;while(1){f=c[a+(b<<2)>>2]|0;g=ba(16777216-(ba(f,f)|0)>>12,d)|0;f=g>>>12;if((f|0)==0){h=0;i=7;break}if(g>>>0<67108864>>>0){g=f;j=e;while(1){k=j+1|0;l=g<<2;if(l>>>0<16384>>>0){g=l;j=k}else{m=l;n=k;break}}}else{m=f;n=e}j=b+1|0;if((j|0)<10){b=j;d=m;e=n}else{break}}if((i|0)==7){return h|0}h=(fnb(m)|0)>>n;return h|0}function hnb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;i=i+40|0;j=h|0;k=4-e|0;l=c[a+1388>>2]|0;m=c[a+1392>>2]|0;n=ba(c[l>>2]|0,e)|0;b[d>>1]=((ba(c[m>>2]|0,k)|0)+n|0)>>>2;n=ba(c[l+4>>2]|0,e)|0;o=d+2|0;b[o>>1]=((ba(c[m+4>>2]|0,k)|0)+n|0)>>>2;n=ba(c[l+8>>2]|0,e)|0;p=d+4|0;b[p>>1]=((ba(c[m+8>>2]|0,k)|0)+n|0)>>>2;n=ba(c[l+12>>2]|0,e)|0;q=d+6|0;b[q>>1]=((ba(c[m+12>>2]|0,k)|0)+n|0)>>>2;n=ba(c[l+16>>2]|0,e)|0;r=d+8|0;b[r>>1]=((ba(c[m+16>>2]|0,k)|0)+n|0)>>>2;n=ba(c[l+20>>2]|0,e)|0;s=d+10|0;b[s>>1]=((ba(c[m+20>>2]|0,k)|0)+n|0)>>>2;n=ba(c[l+24>>2]|0,e)|0;t=d+12|0;b[t>>1]=((ba(c[m+24>>2]|0,k)|0)+n|0)>>>2;n=ba(c[l+28>>2]|0,e)|0;u=d+14|0;b[u>>1]=((ba(c[m+28>>2]|0,k)|0)+n|0)>>>2;n=ba(c[l+32>>2]|0,e)|0;v=d+16|0;b[v>>1]=((ba(c[m+32>>2]|0,k)|0)+n|0)>>>2;n=ba(c[l+36>>2]|0,e)|0;e=d+18|0;b[e>>1]=((ba(c[m+36>>2]|0,k)|0)+n|0)>>>2;if((cnb(j|0,d,c[a>>2]|0)|0)==0){w=0;x=65536;y=10}else{n=c[a+1388+(f<<2)>>2]|0;b[d>>1]=c[n>>2];b[o>>1]=c[n+4>>2];b[p>>1]=c[n+8>>2];b[q>>1]=c[n+12>>2];b[r>>1]=c[n+16>>2];b[s>>1]=c[n+20>>2];b[t>>1]=c[n+24>>2];b[u>>1]=c[n+28>>2];b[v>>1]=c[n+32>>2];b[e>>1]=c[n+36>>2];z=c[a+1396+(f<<2)>>2]|0;A=ba(z,g)|0;B=A>>>10;i=h;return B|0}while(1){f=c[j+(w<<2)>>2]|0;a=ba(16777216-(ba(f,f)|0)>>12,x)|0;f=a>>>12;if((f|0)==0){z=0;C=8;break}if(a>>>0<67108864>>>0){a=f;n=y;while(1){e=n+1|0;v=a<<2;if(v>>>0<16384>>>0){a=v;n=e}else{D=v;E=e;break}}}else{D=f;E=y}n=w+1|0;if((n|0)<10){w=n;x=D;y=E}else{break}}if((C|0)==8){A=ba(z,g)|0;B=A>>>10;i=h;return B|0}z=(fnb(D)|0)>>E;A=ba(z,g)|0;B=A>>>10;i=h;return B|0}function inb(a,b){a=a|0;b=b|0;return(ba(b,a)|0)>>>10|0}function jnb(a,b){a=a|0;b=b|0;var d=0,e=0;d=ze[c[a+1224>>2]&511](b,b,40)|0;if((d|0)==0){e=0;return e|0}e=536870912/((fnb(d)|0)>>8|0)|0;return e|0}function knb(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=i;i=i+32|0;o=n|0;p=n+16|0;if((h|0)==0){c[p>>2]=0;q=1;r=f+2128|0}else{s=h+19|0;t=f+2128|0;u=f+1824+(127-h<<1)|0;v=(s|0)<40;UGb(t|0,u|0,v?s<<1:80)|0;if(v){UGb(f+2128+(s<<1)|0,u|0,21-h<<1)|0}h=ze[c[f+1228>>2]&511](t,t,40)|0;if((h|0)==0){w=0}else{w=536870912/((fnb(h)|0)>>8|0)|0}c[p>>2]=(ba(w,l)|0)>>12;q=(s|0)==0;r=t}c[p+4>>2]=(ba(e[1255128+(j<<1)>>1]|0,l)|0)>>8;c[p+8>>2]=(ba(e[1249752+(k<<1)>>1]|0,l)|0)>>8;VGb(f+1824|0,f+1904|0,212)|0;l=o|0;c[l>>2]=0;t=d[1216560+m|0]|0;s=q&1;do{c[o+(s<<2)>>2]=(ba(b[1215024+(m*6|0)+(s<<1)>>1]|0,c[p+(s<<2)>>2]|0)|0)>>t;s=s+1|0;}while((s|0)<3);s=f+2036|0;t=q?0:r;r=c[l>>2]|0;l=c[o+4>>2]|0;q=c[o+8>>2]|0;if((r|0)==0){o=0;do{p=ba(a[1250008+(j*40|0)+o|0]|0,l)|0;b[f+1824+(o+106<<1)>>1]=((ba(a[1244632+(k*40|0)+o|0]|0,q)|0)+p|0)>>>12;o=o+1|0;}while((o|0)<40)}else{o=0;do{p=ba(b[t+(o<<1)>>1]|0,r)|0;m=(ba(a[1250008+(j*40|0)+o|0]|0,l)|0)+p|0;b[f+1824+(o+106<<1)>>1]=(m+(ba(a[1244632+(k*40|0)+o|0]|0,q)|0)|0)>>>12;o=o+1|0;}while((o|0)<40)}o=f+1724|0;UGb(o|0,f+1804|0,20)|0;if((x$(f+1744|0,g,s,40,10,1,0,4095)|0)==0){i=n;return}TGb(o|0,0,100)|0;i=n;return}function lnb(b,c,d,e,f,g,h,i,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a:do{if((f|0)>0){k=(e|0)==1;l=e+1|0;m=b+c|0;n=d;o=0;p=b;b:while(1){q=f-o|0;r=n+e|0;s=(q|0)<127?q:127;c:do{if((s|0)>1){d:do{if(k){q=a[n]|0;t=1;u=r;while(1){if(!(q<<24>>24==(a[u]|0))){v=t;break d}w=t+1|0;if((w|0)<(s|0)){t=w;u=u+1|0}else{v=w;break}}}else{u=n;t=1;q=r;while(1){if((PGb(u,q,e)|0)!=0){v=t;break d}w=t+1|0;if((w|0)<(s|0)){u=q;t=w;q=q+e|0}else{v=w;break}}}}while(0);if((v|0)>1){if((p+l|0)>>>0>m>>>0){x=-1;y=26;break b}a[p]=(v^h)+g;UGb(p+1|0,n|0,e)|0;z=e;A=v;break}e:do{if(k){q=n;t=1;u=r;w=a[n]|0;while(1){B=a[u]|0;C=t+1|0;if(w<<24>>24==B<<24>>24){if((C|0)>=(s|0)){D=t;break e}if(w<<24>>24==(a[q+l|0]|0)){D=t;break e}}if((C|0)<(s|0)){q=u;t=C;u=u+1|0;w=B}else{E=C;y=22;break c}}}else{w=n;u=1;t=r;while(1){if((PGb(w,t,e)|0)==0){D=u;break e}q=u+1|0;if((q|0)<(s|0)){w=t;u=q;t=t+e|0}else{E=q;y=22;break c}}}}while(0);E=D-1|0;y=22}else{E=1;y=22}}while(0);if((y|0)==22){y=0;s=ba(E,e)|0;if(!((p+s|0)>>>0<m>>>0)){x=-1;y=26;break}a[p]=(E^j)+i;UGb(p+1|0,n|0,s)|0;z=s;A=E}s=p+(z+1)|0;r=n+(ba(A,e)|0)|0;t=A+o|0;if((t|0)<(f|0)){n=r;o=t;p=s}else{F=s;break a}}if((y|0)==26){return x|0}}else{F=b}}while(0);x=F-b|0;return x|0}function mnb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=b+12|0;b=c[g>>2]|0;h=c[b+32>>2]|0;i=(ba(h,e)|0)+d|0;j=c[b>>2]|0;a[j+i|0]=a[f|0]|0;a[j+(i+1)|0]=a[f+1|0]|0;a[j+(i+h)|0]=a[f+2|0]|0;a[j+(h+1+i)|0]=a[f+3|0]|0;i=c[g>>2]|0;h=c[i+36>>2]|0;j=(ba(h,e)|0)+d|0;d=c[i+4>>2]|0;i=a[f+4|0]|0;e=h+1+j|0;a[d+e|0]=i;b=j+h|0;a[d+b|0]=i;h=j+1|0;a[d+h|0]=i;a[d+j|0]=i;i=c[(c[g>>2]|0)+8>>2]|0;g=a[f+5|0]|0;a[i+e|0]=g;a[i+b|0]=g;a[i+h|0]=g;a[i+j|0]=g;return}function nnb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=b+12|0;b=c[g>>2]|0;h=c[b+32>>2]|0;i=(ba(h,e)|0)+d|0;j=c[b>>2]|0;b=a[f|0]|0;a[j+(h+1+i)|0]=b;a[j+(i+h)|0]=b;a[j+(i+1)|0]=b;a[j+i|0]=b;b=a[f+1|0]|0;a[j+(h+3+i)|0]=b;a[j+(h+2+i)|0]=b;a[j+(i+3)|0]=b;a[j+(i+2)|0]=b;b=a[f+2|0]|0;k=h*3|0;a[j+(k+1+i)|0]=b;a[j+(i+k)|0]=b;l=h<<1;a[j+(i+(l|1))|0]=b;a[j+(i+l)|0]=b;b=a[f+3|0]|0;a[j+(k+3+i)|0]=b;a[j+(k+2+i)|0]=b;a[j+(l+3+i)|0]=b;a[j+(l+2+i)|0]=b;b=c[g>>2]|0;i=c[b+36>>2]|0;l=(ba(i,e)|0)+d|0;d=c[b+4>>2]|0;b=a[f+4|0]|0;e=i*3|0;j=e+3+l|0;a[d+j|0]=b;k=e+2+l|0;a[d+k|0]=b;h=i<<1;m=h+3+l|0;a[d+m|0]=b;n=h+2+l|0;a[d+n|0]=b;o=e+1+l|0;a[d+o|0]=b;p=l+e|0;a[d+p|0]=b;e=l+(h|1)|0;a[d+e|0]=b;q=l+h|0;a[d+q|0]=b;h=i+3+l|0;a[d+h|0]=b;r=i+2+l|0;a[d+r|0]=b;s=l+3|0;a[d+s|0]=b;t=l+2|0;a[d+t|0]=b;u=i+1+l|0;a[d+u|0]=b;v=l+i|0;a[d+v|0]=b;i=l+1|0;a[d+i|0]=b;a[d+l|0]=b;b=c[(c[g>>2]|0)+8>>2]|0;g=a[f+5|0]|0;a[b+j|0]=g;a[b+k|0]=g;a[b+m|0]=g;a[b+n|0]=g;a[b+o|0]=g;a[b+p|0]=g;a[b+e|0]=g;a[b+q|0]=g;a[b+h|0]=g;a[b+r|0]=g;a[b+s|0]=g;a[b+t|0]=g;a[b+u|0]=g;a[b+v|0]=g;a[b+i|0]=g;a[b+l|0]=g;return}function onb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;pnb(a,b,c,d,e,4);return}function pnb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;j=e+b|0;e=f+d|0;f=c[a+5664>>2]|0;do{if((j|0)>=0){if((j|0)>(f-g|0)|(e|0)<0){break}if((e|0)>((c[a+5668>>2]|0)-g|0)){break}k=a+8|0;l=c[k>>2]|0;m=c[l>>2]|0;if((m|0)==0){yDb(c[a+4>>2]|0,16,2302792,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;i=h;return}o=a+12|0;if((g|0)==0){i=h;return}p=c[o>>2]|0;q=c[p+32>>2]|0;r=c[l+32>>2]|0;l=(ba(r,e)|0)+j|0;s=(ba(q,d)|0)+b|0;t=m+l|0;l=(c[p>>2]|0)+s|0;s=g;while(1){p=s-1|0;UGb(l|0,t|0,g)|0;if((p|0)==0){break}else{t=t+r|0;l=l+q|0;s=p}}s=c[o>>2]|0;q=c[k>>2]|0;l=c[s+36>>2]|0;r=c[q+36>>2]|0;t=ba(l,d)|0;p=(ba(r,e)|0)+j|0;m=(c[q+4>>2]|0)+p|0;p=(c[s+4>>2]|0)+(t+b)|0;t=g;while(1){s=t-1|0;UGb(p|0,m|0,g)|0;if((s|0)==0){break}else{m=m+r|0;p=p+l|0;t=s}}t=c[o>>2]|0;l=c[k>>2]|0;p=c[t+40>>2]|0;r=c[l+40>>2]|0;m=ba(p,d)|0;s=(ba(r,e)|0)+j|0;q=(c[l+8>>2]|0)+s|0;s=(c[t+8>>2]|0)+(m+b)|0;m=g;while(1){t=m-1|0;UGb(s|0,q|0,g)|0;if((t|0)==0){break}else{q=q+r|0;s=s+p|0;m=t}}i=h;return}}while(0);g=c[a+5668>>2]|0;yDb(c[a+4>>2]|0,16,2171200,(n=i,i=i+32|0,c[n>>2]=j,c[n+8>>2]=e,c[n+16>>2]=f,c[n+24>>2]=g,n)|0);i=n;i=h;return}function qnb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;pnb(a,b,c,d,e,8);return}function rnb(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+544|0;d=b|0;e=b+32|0;iob(a);pea(d,8);Soa(e,8);c[a>>2]=c[e>>2];c[a+4>>2]=1104;c[a+8>>2]=588;c[a+16>>2]=200;c[a+20>>2]=1430;c[a+24>>2]=1510;c[a+32>>2]=2218;c[a+36>>2]=506;c[a+40>>2]=2;c[a+256>>2]=c[e+256>>2];c[a+260>>2]=658;c[a+264>>2]=1538;c[a+272>>2]=258;c[a+276>>2]=1588;c[a+280>>2]=1194;c[a+288>>2]=1720;c[a+292>>2]=76;c[a+296>>2]=1776;c[a+64>>2]=c[e+64>>2];c[a+68>>2]=158;c[a+72>>2]=1240;c[a+80>>2]=1368;c[a+84>>2]=1178;c[a+88>>2]=338;c[a+96>>2]=1384;c[a+100>>2]=1022;c[a+104>>2]=1854;c[a+320>>2]=c[e+320>>2];c[a+324>>2]=1880;c[a+328>>2]=180;c[a+336>>2]=2072;c[a+340>>2]=950;c[a+344>>2]=1062;c[a+352>>2]=612;c[a+356>>2]=1274;c[a+360>>2]=1938;c[a+512>>2]=c[d>>2];c[a+516>>2]=c[d+4>>2];c[a+524>>2]=c[d+16>>2];c[a+528>>2]=c[d+20>>2];i=b;return}function snb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;hob(a,b,c,c,12,6);hob(a+8|0,b+8|0,c,c,12,6);d=c<<3;hob(a+d|0,b+d|0,c,c,12,6);e=d+8|0;hob(a+e|0,b+e|0,c,c,12,6);return}function tnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;hob(a,b,c,c,6,12);hob(a+8|0,b+8|0,c,c,6,12);d=c<<3;hob(a+d|0,b+d|0,c,c,6,12);e=d+8|0;hob(a+e|0,b+e|0,c,c,6,12);return}function unb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;eob(a,b,c,c,12,6);eob(a+8|0,b+8|0,c,c,12,6);d=c<<3;eob(a+d|0,b+d|0,c,c,12,6);e=d+8|0;eob(a+e|0,b+e|0,c,c,12,6);return}function vnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;gob(a,b,c,c);gob(a+8|0,b+8|0,c,c);d=c<<3;gob(a+d|0,b+d|0,c,c);e=d+8|0;gob(a+e|0,b+e|0,c,c);return}function wnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;fob(a,b,c,c);fob(a+8|0,b+8|0,c,c);d=c<<3;fob(a+d|0,b+d|0,c,c);e=d+8|0;fob(a+e|0,b+e|0,c,c);return}function xnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;eob(a,b,c,c,6,12);eob(a+8|0,b+8|0,c,c,6,12);d=c<<3;eob(a+d|0,b+d|0,c,c,6,12);e=d+8|0;eob(a+e|0,b+e|0,c,c,6,12);return}function ynb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;dob(a,b,c,c);dob(a+8|0,b+8|0,c,c);d=c<<3;dob(a+d|0,b+d|0,c,c);e=d+8|0;dob(a+e|0,b+e|0,c,c);return}function znb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;cob(a,b,c,c);cob(a+8|0,b+8|0,c,c);d=c<<3;cob(a+d|0,b+d|0,c,c);e=d+8|0;cob(a+e|0,b+e|0,c,c);return}function Anb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;bob(a,b,c,c,12,6);bob(a+8|0,b+8|0,c,c,12,6);d=c<<3;bob(a+d|0,b+d|0,c,c,12,6);e=d+8|0;bob(a+e|0,b+e|0,c,c,12,6);return}function Bnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;bob(a,b,c,c,6,12);bob(a+8|0,b+8|0,c,c,6,12);d=c<<3;bob(a+d|0,b+d|0,c,c,6,12);e=d+8|0;bob(a+e|0,b+e|0,c,c,6,12);return}function Cnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;_nb(a,b,c,c,12,6);_nb(a+8|0,b+8|0,c,c,12,6);d=c<<3;_nb(a+d|0,b+d|0,c,c,12,6);e=d+8|0;_nb(a+e|0,b+e|0,c,c,12,6);return}function Dnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;aob(a,b,c,c);aob(a+8|0,b+8|0,c,c);d=c<<3;aob(a+d|0,b+d|0,c,c);e=d+8|0;aob(a+e|0,b+e|0,c,c);return}function Enb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;$nb(a,b,c,c);$nb(a+8|0,b+8|0,c,c);d=c<<3;$nb(a+d|0,b+d|0,c,c);e=d+8|0;$nb(a+e|0,b+e|0,c,c);return}function Fnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;_nb(a,b,c,c,6,12);_nb(a+8|0,b+8|0,c,c,6,12);d=c<<3;_nb(a+d|0,b+d|0,c,c,6,12);e=d+8|0;_nb(a+e|0,b+e|0,c,c,6,12);return}function Gnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Znb(a,b,c,c);Znb(a+8|0,b+8|0,c,c);d=c<<3;Znb(a+d|0,b+d|0,c,c);e=d+8|0;Znb(a+e|0,b+e|0,c,c);return}function Hnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Ynb(a,b,c,c);Ynb(a+8|0,b+8|0,c,c);d=c<<3;Ynb(a+d|0,b+d|0,c,c);e=d+8|0;Ynb(a+e|0,b+e|0,c,c);return}function Inb(a,b,c){a=a|0;b=b|0;c=c|0;hob(a,b,c,c,12,6);return}function Jnb(a,b,c){a=a|0;b=b|0;c=c|0;hob(a,b,c,c,6,12);return}function Knb(a,b,c){a=a|0;b=b|0;c=c|0;eob(a,b,c,c,12,6);return}function Lnb(a,b,c){a=a|0;b=b|0;c=c|0;gob(a,b,c,c);return}function Mnb(a,b,c){a=a|0;b=b|0;c=c|0;fob(a,b,c,c);return}function Nnb(a,b,c){a=a|0;b=b|0;c=c|0;eob(a,b,c,c,6,12);return}function Onb(a,b,c){a=a|0;b=b|0;c=c|0;dob(a,b,c,c);return}function Pnb(a,b,c){a=a|0;b=b|0;c=c|0;cob(a,b,c,c);return}function Qnb(a,b,c){a=a|0;b=b|0;c=c|0;bob(a,b,c,c,12,6);return}function Rnb(a,b,c){a=a|0;b=b|0;c=c|0;bob(a,b,c,c,6,12);return}function Snb(a,b,c){a=a|0;b=b|0;c=c|0;_nb(a,b,c,c,12,6);return}function Tnb(a,b,c){a=a|0;b=b|0;c=c|0;aob(a,b,c,c);return}function Unb(a,b,c){a=a|0;b=b|0;c=c|0;$nb(a,b,c,c);return}function Vnb(a,b,c){a=a|0;b=b|0;c=c|0;_nb(a,b,c,c,6,12);return}function Wnb(a,b,c){a=a|0;b=b|0;c=c|0;Znb(a,b,c,c);return}function Xnb(a,b,c){a=a|0;b=b|0;c=c|0;Ynb(a,b,c,c);return}function Ynb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=c+i|0;k=i+1|0;l=i+2|0;a[j]=((d[j]|0)+1+(d[(((d[h+i|0]|0)*36|0)+128+((d[h+(k+f)|0]|0)*81|0)+(d[h+(l+g)|0]|0)+(((d[h+(k+g)|0]|0)+(d[h+(l+f)|0]|0)|0)*9|0)+(((d[h+(i+g)|0]|0)+(d[h+l|0]|0)|0)*6|0)+(((d[h+(i+f)|0]|0)+(d[h+k|0]|0)|0)*54|0)>>8)+1236056|0]|0)|0)>>>1;if((k|0)<8){i=k}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function Znb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=c+i|0;k=i-f|0;l=i+1|0;m=i+f|0;n=i+g|0;a[j]=((d[j]|0)+1+(d[((d[h+(k-1)|0]|0)+128+(d[h+(k+2)|0]|0)+((d[h+l|0]|0)*36|0)+((d[h+m|0]|0)*144|0)+(d[h+(n-1)|0]|0)+(d[h+(n+2)|0]|0)+(((d[h+(i-1)|0]|0)+(d[h+(k+1)|0]|0)+(d[h+(i+2)|0]|0)+(d[h+(n+1)|0]|0)|0)*-6|0)+(((d[h+(m-1)|0]|0)+(d[h+k|0]|0)+(d[h+(m+2)|0]|0)+(d[h+n|0]|0)|0)*-12|0)+(((d[h+(m+1)|0]|0)+(d[h+i|0]|0)|0)*72|0)>>8)+1236056|0]|0)|0)>>>1;if((l|0)<8){i=l}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function _nb(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=-f|0;j=f<<1;k=f*3|0;l=f<<2;m=f*5|0;n=f*6|0;o=f*7|0;p=f<<3;q=f*9|0;r=e<<1;s=e*3|0;t=e<<2;u=e*5|0;v=e*6|0;w=e*7|0;x=0;y=c;c=b;while(1){b=d[y]|0;z=d[y+f|0]|0;A=d[y+j|0]|0;B=d[y+k|0]|0;C=d[y+l|0]|0;D=d[y+m|0]|0;E=d[y+n|0]|0;F=d[y+o|0]|0;G=d[y+p|0]|0;H=d[y+q|0]|0;a[c]=((d[c]|0)+1+(d[(8-(d[y+i|0]|0)+(ba(b,g)|0)-A+(ba(z,h)|0)>>4)+1236056|0]|0)|0)>>>1;I=c+e|0;a[I]=((d[I]|0)+1+(d[(8-b+(ba(z,g)|0)-B+(ba(A,h)|0)>>4)+1236056|0]|0)|0)>>>1;b=c+r|0;a[b]=((d[b]|0)+1+(d[(8-z+(ba(A,g)|0)-C+(ba(B,h)|0)>>4)+1236056|0]|0)|0)>>>1;z=c+s|0;a[z]=((d[z]|0)+1+(d[(8-A+(ba(B,g)|0)-D+(ba(C,h)|0)>>4)+1236056|0]|0)|0)>>>1;A=c+t|0;a[A]=((d[A]|0)+1+(d[(8-B+(ba(C,g)|0)-E+(ba(D,h)|0)>>4)+1236056|0]|0)|0)>>>1;B=c+u|0;a[B]=((d[B]|0)+1+(d[(8-C+(ba(D,g)|0)-F+(ba(E,h)|0)>>4)+1236056|0]|0)|0)>>>1;C=c+v|0;a[C]=((d[C]|0)+1+(d[(8-D+(ba(E,g)|0)-G+(ba(F,h)|0)>>4)+1236056|0]|0)|0)>>>1;D=c+w|0;a[D]=((d[D]|0)+1+(d[(8-E+(ba(F,g)|0)-H+(ba(G,h)|0)>>4)+1236056|0]|0)|0)>>>1;G=x+1|0;if((G|0)<8){x=G;y=y+1|0;c=c+1|0}else{break}}return}function $nb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=c+i|0;k=i-f|0;l=i+1|0;m=i+f|0;n=i+g|0;a[j]=((d[j]|0)+1+(d[((d[h+(k-1)|0]|0)+128+(d[h+(k+2)|0]|0)+((d[h+l|0]|0)*144|0)+((d[h+m|0]|0)*36|0)+(d[h+(n-1)|0]|0)+(d[h+(n+2)|0]|0)+(((d[h+(m-1)|0]|0)+(d[h+k|0]|0)+(d[h+(m+2)|0]|0)+(d[h+n|0]|0)|0)*-6|0)+(((d[h+(i-1)|0]|0)+(d[h+(k+1)|0]|0)+(d[h+(i+2)|0]|0)+(d[h+(n+1)|0]|0)|0)*-12|0)+(((d[h+(m+1)|0]|0)+(d[h+i|0]|0)|0)*72|0)>>8)+1236056|0]|0)|0)>>>1;if((l|0)<8){i=l}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function aob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=c+i|0;k=i-f|0;l=i+1|0;m=i+f|0;n=i+g|0;a[j]=((d[j]|0)+1+(d[((d[h+(k-1)|0]|0)+128+(d[h+(k+2)|0]|0)+((d[h+i|0]|0)*144|0)+((d[h+(m+1)|0]|0)*36|0)+(d[h+(n-1)|0]|0)+(d[h+(n+2)|0]|0)+(((d[h+(m-1)|0]|0)+(d[h+(k+1)|0]|0)+(d[h+(m+2)|0]|0)+(d[h+(n+1)|0]|0)|0)*-6|0)+(((d[h+(i-1)|0]|0)+(d[h+k|0]|0)+(d[h+(i+2)|0]|0)+(d[h+n|0]|0)|0)*-12|0)+(((d[h+m|0]|0)+(d[h+l|0]|0)|0)*72|0)>>8)+1236056|0]|0)|0)>>>1;if((l|0)<8){i=l}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function bob(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=c;c=b;b=0;while(1){j=i+2|0;k=ba(d[i]|0,g)|0;l=i+1|0;a[c]=((d[c]|0)+1+(d[(8-(d[i-1|0]|0)-(d[j]|0)+k+(ba(d[l]|0,h)|0)>>4)+1236056|0]|0)|0)>>>1;k=c+1|0;m=i+3|0;n=ba(d[l]|0,g)|0;a[k]=((d[k]|0)+1+(d[(8-(d[i]|0)-(d[m]|0)+n+(ba(d[j]|0,h)|0)>>4)+1236056|0]|0)|0)>>>1;n=c+2|0;k=i+4|0;o=ba(d[j]|0,g)|0;a[n]=((d[n]|0)+1+(d[(8-(d[l]|0)-(d[k]|0)+o+(ba(d[m]|0,h)|0)>>4)+1236056|0]|0)|0)>>>1;o=c+3|0;l=i+5|0;n=ba(d[m]|0,g)|0;a[o]=((d[o]|0)+1+(d[(8-(d[j]|0)-(d[l]|0)+n+(ba(d[k]|0,h)|0)>>4)+1236056|0]|0)|0)>>>1;n=c+4|0;j=i+6|0;o=ba(d[k]|0,g)|0;a[n]=((d[n]|0)+1+(d[(8-(d[m]|0)-(d[j]|0)+o+(ba(d[l]|0,h)|0)>>4)+1236056|0]|0)|0)>>>1;o=c+5|0;m=i+7|0;n=ba(d[l]|0,g)|0;a[o]=((d[o]|0)+1+(d[(8-(d[k]|0)-(d[m]|0)+n+(ba(d[j]|0,h)|0)>>4)+1236056|0]|0)|0)>>>1;n=c+6|0;k=i+8|0;o=ba(d[j]|0,g)|0;a[n]=((d[n]|0)+1+(d[(8-(d[l]|0)-(d[k]|0)+o+(ba(d[m]|0,h)|0)>>4)+1236056|0]|0)|0)>>>1;o=c+7|0;l=ba(d[m]|0,g)|0;a[o]=((d[o]|0)+1+(d[(8-(d[j]|0)-(d[i+9|0]|0)+l+(ba(d[k]|0,h)|0)>>4)+1236056|0]|0)|0)>>>1;k=b+1|0;if((k|0)<8){i=i+f|0;c=c+e|0;b=k}else{break}}return}function cob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=i+1|0;k=i+2|0;a[c+i|0]=a[(((d[h+i|0]|0)*36|0)+128+((d[h+(j+f)|0]|0)*81|0)+(d[h+(k+g)|0]|0)+(((d[h+(j+g)|0]|0)+(d[h+(k+f)|0]|0)|0)*9|0)+(((d[h+(i+g)|0]|0)+(d[h+k|0]|0)|0)*6|0)+(((d[h+(i+f)|0]|0)+(d[h+j|0]|0)|0)*54|0)>>8)+1236056|0]|0;if((j|0)<8){i=j}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function dob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=i-f|0;k=i+1|0;l=i+f|0;m=i+g|0;a[c+i|0]=a[((d[h+(j-1)|0]|0)+128+(d[h+(j+2)|0]|0)+((d[h+k|0]|0)*36|0)+((d[h+l|0]|0)*144|0)+(d[h+(m-1)|0]|0)+(d[h+(m+2)|0]|0)+(((d[h+(i-1)|0]|0)+(d[h+(j+1)|0]|0)+(d[h+(i+2)|0]|0)+(d[h+(m+1)|0]|0)|0)*-6|0)+(((d[h+(l-1)|0]|0)+(d[h+j|0]|0)+(d[h+(l+2)|0]|0)+(d[h+m|0]|0)|0)*-12|0)+(((d[h+(l+1)|0]|0)+(d[h+i|0]|0)|0)*72|0)>>8)+1236056|0]|0;if((k|0)<8){i=k}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function eob(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;i=-f|0;j=f<<1;k=f*3|0;l=f<<2;m=f*5|0;n=f*6|0;o=f*7|0;p=f<<3;q=f*9|0;r=e<<1;s=e*3|0;t=e<<2;u=e*5|0;v=e*6|0;w=e*7|0;x=0;y=c;c=b;while(1){b=d[y]|0;z=d[y+f|0]|0;A=d[y+j|0]|0;B=d[y+k|0]|0;C=d[y+l|0]|0;D=d[y+m|0]|0;E=d[y+n|0]|0;F=d[y+o|0]|0;G=d[y+p|0]|0;H=d[y+q|0]|0;a[c]=a[(8-(d[y+i|0]|0)+(ba(b,g)|0)-A+(ba(z,h)|0)>>4)+1236056|0]|0;a[c+e|0]=a[(8-b+(ba(z,g)|0)-B+(ba(A,h)|0)>>4)+1236056|0]|0;a[c+r|0]=a[(8-z+(ba(A,g)|0)-C+(ba(B,h)|0)>>4)+1236056|0]|0;a[c+s|0]=a[(8-A+(ba(B,g)|0)-D+(ba(C,h)|0)>>4)+1236056|0]|0;a[c+t|0]=a[(8-B+(ba(C,g)|0)-E+(ba(D,h)|0)>>4)+1236056|0]|0;a[c+u|0]=a[(8-C+(ba(D,g)|0)-F+(ba(E,h)|0)>>4)+1236056|0]|0;a[c+v|0]=a[(8-D+(ba(E,g)|0)-G+(ba(F,h)|0)>>4)+1236056|0]|0;a[c+w|0]=a[(8-E+(ba(F,g)|0)-H+(ba(G,h)|0)>>4)+1236056|0]|0;G=x+1|0;if((G|0)<8){x=G;y=y+1|0;c=c+1|0}else{break}}return}function fob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=i-f|0;k=i+1|0;l=i+f|0;m=i+g|0;a[c+i|0]=a[((d[h+(j-1)|0]|0)+128+(d[h+(j+2)|0]|0)+((d[h+k|0]|0)*144|0)+((d[h+l|0]|0)*36|0)+(d[h+(m-1)|0]|0)+(d[h+(m+2)|0]|0)+(((d[h+(l-1)|0]|0)+(d[h+j|0]|0)+(d[h+(l+2)|0]|0)+(d[h+m|0]|0)|0)*-6|0)+(((d[h+(i-1)|0]|0)+(d[h+(j+1)|0]|0)+(d[h+(i+2)|0]|0)+(d[h+(m+1)|0]|0)|0)*-12|0)+(((d[h+(l+1)|0]|0)+(d[h+i|0]|0)|0)*72|0)>>8)+1236056|0]|0;if((k|0)<8){i=k}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function gob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=i-f|0;k=i+1|0;l=i+f|0;m=i+g|0;a[c+i|0]=a[((d[h+(j-1)|0]|0)+128+(d[h+(j+2)|0]|0)+((d[h+i|0]|0)*144|0)+((d[h+(l+1)|0]|0)*36|0)+(d[h+(m-1)|0]|0)+(d[h+(m+2)|0]|0)+(((d[h+(l-1)|0]|0)+(d[h+(j+1)|0]|0)+(d[h+(l+2)|0]|0)+(d[h+(m+1)|0]|0)|0)*-6|0)+(((d[h+(i-1)|0]|0)+(d[h+j|0]|0)+(d[h+(i+2)|0]|0)+(d[h+m|0]|0)|0)*-12|0)+(((d[h+l|0]|0)+(d[h+k|0]|0)|0)*72|0)>>8)+1236056|0]|0;if((k|0)<8){i=k}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function hob(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c;c=b;b=0;while(1){j=i+2|0;k=ba(d[i]|0,g)|0;l=i+1|0;a[c]=a[(8-(d[i-1|0]|0)-(d[j]|0)+k+(ba(d[l]|0,h)|0)>>4)+1236056|0]|0;k=i+3|0;m=ba(d[l]|0,g)|0;a[c+1|0]=a[(8-(d[i]|0)-(d[k]|0)+m+(ba(d[j]|0,h)|0)>>4)+1236056|0]|0;m=i+4|0;n=ba(d[j]|0,g)|0;a[c+2|0]=a[(8-(d[l]|0)-(d[m]|0)+n+(ba(d[k]|0,h)|0)>>4)+1236056|0]|0;n=i+5|0;l=ba(d[k]|0,g)|0;a[c+3|0]=a[(8-(d[j]|0)-(d[n]|0)+l+(ba(d[m]|0,h)|0)>>4)+1236056|0]|0;l=i+6|0;j=ba(d[m]|0,g)|0;a[c+4|0]=a[(8-(d[k]|0)-(d[l]|0)+j+(ba(d[n]|0,h)|0)>>4)+1236056|0]|0;j=i+7|0;k=ba(d[n]|0,g)|0;a[c+5|0]=a[(8-(d[m]|0)-(d[j]|0)+k+(ba(d[l]|0,h)|0)>>4)+1236056|0]|0;k=i+8|0;m=ba(d[l]|0,g)|0;a[c+6|0]=a[(8-(d[n]|0)-(d[k]|0)+m+(ba(d[j]|0,h)|0)>>4)+1236056|0]|0;m=ba(d[j]|0,g)|0;a[c+7|0]=a[(8-(d[l]|0)-(d[i+9|0]|0)+m+(ba(d[k]|0,h)|0)>>4)+1236056|0]|0;k=b+1|0;if((k|0)<8){i=i+f|0;c=c+e|0;b=k}else{break}}return}function iob(a){a=a|0;c[a+552>>2]=234;c[a+556>>2]=354;c[a+560>>2]=728;c[a+564>>2]=1306;return}function job(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+64|0;e=d|0;f=0;while(1){g=b[a+(f<<1)>>1]|0;h=b[a+(f+8<<1)>>1]|0;j=(h+g|0)*13|0;k=(g-h|0)*13|0;h=b[a+(f+4<<1)>>1]|0;g=b[a+(f+12<<1)>>1]|0;l=(g*-17|0)+(h*7|0)|0;m=(g*7|0)+(h*17|0)|0;h=f<<2;c[e+(h<<2)>>2]=m+j;c[e+((h|1)<<2)>>2]=l+k;c[e+((h|2)<<2)>>2]=k-l;c[e+((h|3)<<2)>>2]=j-m;m=f+1|0;if((m|0)<4){f=m}else{n=0;break}}do{f=c[e+(n<<2)>>2]|0;m=c[e+(n+8<<2)>>2]|0;j=(m+f|0)*39|0;h=(f-m|0)*39|0;m=c[e+(n+4<<2)>>2]|0;f=c[e+(n+12<<2)>>2]|0;l=(f*-51|0)+(m*21|0)|0;k=(f*21|0)+(m*51|0)|0;m=n<<2;b[a+(m<<1)>>1]=(k+j|0)>>>11;b[a+((m|1)<<1)>>1]=(l+h|0)>>>11;b[a+((m|2)<<1)>>1]=(h-l|0)>>>11;b[a+((m|3)<<1)>>1]=(j-k|0)>>>11;n=n+1|0;}while((n|0)<4);i=d;return}function kob(a){a=a|0;var c=0;c=((b[a>>1]|0)*507|0)>>>11&65535;b[a>>1]=c;b[a+2>>1]=c;b[a+4>>1]=c;b[a+6>>1]=c;b[a+8>>1]=c;b[a+10>>1]=c;b[a+12>>1]=c;b[a+14>>1]=c;b[a+16>>1]=c;b[a+18>>1]=c;b[a+20>>1]=c;b[a+22>>1]=c;b[a+24>>1]=c;b[a+26>>1]=c;b[a+28>>1]=c;b[a+30>>1]=c;return}function lob(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+64|0;j=h|0;k=0;do{l=b[g+(k<<1)>>1]|0;m=b[g+(k+8<<1)>>1]|0;n=(m+l|0)*13|0;o=(l-m|0)*13|0;m=b[g+(k+4<<1)>>1]|0;l=b[g+(k+12<<1)>>1]|0;p=(l*-17|0)+(m*7|0)|0;q=(l*7|0)+(m*17|0)|0;m=k<<2;c[j+(m<<2)>>2]=q+n;c[j+((m|1)<<2)>>2]=p+o;c[j+((m|2)<<2)>>2]=o-p;c[j+((m|3)<<2)>>2]=n-q;k=k+1|0;}while((k|0)<4);TGb(g|0,0,32)|0;g=0;k=e;while(1){e=c[j+(g<<2)>>2]|0;q=c[j+(g+8<<2)>>2]|0;n=((q+e|0)*13|0)+512|0;m=((e-q|0)*13|0)+512|0;q=c[j+(g+4<<2)>>2]|0;e=c[j+(g+12<<2)>>2]|0;p=(e*-17|0)+(q*7|0)|0;o=(e*7|0)+(q*17|0)|0;q=(o+n>>10)+(d[k]|0)|0;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[k]=r;q=k+1|0;e=(d[q]|0)+(p+m>>10)|0;if(e>>>0>255>>>0){s=-e>>31&255}else{s=e&255}a[q]=s;q=k+2|0;e=(d[q]|0)+(m-p>>10)|0;if(e>>>0>255>>>0){t=-e>>31&255}else{t=e&255}a[q]=t;q=k+3|0;e=(d[q]|0)+(n-o>>10)|0;if(e>>>0>255>>>0){u=-e>>31&255}else{u=e&255}a[q]=u;q=g+1|0;if((q|0)<4){g=q;k=k+f|0}else{break}}i=h;return}function mob(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(e*169|0)+512>>10;e=b;b=0;while(1){g=(d[e]|0)+f|0;if(g>>>0>255>>>0){h=-g>>31&255}else{h=g&255}a[e]=h;g=e+1|0;i=(d[g]|0)+f|0;if(i>>>0>255>>>0){j=-i>>31&255}else{j=i&255}a[g]=j;g=e+2|0;i=(d[g]|0)+f|0;if(i>>>0>255>>>0){k=-i>>31&255}else{k=i&255}a[g]=k;g=e+3|0;i=(d[g]|0)+f|0;if(i>>>0>255>>>0){l=-i>>31&255}else{l=i&255}a[g]=l;g=b+1|0;if((g|0)<4){e=e+c|0;b=g}else{break}}return}function nob(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=e>>>2;g=d>>>2;if((g|0)==0){return}d=c>>>2;h=e-c|0;if((d|0)==0){return}c=d<<2;e=0;i=b;while(1){b=0;j=i;while(1){oob(a,j,f,0,0,0);k=b+1|0;if(k>>>0<d>>>0){b=k;j=j+16|0}else{break}}j=e+1|0;if(j>>>0<g>>>0){e=j;i=i+(c+h<<2)|0}else{break}}return}function oob(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=i;i=i+16|0;k=j|0;l=(f|0)!=0;f=-(l&1^1)<<24;m=a|0;n=c[m>>2]|0;o=c[a+4>>2]|0;if((o-n|0)<2){p=0;q=n}else{a=n+2|0;c[m>>2]=a;r=n;p=(d[r]|d[r+1|0]<<8)<<16>>16&65535;q=a}if((o-q|0)<2){s=0;t=q}else{a=q+2|0;c[m>>2]=a;r=q;s=(d[r]|d[r+1|0]<<8)<<16>>16&65535;t=a}a=p<<3|p<<8;r=s<<3|s<<8;q=a>>>5&458759|a&16253176;a=r>>>5&458759|r&16253176;r=p<<5&64512;n=s<<5&64512;u=r>>>6&768|r;r=n>>>6&768|n;c[k>>2]=u|f|q;c[k+4>>2]=r|f|a;if(p>>>0>s>>>0|l){c[k+12>>2]=(((r<<1)+u|0)*21|0)>>>6&65280|f|(((a<<1)+q|0)*21|0)>>>6&16711935;v=((r+(u<<1)|0)*21|0)>>>6;w=((a+(q<<1)|0)*21|0)>>>6}else{c[k+12>>2]=0;v=(r+u|0)>>>1;w=(a+q|0)>>>1}c[k+8>>2]=w&16711935|f|v&65280;if((o-t|0)<4){x=0;y=h;z=g;A=b;B=0}else{c[m>>2]=t+4;m=t;x=0;y=h;z=g;A=b;B=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0}while(1){c[A>>2]=(c[k+((B&3)<<2)>>2]|0)+((z<<24|0>>>8)&251658240|(z<<28|0>>>4));m=z>>>4|y<<28;c[A+4>>2]=(c[k+((B>>>2&3)<<2)>>2]|0)+((m<<24|0>>>8)&251658240|(m<<28|0>>>4));m=z>>>8|y<<24;c[A+8>>2]=(c[k+((B>>>4&3)<<2)>>2]|0)+((m<<24|0>>>8)&251658240|(m<<28|0>>>4));m=z>>>12|y<<20;c[A+12>>2]=(c[k+((B>>>6&3)<<2)>>2]|0)+((m<<24|0>>>8)&251658240|(m<<28|0>>>4));m=z>>>16|y<<16;b=x+1|0;if(b>>>0<4>>>0){x=b;y=y>>>16|0<<16;z=m;A=A+(e<<2)|0;B=B>>>8}else{break}}i=j;return}function pob(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=g>>>2;i=f>>>2;if((i|0)==0){return}f=e>>>2;j=g-e|0;e=a+4|0;g=a|0;if((f|0)==0){return}k=f<<2;l=0;m=b;while(1){b=0;n=m;while(1){o=c[g>>2]|0;if(((c[e>>2]|0)-o|0)<8){p=0;q=0}else{c[g>>2]=o+8;r=o;o=r|0;s=r+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0}oob(a,n,h,1,q,p);o=b+1|0;if(o>>>0<f>>>0){b=o;n=n+16|0}else{break}}n=l+1|0;if(n>>>0<i>>>0){l=n;m=m+(k+j<<2)|0}else{break}}return}function qob(a){a=a|0;c[a>>2]=198;c[a+4>>2]=2;c[a+8>>2]=356;c[a+12>>2]=248;c[a+16>>2]=436;c[a+20>>2]=226;c[a+24>>2]=136;c[a+28>>2]=40;c[a+32>>2]=4;c[a+36>>2]=84;c[a+40>>2]=22;c[a+44>>2]=220;c[a+48>>2]=24;c[a+52>>2]=224;return}function rob(a){a=a|0;var b=0,c=0;b=0;do{c=a+(b<<2)|0;g[c>>2]=+g[c>>2]+ +g[a+(b+64<<2)>>2]+ +g[a+(b+128<<2)>>2]+ +g[a+(b+192<<2)>>2]+ +g[a+(b+256<<2)>>2];b=b+1|0;}while((b|0)<64);return}function sob(a,b){a=a|0;b=b|0;var c=0.0,d=0.0,e=0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0,m=0.0,n=0.0;if((b|0)>0){c=0.0;d=0.0;e=0}else{f=0.0;h=0.0;i=f+h;return+i}while(1){j=+g[a+(e<<3)>>2];k=+g[a+(e<<3)+4>>2];l=e|1;m=+g[a+(l<<3)>>2];n=c+j*j+m*m;m=+g[a+(l<<3)+4>>2];j=d+k*k+m*m;l=e+2|0;if((l|0)<(b|0)){c=n;d=j;e=l}else{f=n;h=j;break}}i=f+h;return+i}function tob(a){a=a|0;var b=0,d=0;b=1;do{d=a+(b<<2)|0;c[d>>2]=c[d>>2]^-2147483648;d=a+(b+2<<2)|0;c[d>>2]=c[d>>2]^-2147483648;b=b+4|0;}while((b|0)<64);return}function uob(a){a=a|0;var b=0,d=0;c[a+256>>2]=c[a>>2];c[a+260>>2]=c[a+4>>2];b=1;do{d=b<<1;c[a+(d+64<<2)>>2]=c[a+(64-b<<2)>>2]^-2147483648;c[a+(d+65<<2)>>2]=c[a+(b+1<<2)>>2];c[a+(d+66<<2)>>2]=c[a+(63-b<<2)>>2]^-2147483648;b=b+2|0;c[a+(d+67<<2)>>2]=c[a+(b<<2)>>2];}while((b|0)<31);c[a+504>>2]=c[a+132>>2]^-2147483648;c[a+508>>2]=c[a+128>>2];return}function vob(a,b){a=a|0;b=b|0;var d=0,e=0;d=0;do{e=d<<1;c[a+(e<<2)>>2]=c[b+(63-d<<2)>>2]^-2147483648;c[a+((e|1)<<2)>>2]=c[b+(d<<2)>>2];c[a+((e|2)<<2)>>2]=c[b+(62-d<<2)>>2]^-2147483648;c[a+((e|3)<<2)>>2]=c[b+((d|1)<<2)>>2];d=d+2|0;}while((d|0)<32);return}function wob(a,b){a=a|0;b=b|0;var d=0,e=0;d=0;do{e=63-(d<<1)|0;c[a+(d<<2)>>2]=c[b+(e<<2)>>2];c[a+(63-d<<2)>>2]=c[b+(e-1<<2)>>2]^-2147483648;d=d+1|0;}while((d|0)<32);return}function xob(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=0;do{e=b+(d<<2)|0;f=c+(63-d<<2)|0;g[a+(d<<2)>>2]=+g[e>>2]- +g[f>>2];g[a+(127-d<<2)>>2]=+g[e>>2]+ +g[f>>2];d=d+1|0;}while((d|0)<64);return}function yob(a,b){a=a|0;b=b|0;var c=0,d=0.0,e=0.0,f=0,h=0.0,i=0.0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0,u=0.0,v=0.0,w=0,x=0.0,y=0.0,z=0.0;c=a|0;d=+g[c>>2];e=+g[a+16>>2];f=a+4|0;h=+g[f>>2];i=+g[a+20>>2];j=a+8|0;k=a+12|0;l=d*e+h*i;m=d*i-e*h;h=0.0;d=0.0;n=0.0;o=1;p=+g[j>>2];q=+g[k>>2];r=e;e=i;while(1){s=n+(p*p+q*q);t=o+1|0;u=h+(p*r+q*e);v=d+(p*e-q*r);w=o+2|0;i=+g[a+(w<<3)>>2];x=+g[a+(w<<3)+4>>2];y=l+(p*i+q*x);z=m+(p*x-q*i);if((t|0)<38){l=y;m=z;h=u;d=v;n=s;o=t;p=r;q=e;r=i;e=x}else{break}}g[b+8>>2]=y;g[b+12>>2]=z;z=+g[c>>2];y=+g[f>>2];g[b+40>>2]=s+z*z+y*y;o=a+304|0;y=+g[o>>2];t=a+308|0;z=+g[t>>2];g[b+16>>2]=s+y*y+z*z;g[b+24>>2]=u+ +g[c>>2]*+g[j>>2]+ +g[f>>2]*+g[k>>2];g[b+28>>2]=v+ +g[c>>2]*+g[k>>2]- +g[f>>2]*+g[j>>2];j=a+312|0;f=a+316|0;g[b>>2]=u+ +g[o>>2]*+g[j>>2]+ +g[t>>2]*+g[f>>2];g[b+4>>2]=v+ +g[o>>2]*+g[f>>2]- +g[t>>2]*+g[j>>2];return}function zob(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=f|0;h=h|0;var i=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0;i=+g[d>>2]*e*e;j=+g[d+4>>2]*e*e;k=+g[c>>2]*e;l=+g[c+4>>2]*e;if((f|0)<(h|0)){m=f}else{return}do{f=m-2|0;c=b+(f<<3)|0;d=b+(f<<3)+4|0;f=m-1|0;n=b+(f<<3)|0;o=b+(f<<3)+4|0;g[a+(m<<3)>>2]=+g[b+(m<<3)>>2]+(i*+g[c>>2]-j*+g[d>>2]+k*+g[n>>2]-l*+g[o>>2]);g[a+(m<<3)+4>>2]=+g[b+(m<<3)+4>>2]+(i*+g[d>>2]+j*+g[c>>2]+k*+g[o>>2]+l*+g[n>>2]);m=m+1|0;}while((m|0)<(h|0));return}function Aob(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0;if((d|0)>0){f=0}else{return}do{h=c+(f<<2)|0;g[a+(f<<3)>>2]=+g[b+(f*320|0)+(e<<3)>>2]*+g[h>>2];g[a+(f<<3)+4>>2]=+g[b+(f*320|0)+(e<<3)+4>>2]*+g[h>>2];f=f+1|0;}while((f|0)<(d|0));return}function Bob(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0.0;if((f|0)>0){h=0.0;i=d;j=0}else{return}while(1){d=a+(j<<3)|0;e=a+(j<<3)+4|0;k=i+1&511;l=+g[b+(j<<2)>>2];if(l!=0.0){m=h*l;n=l}else{l=+g[c+(j<<2)>>2];m=l*+g[1139692+(k<<3)>>2];n=l*+g[1139688+(k<<3)>>2]}l=+g[e>>2]+m;g[d>>2]=+g[d>>2]+n;g[e>>2]=l;e=j+1|0;if((e|0)<(f|0)){h=-0.0-h;i=k;j=e}else{break}}return}function Cob(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0.0;if((f|0)<=0){return}h=+(1-(e<<1&2)|0);e=d;d=0;while(1){i=a+(d<<3)|0;j=a+(d<<3)+4|0;k=e+1&511;l=+g[b+(d<<2)>>2];if(l!=0.0){m=h*l;n=l*0.0}else{l=+g[c+(d<<2)>>2];m=l*+g[1139692+(k<<3)>>2];n=l*+g[1139688+(k<<3)>>2]}l=+g[j>>2]+m;g[i>>2]=+g[i>>2]+n;g[j>>2]=l;j=d+1|0;if((j|0)<(f|0)){h=-0.0-h;e=k;d=j}else{break}}return}function Dob(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0.0;if((f|0)>0){h=0.0;i=d;j=0}else{return}while(1){d=a+(j<<3)|0;e=a+(j<<3)+4|0;k=i+1&511;l=+g[b+(j<<2)>>2];if(l!=0.0){m=h*l;n=l*-1.0}else{l=+g[c+(j<<2)>>2];m=l*+g[1139692+(k<<3)>>2];n=l*+g[1139688+(k<<3)>>2]}l=+g[e>>2]+m;g[d>>2]=+g[d>>2]+n;g[e>>2]=l;e=j+1|0;if((e|0)<(f|0)){h=-0.0-h;i=k;j=e}else{break}}return}function Eob(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0.0,i=0,j=0,k=0.0,l=0.0,m=0.0;if((f|0)<=0){return}h=+(1-(e<<1&2)|0);e=d;d=0;do{h=-0.0-h;i=a+(d<<3)|0;j=a+(d<<3)+4|0;e=e+1&511;k=+g[b+(d<<2)>>2];if(k!=0.0){l=k*h;m=k*0.0}else{k=+g[c+(d<<2)>>2];l=k*+g[1139692+(e<<3)>>2];m=k*+g[1139688+(e<<3)>>2]}k=+g[j>>2]+l;g[i>>2]=+g[i>>2]+m;g[j>>2]=k;d=d+1|0;}while((d|0)<(f|0));return}function Fob(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((j|0)<=0){return}q=g>>1;r=n|0;s=(i|0)>0;t=h+12|0;u=h+8|0;v=h+4|0;w=(o|0)==0;o=0;do{x=ba(o,g)|0;y=x+q|0;z=ba(o+q|0,g)|0;A=z+q|0;B=o+l|0;C=c[(c[r>>2]|0)+(B<<2)>>2]|0;if((C|0)==0){D=oYa(n,B)|0}else{D=C}a:do{if(s){C=ba(o,m)|0;if(w){B=0;while(1){E=B+C|0;F=D+(B+k<<1)|0;G=(ba(d[(c[u>>2]|0)+E|0]|0,d[f+(y+B)|0]|0)|0)+(ba(d[(c[t>>2]|0)+E|0]|0,d[f+(B+x)|0]|0)|0)+(ba(d[(c[v>>2]|0)+E|0]|0,d[f+(B+z)|0]|0)|0)+(ba(d[(c[h>>2]|0)+E|0]|0,d[f+(A+B)|0]|0)|0)|0;b[F>>1]=(e[F>>1]|0)-(G>>>4);B=B+1|0;if((B|0)>=(i|0)){break a}}}else{H=0}do{B=H+C|0;G=(ba(d[(c[u>>2]|0)+B|0]|0,d[f+(y+H)|0]|0)|0)+(ba(d[(c[t>>2]|0)+B|0]|0,d[f+(H+x)|0]|0)|0)+(ba(d[(c[v>>2]|0)+B|0]|0,d[f+(H+z)|0]|0)|0)+(ba(d[(c[h>>2]|0)+B|0]|0,d[f+(A+H)|0]|0)|0)|0;F=(b[D+(H+k<<1)>>1]|0)+8+(G>>>4)|0;G=F>>4;if(G>>>0>255>>>0){I=(F>>31^255)&255}else{I=G&255}a[p+B|0]=I;H=H+1|0;}while((H|0)<(i|0))}}while(0);o=o+1|0;}while((o|0)<(j|0));return}function Gob(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=0;do{c=0;while(1){TGb(a+7548+(b*533028|0)+8+(c*16656|0)+48|0,-128|0,16608)|0;d=c+1|0;if((d|0)<4){c=d}else{e=1;break}}while(1){TGb(a+7548+(b*533028|0)+66632+(e*16656|0)+48|0,-128|0,16608)|0;c=e+1|0;if((c|0)<4){e=c}else{f=1;break}}while(1){TGb(a+7548+(b*533028|0)+133256+(f*16656|0)+48|0,-128|0,16608)|0;c=f+1|0;if((c|0)<4){f=c}else{g=1;break}}while(1){TGb(a+7548+(b*533028|0)+199880+(g*16656|0)+48|0,-128|0,16608)|0;c=g+1|0;if((c|0)<4){g=c}else{h=1;break}}while(1){TGb(a+7548+(b*533028|0)+266504+(h*16656|0)+48|0,-128|0,16608)|0;c=h+1|0;if((c|0)<4){h=c}else{i=1;break}}while(1){TGb(a+7548+(b*533028|0)+333128+(i*16656|0)+48|0,-128|0,16608)|0;c=i+1|0;if((c|0)<4){i=c}else{j=1;break}}while(1){TGb(a+7548+(b*533028|0)+399752+(j*16656|0)+48|0,-128|0,16608)|0;c=j+1|0;if((c|0)<4){j=c}else{k=1;break}}do{TGb(a+7548+(b*533028|0)+466376+(k*16656|0)+48|0,-128|0,16608)|0;k=k+1|0;}while((k|0)<4);b=b+1|0;}while((b|0)<3);TGb(a+3092|0,-128|0,4256)|0;return}function Hob(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+4>>2]|0;d=(c[b+120>>2]|0)+15>>4;e=(c[b+124>>2]|0)+15>>4;c[a+7528>>2]=d;c[a+7532>>2]=e;b=a+2139660|0;ZDb(c[b>>2]|0);f=ba(d*10|0,e)|0;e=cEb(f<<(c[a+7536>>2]<<1))|0;c[b>>2]=e;return((e|0)==0?-12:0)|0}function Iob(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if(!((a[m+8|0]&1)==0)){q=a[m+5+n|0]|0;r=ba(q&255,16843009)|0;if((k|0)==32){if((l|0)>0){s=0}else{return}do{t=ba(s,h)|0;c[f+t>>2]=r;c[f+(t+4)>>2]=r;c[f+(t+8)>>2]=r;c[f+(t+12)>>2]=r;c[f+(t+16)>>2]=r;c[f+(t+20)>>2]=r;c[f+(t+24)>>2]=r;c[f+(t+28)>>2]=r;s=s+1|0;}while((s|0)<(l|0));return}else if((k|0)==8){if((l|0)>0){u=0}else{return}do{s=ba(u,h)|0;c[f+s>>2]=r;c[f+(s+4)>>2]=r;u=u+1|0;}while((u|0)<(l|0));return}else if((k|0)==4){if((l|0)>0){v=0}else{return}do{c[f+(ba(v,h)|0)>>2]=r;v=v+1|0;}while((v|0)<(l|0));return}else if((k|0)==16){if((l|0)>0){w=0}else{return}do{v=ba(w,h)|0;c[f+v>>2]=r;c[f+(v+4)>>2]=r;c[f+(v+8)>>2]=r;c[f+(v+12)>>2]=r;w=w+1|0;}while((w|0)<(l|0));return}else{if((l|0)>0&(k|0)>0){x=0}else{return}do{TGb(f+(ba(x,h)|0)|0,q|0,k|0)|0;x=x+1|0;}while((x|0)<(l|0));return}}x=c[e+7512>>2]<<1;if((n|0)==0){y=x}else{y=x>>c[e+7480>>2]}x=ba(b[m>>1]|0,y)|0;q=ba(b[m+2>>1]|0,y)|0;y=x&15;w=q&15;r=3-(k>>2)+(k>>4)|0;v=i-3+(x>>4)|0;i=j-3+(q>>4)|0;j=(c[(c[e+2544+(d[m+4|0]<<2)>>2]|0)+(n<<2)>>2]|0)+((ba(i,h)|0)+v)|0;m=o-k-6|0;if(v>>>0<((m|0)>0?m:0)>>>0){m=p-l-6|0;if(i>>>0<((m|0)>0?m:0)>>>0){z=j}else{A=17}}else{A=17}if((A|0)==17){A=g+16|0;Ne[c[e+2e3>>2]&127](A,j,h,h,k+7|0,l+7|0,v,i,o,p);z=A}do{if((x&3|0)==0){if((q&3|0)!=0){break}A=(k|0)==(l|0);p=(l<<1|0)==(k|0);if(!(A|(k<<1|0)==(l|0)|p)){break}if((k-1&k|0)!=0){break}if((c[e+7548+(n*533028|0)+533012>>2]|0)==0){break}if((k|0)==32){if((l|0)<=0){return}o=e+2008+(w+(y>>>2)<<2)|0;i=0;do{v=ba(i,h)|0;j=ba(i|3,h)|0;Xe[c[o>>2]&4095](f+v|0,z+(j+3)|0,h);Xe[c[o>>2]&4095](f+(v+16)|0,z+(j+19)|0,h);i=i+16|0;}while((i|0)<(l|0));return}i=w+(y>>>2)|0;if(A){Xe[c[e+2008+(r<<6)+(i<<2)>>2]&4095](f,z+((h*3|0)+3)|0,h);return}if(p){o=e+2008+(r+1<<6)+(i<<2)|0;j=(h*3|0)+3|0;Xe[c[o>>2]&4095](f,z+j|0,h);Xe[c[o>>2]&4095](f+l|0,z+(j+l)|0,h);return}else{j=e+2008+(r<<6)+(i<<2)|0;i=(h*3|0)+3|0;Xe[c[j>>2]&4095](f,z+i|0,h);o=ba(k,h)|0;Xe[c[j>>2]&4095](f+o|0,z+(o+i)|0,h);return}}}while(0);Job(e+7548+(n*533028|0)|0,f,z,h,k,l,y,w);return}function Job(e,f,g,h,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;n=i;i=i+12848|0;o=n+5120|0;p=n+12800|0;q=n|0;r=o|0;s=d[679320+((m<<4)+l)|0]|0;t=s&15;u=s>>>4;s=(a[679304+t|0]|a[679304+u|0])&255;v=(e|0)!=0;if(v){w=(c[e+533008>>2]|0)==0?15:s}else{w=s}if((w&5|0)==0){x=g}else{s=k+7|0;if((s|0)>0){y=(j|0)>0;z=e+533012|0;A=e+533004|0;B=e+533005|0;C=e+533006|0;D=e+533007|0;E=ba(s,h)|0;F=r;r=q;G=0;H=g;while(1){if(y){I=0;J=a[H]|0;K=a[H+1|0]|0;L=a[H+2|0]|0;M=a[H+3|0]|0;N=a[H+4|0]|0;O=a[H+5|0]|0;P=a[H+6|0]|0;while(1){Q=J&255;R=I+1|0;S=K&255;T=L&255;U=M&255;V=N&255;W=O&255;X=P&255;Y=a[H+(I+7)|0]|0;Z=Y&255;do{if(v){if((c[z>>2]|0)!=0){_=10;break}$=ba(a[A]|0,V+U|0)|0;aa=(ba(a[B]|0,W+T|0)|0)+$|0;$=aa+(ba(a[C]|0,X+S|0)|0)|0;aa=$+(ba(a[D]|0,Z+Q|0)|0)|0;b[r+(I<<1)>>1]=aa;ca=aa+32>>6}else{_=10}}while(0);if((_|0)==10){_=0;Q=((V+U|0)*20|0)+S+X+((W+T|0)*-5|0)|0;b[r+(I<<1)>>1]=Q;ca=Q+16>>5}if(ca>>>0>255>>>0){da=(ca>>31^255)&255}else{da=ca&255}a[F+I|0]=da;if((R|0)<(j|0)){I=R;J=K;K=L;L=M;M=N;N=O;O=P;P=Y}else{break}}}P=G+1|0;if((P|0)<(s|0)){F=F+64|0;r=r+128|0;G=P;H=H+h|0}else{break}}ea=s;fa=g+E|0}else{ea=0;fa=g}x=fa+(ba(ea,-h|0)|0)|0}ea=x+3|0;fa=o+2560|0;if((w&2|0)==0){ga=ea}else{if((k|0)>0){g=j+1|0;E=(g|0)>0;s=h<<1;H=h*3|0;G=h<<2;r=h*5|0;F=h*6|0;da=h*7|0;ca=e+533012|0;D=e+533004|0;C=e+533005|0;B=e+533006|0;A=e+533007|0;z=(ba(k,h)|0)+3|0;y=fa;P=0;O=ea;while(1){if(E){N=0;do{M=d[O+N|0]|0;L=d[O+(N+h)|0]|0;K=d[O+(N+s)|0]|0;J=d[O+(N+H)|0]|0;I=d[O+(N+G)|0]|0;Q=d[O+(N+r)|0]|0;Z=d[O+(N+F)|0]|0;aa=d[O+(N+da)|0]|0;do{if(v){if((c[ca>>2]|0)!=0){_=24;break}$=ba(a[D]|0,I+J|0)|0;ha=ba(a[C]|0,Q+K|0)|0;ia=ba(a[B]|0,Z+L|0)|0;ja=$+32+ha+ia+(ba(a[A]|0,aa+M|0)|0)>>6}else{_=24}}while(0);if((_|0)==24){_=0;ja=L+16+((I+J|0)*20|0)+Z+((Q+K|0)*-5|0)>>5}if(ja>>>0>255>>>0){ka=(ja>>31^255)&255}else{ka=ja&255}a[y+N|0]=ka;N=N+1|0;}while((N|0)<(g|0))}N=P+1|0;if((N|0)<(k|0)){y=y+64|0;P=N;O=O+h|0}else{break}}la=k;ma=x+z|0}else{la=0;ma=ea}ga=ma+(ba(la,-h|0)|0)|0}la=h*3|0;ma=ga+la|0;ea=o+5120|0;if((w&4|0)!=0&(k|0)>0){z=(j|0)>0;x=e+533012|0;O=e+533004|0;P=e+533005|0;y=e+533006|0;g=e+533007|0;e=ea;ka=q;q=0;while(1){if(z){ja=0;do{A=b[ka+(ja<<1)>>1]|0;B=b[ka+(ja+64<<1)>>1]|0;C=b[ka+(ja+128<<1)>>1]|0;D=b[ka+(ja+192<<1)>>1]|0;ca=b[ka+(ja+256<<1)>>1]|0;da=b[ka+(ja+320<<1)>>1]|0;F=b[ka+(ja+384<<1)>>1]|0;r=b[ka+(ja+448<<1)>>1]|0;do{if(v){if((c[x>>2]|0)!=0){_=37;break}G=ba(a[O]|0,ca+D|0)|0;H=ba(a[P]|0,da+C|0)|0;s=ba(a[y]|0,F+B|0)|0;na=G+2048+H+s+(ba(a[g]|0,r+A|0)|0)>>12}else{_=37}}while(0);if((_|0)==37){_=0;na=B+512+((ca+D|0)*20|0)+F+((da+C|0)*-5|0)>>10}if(na>>>0>255>>>0){oa=(na>>31^255)&255}else{oa=na&255}a[e+ja|0]=oa;ja=ja+1|0;}while((ja|0)<(j|0))}ja=q+1|0;if((ja|0)<(k|0)){e=e+64|0;ka=ka+128|0;q=ja}else{break}}}c[p>>2]=ma;c[p+4>>2]=o+192;c[p+8>>2]=ga+(la+1);c[p+16>>2]=fa;c[p+20>>2]=ea;c[p+24>>2]=o+2561;ea=la+h|0;c[p+32>>2]=ga+ea;c[p+36>>2]=o+256;c[p+40>>2]=ga+(ea+1);if((w|0)!=15){w=(4722>>>(u>>>0)&1|0)!=0?64:h;ea=(4722>>>(t>>>0)&1|0)!=0?64:h;ga=d[679240+(m<<3&56|l&7)|0]|0;o=8-ga|0;if((k|0)>0&(j|0)>0){pa=0;qa=c[p+(u<<2)>>2]|0;ra=c[p+(t<<2)>>2]|0;sa=f}else{i=n;return}while(1){t=0;do{u=ba(d[qa+t|0]|0,ga)|0;a[sa+t|0]=(u+4+(ba(d[ra+t|0]|0,o)|0)|0)>>>3;t=t+1|0;}while((t|0)<(j|0));t=pa+1|0;if((t|0)<(k|0)){pa=t;qa=qa+w|0;ra=ra+ea|0;sa=sa+h|0}else{break}}i=n;return}sa=(((m|0)/8|0)<<2)+((l|0)/8|0)|0;ea=sa+1|0;ra=sa+4|0;w=sa+5|0;qa=(4722>>>(sa>>>0)&1|0)!=0?64:h;pa=(4722>>>(ea>>>0)&1|0)!=0?64:h;o=(4722>>>(ra>>>0)&1|0)!=0?64:h;ga=(4722>>>(w>>>0)&1|0)!=0?64:h;t=l&7;l=m&7;if((k|0)<=0){i=n;return}m=8-t|0;u=8-l|0;if((j|0)>0){ta=c[p+(sa<<2)>>2]|0;ua=c[p+(ea<<2)>>2]|0;va=c[p+(ra<<2)>>2]|0;wa=c[p+(w<<2)>>2]|0;xa=0;ya=f}else{i=n;return}while(1){f=0;do{w=ba(d[ta+f|0]|0,m)|0;p=ba(d[ua+f|0]|0,t)|0;ra=ba(d[va+f|0]|0,m)|0;a[ya+f|0]=((ba((ba(d[wa+f|0]|0,t)|0)+ra|0,l)|0)+32+(ba(p+w|0,u)|0)|0)>>>6;f=f+1|0;}while((f|0)<(j|0));f=xa+1|0;if((f|0)<(k|0)){ta=ta+qa|0;ua=ua+pa|0;va=va+o|0;wa=wa+ga|0;xa=f;ya=ya+h|0}else{break}}i=n;return}function Kob(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=c[b+60>>2]|0;f=e+4|0;c[f>>2]=b;c[e+7384>>2]=1;Z3(e+548|0,b);g=e+1792|0;BFa(g,c[b+88>>2]|0);T3a(e+2e3|0,8);GYa(e+2520|0);h=e+2008|0;Soa(h,8);j=c[h>>2]|0;c[e+1428>>2]=j;c[e+1172>>2]=j;j=c[e+2072>>2]|0;c[e+1492>>2]=j;c[e+1236>>2]=j;j=c[e+2012>>2]|0;c[e+1432>>2]=j;c[e+1176>>2]=j;j=c[e+2076>>2]|0;c[e+1496>>2]=j;c[e+1240>>2]=j;j=c[e+2016>>2]|0;c[e+1436>>2]=j;c[e+1180>>2]=j;j=c[e+2080>>2]|0;c[e+1500>>2]=j;c[e+1244>>2]=j;j=c[e+2020>>2]|0;c[e+1440>>2]=j;c[e+1184>>2]=j;j=c[e+2084>>2]|0;c[e+1504>>2]=j;c[e+1248>>2]=j;j=c[e+2024>>2]|0;c[e+1444>>2]=j;c[e+1188>>2]=j;j=c[e+2088>>2]|0;c[e+1508>>2]=j;c[e+1252>>2]=j;j=c[e+2028>>2]|0;c[e+1448>>2]=j;c[e+1192>>2]=j;j=c[e+2092>>2]|0;c[e+1512>>2]=j;c[e+1256>>2]=j;j=c[e+2032>>2]|0;c[e+1452>>2]=j;c[e+1196>>2]=j;j=c[e+2096>>2]|0;c[e+1516>>2]=j;c[e+1260>>2]=j;j=c[e+2036>>2]|0;c[e+1456>>2]=j;c[e+1200>>2]=j;j=c[e+2100>>2]|0;c[e+1520>>2]=j;c[e+1264>>2]=j;j=c[e+2040>>2]|0;c[e+1460>>2]=j;c[e+1204>>2]=j;j=c[e+2104>>2]|0;c[e+1524>>2]=j;c[e+1268>>2]=j;j=c[e+2044>>2]|0;c[e+1464>>2]=j;c[e+1208>>2]=j;j=c[e+2108>>2]|0;c[e+1528>>2]=j;c[e+1272>>2]=j;j=c[e+2048>>2]|0;c[e+1468>>2]=j;c[e+1212>>2]=j;j=c[e+2112>>2]|0;c[e+1532>>2]=j;c[e+1276>>2]=j;j=c[e+2052>>2]|0;c[e+1472>>2]=j;c[e+1216>>2]=j;j=c[e+2116>>2]|0;c[e+1536>>2]=j;c[e+1280>>2]=j;j=c[e+2056>>2]|0;c[e+1476>>2]=j;c[e+1220>>2]=j;j=c[e+2120>>2]|0;c[e+1540>>2]=j;c[e+1284>>2]=j;j=c[e+2060>>2]|0;c[e+1480>>2]=j;c[e+1224>>2]=j;j=c[e+2124>>2]|0;c[e+1544>>2]=j;c[e+1288>>2]=j;j=c[e+2064>>2]|0;c[e+1484>>2]=j;c[e+1228>>2]=j;j=c[e+2128>>2]|0;c[e+1548>>2]=j;c[e+1292>>2]=j;j=c[e+2068>>2]|0;c[e+1488>>2]=j;c[e+1232>>2]=j;j=c[e+2132>>2]|0;c[e+1552>>2]=j;c[e+1296>>2]=j;c[e+1920>>2]=512;c[g>>2]=512;c[e+1936>>2]=784;c[e+1808>>2]=784;c[e+1924>>2]=536;c[e+1796>>2]=536;c[e+1940>>2]=768;c[e+1812>>2]=768;c[e+1928>>2]=804;c[e+1800>>2]=804;c[e+1944>>2]=622;c[e+1816>>2]=622;c[e+1932>>2]=500;c[e+1804>>2]=500;c[e+1948>>2]=632;c[e+1820>>2]=632;g=0;k=128.0;while(1){a[5728784+g|0]=Gc(+k)|0;j=g+1|0;if((j|0)<32){g=j;k=k*1.0218971486541166}else{break}}g=c[f>>2]|0;f=c[g+120>>2]|0;j=c[g+124>>2]|0;g=ba(j,f)|0;h=g<<1;l=cEb(h)|0;c[e+7464>>2]=l;a:do{if((l|0)!=0|(h|0)==0){m=g<<2;n=cEb(m)|0;c[e+7456>>2]=n;if(!((n|0)!=0|(m|0)==0)){yDb(b,16,2170560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}m=f<<2;n=cEb(m)|0;c[e+7460>>2]=n;if(!((n|0)!=0|(m|0)==0)){yDb(b,16,2170560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}m=f<<1;n=cEb(m)|0;c[e+7468>>2]=n;if(!((n|0)!=0|(m|0)==0)){yDb(b,16,2170560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}m=ba((f+1|0)>>>1<<2,j+1>>1)|0;n=WDb(m)|0;c[e+7472>>2]=n;if(!((n|0)!=0|(m|0)==0)){yDb(b,16,2170560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}m=e+2544|0;n=0;while(1){if((n|0)>=8){break}p=(n<<8)+256|0;c[5728520+(n<<5)>>2]=p;c[5728524+(n<<5)>>2]=(p|0)/2|0;c[5728528+(n<<5)>>2]=(p|0)/3|0;c[5728532+(n<<5)>>2]=(p|0)/4|0;c[5728536+(n<<5)>>2]=(p|0)/5|0;c[5728540+(n<<5)>>2]=(p|0)/6|0;c[5728544+(n<<5)>>2]=(p|0)/7|0;c[5728548+(n<<5)>>2]=(p|0)/8|0;p=ICb()|0;c[m+(n<<2)>>2]=p;if((p|0)==0){break a}else{n=n+1|0}}n=e+3088|0;c[n>>2]=ICb()|0;m=ICb()|0;c[e+2540>>2]=m;if((c[n>>2]|0)==0|(m|0)==0){break}else{q=0}i=d;return q|0}else{yDb(b,16,2170560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);q=-12;i=d;return q|0}function Lob(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Job(0,a,b+((c*-3|0)-3)|0,c,16,16,0,0);return}function Mob(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Job(0,a,b+((c*-3|0)-3)|0,c,8,8,0,0);return}function Nob(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Job(0,a,b+((c*-3|0)-3)|0,c,16,16,8,0);return}function Oob(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Job(0,a,b+((c*-3|0)-3)|0,c,8,8,8,0);return}function Pob(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Job(0,a,b+((c*-3|0)-3)|0,c,16,16,0,8);return}function Qob(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Job(0,a,b+((c*-3|0)-3)|0,c,8,8,0,8);return}function Rob(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Job(0,a,b+((c*-3|0)-3)|0,c,16,16,8,8);return}function Sob(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Job(0,a,b+((c*-3|0)-3)|0,c,8,8,8,8);return}function Tob(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;b=i;d=c[a+60>>2]|0;e=d+2158472|0;do{if((c[e>>2]|0)==0){f=d+3088|0;g=_$a(c[d+4>>2]|0,c[f>>2]|0,1)|0;if((g|0)<0){h=g;i=b;return h|0}g=c[(c[f>>2]|0)+32>>2]|0;j=a+120|0;k=(c[j>>2]<<1)+256|0;l=cEb(((g|0)>(k|0)?g:k)*112|0)|0;c[e>>2]=l;k=c[(c[f>>2]|0)+32>>2]|0;g=c[j>>2]|0;do{if((l|0)==0){j=(g<<1)+256|0;if((((k|0)>(j|0)?k:j)*112|0|0)==0){break}yDb(a,16,2170560,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-12;i=b;return h|0}}while(0);l=(g<<1)+256|0;j=((k|0)>(l|0)?k:l)*39|0;l=WDb(j)|0;c[d+2158476>>2]=l;if((l|0)!=0|(j|0)==0){n=f;break}yDb(a,16,2170560,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-12;i=b;return h|0}else{n=d+3088|0}}while(0);if((c[(c[n>>2]|0)+80>>2]|0)!=(c[a+140>>2]|0)){yDb(a,16,2302768,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}m=d+7544|0;if((c[m>>2]|0)<=0){h=0;i=b;return h|0}a=d+4|0;n=d+7548|0;e=d+7372|0;j=d+7456|0;l=d+7464|0;o=d+7480|0;p=d+7484|0;d=0;a:while(1){q=c[a>>2]|0;r=c[q+120>>2]|0;s=c[q+124>>2]|0;if((d|0)==0){t=s;u=r}else{t=s>>c[p>>2];u=r>>c[o>>2]}r=n+(d*533028|0)|0;c[r>>2]=u;c[n+(d*533028|0)+4>>2]=t;s=c[e>>2]|0;if((s|0)>0){q=u;v=t;w=s;while(1){s=w-1|0;x=(s|0)!=0;y=w-2|0;z=q+1>>1;A=x&1;while(1){if((A|0)>=4){break}B=c[j>>2]|0;C=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+20|0;c[C>>2]=B;c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)>>2]=s;D=c[r>>2]<<(c[e>>2]|0)-s;c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+4>>2]=D;E=A&1;F=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+8|0;c[F>>2]=(E^1)+q>>1;G=(A|0)>1;H=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+12|0;c[H>>2]=(G&1^1)+v>>1;I=1<<(c[e>>2]|0)-s;c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+36>>2]=I;J=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+28|0;c[J>>2]=0;K=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+32|0;c[K>>2]=0;if((E|0)==0){L=B}else{E=B+(z<<2)|0;c[C>>2]=E;c[J>>2]=z;L=E}if(G){G=L+(D>>1<<2)|0;c[C>>2]=G;c[K>>2]=I>>1;M=G}else{M=L}c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+24>>2]=(c[l>>2]|0)+(M-(c[j>>2]|0)>>2<<1);if(x){c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+44>>2]=n+(d*533028|0)+8+(y*66624|0)+(A*16656|0)}G=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+40|0;$Db(G);I=cEb((ba(c[H>>2]<<2,(c[F>>2]|0)+1|0)|0)+4|0)|0;c[G>>2]=I;if((I|0)==0){h=-12;N=27;break a}else{A=A+1|0}}if((s|0)>0){q=z;v=v+1>>1;w=s}else{break}}}w=d+1|0;if((w|0)<(c[m>>2]|0)){d=w}else{h=0;N=27;break}}if((N|0)==27){i=b;return h|0}return 0}function Uob(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+60>>2]|0;a=b+7384|0;d=c[b+2544+((c[a>>2]|0)-1<<2)>>2]|0;if((c[d>>2]|0)==0){return}KCb(d);d=b+2576|0;e=b+2540|0;b=0;do{f=(b|0)%3|0;g=c[d+((c[a>>2]|0)-1<<6)+(((b|0)/3|0)+1<<4)+(f<<2)>>2]|0;if((g|0)!=0){ZDb(g+(-16-(c[(c[e>>2]|0)+32+(f<<2)>>2]<<4))|0)}b=b+1|0;}while((b|0)<9);return}function Vob(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=a+4|0;e=c[d>>2]|0;f=c[e+120>>2]|0;g=c[e+124>>2]|0;h=a+2540|0;j=c[h>>2]|0;k=c[j>>2]|0;do{if((k|0)!=0){if((c[e+88>>2]&16384|0)!=0){break}l=a+1752|0;Ke[c[l>>2]&1023](k,c[j+32>>2]|0,f,g,16,16,3);m=c[h>>2]|0;if((c[m+8>>2]|0)==0){break}n=a+7480|0;o=c[n>>2]|0;p=a+7484|0;q=c[p>>2]|0;Ke[c[l>>2]&1023](c[m+4>>2]|0,c[m+36>>2]|0,f>>o,g>>q,16>>>(o>>>0),16>>>(q>>>0),3);q=c[h>>2]|0;o=c[n>>2]|0;n=c[p>>2]|0;Ke[c[l>>2]&1023](c[q+8>>2]|0,c[q+40>>2]|0,f>>o,g>>n,16>>>(o>>>0),16>>>(n>>>0),3)}}while(0);g=c[(c[d>>2]|0)+60>>2]|0;f=g+7384|0;j=c[g+2544+((c[f>>2]|0)-1<<2)>>2]|0;if((c[j>>2]|0)!=0){KCb(j);j=g+2576|0;k=g+2540|0;g=0;do{e=(g|0)%3|0;n=c[j+((c[f>>2]|0)-1<<6)+(((g|0)/3|0)+1<<4)+(e<<2)>>2]|0;if((n|0)!=0){ZDb(n+(-16-(c[(c[k>>2]|0)+32+(e<<2)>>2]<<4))|0)}g=g+1|0;}while((g|0)<9)}g=a+7384|0;k=c[g>>2]|0;f=k-1|0;j=c[a+2544+(f<<2)>>2]|0;if((f|0)>0){e=f;while(1){f=e-1|0;c[a+2544+(e<<2)>>2]=c[a+2544+(f<<2)>>2];if((f|0)>0){e=f}else{break}}r=c[g>>2]|0}else{r=k}VGb(a+2640|0,a+2576|0,(r<<6)-64|0)|0;r=c[h>>2]|0;c[a+2544>>2]=r;c[h>>2]=j;k=a+7348|0;do{if((c[k>>2]|0)==0){e=c[g>>2]|0;if((e|0)>0){f=0;n=r;while(1){if((c[n>>2]|0)==0){s=f;break}if((f|0)!=0){if((c[(c[a+2544+(f-1<<2)>>2]|0)+84>>2]|0)!=0){s=f;break}}o=f+1|0;if((o|0)>=(e|0)){s=o;break}f=o;n=c[a+2544+(o<<2)>>2]|0}c[a+7388>>2]=s;if((s|0)!=0){break}}else{c[a+7388>>2]=0}yDb(c[d>>2]|0,16,2172888,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;t=-1;i=b;return t|0}else{c[a+7388>>2]=0}}while(0);a=_$a(c[d>>2]|0,j,1)|0;if((a|0)<0){t=a;i=b;return t|0}c[(c[h>>2]|0)+84>>2]=c[k>>2];t=0;i=b;return t|0}function Wob(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;$Db(a+7456|0);$Db(a+7460|0);$Db(a+7464|0);$Db(a+7468|0);$Db(a+7472|0);c[a+2156008>>2]=0;$Db(a+2155992|0);$Db(a+2156016|0);$Db(a+2156020|0);$Db(a+2153752|0);$Db(a+2139660|0);$Db(a+2158472|0);$Db(a+2158476|0);d=a+2540|0;e=0;do{$Db(a+7392+(e<<2)|0);$Db(a+7424+(e<<2)|0);f=a+2544+(e<<2)|0;g=c[c[f>>2]>>2]|0;if((g|0)!=0){if((g|0)==(c[c[d>>2]>>2]|0)){h=6;break}}JCb(f);e=e+1|0;}while((e|0)<8);if((h|0)==6){yDb(0,0,2098328,(h=i,i=i+24|0,c[h>>2]=2043104,c[h+8>>2]=1998032,c[h+16>>2]=693,h)|0);i=h;Cd()}h=a+7544|0;e=c[h>>2]|0;if((e|0)<=0){j=a+3088|0;JCb(j);JCb(d);i=b;return}f=a+7372|0;g=0;k=e;while(1){e=c[f>>2]|0;if((e|0)>0){l=e;do{l=l-1|0;e=(l|0)!=0|0;do{$Db(a+7548+(g*533028|0)+8+(l*66624|0)+(e*16656|0)+40|0);e=e+1|0;}while((e|0)<4);}while((l|0)>0);m=c[h>>2]|0}else{m=k}l=g+1|0;if((l|0)<(m|0)){g=l;k=m}else{break}}j=a+3088|0;JCb(j);JCb(d);i=b;return}function Xob(a,b,c){a=a|0;b=b|0;c=c|0;var f=0,g=0,h=0;if((b|0)>0){f=c;g=0}else{h=c&65535;return h|0}do{f=(e[1487616+(((d[a+g|0]|0)^f>>8)<<1)>>1]|0)^f<<8&65280;g=g+1|0;}while((g|0)<(b|0));h=f&65535;return h|0}function Yob(a,b){a=a|0;b=b|0;return((d[a+1|0]|0)-(d[b+1|0]|0)<<8|(d[a]|0))-(d[b]|0)|0}function Zob(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=b-1|0;if((c|0)==0){b=0;while(1){d=b+1|0;if(d>>>0>a>>>0){e=b;break}else{b=d}}return e|0}else{f=0}while(1){b=f+1|0;d=0;g=b;do{g=ba(g,b)|0;d=d+1|0;}while(d>>>0<c>>>0);if(g>>>0>a>>>0){e=f;break}else{f=b}}return e|0}function _ob(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+136|0;g=f|0;TGb(g|0,0,132)|0;c[g>>2]=404;h=0;while(1){j=b+h|0;k=h+1|0;if((a[j]|0)==0&h>>>0<e>>>0){h=k}else{break}}if((h|0)==(e|0)){l=0;i=f;return l|0}c[d+(h<<2)>>2]=0;h=a[j]|0;if((h&255)>>>0>32>>>0){l=1;i=f;return l|0}if(h<<24>>24==0){m=k}else{j=h&255;h=0;while(1){n=h+1|0;c[g+(n<<2)>>2]=1<<h;if(n>>>0<j>>>0){h=n}else{m=k;break}}}while(1){if((a[b+m|0]|0)==0&m>>>0<e>>>0){m=m+1|0}else{break}}if((m|0)==(e|0)){l=0;i=f;return l|0}a:do{if(k>>>0<e>>>0){m=k;b:while(1){h=a[b+m|0]|0;if((h&255)>>>0>32>>>0){l=1;o=22;break}if(!(h<<24>>24==0)){j=h&255;h=j;while(1){if((h|0)==0){l=1;o=22;break b}p=g+(h<<2)|0;q=c[p>>2]|0;if((q|0)==0){h=h-1|0}else{break}}c[p>>2]=0;n=h+1|0;if(!(n>>>0>j>>>0)){r=h;s=n;while(1){c[g+(s<<2)>>2]=(1<<r)+q;n=s+1|0;if(n>>>0>j>>>0){break}else{r=s;s=n}}}c[d+(m<<2)>>2]=q}s=m+1|0;if(s>>>0<e>>>0){m=s}else{t=1;break a}}if((o|0)==22){i=f;return l|0}}else{t=1}}while(0);while(1){if(!(t>>>0<33>>>0)){l=0;o=22;break}if((c[g+(t<<2)>>2]|0)==0){t=t+1|0}else{l=1;o=22;break}}if((o|0)==22){i=f;return l|0}return 0}function $ob(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;b[d+2>>1]=0;b[d+10>>1]=1;if((f|0)>2){h=2;do{j=d+(h<<3)+4|0;b[j>>1]=0;k=d+(h<<3)+6|0;b[k>>1]=1;b[d+(h<<3)+2>>1]=h;if((h|0)>2){l=b[d+(h<<3)>>1]|0;m=2;n=0;o=1;while(1){p=b[d+(m<<3)>>1]|0;do{if((p&65535)>>>0<(l&65535)>>>0){if(!((p&65535)>>>0>(e[d+((n&65535)<<3)>>1]|0)>>>0)){q=n;r=o;break}s=m&65535;b[j>>1]=s;q=s;r=o}else{if(!((p&65535)>>>0<(e[d+((o&65535)<<3)>>1]|0)>>>0)){q=n;r=o;break}s=m&65535;b[k>>1]=s;q=n;r=s}}while(0);p=m+1|0;if((p|0)<(h|0)){m=p;n=q;o=r}else{break}}}h=h+1|0;}while((h|0)<(f|0))}h=f-1|0;if((h|0)>0){t=0}else{u=0;i=g;return u|0}a:while(1){r=t+1|0;if((r|0)<(f|0)){q=b[d+(t<<3)>>1]|0;o=d+(t<<3)+2|0;n=r;do{if(q<<16>>16==(b[d+(n<<3)>>1]|0)){break a}m=b[o>>1]|0;k=d+(n<<3)+2|0;j=b[k>>1]|0;if((e[d+((m&65535)<<3)>>1]|0)>>>0>(e[d+((j&65535)<<3)>>1]|0)>>>0){b[o>>1]=j;b[k>>1]=m}n=n+1|0;}while((n|0)<(f|0))}if((r|0)<(h|0)){t=r}else{u=0;v=20;break}}if((v|0)==20){i=g;return u|0}yDb(a,16,2170312,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;u=-1094995529;i=g;return u|0}function apb(a,b,d,f,g,h,i){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=0;k=ba(e[d>>1]|0,g)|0;l=1;while(1){if((l|0)>=(b|0)){m=j;n=k;break}o=e[a+(l<<3)+2>>1]|0;do{if((c[f+(o<<2)>>2]|0)==0){p=j;q=k}else{r=e[a+(o<<3)>>1]|0;s=ba(e[d+(o<<1)>>1]|0,g)|0;if((j|0)>=(i|0)){p=r;q=s;break}bpb(j,k,(r|0)>(i|0)?i:r,s,h);p=r;q=s}}while(0);if((p|0)<(i|0)){j=p;k=q;l=l+1|0}else{m=p;n=q;break}}if((m|0)>=(i|0)){return}bpb(m,n,i,n,h);return}function bpb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=d-b|0;d=c-a|0;h=-d|0;i=(f|0)>-1?f:-f|0;j=f>>31|1;if(b>>>0>255>>>0){k=-b>>31&255}else{k=b&255}g[e+(a<<2)>>2]=+g[1087520+((k&255)<<2)>>2];if((i<<1|0)>(d|0)){k=(f|0)/(d|0)|0;f=i-(ba((k|0)>-1?k:-k|0,d)|0)|0;l=a+1|0;if((l|0)<(c|0)){m=b;n=h;o=l}else{return}while(1){l=m+k|0;p=n+f|0;if((p|0)>-1){q=p-d|0;r=l+j|0}else{q=p;r=l}if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}g[e+(o<<2)>>2]=+g[1087520+((s&255)<<2)>>2];l=o+1|0;if((l|0)<(c|0)){m=r;n=q;o=l}else{break}}return}o=c-1|0;q=a-o|0;a=q+1|0;if((a|0)<0){n=i-d|0;d=b;r=q;m=h;s=a;while(1){a=m+i|0;if((a|0)>-1){f=d+j|0;if(f>>>0>255>>>0){t=-f>>31&255}else{t=f&255}g[e+(r+c<<2)>>2]=+g[1087520+((t&255)<<2)>>2];u=n+a|0;v=r+2|0;w=f}else{u=a;v=s;w=d}if(w>>>0>255>>>0){x=-w>>31&255}else{x=w&255}g[e+(v+o<<2)>>2]=+g[1087520+((x&255)<<2)>>2];a=v+1|0;if((a|0)<0){d=w;r=v;m=u;s=a}else{y=w;z=v;A=u;break}}}else{y=b;z=q;A=h}if((z|0)>=0){return}h=((A+i|0)>-1?j:0)+y|0;if(h>>>0>255>>>0){B=-h>>31&255}else{B=h&255}g[e+(z+c<<2)>>2]=+g[1087520+((B&255)<<2)>>2];return}function cpb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if(e<<24>>24==0){return}f=b+4|0;g=b|0;b=c[g>>2]|0;if((b|0)<1){h=0;i=f;j=e;k=b;l=0}else{b=0;m=f;f=e&255;while(1){e=(d[m]|0)+f&65535;n=m+1|0;a[m]=e;o=(e&65535)>>>8;p=b+1|0;q=c[g>>2]|0;r=o<<16>>16==0;if((p|0)>=(q|0)|r){break}else{b=p;m=n;f=o}}h=p;i=n;j=o&255;k=q;l=r}if((h|0)!=(k|0)|l){return}c[g>>2]=k+1;a[i]=j;return}function dpb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=b;do{if(!(e<<24>>24==1)){h=b|0;i=c[h>>2]|0;if((i|0)==0){break}if(e<<24>>24==0){j=i-1|0;c[h>>2]=j;k=b+4|0;a[f]=a[k]|0;if((j|0)==0){l=k}else{m=i+3|0;n=j;j=k;while(1){k=n-1|0;o=j+1|0;a[j]=a[o]|0;if((k|0)==0){break}else{n=k;j=o}}l=g+m|0}a[l]=0;return}else{j=e&255;n=i;o=b+4+i|0;k=0;while(1){p=n-1|0;q=o-1|0;r=(d[q]|k<<8)&65535;s=(r>>>0)%(j>>>0)|0;a[q]=(r>>>0)/(j>>>0)|0;if((p|0)==0){break}else{n=p;o=q;k=s&65535}}a[f]=s;k=(c[h>>2]|0)-1|0;if((a[b+4+k|0]|0)!=0){return}c[h>>2]=k;return}}}while(0);a[f]=0;return}function epb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;if(e<<24>>24==1){return}g=b|0;h=c[g>>2]|0;if((h|0)==0){return}if(e<<24>>24==0){c[g>>2]=h+1;i=h;j=b+4+h|0;while(1){k=i-1|0;l=j-1|0;a[j]=a[l]|0;if((k|0)==0){break}else{i=k;j=l}}a[b+4|0]=0;return}j=e&255;e=h+4|0;i=h;h=b+4|0;b=0;while(1){l=i-1|0;k=(ba(d[h]|0,j)|0)+b&65535;a[h]=k;m=(k&65535)>>>8;if((l|0)==0){break}else{i=l;h=h+1|0;b=m}}if(m<<16>>16==0){return}c[g>>2]=(c[g>>2]|0)+1;a[f+e|0]=m;return}function fpb(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=0;while(1){f=e*48|0;g=e-2|0;h=0;a:while(1){i=h+2|0;j=0;k=h-2|0;while(1){l=(k-1|0)>>>0<48>>>0;do{if((k|0)<(h|0)){if(l){m=j;n=g}else{o=j;break}while(1){if((n|0)>0){p=(d[c+((n*48|0)+k)|0]|0)+(m<<1)|0}else{p=m}q=n+1|0;if((q|0)>(e|0)){o=p;break}else{m=p;n=q}}}else{if(l){r=j;s=g}else{o=j;break}while(1){if((s|0)!=(e|0)&(s|0)>0){t=(d[c+((s*48|0)+k)|0]|0)+(r<<1)|0}else{t=r}q=s+1|0;if((q|0)>(e|0)){o=t;break}else{r=t;s=q}}}}while(0);l=k+1|0;if((l|0)>(i|0)){break}else{j=o;k=l}}u=h+f|0;do{if((h|0)==1){if((e|0)==1){k=b+u|0;a[k]=(d[5221400+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}else if((e|0)==2){k=b+u|0;a[k]=(d[1039848+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=35;break}else{k=b+u|0;a[k]=(d[1039856+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=35;break}}else if((h|0)==2){if((e|0)==1){k=b+u|0;a[k]=(d[1039864+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}else if((e|0)==2){k=b+u|0;a[k]=(d[1039872+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=35;break}else{k=b+u|0;a[k]=(d[1039880+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=35;break}}else if((h|0)==47){if((e|0)==2){v=25;break a}else if((e|0)!=1){v=26;break a}k=b+u|0;a[k]=(d[1039800+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36}else if((h|0)==48){if((e|0)==2){v=29;break a}else if((e|0)!=1){v=30;break a}k=b+u|0;a[k]=(d[1039800+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36}else{if((e|0)==1){k=b+u|0;a[k]=(d[1039944+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}else if((e|0)==2){k=b+u|0;a[k]=(d[1039952+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}else{k=b+u|0;a[k]=(d[1039968+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}}}while(0);if((v|0)==35){v=0;h=h+1|0;continue}else if((v|0)==36){v=0;k=h+1|0;if((k|0)<48){h=k;continue}else{v=38;break}}}if((v|0)==25){v=0;h=b+u|0;a[h]=(d[1039664+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[h]|0);v=37}else if((v|0)==26){v=0;h=b+u|0;a[h]=(d[1039672+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[h]|0);v=38}else if((v|0)==29){v=0;h=b+u|0;a[h]=(d[1039808+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[h]|0);v=37}else if((v|0)==30){v=0;h=b+u|0;a[h]=(d[1039816+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[h]|0);v=38}if((v|0)==37){v=0;e=e+1|0;continue}else if((v|0)==38){v=0;h=e+1|0;if((h|0)<48){e=h;continue}else{break}}}return}function gpb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=+h;var j=0,k=0,l=0,m=0,n=0.0,o=0,p=0.0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0.0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,T=0.0,U=0,V=0,W=0,X=0.0,Y=0.0,Z=0,_=0.0,$=0,aa=0.0,ba=0.0,ca=0.0,da=0.0,ea=0,fa=0,ga=0.0,ha=0,ia=0.0,ja=0.0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0.0,va=0,wa=0.0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0.0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0.0,Ja=0,Ka=0.0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0.0,Sa=0,Ta=0.0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0;b=i;i=i+1024|0;j=b|0;k=b+512|0;l=f+88|0;m=c[l>>2]|0;n=((m|0)>1?85.8:147.84)/h;o=c[f+80>>2]|0;if((m|0)==1){p=0.0;q=0;s=0;t=0;u=0;v=0;while(1){w=d[o+q|0]|0;if((u-v|0)<(w|0)){x=v;y=q}else{x=w+v|0;y=q+1|0}z=+g[f+5312+(u<<2)>>2];if(z!=0.0){A=u;B=y;C=p+z*z}else{A=t;B=s;C=p}w=u+1|0;if((w|0)<1024){p=C;q=y;s=B;t=A;u=w;v=x}else{D=A;E=B;F=C;break}}}else{C=0.0;B=0;A=0;x=0;while(1){v=x<<7;p=C;u=0;t=B;s=A;y=0;q=0;while(1){w=d[o+u|0]|0;if((y-q|0)<(w|0)){G=q;H=u}else{G=w+q|0;H=u+1|0}z=+g[f+5312+(y+v<<2)>>2];if(z!=0.0){I=(s|0)>(y|0)?s:y;J=(t|0)>(H|0)?t:H;K=p+z*z}else{I=s;J=t;K=p}w=y+1|0;if((w|0)<128){p=K;u=H;t=J;s=I;y=w;q=G}else{break}}q=x+1|0;if((q|0)<8){C=K;B=J;A=I;x=q}else{D=I;E=J;F=K;break}}}J=D+1|0;K=F/+(J|0);if(K==0.0){D=0;do{c[f+4644+(D<<2)>>2]=140;D=D+1|0;}while(D>>>0<128>>>0);i=b;return}if((m|0)>0){D=f+84|0;I=f+80|0;F=+(E|0);C=+(J|0);p=n;J=0;x=c[D>>2]|0;A=m;while(1){if((x|0)>0){B=J<<4;G=f+20+J|0;H=0;o=J<<7;q=x;while(1){y=a[(c[I>>2]|0)+H|0]|0;s=y&255;t=s+o|0;u=H+B|0;v=k+(u<<2)|0;g[v>>2]=0.0;do{if((H|0)>(E|0)){g[v>>2]=0.0;if((a[G]|0)==0){L=q;M=0;break}w=s<<2;N=0;do{TGb(f+5312+((N<<7)+o<<2)|0,0,w|0)|0;N=N+1|0;O=a[G]|0;}while((N|0)<(O&255|0));L=c[D>>2]|0;M=O}else{N=a[G]|0;a:do{if(N<<24>>24==0){P=o;T=0.0}else{w=N&255;if(y<<24>>24==0){U=0;while(1){V=U+1|0;if((V|0)<(w|0)){U=V}else{P=o;T=0.0;break a}}}else{W=o;X=-1.0;Y=0.0;Z=0;_=0.0}while(1){U=(Z<<7)+o|0;if((c[l>>2]|0)==1){V=W;n=X;z=Y;$=0;aa=_;while(1){ba=+g[f+5312+(U+$<<2)>>2];ca=ba*ba;da=+Q(+ba);ba=aa>da?aa:da;da=z+ca;ea=n<ca;fa=ea?$+o|0:V;ga=ea?ca:n;ea=$+1|0;if((ea|0)<(s|0)){V=fa;n=ga;z=da;$=ea;aa=ba}else{ha=fa;ia=ga;ja=da;ka=ba;break}}}else{aa=Y;$=0;z=_;while(1){n=+g[f+5312+(U+$<<2)>>2];ba=+Q(+n);da=z>ba?z:ba;ba=aa+n*n;V=$+1|0;if((V|0)<(s|0)){aa=ba;$=V;z=da}else{ha=W;ia=X;ja=ba;ka=da;break}}}g[v>>2]=ka;$=Z+1|0;if(($|0)<(w|0)){W=ha;X=ia;Y=ja;Z=$;_=ka}else{P=ha;T=ja;break}}}}while(0);if((c[l>>2]|0)==1){w=P-2|0;$=P+3|0;la=($|0)>(t|0)?t:$;ma=(w|0)>(o|0)?w:o}else{la=s;ma=0}z=1.0- +(ma|0)/C;g[j+(u<<2)>>2]=p/(+S(+(T/(K*+(la-ma|0))),+(+(E-H|0)*.1/F+.3))*1.4+z*z*z+.075);L=q;M=N}}while(0);u=H+1|0;if((u|0)<(L|0)){H=u;o=t;q=L}else{break}}na=L;oa=M;pa=c[l>>2]|0}else{na=x;oa=a[f+20+J|0]|0;pa=A}q=(oa&255)+J|0;if((q|0)<(pa|0)){J=q;x=na;A=pa}else{qa=pa;break}}}else{qa=m}m=f+4644|0;TGb(m|0,0,512)|0;pa=0;do{F=+Q(+(+g[f+5312+(pa<<2)>>2]));g[e+736+(pa<<2)>>2]=+R(F*+R(F));pa=pa+1|0;}while((pa|0)<1024);pa=e+736|0;if((qa|0)>0){A=f+84|0;na=f+80|0;F=.001953125/h;x=c[319282]|0;J=0;oa=0;M=qa;qa=c[A>>2]|0;while(1){if((qa|0)>0){L=oa<<4;E=f+20+oa|0;ma=J;la=0;P=oa<<7;while(1){ha=d[(c[na>>2]|0)+la|0]|0;Z=la+L|0;K=+g[k+(Z<<2)>>2];W=f+5156+Z|0;do{if(K<21.544){a[W]=1;ra=ma}else{a[W]=0;O=~~(104.0- +gc(+(1.0/K))*16.0/3.0);if((O|0)<60){sa=60}else{sa=(O|0)>218?218:O}O=j+(Z<<2)|0;D=256;I=-1;q=sa;o=sa;H=ma;G=a[E]|0;while(1){if(G<<24>>24==0){ta=H;ua=0.0;va=0}else{B=200-o+104|0;u=7994608+(B<<2)|0;s=7992896+(B<<2)|0;B=7994608+(o+96<<2)|0;v=H;y=0;T=0.0;while(1){w=(y<<7)+P|0;$=e+736+(w<<2)|0;U=a[(c[na>>2]|0)+la|0]|0;V=U&255;p=+g[u>>2];C=+g[s>>2];ja=+g[B>>2];ka=ja*165140.0;do{if(($|0)==0){if(U<<24>>24==0){wa=0.0;xa=0;break}else{ya=0}while(1){_=+Q(+(+g[f+5312+(ya+w<<2)>>2]));g[e+736+(ya<<2)>>2]=+R(_*+R(_));fa=ya+1|0;if((fa|0)<(V|0)){ya=fa}else{za=pa;Aa=56;break}}}else{za=$;Aa=56}}while(0);b:do{if((Aa|0)==56){Aa=0;$=U<<24>>24==0;if($){wa=0.0;xa=0;break}else{Ba=0}do{_=C*+g[za+(Ba<<2)>>2]+.4054;c[e+336+(Ba<<2)>>2]=_>16.0?16:~~_;Ba=Ba+1|0;}while((Ba|0)<(V|0));if($){wa=0.0;xa=0;break}else{Ca=0;Da=0.0;Ea=0}while(1){fa=(c[e+336+((Ea|1)<<2)>>2]|0)+((c[e+336+(Ea<<2)>>2]|0)*17|0)|0;ea=d[x+fa|0]|0;Fa=fa<<1;fa=c[321528]|0;Ga=Ea+w|0;_=+Q(+(+g[f+5312+(Ga<<2)>>2]));Ha=fa+(Fa<<2)|0;Y=+g[Ha>>2];do{if(Y==64.0){if(!(_<ka)){Ia=ka;Ja=ea+21|0;Ka=Y;break}ia=p*_;La=~~(+R(ia*+R(ia))+.4054);if((La|0)<0){Ma=0}else{Ma=(La|0)>8191?8191:La}ia=+(Ma|0);X=ja*ia*+sb(+ia);La=Ma>>>0>65535>>>0;Na=La?Ma>>>16:Ma;Oa=La?16:0;if((Na&65280|0)==0){Pa=Oa;Qa=Na}else{Pa=Oa|8;Qa=Na>>>8}Ia=X;Ja=ea-3+((d[1191992+Qa|0]|0)+Pa<<1)|0;Ka=+g[Ha>>2]}else{Ia=ja*Y;Ja=ea;Ka=Y}}while(0);Y=_-Ia;ea=(Ka!=0.0)+Ja|0;X=Y*Y+0.0;Y=+Q(+(+g[f+5312+(Ga+1<<2)>>2]));Ha=fa+((Fa|1)<<2)|0;ia=+g[Ha>>2];do{if(ia==64.0){if(!(Y<ka)){Ra=ka;Sa=ea+21|0;Ta=ia;break}z=p*Y;Na=~~(+R(z*+R(z))+.4054);if((Na|0)<0){Ua=0}else{Ua=(Na|0)>8191?8191:Na}z=+(Ua|0);aa=ja*z*+sb(+z);Na=Ua>>>0>65535>>>0;Oa=Na?Ua>>>16:Ua;La=Na?16:0;if((Oa&65280|0)==0){Va=La;Wa=Oa}else{Va=La|8;Wa=Oa>>>8}Ra=aa;Sa=ea-3+((d[1191992+Wa|0]|0)+Va<<1)|0;Ta=+g[Ha>>2]}else{Ra=ja*ia;Sa=ea;Ta=ia}}while(0);ia=Y-Ra;ea=(Ta!=0.0)+Sa|0;_=Da+(+(ea|0)+(X+ia*ia)*h);if(!(_<r)){wa=r;xa=v;break b}Ha=ea+Ca|0;ea=Ea+2|0;if((ea|0)<(V|0)){Ca=Ha;Da=_;Ea=ea}else{wa=_;xa=Ha;break}}}}while(0);ja=T+wa- +(xa|0);V=y+1|0;w=a[E]|0;if((V|0)<(w&255|0)){v=xa;y=V;T=ja}else{ta=xa;ua=ja;va=w;break}}}T=ua*F;ja=K*+g[7994608+(304-o<<2)>>2];if((~~(+R(ja*+R(ja))+.4054)|0)>8190){Aa=72;break}ja=+g[O>>2];p=+Q(+(T-ja));if(p>1.0){Xa=~~+gc(+p)}else{Xa=0}y=(T>ja?-Xa|0:Xa)+o|0;if(y>>>0>255>>>0){Ya=-y>>31&255}else{Ya=y&255}Za=Ya&255;y=Za-o|0;v=(y|0)>-1;if(((v?y:-y|0)|0)<2){break}B=(y|0)>0;if(!((Za|0)<(D|0)|B^1)){break}if(!(v|(Za|0)>(I|0))){break}D=B?D:o;I=B?o:I;q=o;o=Za;H=ta;G=va}if((Aa|0)==72){Aa=0;c[f+4644+(Z<<2)>>2]=q;ra=ta;break}if((Za|0)<(I|0)){_a=I}else{_a=(Za|0)>(D|0)?D:Za}c[f+4644+(Z<<2)>>2]=_a;ra=ta}}while(0);Z=la+1|0;$a=c[A>>2]|0;if((Z|0)>=($a|0)){break}ma=ra;la=Z;P=ha+P|0}ab=ra;bb=c[l>>2]|0;cb=$a;db=E}else{ab=J;bb=M;cb=qa;db=f+20+oa|0}P=(d[db]|0)+oa|0;if((P|0)<(bb|0)){J=ab;oa=P;M=bb;qa=cb}else{break}}eb=c[m>>2]|0}else{eb=0}m=(eb|0)==0?2147483647:eb;eb=1;while(1){cb=f+4644+(eb<<2)|0;qa=c[cb>>2]|0;if((qa|0)==0){c[cb>>2]=c[f+4644+(eb-1<<2)>>2];fb=m}else{fb=(m|0)>(qa|0)?qa:m}qa=eb+1|0;if((qa|0)<128){m=fb;eb=qa}else{break}}eb=(fb|0)==2147483647?0:fb;fb=(eb|0)>255?255:eb;eb=fb+60|0;m=(eb|0)>255?255:eb;eb=126;while(1){qa=f+4644+(eb<<2)|0;cb=c[qa>>2]|0;if((cb|0)==0){bb=c[f+4644+(eb+1<<2)>>2]|0;c[qa>>2]=bb;gb=bb}else{gb=cb}if((gb|0)<(fb|0)){hb=fb}else{hb=(gb|0)>(m|0)?m:gb}c[qa>>2]=hb;if((eb|0)>0){eb=eb-1|0}else{break}}i=b;return}function hpb(b,e,f,h,j){b=b|0;e=e|0;f=f|0;h=h|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0.0,w=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0,L=0,M=0.0,N=0,O=0,P=0.0,S=0.0,T=0,U=0,V=0,W=0.0,X=0.0,Y=0,Z=0.0,_=0,$=0,aa=0,ba=0.0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;k=i;i=i+18240|0;l=k|0;m=k+17280|0;n=k+17760|0;o=a[e|0]|0;p=e+88|0;q=c[p>>2]|0;s=(q|0)==1?5:3;t=1<<s;u=0;do{v=+Q(+(+g[e+5312+(u<<2)>>2]));g[b+736+(u<<2)>>2]=+R(v*+R(v));u=u+1|0;}while((u|0)<1024);u=o&255;w=t-1|0;g[l+4>>2]=0.0;c[l>>2]=-1;c[l+8>>2]=0;g[l+16>>2]=0.0;c[l+12>>2]=-1;c[l+20>>2]=0;g[l+28>>2]=0.0;c[l+24>>2]=-1;c[l+32>>2]=0;g[l+40>>2]=0.0;c[l+36>>2]=-1;c[l+44>>2]=0;g[l+52>>2]=0.0;c[l+48>>2]=-1;c[l+56>>2]=0;g[l+64>>2]=0.0;c[l+60>>2]=-1;c[l+68>>2]=0;g[l+76>>2]=0.0;c[l+72>>2]=-1;c[l+80>>2]=0;g[l+88>>2]=0.0;c[l+84>>2]=-1;c[l+92>>2]=0;g[l+100>>2]=0.0;c[l+96>>2]=-1;c[l+104>>2]=0;g[l+112>>2]=0.0;c[l+108>>2]=-1;c[l+116>>2]=0;g[l+124>>2]=0.0;c[l+120>>2]=-1;c[l+128>>2]=0;g[l+136>>2]=0.0;c[l+132>>2]=-1;c[l+140>>2]=0;t=o<<24>>24==0;if(!t){o=e+80|0;y=f<<4;z=(h|0)>0;v=+(s|0);A=b+292|0;B=b+248|0;C=r;D=0;E=f<<7;F=0;G=c[o>>2]|0;H=q;while(1){q=d[G+F|0]|0;I=F+1|0;a:do{if((a[F+y+(e+5156)|0]|0)==0){if(z){J=r;K=0;L=0}else{M=r;N=0;O=0;while(1){P=+g[l+(F*144|0)+(O*12|0)+4>>2]+0.0;S=v+(C+0.0)+4.0;T=c[l+(F*144|0)+(O*12|0)+8>>2]|0;U=c[545552+(((H|0)==8)<<2)>>2]|0;V=T+1|0;if((a[U+T|0]|0)==(a[U+V|0]|0)){W=P}else{W=v+P}U=l+(I*144|0)+(O*12|0)|0;if(S<W){c[U>>2]=D;g[l+(I*144|0)+(O*12|0)+4>>2]=S;c[l+(I*144|0)+(O*12|0)+8>>2]=1;X=S}else{c[U>>2]=O;g[l+(I*144|0)+(O*12|0)+4>>2]=W;c[l+(I*144|0)+(O*12|0)+8>>2]=V;X=W}V=X<M;S=V?X:M;U=V?O:N;V=O+1|0;if((V|0)<12){M=S;N=U;O=V}else{Y=U;Z=S;_=H;$=G;break a}}}do{O=c[552112+(L<<2)>>2]|0;M=0.0;N=0;do{U=(N+f<<4)+F|0;V=(N<<7)+E|0;M=M+ +ye[O&15](b,0,e+5312+(V<<2)|0,b+736+(V<<2)|0,q,c[e+4644+(U<<2)>>2]|0,L,j/+g[(c[B>>2]|0)+((c[A>>2]|0)*2564|0)+(U*20|0)+8>>2],r,0);N=N+1|0;}while((N|0)<(h|0));aa=c[p>>2]|0;S=M+ +g[l+(F*144|0)+(L*12|0)+4>>2];P=v+(C+M)+4.0;N=c[l+(F*144|0)+(L*12|0)+8>>2]|0;O=c[545552+(((aa|0)==8)<<2)>>2]|0;U=N+1|0;if((a[O+N|0]|0)==(a[O+U|0]|0)){ba=S}else{ba=v+S}O=l+(I*144|0)+(L*12|0)|0;if(P<ba){c[O>>2]=D;g[l+(I*144|0)+(L*12|0)+4>>2]=P;c[l+(I*144|0)+(L*12|0)+8>>2]=1;ca=P}else{c[O>>2]=L;g[l+(I*144|0)+(L*12|0)+4>>2]=ba;c[l+(I*144|0)+(L*12|0)+8>>2]=U;ca=ba}U=ca<J;J=U?ca:J;K=U?L:K;L=L+1|0;}while((L|0)<12);Y=K;Z=J;_=aa;$=c[o>>2]|0}else{U=0;while(1){c[l+(I*144|0)+(U*12|0)>>2]=U;g[l+(I*144|0)+(U*12|0)+4>>2]=+g[l+(F*144|0)+(U*12|0)+4>>2];c[l+(I*144|0)+(U*12|0)+8>>2]=(c[l+(F*144|0)+(U*12|0)+8>>2]|0)+1;O=U+1|0;if((O|0)<12){U=O}else{Y=D;Z=C;_=H;$=G;break}}}}while(0);I=F+1|0;if((I|0)<(u|0)){C=Z;D=Y;E=(d[$+F|0]|0)+E|0;F=I;G=$;H=_}else{break}}}_=+g[l+(u*144|0)+16>>2]<+g[l+(u*144|0)+4>>2]|0;H=+g[l+(u*144|0)+28>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?2:_;_=+g[l+(u*144|0)+40>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?3:H;H=+g[l+(u*144|0)+52>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?4:_;_=+g[l+(u*144|0)+64>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?5:H;H=+g[l+(u*144|0)+76>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?6:_;_=+g[l+(u*144|0)+88>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?7:H;H=+g[l+(u*144|0)+100>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?8:_;_=+g[l+(u*144|0)+112>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?9:H;H=+g[l+(u*144|0)+124>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?10:_;if(t){i=k;return}t=+g[l+(u*144|0)+136>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?11:H;H=u;u=0;while(1){_=c[l+(H*144|0)+(t*12|0)+8>>2]|0;c[m+(u<<2)>>2]=_;c[n+(u<<2)>>2]=t;$=H-_|0;da=u+1|0;if(($|0)>0){t=c[l+(($+1|0)*144|0)+(t*12|0)>>2]|0;H=$;u=da}else{break}}if((da|0)<=0){i=k;return}u=b+12|0;H=b+16|0;t=f<<4;f=b+24|0;b=32-s|0;l=0;$=da;da=c[u>>2]|0;_=c[H>>2]|0;while(1){G=$-1|0;F=c[n+(G<<2)>>2]|0;if((_|0)>4){ea=_-4|0;fa=da<<4|F}else{E=fe(F>>>((4-_|0)>>>0)|da<<_|0)|0;Y=c[f>>2]|0;x=E;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;ea=_+28|0;fa=F}c[u>>2]=fa;c[H>>2]=ea;Y=c[m+(G<<2)>>2]|0;TGb(l+t+(e+5156)|0,(F|0)==0|0,Y|0)|0;if((Y|0)>0){E=0;D=l;while(1){c[e+3172+(D+t<<2)>>2]=F;o=E+1|0;if((o|0)<(Y|0)){E=o;D=D+1|0}else{break}}ga=l+Y|0}else{ga=l}D=c[u>>2]|0;E=c[H>>2]|0;F=(E|0)>(s|0);if((Y|0)<(w|0)){ha=Y;ia=D;ja=E;ka=F}else{o=Y;aa=D;D=E;E=F;while(1){if(E){la=D-s|0;ma=aa<<s|w}else{F=fe(w>>>((s-D|0)>>>0)|aa<<D|0)|0;K=c[f>>2]|0;x=F;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;la=b+D|0;ma=w}c[u>>2]=ma;c[H>>2]=la;K=o-w|0;F=(la|0)>(s|0);if((K|0)<(w|0)){ha=K;ia=ma;ja=la;ka=F;break}else{o=K;aa=ma;D=la;E=F}}}if(ka){na=ja-s|0;oa=ia<<s|ha}else{E=fe(ha>>>((s-ja|0)>>>0)|ia<<ja|0)|0;D=c[f>>2]|0;x=E;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;na=b+ja|0;oa=ha}c[u>>2]=oa;c[H>>2]=na;if((G|0)>0){l=ga;$=G;da=oa;_=na}else{break}}i=k;return}function ipb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;+ye[c[552112+(g<<2)>>2]&15](a,b,d,0,e,f,g,h,r,0);return}function jpb(b,e,f){b=b|0;e=e|0;f=+f;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,S=0,T=0,U=0.0,V=0,W=0.0,X=0.0,Y=0.0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0.0,pa=0,qa=0,ra=0,sa=0,ta=0;h=i;i=i+1024|0;j=h|0;k=h+512|0;l=b+736|0;m=b+1248|0;n=b+1760|0;o=b+2272|0;if((c[e>>2]|0)==0){i=h;return}p=e+248|0;q=c[p>>2]|0;if((q|0)<=0){i=h;return}s=e+244|0;t=b+292|0;u=b+248|0;v=e+240|0;w=j|0;x=k|0;y=e+52432|0;z=0;A=0;B=c[s>>2]|0;C=q;while(1){if((B|0)>0){q=z<<4;D=e+180+z|0;E=0;F=A;G=B;while(1){H=E+q|0;do{if((a[e+5316+H|0]|0)==0){if((a[e+57508+H|0]|0)!=0){I=G;break}if((a[D]|0)==0){J=0.0;K=0.0}else{L=0.0;M=0.0;N=0;while(1){O=(N+z<<4)+E|0;P=c[t>>2]|0;S=c[u>>2]|0;T=S+(P*2564|0)+(O*20|0)+8|0;U=+g[T>>2];V=S+((P+1|0)*2564|0)+(O*20|0)+8|0;W=+g[V>>2];P=U>W;X=P?W:U;Y=P?U:W;P=(c[v>>2]|0)+E|0;S=(N<<7)+F|0;do{if((a[P]|0)==0){Z=e+5472+(S<<2)|0;_=15}else{$=0;do{aa=$+S|0;W=+g[e+57664+(aa<<2)>>2];U=(+g[e+5472+(aa<<2)>>2]+W)*.5;g[j+($<<2)>>2]=U;g[k+($<<2)>>2]=U-W;$=$+1|0;ba=a[P]|0;ca=ba&255;}while(($|0)<(ca|0));$=e+5472+(S<<2)|0;if(ba<<24>>24==0){Z=$;_=15;break}else{da=0}do{W=+Q(+(+g[e+5472+(da+S<<2)>>2]));g[b+736+(da<<2)>>2]=+R(W*+R(W));da=da+1|0;}while((da|0)<(ca|0));aa=a[P]|0;ea=e+57664+(S<<2)|0;fa=aa&255;if(aa<<24>>24==0){ga=0;ha=$;ia=ea;break}else{ja=0}do{W=+Q(+(+g[e+57664+(ja+S<<2)>>2]));g[b+736+(ja+128<<2)>>2]=+R(W*+R(W));ja=ja+1|0;}while((ja|0)<(fa|0));fa=a[P]|0;aa=fa&255;if(fa<<24>>24==0){ga=0;ha=$;ia=ea;break}else{ka=0}do{W=+Q(+(+g[j+(ka<<2)>>2]));g[b+736+(ka+256<<2)>>2]=+R(W*+R(W));ka=ka+1|0;}while((ka|0)<(aa|0));aa=a[P]|0;fa=aa&255;if(aa<<24>>24==0){ga=0;ha=$;ia=ea;break}else{la=0}do{W=+Q(+(+g[k+(la<<2)>>2]));g[b+736+(la+384<<2)>>2]=+R(W*+R(W));la=la+1|0;}while((la|0)<(fa|0));ga=d[P]|0;ha=$;ia=ea}}while(0);if((_|0)==15){_=0;ga=0;ha=Z;ia=e+57664+(S<<2)|0}P=e+4804+(O<<2)|0;fa=e+3332+(O<<2)|0;aa=c[fa>>2]|0;W=L+ +ye[c[552112+(aa<<2)>>2]&15](b,0,ha,l,ga,c[P>>2]|0,aa,f/+g[T>>2],r,0);aa=e+56996+(O<<2)|0;ma=e+55524+(O<<2)|0;na=c[ma>>2]|0;U=W+ +ye[c[552112+(na<<2)>>2]&15](b,0,ia,m,d[(c[y>>2]|0)+E|0]|0,c[aa>>2]|0,na,f/+g[V>>2],r,0);na=c[fa>>2]|0;W=M+ +ye[c[552112+(na<<2)>>2]&15](b,0,w,n,d[(c[v>>2]|0)+E|0]|0,c[P>>2]|0,na,f/Y,r,0);na=c[ma>>2]|0;oa=W+ +ye[c[552112+(na<<2)>>2]&15](b,0,x,o,d[(c[y>>2]|0)+E|0]|0,c[aa>>2]|0,na,f/X,r,0);na=N+1|0;if((na|0)<(d[D]|0)){L=U;M=oa;N=na}else{J=U;K=oa;break}}}a[e+8+H|0]=K<J|0;I=c[s>>2]|0}else{I=G}}while(0);pa=(d[(c[v>>2]|0)+E|0]|0)+F|0;H=E+1|0;if((H|0)<(I|0)){E=H;F=pa;G=I}else{break}}qa=pa;ra=I;sa=c[p>>2]|0;ta=D}else{qa=A;ra=B;sa=C;ta=e+180+z|0}G=(d[ta]|0)+z|0;if((G|0)<(sa|0)){z=G;A=qa;B=ra;C=sa}else{break}}i=h;return}function kpb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=+h;var j=0,k=0,l=0.0,m=0,n=0.0,o=0.0,p=0,q=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0.0,Y=0.0,Z=0,_=0,$=0,aa=0.0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0,ka=0,la=0.0,ma=0,na=0.0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;b=i;i=i+59536|0;j=b|0;k=b+59048|0;l=0.0;m=0;n=0.0;o=3.4028234663852886e+38;p=0;while(1){q=+g[f+5312+(p<<2)>>2];s=+Q(+q);if(q==0.0){t=o;u=n;v=m;w=l}else{t=o>s?s:o;u=n>s?n:s;v=m+1|0;w=l+s*s}x=p+1|0;if((x|0)<1024){l=w;m=v;n=u;o=t;p=x}else{break}}if((v|0)==0){TGb(f+4644|0,0,512)|0;TGb(f+5156|0,1,128)|0;i=b;return}p=~~(+gc(+t)*4.0+-69.0+140.0+-36.0);if(p>>>0>255>>>0){y=-p>>31&255}else{y=p&255}p=y&255;y=~~(+gc(+u)*4.0+6.0+140.0+-36.0);if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}y=z&255;do{if((y-p|0)>60){z=~~(+gc(+(+R(w/+(v|0))))*4.0+-31.0+140.0+-36.0);if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}z=A&255;m=z+30|0;x=z-30|0;if((x|0)<(p|0)){B=p+60|0;C=p;break}else{z=m>>>0>y>>>0;B=z?y:m;C=z?y-60|0:x;break}}else{B=y;C=p}}while(0);p=0;while(1){g[j+(p<<3)>>2]=0.0;c[j+(p<<3)+4>>2]=-1;y=p+1|0;if((y|0)<61){p=y}else{D=1;break}}while(1){p=0;do{g[j+(D*488|0)+(p<<3)>>2]=r;c[j+(D*488|0)+(p<<3)+4>>2]=-2;p=p+1|0;}while((p|0)<61);p=D+1|0;if((p|0)<121){D=p}else{E=0;break}}do{w=+Q(+(+g[f+5312+(E<<2)>>2]));g[e+736+(E<<2)>>2]=+R(w*+R(w));E=E+1|0;}while((E|0)<1024);E=f+88|0;D=c[E>>2]|0;if((D|0)>0){p=f+84|0;y=f+80|0;A=B-C|0;B=(A|0)>0;v=e+292|0;x=e+248|0;z=1;m=0;F=c[p>>2]|0;G=D;while(1){if((F|0)>0){H=m<<4;I=f+20+m|0;J=z;K=m<<7;L=0;while(1){M=L+H|0;c[k+(J<<2)>>2]=M;do{if((a[I]|0)==0){N=38}else{w=2147483648.0;u=0.0;O=0;P=0;while(1){S=(P+m<<4)+L|0;T=c[v>>2]|0;U=c[x>>2]|0;t=+g[U+(T*2564|0)+(S*20|0)+8>>2];V=f+5156+S|0;do{if(+g[U+(T*2564|0)+(S*20|0)+4>>2]<=t|t==0.0){a[V]=1;W=O;X=u;Y=w}else{a[V]=0;Z=a[(c[y>>2]|0)+L|0]|0;if(Z<<24>>24==0){W=1;X=u;Y=w;break}_=(P<<7)+K|0;$=Z&255;o=w;n=u;Z=0;while(1){l=+g[f+5312+(_+Z<<2)>>2];s=+Q(+l);if(l==0.0){aa=o}else{aa=o>s?s:o}l=n>s?n:s;ba=Z+1|0;if((ba|0)<($|0)){o=aa;n=l;Z=ba}else{W=1;X=l;Y=aa;break}}}}while(0);V=P+1|0;ca=a[I]|0;if((V|0)<(ca&255|0)){w=Y;u=X;O=W;P=V}else{break}}P=(W|0)!=0;if(!P){N=38;break}O=~~(+gc(+Y)*4.0+-69.0+140.0+-36.0);if(O>>>0>255>>>0){da=-O>>31&255}else{da=O&255}O=~~(+gc(+X)*4.0+6.0+140.0+-36.0);if(O>>>0>255>>>0){ea=-O>>31&255}else{ea=O&255}O=(da&255)-C|0;if((O|0)<0){fa=0}else{fa=(O|0)>60?60:O}O=(ea&255)-C|0;if((O|0)<0){ga=0}else{ga=(O|0)>61?61:O}O=ca&255;V=a[(c[y>>2]|0)+L|0]|0;S=V&255;if(ca<<24>>24==0){ha=0.0}else{T=V<<24>>24==0;u=0.0;V=0;while(1){if(T){ia=u}else{U=(V<<7)+K|0;w=u;Z=0;while(1){t=+g[e+736+(U+Z<<2)>>2];n=w>t?w:t;$=Z+1|0;if(($|0)<(S|0)){w=n;Z=$}else{ia=n;break}}}Z=V+1|0;if((Z|0)<(O|0)){u=ia;V=Z}else{ha=ia;break}}}if((fa|0)>=(ga|0)){ja=P;break}V=f+4644+(M<<2)|0;O=J-1|0;S=fa;T=ca;while(1){u=+g[7994608+(304-(c[V>>2]|0)<<2)>>2];Z=~~(ha*+R(u*+R(u))+.40540000796318054);do{if((Z|0)==1){ka=1}else if((Z|0)==2){ka=3}else if((Z|0)==0){ka=0}else{if((Z|0)<5){ka=5;break}if((Z|0)<8){ka=7;break}ka=(Z|0)<13?9:11}}while(0);if(T<<24>>24==0){la=0.0;ma=0}else{Z=S+C|0;U=c[552112+(ka<<2)>>2]|0;u=0.0;$=0;while(1){_=($<<7)+K|0;w=u+ +ye[U&15](e,0,f+5312+(_<<2)|0,e+736+(_<<2)|0,d[(c[y>>2]|0)+L|0]|0,Z,ka,h/+g[(c[x>>2]|0)+((c[v>>2]|0)*2564|0)+((($+m<<4)+L|0)*20|0)+8>>2],r,0);_=$+1|0;ba=a[I]|0;if((_|0)<(ba&255|0)){u=w;$=_}else{la=w;ma=ba;break}}}if(B){$=S+60|0;Z=j+(J*488|0)+(S<<3)|0;U=j+(J*488|0)+(S<<3)+4|0;ba=0;u=+g[Z>>2];while(1){w=la+ +g[j+(O*488|0)+(ba<<3)>>2]+ +(d[1277624+($-ba)|0]|0);if(w<u){g[Z>>2]=w;c[U>>2]=ba;na=w}else{na=u}_=ba+1|0;if((_|0)<(A|0)){ba=_;u=na}else{break}}}ba=S+1|0;if((ba|0)<(ga|0)){S=ba;T=ma}else{ja=P;break}}}}while(0);do{if((N|0)==38){N=0;if(!B){ja=0;break}P=J-1|0;T=0;while(1){g[j+(J*488|0)+(T<<3)>>2]=+g[j+(P*488|0)+(T<<3)>>2]+1.0;c[j+(J*488|0)+(T<<3)+4>>2]=T;S=T+1|0;if((S|0)<(A|0)){T=S}else{ja=0;break}}}}while(0);a[f+5156+M|0]=ja&1^1;oa=J+1|0;T=L+1|0;pa=c[p>>2]|0;if((T|0)<(pa|0)){J=oa;K=(d[(c[y>>2]|0)+L|0]|0)+K|0;L=T}else{break}}qa=oa;ra=pa;sa=c[E>>2]|0;ta=I}else{qa=z;ra=F;sa=G;ta=f+20+m|0}L=(d[ta]|0)+m|0;if((L|0)<(sa|0)){z=qa;m=L;F=ra;G=sa}else{ua=qa;va=sa;break}}}else{ua=1;va=D}D=ua-1|0;na=+g[j+(D*488|0)>>2];ua=0;sa=1;while(1){la=+g[j+(D*488|0)+(sa<<3)>>2];qa=la<na;wa=qa?sa:ua;G=sa+1|0;if((G|0)<61){na=qa?la:na;ua=wa;sa=G}else{break}}if((D|0)==0){xa=va}else{va=wa;wa=D;while(1){c[f+4644+(c[k+(wa<<2)>>2]<<2)>>2]=va+C;D=wa-1|0;if((D|0)==0){break}else{va=c[j+(wa*488|0)+(va<<3)+4>>2]|0;wa=D}}xa=c[E>>2]|0}if((xa|0)<=0){i=b;return}wa=f+84|0;va=0;j=c[wa>>2]|0;C=xa;while(1){xa=f+20+va|0;if((j|0)>0){k=va<<4;D=0;sa=a[xa]|0;ua=j;while(1){if((sa&255)>>>0>1>>>0){G=f+4644+(D+k<<2)|0;qa=1;do{c[f+4644+((qa+va<<4)+D<<2)>>2]=c[G>>2];qa=qa+1|0;ya=a[xa]|0;}while((qa|0)<(ya&255|0));za=ya;Aa=c[wa>>2]|0}else{za=sa;Aa=ua}qa=D+1|0;if((qa|0)<(Aa|0)){D=qa;sa=za;ua=Aa}else{break}}Ba=Aa;Ca=c[E>>2]|0;Da=za}else{Ba=j;Ca=C;Da=a[xa]|0}ua=(Da&255)+va|0;if((ua|0)<(Ca|0)){va=ua;j=Ba;C=Ca}else{break}}i=b;return}function lpb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=+h;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0.0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0,O=0,P=0.0,S=0,T=0,U=0,V=0.0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0.0,da=0.0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;j=i;i=i+1544|0;k=j|0;l=j+512|0;m=j+1024|0;n=j+1536|0;o=~~(+(c[b+72>>2]|0)*1024.0/+(c[b+412>>2]|0)/+(c[b+416>>2]|0)*(h/120.0));TGb(k|0,0,512)|0;b=(o|0)>5800?5800:o;o=f+88|0;p=c[o>>2]|0;if((p|0)<=0){i=j;return}q=f+84|0;s=e+292|0;t=e+248|0;u=0;h=r;v=0;w=c[q>>2]|0;x=p;while(1){p=f+20+v|0;if((w|0)>0){y=v<<4;z=u;A=h;B=0;while(1){C=a[p]|0;if(C<<24>>24==0){D=0;E=0.0}else{F=0;G=0.0;H=0;I=C;while(1){C=(H+v<<4)+B|0;J=c[s>>2]|0;K=c[t>>2]|0;L=+g[K+(J*2564|0)+(C*20|0)+8>>2];M=G+L;if(+g[K+(J*2564|0)+(C*20|0)+4>>2]<=L|L==0.0){a[f+5156+C|0]=1;N=F;O=a[p]|0}else{N=1;O=I}C=H+1|0;if((C|0)<(O&255|0)){F=N;G=M;H=C;I=O}else{D=N;E=M;break}}}I=B+y|0;g[l+(I<<2)>>2]=E*512.0;H=(D|0)!=0;a[f+5156+I|0]=H&1^1;if(H){P=A>E?E:A}else{P=A}S=D|z;H=B+1|0;T=c[q>>2]|0;if((H|0)<(T|0)){z=S;A=P;B=H}else{break}}U=S;V=P;W=T;X=c[o>>2]|0}else{U=u;V=h;W=w;X=x}B=(d[p]|0)+v|0;if((B|0)<(X|0)){u=U;h=V;v=B;w=W;x=X}else{break}}if((X|0)>0){x=f+84|0;W=0;w=c[x>>2]|0;v=X;while(1){if((w|0)>0){u=W<<4;T=0;do{S=T+u|0;if((a[f+5156+S|0]|0)==0){h=+gc(+(+g[l+(S<<2)>>2]/V))*4.0;if(h>59.0){Y=199}else{Y=~~(h+140.0)}c[f+4644+(S<<2)>>2]=Y}else{c[f+4644+(S<<2)>>2]=140}T=T+1|0;Z=c[x>>2]|0;}while((T|0)<(Z|0));_=Z;$=c[o>>2]|0}else{_=w;$=v}T=(d[f+20+W|0]|0)+W|0;if((T|0)<($|0)){W=T;w=_;v=$}else{aa=$;break}}}else{aa=X}if((U|0)==0){i=j;return}else{ba=0}do{V=+Q(+(+g[f+5312+(ba<<2)>>2]));g[e+736+(ba<<2)>>2]=+R(V*+R(V));ba=ba+1|0;}while((ba|0)<1024);ba=f+84|0;if((aa|0)>0){U=c[ba>>2]|0;X=(U|0)>0;$=f+80|0;v=0;while(1){_=a[f+20+v|0]|0;w=_&255;if(X){W=c[$>>2]|0;Z=v<<4;x=0;Y=v<<7;while(1){T=a[W+x|0]|0;u=T&255;if(_<<24>>24==0){ca=0.0}else{p=T<<24>>24==0;V=0.0;T=0;while(1){if(p){da=V}else{S=(T<<7)+Y|0;h=V;q=0;while(1){P=+g[e+736+(S+q<<2)>>2];E=h>P?h:P;D=q+1|0;if((D|0)<(u|0)){h=E;q=D}else{da=E;break}}}q=T+1|0;if((q|0)<(w|0)){V=da;T=q}else{ca=da;break}}}g[m+(x+Z<<2)>>2]=ca;T=x+1|0;if((T|0)<(U|0)){x=T;Y=u+Y|0}else{break}}}Y=w+v|0;if((Y|0)<(aa|0)){v=Y}else{ea=$;break}}}else{ea=f+80|0}$=f+4644|0;ca=+(b|0)*1.02;v=0;U=aa;while(1){aa=(v|0)!=0?1:32;X=c[$>>2]|0;Y=U;while(1){if((Y|0)>0){x=X;Z=0;_=-1;W=0;T=c[ba>>2]|0;p=Y;while(1){if((T|0)>0){q=W<<4;S=f+20+W|0;D=x;N=0;O=Z;t=_;s=W<<7;B=T;while(1){z=N+q|0;do{if((a[f+5156+z|0]|0)==0){y=f+4644+(z<<2)|0;H=c[y>>2]|0;if((H|0)>217){fa=t;ga=O;ha=D;ia=B;break}I=(D|0)>(H|0)?H:D;da=+g[7994608+(304-H<<2)>>2];F=~~(+g[m+(z<<2)>>2]*+R(da*+R(da))+.40540000796318054);do{if((F|0)==1){ja=1}else if((F|0)==2){ja=3}else if((F|0)==0){ja=0}else{if((F|0)<5){ja=5;break}if((F|0)<8){ja=7;break}ja=(F|0)<13?9:11}}while(0);a:do{if((a[S]|0)==0){ka=0;la=0.0}else{F=c[552112+(ja<<2)>>2]|0;C=0;J=0;da=0.0;K=H;while(1){ma=(C<<7)+s|0;V=da+ +ye[F&15](e,0,f+5312+(ma<<2)|0,e+736+(ma<<2)|0,d[(c[ea>>2]|0)+N|0]|0,K,ja,1.0,r,n);ma=(c[n>>2]|0)+J|0;na=C+1|0;if((na|0)>=(d[S]|0)){ka=ma;la=V;break a}C=na;J=ma;da=V;K=c[y>>2]|0}}}while(0);g[k+(z<<2)>>2]=la- +(ka|0);H=c[y>>2]|0;if((t|0)==-1){oa=ka}else{oa=(d[1277624+(60-t+H)|0]|0)+ka|0}fa=H;ga=oa+O|0;ha=I;ia=c[ba>>2]|0}else{fa=t;ga=O;ha=D;ia=B}}while(0);z=(d[(c[ea>>2]|0)+N|0]|0)+s|0;H=N+1|0;if((H|0)<(ia|0)){D=ha;N=H;O=ga;t=fa;s=z;B=ia}else{break}}pa=ha;qa=ga;ra=fa;sa=ia;ta=c[o>>2]|0;ua=S}else{pa=x;qa=Z;ra=_;sa=T;ta=p;ua=f+20+W|0}B=(d[ua]|0)+W|0;if((B|0)<(ta|0)){x=pa;Z=qa;_=ra;W=B;T=sa;p=ta}else{va=pa;wa=qa;break}}}else{va=X;wa=0}if((wa|0)>(b|0)){p=218-aa|0;T=0;do{W=f+4644+(T<<2)|0;_=c[W>>2]|0;if((_|0)<(p|0)){c[W>>2]=_+aa}T=T+1|0;}while((T|0)<128)}else{T=60-aa|0;p=0;do{_=f+4644+(p<<2)|0;W=c[_>>2]|0;if((W|0)>(T|0)){c[_>>2]=W-aa}p=p+1|0;}while((p|0)<128)}p=aa>>1;if((p|0)==0){if(!(+(wa|0)>ca)){break}T=(c[$>>2]|0)<217;if(!T){break}xa=T&1}else{xa=p}aa=xa;X=va;Y=c[o>>2]|0}if((va|0)<60){ya=60}else{ya=(va|0)>195?195:va}Y=c[o>>2]|0;if((Y|0)<=0){za=102;break}X=ya+60|0;aa=0;w=0;p=Y;Y=c[ba>>2]|0;while(1){if((Y|0)>0){T=w<<4;W=aa;_=0;do{Z=_+T|0;x=f+4644+(Z<<2)|0;u=c[x>>2]|0;do{if(+g[k+(Z<<2)>>2]>+g[l+(Z<<2)>>2]&(u|0)>60){da=+g[7994608+(305-u<<2)>>2];if((~~(+g[m+(Z<<2)>>2]*+R(da*+R(da))+.40540000796318054)|0)==0){B=u-2|0;c[x>>2]=B;Aa=B;break}else{B=u-1|0;c[x>>2]=B;Aa=B;break}}else{Aa=u}}while(0);if((Aa|0)<(ya|0)){Ba=ya}else{Ba=(Aa|0)>(X|0)?X:Aa}S=(Ba|0)>219?219:Ba;c[x>>2]=S;W=(S|0)==(u|0)?W:1;da=+g[7994608+(304-S<<2)>>2];S=~~(+g[m+(Z<<2)>>2]*+R(da*+R(da))+.40540000796318054);do{if((S|0)==1){Ca=1}else if((S|0)==2){Ca=3}else if((S|0)==0){Ca=0}else{if((S|0)<5){Ca=5;break}if((S|0)<8){Ca=7;break}Ca=(S|0)<13?9:11}}while(0);c[f+3172+(Z<<2)>>2]=Ca;_=_+1|0;Da=c[ba>>2]|0;}while((_|0)<(Da|0));Ea=W;Fa=c[o>>2]|0;Ga=Da}else{Ea=aa;Fa=p;Ga=Y}_=(d[f+20+w|0]|0)+w|0;if((_|0)<(Fa|0)){aa=Ea;w=_;p=Fa;Y=Ga}else{break}}Y=v+1|0;if((Ea|0)!=0&(Y|0)<10){v=Y;U=Fa}else{za=102;break}}if((za|0)==102){i=j;return}}function mpb(b,e,f,h,j){b=b|0;e=e|0;f=f|0;h=h|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0.0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0.0,P=0,S=0,T=0,U=0,V=0.0,W=0,X=0.0,Y=0,Z=0.0,_=0.0,$=0.0,aa=0.0,ba=0.0,ca=0,da=0.0,ea=0.0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;k=i;i=i+18240|0;l=k|0;m=k+17280|0;n=k+17760|0;o=a[e|0]|0;p=e+88|0;q=c[p>>2]|0;s=(q|0)==1?5:3;t=1<<s;u=0;do{j=+Q(+(+g[e+5312+(u<<2)>>2]));g[b+736+(u<<2)>>2]=+R(j*+R(j));u=u+1|0;}while((u|0)<1024);u=o&255;v=t-1|0;j=+(s+4|0);g[l+4>>2]=j;c[l>>2]=-1;c[l+8>>2]=0;g[l+16>>2]=j;c[l+12>>2]=-1;c[l+20>>2]=0;g[l+28>>2]=j;c[l+24>>2]=-1;c[l+32>>2]=0;g[l+40>>2]=j;c[l+36>>2]=-1;c[l+44>>2]=0;g[l+52>>2]=j;c[l+48>>2]=-1;c[l+56>>2]=0;g[l+64>>2]=j;c[l+60>>2]=-1;c[l+68>>2]=0;g[l+76>>2]=j;c[l+72>>2]=-1;c[l+80>>2]=0;g[l+88>>2]=j;c[l+84>>2]=-1;c[l+92>>2]=0;g[l+100>>2]=j;c[l+96>>2]=-1;c[l+104>>2]=0;g[l+112>>2]=j;c[l+108>>2]=-1;c[l+116>>2]=0;g[l+124>>2]=j;c[l+120>>2]=-1;c[l+128>>2]=0;g[l+136>>2]=j;c[l+132>>2]=-1;c[l+140>>2]=0;t=o<<24>>24==0;if(!t){o=e+80|0;w=f<<4;y=(h|0)>0;j=+(s|0);z=r;A=0;B=f<<7;C=0;D=c[o>>2]|0;E=q;while(1){q=d[D+C|0]|0;F=C+w|0;a:do{if((a[e+5156+F|0]|0)==0){G=c[e+3172+(F<<2)>>2]|0;do{if((G|0)>0){H=C+1|0;I=0;do{g[l+(H*144|0)+(I*12|0)+4>>2]=61450.0;c[l+(H*144|0)+(I*12|0)>>2]=-1;c[l+(H*144|0)+(I*12|0)+8>>2]=0;I=I+1|0;}while((I|0)<(G|0));if((G|0)<12){break}J=0;K=r;L=E;M=D;N=C+1|0;break a}}while(0);I=C+1|0;O=r;H=0;P=G;S=E;while(1){if(y){T=c[552112+(P<<2)>>2]|0;U=0;V=0.0;do{W=(U<<7)+B|0;V=V+ +ye[T&15](b,0,e+5312+(W<<2)|0,b+736+(W<<2)|0,q,c[e+4644+((U+f<<4)+C<<2)>>2]|0,P,0.0,r,0);U=U+1|0;}while((U|0)<(h|0));X=V;Y=c[p>>2]|0}else{X=0.0;Y=S}Z=X+ +g[l+(C*144|0)+(P*12|0)+4>>2];_=j+(z+X)+4.0;U=c[l+(C*144|0)+(P*12|0)+8>>2]|0;T=c[545552+(((Y|0)==8)<<2)>>2]|0;W=U+1|0;if((a[T+U|0]|0)==(a[T+W|0]|0)){$=Z}else{$=j+Z}T=l+(I*144|0)+(P*12|0)|0;if(_<$){c[T>>2]=A;g[l+(I*144|0)+(P*12|0)+4>>2]=_;c[l+(I*144|0)+(P*12|0)+8>>2]=1;aa=_}else{c[T>>2]=P;g[l+(I*144|0)+(P*12|0)+4>>2]=$;c[l+(I*144|0)+(P*12|0)+8>>2]=W;aa=$}W=aa<O;ba=W?aa:O;ca=W?P:H;W=P+1|0;if((W|0)<12){O=ba;H=ca;P=W;S=Y}else{break}}J=ca;K=ba;L=Y;M=c[o>>2]|0;N=I}else{O=+g[l+(C*144|0)+4>>2];_=j+z+4.0;S=c[l+(C*144|0)+8>>2]|0;P=c[545552+(((E|0)==8)<<2)>>2]|0;H=S+1|0;if((a[P+S|0]|0)==(a[P+H|0]|0)){da=O}else{da=j+O}P=C+1|0;S=l+(P*144|0)|0;if(_<da){c[S>>2]=A;g[l+(P*144|0)+4>>2]=_;c[l+(P*144|0)+8>>2]=1;ea=_}else{c[S>>2]=0;g[l+(P*144|0)+4>>2]=da;c[l+(P*144|0)+8>>2]=H;ea=da}g[l+(P*144|0)+16>>2]=61450.0;c[l+(P*144|0)+12>>2]=-1;c[l+(P*144|0)+20>>2]=0;g[l+(P*144|0)+28>>2]=61450.0;c[l+(P*144|0)+24>>2]=-1;c[l+(P*144|0)+32>>2]=0;g[l+(P*144|0)+40>>2]=61450.0;c[l+(P*144|0)+36>>2]=-1;c[l+(P*144|0)+44>>2]=0;g[l+(P*144|0)+52>>2]=61450.0;c[l+(P*144|0)+48>>2]=-1;c[l+(P*144|0)+56>>2]=0;g[l+(P*144|0)+64>>2]=61450.0;c[l+(P*144|0)+60>>2]=-1;c[l+(P*144|0)+68>>2]=0;g[l+(P*144|0)+76>>2]=61450.0;c[l+(P*144|0)+72>>2]=-1;c[l+(P*144|0)+80>>2]=0;g[l+(P*144|0)+88>>2]=61450.0;c[l+(P*144|0)+84>>2]=-1;c[l+(P*144|0)+92>>2]=0;g[l+(P*144|0)+100>>2]=61450.0;c[l+(P*144|0)+96>>2]=-1;c[l+(P*144|0)+104>>2]=0;g[l+(P*144|0)+112>>2]=61450.0;c[l+(P*144|0)+108>>2]=-1;c[l+(P*144|0)+116>>2]=0;g[l+(P*144|0)+124>>2]=61450.0;c[l+(P*144|0)+120>>2]=-1;c[l+(P*144|0)+128>>2]=0;g[l+(P*144|0)+136>>2]=61450.0;c[l+(P*144|0)+132>>2]=-1;c[l+(P*144|0)+140>>2]=0;J=0;K=ea;L=E;M=D;N=P}}while(0);if((N|0)<(u|0)){z=K;A=J;B=(d[M+C|0]|0)+B|0;C=N;D=M;E=L}else{break}}}L=+g[l+(u*144|0)+16>>2]<+g[l+(u*144|0)+4>>2]|0;E=+g[l+(u*144|0)+28>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?2:L;L=+g[l+(u*144|0)+40>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?3:E;E=+g[l+(u*144|0)+52>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?4:L;L=+g[l+(u*144|0)+64>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?5:E;E=+g[l+(u*144|0)+76>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?6:L;L=+g[l+(u*144|0)+88>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?7:E;E=+g[l+(u*144|0)+100>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?8:L;L=+g[l+(u*144|0)+112>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?9:E;E=+g[l+(u*144|0)+124>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?10:L;if(t){i=k;return}t=+g[l+(u*144|0)+136>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?11:E;E=u;u=0;while(1){L=c[l+(E*144|0)+(t*12|0)+8>>2]|0;c[m+(u<<2)>>2]=L;c[n+(u<<2)>>2]=t;M=E-L|0;fa=u+1|0;if((M|0)>0){t=c[l+((M+1|0)*144|0)+(t*12|0)>>2]|0;E=M;u=fa}else{break}}if((fa|0)<=0){i=k;return}u=b+12|0;E=b+16|0;t=f<<4;f=b+24|0;b=32-s|0;l=0;M=fa;fa=c[u>>2]|0;L=c[E>>2]|0;while(1){D=M-1|0;N=c[n+(D<<2)>>2]|0;if((L|0)>4){ga=L-4|0;ha=fa<<4|N}else{C=fe(N>>>((4-L|0)>>>0)|fa<<L|0)|0;B=c[f>>2]|0;x=C;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;ga=L+28|0;ha=N}c[u>>2]=ha;c[E>>2]=ga;B=c[m+(D<<2)>>2]|0;TGb(l+t+(e+5156)|0,(N|0)==0|0,B|0)|0;if((B|0)>0){C=0;J=l;while(1){c[e+3172+(J+t<<2)>>2]=N;A=C+1|0;if((A|0)<(B|0)){C=A;J=J+1|0}else{break}}ia=l+B|0}else{ia=l}J=c[u>>2]|0;C=c[E>>2]|0;N=(C|0)>(s|0);if((B|0)<(v|0)){ja=B;ka=J;la=C;ma=N}else{A=B;o=J;J=C;C=N;while(1){if(C){na=J-s|0;oa=o<<s|v}else{N=fe(v>>>((s-J|0)>>>0)|o<<J|0)|0;Y=c[f>>2]|0;x=N;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;na=b+J|0;oa=v}c[u>>2]=oa;c[E>>2]=na;Y=A-v|0;N=(na|0)>(s|0);if((Y|0)<(v|0)){ja=Y;ka=oa;la=na;ma=N;break}else{A=Y;o=oa;J=na;C=N}}}if(ma){pa=la-s|0;qa=ka<<s|ja}else{C=fe(ja>>>((s-la|0)>>>0)|ka<<la|0)|0;J=c[f>>2]|0;x=C;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;pa=b+la|0;qa=ja}c[u>>2]=qa;c[E>>2]=pa;if((D|0)>0){l=ia;M=D;fa=qa;L=pa}else{break}}i=k;return}function npb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=+f;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;TGb(e+4644|0,0,512)|0;b=e+88|0;h=c[b>>2]|0;if((h|0)>0){i=e+84|0;j=d+292|0;k=d+248|0;d=0;l=c[i>>2]|0;m=h;while(1){h=e+20+d|0;n=a[h]|0;if((l|0)>0){o=0;p=n;q=l;r=n;while(1){if(p<<24>>24==0){s=0;t=q;u=r}else{v=0;do{w=(v+d<<4)+o|0;x=c[j>>2]|0;y=c[k>>2]|0;f=+g[y+(x*2564|0)+(w*20|0)+8>>2];if(+g[y+(x*2564|0)+(w*20|0)+4>>2]>f){x=~~(+gc(+f)+104.0);if((x|0)<80){z=80}else{z=(x|0)>218?218:x}c[e+4644+(w<<2)>>2]=z;a[e+5156+w|0]=0}else{c[e+4644+(w<<2)>>2]=218;a[e+5156+w|0]=1}v=v+1|0;A=a[h]|0;}while((v|0)<(A&255|0));s=A;t=c[i>>2]|0;u=A}v=o+1|0;if((v|0)<(t|0)){o=v;p=s;q=t;r=u}else{break}}B=t;C=u;D=c[b>>2]|0}else{B=l;C=n;D=m}r=(C&255)+d|0;if((r|0)<(D|0)){d=r;l=B;m=D}else{E=0;break}}}else{E=0}do{c[e+4644+(E<<2)>>2]=140;E=E+1|0;}while((E|0)<128);E=c[b>>2]|0;if((E|0)<=0){return}D=e+84|0;m=0;B=c[D>>2]|0;l=E;while(1){E=e+20+m|0;if((B|0)>0){d=m<<4;C=0;u=a[E]|0;t=B;while(1){if((u&255)>>>0>1>>>0){s=e+4644+(C+d<<2)|0;A=1;do{c[e+4644+((A+m<<4)+C<<2)>>2]=c[s>>2];A=A+1|0;F=a[E]|0;}while((A|0)<(F&255|0));G=F;H=c[D>>2]|0}else{G=u;H=t}A=C+1|0;if((A|0)<(H|0)){C=A;u=G;t=H}else{break}}I=H;J=c[b>>2]|0;K=G}else{I=B;J=l;K=a[E]|0}t=(K&255)+m|0;if((t|0)<(J|0)){m=t;B=I;l=J}else{break}}return}function opb(a,b,d,e,f,h,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=+j;k=+k;l=l|0;var m=0.0,n=0.0,o=0.0,p=0.0;if((f|0)>0){k=0.0;i=0;while(1){m=+g[d+(i<<2)>>2];n=k+m*m;h=i+1|0;if((h|0)<(f|0)){k=n;i=h}else{o=n;break}}}else{o=0.0}if((l|0)==0){p=o*j;return+p}c[l>>2]=0;p=o*j;return+p}function ppb(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0.0,S=0.0,T=0.0,U=0,V=0;p=+g[7992896+(304-k<<2)>>2];q=+g[7994608+(k+96<<2)>>2];k=d[1878840+l|0]|0;r=d[1878856+l|0]|0;do{if((i|0)==0){s=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+Q(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+R(w*+R(w));y=t+1|0;if((y|0)<(j|0)){t=y}else{z=s;A=4;break}}}else{z=i;A=4}}while(0);a:do{if((A|0)==4){if((j|0)<=0){u=0;v=0.0;break}w=+(r|0);i=0;do{B=p*+g[z+(i<<2)>>2]+.4054;t=~~(B>w?w:B);s=b+336+(i<<2)|0;c[s>>2]=t;if(+g[h+(i<<2)>>2]<0.0){c[s>>2]=-t}i=i+1|0;}while((i|0)<(j|0));i=l-1|0;t=c[1277088+(i<<2)>>2]|0;s=1286072+(i<<2)|0;y=(f|0)==0;C=1277040+(i<<2)|0;i=f|0;D=f+4|0;E=f+12|0;F=0;w=0.0;G=0;while(1){H=ba(r+(c[b+336+(G<<2)>>2]|0)|0,k)|0;I=G|1;J=ba(H+r+(c[b+336+(I<<2)>>2]|0)|0,k)|0;H=G|2;K=ba(J+r+(c[b+336+(H<<2)>>2]|0)|0,k)|0;J=G|3;L=K+r+(c[b+336+(J<<2)>>2]|0)|0;K=L<<2;M=c[s>>2]|0;B=+g[h+(G<<2)>>2]-q*+g[M+(K<<2)>>2];N=+g[h+(I<<2)>>2]-q*+g[M+((K|1)<<2)>>2];O=+g[h+(H<<2)>>2]-q*+g[M+((K|2)<<2)>>2];P=+g[h+(J<<2)>>2]-q*+g[M+((K|3)<<2)>>2];K=d[t+L|0]|0;S=w+(+(K|0)+(B*B+0.0+N*N+O*O+P*P)*m);M=K+F|0;if(!(S<n)){T=n;break}if(!y){J=e[(c[C>>2]|0)+(L<<1)>>1]|0;L=c[i>>2]|0;H=c[D>>2]|0;if((H|0)>(K|0)){U=H-K|0;V=L<<K|J}else{I=fe(J>>>((K-H|0)>>>0)|L<<H|0)|0;L=c[E>>2]|0;x=I;a[L]=x;x=x>>8;a[L+1|0]=x;x=x>>8;a[L+2|0]=x;x=x>>8;a[L+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;U=32-K+H|0;V=J}c[i>>2]=V;c[D>>2]=U}J=G+4|0;if((J|0)<(j|0)){F=M;w=S;G=J}else{u=M;v=S;break a}}return+T}}while(0);if((o|0)==0){T=v;return+T}c[o>>2]=u;T=v;return+T}function qpb(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,S=0.0,T=0,U=0.0,V=0.0,W=0,X=0.0,Y=0.0,Z=0,_=0.0,$=0.0,aa=0,ca=0,da=0.0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0.0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;p=+g[7992896+(304-k<<2)>>2];q=+g[7994608+(k+96<<2)>>2];k=d[1878840+l|0]|0;r=d[1878856+l|0]|0;do{if((i|0)==0){s=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+Q(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+R(w*+R(w));y=t+1|0;if((y|0)<(j|0)){t=y}else{z=s;A=4;break}}}else{z=i;A=4}}while(0);a:do{if((A|0)==4){if((j|0)<=0){u=0;v=0.0;break}w=+(r|0);i=0;do{B=p*+g[z+(i<<2)>>2]+.4054;c[b+336+(i<<2)>>2]=~~(B>w?w:B);i=i+1|0;}while((i|0)<(j|0));i=l-1|0;t=c[1277088+(i<<2)>>2]|0;s=1286072+(i<<2)|0;y=(f|0)==0;C=1277040+(i<<2)|0;i=f|0;D=f+4|0;E=f+12|0;F=0;w=0.0;G=0;while(1){H=ba(c[b+336+(G<<2)>>2]|0,k)|0;I=G|1;J=ba(H+(c[b+336+(I<<2)>>2]|0)|0,k)|0;H=G|2;K=ba(J+(c[b+336+(H<<2)>>2]|0)|0,k)|0;J=G|3;L=K+(c[b+336+(J<<2)>>2]|0)|0;K=d[t+L|0]|0;M=L<<2;N=c[s>>2]|0;O=h+(G<<2)|0;B=+Q(+(+g[O>>2]));P=+g[N+(M<<2)>>2];S=B-q*P;T=h+(I<<2)|0;B=+Q(+(+g[T>>2]));I=M|1;U=+g[N+(I<<2)>>2];V=B-q*U;W=h+(H<<2)|0;B=+Q(+(+g[W>>2]));H=M|2;X=+g[N+(H<<2)>>2];Y=B-q*X;Z=h+(J<<2)|0;B=+Q(+(+g[Z>>2]));J=M|3;_=+g[N+(J<<2)>>2];$=B-q*_;aa=(_!=0.0)+((X!=0.0)+((U!=0.0)+((P!=0.0)+K)))|0;U=w+(+(aa|0)+(S*S+0.0+V*V+Y*Y+$*$)*m);ca=aa+F|0;if(!(U<n)){da=n;break}do{if(!y){aa=e[(c[C>>2]|0)+(L<<1)>>1]|0;ea=c[i>>2]|0;fa=c[D>>2]|0;if((fa|0)>(K|0)){ga=fa-K|0;ha=ea<<K|aa;ia=N;ja=P}else{ka=fe(aa>>>((K-fa|0)>>>0)|ea<<fa|0)|0;ea=c[E>>2]|0;x=ka;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;ea=c[s>>2]|0;ga=32-K+fa|0;ha=aa;ia=ea;ja=+g[ea+(M<<2)>>2]}c[i>>2]=ha;c[D>>2]=ga;if(ja!=0.0){ea=+g[O>>2]<0.0|0;if((ga|0)>1){la=ga-1|0;ma=ea|ha<<1;na=ia}else{aa=fe(ea>>>((1-ga|0)>>>0)|ha<<ga|0)|0;fa=c[E>>2]|0;x=aa;a[fa]=x;x=x>>8;a[fa+1|0]=x;x=x>>8;a[fa+2|0]=x;x=x>>8;a[fa+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;la=ga+31|0;ma=ea;na=c[s>>2]|0}c[i>>2]=ma;c[D>>2]=la;oa=ma;pa=la;qa=na}else{oa=ha;pa=ga;qa=ia}if(+g[qa+(I<<2)>>2]!=0.0){ea=+g[T>>2]<0.0|0;if((pa|0)>1){ra=pa-1|0;sa=ea|oa<<1;ta=qa}else{fa=fe(ea>>>((1-pa|0)>>>0)|oa<<pa|0)|0;aa=c[E>>2]|0;x=fa;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;ra=pa+31|0;sa=ea;ta=c[s>>2]|0}c[i>>2]=sa;c[D>>2]=ra;ua=sa;va=ra;wa=ta}else{ua=oa;va=pa;wa=qa}if(+g[wa+(H<<2)>>2]!=0.0){ea=+g[W>>2]<0.0|0;if((va|0)>1){xa=va-1|0;ya=ea|ua<<1;za=wa}else{aa=fe(ea>>>((1-va|0)>>>0)|ua<<va|0)|0;fa=c[E>>2]|0;x=aa;a[fa]=x;x=x>>8;a[fa+1|0]=x;x=x>>8;a[fa+2|0]=x;x=x>>8;a[fa+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;xa=va+31|0;ya=ea;za=c[s>>2]|0}c[i>>2]=ya;c[D>>2]=xa;Aa=ya;Ba=xa;Ca=za}else{Aa=ua;Ba=va;Ca=wa}if(!(+g[Ca+(J<<2)>>2]!=0.0)){break}ea=+g[Z>>2]<0.0|0;if((Ba|0)>1){Da=Ba-1|0;Ea=ea|Aa<<1}else{fa=fe(ea>>>((1-Ba|0)>>>0)|Aa<<Ba|0)|0;aa=c[E>>2]|0;x=fa;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;Da=Ba+31|0;Ea=ea}c[i>>2]=Ea;c[D>>2]=Da}}while(0);Z=G+4|0;if((Z|0)<(j|0)){F=ca;w=U;G=Z}else{u=ca;v=U;break a}}return+da}}while(0);if((o|0)==0){da=v;return+da}c[o>>2]=u;da=v;return+da}function rpb(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0,P=0,S=0,T=0;p=+g[7992896+(304-k<<2)>>2];q=+g[7994608+(k+96<<2)>>2];k=d[1878840+l|0]|0;r=d[1878856+l|0]|0;do{if((i|0)==0){s=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+Q(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+R(w*+R(w));y=t+1|0;if((y|0)<(j|0)){t=y}else{z=s;A=4;break}}}else{z=i;A=4}}while(0);a:do{if((A|0)==4){if((j|0)<=0){u=0;v=0.0;break}w=+(r|0);i=0;do{B=p*+g[z+(i<<2)>>2]+.4054;t=~~(B>w?w:B);s=b+336+(i<<2)|0;c[s>>2]=t;if(+g[h+(i<<2)>>2]<0.0){c[s>>2]=-t}i=i+1|0;}while((i|0)<(j|0));i=l-1|0;t=c[1277088+(i<<2)>>2]|0;s=1286072+(i<<2)|0;y=(f|0)==0;C=1277040+(i<<2)|0;i=f|0;D=f+4|0;E=f+12|0;F=0;w=0.0;G=0;while(1){H=ba(r+(c[b+336+(G<<2)>>2]|0)|0,k)|0;I=G|1;J=H+r+(c[b+336+(I<<2)>>2]|0)|0;H=J<<1;K=c[s>>2]|0;B=+g[h+(G<<2)>>2]-q*+g[K+(H<<2)>>2];L=+g[h+(I<<2)>>2]-q*+g[K+((H|1)<<2)>>2];H=d[t+J|0]|0;M=w+(+(H|0)+(B*B+0.0+L*L)*m);K=H+F|0;if(!(M<n)){N=n;break}if(!y){I=e[(c[C>>2]|0)+(J<<1)>>1]|0;J=c[i>>2]|0;O=c[D>>2]|0;if((O|0)>(H|0)){P=O-H|0;S=J<<H|I}else{T=fe(I>>>((H-O|0)>>>0)|J<<O|0)|0;J=c[E>>2]|0;x=T;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;P=32-H+O|0;S=I}c[i>>2]=S;c[D>>2]=P}I=G+2|0;if((I|0)<(j|0)){F=K;w=M;G=I}else{u=K;v=M;break a}}return+N}}while(0);if((o|0)==0){N=v;return+N}c[o>>2]=u;N=v;return+N}function spb(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,S=0.0,T=0.0,U=0,V=0,W=0.0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;p=+g[7992896+(304-k<<2)>>2];q=+g[7994608+(k+96<<2)>>2];k=d[1878840+l|0]|0;r=d[1878856+l|0]|0;do{if((i|0)==0){s=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+Q(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+R(w*+R(w));y=t+1|0;if((y|0)<(j|0)){t=y}else{z=s;A=4;break}}}else{z=i;A=4}}while(0);a:do{if((A|0)==4){if((j|0)<=0){u=0;v=0.0;break}w=+(r|0);i=0;do{B=p*+g[z+(i<<2)>>2]+.4054;c[b+336+(i<<2)>>2]=~~(B>w?w:B);i=i+1|0;}while((i|0)<(j|0));i=l-1|0;t=c[1277088+(i<<2)>>2]|0;s=1286072+(i<<2)|0;y=(f|0)==0;C=1277040+(i<<2)|0;i=f|0;D=f+4|0;E=f+12|0;F=0;w=0.0;G=0;while(1){H=ba(c[b+336+(G<<2)>>2]|0,k)|0;I=G|1;J=H+(c[b+336+(I<<2)>>2]|0)|0;H=d[t+J|0]|0;K=J<<1;L=c[s>>2]|0;M=h+(G<<2)|0;B=+Q(+(+g[M>>2]));N=+g[L+(K<<2)>>2];O=B-q*N;P=h+(I<<2)|0;B=+Q(+(+g[P>>2]));I=K|1;S=+g[L+(I<<2)>>2];T=B-q*S;U=(S!=0.0)+((N!=0.0)+H)|0;S=w+(+(U|0)+(O*O+0.0+T*T)*m);V=U+F|0;if(!(S<n)){W=n;break}do{if(!y){U=e[(c[C>>2]|0)+(J<<1)>>1]|0;X=c[i>>2]|0;Y=c[D>>2]|0;if((Y|0)>(H|0)){Z=Y-H|0;_=X<<H|U;$=L;aa=N}else{ca=fe(U>>>((H-Y|0)>>>0)|X<<Y|0)|0;X=c[E>>2]|0;x=ca;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;X=c[s>>2]|0;Z=32-H+Y|0;_=U;$=X;aa=+g[X+(K<<2)>>2]}c[i>>2]=_;c[D>>2]=Z;if(aa!=0.0){X=+g[M>>2]<0.0|0;if((Z|0)>1){da=Z-1|0;ea=X|_<<1;fa=$}else{U=fe(X>>>((1-Z|0)>>>0)|_<<Z|0)|0;Y=c[E>>2]|0;x=U;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;da=Z+31|0;ea=X;fa=c[s>>2]|0}c[i>>2]=ea;c[D>>2]=da;ga=ea;ha=da;ia=fa}else{ga=_;ha=Z;ia=$}if(!(+g[ia+(I<<2)>>2]!=0.0)){break}X=+g[P>>2]<0.0|0;if((ha|0)>1){ja=ha-1|0;ka=X|ga<<1}else{Y=fe(X>>>((1-ha|0)>>>0)|ga<<ha|0)|0;U=c[E>>2]|0;x=Y;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;ja=ha+31|0;ka=X}c[i>>2]=ka;c[D>>2]=ja}}while(0);P=G+2|0;if((P|0)<(j|0)){F=V;w=S;G=P}else{u=V;v=S;break a}}return+W}}while(0);if((o|0)==0){W=v;return+W}c[o>>2]=u;W=v;return+W}function tpb(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0.0,s=0.0,t=0,u=0,v=0.0,w=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0.0,P=0.0,S=0,T=0.0,U=0.0,V=0,W=0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0.0,ba=0,ca=0.0,da=0.0,ea=0,fa=0.0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;l=200-k+104|0;p=+g[7994608+(l<<2)>>2];q=+g[7992896+(l<<2)>>2];r=+g[7994608+(k+96<<2)>>2];s=r*165140.0;do{if((i|0)==0){k=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+Q(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+R(w*+R(w));l=t+1|0;if((l|0)<(j|0)){t=l}else{y=k;z=4;break}}}else{y=i;z=4}}while(0);a:do{if((z|0)==4){if((j|0)>0){A=0}else{u=0;v=0.0;break}do{w=q*+g[y+(A<<2)>>2]+.4054;c[b+336+(A<<2)>>2]=w>16.0?16:~~w;A=A+1|0;}while((A|0)<(j|0));i=c[319282]|0;t=(f|0)==0;k=f|0;l=f+4|0;B=f+12|0;C=c[319270]|0;D=0;w=0.0;E=0;while(1){F=E|1;G=((c[b+336+(E<<2)>>2]|0)*17|0)+(c[b+336+(F<<2)>>2]|0)|0;H=i+G|0;I=d[H]|0;J=G<<1;K=c[321528]|0;L=h+(E<<2)|0;M=+Q(+(+g[L>>2]));N=K+(J<<2)|0;O=+g[N>>2];do{if(O==64.0){if(!(M<s)){P=s;S=I+21|0;T=O;break}U=p*M;V=~~(+R(U*+R(U))+.4054);if((V|0)<0){W=0}else{W=(V|0)>8191?8191:V}U=+(W|0);X=r*U*+sb(+U);V=W>>>0>65535>>>0;Y=V?W>>>16:W;Z=V?16:0;if((Y&65280|0)==0){_=Z;$=Y}else{_=Z|8;$=Y>>>8}P=X;S=I-3+((d[1191992+$|0]|0)+_<<1)|0;T=+g[N>>2]}else{P=r*O;S=I;T=O}}while(0);O=M-P;I=(T!=0.0)+S|0;X=O*O+0.0;N=h+(F<<2)|0;O=+Q(+(+g[N>>2]));Y=J|1;Z=K+(Y<<2)|0;U=+g[Z>>2];do{if(U==64.0){if(!(O<s)){aa=s;ba=I+21|0;ca=U;break}da=p*O;V=~~(+R(da*+R(da))+.4054);if((V|0)<0){ea=0}else{ea=(V|0)>8191?8191:V}da=+(ea|0);fa=r*da*+sb(+da);V=ea>>>0>65535>>>0;ga=V?ea>>>16:ea;ha=V?16:0;if((ga&65280|0)==0){ia=ha;ja=ga}else{ia=ha|8;ja=ga>>>8}aa=fa;ba=I-3+((d[1191992+ja|0]|0)+ia<<1)|0;ca=+g[Z>>2]}else{aa=r*U;ba=I;ca=U}}while(0);U=O-aa;I=(ca!=0.0)+ba|0;M=w+((X+U*U)*m+ +(I|0));Z=I+D|0;if(!(M<n)){ka=n;break}if(!t){I=d[H]|0;K=e[C+(G<<1)>>1]|0;F=c[k>>2]|0;ga=c[l>>2]|0;if((ga|0)>(I|0)){la=ga-I|0;ma=F<<I|K}else{ha=fe(K>>>((I-ga|0)>>>0)|F<<ga|0)|0;F=c[B>>2]|0;x=ha;a[F]=x;x=x>>8;a[F+1|0]=x;x=x>>8;a[F+2|0]=x;x=x>>8;a[F+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;la=32-I+ga|0;ma=K}c[k>>2]=ma;c[l>>2]=la;K=c[321528]|0;if(+g[K+(J<<2)>>2]!=0.0){ga=+g[L>>2]<0.0|0;if((la|0)>1){na=la-1|0;oa=ga|ma<<1;pa=K}else{I=fe(ga>>>((1-la|0)>>>0)|ma<<la|0)|0;F=c[B>>2]|0;x=I;a[F]=x;x=x>>8;a[F+1|0]=x;x=x>>8;a[F+2|0]=x;x=x>>8;a[F+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;na=la+31|0;oa=ga;pa=c[321528]|0}c[k>>2]=oa;c[l>>2]=na;qa=oa;ra=na;sa=pa}else{qa=ma;ra=la;sa=K}if(+g[sa+(Y<<2)>>2]!=0.0){K=+g[N>>2]<0.0|0;if((ra|0)>1){ta=ra-1|0;ua=K|qa<<1}else{ga=fe(K>>>((1-ra|0)>>>0)|qa<<ra|0)|0;F=c[B>>2]|0;x=ga;a[F]=x;x=x>>8;a[F+1|0]=x;x=x>>8;a[F+2|0]=x;x=x>>8;a[F+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;ta=ra+31|0;ua=K}c[k>>2]=ua;c[l>>2]=ta;va=0;wa=ua;xa=ta}else{va=0;wa=qa;xa=ra}while(1){if(+g[(c[321528]|0)+(va+J<<2)>>2]==64.0){U=p*+Q(+(+g[h+(va+E<<2)>>2]));K=~~(+R(U*+R(U))+.4054);if((K|0)<0){ya=0}else{ya=(K|0)>8191?8191:K}K=ya>>>0>65535>>>0;F=K?ya>>>16:ya;ga=K?16:0;if((F&65280|0)==0){za=ga;Aa=F}else{za=ga|8;Aa=F>>>8}F=(d[1191992+Aa|0]|0)+za|0;ga=F-3|0;K=(1<<ga)-2|0;if((xa|0)>(ga|0)){Ba=xa-ga|0;Ca=K|wa<<ga}else{I=fe(K>>>((ga-xa|0)>>>0)|wa<<xa|0)|0;ga=c[B>>2]|0;x=I;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;Ba=xa+35-F|0;Ca=K}c[k>>2]=Ca;c[l>>2]=Ba;K=(1<<F)-1&ya;if((Ba|0)>(F|0)){Da=Ba-F|0;Ea=Ca<<F|K}else{ga=fe(K>>>((F-Ba|0)>>>0)|Ca<<Ba|0)|0;I=c[B>>2]|0;x=ga;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;Da=32-F+Ba|0;Ea=K}c[k>>2]=Ea;c[l>>2]=Da;Fa=Ea;Ga=Da}else{Fa=wa;Ga=xa}K=va+1|0;if((K|0)<2){va=K;wa=Fa;xa=Ga}else{break}}}J=E+2|0;if((J|0)<(j|0)){D=Z;w=M;E=J}else{u=Z;v=M;break a}}return+ka}}while(0);if((o|0)==0){ka=v;return+ka}c[o>>2]=u;ka=v;return+ka}function upb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0;j=i;i=i+24|0;k=j|0;l=f+8|0;m=c[l>>2]|0;n=k;o=f;c[n>>2]=c[o>>2];c[n+4>>2]=c[o+4>>2];c[n+8>>2]=c[o+8>>2];c[n+12>>2]=c[o+12>>2];c[n+16>>2]=c[o+16>>2];o=k+8|0;n=c[o>>2]|0;p=k|0;q=c[p>>2]|0;r=d[q+(n>>>3)|0]|0;s=k+16|0;t=c[s>>2]|0;u=((n|0)<(t|0))+n|0;c[o>>2]=u;v=(r&128>>>((n&7)>>>0)|0)!=0;a:do{if(v){n=d[q+(u>>>3)|0]<<(u&7)>>>7;r=((u|0)<(t|0))+u|0;c[o>>2]=r;w=n&1;c[g+4>>2]=w;do{if((w|0)==0){x=r}else{n=q+(r>>>3)|0;y=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(r&7);n=y>>>29;z=r+3|0;A=t>>>0>z>>>0?z:t;c[o>>2]=A;if(y>>>0>3221225471>>>0){yDb(e,16,217e4,(B=i,i=i+8|0,c[B>>2]=n,B)|0);i=B;break a}else{c[g+12>>2]=a[630456+n|0]|0;c[g+8>>2]=y>>>0>1610612735>>>0;c[g+16>>2]=a[630448+n|0]|0;x=A;break}}}while(0);r=d[q+(x>>>3)|0]<<(x&7)>>>7;w=((x|0)<(t|0))+x|0;c[o>>2]=w;A=r&1;c[g+20>>2]=A;do{if((A|0)==0){C=w}else{r=q+(w>>>3)|0;n=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(w&7);r=n>>>29;y=w+3|0;z=t>>>0>y>>>0?y:t;c[o>>2]=z;c[g+24>>2]=r;if(n>>>0>3221225471>>>0){yDb(e,16,2302688,(B=i,i=i+8|0,c[B>>2]=r,B)|0);i=B;break a}else{c[g+28>>2]=a[630456+r|0]|0;C=z;break}}}while(0);w=d[q+(C>>>3)|0]<<(C&7)>>>7;A=((C|0)<(t|0))+C|0;c[o>>2]=A;c[g+32>>2]=w&1;D=A;E=11}else{D=u;E=11}}while(0);b:do{if((E|0)==11){u=((D|0)<(t|0))+D|0;C=d[q+(D>>>3)|0]<<(D&7)>>>7&1;c[g+36>>2]=C;x=g+44|0;A=g+40|0;c[A>>2]=c[x>>2];w=q+(u>>>3)|0;z=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>30;w=u+2|0;u=t>>>0>w>>>0?w:t;c[o>>2]=u;w=a[630080+(C<<2)+z|0]|0;z=w<<24>>24;c[x>>2]=z;c[g+52>>2]=-1;r=w<<24>>24<1;do{if((C|0)==0){if(r){F=z;G=u;break}else{H=1;I=z}while(1){c[g+52+(H<<2)>>2]=(H<<5>>d[1191992+I|0])-1;w=H+1|0;n=c[x>>2]|0;if((w|0)>(n|0)){F=n;G=u;break}else{H=w;I=n}}}else{if(r){F=z;G=u;break}else{J=1;K=u}do{n=q+(K>>>3)|0;w=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(K&7)>>>27;n=K+5|0;K=t>>>0>n>>>0?n:t;c[g+52+(J<<2)>>2]=w;J=J+1|0;L=c[x>>2]|0;}while((J|0)<=(L|0));c[o>>2]=K;F=L;G=K}}while(0);u=g+4|0;do{if((c[u>>2]|0)==0){TGb(g+76|0,0,170)|0;M=F;N=G}else{if((F|0)<=0){M=F;N=G;break}z=g+8|0;r=g+12|0;C=0;w=G;n=c[z>>2]|0;c:while(1){y=((w|0)<(t|0))+w|0;O=d[q+(w>>>3)|0]<<(w&7)>>>7&1;P=c[920928+((O<<1)+n<<2)>>2]|0;Q=c[r>>2]|0;R=c[2585908+(P*20|0)>>2]|0;d:do{if((O|0)==0){S=920072+P|0;T=0;U=0;V=y;W=n;while(1){if((U|0)>=(Q|0)){X=V;Y=W;break d}Z=q+(V>>>3)|0;_=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(V&7)>>>23;Z=b[R+(_<<2)>>1]|0;$=b[R+(_<<2)+2>>1]|0;_=$<<16>>16;do{if($<<16>>16<0){aa=V+9|0;ba=t>>>0>aa>>>0?aa:t;aa=q+(ba>>>3)|0;ca=((fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ba&7)>>>((_+32|0)>>>0))+Z|0;aa=b[R+(ca<<2)>>1]|0;da=b[R+(ca<<2)+2>>1]|0;ca=da<<16>>16;if(!(da<<16>>16<0)){ea=ca;fa=aa;ga=ba;break}da=ba-_|0;ba=t>>>0>da>>>0?da:t;da=q+(ba>>>3)|0;ha=((fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ba&7)>>>((ca+32|0)>>>0))+aa|0;ea=b[R+(ha<<2)+2>>1]|0;fa=b[R+(ha<<2)>>1]|0;ga=ba}else{ea=_;fa=Z;ga=V}}while(0);Z=ea+ga|0;_=t>>>0>Z>>>0?Z:t;Z=fa-(a[S]|0)+T|0;$=Z&255;a[g+76+(C*34|0)+U|0]=$;ba=$<<24>>24;ha=c[z>>2]|0;if((($<<24>>24>-1?ba:-ba|0)|0)>(ha<<3|7|0)){ia=_;E=35;break c}else{T=Z;U=U+1|0;V=_;W=ha}}}else{if((C|0)==0){ja=c[A>>2]|0}else{ja=C}W=ja-1|0;V=(W|0)>0?W:0;W=920072+P|0;U=0;T=y;S=n;while(1){if((U|0)>=(Q|0)){X=T;Y=S;break d}ha=d[g+76+(V*34|0)+U|0]|0;_=q+(T>>>3)|0;Z=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(T&7)>>>23;_=b[R+(Z<<2)>>1]|0;ba=b[R+(Z<<2)+2>>1]|0;Z=ba<<16>>16;do{if(ba<<16>>16<0){$=T+9|0;aa=t>>>0>$>>>0?$:t;$=q+(aa>>>3)|0;ca=((fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(aa&7)>>>((Z+32|0)>>>0))+_|0;$=b[R+(ca<<2)>>1]|0;da=b[R+(ca<<2)+2>>1]|0;ca=da<<16>>16;if(!(da<<16>>16<0)){ka=ca;la=$;ma=aa;break}da=aa-Z|0;aa=t>>>0>da>>>0?da:t;da=q+(aa>>>3)|0;na=((fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(aa&7)>>>((ca+32|0)>>>0))+$|0;ka=b[R+(na<<2)+2>>1]|0;la=b[R+(na<<2)>>1]|0;ma=aa}else{ka=Z;la=_;ma=T}}while(0);_=ka+ma|0;Z=t>>>0>_>>>0?_:t;_=la+ha-(d[W]|0)&255;a[g+76+(C*34|0)+U|0]=_;ba=_<<24>>24;aa=c[z>>2]|0;if(((_<<24>>24>-1?ba:-ba|0)|0)>(aa<<3|7|0)){ia=Z;E=35;break c}else{U=U+1|0;T=Z;S=aa}}}}while(0);R=C+1|0;oa=c[x>>2]|0;if((R|0)<(oa|0)){C=R;w=X;n=Y}else{E=38;break}}if((E|0)==35){c[o>>2]=ia;yDb(e,16,2228136,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}else if((E|0)==38){c[o>>2]=X;M=oa;N=X;break}}}while(0);n=g+20|0;do{if((c[n>>2]|0)==0){TGb(g+246|0,0,170)|0;pa=M;qa=N}else{if((M|0)<=0){pa=M;qa=N;break}w=g+28|0;C=0;z=N;e:while(1){r=((z|0)<(t|0))+z|0;R=d[q+(z>>>3)|0]<<(z&7)>>>7&1;Q=R|4;y=c[w>>2]|0;P=c[2585908+(Q*20|0)>>2]|0;f:do{if((R|0)==0){O=920072+Q|0;S=0;T=0;U=r;while(1){if((T|0)>=(y|0)){ra=U;break f}W=q+(U>>>3)|0;V=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(U&7)>>>23;W=b[P+(V<<2)>>1]|0;aa=b[P+(V<<2)+2>>1]|0;V=aa<<16>>16;do{if(aa<<16>>16<0){Z=U+9|0;ba=t>>>0>Z>>>0?Z:t;Z=q+(ba>>>3)|0;_=((fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(ba&7)>>>((V+32|0)>>>0))+W|0;Z=b[P+(_<<2)>>1]|0;na=b[P+(_<<2)+2>>1]|0;_=na<<16>>16;if(!(na<<16>>16<0)){sa=_;ta=Z;ua=ba;break}na=ba-V|0;ba=t>>>0>na>>>0?na:t;na=q+(ba>>>3)|0;$=((fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ba&7)>>>((_+32|0)>>>0))+Z|0;sa=b[P+($<<2)+2>>1]|0;ta=b[P+($<<2)>>1]|0;ua=ba}else{sa=V;ta=W;ua=U}}while(0);W=sa+ua|0;V=t>>>0>W>>>0?W:t;W=ta-(a[O]|0)+S|0;aa=W&255;a[g+246+(C*34|0)+T|0]=aa;if((aa&255)>>>0>7>>>0){va=V;E=57;break e}else{S=W;T=T+1|0;U=V}}}else{if((C|0)==0){wa=c[A>>2]|0}else{wa=C}U=wa-1|0;T=(U|0)>0?U:0;U=920072+Q|0;S=0;O=r;while(1){if((S|0)>=(y|0)){ra=O;break f}V=d[g+246+(T*34|0)+S|0]|0;W=q+(O>>>3)|0;aa=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(O&7)>>>23;W=b[P+(aa<<2)>>1]|0;ha=b[P+(aa<<2)+2>>1]|0;aa=ha<<16>>16;do{if(ha<<16>>16<0){ba=O+9|0;$=t>>>0>ba>>>0?ba:t;ba=q+($>>>3)|0;Z=((fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<($&7)>>>((aa+32|0)>>>0))+W|0;ba=b[P+(Z<<2)>>1]|0;_=b[P+(Z<<2)+2>>1]|0;Z=_<<16>>16;if(!(_<<16>>16<0)){xa=Z;ya=ba;za=$;break}_=$-aa|0;$=t>>>0>_>>>0?_:t;_=q+($>>>3)|0;na=((fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<($&7)>>>((Z+32|0)>>>0))+ba|0;xa=b[P+(na<<2)+2>>1]|0;ya=b[P+(na<<2)>>1]|0;za=$}else{xa=aa;ya=W;za=O}}while(0);W=xa+za|0;aa=t>>>0>W>>>0?W:t;W=ya+V-(d[U]|0)&255;a[g+246+(C*34|0)+S|0]=W;if((W&255)>>>0>7>>>0){va=aa;E=57;break e}else{S=S+1|0;O=aa}}}}while(0);P=C+1|0;Aa=c[x>>2]|0;if((P|0)<(Aa|0)){C=P;z=ra}else{E=60;break}}if((E|0)==57){c[o>>2]=va;yDb(e,16,2240184,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}else if((E|0)==60){c[o>>2]=ra;pa=Aa;qa=ra;break}}}while(0);do{if((c[g+32>>2]|0)==0){Ba=pa;Ca=qa}else{z=q+(qa>>>3)|0;C=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(qa&7)>>>28;z=qa+4|0;w=t>>>0>z>>>0?z:t;c[o>>2]=w;if((C|0)==15){z=q+(w>>>3)|0;P=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7)>>>24;z=w+8|0;y=t>>>0>z>>>0?z:t;c[o>>2]=y;Da=P+15|0;Ea=y}else{Da=C;Ea=w}w=Da<<3;g:do{if((w|0)>7){C=g+48|0;y=g+416|0;P=g+586|0;z=w;r=pa;Q=Ea;R=t;O=q;while(1){S=O+(Q>>>3)|0;U=fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0;S=Q+2|0;T=R>>>0>S>>>0?S:R;c[o>>2]=T;if((U&-1073741824>>>((Q&7)>>>0)|0)==0){U=d[O+(T>>>3)|0]<<(T&7)>>>7;S=((T|0)<(R|0))+T|0;c[o>>2]=S;aa=U&1;c[C>>2]=aa;if((aa|0)!=0&(r|0)>0){aa=0;U=O;W=S;ha=R;while(1){$=d[U+(W>>>3)|0]<<(W&7)>>>7;c[o>>2]=((W|0)<(ha|0))+W;na=$&1;Cpb(k,g,y,na|6,aa,na);na=c[o>>2]|0;$=d[(c[p>>2]|0)+(na>>>3)|0]<<(na&7)>>>7;c[o>>2]=((na|0)<(c[s>>2]|0))+na;na=$&1;Cpb(k,g,P,na|8,aa,na);na=aa+1|0;Fa=c[x>>2]|0;if((na|0)>=(Fa|0)){break}aa=na;U=c[p>>2]|0;W=c[o>>2]|0;ha=c[s>>2]|0}Ga=Fa;Ha=c[o>>2]|0;Ia=c[s>>2]|0}else{Ga=r;Ha=S;Ia=R}ha=Ha+1|0;W=Ia>>>0>ha>>>0?ha:Ia;c[o>>2]=W;Ja=2-T+W|0;Ka=Ga;La=W;Ma=Ia}else{Ja=2;Ka=r;La=T;Ma=R}W=z-Ja|0;if((W|0)<=7){Na=W;Oa=Ka;Pa=La;Qa=Ma;break g}z=W;r=Ka;Q=La;R=Ma;O=c[p>>2]|0}}else{Na=w;Oa=pa;Pa=Ea;Qa=t}}while(0);if((Na|0)<0){yDb(e,16,2172856,(B=i,i=i+8|0,c[B>>2]=Na,B)|0);i=B;break b}else{w=Pa+Na|0;O=Qa>>>0>w>>>0?w:Qa;c[o>>2]=O;Ba=Oa;Ca=O;break}}}while(0);O=g+48|0;c[O>>2]=c[O>>2]&1;if((Ba|0)==0){Ra=c[A>>2]|0;Sa=0;E=80}else{if((c[g+52+(Ba<<2)>>2]|0)<31){Ra=Ba;Sa=Ba;E=80}}if((E|0)==80){w=Ra-1|0;do{if(!((Ra|0)<1|(w|0)==(Sa|0))){if((c[u>>2]|0)!=0){UGb(g+76+(Sa*34|0)|0,g+76+(w*34|0)|0,34)|0}if((c[n>>2]|0)!=0){UGb(g+246+((c[x>>2]|0)*34|0)|0,g+246+(w*34|0)|0,34)|0}if((c[O>>2]|0)==0){break}UGb(g+416+((c[x>>2]|0)*34|0)|0,g+416+(w*34|0)|0,34)|0;UGb(g+586+((c[x>>2]|0)*34|0)|0,g+586+(w*34|0)|0,34)|0}}while(0);h:do{if((c[u>>2]|0)!=0){w=c[g+12>>2]|0;A=g+8|0;R=0;while(1){if((R|0)>=(w|0)){break h}Q=a[g+76+((c[x>>2]|0)*34|0)+R|0]|0;r=Q<<24>>24;if(((Q<<24>>24>-1?r:-r|0)|0)>(c[A>>2]<<3|7|0)){break}else{R=R+1|0}}yDb(e,16,2098304,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}}while(0);i:do{if((c[n>>2]|0)!=0){R=c[g+12>>2]|0;A=0;while(1){if((A|0)>=(R|0)){break i}if((d[g+246+((c[x>>2]|0)*34|0)+A|0]|0)>>>0>7>>>0){break}else{A=A+1|0}}yDb(e,16,2043080,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}}while(0);A=(c[x>>2]|0)+1|0;c[x>>2]=A;c[g+52+(A<<2)>>2]=31}A=g+756|0;c[g+760>>2]=c[A>>2];do{if((c[u>>2]|0)==0){if((c[n>>2]|0)!=0){E=102}}else{if((c[g+12>>2]|0)==34){Ta=1;E=103;break}if((c[n>>2]|0)==0){Ta=0;E=103}else{E=102}}}while(0);if((E|0)==102){Ta=(c[g+28>>2]|0)==34|0;E=103}if((E|0)==103){c[A>>2]=Ta}if((c[O>>2]|0)==0){TGb(g+416|0,0,340)|0}if(v){c[g>>2]=1}n=Ca-m|0;if((n|0)>(h|0)){yDb(e,16,1997984,(B=i,i=i+16|0,c[B>>2]=h,c[B+8>>2]=n,B)|0);i=B;break}u=c[l>>2]|0;x=-u|0;R=(c[f+16>>2]|0)-u|0;if((n|0)<(x|0)){Ua=x}else{Ua=(R|0)<(n|0)?R:n}c[l>>2]=Ua+u;Va=n;i=j;return Va|0}}while(0);c[g>>2]=0;Ua=c[l>>2]|0;B=-Ua|0;e=(c[f+16>>2]|0)-Ua|0;if((h|0)<(B|0)){Wa=B}else{Wa=(e|0)<(h|0)?e:h}c[l>>2]=Wa+Ua;TGb(g+76|0,0,680)|0;Va=h;i=j;return Va|0}function vpb(b,d,e,f,h){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0.0,aa=0.0,ba=0.0,ca=0.0,da=0.0,ea=0.0,fa=0,ga=0,ha=0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0,na=0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0.0,ta=0.0,ua=0,va=0;b=i;i=i+56160|0;j=b|0;k=b+176|0;l=b+352|0;m=b+528|0;n=b+704|0;o=b+712|0;p=b+720|0;q=b+728|0;r=b+736|0;s=b+768|0;t=b+800|0;u=b+5152|0;v=b+9504|0;w=b+9568|0;x=b+32864|0;y=w|0;z=x|0;A=c[d+756>>2]|0;B=2363200+(A<<2)|0;C=c[B>>2]|0;D=h-64+C|0;TGb(d+2528+(D*368|0)|0,0,(64-h|0)*368|0|0)|0;h=c[2363208+(A<<2)>>2]|0;if((D|0)<(h|0)){TGb(d+36016+(D*888|0)|0,0,(h-D|0)*888|0|0)|0}D=d+87444|0;E=0;do{F=E+6|0;g[d+768+(F<<3)>>2]=+g[e+(E<<8)>>2];g[d+768+(F<<3)+4>>2]=+g[e+9728+(E<<8)>>2];E=E+1|0;}while((E|0)<38);E=d+768|0;F=0;while(1){G=F+6|0;g[d+1120+(G<<3)>>2]=+g[e+(F<<8)+4>>2];g[d+1120+(G<<3)+4>>2]=+g[e+9728+(F<<8)+4>>2];G=F+1|0;if((G|0)<38){F=G}else{H=0;break}}while(1){F=H+6|0;g[d+1472+(F<<3)>>2]=+g[e+(H<<8)+8>>2];g[d+1472+(F<<3)+4>>2]=+g[e+9728+(H<<8)+8>>2];F=H+1|0;if((F|0)<38){H=F}else{I=0;break}}while(1){H=I+6|0;g[d+1824+(H<<3)>>2]=+g[e+(I<<8)+12>>2];g[d+1824+(H<<3)+4>>2]=+g[e+9728+(I<<8)+12>>2];H=I+1|0;if((H|0)<38){I=H}else{J=0;break}}do{I=J+6|0;g[d+2176+(I<<3)>>2]=+g[e+(J<<8)+16>>2];g[d+2176+(I<<3)+4>>2]=+g[e+9728+(J<<8)+16>>2];J=J+1|0;}while((J|0)<38);J=E|0;if((A|0)==0){I=v|0;H=d+87452|0;F=v+48|0;G=v+52|0;K=v+56|0;L=v+60|0;M=v|0;N=v+4|0;O=v+8|0;P=v+12|0;Q=v+16|0;R=v+40|0;S=v+20|0;T=v+44|0;U=v+24|0;V=v+32|0;W=v+28|0;X=v+36|0;v=0;Y=J;while(1){le[c[H>>2]&1023](I,Y,8018864,1,8);g[w+(v<<3)>>2]=+g[F>>2];g[w+(v<<3)+4>>2]=+g[G>>2];g[w+256+(v<<3)>>2]=+g[K>>2];g[w+256+(v<<3)+4>>2]=+g[L>>2];g[w+512+(v<<3)>>2]=+g[M>>2];g[w+512+(v<<3)+4>>2]=+g[N>>2];g[w+768+(v<<3)>>2]=+g[O>>2];g[w+768+(v<<3)+4>>2]=+g[P>>2];g[w+1024+(v<<3)>>2]=+g[Q>>2]+ +g[R>>2];g[w+1024+(v<<3)+4>>2]=+g[S>>2]+ +g[T>>2];g[w+1280+(v<<3)>>2]=+g[U>>2]+ +g[V>>2];g[w+1280+(v<<3)+4>>2]=+g[W>>2]+ +g[X>>2];Z=v+1|0;if((Z|0)<32){v=Z;Y=Y+8|0}else{break}}Y=0;v=d+1120|0;while(1){_=(+g[v+8>>2]+ +g[v+88>>2])*.018994875252246857+0.0+(+g[v+24>>2]+ +g[v+72>>2])*-.07293139398097992+(+g[v+40>>2]+ +g[v+56>>2])*.305966317653656;$=(+g[v+12>>2]+ +g[v+92>>2])*.018994875252246857+0.0+(+g[v+28>>2]+ +g[v+76>>2])*-.07293139398097992+(+g[v+44>>2]+ +g[v+60>>2])*.305966317653656;aa=+g[v+48>>2]*.5;ba=+g[v+52>>2]*.5;g[w+1792+(Y<<3)>>2]=aa+_;g[w+1792+(Y<<3)+4>>2]=ba+$;g[w+1536+(Y<<3)>>2]=aa-_;g[w+1536+(Y<<3)+4>>2]=ba-$;X=Y+1|0;if((X|0)<32){Y=X;v=v+8|0}else{break}}v=0;Y=d+1472|0;while(1){$=(+g[Y+8>>2]+ +g[Y+88>>2])*.018994875252246857+0.0+(+g[Y+24>>2]+ +g[Y+72>>2])*-.07293139398097992+(+g[Y+40>>2]+ +g[Y+56>>2])*.305966317653656;ba=(+g[Y+12>>2]+ +g[Y+92>>2])*.018994875252246857+0.0+(+g[Y+28>>2]+ +g[Y+76>>2])*-.07293139398097992+(+g[Y+44>>2]+ +g[Y+60>>2])*.305966317653656;_=+g[Y+48>>2]*.5;aa=+g[Y+52>>2]*.5;g[w+2048+(v<<3)>>2]=_+$;g[w+2048+(v<<3)+4>>2]=aa+ba;g[w+2304+(v<<3)>>2]=_-$;g[w+2304+(v<<3)+4>>2]=aa-ba;X=v+1|0;if((X|0)<32){v=X;Y=Y+8|0}else{break}}cf[c[d+87456>>2]&1023](w+1792|0,e,3,32)}else{Y=d+87452|0;v=J;J=0;while(1){le[c[Y>>2]&1023](w+(J<<3)|0,v,8018096,32,12);X=J+1|0;if((X|0)<32){v=v+8|0;J=X}else{break}}J=d+1120|0;v=0;while(1){le[c[Y>>2]&1023](w+3072+(v<<3)|0,J,8017584,32,8);X=v+1|0;if((X|0)<32){J=J+8|0;v=X}else{break}}v=d+1472|0;J=0;while(1){le[c[Y>>2]&1023](w+5120+(J<<3)|0,v,8017328,32,4);X=J+1|0;if((X|0)<32){v=v+8|0;J=X}else{break}}J=d+1824|0;v=0;while(1){le[c[Y>>2]&1023](w+6144+(v<<3)|0,J,8017328,32,4);X=v+1|0;if((X|0)<32){J=J+8|0;v=X}else{break}}v=d+2176|0;J=0;while(1){le[c[Y>>2]&1023](w+7168+(J<<3)|0,v,8017328,32,4);X=J+1|0;if((X|0)<32){v=v+8|0;J=X}else{break}}cf[c[d+87456>>2]&1023](w+6912|0,e,5,32)}UGb(E|0,d+1024|0,48)|0;UGb(d+1120|0,d+1376|0,48)|0;UGb(d+1472|0,d+1728|0,48)|0;UGb(d+1824|0,d+2080|0,48)|0;UGb(d+2176|0,d+2432|0,48)|0;E=(A|0)!=0;J=E?879912:880008;TGb(t|0,0,4352)|0;v=d+760|0;if((c[v>>2]|0)!=(A|0)){TGb(d+80560|0,0,136)|0;TGb(d+80704|0,0,136)|0;TGb(d+2528|0,0,78024)|0}Y=A>>>0<2>>>0;if(Y){X=d+87444|0;W=0;do{Xe[c[X>>2]&4095](t+(a[J+W|0]<<7)|0,w+(W<<8)|0,32);W=W+1|0;}while((W|0)<(C|0));W=c[2363184+(A<<2)>>2]|0;X=0;do{V=d+80416+(X<<2)|0;U=d+80560+(X<<2)|0;T=d+80704+(X<<2)|0;S=0;ba=+g[V>>2];aa=+g[U>>2];$=+g[T>>2];do{_=ba*.765928328037262;ca=+g[t+(X<<7)+(S<<2)>>2];ba=_>ca?_:ca;aa=aa+(ca-aa)*.25;$=$+(ba-ca-$)*.25;ca=$*1.5;if(ca>aa){da=aa/ca}else{da=1.0}g[u+(X<<7)+(S<<2)>>2]=da;S=S+1|0;}while((S|0)<32);g[V>>2]=ba;g[U>>2]=aa;g[T>>2]=$;X=X+1|0;}while((X|0)<(W|0));W=c[2365744+(A<<2)>>2]|0;X=d+87464|0;t=0;do{S=a[J+t|0]|0;da=1.0- +(t-W|0)*.05000000074505806;if(da<0.0){ea=0.0}else{ea=da>1.0?1.0:da}UGb(d+2528+(t*368|0)|0,d+2528+(t*368|0)+256|0,112)|0;UGb(d+2528+(t*368|0)+112|0,w+(t<<8)|0,256)|0;R=d+36016+(t*888|0)|0;UGb(R|0,d+36016+(t*888|0)+256|0,40)|0;UGb(d+36016+(t*888|0)+296|0,d+36016+(t*888|0)+552|0,40)|0;UGb(d+36016+(t*888|0)+592|0,d+36016+(t*888|0)+848|0,40)|0;ke[c[X>>2]&3](x+(t<<8)|0,d+2528+(t*368|0)+96|0,R,4649728+(A*400|0)+(t<<3)|0,9204136+(A*1200|0)+(t*24|0)|0,u+(S<<7)|0,ea,32);t=t+1|0;}while((t|0)<(h|0));fa=(h|0)>1?h:1}else{fa=0}h=c[2362440+(A<<2)>>2]|0;if((fa|0)<(h|0)){t=d+87448|0;X=fa+1|0;W=fa;do{S=a[J+W|0]|0;UGb(d+2528+(W*368|0)|0,d+2528+(W*368|0)+256|0,112)|0;UGb(d+2528+(W*368|0)+112|0,w+(W<<8)|0,256)|0;cf[c[t>>2]&1023](x+(W<<8)|0,d+2528+(W*368|0)|0,u+(S<<7)|0,32);W=W+1|0;}while((W|0)<(h|0));ga=(h|0)>(X|0)?h:X}else{ga=fa}if((ga|0)<(C|0)){fa=d+87448|0;X=ga;do{ga=a[J+X|0]|0;UGb(d+2528+(X*368|0)|0,d+2528+(X*368|0)+256|0,112)|0;UGb(d+2528+(X*368|0)+112|0,w+(X<<8)|0,256)|0;cf[c[fa>>2]&1023](x+(X<<8)|0,d+2528+(X*368|0)+104|0,u+(ga<<7)|0,32);X=X+1|0;}while((X|0)<(C|0))}C=d+80848|0;X=d+82480|0;u=d+84112|0;fa=d+85744|0;ga=d+87376|0;h=d+87410|0;c[n>>2]=j;c[o>>2]=k;c[p>>2]=l;c[q>>2]=m;m=(c[d+24>>2]|0)<3?9212424:9206536;l=c[d+40>>2]|0;if((l|0)!=0){UGb(C|0,d+80848+(l*136|0)|0,136)|0;UGb(d+81664|0,d+81664+(l*136|0)|0,136)|0;UGb(X|0,d+82480+(l*136|0)|0,136)|0;UGb(d+83296|0,d+83296+(l*136|0)|0,136)|0;UGb(u|0,d+84112+(l*136|0)|0,136)|0;UGb(d+84928|0,d+84928+(l*136|0)|0,136)|0;UGb(fa|0,d+85744+(l*136|0)|0,136)|0;UGb(d+86560|0,d+86560+(l*136|0)|0,136)|0}l=d+76|0;k=c[d+12>>2]|0;j=d+44|0;W=c[j>>2]|0;do{if(E){zpb(n,l,k,W,1);zpb(o,d+246|0,c[d+28>>2]|0,c[j>>2]|0,1);if((c[d+48>>2]|0)!=0){t=d+16|0;zpb(p,d+416|0,c[t>>2]|0,c[j>>2]|0,0);zpb(q,d+586|0,c[t>>2]|0,c[j>>2]|0,0)}if((c[v>>2]|0)!=0){break}t=d+80924|0;ea=+g[t>>2];g[d+80980>>2]=ea;g[d+80976>>2]=ea;S=d+80920|0;ea=+g[S>>2];g[d+80972>>2]=ea;g[d+80968>>2]=ea;g[d+80964>>2]=ea;g[d+80960>>2]=ea;R=d+80916|0;ea=+g[R>>2];g[d+80956>>2]=ea;g[d+80952>>2]=ea;Q=d+80912|0;ea=+g[Q>>2];g[d+80948>>2]=ea;g[d+80944>>2]=ea;P=d+80908|0;ea=+g[P>>2];g[d+80940>>2]=ea;g[d+80936>>2]=ea;O=d+80904|0;ea=+g[O>>2];g[d+80932>>2]=ea;g[d+80928>>2]=ea;N=d+80900|0;g[t>>2]=+g[N>>2];t=d+80896|0;g[S>>2]=+g[t>>2];S=d+80892|0;g[R>>2]=+g[S>>2];R=d+80888|0;g[Q>>2]=+g[R>>2];Q=d+80884|0;ea=+g[Q>>2];g[P>>2]=ea;g[O>>2]=ea;O=d+80880|0;ea=+g[O>>2];g[N>>2]=ea;g[t>>2]=ea;t=d+80876|0;g[S>>2]=+g[t>>2];S=d+80872|0;g[R>>2]=+g[S>>2];R=d+80868|0;ea=+g[R>>2];g[Q>>2]=ea;g[O>>2]=ea;O=d+80864|0;ea=+g[O>>2];g[t>>2]=ea;g[S>>2]=ea;S=d+80860|0;ea=+g[S>>2];g[R>>2]=ea;R=d+80856|0;da=+g[R>>2];g[O>>2]=(ea+da)*.5;g[S>>2]=da;S=d+80852|0;da=+g[S>>2];g[R>>2]=da;g[S>>2]=(da+ +g[C>>2])*.5;S=d+81740|0;da=+g[S>>2];g[d+81796>>2]=da;g[d+81792>>2]=da;R=d+81736|0;da=+g[R>>2];g[d+81788>>2]=da;g[d+81784>>2]=da;g[d+81780>>2]=da;g[d+81776>>2]=da;O=d+81732|0;da=+g[O>>2];g[d+81772>>2]=da;g[d+81768>>2]=da;t=d+81728|0;da=+g[t>>2];g[d+81764>>2]=da;g[d+81760>>2]=da;Q=d+81724|0;da=+g[Q>>2];g[d+81756>>2]=da;g[d+81752>>2]=da;N=d+81720|0;da=+g[N>>2];g[d+81748>>2]=da;g[d+81744>>2]=da;P=d+81716|0;g[S>>2]=+g[P>>2];S=d+81712|0;g[R>>2]=+g[S>>2];R=d+81708|0;g[O>>2]=+g[R>>2];O=d+81704|0;g[t>>2]=+g[O>>2];t=d+81700|0;da=+g[t>>2];g[Q>>2]=da;g[N>>2]=da;N=d+81696|0;da=+g[N>>2];g[P>>2]=da;g[S>>2]=da;S=d+81692|0;g[R>>2]=+g[S>>2];R=d+81688|0;g[O>>2]=+g[R>>2];O=d+81684|0;da=+g[O>>2];g[t>>2]=da;g[N>>2]=da;N=d+81680|0;da=+g[N>>2];g[S>>2]=da;g[R>>2]=da;R=d+81676|0;da=+g[R>>2];g[O>>2]=da;O=d+81672|0;ea=+g[O>>2];g[N>>2]=(da+ea)*.5;g[R>>2]=ea;R=d+81668|0;ea=+g[R>>2];g[O>>2]=ea;g[R>>2]=(ea+ +g[d+81664>>2])*.5;R=d+82556|0;ea=+g[R>>2];g[d+82612>>2]=ea;g[d+82608>>2]=ea;O=d+82552|0;ea=+g[O>>2];g[d+82604>>2]=ea;g[d+82600>>2]=ea;g[d+82596>>2]=ea;g[d+82592>>2]=ea;N=d+82548|0;ea=+g[N>>2];g[d+82588>>2]=ea;g[d+82584>>2]=ea;S=d+82544|0;ea=+g[S>>2];g[d+82580>>2]=ea;g[d+82576>>2]=ea;t=d+82540|0;ea=+g[t>>2];g[d+82572>>2]=ea;g[d+82568>>2]=ea;P=d+82536|0;ea=+g[P>>2];g[d+82564>>2]=ea;g[d+82560>>2]=ea;Q=d+82532|0;g[R>>2]=+g[Q>>2];R=d+82528|0;g[O>>2]=+g[R>>2];O=d+82524|0;g[N>>2]=+g[O>>2];N=d+82520|0;g[S>>2]=+g[N>>2];S=d+82516|0;ea=+g[S>>2];g[t>>2]=ea;g[P>>2]=ea;P=d+82512|0;ea=+g[P>>2];g[Q>>2]=ea;g[R>>2]=ea;R=d+82508|0;g[O>>2]=+g[R>>2];O=d+82504|0;g[N>>2]=+g[O>>2];N=d+82500|0;ea=+g[N>>2];g[S>>2]=ea;g[P>>2]=ea;P=d+82496|0;ea=+g[P>>2];g[R>>2]=ea;g[O>>2]=ea;O=d+82492|0;ea=+g[O>>2];g[N>>2]=ea;N=d+82488|0;da=+g[N>>2];g[P>>2]=(ea+da)*.5;g[O>>2]=da;O=d+82484|0;da=+g[O>>2];g[N>>2]=da;g[O>>2]=(da+ +g[X>>2])*.5;O=d+83372|0;da=+g[O>>2];g[d+83428>>2]=da;g[d+83424>>2]=da;N=d+83368|0;da=+g[N>>2];g[d+83420>>2]=da;g[d+83416>>2]=da;g[d+83412>>2]=da;g[d+83408>>2]=da;P=d+83364|0;da=+g[P>>2];g[d+83404>>2]=da;g[d+83400>>2]=da;R=d+83360|0;da=+g[R>>2];g[d+83396>>2]=da;g[d+83392>>2]=da;S=d+83356|0;da=+g[S>>2];g[d+83388>>2]=da;g[d+83384>>2]=da;Q=d+83352|0;da=+g[Q>>2];g[d+83380>>2]=da;g[d+83376>>2]=da;t=d+83348|0;g[O>>2]=+g[t>>2];O=d+83344|0;g[N>>2]=+g[O>>2];N=d+83340|0;g[P>>2]=+g[N>>2];P=d+83336|0;g[R>>2]=+g[P>>2];R=d+83332|0;da=+g[R>>2];g[S>>2]=da;g[Q>>2]=da;Q=d+83328|0;da=+g[Q>>2];g[t>>2]=da;g[O>>2]=da;O=d+83324|0;g[N>>2]=+g[O>>2];N=d+83320|0;g[P>>2]=+g[N>>2];P=d+83316|0;da=+g[P>>2];g[R>>2]=da;g[Q>>2]=da;Q=d+83312|0;da=+g[Q>>2];g[O>>2]=da;g[N>>2]=da;N=d+83308|0;da=+g[N>>2];g[P>>2]=da;P=d+83304|0;ea=+g[P>>2];g[Q>>2]=(da+ea)*.5;g[N>>2]=ea;N=d+83300|0;ea=+g[N>>2];g[P>>2]=ea;g[N>>2]=(ea+ +g[d+83296>>2])*.5;N=d+84188|0;ea=+g[N>>2];g[d+84244>>2]=ea;g[d+84240>>2]=ea;P=d+84184|0;ea=+g[P>>2];g[d+84236>>2]=ea;g[d+84232>>2]=ea;g[d+84228>>2]=ea;g[d+84224>>2]=ea;Q=d+84180|0;ea=+g[Q>>2];g[d+84220>>2]=ea;g[d+84216>>2]=ea;O=d+84176|0;ea=+g[O>>2];g[d+84212>>2]=ea;g[d+84208>>2]=ea;R=d+84172|0;ea=+g[R>>2];g[d+84204>>2]=ea;g[d+84200>>2]=ea;t=d+84168|0;ea=+g[t>>2];g[d+84196>>2]=ea;g[d+84192>>2]=ea;S=d+84164|0;g[N>>2]=+g[S>>2];N=d+84160|0;g[P>>2]=+g[N>>2];P=d+84156|0;g[Q>>2]=+g[P>>2];Q=d+84152|0;g[O>>2]=+g[Q>>2];O=d+84148|0;ea=+g[O>>2];g[R>>2]=ea;g[t>>2]=ea;t=d+84144|0;ea=+g[t>>2];g[S>>2]=ea;g[N>>2]=ea;N=d+84140|0;g[P>>2]=+g[N>>2];P=d+84136|0;g[Q>>2]=+g[P>>2];Q=d+84132|0;ea=+g[Q>>2];g[O>>2]=ea;g[t>>2]=ea;t=d+84128|0;ea=+g[t>>2];g[N>>2]=ea;g[P>>2]=ea;P=d+84124|0;ea=+g[P>>2];g[Q>>2]=ea;Q=d+84120|0;da=+g[Q>>2];g[t>>2]=(ea+da)*.5;g[P>>2]=da;P=d+84116|0;da=+g[P>>2];g[Q>>2]=da;g[P>>2]=(da+ +g[u>>2])*.5;P=d+85004|0;da=+g[P>>2];g[d+85060>>2]=da;g[d+85056>>2]=da;Q=d+85e3|0;da=+g[Q>>2];g[d+85052>>2]=da;g[d+85048>>2]=da;g[d+85044>>2]=da;g[d+85040>>2]=da;t=d+84996|0;da=+g[t>>2];g[d+85036>>2]=da;g[d+85032>>2]=da;N=d+84992|0;da=+g[N>>2];g[d+85028>>2]=da;g[d+85024>>2]=da;O=d+84988|0;da=+g[O>>2];g[d+85020>>2]=da;g[d+85016>>2]=da;S=d+84984|0;da=+g[S>>2];g[d+85012>>2]=da;g[d+85008>>2]=da;R=d+84980|0;g[P>>2]=+g[R>>2];P=d+84976|0;g[Q>>2]=+g[P>>2];Q=d+84972|0;g[t>>2]=+g[Q>>2];t=d+84968|0;g[N>>2]=+g[t>>2];N=d+84964|0;da=+g[N>>2];g[O>>2]=da;g[S>>2]=da;S=d+84960|0;da=+g[S>>2];g[R>>2]=da;g[P>>2]=da;P=d+84956|0;g[Q>>2]=+g[P>>2];Q=d+84952|0;g[t>>2]=+g[Q>>2];t=d+84948|0;da=+g[t>>2];g[N>>2]=da;g[S>>2]=da;S=d+84944|0;da=+g[S>>2];g[P>>2]=da;g[Q>>2]=da;Q=d+84940|0;da=+g[Q>>2];g[t>>2]=da;t=d+84936|0;ea=+g[t>>2];g[S>>2]=(da+ea)*.5;g[Q>>2]=ea;Q=d+84932|0;ea=+g[Q>>2];g[t>>2]=ea;g[Q>>2]=(ea+ +g[d+84928>>2])*.5;Q=d+85820|0;ea=+g[Q>>2];g[d+85876>>2]=ea;g[d+85872>>2]=ea;t=d+85816|0;ea=+g[t>>2];g[d+85868>>2]=ea;g[d+85864>>2]=ea;g[d+85860>>2]=ea;g[d+85856>>2]=ea;S=d+85812|0;ea=+g[S>>2];g[d+85852>>2]=ea;g[d+85848>>2]=ea;P=d+85808|0;ea=+g[P>>2];g[d+85844>>2]=ea;g[d+85840>>2]=ea;N=d+85804|0;ea=+g[N>>2];g[d+85836>>2]=ea;g[d+85832>>2]=ea;R=d+85800|0;ea=+g[R>>2];g[d+85828>>2]=ea;g[d+85824>>2]=ea;O=d+85796|0;g[Q>>2]=+g[O>>2];Q=d+85792|0;g[t>>2]=+g[Q>>2];t=d+85788|0;g[S>>2]=+g[t>>2];S=d+85784|0;g[P>>2]=+g[S>>2];P=d+85780|0;ea=+g[P>>2];g[N>>2]=ea;g[R>>2]=ea;R=d+85776|0;ea=+g[R>>2];g[O>>2]=ea;g[Q>>2]=ea;Q=d+85772|0;g[t>>2]=+g[Q>>2];t=d+85768|0;g[S>>2]=+g[t>>2];S=d+85764|0;ea=+g[S>>2];g[P>>2]=ea;g[R>>2]=ea;R=d+85760|0;ea=+g[R>>2];g[Q>>2]=ea;g[t>>2]=ea;t=d+85756|0;ea=+g[t>>2];g[S>>2]=ea;S=d+85752|0;da=+g[S>>2];g[R>>2]=(ea+da)*.5;g[t>>2]=da;t=d+85748|0;da=+g[t>>2];g[S>>2]=da;g[t>>2]=(da+ +g[fa>>2])*.5;t=d+86636|0;da=+g[t>>2];g[d+86692>>2]=da;g[d+86688>>2]=da;S=d+86632|0;da=+g[S>>2];g[d+86684>>2]=da;g[d+86680>>2]=da;g[d+86676>>2]=da;g[d+86672>>2]=da;R=d+86628|0;da=+g[R>>2];g[d+86668>>2]=da;g[d+86664>>2]=da;Q=d+86624|0;da=+g[Q>>2];g[d+86660>>2]=da;g[d+86656>>2]=da;P=d+86620|0;da=+g[P>>2];g[d+86652>>2]=da;g[d+86648>>2]=da;O=d+86616|0;da=+g[O>>2];g[d+86644>>2]=da;g[d+86640>>2]=da;N=d+86612|0;g[t>>2]=+g[N>>2];t=d+86608|0;g[S>>2]=+g[t>>2];S=d+86604|0;g[R>>2]=+g[S>>2];R=d+86600|0;g[Q>>2]=+g[R>>2];Q=d+86596|0;da=+g[Q>>2];g[P>>2]=da;g[O>>2]=da;O=d+86592|0;da=+g[O>>2];g[N>>2]=da;g[t>>2]=da;t=d+86588|0;g[S>>2]=+g[t>>2];S=d+86584|0;g[R>>2]=+g[S>>2];R=d+86580|0;da=+g[R>>2];g[Q>>2]=da;g[O>>2]=da;O=d+86576|0;da=+g[O>>2];g[t>>2]=da;g[S>>2]=da;S=d+86572|0;da=+g[S>>2];g[R>>2]=da;R=d+86568|0;ea=+g[R>>2];g[O>>2]=(da+ea)*.5;g[S>>2]=ea;S=d+86564|0;ea=+g[S>>2];g[R>>2]=ea;g[S>>2]=(ea+ +g[d+86560>>2])*.5;TGb(ga|0,0,17)|0;TGb(h|0,0,17)|0}else{Apb(n,l,k,W,1);Apb(o,d+246|0,c[d+28>>2]|0,c[j>>2]|0,1);if((c[d+48>>2]|0)!=0){S=d+16|0;Apb(p,d+416|0,c[S>>2]|0,c[j>>2]|0,0);Apb(q,d+586|0,c[S>>2]|0,c[j>>2]|0,0)}if((c[v>>2]|0)==0){break}Bpb(C|0);Bpb(d+81664|0);Bpb(X|0);Bpb(d+83296|0);Bpb(u|0);Bpb(d+84928|0);Bpb(fa|0);Bpb(d+86560|0);TGb(ga|0,0,17)|0;TGb(h|0,0,17)|0}}while(0);if((c[j>>2]|0)<=0){wpb(D,e,y,A);wpb(D,f,z,A);i=b;return 0}h=2363184+(A<<2)|0;ga=r|0;fa=r|0;u=r+4|0;X=r+8|0;C=r+12|0;v=d+48|0;W=s|0;k=s|0;l=s+4|0;S=s+8|0;R=s+12|0;O=r+16|0;t=s+16|0;Q=r+20|0;N=s+20|0;P=r+24|0;M=s+24|0;L=r+28|0;r=s+28|0;s=c[o>>2]|0;o=c[n>>2]|0;n=d+8|0;K=2363192+(A<<2)|0;G=c[q>>2]|0;q=c[p>>2]|0;p=0;while(1){F=p+1|0;if(Y){I=c[h>>2]|0;H=0;do{Z=a[s+(p*34|0)+H|0]|0;ha=(a[o+(p*34|0)+H|0]|0)+7+((c[n>>2]|0)*23|0)|0;ea=+g[m+(ha<<7)+(Z<<4)>>2];da=+g[m+(ha<<7)+(Z<<4)+4>>2];ca=+g[m+(ha<<7)+(Z<<4)+8>>2];_=+g[m+(ha<<7)+(Z<<4)+12>>2];do{if((c[v>>2]|0)==0){ia=ea;ja=da;ka=ca;la=_}else{if((H|0)>=(c[K>>2]|0)){ia=ea;ja=da;ka=ca;la=_;break}Z=d+87376+H|0;ha=(a[G+(p*34|0)+H|0]|0)+(a[Z]<<3)|0;ma=d+87410+H|0;na=(a[q+(p*34|0)+H|0]|0)+(a[ma]<<3)|0;oa=+g[4650528+(ha<<2)>>2];pa=+g[4652576+(ha<<2)>>2];qa=+g[4650528+(na<<2)>>2];ra=+g[4652576+(na<<2)>>2];a[Z]=ha&63;a[ma]=na&63;sa=oa*qa+pa*ra;ta=pa*qa-oa*ra;g[d+81664+(F*136|0)+(H<<2)>>2]=ea*pa;g[d+83296+(F*136|0)+(H<<2)>>2]=da*ta;g[d+84928+(F*136|0)+(H<<2)>>2]=ca*pa;g[d+86560+(F*136|0)+(H<<2)>>2]=_*ta;ia=ea*oa;ja=da*sa;ka=ca*oa;la=_*sa}}while(0);g[d+80848+(F*136|0)+(H<<2)>>2]=ia;g[d+82480+(F*136|0)+(H<<2)>>2]=ja;g[d+84112+(F*136|0)+(H<<2)>>2]=ka;g[d+85744+(F*136|0)+(H<<2)>>2]=la;H=H+1|0;}while((H|0)<(I|0));I=d+52+(p<<2)|0;H=d+52+(F<<2)|0;T=c[B>>2]|0;U=0;do{V=c[I>>2]|0;na=(c[H>>2]|0)-V|0;$=1.0/+(na|0);ma=a[J+U|0]|0;aa=+g[d+80848+(p*136|0)+(ma<<2)>>2];g[fa>>2]=aa;ba=+g[d+82480+(p*136|0)+(ma<<2)>>2];g[u>>2]=ba;_=+g[d+84112+(p*136|0)+(ma<<2)>>2];g[X>>2]=_;ca=+g[d+85744+(p*136|0)+(ma<<2)>>2];g[C>>2]=ca;ha=c[v>>2]|0;Z=(ha|0)==0;do{if(!Z){if(E){if((U-9|0)>>>0<5>>>0){ua=76}else{ua=77}}else{if((U|0)<2){ua=76}else{ua=77}}if((ua|0)==76){ua=0;g[O>>2]=-0.0- +g[d+81664+(p*136|0)+(ma<<2)>>2];g[Q>>2]=-0.0- +g[d+83296+(p*136|0)+(ma<<2)>>2];g[P>>2]=-0.0- +g[d+84928+(p*136|0)+(ma<<2)>>2];g[L>>2]=-0.0- +g[d+86560+(p*136|0)+(ma<<2)>>2];break}else if((ua|0)==77){ua=0;g[O>>2]=+g[d+81664+(p*136|0)+(ma<<2)>>2];g[Q>>2]=+g[d+83296+(p*136|0)+(ma<<2)>>2];g[P>>2]=+g[d+84928+(p*136|0)+(ma<<2)>>2];g[L>>2]=+g[d+86560+(p*136|0)+(ma<<2)>>2];break}}}while(0);g[k>>2]=$*(+g[d+80848+(F*136|0)+(ma<<2)>>2]-aa);g[l>>2]=$*(+g[d+82480+(F*136|0)+(ma<<2)>>2]-ba);g[S>>2]=$*(+g[d+84112+(F*136|0)+(ma<<2)>>2]-_);g[R>>2]=$*(+g[d+85744+(F*136|0)+(ma<<2)>>2]-ca);if(!Z){g[t>>2]=$*(+g[d+81664+(F*136|0)+(ma<<2)>>2]- +g[O>>2]);g[N>>2]=$*(+g[d+83296+(F*136|0)+(ma<<2)>>2]- +g[Q>>2]);g[M>>2]=$*(+g[d+84928+(F*136|0)+(ma<<2)>>2]- +g[P>>2]);g[r>>2]=$*(+g[d+86560+(F*136|0)+(ma<<2)>>2]- +g[L>>2])}va=V+1|0;le[c[d+87468+(((ha|0)!=0)<<2)>>2]&1023](w+(U<<8)+(va<<3)|0,x+(U<<8)+(va<<3)|0,ga,W,na);U=U+1|0;}while((U|0)<(T|0))}if((F|0)<(c[j>>2]|0)){p=F}else{break}}wpb(D,e,y,A);wpb(D,f,z,A);i=b;return 0}function wpb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0;if((e|0)==0){e=0;do{g[b+(e<<8)>>2]=+g[d+(e<<3)>>2]+ +g[d+256+(e<<3)>>2]+ +g[d+512+(e<<3)>>2]+ +g[d+768+(e<<3)>>2]+ +g[d+1024+(e<<3)>>2]+ +g[d+1280+(e<<3)>>2];g[b+9728+(e<<8)>>2]=+g[d+(e<<3)+4>>2]+ +g[d+256+(e<<3)+4>>2]+ +g[d+512+(e<<3)+4>>2]+ +g[d+768+(e<<3)+4>>2]+ +g[d+1024+(e<<3)+4>>2]+ +g[d+1280+(e<<3)+4>>2];g[b+(e<<8)+4>>2]=+g[d+1536+(e<<3)>>2]+ +g[d+1792+(e<<3)>>2];g[b+9728+(e<<8)+4>>2]=+g[d+1536+(e<<3)+4>>2]+ +g[d+1792+(e<<3)+4>>2];g[b+(e<<8)+8>>2]=+g[d+2048+(e<<3)>>2]+ +g[d+2304+(e<<3)>>2];g[b+9728+(e<<8)+8>>2]=+g[d+2048+(e<<3)+4>>2]+ +g[d+2304+(e<<3)+4>>2];e=e+1|0;}while((e|0)<32);cf[c[a+16>>2]&1023](b,d+1792|0,3,32);return}else{f=0}do{e=b+(f<<8)|0;TGb(e|0,0,20)|0;h=b+9728+(f<<8)|0;TGb(h|0,0,20)|0;i=e|0;e=h|0;h=0;j=0.0;k=0.0;do{j=+g[d+(h<<8)+(f<<3)>>2]+j;g[i>>2]=j;k=+g[d+(h<<8)+(f<<3)+4>>2]+k;g[e>>2]=k;h=h+1|0;}while((h|0)<12);h=b+(f<<8)+4|0;e=b+9728+(f<<8)+4|0;k=+g[d+3072+(f<<3)>>2]+ +g[h>>2];g[h>>2]=k;j=+g[d+3072+(f<<3)+4>>2]+ +g[e>>2];g[e>>2]=j;l=+g[d+3328+(f<<3)>>2]+k;g[h>>2]=l;k=+g[d+3328+(f<<3)+4>>2]+j;g[e>>2]=k;j=+g[d+3584+(f<<3)>>2]+l;g[h>>2]=j;l=+g[d+3584+(f<<3)+4>>2]+k;g[e>>2]=l;k=+g[d+3840+(f<<3)>>2]+j;g[h>>2]=k;j=+g[d+3840+(f<<3)+4>>2]+l;g[e>>2]=j;l=+g[d+4096+(f<<3)>>2]+k;g[h>>2]=l;k=+g[d+4096+(f<<3)+4>>2]+j;g[e>>2]=k;j=+g[d+4352+(f<<3)>>2]+l;g[h>>2]=j;l=+g[d+4352+(f<<3)+4>>2]+k;g[e>>2]=l;k=+g[d+4608+(f<<3)>>2]+j;g[h>>2]=k;j=+g[d+4608+(f<<3)+4>>2]+l;g[e>>2]=j;g[h>>2]=+g[d+4864+(f<<3)>>2]+k;g[e>>2]=+g[d+4864+(f<<3)+4>>2]+j;e=b+(f<<8)+8|0;h=b+9728+(f<<8)+8|0;i=b+(f<<8)+12|0;m=b+9728+(f<<8)+12|0;n=b+(f<<8)+16|0;o=b+9728+(f<<8)+16|0;j=+g[d+5120+(f<<3)>>2]+ +g[e>>2];g[e>>2]=j;k=+g[d+5120+(f<<3)+4>>2]+ +g[h>>2];g[h>>2]=k;l=+g[d+6144+(f<<3)>>2]+ +g[i>>2];g[i>>2]=l;p=+g[d+6144+(f<<3)+4>>2]+ +g[m>>2];g[m>>2]=p;q=+g[d+7168+(f<<3)>>2]+ +g[n>>2];g[n>>2]=q;r=+g[d+7168+(f<<3)+4>>2]+ +g[o>>2];g[o>>2]=r;s=+g[d+5376+(f<<3)>>2]+j;g[e>>2]=s;j=+g[d+5376+(f<<3)+4>>2]+k;g[h>>2]=j;k=+g[d+6400+(f<<3)>>2]+l;g[i>>2]=k;l=+g[d+6400+(f<<3)+4>>2]+p;g[m>>2]=l;p=+g[d+7424+(f<<3)>>2]+q;g[n>>2]=p;q=+g[d+7424+(f<<3)+4>>2]+r;g[o>>2]=q;r=+g[d+5632+(f<<3)>>2]+s;g[e>>2]=r;s=+g[d+5632+(f<<3)+4>>2]+j;g[h>>2]=s;j=+g[d+6656+(f<<3)>>2]+k;g[i>>2]=j;k=+g[d+6656+(f<<3)+4>>2]+l;g[m>>2]=k;l=+g[d+7680+(f<<3)>>2]+p;g[n>>2]=l;p=+g[d+7680+(f<<3)+4>>2]+q;g[o>>2]=p;g[e>>2]=+g[d+5888+(f<<3)>>2]+r;g[h>>2]=+g[d+5888+(f<<3)+4>>2]+s;g[i>>2]=+g[d+6912+(f<<3)>>2]+j;g[m>>2]=+g[d+6912+(f<<3)+4>>2]+k;g[n>>2]=+g[d+7936+(f<<3)>>2]+l;g[o>>2]=+g[d+7936+(f<<3)+4>>2]+p;f=f+1|0;}while((f|0)<32);cf[c[a+16>>2]&1023](b,d+6912|0,5,32);return}function xpb(){var b=0,d=0.0,e=0.0,f=0,h=0,i=0.0,j=0.0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0,A=0.0,B=0,C=0,D=0;c[646477]=5752928;c[646479]=1544;N_(2585904,9,61,920712,1,1,920464,4,4,0,0,0,4)|0;c[646482]=5739232;c[646484]=832;N_(2585924,9,61,920248,1,1,920120,2,2,0,0,0,4)|0;c[646487]=5735136;c[646489]=1024;N_(2585944,9,29,920896,1,1,920776,4,4,0,0,0,4)|0;c[646492]=5730992;c[646494]=1036;N_(2585964,9,29,920432,1,1,920312,4,4,0,0,0,4)|0;c[646497]=5728816;c[646499]=544;N_(2585984,9,15,921024,1,1,920992,2,2,0,0,0,4)|0;c[646502]=5750752;c[646504]=544;N_(2586004,9,15,920976,1,1,920944,2,2,0,0,0,4)|0;c[646507]=5748704;c[646509]=512;N_(2586024,9,8,920112,1,1,920104,1,1,0,0,0,4)|0;c[646512]=5746656;c[646514]=512;N_(2586044,9,8,920096,1,1,920088,1,1,0,0,0,4)|0;c[646517]=5744608;c[646519]=512;N_(2586064,9,8,920064,1,1,920056,1,1,0,0,0,4)|0;c[646522]=5742560;c[646524]=512;N_(2586084,9,8,920048,1,1,920040,1,1,0,0,0,4)|0;b=0;while(1){d=+g[560656+(b<<2)>>2]*.25;e=+g[560624+(b<<2)>>2]*.25;f=b<<6;h=0;do{i=d+ +g[560656+(h<<2)>>2]*.5;j=e+ +g[560624+(h<<2)>>2]*.5;k=(h<<3)+f|0;l=0;do{m=i+ +g[560656+(l<<2)>>2];n=j+ +g[560624+(l<<2)>>2];o=1.0/+R(m*m+n*n);p=k+l|0;g[4650528+(p<<2)>>2]=m*o;g[4652576+(p<<2)>>2]=n*o;l=l+1|0;}while((l|0)<8);h=h+1|0;}while((h|0)<8);h=b+1|0;if((h|0)<8){b=h}else{q=0;break}}while(1){e=+g[560688+(q<<2)>>2];d=e*e;j=1.4142135381698608/+R(d+1.0);i=e*j;o=j-i;n=e*2.0;m=d+-1.0;d=e+1.0/e;e=d*d;b=0;do{d=+g[560952+(b<<2)>>2]*.5;r=o*d*.7071067690849304;s=d+r;g[9212424+(q<<7)+(b<<4)>>2]=i*+T(s);t=r-d;g[9212424+(q<<7)+(b<<4)+4>>2]=j*+T(t);g[9212424+(q<<7)+(b<<4)+8>>2]=i*+U(s);g[9212424+(q<<7)+(b<<4)+12>>2]=j*+U(t);if(b>>>0<5>>>0){u=+g[560872+(b<<2)>>2]}else{u=.05000000074505806}t=+Z(+(n*u),+m)*.5;s=+R((u*u*4.0+-4.0)/e+1.0);d=+Y(+R((1.0-s)/(s+1.0)));if(t<0.0){v=t+1.5707963267948966}else{v=t}t=+U(v);s=+U(d);r=+T(v)*1.4142135623730951;w=+T(d);g[9206536+(q<<7)+(b<<4)>>2]=r*w;d=t;g[9206536+(q<<7)+(b<<4)+4>>2]=d*1.4142135623730951*w;w=s;g[9206536+(q<<7)+(b<<4)+8>>2]=d*-1.4142135623730951*w;g[9206536+(q<<7)+(b<<4)+12>>2]=r*w;b=b+1|0;}while((b|0)<8);b=q+1|0;if((b|0)<46){q=b}else{x=0;break}}while(1){if(x>>>0<10>>>0){y=+(a[560936+x|0]|0)*.125}else{y=+(x|0)+ -6.5}v=y*-1.3508848635140327;g[9204136+(x*24|0)>>2]=+T(v);g[9204140+(x*24|0)>>2]=+U(v);v=y*-2.356194490192345;g[9204144+(x*24|0)>>2]=+T(v);g[9204148+(x*24|0)>>2]=+U(v);v=y*-1.0901326597838268;g[9204152+(x*24|0)>>2]=+T(v);g[9204156+(x*24|0)>>2]=+U(v);v=y*-1.225221089959176;g[4649728+(x<<3)>>2]=+T(v);g[4649732+(x<<3)>>2]=+U(v);q=x+1|0;if((q|0)<30){x=q}else{z=0;break}}while(1){if(z>>>0<32>>>0){A=+(a[560904+z|0]|0)/24.0}else{A=+(z|0)+ -26.5}y=A*-1.3508848635140327;g[9205336+(z*24|0)>>2]=+T(y);g[9205340+(z*24|0)>>2]=+U(y);y=A*-2.356194490192345;g[9205344+(z*24|0)>>2]=+T(y);g[9205348+(z*24|0)>>2]=+U(y);y=A*-1.0901326597838268;g[9205352+(z*24|0)>>2]=+T(y);g[9205356+(z*24|0)>>2]=+U(y);y=A*-1.225221089959176;g[4650128+(z<<3)>>2]=+T(y);g[4650132+(z<<3)>>2]=+U(y);x=z+1|0;if((x|0)<50){z=x}else{B=0;break}}while(1){A=(+(B|0)+.5)*6.283185307179586;y=A*-6.0*.125;g[8018864+(B<<6)>>2]=+T(y)*.007460829336196184;g[8018868+(B<<6)>>2]=+U(y)*-.007460829336196184;y=A*-5.0*.125;g[8018872+(B<<6)>>2]=+T(y)*.02270421013236046;g[8018876+(B<<6)>>2]=+U(y)*-.02270421013236046;y=A*-4.0*.125;g[8018880+(B<<6)>>2]=+T(y)*.045468658208847046;g[8018884+(B<<6)>>2]=+U(y)*-.045468658208847046;y=A*-3.0*.125;g[8018888+(B<<6)>>2]=+T(y)*.0726611390709877;g[8018892+(B<<6)>>2]=+U(y)*-.0726611390709877;y=A*-2.0*.125;g[8018896+(B<<6)>>2]=+T(y)*.09885108470916748;g[8018900+(B<<6)>>2]=+U(y)*-.09885108470916748;y=A*-1.0*.125;g[8018904+(B<<6)>>2]=+T(y)*.1179371029138565;g[8018908+(B<<6)>>2]=+U(y)*-.1179371029138565;y=A*0.0*.125;g[8018912+(B<<6)>>2]=+T(y)*.125;g[8018916+(B<<6)>>2]=+U(y)*-.125;z=B+1|0;if((z|0)<8){B=z}else{C=0;break}}while(1){y=(+(C|0)+.5)*6.283185307179586;A=y*-6.0/12.0;g[8018096+(C<<6)>>2]=+T(A)*.040811799466609955;g[8018100+(C<<6)>>2]=+U(A)*-.040811799466609955;A=y*-5.0/12.0;g[8018104+(C<<6)>>2]=+T(A)*.03812811151146889;g[8018108+(C<<6)>>2]=+U(A)*-.03812811151146889;A=y*-4.0/12.0;g[8018112+(C<<6)>>2]=+T(A)*.05144908279180527;g[8018116+(C<<6)>>2]=+U(A)*-.05144908279180527;A=y*-3.0/12.0;g[8018120+(C<<6)>>2]=+T(A)*.06399831175804138;g[8018124+(C<<6)>>2]=+U(A)*-.06399831175804138;A=y*-2.0/12.0;g[8018128+(C<<6)>>2]=+T(A)*.07428313791751862;g[8018132+(C<<6)>>2]=+U(A)*-.07428313791751862;A=y*-1.0/12.0;g[8018136+(C<<6)>>2]=+T(A)*.08100347965955734;g[8018140+(C<<6)>>2]=+U(A)*-.08100347965955734;A=y*0.0/12.0;g[8018144+(C<<6)>>2]=+T(A)*.0833333358168602;g[8018148+(C<<6)>>2]=+U(A)*-.0833333358168602;B=C+1|0;if((B|0)<12){C=B}else{D=0;break}}do{A=(+(D|0)+.5)*6.283185307179586;y=A*-6.0*.125;g[8017584+(D<<6)>>2]=+T(y)*.01565675623714924;g[8017588+(D<<6)>>2]=+U(y)*-.01565675623714924;y=A*-5.0*.125;g[8017592+(D<<6)>>2]=+T(y)*.037527162581682205;g[8017596+(D<<6)>>2]=+U(y)*-.037527162581682205;y=A*-4.0*.125;g[8017600+(D<<6)>>2]=+T(y)*.054178912192583084;g[8017604+(D<<6)>>2]=+U(y)*-.054178912192583084;y=A*-3.0*.125;g[8017608+(D<<6)>>2]=+T(y)*.08417043834924698;g[8017612+(D<<6)>>2]=+U(y)*-.08417043834924698;y=A*-2.0*.125;g[8017616+(D<<6)>>2]=+T(y)*.10307344049215317;g[8017620+(D<<6)>>2]=+U(y)*-.10307344049215317;y=A*-1.0*.125;g[8017624+(D<<6)>>2]=+T(y)*.12222452461719513;g[8017628+(D<<6)>>2]=+U(y)*-.12222452461719513;y=A*0.0*.125;g[8017632+(D<<6)>>2]=+T(y)*.125;g[8017636+(D<<6)>>2]=+U(y)*-.125;D=D+1|0;}while((D|0)<8);g[2004332]=1.0853208515459211e-17;g[2004333]=.059082113206386566;g[2004334]=.03444669395685196;g[2004335]=.03444669395685196;g[2004336]=-0.0;g[2004337]=0.0;g[2004338]=-.05500388517975807;g[2004339]=.05500388517975807;g[2004340]=1.0094949418724715e-17;g[2004341]=.16486303508281708;g[2004342]=.16461344063282013;g[2004343]=.16461344063282013;g[2004344]=.25;g[2004345]=-0.0;g[2004348]=-3.2559625546377634e-17;g[2004349]=-.059082113206386566;g[2004350]=-.03444669395685196;g[2004351]=.03444669395685196;g[2004352]=-0.0;g[2004353]=0.0;g[2004354]=.05500388517975807;g[2004355]=.05500388517975807;g[2004356]=-3.0284849083354756e-17;g[2004357]=-.16486303508281708;g[2004358]=-.16461344063282013;g[2004359]=.16461344063282013;g[2004360]=.25;g[2004361]=-0.0;g[2004364]=1.5921695514895825e-16;g[2004365]=.059082113206386566;g[2004366]=-.03444669395685196;g[2004367]=-.03444669395685196;g[2004368]=-0.0;g[2004369]=0.0;g[2004370]=.05500388517975807;g[2004371]=-.05500388517975807;g[2004372]=5.047474626644296e-17;g[2004373]=.16486303508281708;g[2004374]=-.16461344063282013;g[2004375]=-.16461344063282013;g[2004376]=.25;g[2004377]=-0.0;g[2004380]=2.897845958089261e-17;g[2004381]=-.059082113206386566;g[2004382]=.03444669395685196;g[2004383]=-.03444669395685196;g[2004384]=-0.0;g[2004385]=0.0;g[2004386]=-.05500388517975807;g[2004387]=-.05500388517975807;g[2004388]=-7.066464344953116e-17;g[2004389]=-.16486303508281708;g[2004390]=.16461344063282013;g[2004391]=-.16461344063282013;g[2004392]=.25;g[2004393]=-0.0;return}function ypb(a){a=a|0;Dpb(a+87444|0);return}function zpb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;h=c[b>>2]|0;if((e|0)==10|(e|0)==5){if((f|0)<=0){return}if((g|0)==0){i=0;do{j=d+(i*34|0)|0;a[h+(i*34|0)+16|0]=0;k=d+(i*34|0)+4|0;a[h+(i*34|0)+15|0]=a[k]|0;a[h+(i*34|0)+14|0]=a[k]|0;a[h+(i*34|0)+13|0]=a[k]|0;a[h+(i*34|0)+12|0]=a[k]|0;k=d+(i*34|0)+3|0;a[h+(i*34|0)+11|0]=a[k]|0;a[h+(i*34|0)+10|0]=a[k]|0;k=d+(i*34|0)+2|0;a[h+(i*34|0)+9|0]=a[k]|0;a[h+(i*34|0)+8|0]=a[k]|0;a[h+(i*34|0)+7|0]=a[k]|0;a[h+(i*34|0)+6|0]=a[k]|0;k=d+(i*34|0)+1|0;a[h+(i*34|0)+5|0]=a[k]|0;a[h+(i*34|0)+4|0]=a[k]|0;a[h+(i*34|0)+3|0]=a[k]|0;a[h+(i*34|0)+2|0]=a[j]|0;a[h+(i*34|0)+1|0]=a[j]|0;a[h+(i*34|0)|0]=a[j]|0;i=i+1|0;}while((i|0)<(f|0));return}else{i=0;do{j=d+(i*34|0)|0;k=d+(i*34|0)+9|0;a[h+(i*34|0)+33|0]=a[k]|0;a[h+(i*34|0)+32|0]=a[k]|0;a[h+(i*34|0)+31|0]=a[k]|0;a[h+(i*34|0)+30|0]=a[k]|0;a[h+(i*34|0)+29|0]=a[k]|0;a[h+(i*34|0)+28|0]=a[k]|0;k=d+(i*34|0)+8|0;a[h+(i*34|0)+27|0]=a[k]|0;a[h+(i*34|0)+26|0]=a[k]|0;a[h+(i*34|0)+25|0]=a[k]|0;a[h+(i*34|0)+24|0]=a[k]|0;k=d+(i*34|0)+7|0;a[h+(i*34|0)+23|0]=a[k]|0;a[h+(i*34|0)+22|0]=a[k]|0;a[h+(i*34|0)+21|0]=a[k]|0;a[h+(i*34|0)+20|0]=a[k]|0;k=d+(i*34|0)+6|0;a[h+(i*34|0)+19|0]=a[k]|0;a[h+(i*34|0)+18|0]=a[k]|0;k=d+(i*34|0)+5|0;a[h+(i*34|0)+17|0]=a[k]|0;a[h+(i*34|0)+16|0]=a[k]|0;k=d+(i*34|0)+4|0;a[h+(i*34|0)+15|0]=a[k]|0;a[h+(i*34|0)+14|0]=a[k]|0;a[h+(i*34|0)+13|0]=a[k]|0;a[h+(i*34|0)+12|0]=a[k]|0;k=d+(i*34|0)+3|0;a[h+(i*34|0)+11|0]=a[k]|0;a[h+(i*34|0)+10|0]=a[k]|0;k=d+(i*34|0)+2|0;a[h+(i*34|0)+9|0]=a[k]|0;a[h+(i*34|0)+8|0]=a[k]|0;a[h+(i*34|0)+7|0]=a[k]|0;a[h+(i*34|0)+6|0]=a[k]|0;k=d+(i*34|0)+1|0;a[h+(i*34|0)+5|0]=a[k]|0;a[h+(i*34|0)+4|0]=a[k]|0;a[h+(i*34|0)+3|0]=a[k]|0;a[h+(i*34|0)+2|0]=a[j]|0;a[h+(i*34|0)+1|0]=a[j]|0;a[h+(i*34|0)|0]=a[j]|0;i=i+1|0;}while((i|0)<(f|0));return}}else if((e|0)==20|(e|0)==11){if((f|0)<=0){return}if((g|0)==0){g=0;do{e=d+(g*34|0)|0;a[h+(g*34|0)+16|0]=a[d+(g*34|0)+10|0]|0;i=d+(g*34|0)+9|0;a[h+(g*34|0)+15|0]=a[i]|0;a[h+(g*34|0)+14|0]=a[i]|0;i=d+(g*34|0)+8|0;a[h+(g*34|0)+13|0]=a[i]|0;a[h+(g*34|0)+12|0]=a[i]|0;a[h+(g*34|0)+11|0]=a[d+(g*34|0)+7|0]|0;a[h+(g*34|0)+10|0]=a[d+(g*34|0)+6|0]|0;i=d+(g*34|0)+5|0;a[h+(g*34|0)+9|0]=a[i]|0;a[h+(g*34|0)+8|0]=a[i]|0;i=d+(g*34|0)+4|0;a[h+(g*34|0)+7|0]=a[i]|0;a[h+(g*34|0)+6|0]=a[i]|0;i=d+(g*34|0)+3|0;a[h+(g*34|0)+5|0]=a[i]|0;j=d+(g*34|0)+2|0;a[h+(g*34|0)+4|0]=((a[i]|0)+(a[j]|0)|0)/2|0;a[h+(g*34|0)+3|0]=a[j]|0;j=d+(g*34|0)+1|0;a[h+(g*34|0)+2|0]=a[j]|0;a[h+(g*34|0)+1|0]=((a[j]|0)+(a[e]|0)|0)/2|0;a[h+(g*34|0)|0]=a[e]|0;g=g+1|0;}while((g|0)<(f|0));return}else{g=0;do{e=d+(g*34|0)|0;j=d+(g*34|0)+19|0;a[h+(g*34|0)+33|0]=a[j]|0;a[h+(g*34|0)+32|0]=a[j]|0;j=d+(g*34|0)+18|0;a[h+(g*34|0)+31|0]=a[j]|0;a[h+(g*34|0)+30|0]=a[j]|0;a[h+(g*34|0)+29|0]=a[j]|0;a[h+(g*34|0)+28|0]=a[j]|0;j=d+(g*34|0)+17|0;a[h+(g*34|0)+27|0]=a[j]|0;a[h+(g*34|0)+26|0]=a[j]|0;j=d+(g*34|0)+16|0;a[h+(g*34|0)+25|0]=a[j]|0;a[h+(g*34|0)+24|0]=a[j]|0;j=d+(g*34|0)+15|0;a[h+(g*34|0)+23|0]=a[j]|0;a[h+(g*34|0)+22|0]=a[j]|0;j=d+(g*34|0)+14|0;a[h+(g*34|0)+21|0]=a[j]|0;a[h+(g*34|0)+20|0]=a[j]|0;a[h+(g*34|0)+19|0]=a[d+(g*34|0)+13|0]|0;a[h+(g*34|0)+18|0]=a[d+(g*34|0)+12|0]|0;a[h+(g*34|0)+17|0]=a[d+(g*34|0)+11|0]|0;a[h+(g*34|0)+16|0]=a[d+(g*34|0)+10|0]|0;j=d+(g*34|0)+9|0;a[h+(g*34|0)+15|0]=a[j]|0;a[h+(g*34|0)+14|0]=a[j]|0;j=d+(g*34|0)+8|0;a[h+(g*34|0)+13|0]=a[j]|0;a[h+(g*34|0)+12|0]=a[j]|0;a[h+(g*34|0)+11|0]=a[d+(g*34|0)+7|0]|0;a[h+(g*34|0)+10|0]=a[d+(g*34|0)+6|0]|0;j=d+(g*34|0)+5|0;a[h+(g*34|0)+9|0]=a[j]|0;a[h+(g*34|0)+8|0]=a[j]|0;j=d+(g*34|0)+4|0;a[h+(g*34|0)+7|0]=a[j]|0;a[h+(g*34|0)+6|0]=a[j]|0;j=d+(g*34|0)+3|0;a[h+(g*34|0)+5|0]=a[j]|0;i=d+(g*34|0)+2|0;a[h+(g*34|0)+4|0]=((a[j]|0)+(a[i]|0)|0)/2|0;a[h+(g*34|0)+3|0]=a[i]|0;i=d+(g*34|0)+1|0;a[h+(g*34|0)+2|0]=a[i]|0;a[h+(g*34|0)+1|0]=((a[i]|0)+(a[e]|0)|0)/2|0;a[h+(g*34|0)|0]=a[e]|0;g=g+1|0;}while((g|0)<(f|0));return}}else{c[b>>2]=d;return}}function Apb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c[b>>2]|0;if((e|0)==10|(e|0)==5){if((f|0)<=0){return}if((g|0)==0){i=0;do{a[h+(i*34|0)+10|0]=0;j=4;while(1){k=a[d+(i*34|0)+j|0]|0;l=j<<1;a[h+(i*34|0)+l|0]=k;a[(l|1)+(h+(i*34|0))|0]=k;if((j|0)>0){j=j-1|0}else{break}}i=i+1|0;}while((i|0)<(f|0));return}else{i=0;do{j=9;while(1){k=a[d+(i*34|0)+j|0]|0;l=j<<1;a[h+(i*34|0)+l|0]=k;a[(l|1)+(h+(i*34|0))|0]=k;if((j|0)>0){j=j-1|0}else{break}}i=i+1|0;}while((i|0)<(f|0));return}}else if((e|0)==34|(e|0)==17){if((f|0)<=0){return}if((g|0)==0){g=0;do{e=d+(g*34|0)+1|0;a[h+(g*34|0)|0]=((a[d+(g*34|0)|0]<<1)+(a[e]|0)|0)/3|0;a[h+(g*34|0)+1|0]=((a[d+(g*34|0)+2|0]<<1)+(a[e]|0)|0)/3|0;e=d+(g*34|0)+4|0;a[h+(g*34|0)+2|0]=((a[d+(g*34|0)+3|0]<<1)+(a[e]|0)|0)/3|0;a[h+(g*34|0)+3|0]=((a[d+(g*34|0)+5|0]<<1)+(a[e]|0)|0)/3|0;a[h+(g*34|0)+4|0]=((a[d+(g*34|0)+7|0]|0)+(a[d+(g*34|0)+6|0]|0)|0)/2|0;a[h+(g*34|0)+5|0]=((a[d+(g*34|0)+9|0]|0)+(a[d+(g*34|0)+8|0]|0)|0)/2|0;a[h+(g*34|0)+6|0]=a[d+(g*34|0)+10|0]|0;a[h+(g*34|0)+7|0]=a[d+(g*34|0)+11|0]|0;a[h+(g*34|0)+8|0]=((a[d+(g*34|0)+13|0]|0)+(a[d+(g*34|0)+12|0]|0)|0)/2|0;a[h+(g*34|0)+9|0]=((a[d+(g*34|0)+15|0]|0)+(a[d+(g*34|0)+14|0]|0)|0)/2|0;a[h+(g*34|0)+10|0]=a[d+(g*34|0)+16|0]|0;g=g+1|0;}while((g|0)<(f|0));return}else{g=0;do{e=d+(g*34|0)+1|0;a[h+(g*34|0)|0]=((a[d+(g*34|0)|0]<<1)+(a[e]|0)|0)/3|0;a[h+(g*34|0)+1|0]=((a[d+(g*34|0)+2|0]<<1)+(a[e]|0)|0)/3|0;e=d+(g*34|0)+4|0;a[h+(g*34|0)+2|0]=((a[d+(g*34|0)+3|0]<<1)+(a[e]|0)|0)/3|0;a[h+(g*34|0)+3|0]=((a[d+(g*34|0)+5|0]<<1)+(a[e]|0)|0)/3|0;a[h+(g*34|0)+4|0]=((a[d+(g*34|0)+7|0]|0)+(a[d+(g*34|0)+6|0]|0)|0)/2|0;a[h+(g*34|0)+5|0]=((a[d+(g*34|0)+9|0]|0)+(a[d+(g*34|0)+8|0]|0)|0)/2|0;a[h+(g*34|0)+6|0]=a[d+(g*34|0)+10|0]|0;a[h+(g*34|0)+7|0]=a[d+(g*34|0)+11|0]|0;a[h+(g*34|0)+8|0]=((a[d+(g*34|0)+13|0]|0)+(a[d+(g*34|0)+12|0]|0)|0)/2|0;a[h+(g*34|0)+9|0]=((a[d+(g*34|0)+15|0]|0)+(a[d+(g*34|0)+14|0]|0)|0)/2|0;a[h+(g*34|0)+10|0]=a[d+(g*34|0)+16|0]|0;a[h+(g*34|0)+11|0]=a[d+(g*34|0)+17|0]|0;a[h+(g*34|0)+12|0]=a[d+(g*34|0)+18|0]|0;a[h+(g*34|0)+13|0]=a[d+(g*34|0)+19|0]|0;a[h+(g*34|0)+14|0]=((a[d+(g*34|0)+21|0]|0)+(a[d+(g*34|0)+20|0]|0)|0)/2|0;a[h+(g*34|0)+15|0]=((a[d+(g*34|0)+23|0]|0)+(a[d+(g*34|0)+22|0]|0)|0)/2|0;a[h+(g*34|0)+16|0]=((a[d+(g*34|0)+25|0]|0)+(a[d+(g*34|0)+24|0]|0)|0)/2|0;a[h+(g*34|0)+17|0]=((a[d+(g*34|0)+27|0]|0)+(a[d+(g*34|0)+26|0]|0)|0)/2|0;a[h+(g*34|0)+18|0]=((a[d+(g*34|0)+29|0]|0)+(a[d+(g*34|0)+28|0]|0)+(a[d+(g*34|0)+30|0]|0)+(a[d+(g*34|0)+31|0]|0)|0)/4|0;a[h+(g*34|0)+19|0]=((a[d+(g*34|0)+33|0]|0)+(a[d+(g*34|0)+32|0]|0)|0)/2|0;g=g+1|0;}while((g|0)<(f|0));return}}else{c[b>>2]=d;return}}function Bpb(a){a=a|0;var b=0,c=0.0,d=0,e=0,f=0,h=0,i=0,j=0;b=a+4|0;c=+g[b>>2];g[a>>2]=(+g[a>>2]*2.0+c)*.3333333432674408;d=a+8|0;g[b>>2]=(c+ +g[d>>2]*2.0)*.3333333432674408;b=a+12|0;e=a+16|0;c=+g[e>>2];g[d>>2]=(+g[b>>2]*2.0+c)*.3333333432674408;d=a+20|0;g[b>>2]=(c+ +g[d>>2]*2.0)*.3333333432674408;b=a+24|0;f=a+28|0;g[e>>2]=(+g[b>>2]+ +g[f>>2])*.5;e=a+32|0;h=a+36|0;g[d>>2]=(+g[e>>2]+ +g[h>>2])*.5;d=a+40|0;g[b>>2]=+g[d>>2];b=a+44|0;g[f>>2]=+g[b>>2];f=a+48|0;i=a+52|0;g[e>>2]=(+g[f>>2]+ +g[i>>2])*.5;e=a+56|0;j=a+60|0;g[h>>2]=(+g[e>>2]+ +g[j>>2])*.5;h=a+64|0;g[d>>2]=+g[h>>2];d=a+68|0;g[b>>2]=+g[d>>2];b=a+72|0;g[f>>2]=+g[b>>2];f=a+76|0;g[i>>2]=+g[f>>2];g[e>>2]=(+g[a+80>>2]+ +g[a+84>>2])*.5;g[j>>2]=(+g[a+88>>2]+ +g[a+92>>2])*.5;g[h>>2]=(+g[a+96>>2]+ +g[a+100>>2])*.5;g[d>>2]=(+g[a+104>>2]+ +g[a+108>>2])*.5;g[b>>2]=(+g[a+112>>2]+ +g[a+116>>2]+ +g[a+120>>2]+ +g[a+124>>2])*.25;g[f>>2]=(+g[a+128>>2]+ +g[a+132>>2])*.5;return}function Cpb(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=c[f+16>>2]|0;l=c[2585908+(h*20|0)>>2]|0;if((j|0)==0){if((k|0)<=0){return}j=e+8|0;h=e+16|0;m=e|0;n=0;o=0;do{p=c[j>>2]|0;q=c[h>>2]|0;r=c[m>>2]|0;s=r+(p>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(p&7)>>>23;s=b[l+(t<<2)>>1]|0;u=b[l+(t<<2)+2>>1]|0;t=u<<16>>16;do{if(u<<16>>16<0){v=p+9|0;w=q>>>0>v>>>0?v:q;v=r+(w>>>3)|0;x=((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(w&7)>>>((t+32|0)>>>0))+s|0;v=b[l+(x<<2)>>1]|0;y=b[l+(x<<2)+2>>1]|0;x=y<<16>>16;if(!(y<<16>>16<0)){z=x;A=v;B=w;break}y=w-t|0;w=q>>>0>y>>>0?y:q;y=r+(w>>>3)|0;C=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>((x+32|0)>>>0))+v|0;z=b[l+(C<<2)+2>>1]|0;A=b[l+(C<<2)>>1]|0;B=w}else{z=t;A=s;B=p}}while(0);p=z+B|0;c[j>>2]=q>>>0>p>>>0?p:q;o=A+o&7;a[g+(i*34|0)+n|0]=o;n=n+1|0;}while((n|0)<(k|0));return}if((i|0)==0){D=c[f+40>>2]|0}else{D=i}f=D-1|0;D=(f|0)>0?f:0;if((k|0)<=0){return}f=e+8|0;n=e+16|0;o=e|0;e=0;do{A=d[g+(D*34|0)+e|0]|0;j=c[f>>2]|0;B=c[n>>2]|0;z=c[o>>2]|0;m=z+(j>>>3)|0;h=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>23;m=b[l+(h<<2)>>1]|0;p=b[l+(h<<2)+2>>1]|0;h=p<<16>>16;do{if(p<<16>>16<0){s=j+9|0;t=B>>>0>s>>>0?s:B;s=z+(t>>>3)|0;r=((fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(t&7)>>>((h+32|0)>>>0))+m|0;s=b[l+(r<<2)>>1]|0;u=b[l+(r<<2)+2>>1]|0;r=u<<16>>16;if(!(u<<16>>16<0)){E=r;F=s;G=t;break}u=t-h|0;t=B>>>0>u>>>0?u:B;u=z+(t>>>3)|0;w=((fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7)>>>((r+32|0)>>>0))+s|0;E=b[l+(w<<2)+2>>1]|0;F=b[l+(w<<2)>>1]|0;G=t}else{E=h;F=m;G=j}}while(0);j=E+G|0;c[f>>2]=B>>>0>j>>>0?j:B;a[g+(i*34|0)+e|0]=F+A&7;e=e+1|0;}while((e|0)<(k|0));return}function Dpb(a){a=a|0;c[a>>2]=1406;c[a+4>>2]=246;c[a+8>>2]=268;c[a+12>>2]=524;c[a+16>>2]=128;c[a+20>>2]=2;c[a+24>>2]=212;c[a+28>>2]=440;return}function Epb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0.0,f=0.0,h=0;if((c|0)>0){d=0}else{return}do{e=+g[b+(d<<3)>>2];f=+g[b+(d<<3)+4>>2];h=a+(d<<2)|0;g[h>>2]=+g[h>>2]+(e*e+f*f);d=d+1|0;}while((d|0)<(c|0));return}function Fpb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if((d|0)>0){e=0}else{return}do{f=c+(e<<2)|0;g[a+(e<<3)>>2]=+g[b+(e<<3)>>2]*+g[f>>2];g[a+(e<<3)+4>>2]=+g[b+(e<<3)+4>>2]*+g[f>>2];e=e+1|0;}while((e|0)<(d|0));return}function Gpb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0.0;if((e|0)<=0){return}f=b+48|0;h=b+52|0;i=0;do{j=+g[c+(i<<6)+48>>2];k=j*+g[h>>2];l=j*+g[f>>2];m=0;do{j=+g[b+(m<<3)>>2];n=+g[b+(m<<3)+4>>2];o=12-m|0;p=+g[b+(o<<3)>>2];q=+g[b+(o<<3)+4>>2];r=+g[c+(i<<6)+(m<<3)>>2];s=+g[c+(i<<6)+(m<<3)+4>>2];l=l+((j+p)*r-(n-q)*s);k=k+(r*(n+q)+(j-p)*s);m=m+1|0;}while((m|0)<6);m=ba(i,d)|0;g[a+(m<<3)>>2]=l;g[a+(m<<3)+4>>2]=k;i=i+1|0;}while((i|0)<(e|0));return}function Hpb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((c|0)<64&(d|0)>0){e=c}else{return}do{c=0;do{g[a+(e<<8)+(c<<3)>>2]=+g[b+(c<<8)+(e<<2)>>2];g[a+(e<<8)+(c<<3)+4>>2]=+g[b+9728+(c<<8)+(e<<2)>>2];c=c+1|0;}while((c|0)<(d|0));e=e+1|0;}while((e|0)<64);return}function Ipb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((c|0)<64&(d|0)>0){e=c}else{return}do{c=0;do{g[a+(c<<8)+(e<<2)>>2]=+g[b+(e<<8)+(c<<3)>>2];g[a+9728+(c<<8)+(e<<2)>>2]=+g[b+(e<<8)+(c<<3)+4>>2];c=c+1|0;}while((c|0)<(d|0));e=e+1|0;}while((e|0)<64);return}function Jpb(a,b,c,d,e,f,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=+h;i=i|0;var j=0.0,k=0.0,l=0.0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0,u=0,v=0.0,w=0.0;j=h*.6514390707015991;k=h*.5647181272506714;l=h*.4895416498184204;if((i|0)<=0){return}m=d+4|0;n=0;do{h=+g[b+(n<<3)>>2];o=+g[d>>2];p=+g[b+(n<<3)+4>>2];q=+g[m>>2];r=h*o-p*q;s=o*p+h*q;t=n+2|0;u=n+5|0;q=+g[c+(t<<3)>>2];h=+g[c+(t<<3)+4>>2];p=+g[e>>2];o=+g[e+4>>2];v=q*p-h*o-r*j;w=h*p+q*o-s*j;g[c+(u<<3)>>2]=r+j*v;g[c+(u<<3)+4>>2]=s+j*w;t=n+1|0;s=+g[c+296+(t<<3)>>2];r=+g[c+296+(t<<3)+4>>2];o=+g[e+8>>2];q=+g[e+12>>2];p=s*o-r*q-v*k;h=r*o+s*q-w*k;g[c+296+(u<<3)>>2]=v+k*p;g[c+296+(u<<3)+4>>2]=w+k*h;w=+g[c+592+(n<<3)>>2];v=+g[c+592+(n<<3)+4>>2];q=+g[e+16>>2];s=+g[e+20>>2];o=w*q-v*s-p*l;r=v*q+w*s-h*l;g[c+592+(u<<3)>>2]=p+l*o;g[c+592+(u<<3)+4>>2]=h+l*r;u=f+(n<<2)|0;g[a+(n<<3)>>2]=o*+g[u>>2];g[a+(n<<3)+4>>2]=r*+g[u>>2];n=n+1|0;}while((n|0)<(i|0));return}function Kpb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0.0,r=0,s=0.0,t=0,u=0.0;f=+g[d>>2];h=+g[d+4>>2];i=+g[d+8>>2];j=+g[d+12>>2];if((e|0)<=0){return}d=0;k=+g[c+12>>2];l=+g[c+8>>2];m=+g[c+4>>2];n=+g[c>>2];do{c=a+(d<<3)|0;o=+g[c>>2];p=a+(d<<3)+4|0;q=+g[p>>2];r=b+(d<<3)|0;s=+g[r>>2];t=b+(d<<3)+4|0;u=+g[t>>2];n=f+n;m=h+m;l=i+l;k=j+k;g[c>>2]=n*o+l*s;g[p>>2]=n*q+l*u;g[r>>2]=m*o+k*s;g[t>>2]=m*q+k*u;d=d+1|0;}while((d|0)<(e|0));return}function Lpb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0,A=0.0,B=0,C=0.0;f=+g[d>>2];h=+g[d+16>>2];i=+g[d+4>>2];j=+g[d+20>>2];k=+g[d+8>>2];l=+g[d+24>>2];m=+g[d+12>>2];n=+g[d+28>>2];if((e|0)<=0){return}o=+g[c+28>>2];p=+g[c+12>>2];q=+g[c+24>>2];r=+g[c+8>>2];d=0;s=+g[c+20>>2];t=+g[c+4>>2];u=+g[c+16>>2];v=+g[c>>2];do{c=a+(d<<3)|0;w=+g[c>>2];x=a+(d<<3)+4|0;y=+g[x>>2];z=b+(d<<3)|0;A=+g[z>>2];B=b+(d<<3)+4|0;C=+g[B>>2];v=f+v;t=i+t;r=k+r;p=m+p;u=h+u;s=j+s;q=l+q;o=n+o;g[c>>2]=v*w+r*A-u*y-q*C;g[x>>2]=q*A+(u*w+(v*y+r*C));g[z>>2]=t*w+p*A-s*y-o*C;g[B>>2]=o*A+(s*w+(t*y+p*C));d=d+1|0;}while((d|0)<(e|0));return}function Mpb(b){b=b|0;var e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0.0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0,E=0.0,F=0,G=0,H=0.0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;e=b|0;f=c[e>>2]|0;h=c[f+72>>2]|0;i=(h|0)/(c[f+416>>2]|0)|0;j=c[f+436>>2]|0;do{if((j|0)==0){if((h|0)==0){k=(c[f+412>>2]|0)/2|0;break}else{l=((h|0)/8|0)+4e3|0;m=((h|0)/32|0)+12e3|0;n=(l|0)>(m|0)?m:l;l=(c[f+412>>2]|0)/2|0;k=(n|0)>(l|0)?l:n;break}}else{k=j}}while(0);o=+(k|0);p=o/7500.0;q=+Y(o*.0007600000244565308)*13.300000190734863+ +Y(p*p)*3.5;k=cEb(3616)|0;c[b+40>>2]=k;c[k>>2]=i;j=c[e>>2]|0;f=j+412|0;h=(i<<10|0)/(c[f>>2]|0)|0;c[k+4>>2]=h;p=+(c[f>>2]|0)*2.0;g[k+12>>2]=o*8192.0/p;g[k+16>>2]=o*12288.0/p;n=6144-h|0;h=n-((n|0)%8|0)|0;c[b+32>>2]=h;c[k+8>>2]=h;h=k+28|0;p=+(i|0);i=b+24|0;o=p<=22.0?1.5:2.0;n=c[b+20>>2]|0;b=c[f>>2]|0;f=0;do{l=c[n+(f<<2)>>2]|0;r=+(b|0);m=(f|0)!=0;s=r/(m?256.0:2048.0);t=p*(m?128.0:1024.0)/r*1.1799999475479126*.024000000208616257/q;r=m?2.0:3.0;u=m?1.5:o;m=c[(c[i>>2]|0)+(f<<2)>>2]|0;v=(m|0)>0;if(v){w=0.0;x=0;y=0;while(1){z=(d[l+x|0]|0)+y|0;A=s*+(z-1|0);B=A/7500.0;C=+Y(A*.0007600000244565308)*13.300000190734863+ +Y(B*B)*3.5;g[h+(f*1792|0)+(x*28|0)+4>>2]=(w+C)*.5;D=x+1|0;if((D|0)<(m|0)){w=C;x=D;y=z}else{break}}}y=m-1|0;if((y|0)>0){x=h+(f*1792|0)+4|0;z=0;while(1){D=z+1|0;w=+g[h+(f*1792|0)+(D*28|0)+4>>2]- +g[x>>2];C=-0.0-w;g[h+(f*1792|0)+(z*28|0)+8>>2]=+S(+10.0,+(w*-3.0));g[h+(f*1792|0)+(z*28|0)+16>>2]=+S(+10.0,+(w*-1.5));g[h+(f*1792|0)+(z*28|0)+12>>2]=+S(+10.0,+(r*C));g[h+(f*1792|0)+(z*28|0)+20>>2]=+S(+10.0,+(u*C));C=1.0/(+Wc(+(t*w/+(d[l+z|0]|0|0)))+ -1.5);if(C<.003162277629598975){E=.003162277629598975}else{E=C>.7943282127380371?.7943282127380371:C}g[h+(f*1792|0)+(z*28|0)+24>>2]=E;if((D|0)<(y|0)){z=D}else{break}}}if(v){z=0;y=0;while(1){t=s*+(z|0)/1.0e3;u=t+ -3.4;r=t+ -8.7;C=+S(+t,+-.8)*3.64- +_(u*u*-.6)*6.8+ +_(r*r*-.15)*6.0+t*t*t*t*76.0e-5;x=l+y|0;D=a[x]|0;if((D&255)>>>0>1>>>0){F=D&255;t=C;D=1;while(1){r=s*+(D+z|0)/1.0e3;u=r+ -3.4;w=r+ -8.7;B=+S(+r,+-.8)*3.64- +_(u*u*-.6)*6.8+ +_(w*w*-.15)*6.0+r*r*r*r*76.0e-5;r=t>B?B:t;G=D+1|0;if((G|0)<(F|0)){t=r;D=G}else{H=r;break}}}else{H=C}g[h+(f*1792|0)+(y*28|0)>>2]=H+5.242379665374756;D=y+1|0;if((D|0)<(m|0)){z=(d[x]|0)+z|0;y=D}else{break}}}f=f+1|0;}while((f|0)<2);f=cEb((c[j+416>>2]|0)*9340|0)|0;c[k+3612>>2]=f;k=c[e>>2]|0;e=c[k+416>>2]|0;if((e|0)<=0){return 0}j=k+72|0;h=k+80|0;if((c[k+88>>2]&2|0)==0){I=0}else{k=0;do{g[f+(k*9340|0)+9236>>2]=+g[559892+(((c[h>>2]|0)/118|0)<<3)>>2];g[f+(k*9340|0)+9240>>2]=10.0;g[f+(k*9340|0)+9244>>2]=10.0;g[f+(k*9340|0)+9248>>2]=10.0;g[f+(k*9340|0)+9252>>2]=10.0;g[f+(k*9340|0)+9256>>2]=10.0;g[f+(k*9340|0)+9260>>2]=10.0;g[f+(k*9340|0)+9264>>2]=10.0;g[f+(k*9340|0)+9268>>2]=10.0;g[f+(k*9340|0)+9272>>2]=10.0;g[f+(k*9340|0)+9276>>2]=10.0;g[f+(k*9340|0)+9280>>2]=10.0;g[f+(k*9340|0)+9284>>2]=10.0;g[f+(k*9340|0)+9288>>2]=10.0;g[f+(k*9340|0)+9292>>2]=10.0;g[f+(k*9340|0)+9296>>2]=10.0;g[f+(k*9340|0)+9300>>2]=10.0;g[f+(k*9340|0)+9304>>2]=10.0;g[f+(k*9340|0)+9308>>2]=10.0;g[f+(k*9340|0)+9312>>2]=10.0;g[f+(k*9340|0)+9316>>2]=10.0;g[f+(k*9340|0)+9320>>2]=10.0;g[f+(k*9340|0)+9324>>2]=10.0;g[f+(k*9340|0)+9328>>2]=10.0;g[f+(k*9340|0)+9332>>2]=10.0;k=k+1|0;}while((k|0)<(e|0));return 0}do{k=((c[j>>2]|0)/(e|0)|0|0)/1e3|0;h=1;while(1){if((h|0)>=13){J=160;K=160;L=12;M=12;break}N=c[559976+(h<<3)>>2]|0;if((((N|0)<(k|0)?k:N)|0)==(k|0)){h=h+1|0}else{O=24;break}}if((O|0)==24){O=0;i=h-1|0;J=N;K=c[559976+(i<<3)>>2]|0;L=h;M=i}g[f+(I*9340|0)+9236>>2]=+g[559980+(((J-k|0)>(k-K|0)?M:L)<<3)>>2];g[f+(I*9340|0)+9240>>2]=10.0;g[f+(I*9340|0)+9244>>2]=10.0;g[f+(I*9340|0)+9248>>2]=10.0;g[f+(I*9340|0)+9252>>2]=10.0;g[f+(I*9340|0)+9256>>2]=10.0;g[f+(I*9340|0)+9260>>2]=10.0;g[f+(I*9340|0)+9264>>2]=10.0;g[f+(I*9340|0)+9268>>2]=10.0;g[f+(I*9340|0)+9272>>2]=10.0;g[f+(I*9340|0)+9276>>2]=10.0;g[f+(I*9340|0)+9280>>2]=10.0;g[f+(I*9340|0)+9284>>2]=10.0;g[f+(I*9340|0)+9288>>2]=10.0;g[f+(I*9340|0)+9292>>2]=10.0;g[f+(I*9340|0)+9296>>2]=10.0;g[f+(I*9340|0)+9300>>2]=10.0;g[f+(I*9340|0)+9304>>2]=10.0;g[f+(I*9340|0)+9308>>2]=10.0;g[f+(I*9340|0)+9312>>2]=10.0;g[f+(I*9340|0)+9316>>2]=10.0;g[f+(I*9340|0)+9320>>2]=10.0;g[f+(I*9340|0)+9324>>2]=10.0;g[f+(I*9340|0)+9328>>2]=10.0;g[f+(I*9340|0)+9332>>2]=10.0;I=I+1|0;}while((I|0)<(e|0));return 0}function Npb(b,e,f,h,j,k){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,R=0.0,S=0.0,T=0.0,U=0.0,V=0,W=0,X=0,Y=0,Z=0.0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;f=i;i=i+4456|0;l=f|0;m=f+40|0;n=f+96|0;o=f+4192|0;p=f+4304|0;q=f+4416|0;r=c[(c[e+40>>2]|0)+3612>>2]|0;TGb(l|0,0,36)|0;e=m;TGb(e|0,0,56)|0;a:do{if((h|0)==0){s=r+(j*9340|0)+9232|0;t=c[s>>2]|0;if((k|0)==2){u=s;v=t;w=36}else{x=s;y=t;w=35}}else{TGb(q|0,0,36)|0;t=0;z=+g[h+44>>2];A=+g[h+48>>2];B=+g[h+124>>2];C=+g[h+52>>2];D=+g[h+56>>2];E=+g[h+116>>2];F=+g[h+60>>2];G=+g[h+64>>2];H=+g[h+108>>2];I=+g[h+68>>2];J=+g[h+72>>2];K=+g[h+100>>2];L=+g[h+76>>2];M=+g[h+80>>2];N=+g[h+92>>2];while(1){O=+g[h+(t+21<<2)>>2];P=+g[h+(t+32<<2)>>2];s=t+1|0;R=+g[h+(t+30<<2)>>2];S=+g[h+(t+28<<2)>>2];T=+g[h+(t+26<<2)>>2];U=+g[h+(t+24<<2)>>2];g[n+(t<<2)>>2]=(O+(z+P)*-1.7303260184043527e-17+(C+R)*-1.3495279640235235e-17+(F+S)*-6.732779685849225e-17+(I+T)*-3.0835000291318875e-17+(L+U)*-1.1044240253100168e-16+((A+B)*-.017031719908118248+0.0+(D+E)*.04180720075964928+(G+H)*-.08763240277767181+(J+K)*.1863476037979126+(M+N)*-.6276379823684692))*32768.0;if((s|0)<1024){t=s;z=A;A=C;B=P;C=D;D=F;E=R;F=G;G=I;H=S;I=J;J=L;K=T;L=M;M=O;N=U}else{break}}t=q|0;N=+g[r+(j*9340|0)+9324>>2];g[p>>2]=N;g[o>>2]=N/+g[r+(j*9340|0)+9316>>2];M=+g[r+(j*9340|0)+9328>>2];g[p+4>>2]=M;g[o+4>>2]=M/+g[r+(j*9340|0)+9320>>2];L=+g[r+(j*9340|0)+9332>>2];g[p+8>>2]=L;g[o+8>>2]=L/N;g[t>>2]=L+(M+(N+0.0));s=n|0;V=0;while(1){W=s+168|0;X=s;N=1.0;do{M=+Q(+(+g[X>>2]));N=N>M?N:M;X=X+4|0;}while(X>>>0<W>>>0);W=V+3|0;g[p+(W<<2)>>2]=N;g[r+(j*9340|0)+9240+(V<<2)>>2]=N;Y=q+(((V|0)/3|0)+1<<2)|0;g[Y>>2]=N+ +g[Y>>2];Y=V+1|0;M=+g[p+(Y<<2)>>2];do{if(N>M){Z=N/M}else{L=N*10.0;if(!(M>L)){Z=0.0;break}Z=M/L}}while(0);g[o+(W<<2)>>2]=Z;if((Y|0)<24){s=X;V=Y}else{break}}V=r+(j*9340|0)+9236|0;s=0;do{_=l+(((s|0)/3|0)<<2)|0;do{if((c[_>>2]|0)==0){if(!(+g[o+(s<<2)>>2]>+g[V>>2])){break}c[_>>2]=((s|0)%3|0)+1}}while(0);s=s+1|0;}while((s|0)<27);s=l|0;V=0;_=1;M=+g[t>>2];while(1){N=+g[q+(_<<2)>>2];if((M>N?M:N)<4.0e4&M<N*1.7000000476837158&N<M*1.7000000476837158){do{if((_|0)==1){if((c[s>>2]|0)>=(c[l+4>>2]|0)){break}c[s>>2]=0}}while(0);c[l+(_<<2)>>2]=0;$=0}else{$=c[l+(_<<2)>>2]|0}aa=$+V|0;Y=_+1|0;if((Y|0)<9){V=aa;_=Y;M=N}else{break}}_=c[s>>2]|0;V=c[r+(j*9340|0)+9336>>2]|0;if((_|0)>(V|0)){ba=_}else{c[s>>2]=0;ba=0}do{if((V|0)!=3){if((aa|0)!=(-ba|0)){break}_=r+(j*9340|0)+9232|0;x=_;y=c[_>>2]|0;w=35;break a}}while(0);V=l+4|0;s=c[V>>2]|0;do{if((s|0)==0){ca=0}else{if((ba|0)==0){ca=s;break}c[V>>2]=0;ca=0}}while(0);V=l+8|0;s=c[V>>2]|0;do{if((s|0)==0){da=0}else{if((ca|0)==0){da=s;break}c[V>>2]=0;da=0}}while(0);V=l+12|0;s=c[V>>2]|0;do{if((s|0)==0){ea=0}else{if((da|0)==0){ea=s;break}c[V>>2]=0;ea=0}}while(0);V=l+16|0;s=c[V>>2]|0;do{if((s|0)==0){fa=0}else{if((ea|0)==0){fa=s;break}c[V>>2]=0;fa=0}}while(0);V=l+20|0;s=c[V>>2]|0;do{if((s|0)==0){ga=0}else{if((fa|0)==0){ga=s;break}c[V>>2]=0;ga=0}}while(0);V=l+24|0;s=c[V>>2]|0;do{if((s|0)==0){ha=0}else{if((ga|0)==0){ha=s;break}c[V>>2]=0;ha=0}}while(0);V=l+28|0;s=c[V>>2]|0;do{if((s|0)==0){ia=0}else{if((ha|0)==0){ia=s;break}c[V>>2]=0;ia=0}}while(0);V=l+32|0;if(!((c[V>>2]|0)==0|(ia|0)==0)){c[V>>2]=0}V=r+(j*9340|0)+9232|0;u=V;v=c[V>>2]|0;w=36}}while(0);do{if((w|0)==35){ja=(y|0)==2?3:0;ka=y;la=x}else if((w|0)==36){if((v|0)==3){c[u>>2]=2;ja=2;ka=2;la=u;break}else if((v|0)==0){c[u>>2]=1;ja=2;ka=1;la=u;break}else{ja=2;ka=v;la=u;break}}}while(0);c[m>>2]=ka;c[la>>2]=ja;c[m+4>>2]=k;k=m+16|0;do{if((ka|0)==2){c[k>>2]=8;c[m+12>>2]=0;ja=d[r+(j*9340|0)+9228|0]|0;c[m+20>>2]=1;la=ja>>>1&1^1;u=m+20+(la<<2)|0;c[u>>2]=(c[u>>2]|0)+1;u=(ja&4|0)==0?2:la;la=m+20+(u<<2)|0;c[la>>2]=(c[la>>2]|0)+1;la=(ja&8|0)==0?3:u;u=m+20+(la<<2)|0;c[u>>2]=(c[u>>2]|0)+1;u=(ja&16|0)==0?4:la;la=m+20+(u<<2)|0;c[la>>2]=(c[la>>2]|0)+1;la=(ja&32|0)==0?5:u;u=m+20+(la<<2)|0;c[u>>2]=(c[u>>2]|0)+1;u=(ja&64|0)==0?6:la;la=m+20+(u<<2)|0;c[la>>2]=(c[la>>2]|0)+1;la=m+20+(((ja&128|0)==0?7:u)<<2)|0;c[la>>2]=(c[la>>2]|0)+1;ma=0}else{c[k>>2]=1;c[m+20>>2]=1;la=m+12|0;if((ka|0)==1){c[la>>2]=0;ma=0;break}else{c[la>>2]=1;ma=0;break}}}while(0);while(1){if((ma|0)>=9){na=0;w=46;break}if((c[l+(ma<<2)>>2]|0)==0){ma=ma+1|0}else{na=ma;w=46;break}}if((w|0)==46){a[r+(j*9340|0)+9228|0]=a[57800+na|0]|0;c[r+(j*9340|0)+9336>>2]=c[l+32>>2];UGb(b|0,e|0,56)|0;i=f;return}}function Opb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0.0,U=0.0,V=0.0,W=0.0,X=0,Y=0.0,Z=0,_=0.0,$=0,aa=0.0,ba=0.0,ca=0,da=0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0.0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0,ta=0.0,ua=0.0,va=0.0,wa=0,xa=0.0,ya=0.0,za=0.0,Aa=0,Ba=0,Ca=0.0,Da=0.0,Ea=0.0,Fa=0.0,Ga=0.0,Ha=0.0,Ia=0.0,Ja=0.0,Ka=0.0,La=0.0,Ma=0.0,Na=0.0,Oa=0.0,Pa=0.0,Qa=0.0,Ra=0.0,Sa=0.0,Ta=0,Ua=0.0,Va=0.0,Wa=0,Xa=0.0,Ya=0.0,Za=0.0,_a=0,$a=0,ab=0.0,bb=0.0,cb=0.0,db=0.0,eb=0.0,fb=0.0,gb=0.0,hb=0.0,ib=0,jb=0.0,kb=0.0,lb=0.0,mb=0.0,nb=0.0,ob=0.0,pb=0.0,qb=0.0,rb=0.0,sb=0.0,tb=0,ub=0.0,vb=0.0,wb=0,xb=0,yb=0.0,zb=0,Ab=0,Bb=0.0,Cb=0.0,Db=0.0;j=i;i=i+512|0;k=j|0;l=(Ymb(b,e)|0)+80|0;if((a[l]|0)==0){i=j;return}m=k;n=b+40|0;o=b+24|0;p=b+20|0;r=k|0;s=b+8|0;t=b+36|0;u=b+32|0;b=0;do{v=b+e|0;w=c[f+(b<<2)>>2]|0;x=c[n>>2]|0;y=c[x+3612>>2]|0;z=y+(v*9340|0)|0;TGb(m|0,0,512)|0;A=c[x>>2]|0;do{if((A|0)>32e3){B=0.0}else{C=100.0- +(A|0)*100.0/32.0e3;if(C<50.0){B=50.0;break}B=C}}while(0);A=h+(b*56|0)+16|0;D=c[A>>2]|0;E=(D|0)==8;F=E&1;G=c[(c[o>>2]|0)+(F<<2)>>2]|0;H=c[(c[p>>2]|0)+(F<<2)>>2]|0;I=x+28|0;C=E?.6299999952316284:.5;E=D<<4;if((E|0)>0){J=(G|0)>0;if(J){K=0;L=0;while(1){M=0;N=K;do{O=M+L|0;P=y+(v*9340|0)+(O*36|0)|0;g[P>>2]=0.0;S=H+M|0;do{if((a[S]|0)==0){T=0.0;U=0.0;V=0.0}else{W=0.0;X=0;Y=0.0;do{Z=w+(X+N<<2)|0;_=+g[Z>>2];Y=Y+_*_;g[P>>2]=Y;W=W+ +R(+Q(+(+g[Z>>2])));X=X+1|0;$=a[S]|0;}while((X|0)<($&255|0));if(!(Y>0.0)){T=0.0;U=Y;V=W;break}T=+R(+(($&255)>>>0)/Y);U=Y;V=W}}while(0);g[y+(v*9340|0)+(O*36|0)+4>>2]=U*.0012589249527081847;g[y+(v*9340|0)+(O*36|0)+12>>2]=V*+R(T);N=(d[S]|0)+N|0;M=M+1|0;}while((M|0)<(G|0));M=L+16|0;if((M|0)<(E|0)){K=N;L=M}else{break}}}L=(G|0)>1;K=G-2|0;E=(K|0)>-1;w=h+(b*56|0)|0;H=h+(b*56|0)+4|0;_=B;aa=0.0;ba=0.0;M=0;P=D;while(1){g[r>>2]=+g[y+(v*9340|0)+(M*36|0)>>2];if(L){X=M-1|0;Z=1;do{ca=Z+M|0;da=y+(v*9340|0)+(ca*36|0)+4|0;ea=+g[da>>2];fa=+g[y+(v*9340|0)+((X+Z|0)*36|0)+4>>2]*+g[I+(F*1792|0)+(Z*28|0)+16>>2];g[da>>2]=ea>fa?ea:fa;fa=+g[y+(v*9340|0)+(ca*36|0)>>2];ea=+g[k+(ca-1<<2)>>2]*+g[I+(F*1792|0)+(Z*28|0)+20>>2];g[k+(ca<<2)>>2]=fa>ea?fa:ea;Z=Z+1|0;}while((Z|0)<(G|0))}if(E){Z=M|1;X=K;while(1){N=X+M|0;ca=y+(v*9340|0)+(N*36|0)+4|0;ea=+g[ca>>2];fa=+g[y+(v*9340|0)+((X+Z|0)*36|0)+4>>2]*+g[I+(F*1792|0)+(X*28|0)+8>>2];g[ca>>2]=ea>fa?ea:fa;ca=k+(N<<2)|0;fa=+g[ca>>2];ea=+g[k+(N+1<<2)>>2]*+g[I+(F*1792|0)+(X*28|0)+12>>2];g[ca>>2]=fa>ea?fa:ea;if((X|0)>0){X=X-1|0}else{break}}}if(J){X=(M|0)==0;ea=_;fa=aa;ga=ba;Z=0;do{ca=Z+M|0;N=y+(v*9340|0)+(ca*36|0)+4|0;ha=+g[N>>2];ia=+g[I+(F*1792|0)+(Z*28|0)>>2];ja=ha>ia?ha:ia;g[N>>2]=ja;g[y+(v*9340|0)+(ca*36|0)+8>>2]=ja;do{if((c[w>>2]|0)==3){ka=ja}else{if((c[H>>2]|0)==1&X){ka=ja;break}ia=ja*.009999999776482582;ha=+g[y+(v*9340|0)+4608+(ca*36|0)+8>>2]*2.0;la=ja>ha?ha:ja;ha=ia>la?ia:la;g[N>>2]=ha;ka=ha}}while(0);N=y+(v*9340|0)+(ca*36|0)+20|0;g[N>>2]=0.0;S=y+(v*9340|0)+(ca*36|0)+24|0;g[S>>2]=0.0;O=y+(v*9340|0)+(ca*36|0)+16|0;g[O>>2]=0.0;ja=+g[y+(v*9340|0)+(ca*36|0)>>2];if(ja>ka){ha=+gc(+ja);la=ha- +gc(+ka);ia=+g[y+(v*9340|0)+(ca*36|0)+12>>2];if(la<3.0){ma=ha*.5593572854995728+1.3219281435012817;na=la*.5593572854995728+1.3219281435012817;oa=ia*.5593572854995728}else{ma=ha;na=la;oa=ia}g[O>>2]=oa;la=ia*na;g[N>>2]=la;ha=ia*ma;g[S>>2]=ha;pa=la;qa=ha;ra=oa}else{pa=0.0;qa=0.0;ra=0.0}ea=ea+pa;ga=ga+qa;fa=fa+ra;do{if(C*+g[k+(ca<<2)>>2]>ja){sa=33}else{if(+g[I+(F*1792|0)+(Z*28|0)+24>>2]>1.0){sa=33;break}c[y+(v*9340|0)+(ca*36|0)+32>>2]=1}}while(0);if((sa|0)==33){sa=0;c[y+(v*9340|0)+(ca*36|0)+32>>2]=0}Z=Z+1|0;}while((Z|0)<(G|0));ta=ea;ua=fa;va=ga;wa=c[A>>2]|0}else{ta=_;ua=aa;va=ba;wa=P}Z=M+16|0;if((Z|0)<(wa<<4|0)){_=ta;aa=ua;ba=va;M=Z;P=wa}else{xa=ta;ya=ua;za=va;Aa=wa;break}}}else{xa=B;ya=0.0;za=0.0;Aa=D}g[(c[s>>2]|0)+(v*2564|0)+2560>>2]=xa;P=c[t>>2]|0;M=c[u>>2]|0;H=(Aa|0)==8;ba=H?.75:.949999988079071;w=c[x+4>>2]|0;J=x+8|0;K=(c[J>>2]|0)+(w-P)|0;if((K|0)<0){Ba=0}else{Ba=(K|0)>(M|0)?M:K}c[J>>2]=Ba;aa=+(Ba|0)/+(M|0);if(aa<.20000000298023224){Ca=.20000000298023224}else{Ca=aa>ba?ba:aa}J=x+12|0;aa=+g[J>>2];K=x+16|0;ba=+g[K>>2];if(aa>xa){Da=aa}else{Da=ba<xa?ba:xa}_=(H?-.3636363744735718:-.46666666865348816)*((H?-.75:-.8428571224212646)+Ca);g[K>>2]=ba<xa?xa:ba;g[J>>2]=aa<xa?aa:xa;C=+(w|0)*(1.0-_+((H?.8181818127632141:.6666666865348816)*((H?-.2611111104488373:-.3499999940395355)+Ca)-_)/(ba-aa)*(Da-aa));aa=+(M-P+w|0);ba=+(~~(C>aa?aa:C)|0)*1.1799999475479126;w=c[t>>2]|0;P=x+20|0;if((w|0)>0){C=+g[P>>2]/(+(w|0)*1.1799999475479126);if(C<.8500000238418579){Ea=.8500000238418579}else{Ea=C>1.149999976158142?1.149999976158142:C}Fa=ba*Ea}else{Fa=ba}g[P>>2]=ba;P=c[A>>2]|0;a:do{if(Fa<xa){if((P<<4|0)>0){w=(G|0)>0;ba=xa;C=ya;aa=za;M=0;H=P;while(1){if(C==0.0){Ga=0.0}else{_=C*4.0;ja=+Wc(+((aa-ba)/_));ha=+Wc(+((aa-Fa)/_))-ja;Ga=ha>0.0?ha:0.0}if(w){ha=0.0;ja=0.0;_=0.0;J=0;do{K=J+M|0;E=y+(v*9340|0)+(K*36|0)+4|0;la=+g[E>>2];ia=+g[y+(v*9340|0)+(K*36|0)>>2];do{if(ia>la){Ha=Ga+ +R(+R(la));Ia=Ha*Ha;Ha=Ia*Ia;Ia=ia*+g[I+(F*1792|0)+(J*28|0)+24>>2];if(!(Ha>Ia)){Ja=Ha;break}L=y+(v*9340|0)+(K*36|0)+32|0;if((c[L>>2]|0)==0){Ja=Ha;break}c[L>>2]=2;Ja=la>Ia?la:Ia}else{Ja=la}}while(0);g[E>>2]=Ja;L=y+(v*9340|0)+(K*36|0)+20|0;g[L>>2]=0.0;Z=y+(v*9340|0)+(K*36|0)+24|0;g[Z>>2]=0.0;X=y+(v*9340|0)+(K*36|0)+16|0;g[X>>2]=0.0;if(ia>Ja){la=+gc(+ia);W=la- +gc(+Ja);Y=+g[y+(v*9340|0)+(K*36|0)+12>>2];if(W<3.0){Ka=la*.5593572854995728+1.3219281435012817;La=W*.5593572854995728+1.3219281435012817;Ma=Y*.5593572854995728}else{Ka=la;La=W;Ma=Y}g[X>>2]=Ma;W=Y*La;g[L>>2]=W;la=Y*Ka;g[Z>>2]=la;Na=W;Oa=la;Pa=Ma}else{Na=0.0;Oa=0.0;Pa=0.0}ha=ha+Na;_=_+Oa;ja=ja+Pa;J=J+1|0;}while((J|0)<(G|0));Qa=ha;Ra=ja;Sa=_;Ta=c[A>>2]|0}else{Qa=0.0;Ra=0.0;Sa=0.0;Ta=H}J=M+16|0;if((J|0)<(Ta<<4|0)){ba=Qa;C=Ra;aa=Sa;M=J;H=Ta}else{Ua=Qa;Va=Ga;Wa=Ta;break}}}else{Ua=xa;Va=+q;Wa=P}aa=Fa*.05000000074505806;H=(G|0)>0;M=0;C=0.0;ba=Va;ga=0.0;fa=Ua;w=Wa;J=Wa;while(1){if((M|0)>=2){Xa=C;Ya=ga;Za=fa;_a=w;$a=J;break}ca=w<<4;if((ca|0)>0){ea=0.0;la=0.0;W=0.0;Z=0;while(1){if(H){Y=ea;Ia=la;Ha=W;L=0;while(1){X=L+Z|0;if((c[y+(v*9340|0)+(X*36|0)+32>>2]|0)==2){ab=Ha;bb=Ia;cb=Y}else{ab=Ha+ +g[y+(v*9340|0)+(X*36|0)+24>>2];bb=Ia+ +g[y+(v*9340|0)+(X*36|0)+16>>2];cb=Y+ +g[y+(v*9340|0)+(X*36|0)+20>>2]}X=L+1|0;if((X|0)<(G|0)){Y=cb;Ia=bb;Ha=ab;L=X}else{db=cb;eb=bb;fb=ab;break}}}else{db=ea;eb=la;fb=W}L=Z+16|0;if((L|0)<(ca|0)){ea=db;la=eb;W=fb;Z=L}else{break}}W=Fa-(fa-db);la=W>0.0?W:0.0;if(eb>0.0){if(eb==0.0){gb=0.0}else{W=eb*4.0;ea=+Wc(+((fb-db)/W));_=+Wc(+((fb-la)/W))-ea;gb=_>0.0?_:0.0}hb=ba+gb;ib=1}else{hb=ba;ib=0}_=0.0;ea=ga;Z=0;ca=J;while(1){if(H){W=_;la=ea;L=0;do{K=L+Z|0;E=y+(v*9340|0)+(K*36|0)|0;if(ib){X=y+(v*9340|0)+(K*36|0)+4|0;ja=+g[X>>2];ha=+g[E>>2];do{if(ha>ja){Ha=hb+ +R(+R(ja));Ia=Ha*Ha;Ha=Ia*Ia;Ia=ha*+g[I+(F*1792|0)+(L*28|0)+24>>2];if(!(Ha>Ia)){jb=Ha;break}S=y+(v*9340|0)+(K*36|0)+32|0;if((c[S>>2]|0)==0){jb=Ha;break}c[S>>2]=2;jb=ja>Ia?ja:Ia}else{jb=ja}}while(0);g[X>>2]=jb;kb=ha;lb=jb}else{kb=+g[E>>2];lb=+g[y+(v*9340|0)+(K*36|0)+4>>2]}S=y+(v*9340|0)+(K*36|0)+20|0;g[S>>2]=0.0;N=y+(v*9340|0)+(K*36|0)+24|0;g[N>>2]=0.0;O=y+(v*9340|0)+(K*36|0)+16|0;g[O>>2]=0.0;if(kb>lb){ja=+gc(+kb);Ia=ja- +gc(+lb);Ha=+g[y+(v*9340|0)+(K*36|0)+12>>2];if(Ia<3.0){mb=ja*.5593572854995728+1.3219281435012817;nb=Ia*.5593572854995728+1.3219281435012817;ob=Ha*.5593572854995728}else{mb=ja;nb=Ia;ob=Ha}g[O>>2]=ob;Ia=Ha*nb;g[S>>2]=Ia;g[N>>2]=Ha*mb;pb=Ia;qb=ob}else{pb=0.0;qb=0.0}W=W+pb;Ia=qb/lb;g[y+(v*9340|0)+(K*36|0)+28>>2]=Ia;la=la+Ia;L=L+1|0;}while((L|0)<(G|0));rb=W;sb=la;tb=c[A>>2]|0}else{rb=_;sb=ea;tb=ca}L=Z+16|0;if((L|0)<(tb<<4|0)){_=rb;ea=sb;Z=L;ca=tb}else{ub=rb;vb=sb;wb=tb;xb=tb;yb=hb;break}}}else{ub=0.0;vb=ga;wb=w;xb=J;yb=ba}ea=Fa-ub;if(+Q(+ea)>aa){Xa=ea;Ya=vb;Za=ub;_a=wb;$a=xb;break}else{M=M+1|0;C=ea;ba=yb;ga=vb;fa=ub;w=wb;J=xb}}if(Za<Fa*1.149999976158142){fa=1.0/Ya;J=_a<<4;if((J|0)>0){zb=0}else{Ab=$a;break}while(1){if(H){w=0;do{M=w+zb|0;ga=+g[y+(v*9340|0)+(M*36|0)+16>>2];if(ga>.5){ca=y+(v*9340|0)+(M*36|0)+4|0;ba=+g[ca>>2];C=ba*+Wc(+(Xa*fa*+g[y+(v*9340|0)+(M*36|0)+28>>2]/ga));ga=+g[I+(F*1792|0)+(w*28|0)+24>>2]*+g[y+(v*9340|0)+(M*36|0)>>2];do{if(C>ga){if((c[y+(v*9340|0)+(M*36|0)+32>>2]|0)!=1){Bb=C;break}Bb=ba>ga?ba:ga}else{Bb=C}}while(0);g[ca>>2]=Bb}w=w+1|0;}while((w|0)<(G|0))}w=zb+16|0;if((w|0)<(J|0)){zb=w}else{Ab=$a;break a}}}if(!(Za>Fa)){Ab=$a;break}J=_a<<4;H=(J|0)>0;fa=Za;w=G;while(1){M=w-1|0;if((w|0)==0){Ab=$a;break a}if(H){Z=I+(F*1792|0)+(M*28|0)+24|0;C=fa;L=0;while(1){N=L+M|0;do{if((c[y+(v*9340|0)+(N*36|0)+32>>2]|0)==0){Cb=C}else{if(!(+g[Z>>2]<.7943282127380371)){Cb=C;break}g[Z>>2]=.7943282127380371;g[y+(v*9340|0)+(N*36|0)+4>>2]=+g[y+(v*9340|0)+(N*36|0)>>2]*.7943282127380371;Cb=C+(+g[y+(v*9340|0)+(N*36|0)+16>>2]*1.5- +g[y+(v*9340|0)+(N*36|0)+20>>2])}}while(0);N=L+16|0;if((N|0)<(J|0)){C=Cb;L=N}else{Db=Cb;break}}}else{Db=fa}if(Db>Fa){fa=Db;w=M}else{Ab=$a;break}}}else{Ab=P}}while(0);P=Ab<<4;if((P|0)>0){F=(G|0)>0;I=0;do{if(F){A=c[s>>2]|0;x=0;do{D=x+I|0;g[A+(v*2564|0)+(D*20|0)+8>>2]=+g[y+(v*9340|0)+(D*36|0)+4>>2];g[A+(v*2564|0)+(D*20|0)+4>>2]=+g[y+(v*9340|0)+(D*36|0)>>2];x=x+1|0;}while((x|0)<(G|0))}I=I+16|0;}while((I|0)<(P|0))}UGb(y+(v*9340|0)+4608|0,z|0,4608)|0;b=b+1|0;}while((b|0)<(d[l]|0));i=j;return}function Ppb(a){a=a|0;var b=0;b=a+40|0;$Db((c[b>>2]|0)+3612|0);$Db(b);return}function Qpb(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((e|0)<(f|0)){i=e;do{b[g+(i<<1)>>1]=3072-(a[c+i|0]<<7);i=i+1|0;}while((i|0)<(f|0))}i=~f;c=e;j=d[7959496+e|0]|0;while(1){e=b[g+(c<<1)>>1]|0;k=j+1|0;l=d[1276728+k|0]|0;m=(l|0)>(f|0)?f:l;n=c+1|0;if((n|0)<(m|0)){o=~l;p=(i|0)>(o|0)?i:o;o=e<<16>>16;q=n;do{r=b[g+(q<<1)>>1]|0;s=(o|0)>(r|0)?o:r;t=s-(o+1+r>>1)|0;o=s+(d[1275032+((t|0)>255?255:t)|0]|0)|0;q=q+1|0;}while((q|0)<(m|0));u=o&65535;v=~p}else{u=e;v=n}b[h+(j<<1)>>1]=u;if((l|0)<(f|0)){c=v;j=k}else{break}}return}function Rpb(f,g,h,j,k,l,m,n,o,p,q,r){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;s=i;i=i+104|0;t=s|0;u=a[7959496+h|0]|0;h=u&255;v=(d[7959496+(j-1)|0]|0)+1|0;a:do{if(u<<24>>24==0){j=b[g>>1]|0;w=b[g+2>>1]|0;x=w<<16>>16;y=((j<<16>>16)+256|0)==(x|0)?384:0;b[t>>1]=(j&65535)-k-y;j=b[g+4>>1]|0;do{if((x+256|0)==(j<<16>>16|0)){z=384}else{if(!(w<<16>>16>j<<16>>16)){z=y;break}A=y-64|0;z=(A|0)>0?A:0}}while(0);b[t+2>>1]=(w&65535)-(z+k);y=(l|0)==0;j=c[f+8>>2]|0;b:do{if(y){x=2;A=z;while(1){B=b[g+(x<<1)>>1]|0;C=b[g+(x+1<<1)>>1]|0;do{if(((B<<16>>16)+256|0)==(C<<16>>16|0)){D=384}else{if(!(B<<16>>16>C<<16>>16)){D=A;break}E=A-64|0;D=(E|0)>0?E:0}}while(0);C=B<<16>>16;E=C-k|0;b[t+(x<<1)>>1]=E-D;F=x+1|0;if(!(B<<16>>16>(b[g+(F<<1)>>1]|0))){G=C;H=E;I=D;J=F;break b}if((F|0)<7){x=F;A=D}else{G=C;H=E;I=D;J=7;break}}}else{A=2;x=z;while(1){E=(A|0)==6;do{if(E){C=b[g+12>>1]|0;F=C-k|0;b[t+(A<<1)>>1]=F-x;K=x;L=C;M=F;N=13}else{F=b[g+(A<<1)>>1]|0;C=b[g+(A+1<<1)>>1]|0;if(((F<<16>>16)+256|0)==(C<<16>>16|0)){O=F<<16>>16;P=O-k|0;b[t+(A<<1)>>1]=P+65152;Q=384;R=O;S=P}else{if(F<<16>>16>C<<16>>16){C=x-64|0;T=(C|0)>0?C:0}else{T=x}C=F<<16>>16;P=C-k|0;b[t+(A<<1)>>1]=P-T;if(E){K=T;L=C;M=P;N=13;break}else{Q=T;R=C;S=P}}P=A+1|0;if(F<<16>>16>(b[g+(P<<1)>>1]|0)){U=P;V=Q;W=R;X=S}else{G=R;H=S;I=Q;J=P;break b}}}while(0);if((N|0)==13){N=0;U=A+1|0;V=K;W=L;X=M}if((U|0)<7){A=U;x=V}else{G=W;H=X;I=V;J=7;break}}}}while(0);w=G-j|0;x=v>>>0>22>>>0?22:v;if((J|0)>=(x|0)){Y=w;Z=H;_=22;break}A=c[f+16>>2]|0;E=c[f+12>>2]|0;if(y){B=J;P=I;F=H;C=w;while(1){O=b[g+(B<<1)>>1]|0;$=O<<16>>16;aa=B+1|0;ba=b[g+(aa<<1)>>1]|0;ca=ba<<16>>16;do{if((B|0)<7){if(($+256|0)==(ca|0)){da=384;break}if(!(O<<16>>16>ba<<16>>16)){da=P;break}ea=P-64|0;da=(ea|0)>0?ea:0}else{if((B|0)>=20){ea=P-128|0;da=(ea|0)>0?ea:0;break}if(($+256|0)==(ca|0)){da=320;break}if(!(O<<16>>16>ba<<16>>16)){da=P;break}ea=P-64|0;da=(ea|0)>0?ea:0}}while(0);ba=F-A|0;ca=O<<16>>16;$=ca-k|0;ea=(ba|0)>($|0)?ba:$;$=C-E|0;ba=ca-j|0;ca=($|0)>(ba|0)?$:ba;ba=ea-da|0;b[t+(B<<1)>>1]=(ba|0)>(ca|0)?ba:ca;if((aa|0)<(x|0)){B=aa;P=da;F=ea;C=ca}else{Y=ca;Z=ea;_=22;break a}}}else{fa=J;ga=I;ha=H;ia=w}while(1){do{if((fa|0)==6){ja=ga;ka=b[g+12>>1]|0;la=7}else{C=b[g+(fa<<1)>>1]|0;F=C<<16>>16;P=fa+1|0;B=b[g+(P<<1)>>1]|0;y=B<<16>>16;if((fa|0)<7){if((F+256|0)==(y|0)){ja=384;ka=C;la=P;break}if(!(C<<16>>16>B<<16>>16)){ja=ga;ka=C;la=P;break}ea=ga-64|0;ja=(ea|0)>0?ea:0;ka=C;la=P;break}if((fa|0)>=20){ea=ga-128|0;ja=(ea|0)>0?ea:0;ka=C;la=P;break}if((F+256|0)==(y|0)){ja=320;ka=C;la=P;break}if(!(C<<16>>16>B<<16>>16)){ja=ga;ka=C;la=P;break}B=ga-64|0;ja=(B|0)>0?B:0;ka=C;la=P}}while(0);aa=ha-A|0;O=ka<<16>>16;P=O-k|0;C=(aa|0)>(P|0)?aa:P;P=ia-E|0;aa=O-j|0;O=(P|0)>(aa|0)?P:aa;aa=C-ja|0;b[t+(fa<<1)>>1]=(aa|0)>(O|0)?aa:O;if((la|0)<(x|0)){fa=la;ga=ja;ha=C;ia=O}else{Y=O;Z=C;_=22;break}}}else{Y=(c[f+32>>2]<<8)+768|0;Z=(c[f+28>>2]<<8)+768|0;_=h}}while(0);if(_>>>0<v>>>0){ia=c[f+16>>2]|0;ha=c[f+12>>2]|0;ja=c[f+8>>2]|0;ga=_;_=Z;Z=Y;do{Y=_-ia|0;la=b[g+(ga<<1)>>1]|0;fa=la-k|0;_=(Y|0)>(fa|0)?Y:fa;fa=Z-ha|0;Y=la-ja|0;Z=(fa|0)>(Y|0)?fa:Y;b[t+(ga<<1)>>1]=(_|0)>(Z|0)?_:Z;ga=ga+1|0;}while((ga|0)<(v|0))}if(h>>>0<v>>>0){ga=c[f+20>>2]|0;Z=c[f>>2]|0;_=c[f+4>>2]|0;f=h;do{ja=ga-(b[g+(f<<1)>>1]|0)|0;if((ja|0)>0){ha=t+(f<<1)|0;k=(e[ha>>1]|0)+(ja>>>2)&65535;b[ha>>1]=k;ma=k}else{ma=b[t+(f<<1)>>1]|0}k=b[1275296+((f>>_)*6|0)+(Z<<1)>>1]|0;b[r+(f<<1)>>1]=(k&65535|0)>(ma<<16>>16|0)?k:ma;f=f+1|0;}while((f|0)<(v|0))}if(!(m>>>0<2>>>0)){na=0;i=s;return na|0}if((n|0)>8){na=-1;i=s;return na|0}if((n|0)>0){oa=h;pa=0}else{na=0;i=s;return na|0}while(1){h=(d[o+pa|0]|0)+oa|0;if((h|0)>49){na=-1;N=63;break}m=p+pa|0;v=a[m]|0;if((v&255|0)>(50-h|0)){na=-1;N=63;break}f=a[q+pa|0]|0;ma=((f&255)<<7)+((f&255)>>>0>3>>>0?-384:-512)&65535;if(v<<24>>24==0){qa=h}else{v=h;h=0;while(1){f=v+1|0;Z=r+(v<<1)|0;b[Z>>1]=ma+(b[Z>>1]|0);Z=h+1|0;if((Z|0)<(d[m]|0)){v=f;h=Z}else{qa=f;break}}}h=pa+1|0;if((h|0)<(n|0)){oa=qa;pa=h}else{na=0;N=63;break}}if((N|0)==63){i=s;return na|0}return 0}function Spb(){var a=0,b=0,c=0,e=0,f=0;a=0;b=0;while(1){c=a+1|0;e=d[1276728+c|0]|0;if((b|0)<(e|0)){TGb(7959496+b|0,a&255|0,e-b|0)|0;f=e}else{f=b}if((c|0)<50){a=c;b=f}else{break}}return}function Tpb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;do{if((d-2|0)>>>0>14>>>0){f=a+8|0}else{g=a|0;c[g>>2]=d;h=1<<d;i=WDb(h<<1)|0;j=a+8|0;c[j>>2]=i;if((i|0)==0){f=j;break}i=WDb(h<<2)|0;c[a+12>>2]=i;if((i|0)==0){f=j;break}i=a+4|0;c[i>>2]=e;k=a+56|0;c[k>>2]=0;c[a+32>>2]=180;c[a+36>>2]=88;c[a+40>>2]=2212;c[a+44>>2]=1940;c[a+48>>2]=1112;c[a+52>>2]=1460;do{if((d|0)<4){l=0}else{m=4;do{n=1<<m;o=6.283185307179586/+(n|0);p=c[1237528+(m<<2)>>2]|0;q=(n|0)/4|0;do{if(!((n|0)<-3)){r=0;do{s=Gc(+(+T(o*+(r|0))*32768.0))|0;if((s|0)<-32767){t=-32767}else{t=(s|0)>32767?32767:s&65535}b[p+(r<<1)>>1]=t;r=r+1|0;}while((r|0)<=(q|0));if((n|0)<=7){break}r=(n|0)/2|0;s=1;do{b[p+(r-s<<1)>>1]=b[p+(s<<1)>>1]|0;s=s+1|0;}while((s|0)<(q|0))}}while(0);m=m+1|0;}while((m|0)<=(d|0));m=c[k>>2]|0;if((m|0)!=2){l=m;break}m=1<<c[g>>2];if((m|0)<=0){u=0;return u|0}q=m-1|0;p=c[i>>2]|0;n=c[j>>2]|0;s=0;while(1){r=m;v=s;a:while(1){w=r;while(1){if((w|0)<33){break a}x=(w|0)/2|0;if((x|0)>(v|0)){w=x}else{break}}y=(w*3|0|0)/4|0;r=(w|0)/4|0;v=v-((y|0)>(v|0)?x:y)|0}if((v|0)>15){r=0;do{y=(c[1739400+(r<<2)>>2]|0)+s&65535;b[n+((q&-(Wpb(r+s|0,m,p)|0))<<1)>>1]=y;r=r+1|0;}while((r|0)<16)}else{r=0;do{v=r+s|0;b[n+((q&-(Wpb(v,m,p)|0))<<1)>>1]=v>>>1&3|v&65528|v<<2&4;r=r+1|0;}while((r|0)<16)}r=s+16|0;if((r|0)<(m|0)){s=r}else{u=0;break}}return u|0}}while(0);if((h|0)<=0){u=0;return u|0}g=c[i>>2]|0;k=h-1|0;s=c[j>>2]|0;if((l|0)==1){m=0;while(1){b[s+((k&-(Wpb(m,h,g)|0))<<1)>>1]=m>>>1&1|m&65532|m<<1&2;p=m+1|0;if((p|0)<(h|0)){m=p}else{u=0;break}}return u|0}else{m=0;while(1){b[s+((k&-(Wpb(m,h,g)|0))<<1)>>1]=m;j=m+1|0;if((j|0)<(h|0)){m=j}else{u=0;break}}return u|0}}}while(0);$Db(f);$Db(a+12|0);u=-1;return u|0}function Upb(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[a+8>>2]|0;g=1<<c[a>>2];h=a+12|0;if((g|0)>0){i=0}else{j=d;k=c[h>>2]|0;l=k;m=g<<2;UGb(j|0,l|0,m)|0;return}do{a=d+(i<<2)|0;n=(c[h>>2]|0)+((e[f+(i<<1)>>1]|0)<<2)|0;x=e[a>>1]|e[a+2>>1]<<16;b[n>>1]=x;b[n+2>>1]=x>>16;i=i+1|0;}while((i|0)<(g|0));j=d;k=c[h>>2]|0;l=k;m=g<<2;UGb(j|0,l|0,m)|0;return}function Vpb(a,b){a=a|0;b=b|0;me[c[1075016+((c[a>>2]|0)-2<<2)>>2]&511](b);return}function Wpb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if((b|0)<3){d=a&1;return d|0}e=b>>1;if((e&a|0)==0){return(Wpb(a,e,c)|0)<<1|0}e=b>>2;b=(Wpb(a,e,c)|0)<<2;if(((e&a|0)==0|0)==(c|0)){d=b|1;return d|0}else{d=b-1|0;return d|0}return 0}function Xpb(a){a=a|0;$Db(a+8|0);$Db(a+12|0);return}function Ypb(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=a|0;d=b[c>>1]|0;e=a+4|0;f=b[e>>1]|0;g=d-f>>1;h=f+d>>1;d=a+12|0;f=b[d>>1]|0;i=a+8|0;j=b[i>>1]|0;k=f-j>>1;l=j+f>>1;b[i>>1]=(h-l|0)>>>1;b[c>>1]=(l+h|0)>>>1;h=a+2|0;l=b[h>>1]|0;c=a+6|0;i=b[c>>1]|0;f=l-i>>1;j=i+l>>1;l=a+10|0;i=b[l>>1]|0;m=a+14|0;a=b[m>>1]|0;n=i-a>>1;o=a+i>>1;b[m>>1]=(f-k|0)>>>1;b[c>>1]=(f+k|0)>>>1;b[d>>1]=(g-n|0)>>>1;b[e>>1]=(n+g|0)>>>1;b[l>>1]=(j-o|0)>>>1;b[h>>1]=(o+j|0)>>>1;return}function Zpb(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;c=a|0;d=b[c>>1]|0;e=a+4|0;f=b[e>>1]|0;g=d-f>>1;h=f+d>>1;d=a+12|0;f=b[d>>1]|0;i=a+8|0;j=b[i>>1]|0;k=f-j>>1;l=j+f>>1;f=a+2|0;j=b[f>>1]|0;m=a+6|0;n=b[m>>1]|0;o=j-n>>1;p=n+j>>1;j=a+10|0;n=b[j>>1]|0;q=a+14|0;r=b[q>>1]|0;s=n-r>>1;t=r+n>>1;n=a+16|0;r=b[n>>1]|0;u=a+20|0;v=b[u>>1]|0;w=v+r>>1;x=a+18|0;y=b[x>>1]|0;z=a+22|0;A=b[z>>1]|0;B=A+y>>1;C=a+24|0;D=b[C>>1]|0;E=a+28|0;F=b[E>>1]|0;G=F+D>>1;H=a+26|0;I=b[H>>1]|0;J=a+30|0;a=b[J>>1]|0;K=a+I>>1;L=G-w>>1;M=G+w>>1;w=(l+h|0)>>>1<<16>>16;b[n>>1]=(w-M|0)>>>1;b[c>>1]=(M+w|0)>>>1;w=(p-t|0)>>>1<<16>>16;b[H>>1]=(w-L|0)>>>1;b[j>>1]=(w+L|0)>>>1;L=B-K>>1;w=K+B>>1;B=(h-l|0)>>>1<<16>>16;b[C>>1]=(B-L|0)>>>1;b[i>>1]=(L+B|0)>>>1;B=(t+p|0)>>>1<<16>>16;b[x>>1]=(B-w|0)>>>1;b[f>>1]=(w+B|0)>>>1;B=(r-v|0)>>>1<<16>>16;v=(y-A|0)>>>1<<16>>16;A=((v+B|0)*23170|0)>>15;y=((v-B|0)*23170|0)>>15;B=(D-F|0)>>>1<<16>>16;F=(I-a|0)>>>1<<16>>16;a=((B-F|0)*23170|0)>>15;I=((F+B|0)*23170|0)>>15;B=a-A>>1;F=a+A>>1;A=(s+g|0)>>>1<<16>>16;b[u>>1]=(A-F|0)>>>1;b[e>>1]=(F+A|0)>>>1;A=(o-k|0)>>>1<<16>>16;b[J>>1]=(A-B|0)>>>1;b[q>>1]=(B+A|0)>>>1;A=y-I>>1;B=I+y>>1;y=(g-s|0)>>>1<<16>>16;b[E>>1]=(y-A|0)>>>1;b[d>>1]=(A+y|0)>>>1;y=(o+k|0)>>>1<<16>>16;b[z>>1]=(y-B|0)>>>1;b[m>>1]=(B+y|0)>>>1;return}function _pb(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;c=b[3949905]|0;d=b[3949907]|0;Zpb(a);e=a+32|0;f=b[e>>1]|0;g=a+36|0;h=b[g>>1]|0;i=f-h>>1;j=h+f>>1;f=a+44|0;h=b[f>>1]|0;k=a+40|0;l=b[k>>1]|0;m=h-l>>1;n=l+h>>1;h=a+34|0;l=b[h>>1]|0;o=a+38|0;p=b[o>>1]|0;q=l-p>>1;r=p+l>>1;l=a+42|0;p=b[l>>1]|0;s=a+46|0;t=b[s>>1]|0;u=p-t>>1;v=t+p>>1;p=a+48|0;t=b[p>>1]|0;w=a+52|0;x=b[w>>1]|0;y=t-x>>1;z=x+t>>1;t=a+60|0;x=b[t>>1]|0;A=a+56|0;B=b[A>>1]|0;C=x-B>>1;D=B+x>>1;x=a+50|0;B=b[x>>1]|0;E=a+54|0;F=b[E>>1]|0;G=B-F>>1;H=F+B>>1;B=a+58|0;F=b[B>>1]|0;I=a+62|0;J=b[I>>1]|0;K=F-J>>1;L=J+F>>1;F=(n+j|0)>>>1<<16>>16;J=(v+r|0)>>>1<<16>>16;M=(D+z|0)>>>1<<16>>16;N=(L+H|0)>>>1<<16>>16;O=a|0;P=a+2|0;Q=b[P>>1]|0;R=a+16|0;S=b[R>>1]|0;T=a+18|0;U=b[T>>1]|0;V=M-F>>1;W=M+F>>1;F=b[O>>1]|0;b[e>>1]=(F-W|0)>>>1;b[O>>1]=(F+W|0)>>>1;W=U<<16>>16;b[x>>1]=(W-V|0)>>>1;b[T>>1]=(W+V|0)>>>1;V=J-N>>1;W=N+J>>1;J=S<<16>>16;b[p>>1]=(J-V|0)>>>1;b[R>>1]=(J+V|0)>>>1;V=Q<<16>>16;b[h>>1]=(V-W|0)>>>1;b[P>>1]=(V+W|0)>>>1;W=(j-n|0)>>>1<<16>>16;n=(r-v|0)>>>1<<16>>16;v=((n+W|0)*23170|0)>>15;r=((n-W|0)*23170|0)>>15;W=(z-D|0)>>>1<<16>>16;D=(H-L|0)>>>1<<16>>16;L=((W-D|0)*23170|0)>>15;H=((D+W|0)*23170|0)>>15;W=a+8|0;D=a+10|0;z=b[D>>1]|0;n=a+24|0;j=b[n>>1]|0;V=a+26|0;P=b[V>>1]|0;h=L-v>>1;Q=L+v>>1;v=b[W>>1]|0;b[k>>1]=(v-Q|0)>>>1;b[W>>1]=(Q+v|0)>>>1;v=P<<16>>16;b[B>>1]=(v-h|0)>>>1;b[V>>1]=(h+v|0)>>>1;v=r-H>>1;h=H+r>>1;r=j<<16>>16;b[A>>1]=(r-v|0)>>>1;b[n>>1]=(v+r|0)>>>1;r=z<<16>>16;b[l>>1]=(r-h|0)>>>1;b[D>>1]=(h+r|0)>>>1;r=(u+i|0)>>>1<<16>>16;h=c<<16>>16;c=(q+m|0)>>>1<<16>>16;D=d<<16>>16;d=(ba(c,D)|0)+(ba(r,h)|0)>>15;l=(ba(c,h)|0)-(ba(r,D)|0)>>15;r=(K+y|0)>>>1<<16>>16;c=(G+C|0)>>>1<<16>>16;z=(ba(r,h)|0)-(ba(c,D)|0)>>15;v=(ba(c,h)|0)+(ba(r,D)|0)>>15;r=a+4|0;c=a+6|0;n=b[c>>1]|0;A=a+20|0;j=b[A>>1]|0;H=a+22|0;V=b[H>>1]|0;B=z-d>>1;P=z+d>>1;d=b[r>>1]|0;b[g>>1]=(d-P|0)>>>1;b[r>>1]=(P+d|0)>>>1;d=V<<16>>16;b[E>>1]=(d-B|0)>>>1;b[H>>1]=(B+d|0)>>>1;d=l-v>>1;B=v+l>>1;l=j<<16>>16;b[w>>1]=(l-d|0)>>>1;b[A>>1]=(d+l|0)>>>1;l=n<<16>>16;b[o>>1]=(l-B|0)>>>1;b[c>>1]=(B+l|0)>>>1;l=(i-u|0)>>>1<<16>>16;u=(q-m|0)>>>1<<16>>16;m=(ba(u,h)|0)+(ba(l,D)|0)>>15;q=(ba(u,D)|0)-(ba(l,h)|0)>>15;l=(y-K|0)>>>1<<16>>16;K=(G-C|0)>>>1<<16>>16;C=(ba(l,D)|0)-(ba(K,h)|0)>>15;G=(ba(K,D)|0)+(ba(l,h)|0)>>15;h=a+12|0;l=a+14|0;D=b[l>>1]|0;K=a+28|0;y=b[K>>1]|0;u=a+30|0;a=b[u>>1]|0;i=C-m>>1;B=C+m>>1;m=b[h>>1]|0;b[f>>1]=(m-B|0)>>>1;b[h>>1]=(B+m|0)>>>1;m=a<<16>>16;b[I>>1]=(m-i|0)>>>1;b[u>>1]=(i+m|0)>>>1;m=q-G>>1;i=G+q>>1;q=y<<16>>16;b[t>>1]=(q-m|0)>>>1;b[K>>1]=(m+q|0)>>>1;q=D<<16>>16;b[s>>1]=(q-i|0)>>>1;b[l>>1]=(i+q|0)>>>1;return}function $pb(a){a=a|0;_pb(a);Zpb(a+64|0);Zpb(a+96|0);mqb(a,7794496,4);return}function aqb(a){a=a|0;_pb(a);Zpb(a+64|0);Zpb(a+96|0);mqb(a,7794496,4);_pb(a+128|0);_pb(a+192|0);mqb(a,7780480,8);return}function bqb(a){a=a|0;var b=0;_pb(a);Zpb(a+64|0);Zpb(a+96|0);mqb(a,7794496,4);_pb(a+128|0);_pb(a+192|0);mqb(a,7780480,8);b=a+256|0;_pb(b);Zpb(a+320|0);Zpb(a+352|0);mqb(b,7794496,4);b=a+384|0;_pb(b);Zpb(a+448|0);Zpb(a+480|0);mqb(b,7794496,4);mqb(a,7949008,16);return}function cqb(a){a=a|0;var b=0;bqb(a);b=a+512|0;_pb(b);Zpb(a+576|0);Zpb(a+608|0);mqb(b,7794496,4);_pb(a+640|0);_pb(a+704|0);mqb(b,7780480,8);b=a+768|0;_pb(b);Zpb(a+832|0);Zpb(a+864|0);mqb(b,7794496,4);_pb(a+896|0);_pb(a+960|0);mqb(b,7780480,8);mqb(a,7892896,32);return}function dqb(a){a=a|0;cqb(a);bqb(a+1024|0);bqb(a+1536|0);mqb(a,7780672,64);return}function eqb(a){a=a|0;cqb(a);bqb(a+1024|0);bqb(a+1536|0);mqb(a,7780672,64);cqb(a+2048|0);cqb(a+3072|0);lqb(a,7949392,128);return}function fqb(a){a=a|0;var b=0;cqb(a);bqb(a+1024|0);bqb(a+1536|0);mqb(a,7780672,64);cqb(a+2048|0);cqb(a+3072|0);lqb(a,7949392,128);b=a+4096|0;cqb(b);bqb(a+5120|0);bqb(a+5632|0);mqb(b,7780672,64);b=a+6144|0;cqb(b);bqb(a+7168|0);bqb(a+7680|0);mqb(b,7780672,64);lqb(a,7893664,256);return}function gqb(a){a=a|0;var b=0;fqb(a);b=a+8192|0;cqb(b);bqb(a+9216|0);bqb(a+9728|0);mqb(b,7780672,64);cqb(a+10240|0);cqb(a+11264|0);lqb(b,7949392,128);b=a+12288|0;cqb(b);bqb(a+13312|0);bqb(a+13824|0);mqb(b,7780672,64);cqb(a+14336|0);cqb(a+15360|0);lqb(b,7949392,128);lqb(a,7782208,512);return}function hqb(a){a=a|0;gqb(a);fqb(a+16384|0);fqb(a+24576|0);lqb(a,7559296,1024);return}function iqb(a){a=a|0;gqb(a);fqb(a+16384|0);fqb(a+24576|0);lqb(a,7559296,1024);gqb(a+32768|0);gqb(a+49152|0);lqb(a,7899824,2048);return}function jqb(a){a=a|0;var b=0;gqb(a);fqb(a+16384|0);fqb(a+24576|0);lqb(a,7559296,1024);gqb(a+32768|0);gqb(a+49152|0);lqb(a,7899824,2048);b=a+65536|0;gqb(b);fqb(a+81920|0);fqb(a+90112|0);lqb(b,7559296,1024);b=a+98304|0;gqb(b);fqb(a+114688|0);fqb(a+122880|0);lqb(b,7559296,1024);lqb(a,7794528,4096);return}function kqb(a){a=a|0;var b=0;jqb(a);b=a+131072|0;gqb(b);fqb(a+147456|0);fqb(a+155648|0);lqb(b,7559296,1024);gqb(a+163840|0);gqb(a+180224|0);lqb(b,7899824,2048);b=a+196608|0;gqb(b);fqb(a+212992|0);fqb(a+221184|0);lqb(b,7559296,1024);gqb(a+229376|0);gqb(a+245760|0);lqb(b,7899824,2048);lqb(a,7583872,8192);return}function lqb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=d<<1;f=d<<2;g=d*6|0;h=a+(f<<2)|0;i=b[h>>1]|0;j=a+(f<<2)+2|0;k=b[j>>1]|0;l=a+(g<<2)|0;m=b[l>>1]|0;n=a+(g<<2)+2|0;o=b[n>>1]|0;p=a|0;q=a+2|0;r=b[q>>1]|0;s=a+(e<<2)|0;t=b[s>>1]|0;u=a+(e<<2)+2|0;v=b[u>>1]|0;w=m-i>>1;x=m+i>>1;i=b[p>>1]|0;b[h>>1]=(i-x|0)>>>1;b[p>>1]=(i+x|0)>>>1;x=v<<16>>16;b[n>>1]=(x-w|0)>>>1;b[u>>1]=(x+w|0)>>>1;w=k-o>>1;x=o+k>>1;k=t<<16>>16;b[l>>1]=(k-w|0)>>>1;b[s>>1]=(k+w|0)>>>1;w=r<<16>>16;b[j>>1]=(w-x|0)>>>1;b[q>>1]=(w+x|0)>>>1;x=f|1;w=a+(x<<2)|0;q=b[w>>1]|0;j=b[c+2>>1]|0;r=ba(j,q)|0;k=a+(x<<2)+2|0;x=b[k>>1]|0;s=b[c+(e-1<<1)>>1]|0;l=(ba(s,x)|0)+r>>15;r=(ba(x,j)|0)-(ba(s,q)|0)>>15;q=g|1;x=a+(q<<2)|0;t=b[x>>1]|0;o=ba(t,j)|0;u=a+(q<<2)+2|0;n=b[u>>1]|0;v=o-(ba(n,s)|0)>>15;o=(ba(n,j)|0)+(ba(t,s)|0)>>15;s=a+4|0;t=a+6|0;j=b[t>>1]|0;n=e|1;i=a+(n<<2)|0;p=b[i>>1]|0;h=a+(n<<2)+2|0;m=b[h>>1]|0;y=v-l>>1;z=v+l>>1;l=b[s>>1]|0;b[w>>1]=(l-z|0)>>>1;b[s>>1]=(z+l|0)>>>1;l=m<<16>>16;b[u>>1]=(l-y|0)>>>1;b[h>>1]=(y+l|0)>>>1;l=r-o>>1;y=o+r>>1;r=p<<16>>16;b[x>>1]=(r-l|0)>>>1;b[i>>1]=(l+r|0)>>>1;r=j<<16>>16;b[k>>1]=(r-y|0)>>>1;b[t>>1]=(y+r|0)>>>1;r=f|2;y=g+2|0;g=e+2|0;t=f|3;f=q+2|0;q=n+2|0;n=a;a=c;k=d-1|0;d=c+(e<<1)|0;while(1){e=n+8|0;c=a+4|0;j=d-4|0;l=n+(r<<2)|0;i=b[l>>1]|0;x=b[c>>1]|0;p=ba(x,i)|0;o=n+(r<<2)+2|0;h=b[o>>1]|0;u=b[j>>1]|0;m=(ba(u,h)|0)+p>>15;p=(ba(h,x)|0)-(ba(u,i)|0)>>15;i=n+(y<<2)|0;h=b[i>>1]|0;z=ba(h,x)|0;s=n+(y<<2)+2|0;w=b[s>>1]|0;v=z-(ba(w,u)|0)>>15;z=(ba(w,x)|0)+(ba(h,u)|0)>>15;u=e|0;h=n+10|0;x=b[h>>1]|0;w=n+(g<<2)|0;A=b[w>>1]|0;B=n+(g<<2)+2|0;C=b[B>>1]|0;D=v-m>>1;E=v+m>>1;m=b[u>>1]|0;b[l>>1]=(m-E|0)>>>1;b[u>>1]=(E+m|0)>>>1;m=C<<16>>16;b[s>>1]=(m-D|0)>>>1;b[B>>1]=(D+m|0)>>>1;m=p-z>>1;D=z+p>>1;p=A<<16>>16;b[i>>1]=(p-m|0)>>>1;b[w>>1]=(m+p|0)>>>1;p=x<<16>>16;b[o>>1]=(p-D|0)>>>1;b[h>>1]=(D+p|0)>>>1;p=n+(t<<2)|0;D=b[p>>1]|0;h=b[a+6>>1]|0;o=ba(h,D)|0;x=n+(t<<2)+2|0;m=b[x>>1]|0;w=b[d-6>>1]|0;i=(ba(w,m)|0)+o>>15;o=(ba(m,h)|0)-(ba(w,D)|0)>>15;D=n+(f<<2)|0;m=b[D>>1]|0;A=ba(m,h)|0;z=n+(f<<2)+2|0;B=b[z>>1]|0;s=A-(ba(B,w)|0)>>15;A=(ba(B,h)|0)+(ba(m,w)|0)>>15;w=n+12|0;m=n+14|0;h=b[m>>1]|0;B=n+(q<<2)|0;C=b[B>>1]|0;E=n+(q<<2)+2|0;u=b[E>>1]|0;l=s-i>>1;v=s+i>>1;i=b[w>>1]|0;b[p>>1]=(i-v|0)>>>1;b[w>>1]=(v+i|0)>>>1;i=u<<16>>16;b[z>>1]=(i-l|0)>>>1;b[E>>1]=(l+i|0)>>>1;i=o-A>>1;l=A+o>>1;o=C<<16>>16;b[D>>1]=(o-i|0)>>>1;b[B>>1]=(i+o|0)>>>1;o=h<<16>>16;b[x>>1]=(o-l|0)>>>1;b[m>>1]=(l+o|0)>>>1;o=k-1|0;if((o|0)==0){break}else{n=e;a=c;k=o;d=j}}return}function mqb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=d<<1;f=d<<2;g=d*6|0;h=a+(f<<2)|0;i=b[h>>1]|0;j=a+(f<<2)+2|0;k=b[j>>1]|0;l=a+(g<<2)|0;m=b[l>>1]|0;n=a+(g<<2)+2|0;o=b[n>>1]|0;p=m-i>>1;q=m+i>>1;i=a|0;b[h>>1]=((b[i>>1]|0)-q|0)>>>1;b[i>>1]=((b[i>>1]|0)+q|0)>>>1;q=a+(e<<2)+2|0;b[n>>1]=((b[q>>1]|0)-p|0)>>>1;b[q>>1]=((b[q>>1]|0)+p|0)>>>1;p=k-o>>1;q=o+k>>1;k=a+(e<<2)|0;b[l>>1]=((b[k>>1]|0)-p|0)>>>1;b[k>>1]=((b[k>>1]|0)+p|0)>>>1;p=a+2|0;b[j>>1]=((b[p>>1]|0)-q|0)>>>1;b[p>>1]=((b[p>>1]|0)+q|0)>>>1;q=f|1;p=a+(q<<2)|0;j=b[p>>1]|0;k=b[c+2>>1]|0;l=ba(k,j)|0;o=a+(q<<2)+2|0;q=b[o>>1]|0;n=b[c+(e-1<<1)>>1]|0;i=(ba(n,q)|0)+l>>15;l=(ba(q,k)|0)-(ba(n,j)|0)>>15;j=g|1;q=a+(j<<2)|0;h=b[q>>1]|0;m=ba(h,k)|0;r=a+(j<<2)+2|0;s=b[r>>1]|0;t=m-(ba(s,n)|0)>>15;m=(ba(s,k)|0)+(ba(h,n)|0)>>15;n=t-i>>1;h=t+i>>1;i=a+4|0;b[p>>1]=((b[i>>1]|0)-h|0)>>>1;b[i>>1]=(h+(b[i>>1]|0)|0)>>>1;i=e|1;h=a+(i<<2)+2|0;b[r>>1]=((b[h>>1]|0)-n|0)>>>1;b[h>>1]=(n+(b[h>>1]|0)|0)>>>1;h=l-m>>1;n=m+l>>1;l=a+(i<<2)|0;b[q>>1]=((b[l>>1]|0)-h|0)>>>1;b[l>>1]=((b[l>>1]|0)+h|0)>>>1;h=a+6|0;b[o>>1]=((b[h>>1]|0)-n|0)>>>1;b[h>>1]=((b[h>>1]|0)+n|0)>>>1;n=f|2;h=g+2|0;g=e+2|0;o=f|3;f=j+2|0;j=i+2|0;i=c+(e<<1)|0;e=a;a=c;c=d-1|0;while(1){d=e+8|0;l=a+4|0;q=i-4|0;m=e+(n<<2)|0;r=b[m>>1]|0;p=b[l>>1]|0;t=ba(p,r)|0;k=e+(n<<2)+2|0;s=b[k>>1]|0;u=b[q>>1]|0;v=(ba(u,s)|0)+t>>15;t=(ba(s,p)|0)-(ba(u,r)|0)>>15;r=e+(h<<2)|0;s=b[r>>1]|0;w=ba(s,p)|0;x=e+(h<<2)+2|0;y=b[x>>1]|0;z=w-(ba(y,u)|0)>>15;w=(ba(y,p)|0)+(ba(s,u)|0)>>15;u=z-v>>1;s=z+v>>1;v=d|0;b[m>>1]=((b[v>>1]|0)-s|0)>>>1;b[v>>1]=(s+(b[v>>1]|0)|0)>>>1;v=e+(g<<2)+2|0;b[x>>1]=((b[v>>1]|0)-u|0)>>>1;b[v>>1]=(u+(b[v>>1]|0)|0)>>>1;v=t-w>>1;u=w+t>>1;t=e+(g<<2)|0;b[r>>1]=((b[t>>1]|0)-v|0)>>>1;b[t>>1]=((b[t>>1]|0)+v|0)>>>1;v=e+10|0;b[k>>1]=((b[v>>1]|0)-u|0)>>>1;b[v>>1]=((b[v>>1]|0)+u|0)>>>1;u=e+(o<<2)|0;v=b[u>>1]|0;k=b[a+6>>1]|0;t=ba(k,v)|0;r=e+(o<<2)+2|0;w=b[r>>1]|0;x=b[i-6>>1]|0;s=(ba(x,w)|0)+t>>15;t=(ba(w,k)|0)-(ba(x,v)|0)>>15;v=e+(f<<2)|0;w=b[v>>1]|0;m=ba(w,k)|0;z=e+(f<<2)+2|0;p=b[z>>1]|0;y=m-(ba(p,x)|0)>>15;m=(ba(p,k)|0)+(ba(w,x)|0)>>15;x=y-s>>1;w=y+s>>1;s=e+12|0;b[u>>1]=((b[s>>1]|0)-w|0)>>>1;b[s>>1]=(w+(b[s>>1]|0)|0)>>>1;s=e+(j<<2)+2|0;b[z>>1]=((b[s>>1]|0)-x|0)>>>1;b[s>>1]=(x+(b[s>>1]|0)|0)>>>1;s=t-m>>1;x=m+t>>1;t=e+(j<<2)|0;b[v>>1]=((b[t>>1]|0)-s|0)>>>1;b[t>>1]=((b[t>>1]|0)+s|0)>>>1;s=e+14|0;b[r>>1]=((b[s>>1]|0)-x|0)>>>1;b[s>>1]=((b[s>>1]|0)+x|0)>>>1;x=c-1|0;if((x|0)==0){break}else{i=q;e=d;a=l;c=x}}return}function nqb(a,b,d,e,f,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=+f;j=+j;k=+k;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0.0,S=0.0,W=0.0;l=i;i=i+496|0;m=l|0;if(!((e-1|0)>>>0<30>>>0&f<1.0)){n=0;i=l;return n|0}o=cEb(16)|0;p=o;q=(o|0)==0;do{if(q){yDb(a,16,2169800,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}else{s=(e>>>1<<2)+4|0;t=WDb(s)|0;u=o+8|0;c[u>>2]=t;if((t|0)!=0|(s|0)==0){s=e<<2;t=WDb(s)|0;v=t;c[o+12>>2]=v;do{if((t|0)!=0|(s|0)==0){c[o>>2]=e;if((b|0)==2){if((d|0)!=0){yDb(a,16,2043008,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}if((e&1|0)!=0){yDb(a,16,1997920,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}k=+V(f*1.5707963267948966)*2.0;w=c[u>>2]|0;c[w>>2]=1;x=e>>1;y=x+1|0;if((x|0)>0){z=1;A=1;do{B=e-z|0;C=YGb(B,(B|0)<0|0?-1:0,1,0)|0;B=gHb(C,F,A,(A|0)<0|0?-1:0)|0;C=eHb(B,F,z,(z|0)<0|0?-1:0)|0;A=C;c[w+(z<<2)>>2]=A;z=z+1|0;}while((z|0)<(y|0))}y=m|0;h[y>>3]=1.0;z=m+8|0;h[z>>3]=0.0;a:do{if((e|0)<1){j=+h[m+(e<<4)>>3];A=o+4|0;g[A>>2]=j;D=j;E=A}else{A=1;while(1){w=A+1|0;TGb(m+(A<<4)|0,0,16)|0;if((w|0)>(e|0)){break}else{A=w}}if((e|0)<=0){j=+h[m+(e<<4)>>3];A=o+4|0;g[A>>2]=j;D=j;E=A;break}j=+(e|0);A=m+(e<<4)|0;w=m+(e<<4)+8|0;C=0;do{G=(+(C+x|0)+.5)*3.141592653589793/j;H=k*+T(G);I=k*+U(G);G=H+2.0;J=H+-2.0;H=I*I;K=J*J+H;L=(G*J+H)/K;H=(I*J-G*I)/K;B=e;K=+h[A>>3];I=+h[w>>3];while(1){M=B-1|0;G=+h[m+(M<<4)>>3];h[m+(B<<4)>>3]=G+(L*K-H*I);J=+h[m+(M<<4)+8>>3];h[m+(B<<4)+8>>3]=L*I+H*K+J;if((M|0)>0){B=M;K=G;I=J}else{break}}I=+h[y>>3];K=+h[z>>3];N=L*I-H*K;O=H*I+L*K;h[z>>3]=O;h[y>>3]=N;C=C+1|0;}while((C|0)<(e|0));j=+h[A>>3];K=j;C=o+4|0;g[C>>2]=K;I=+h[w>>3];J=j*j+I*I;B=0;G=K;K=N;P=O;while(1){Q=G+K;g[C>>2]=Q;g[v+(B<<2)>>2]=(j*(-0.0-K)+I*(-0.0-P))/J;M=B+1|0;if((M|0)>=(e|0)){D=Q;E=C;break a}B=M;G=Q;K=+h[m+(M<<4)>>3];P=+h[m+(M<<4)+8>>3]}}}while(0);g[E>>2]=D/+(1<<e|0);n=p;i=l;return n|0}else if((b|0)==1){if(d>>>0>1>>>0){yDb(a,16,2172728,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}if((e|0)!=2){yDb(a,16,2098264,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}k=f*3.141592653589793;P=+T(k);K=+U(k)*.5;k=K+1.0;if((d|0)==1){G=P+1.0;J=G*.5/k;I=J;g[o+4>>2]=I;R=-0.0-G;S=J;W=I}else{I=1.0-P;J=I*.5/k;G=J;g[o+4>>2]=G;R=I;S=J;W=G}g[v>>2]=(K+-1.0)/k;g[t+4>>2]=P*2.0/k;y=Gc(+(S/W))|0;c[c[u>>2]>>2]=y;y=Gc(+(R/k/+g[o+4>>2]))|0;c[(c[u>>2]|0)+4>>2]=y;n=p;i=l;return n|0}else{yDb(a,16,2302624,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}}else{yDb(a,16,2169800,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}}while(0);if(q){break}}else{yDb(a,16,2169800,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}ZDb(c[o+8>>2]|0);ZDb(c[o+12>>2]|0)}}while(0);ZDb(o);n=0;i=l;return n|0}function oqb(a){a=a|0;var b=0;if((a|0)==0){b=a;ZDb(b);return}ZDb(c[a+8>>2]|0);ZDb(c[a+12>>2]|0);b=a;ZDb(b);return}function pqb(a){a=a|0;return cEb(a<<2)|0}function qqb(a,b,d,e,f,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0,L=0,M=0.0,N=0.0;j=c[a>>2]|0;if((j|0)==4){if((d|0)<=0){return}k=a+4|0;l=c[a+12>>2]|0;m=b|0;n=l+4|0;o=b+4|0;p=l+8|0;q=b+8|0;r=l+12|0;s=b+12|0;t=f<<1;u=i<<1;v=t+f|0;w=u+i|0;x=v+f|0;y=w+i|0;z=0;A=e;B=h;C=+g[s>>2];while(1){D=+g[m>>2];E=+g[o>>2];F=+g[q>>2];G=+g[A>>2]*+g[k>>2]+ +g[l>>2]*D+ +g[n>>2]*E+ +g[p>>2]*F+ +g[r>>2]*C;g[B>>2]=F*6.0+((E+C)*4.0+(D+G));g[m>>2]=G;D=+g[o>>2];E=+g[q>>2];F=+g[s>>2];H=+g[A+(f<<2)>>2]*+g[k>>2]+ +g[l>>2]*D+ +g[n>>2]*E+ +g[p>>2]*F+G*+g[r>>2];g[B+(i<<2)>>2]=F*6.0+((G+E)*4.0+(D+H));g[o>>2]=H;D=+g[q>>2];E=+g[s>>2];G=+g[m>>2];F=+g[A+(t<<2)>>2]*+g[k>>2]+ +g[l>>2]*D+ +g[n>>2]*E+ +g[p>>2]*G+H*+g[r>>2];g[B+(u<<2)>>2]=G*6.0+((H+E)*4.0+(D+F));g[q>>2]=F;D=+g[s>>2];E=+g[m>>2];H=+g[o>>2];G=+g[A+(v<<2)>>2]*+g[k>>2]+ +g[l>>2]*D+ +g[n>>2]*E+ +g[p>>2]*H+F*+g[r>>2];g[B+(w<<2)>>2]=H*6.0+((F+E)*4.0+(D+G));g[s>>2]=G;I=z+4|0;if((I|0)<(d|0)){z=I;A=A+(x<<2)|0;B=B+(y<<2)|0;C=G}else{break}}return}else if((j|0)==2){if((d|0)<=0){return}y=a+4|0;B=b|0;x=c[a+12>>2]|0;A=b+4|0;z=x+4|0;C=+(c[(c[a+8>>2]|0)+4>>2]|0);s=h;w=e;r=0;G=+g[B>>2];D=+g[A>>2];while(1){E=+g[w>>2]*+g[y>>2]+G*+g[x>>2]+D*+g[z>>2];g[s>>2]=G+E+D*C;F=+g[A>>2];g[B>>2]=F;g[A>>2]=E;p=r+1|0;if((p|0)<(d|0)){s=s+(i<<2)|0;w=w+(f<<2)|0;r=p;G=F;D=E}else{break}}return}else{if((d|0)<=0){return}r=a+4|0;w=b|0;s=c[a+8>>2]|0;A=j>>1;B=(A|0)>1;z=j-1|0;x=(z|0)>0;y=b+(z<<2)|0;p=a+12|0;if((j|0)>0){J=0;K=e;L=h}else{a=0;n=e;e=h;while(1){D=+g[n>>2]*+g[r>>2];G=D+ +g[w>>2]+ +g[b+(A<<2)>>2]*+(c[s+(A<<2)>>2]|0);if(B){h=1;C=G;while(1){E=C+(+g[b+(h<<2)>>2]+ +g[b+(j-h<<2)>>2])*+(c[s+(h<<2)>>2]|0);l=h+1|0;if((l|0)<(A|0)){h=l;C=E}else{M=E;break}}}else{M=G}if(x){h=0;while(1){l=h+1|0;g[b+(h<<2)>>2]=+g[b+(l<<2)>>2];if((l|0)<(z|0)){h=l}else{break}}}g[e>>2]=M;g[y>>2]=D;h=a+1|0;if((h|0)<(d|0)){a=h;n=n+(f<<2)|0;e=e+(i<<2)|0}else{break}}return}while(1){e=c[p>>2]|0;n=0;M=+g[K>>2]*+g[r>>2];do{M=M+ +g[e+(n<<2)>>2]*+g[b+(n<<2)>>2];n=n+1|0;}while((n|0)<(j|0));D=M+ +g[w>>2]+ +g[b+(A<<2)>>2]*+(c[s+(A<<2)>>2]|0);if(B){n=1;G=D;while(1){C=G+(+g[b+(n<<2)>>2]+ +g[b+(j-n<<2)>>2])*+(c[s+(n<<2)>>2]|0);e=n+1|0;if((e|0)<(A|0)){n=e;G=C}else{N=C;break}}}else{N=D}if(x){n=0;while(1){e=n+1|0;g[b+(n<<2)>>2]=+g[b+(e<<2)>>2];if((e|0)<(z|0)){n=e}else{break}}}g[L>>2]=N;g[y>>2]=M;n=J+1|0;if((n|0)<(d|0)){J=n;K=K+(f<<2)|0;L=L+(i<<2)|0}else{break}}return}}function rqb(a){a=a|0;ZDb(a);return}function sqb(a){a=a|0;c[a>>2]=184;return}function tqb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0,j=0,k=0;if((a|0)==0){e=-22;return e|0}if((c[a+6964>>2]|0)!=0){e=-22;return e|0}TGb(a+6984|0,0,4096)|0;f=a+24|0;i=hBb(c[f>>2]|0,c[f+4>>2]|0)|0;f=a+32|0;j=hBb(c[f>>2]|0,c[f+4>>2]|0)|0;if((j|0)>0&(i|0)>0){f=b;b=0;while(1){k=0;do{g[a+6984+(b<<7)+(k<<2)>>2]=+h[f+(k<<3)>>3];k=k+1|0;}while((k|0)<(i|0));k=b+1|0;if((k|0)<(j|0)){f=f+(d<<3)|0;b=k}else{break}}}c[a+5704>>2]=1;e=0;return e|0}function uqb(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0.0,E=0.0,G=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0,P=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;d=i;i=i+33024|0;e=d+128|0;f=b+24|0;j=hBb(c[f>>2]|0,c[f+4>>2]|0)|0;k=b+32|0;l=hBb(c[k>>2]|0,c[k+4>>2]|0)|0;m=b+16264|0;c[m>>2]=0;a:do{if((c[b+5704>>2]|0)==0){n=d+32896|0;TGb(e|0,0,32768)|0;o=c[b+72>>2]|0;p=c[f>>2]|0;q=c[f+4>>2]|0;r=d|0;do{if((p|0)==4&(q|0)==0|(p|0)==0&(q|0)==0){s=5}else{t=YGb(p,q,-1,-1)|0;if(!((t&p|0)==0&(F&q|0)==0)){s=5;break}iBb(r,128,-1,p,q);yDb(b,40,1890208,(u=i,i=i+8|0,c[u>>2]=r,u)|0);i=u;v=0;w=4}}while(0);if((s|0)==5){q=p;v=(q|0)<0|0?-1:0;w=q}q=c[k>>2]|0;t=c[k+4>>2]|0;do{if((q|0)==4&(t|0)==0|(q|0)==0&(t|0)==0){s=9}else{x=YGb(q,t,-1,-1)|0;if(!((x&q|0)==0&(F&t|0)==0)){s=9;break}iBb(r,128,-1,q,t);yDb(b,40,1890208,(u=i,i=i+8|0,c[u>>2]=r,u)|0);i=u;y=0;z=4}}while(0);do{if((s|0)==9){r=q;t=r;p=(r|0)<0|0?-1:0;if((r|0)!=1610612736){y=p;z=t;break}r=(w&1610612736|0)==0&(v&0|0)==0;y=r?0:p;z=r?3:t}}while(0);do{if(!((w&7|0)==0&(v&0|0)==0)){q=w&3;t=v&0;r=(q|0)==0&(t|0)==0;if(!r){p=YGb(w,v,3,0)|0;if((p&q|0)==0&(F&t|0)==0){break}}t=w&1536;q=v&0;if(!((t|0)==0&(q|0)==0)){p=YGb(t,q,2047,0)|0;if((p&t|0)==0&(F&q|0)==0){break}}q=w&48;t=v&0;if(!((q|0)==0&(t|0)==0)){p=YGb(q,t,63,0)|0;if((p&q|0)==0&(F&t|0)==0){break}}t=w&192;q=v&0;if(!((t|0)==0&(q|0)==0)){p=YGb(t,q,255,0)|0;if((p&t|0)==0&(F&q|0)==0){break}}if((hBb(w,v)|0)>=32){break}do{if(!((z&7|0)==0&(y&0|0)==0)){q=z&3;t=y&0;if(!((q|0)==0&(t|0)==0)){p=YGb(z,y,3,0)|0;if((p&q|0)==0&(F&t|0)==0){break}}p=z&1536;x=y&0;if(!((p|0)==0&(x|0)==0)){A=YGb(p,x,2047,0)|0;if((A&p|0)==0&(F&x|0)==0){break}}x=z&48;p=y&0;if(!((x|0)==0&(p|0)==0)){A=YGb(x,p,63,0)|0;if((A&x|0)==0&(F&p|0)==0){break}}p=z&192;x=y&0;if(!((p|0)==0&(x|0)==0)){A=YGb(p,x,255,0)|0;if((A&p|0)==0&(F&x|0)==0){break}}if((hBb(z,y)|0)>=32){break}TGb(b+6984|0,0,4096)|0;x=z&w;p=y&v;A=0;do{B=_Gb(1,0,A|0)|0;if(!((x&B|0)==0&(p&F|0)==0)){h[e+(A<<9)+(A<<3)>>3]=1.0}A=A+1|0;}while((A|0)<64);A=w&~z;p=v&~y;do{if(!((A&4|0)==0&(p&0|0)==0)){if(!((q|0)==3&(t|0)==0)){yDb(0,0,2169680,(u=i,i=i+24|0,c[u>>2]=2302616,c[u+8>>2]=2172696,c[u+16>>2]=164,u)|0);i=u;Cd();return 0}if(r){x=e+16|0;h[x>>3]=+h[x>>3]+.7071067811865476;x=e+528|0;h[x>>3]=+h[x>>3]+.7071067811865476;break}else{C=+g[b+56>>2];x=e+16|0;h[x>>3]=+h[x>>3]+C;x=e+528|0;h[x>>3]=C+ +h[x>>3];break}}}while(0);do{if(!((A&3|0)==0&(p&0|0)==0)){if((z&4|0)==0&(y&0|0)==0){yDb(0,0,2169680,(u=i,i=i+24|0,c[u>>2]=2302616,c[u+8>>2]=2172696,c[u+16>>2]=173,u)|0);i=u;Cd();return 0}t=e+1024|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+1032|0;h[t>>3]=+h[t>>3]+.7071067811865476;if((w&4|0)==0&(v&0|0)==0){break}h[e+1040>>3]=+g[b+56>>2]*1.4142135623730951}}while(0);do{if(!((A&256|0)==0&(p&0|0)==0)){if(!((z&16|0)==0&(y&0|0)==0)){t=e+2112|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+2624|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}if(!((z&512|0)==0&(y&0|0)==0)){t=e+4672|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+5184|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}if((z&1|0)==0&(y&0|0)==0){if((z&4|0)==0&(y&0|0)==0){yDb(0,0,2169680,(u=i,i=i+24|0,c[u>>2]=2302616,c[u+8>>2]=2172696,c[u+16>>2]=200,u)|0);i=u;Cd();return 0}else{t=e+1088|0;h[t>>3]=+h[t>>3]+ +g[b+52>>2]*.7071067811865476;break}}if(!((o-1|0)>>>0<2>>>0)){C=+g[b+52>>2]*.7071067811865476;t=e+64|0;h[t>>3]=+h[t>>3]+C;t=e+576|0;h[t>>3]=+h[t>>3]+C;break}C=+g[b+52>>2];if((A&528|0)==0&(p&0|0)==0){t=e+64|0;h[t>>3]=+h[t>>3]-C;t=e+576|0;h[t>>3]=C+ +h[t>>3];break}else{D=C*.7071067811865476;t=e+64|0;h[t>>3]=+h[t>>3]-D;t=e+576|0;h[t>>3]=D+ +h[t>>3];break}}}while(0);do{if(!((A&16|0)==0&(p&0|0)==0)){if(!((z&256|0)==0&(y&0|0)==0)){t=e+4128|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+4136|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}if(!((z&512|0)==0&(y&0|0)==0)){t=e+4640|0;D=+h[t>>3];if((w&512|0)==0&(v&0|0)==0){h[t>>3]=D+1.0;q=e+5160|0;h[q>>3]=+h[q>>3]+1.0;break}else{h[t>>3]=D+.7071067811865476;t=e+5160|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}}if((z&1|0)==0&(y&0|0)==0){if((z&4|0)==0&(y&0|0)==0){yDb(0,0,2169680,(u=i,i=i+24|0,c[u>>2]=2302616,c[u+8>>2]=2172696,c[u+16>>2]=233,u)|0);i=u;Cd();return 0}else{D=+g[b+52>>2]*.7071067811865476;t=e+1056|0;h[t>>3]=+h[t>>3]+D;t=e+1064|0;h[t>>3]=+h[t>>3]+D;break}}if((o|0)==1){D=+g[b+52>>2]*.7071067811865476;t=e+32|0;h[t>>3]=+h[t>>3]-D;t=e+40|0;h[t>>3]=+h[t>>3]-D;t=e+544|0;h[t>>3]=D+ +h[t>>3];t=e+552|0;h[t>>3]=D+ +h[t>>3];break}D=+g[b+52>>2];if((o|0)==2){C=D*1.224744871391589;t=e+32|0;h[t>>3]=+h[t>>3]-C;E=D*.7071067811865476;t=e+40|0;h[t>>3]=+h[t>>3]-E;t=e+544|0;h[t>>3]=E+ +h[t>>3];t=e+552|0;h[t>>3]=C+ +h[t>>3];break}else{t=e+32|0;h[t>>3]=D+ +h[t>>3];t=e+552|0;h[t>>3]=D+ +h[t>>3];break}}}while(0);do{if(!((A&512|0)==0&(p&0|0)==0)){if(!((z&16|0)==0&(y&0|0)==0)){t=e+2120|0;D=+h[t>>3];if((w&16|0)==0&(v&0|0)==0){h[t>>3]=D+1.0;q=e+2640|0;h[q>>3]=+h[q>>3]+1.0;break}else{h[t>>3]=D+.7071067811865476;t=e+2640|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}}if(!((z&256|0)==0&(y&0|0)==0)){t=e+4168|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+4176|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}if((z&1|0)==0&(y&0|0)==0){if((z&4|0)==0&(y&0|0)==0){yDb(0,0,2169680,(u=i,i=i+24|0,c[u>>2]=2302616,c[u+8>>2]=2172696,c[u+16>>2]=269,u)|0);i=u;Cd();return 0}else{D=+g[b+52>>2]*.7071067811865476;t=e+1096|0;h[t>>3]=+h[t>>3]+D;t=e+1104|0;h[t>>3]=+h[t>>3]+D;break}}if((o|0)==1){D=+g[b+52>>2]*.7071067811865476;t=e+72|0;h[t>>3]=+h[t>>3]-D;t=e+80|0;h[t>>3]=+h[t>>3]-D;t=e+584|0;h[t>>3]=D+ +h[t>>3];t=e+592|0;h[t>>3]=D+ +h[t>>3];break}D=+g[b+52>>2];if((o|0)==2){C=D*1.224744871391589;t=e+72|0;h[t>>3]=+h[t>>3]-C;E=D*.7071067811865476;t=e+80|0;h[t>>3]=+h[t>>3]-E;t=e+584|0;h[t>>3]=E+ +h[t>>3];t=e+592|0;h[t>>3]=C+ +h[t>>3];break}else{t=e+72|0;h[t>>3]=D+ +h[t>>3];t=e+592|0;h[t>>3]=D+ +h[t>>3];break}}}while(0);do{if(!((A&64|0)==0&(p&0|0)==0)){if(!((z&1|0)==0&(y&0|0)==0)){t=e+48|0;h[t>>3]=+h[t>>3]+1.0;t=e+568|0;h[t>>3]=+h[t>>3]+1.0;break}if((z&4|0)==0&(y&0|0)==0){yDb(0,0,2169680,(u=i,i=i+24|0,c[u>>2]=2302616,c[u+8>>2]=2172696,c[u+16>>2]=280,u)|0);i=u;Cd();return 0}else{t=e+1072|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+1080|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}}}while(0);do{if((A&8|0)==0&(p&0|0)==0){G=0;H=0;I=0.0}else{if(!((z&4|0)==0&(y&0|0)==0)){t=e+1048|0;h[t>>3]=+h[t>>3]+ +g[b+60>>2];G=0;H=0;I=0.0;break}if((z&1|0)==0&(y&0|0)==0){yDb(0,0,2169680,(u=i,i=i+24|0,c[u>>2]=2302616,c[u+8>>2]=2172696,c[u+16>>2]=290,u)|0);i=u;Cd();return 0}else{D=+g[b+60>>2]*.7071067811865476;t=e+24|0;h[t>>3]=+h[t>>3]+D;t=e+536|0;h[t>>3]=+h[t>>3]+D;G=0;H=0;I=0.0;break}}}while(0);while(1){p=0;D=0.0;A=0;while(1){C=+h[e+(H<<9)+(p<<3)>>3];g[b+6984+(G<<7)+(A<<2)>>2]=C;if(C!=0.0){J=D+ +Q(+C)}else{J=D}t=_Gb(1,0,p|0)|0;q=p+1|0;if((q|0)<64){p=q;D=J;A=(((t&w|0)!=0|(F&v|0)!=0)&1)+A|0}else{break}}K=I>J?I:J;A=_Gb(1,0,H|0)|0;p=H+1|0;if((p|0)<64){G=(((A&z|0)!=0|(F&y|0)!=0)&1)+G|0;H=p;I=K}else{break}}p=b+64|0;D=+g[p>>2];if(D<0.0){L=-0.0-D}else{L=K}D=+g[b+68>>2];do{if(D>0.0){M=D}else{if((yFb(c[b+20>>2]|0)|0)<3){M=1.0;break}A=(yFb(c[b+16>>2]|0)|0)<3;M=A?1.0:2147483648.0}}while(0);if(L>M){s=119}else{D=+g[p>>2];if(D<0.0){s=119}else{N=D}}if((s|0)==119){D=L/M;A=0;do{t=0;do{q=b+6984+(A<<7)+(t<<2)|0;g[q>>2]=+g[q>>2]/D;t=t+1|0;}while((t|0)<32);A=A+1|0;}while((A|0)<32);N=+g[p>>2]}if(N>0.0){A=0;do{t=0;do{q=b+6984+(A<<7)+(t<<2)|0;g[q>>2]=+g[p>>2]*+g[q>>2];t=t+1|0;}while((t|0)<32);A=A+1|0;}while((A|0)<32)}if((hBb(z,y)|0)>0){O=0}else{break a}while(1){if((hBb(w,v)|0)>0){A=0;do{yDb(0,48,1933480,(u=i,i=i+8|0,h[u>>3]=+g[b+6984+(O<<7)+(A<<2)>>2],u)|0);i=u;A=A+1|0;}while((A|0)<(hBb(w,v)|0))}yDb(0,48,1910480,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;O=O+1|0;if((O|0)>=(hBb(z,y)|0)){break a}}}}while(0);iBb(n,128,-1,c[k>>2]|0,c[k+4>>2]|0);yDb(b,16,1961320,(u=i,i=i+8|0,c[u>>2]=n,u)|0);i=u;P=-22;i=d;return P|0}}while(0);iBb(n,128,-1,c[f>>2]|0,c[f+4>>2]|0);yDb(b,16,1997872,(u=i,i=i+8|0,c[u>>2]=n,u)|0);i=u;P=-22;i=d;return P|0}}while(0);y=c[b+6160>>2]|0;if((y|0)==6){z=b+11080|0;c[z>>2]=dEb(ba(l,j)|0,4)|0;O=cEb(4)|0;v=b+11084|0;c[v>>2]=O;if((l|0)>0&(j|0)>0){w=0;do{H=ba(w,j)|0;G=0;do{e=Gc(+(+g[b+6984+(w<<7)+(G<<2)>>2]*32768.0))|0;c[(c[z>>2]|0)+(G+H<<2)>>2]=e;G=G+1|0;}while((G|0)<(j|0));w=w+1|0;}while((w|0)<(l|0));R=c[v>>2]|0}else{R=O}c[R>>2]=32768;c[b+16248>>2]=198;c[b+16256>>2]=252;do{if((c[k>>2]|0)==3&(c[k+4>>2]|0)==0){R=c[f>>2]|0;O=c[f+4>>2]|0;v=1599;w=0;if((R|0)==1551&(O|0)==0|(R|0)==63&(O|0)==0){if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=154;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=154;break}if(+g[b+6988>>2]!=0.0){s=154;break}if(+g[b+7004>>2]!=0.0){s=154;break}if(+g[b+7112>>2]!=0.0){s=154;break}if(+g[b+7128>>2]!=0.0){s=154;break}else{S=210;break}}else if(!((R|0)==(v|0)&(O|0)==(w|0))){s=154;break}if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=154;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=154;break}if(+g[b+6988>>2]!=0.0){s=154;break}if(+g[b+7004>>2]!=0.0){s=154;break}if(+g[b+7112>>2]!=0.0){s=154;break}if(+g[b+7128>>2]!=0.0){s=154;break}if(+g[b+7012>>2]!=0.0){s=154;break}if(+g[b+7136>>2]!=0.0){s=154}else{S=864}}else{s=154}}while(0);if((s|0)==154){S=0}c[m>>2]=S;T=0}else if((y|0)==8){S=b+11080|0;c[S>>2]=dEb(ba(l,j)|0,4)|0;w=cEb(4)|0;c[b+11084>>2]=w;if((l|0)>0&(j|0)>0){O=0;do{v=ba(O,j)|0;R=c[S>>2]|0;z=0;do{g[R+(z+v<<2)>>2]=+g[b+6984+(O<<7)+(z<<2)>>2];z=z+1|0;}while((z|0)<(j|0));O=O+1|0;}while((O|0)<(l|0))}g[w>>2]=1.0;c[b+16248>>2]=96;c[b+16256>>2]=172;do{if((c[k>>2]|0)==3&(c[k+4>>2]|0)==0){w=c[f>>2]|0;O=c[f+4>>2]|0;S=1599;z=0;if((w|0)==1551&(O|0)==0|(w|0)==63&(O|0)==0){if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=176;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=176;break}if(+g[b+6988>>2]!=0.0){s=176;break}if(+g[b+7004>>2]!=0.0){s=176;break}if(+g[b+7112>>2]!=0.0){s=176;break}if(+g[b+7128>>2]!=0.0){s=176;break}else{U=788;break}}else if(!((w|0)==(S|0)&(O|0)==(z|0))){s=176;break}if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=176;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=176;break}if(+g[b+6988>>2]!=0.0){s=176;break}if(+g[b+7004>>2]!=0.0){s=176;break}if(+g[b+7112>>2]!=0.0){s=176;break}if(+g[b+7128>>2]!=0.0){s=176;break}if(+g[b+7012>>2]!=0.0){s=176;break}if(+g[b+7136>>2]!=0.0){s=176}else{U=816}}else{s=176}}while(0);if((s|0)==176){U=0}c[m>>2]=U;T=0}else if((y|0)==9){U=b+11080|0;c[U>>2]=dEb(ba(l,j)|0,8)|0;z=cEb(8)|0;c[b+11084>>2]=z;if((l|0)>0&(j|0)>0){O=0;do{S=ba(O,j)|0;w=c[U>>2]|0;v=0;do{h[w+(v+S<<3)>>3]=+g[b+6984+(O<<7)+(v<<2)>>2];v=v+1|0;}while((v|0)<(j|0));O=O+1|0;}while((O|0)<(l|0))}h[z>>3]=1.0;c[b+16248>>2]=218;c[b+16256>>2]=60;do{if((c[k>>2]|0)==3&(c[k+4>>2]|0)==0){z=c[f>>2]|0;l=c[f+4>>2]|0;O=1599;j=0;if((z|0)==1551&(l|0)==0|(z|0)==63&(l|0)==0){if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=198;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=198;break}if(+g[b+6988>>2]!=0.0){s=198;break}if(+g[b+7004>>2]!=0.0){s=198;break}if(+g[b+7112>>2]!=0.0){s=198;break}if(+g[b+7128>>2]!=0.0){s=198;break}else{V=230;break}}else if(!((z|0)==(O|0)&(l|0)==(j|0))){s=198;break}if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=198;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=198;break}if(+g[b+6988>>2]!=0.0){s=198;break}if(+g[b+7004>>2]!=0.0){s=198;break}if(+g[b+7112>>2]!=0.0){s=198;break}if(+g[b+7128>>2]!=0.0){s=198;break}if(+g[b+7012>>2]!=0.0){s=198;break}if(+g[b+7136>>2]!=0.0){s=198}else{V=98}}else{s=198}}while(0);if((s|0)==198){V=0}c[m>>2]=V;T=0}else if((y|0)==7){y=cEb(4)|0;c[b+11084>>2]=y;c[y>>2]=32768;c[b+16248>>2]=180;c[b+16256>>2]=268;do{if((c[k>>2]|0)==3&(c[k+4>>2]|0)==0){y=c[f>>2]|0;V=c[f+4>>2]|0;j=1599;l=0;if((y|0)==1551&(V|0)==0|(y|0)==63&(V|0)==0){if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=216;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=216;break}if(+g[b+6988>>2]!=0.0){s=216;break}if(+g[b+7004>>2]!=0.0){s=216;break}if(+g[b+7112>>2]!=0.0){s=216;break}if(+g[b+7128>>2]!=0.0){s=216;break}else{W=232;break}}else if(!((y|0)==(j|0)&(V|0)==(l|0))){s=216;break}if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=216;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=216;break}if(+g[b+6988>>2]!=0.0){s=216;break}if(+g[b+7004>>2]!=0.0){s=216;break}if(+g[b+7112>>2]!=0.0){s=216;break}if(+g[b+7128>>2]!=0.0){s=216;break}if(+g[b+7012>>2]!=0.0){s=216;break}if(+g[b+7136>>2]!=0.0){s=216}else{W=832}}else{s=216}}while(0);if((s|0)==216){W=0}c[m>>2]=W;T=0}else{yDb(0,0,2169680,(u=i,i=i+24|0,c[u>>2]=2302616,c[u+8>>2]=2172696,c[u+16>>2]=397,u)|0);i=u;Cd();return 0}while(1){u=0;W=0;while(1){m=b+6984+(T<<7)+(u<<2)|0;c[b+11096+(T<<7)+(u<<2)>>2]=Gc(+(+g[m>>2]*32768.0))|0;if(+g[m>>2]!=0.0){m=W+1|0;a[b+15192+(T*33|0)+m|0]=u;X=m}else{X=W}m=u+1|0;if((m|0)<32){u=m;W=X}else{break}}a[b+15192+(T*33|0)|0]=X;W=T+1|0;if((W|0)<32){T=W}else{P=0;break}}i=d;return P|0}function vqb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=c[e+(f<<2)>>2]|0;if((g|0)>0){i=0}else{return}do{b[a+(i<<1)>>1]=((ba(b[d+(i<<1)>>1]|0,h)|0)+16384|0)>>>15;i=i+1|0;}while((i|0)<(g|0));return}function wqb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=c[f+(g<<2)>>2]|0;g=c[f+(h<<2)>>2]|0;if((i|0)>0){k=0}else{return}do{h=ba(b[d+(k<<1)>>1]|0,j)|0;b[a+(k<<1)>>1]=(h+16384+(ba(b[e+(k<<1)>>1]|0,g)|0)|0)>>>15;k=k+1|0;}while((k|0)<(i|0));return}function xqb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,h=0;f=+g[c+(d<<2)>>2];if((e|0)>0){h=0}else{return}do{g[a+(h<<2)>>2]=f*+g[b+(h<<2)>>2];h=h+1|0;}while((h|0)<(e|0));return}function yqb(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0.0,j=0.0,k=0;i=+g[d+(e<<2)>>2];j=+g[d+(f<<2)>>2];if((h|0)>0){k=0}else{return}do{g[a+(k<<2)>>2]=i*+g[b+(k<<2)>>2]+j*+g[c+(k<<2)>>2];k=k+1|0;}while((k|0)<(h|0));return}function zqb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,g=0;f=+h[c+(d<<3)>>3];if((e|0)>0){g=0}else{return}do{h[a+(g<<3)>>3]=f*+h[b+(g<<3)>>3];g=g+1|0;}while((g|0)<(e|0));return}function Aqb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0.0,j=0.0,k=0;i=+h[d+(e<<3)>>3];j=+h[d+(f<<3)>>3];if((g|0)>0){k=0}else{return}do{h[a+(k<<3)>>3]=i*+h[b+(k<<3)>>3]+j*+h[c+(k<<3)>>3];k=k+1|0;}while((k|0)<(g|0));return}function Bqb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[d+(e<<2)>>2]|0;e=g;d=(g|0)<0|0?-1:0;if((f|0)>0){h=0}else{return}do{g=c[b+(h<<2)>>2]|0;i=gHb(g,(g|0)<0|0?-1:0,e,d)|0;g=YGb(i,F,16384,0)|0;c[a+(h<<2)>>2]=g>>>15|F<<17;h=h+1|0;}while((h|0)<(f|0));return}function Cqb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=c[e+(f<<2)>>2]|0;f=i;j=(i|0)<0|0?-1:0;i=c[e+(g<<2)>>2]|0;g=i;e=(i|0)<0|0?-1:0;if((h|0)>0){k=0}else{return}do{i=c[b+(k<<2)>>2]|0;l=gHb(i,(i|0)<0|0?-1:0,f,j)|0;i=F;m=c[d+(k<<2)>>2]|0;n=gHb(m,(m|0)<0|0?-1:0,g,e)|0;m=F;o=YGb(l,i,16384,0)|0;i=YGb(o,F,n,m)|0;c[a+(k<<2)>>2]=i>>>15|F<<17;k=k+1|0;}while((k|0)<(h|0));return}function Dqb(a){a=a|0;$Db(a+11080|0);$Db(a+11084|0);$Db(a+11092|0);$Db(a+11088|0);return}function Eqb(e,f,j,k,l){e=e|0;f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0,O=0.0,P=0,Q=0,R=0.0,S=0.0,T=0;m=i;n=c[e+16264>>2]|0;if((n|0)!=0){cf[n&1023](f|0,j|0,c[e+11080>>2]|0,k);i=m;return 0}n=e+16260|0;if((c[n>>2]|0)==0){if((c[e+16252>>2]|0)==0){o=0;p=0}else{q=5}}else{q=5}if((q|0)==5){q=k&-16;o=ba(c[f+136>>2]|0,q)|0;p=q}q=e+32|0;r=c[q>>2]|0;s=c[q+4>>2]|0;do{if(!((r|0)==0&(s|0)==0)){q=c[f+132>>2]|0;if((q|0)==(hBb(r,s)|0)){break}yDb(0,0,2169680,(t=i,i=i+24|0,c[t>>2]=2098168,c[t+8>>2]=2172696,c[t+16>>2]=436,t)|0);i=t;Cd();return 0}}while(0);s=e+24|0;r=c[s>>2]|0;q=c[s+4>>2]|0;do{if(!((r|0)==0&(q|0)==0)){s=c[j+132>>2]|0;if((s|0)==(hBb(r,q)|0)){break}yDb(0,0,2169680,(t=i,i=i+24|0,c[t>>2]=2042912,c[t+8>>2]=2172696,c[t+16>>2]=437,t)|0);i=t;Cd();return 0}}while(0);t=f+132|0;if((c[t>>2]|0)<=0){i=m;return 0}q=e+16|0;r=(k|0)>0;s=(l|0)==0;l=e+16252|0;u=(p|0)==0;v=(p|0)==(k|0);w=e+16248|0;x=e+11080|0;y=j+132|0;z=k-p|0;A=e+11092|0;B=f+136|0;C=e+16256|0;D=0;do{E=e+15192+(D*33|0)|0;F=a[E]|0;G=F&255;a:do{if((G|0)==0){if(s){break}H=c[f+(D<<2)>>2]|0;TGb(H|0,0,ba(BFb(c[q>>2]|0)|0,k)|0)|0}else if((G|0)==1){H=d[e+15192+(D*33|0)+1|0]|0;if(!(+g[e+6984+(D<<7)+(H<<2)>>2]!=1.0)){if(s){c[f+(D<<2)>>2]=c[j+(H<<2)>>2];break}else{UGb(c[f+(D<<2)>>2]|0,c[j+(H<<2)>>2]|0,ba(c[B>>2]|0,k)|0)|0;break}}I=c[l>>2]|0;if(!((I|0)==0|u)){J=(ba(c[y>>2]|0,D)|0)+H|0;le[I&1023](c[f+(D<<2)>>2]|0,c[j+(H<<2)>>2]|0,c[A>>2]|0,J,p)}if(v){break}J=(ba(c[y>>2]|0,D)|0)+H|0;le[c[w>>2]&1023]((c[f+(D<<2)>>2]|0)+o|0,(c[j+(H<<2)>>2]|0)+o|0,c[x>>2]|0,J,z)}else if((G|0)==2){J=d[e+15192+(D*33|0)+1|0]|0;H=d[e+15192+(D*33|0)+2|0]|0;I=c[n>>2]|0;if((I|0)==0|u){K=ba(c[y>>2]|0,D)|0;Ke[c[C>>2]&1023](c[f+(D<<2)>>2]|0,c[j+(J<<2)>>2]|0,c[j+(H<<2)>>2]|0,c[x>>2]|0,K+J|0,K+H|0,p)}else{K=ba(c[y>>2]|0,D)|0;Ke[I&1023](c[f+(D<<2)>>2]|0,c[j+(J<<2)>>2]|0,c[j+(H<<2)>>2]|0,c[A>>2]|0,K+J|0,K+H|0,p)}if(v){break}K=ba(c[y>>2]|0,D)|0;Ke[c[C>>2]&1023]((c[f+(D<<2)>>2]|0)+o|0,(c[j+(J<<2)>>2]|0)+o|0,(c[j+(H<<2)>>2]|0)+o|0,c[x>>2]|0,K+J|0,K+H|0,z)}else{H=c[q>>2]|0;if((H|0)==8){if(!r){break}K=f+(D<<2)|0;J=0;I=F;while(1){if(I<<24>>24==0){L=0.0}else{M=I&255;N=0;O=0.0;while(1){P=N+1|0;Q=d[e+15192+(D*33|0)+P|0]|0;R=O+ +g[(c[j+(Q<<2)>>2]|0)+(J<<2)>>2]*+g[e+6984+(D<<7)+(Q<<2)>>2];if((P|0)<(M|0)){N=P;O=R}else{L=R;break}}}g[(c[K>>2]|0)+(J<<2)>>2]=L;N=J+1|0;if((N|0)>=(k|0)){break a}J=N;I=a[E]|0}}else if((H|0)==9){if(!r){break}I=f+(D<<2)|0;J=0;K=F;while(1){if(K<<24>>24==0){S=0.0}else{N=K&255;M=0;O=0.0;while(1){P=M+1|0;Q=d[e+15192+(D*33|0)+P|0]|0;R=O+ +h[(c[j+(Q<<2)>>2]|0)+(J<<3)>>3]*+g[e+6984+(D<<7)+(Q<<2)>>2];if((P|0)<(N|0)){M=P;O=R}else{S=R;break}}}h[(c[I>>2]|0)+(J<<3)>>3]=S;M=J+1|0;if((M|0)>=(k|0)){break a}J=M;K=a[E]|0}}else{if(!r){break}K=f+(D<<2)|0;J=0;I=F;while(1){if(I<<24>>24==0){T=0}else{H=I&255;M=0;N=0;do{M=M+1|0;P=d[e+15192+(D*33|0)+M|0]|0;N=(ba(b[(c[j+(P<<2)>>2]|0)+(J<<1)>>1]|0,c[e+11096+(D<<7)+(P<<2)>>2]|0)|0)+N|0;}while((M|0)<(H|0));T=(N+16384|0)>>>15&65535}b[(c[K>>2]|0)+(J<<1)>>1]=T;H=J+1|0;if((H|0)>=(k|0)){break a}J=H;I=a[E]|0}}}}while(0);D=D+1|0;}while((D|0)<(c[t>>2]|0));i=m;return 0}function Fqb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((e|0)<=0){return}f=c[b+8>>2]|0;g=d+8|0;h=c[b+12>>2]|0;i=d+12|0;j=c[b>>2]|0;k=c[b+16>>2]|0;l=d+16|0;m=c[a>>2]|0;n=c[b+4>>2]|0;o=d+28|0;p=c[b+20>>2]|0;b=d+44|0;q=c[a+4>>2]|0;a=0;do{r=c[f+(a<<2)>>2]|0;s=c[g>>2]|0;t=gHb(s,(s|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;r=F;s=c[h+(a<<2)>>2]|0;u=c[i>>2]|0;v=gHb(u,(u|0)<0|0?-1:0,s,(s|0)<0|0?-1:0)|0;s=YGb(v,F,t,r)|0;r=F;t=c[j+(a<<2)>>2]|0;v=c[d>>2]|0;u=gHb(v,(v|0)<0|0?-1:0,t,(t|0)<0|0?-1:0)|0;t=F;v=c[k+(a<<2)>>2]|0;w=c[l>>2]|0;x=gHb(w,(w|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=F;w=YGb(s,r,16384,0)|0;r=F;s=YGb(w,r,u,t)|0;t=YGb(s,F,x,v)|0;c[m+(a<<2)>>2]=t>>>15|F<<17;t=c[n+(a<<2)>>2]|0;v=c[o>>2]|0;x=gHb(v,(v|0)<0|0?-1:0,t,(t|0)<0|0?-1:0)|0;t=F;v=c[p+(a<<2)>>2]|0;s=c[b>>2]|0;u=gHb(s,(s|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=F;s=YGb(w,r,x,t)|0;t=YGb(s,F,u,v)|0;c[q+(a<<2)>>2]=t>>>15|F<<17;a=a+1|0;}while((a|0)<(e|0));return}function Gqb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((e|0)<=0){return}f=c[b+8>>2]|0;g=d+8|0;h=c[b+12>>2]|0;i=d+12|0;j=c[b>>2]|0;k=c[b+16>>2]|0;l=d+16|0;m=c[b+24>>2]|0;n=d+24|0;o=c[a>>2]|0;p=c[b+4>>2]|0;q=d+36|0;r=c[b+20>>2]|0;s=d+52|0;t=c[b+28>>2]|0;b=d+60|0;u=c[a+4>>2]|0;a=0;do{v=c[f+(a<<2)>>2]|0;w=c[g>>2]|0;x=gHb(w,(w|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=F;w=c[h+(a<<2)>>2]|0;y=c[i>>2]|0;z=gHb(y,(y|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=YGb(z,F,x,v)|0;v=F;x=c[j+(a<<2)>>2]|0;z=c[d>>2]|0;y=gHb(z,(z|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=F;z=c[k+(a<<2)>>2]|0;A=c[l>>2]|0;B=gHb(A,(A|0)<0|0?-1:0,z,(z|0)<0|0?-1:0)|0;z=F;A=c[m+(a<<2)>>2]|0;C=c[n>>2]|0;D=gHb(C,(C|0)<0|0?-1:0,A,(A|0)<0|0?-1:0)|0;A=F;C=YGb(w,v,16384,0)|0;v=F;w=YGb(C,v,y,x)|0;x=YGb(w,F,B,z)|0;z=YGb(x,F,D,A)|0;c[o+(a<<2)>>2]=z>>>15|F<<17;z=c[p+(a<<2)>>2]|0;A=c[q>>2]|0;D=gHb(A,(A|0)<0|0?-1:0,z,(z|0)<0|0?-1:0)|0;z=F;A=c[r+(a<<2)>>2]|0;x=c[s>>2]|0;B=gHb(x,(x|0)<0|0?-1:0,A,(A|0)<0|0?-1:0)|0;A=F;x=c[t+(a<<2)>>2]|0;w=c[b>>2]|0;y=gHb(w,(w|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=F;w=YGb(C,v,D,z)|0;z=YGb(w,F,B,A)|0;A=YGb(z,F,y,x)|0;c[u+(a<<2)>>2]=A>>>15|F<<17;a=a+1|0;}while((a|0)<(e|0));return}function Hqb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0;if((e|0)<=0){return}f=c[b+8>>2]|0;g=d+16|0;i=c[b+12>>2]|0;j=d+24|0;k=c[b>>2]|0;l=c[b+16>>2]|0;m=d+32|0;n=c[a>>2]|0;o=c[b+4>>2]|0;p=d+56|0;q=c[b+20>>2]|0;b=d+88|0;r=c[a+4>>2]|0;a=0;do{s=+h[f+(a<<3)>>3]*+h[g>>3]+ +h[i+(a<<3)>>3]*+h[j>>3];h[n+(a<<3)>>3]=s+ +h[k+(a<<3)>>3]*+h[d>>3]+ +h[l+(a<<3)>>3]*+h[m>>3];h[r+(a<<3)>>3]=s+ +h[o+(a<<3)>>3]*+h[p>>3]+ +h[q+(a<<3)>>3]*+h[b>>3];a=a+1|0;}while((a|0)<(e|0));return}function Iqb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;if((e|0)<=0){return}f=c[b+8>>2]|0;g=d+16|0;i=c[b+12>>2]|0;j=d+24|0;k=c[b>>2]|0;l=c[b+16>>2]|0;m=d+32|0;n=c[b+24>>2]|0;o=d+48|0;p=c[a>>2]|0;q=c[b+4>>2]|0;r=d+72|0;s=c[b+20>>2]|0;t=d+104|0;u=c[b+28>>2]|0;b=d+120|0;v=c[a+4>>2]|0;a=0;do{w=+h[f+(a<<3)>>3]*+h[g>>3]+ +h[i+(a<<3)>>3]*+h[j>>3];h[p+(a<<3)>>3]=w+ +h[k+(a<<3)>>3]*+h[d>>3]+ +h[l+(a<<3)>>3]*+h[m>>3]+ +h[n+(a<<3)>>3]*+h[o>>3];h[v+(a<<3)>>3]=w+ +h[q+(a<<3)>>3]*+h[r>>3]+ +h[s+(a<<3)>>3]*+h[t>>3]+ +h[u+(a<<3)>>3]*+h[b>>3];a=a+1|0;}while((a|0)<(e|0));return}function Jqb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0;if((e|0)<=0){return}f=c[b+8>>2]|0;h=d+8|0;i=c[b+12>>2]|0;j=d+12|0;k=c[b>>2]|0;l=c[b+16>>2]|0;m=d+16|0;n=c[a>>2]|0;o=c[b+4>>2]|0;p=d+28|0;q=c[b+20>>2]|0;b=d+44|0;r=c[a+4>>2]|0;a=0;do{s=+g[f+(a<<2)>>2]*+g[h>>2]+ +g[i+(a<<2)>>2]*+g[j>>2];g[n+(a<<2)>>2]=s+ +g[k+(a<<2)>>2]*+g[d>>2]+ +g[l+(a<<2)>>2]*+g[m>>2];g[r+(a<<2)>>2]=s+ +g[o+(a<<2)>>2]*+g[p>>2]+ +g[q+(a<<2)>>2]*+g[b>>2];a=a+1|0;}while((a|0)<(e|0));return}function Kqb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;if((e|0)<=0){return}f=c[b+8>>2]|0;h=d+8|0;i=c[b+12>>2]|0;j=d+12|0;k=c[b>>2]|0;l=c[b+16>>2]|0;m=d+16|0;n=c[b+24>>2]|0;o=d+24|0;p=c[a>>2]|0;q=c[b+4>>2]|0;r=d+36|0;s=c[b+20>>2]|0;t=d+52|0;u=c[b+28>>2]|0;b=d+60|0;v=c[a+4>>2]|0;a=0;do{w=+g[f+(a<<2)>>2]*+g[h>>2]+ +g[i+(a<<2)>>2]*+g[j>>2];g[p+(a<<2)>>2]=w+ +g[k+(a<<2)>>2]*+g[d>>2]+ +g[l+(a<<2)>>2]*+g[m>>2]+ +g[n+(a<<2)>>2]*+g[o>>2];g[v+(a<<2)>>2]=w+ +g[q+(a<<2)>>2]*+g[r>>2]+ +g[s+(a<<2)>>2]*+g[t>>2]+ +g[u+(a<<2)>>2]*+g[b>>2];a=a+1|0;}while((a|0)<(e|0));return}function Lqb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((f|0)<=0){return}g=c[d+8>>2]|0;h=c[e+8>>2]|0;i=c[d+12>>2]|0;j=c[e+12>>2]|0;k=c[d>>2]|0;l=c[e>>2]|0;m=c[d+16>>2]|0;n=c[e+16>>2]|0;o=c[a>>2]|0;p=c[d+4>>2]|0;q=c[e+28>>2]|0;r=c[d+20>>2]|0;d=c[e+44>>2]|0;e=c[a+4>>2]|0;a=0;do{s=ba(b[g+(a<<1)>>1]|0,h)|0;t=(ba(b[i+(a<<1)>>1]|0,j)|0)+s|0;s=ba(b[k+(a<<1)>>1]|0,l)|0;u=t+16384|0;b[o+(a<<1)>>1]=(u+s+(ba(b[m+(a<<1)>>1]|0,n)|0)|0)>>>15;s=ba(b[p+(a<<1)>>1]|0,q)|0;b[e+(a<<1)>>1]=(u+s+(ba(b[r+(a<<1)>>1]|0,d)|0)|0)>>>15;a=a+1|0;}while((a|0)<(f|0));return}function Mqb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((f|0)<=0){return}g=c[d+8>>2]|0;h=c[e+8>>2]|0;i=c[d+12>>2]|0;j=c[e+12>>2]|0;k=c[d>>2]|0;l=c[e>>2]|0;m=c[d+16>>2]|0;n=c[e+16>>2]|0;o=c[d+24>>2]|0;p=c[e+24>>2]|0;q=c[a>>2]|0;r=c[d+4>>2]|0;s=c[e+36>>2]|0;t=c[d+20>>2]|0;u=c[e+52>>2]|0;v=c[d+28>>2]|0;d=c[e+60>>2]|0;e=c[a+4>>2]|0;a=0;do{w=ba(b[g+(a<<1)>>1]|0,h)|0;x=(ba(b[i+(a<<1)>>1]|0,j)|0)+w|0;w=ba(b[k+(a<<1)>>1]|0,l)|0;y=ba(b[m+(a<<1)>>1]|0,n)|0;z=x+16384|0;b[q+(a<<1)>>1]=(z+w+y+(ba(b[o+(a<<1)>>1]|0,p)|0)|0)>>>15;y=ba(b[r+(a<<1)>>1]|0,s)|0;w=ba(b[t+(a<<1)>>1]|0,u)|0;b[e+(a<<1)>>1]=(z+y+w+(ba(b[v+(a<<1)>>1]|0,d)|0)|0)>>>15;a=a+1|0;}while((a|0)<(f|0));return}function Nqb(){return 4708}function Oqb(){return 2169192}function Pqb(a,b){a=a|0;b=b|0;var d=0;do{if((a|0)==0){d=-22}else{if((c[a+6964>>2]|0)!=0){d=-22;break}c[a+76>>2]=b;d=0}}while(0);return d|0}function Qqb(){return 1781496}function Rqb(){var a=0,b=0;a=cEb(16272)|0;b=a;if((a|0)==0){return b|0}c[a>>2]=1781496;DEb(a);return b|0}function Sqb(a,b,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;do{if((a|0)==0){m=cEb(16272)|0;if((m|0)==0){n=0;return n|0}else{c[m>>2]=1781496;DEb(m);o=m;break}}else{o=a}}while(0);c[o+4>>2]=k;c[o+8>>2]=l;l=o;vEb(l,2172688,b,d,0)|0;vEb(l,2098160,e,(e|0)<0|0?-1:0,0)|0;vEb(l,2042904,f,(f|0)<0|0?-1:0,0)|0;vEb(l,1997864,g,h,0)|0;vEb(l,1961312,i,(i|0)<0|0?-1:0,0)|0;vEb(l,1933472,j,(j|0)<0|0?-1:0,0)|0;vEb(l,1910472,-1,-1,0)|0;j=o+24|0;i=hBb(c[j>>2]|0,c[j+4>>2]|0)|0;vEb(l,1890200,i,(i|0)<0|0?-1:0,0)|0;i=o+32|0;j=hBb(c[i>>2]|0,c[i+4>>2]|0)|0;vEb(l,2347472,j,(j|0)<0|0?-1:0,0)|0;vEb(l,2327216,0,0,0)|0;n=o;return n|0}function Tqb(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;do{if((b|0)!=0){Uqb(b);d=c[b+6980>>2]|0;if((d|0)==0){break}me[c[d+4>>2]&511](b+6976|0)}}while(0);$Db(a);return}function Uqb(a){a=a|0;c[a+6924>>2]=0;c[a+6928>>2]=0;c[a+6932>>2]=0;TGb(a+5708|0,0,128)|0;TGb(a+6316|0,0,128)|0;ZDb(c[a+5988>>2]|0);TGb(a+5860|0,0,152)|0;ZDb(c[a+6140>>2]|0);TGb(a+6012|0,0,152)|0;ZDb(c[a+6292>>2]|0);TGb(a+6164|0,0,152)|0;ZDb(c[a+6596>>2]|0);TGb(a+6468|0,0,152)|0;ZDb(c[a+6748>>2]|0);TGb(a+6620|0,0,152)|0;ZDb(c[a+6900>>2]|0);TGb(a+6772|0,0,152)|0;ZDb(c[a+5448>>2]|0);TGb(a+5320|0,0,152)|0;ZDb(c[a+5600>>2]|0);TGb(a+5472|0,0,152)|0;irb(a+6964|0);irb(a+6968|0);irb(a+6972|0);Dqb(a);c[a+6936>>2]=0;return}function Vqb(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,G=0.0,H=0,I=0,J=0,K=0;b=i;i=i+2048|0;d=b|0;e=b+1024|0;Uqb(a);f=a+12|0;j=c[f>>2]|0;if((j|0)>9){yDb(a,16,2303176,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;l=-22;i=b;return l|0}j=a+20|0;m=c[j>>2]|0;if((m|0)>9){yDb(a,16,2285256,(k=i,i=i+8|0,c[k>>2]=m,k)|0);i=k;l=-22;i=b;return l|0}m=a+24|0;if((hBb(c[m>>2]|0,c[m+4>>2]|0)|0)>32){n=c[m+4>>2]|0;yDb(a,24,2269688,(k=i,i=i+16|0,c[k>>2]=c[m>>2],c[k+8>>2]=n,k)|0);i=k;c[m>>2]=0;c[m+4>>2]=0}n=a+32|0;if((hBb(c[n>>2]|0,c[n+4>>2]|0)|0)>32){o=c[n+4>>2]|0;yDb(a,24,2254264,(k=i,i=i+16|0,c[k>>2]=c[n>>2],c[k+8>>2]=o,k)|0);i=k;c[n>>2]=0;c[n+4>>2]=0}o=a+84|0;if((c[o>>2]|0)!=0){yDb(a,16,2240136,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-22;i=b;return l|0}p=a+6980|0;c[p>>2]=402680;q=a+80|0;r=c[q>>2]|0;if((r|0)==0){s=c[a+5840>>2]|0;c[q>>2]=s;if((s|0)==0){t=16}else{u=s;t=13}}else{u=r;t=13}do{if((t|0)==13){r=c[m>>2]|0;s=c[m+4>>2]|0;if((r|0)==0&(s|0)==0){t=17;break}if((u|0)==(hBb(r,s)|0)){t=16;break}yDb(a,24,2228024,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;c[m>>2]=0;c[m+4>>2]=0;t=17}}while(0);if((t|0)==16){u=c[m>>2]|0;s=c[m+4>>2]|0;if((u|0)==0&(s|0)==0){t=17}else{v=s;w=u}}if((t|0)==17){u=jBb(c[q>>2]|0)|0;s=F;c[m>>2]=u;c[m+4>>2]=s;v=s;w=u}u=c[n>>2]|0;s=c[n+4>>2]|0;if((u|0)==0&(s|0)==0){r=jBb(c[a+6448>>2]|0)|0;x=F;c[n>>2]=r;c[n+4>>2]=x;y=x;z=r;A=c[m+4>>2]|0;B=c[m>>2]|0}else{y=s;z=u;A=v;B=w}do{if((z|0)==(B|0)&(y|0)==(A|0)){if(+g[a+64>>2]!=1.0){C=1;break}C=(c[a+5704>>2]|0)!=0|0}else{C=1}}while(0);A=a+5700|0;c[A>>2]=C;C=a+16|0;y=c[C>>2]|0;a:do{if((y|0)==-1){if((zFb(c[f>>2]|0)|0)<7){c[C>>2]=6;break}do{if((zFb(c[f>>2]|0)|0)==7){if((zFb(c[j>>2]|0)|0)!=7){break}if((c[A>>2]|0)!=0){break}if((c[o>>2]|0)==1){break}c[C>>2]=7;break a}}while(0);if((zFb(c[f>>2]|0)|0)<9){c[C>>2]=8;break}else{yDb(a,48,2216384,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;c[C>>2]=9;break}}else{if((y-6|0)>>>0<4>>>0){break}B=wFb(y)|0;yDb(a,16,2206656,(k=i,i=i+8|0,c[k>>2]=B,k)|0);i=k;l=-22;i=b;return l|0}}while(0);y=a+5708|0;o=c[f>>2]|0;c[a+5856>>2]=o;c[a+5844>>2]=BFb(o)|0;c[a+5852>>2]=CFb(o)|0;o=a+6316|0;B=c[j>>2]|0;c[a+6464>>2]=B;c[a+6452>>2]=BFb(B)|0;c[a+6460>>2]=CFb(B)|0;B=a+5688|0;z=c[B>>2]|0;w=c[B+4>>2]|0;if((z|0)==0&(w|0)==(-2147483648|0)){B=a+6952|0;c[B>>2]=0;c[B+4>>2]=-2147483648;D=+g[a+5684>>2]}else{B=a+5684|0;E=+g[B>>2];do{if(E!=0.0){G=E}else{if(+g[a+5668>>2]<1.7014117331926443e+38){G=E;break}g[B>>2]=1.0;G=1.0}}while(0);B=c[a+44>>2]|0;v=gHb(B,(B|0)<0|0?-1:0,z,w)|0;w=F;z=a+6944|0;c[z>>2]=v;c[z+4>>2]=w;z=a+6952|0;c[z>>2]=v;c[z+4>>2]=w;D=G}w=a+5684|0;do{if(D!=0.0){z=a+5668|0;if(!(+g[z>>2]<1.7014117331926443e+38)){g[z>>2]=.0010000000474974513}G=+g[w>>2];if(!(G>1.0001)){break}g[a+5680>>2]=G/+(c[a+40>>2]|0)}}while(0);w=a+44|0;z=c[w>>2]|0;v=a+40|0;B=c[v>>2]|0;do{if((z|0)==(B|0)){if((c[a+48>>2]&1|0)!=0){t=49;break}me[c[(c[p>>2]|0)+4>>2]&511](a+6976|0)}else{t=49}}while(0);if((t|0)==49){u=a+6976|0;c[u>>2]=Fe[c[c[p>>2]>>2]&3](c[u>>2]|0,z,B,c[a+5628>>2]|0,c[a+5632>>2]|0,c[a+5636>>2]|0,+h[a+5640>>3],c[C>>2]|0,c[a+5648>>2]|0,c[a+5652>>2]|0,+h[a+5656>>3],c[a+5664>>2]|0)|0}do{if(!(((c[C>>2]|0)-6|0)>>>0<4>>>0)){if((c[a+6976>>2]|0)==0){break}yDb(a,16,2198776,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}}while(0);B=a+5840|0;z=c[B>>2]|0;if((z|0)==0){u=hBb(c[m>>2]|0,c[m+4>>2]|0)|0;c[B>>2]=u;H=u}else{H=z}if((c[q>>2]|0)==0){c[q>>2]=H}z=a+6448|0;u=c[z>>2]|0;if((u|0)==0){p=hBb(c[n>>2]|0,c[n+4>>2]|0)|0;c[z>>2]=p;I=c[B>>2]|0;J=p}else{I=H;J=u}if((I|0)==0){if(!((c[m>>2]|0)==0&(c[m+4>>2]|0)==0)){yDb(0,0,2189904,(k=i,i=i+24|0,c[k>>2]=2173096,c[k+8>>2]=2163592,c[k+16>>2]=370,k)|0);i=k;Cd();return 0}yDb(a,16,2156688,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}do{if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){t=67}else{if((c[m>>2]|0)==0&(c[m+4>>2]|0)==0){t=67;break}K=c[q>>2]|0}}while(0);do{if((t|0)==67){u=c[q>>2]|0;if((u|0)==(J|0)){K=J;break}if((c[a+5704>>2]|0)!=0){K=u;break}u=d|0;iBb(u,1024,I,c[m>>2]|0,c[m+4>>2]|0);H=e|0;iBb(H,1024,c[z>>2]|0,c[n>>2]|0,c[n+4>>2]|0);yDb(a,16,2149864,(k=i,i=i+16|0,c[k>>2]=u,c[k+8>>2]=H,k)|0);i=k;l=-1;i=b;return l|0}}while(0);if((K|0)==0){yDb(0,0,2189904,(k=i,i=i+24|0,c[k>>2]=2142992,c[k+8>>2]=2163592,c[k+16>>2]=384,k)|0);i=k;Cd();return 0}if((J|0)==0){yDb(0,0,2189904,(k=i,i=i+24|0,c[k>>2]=2137608,c[k+8>>2]=2163592,c[k+16>>2]=385,k)|0);i=k;Cd();return 0}k=a+5696|0;c[k>>2]=+(((J|0)/(I|0)|0)-1|0)<+(c[w>>2]|0)/+(c[v>>2]|0)+-1.0;v=y;UGb(a+6468|0,v|0,152)|0;UGb(a+6620|0,v|0,152)|0;y=o;UGb(a+6772|0,y|0,152)|0;o=a+6976|0;do{if((c[o>>2]|0)==0){if((c[A>>2]|0)!=0){break}if((c[a+76>>2]|0)!=0){break}if((c[a+88>>2]|0)!=0){break}c[a+6972>>2]=drb(c[j>>2]|0,c[f>>2]|0,I,0,0)|0;l=0;i=b;return l|0}}while(0);I=a+76|0;w=a+6964|0;c[w>>2]=drb(c[C>>2]|0,c[f>>2]|0,K,c[I>>2]|0,0)|0;K=drb(c[j>>2]|0,c[C>>2]|0,c[z>>2]|0,0,0)|0;c[a+6968>>2]=K;if((c[w>>2]|0)==0|(K|0)==0){l=-12;i=b;return l|0}UGb(a+5860|0,v|0,152)|0;UGb(a+6164|0,y|0,152)|0;UGb(a+6012|0,v|0,152)|0;do{if((c[I>>2]|0)!=0){v=c[q>>2]|0;c[a+6144>>2]=v;c[a+5992>>2]=v;if((c[o>>2]|0)==0){break}c[a+6600>>2]=v}}while(0);do{if((c[k>>2]|0)==0){q=c[z>>2]|0;c[a+6144>>2]=q;if((c[o>>2]|0)==0){break}c[a+6600>>2]=q}}while(0);z=c[C>>2]|0;c[a+6008>>2]=z;c[a+5996>>2]=BFb(z)|0;c[a+6004>>2]=CFb(z)|0;z=c[C>>2]|0;c[a+6160>>2]=z;c[a+6148>>2]=BFb(z)|0;c[a+6156>>2]=CFb(z)|0;z=c[C>>2]|0;c[a+6312>>2]=z;c[a+6300>>2]=BFb(z)|0;c[a+6308>>2]=CFb(z)|0;if((c[o>>2]|0)!=0){o=c[C>>2]|0;c[a+6616>>2]=o;c[a+6604>>2]=BFb(o)|0;c[a+6612>>2]=CFb(o)|0}o=Krb(a,c[j>>2]|0,c[C>>2]|0)|0;if((o|0)<0){l=o;i=b;return l|0}do{if((c[A>>2]|0)==0){if((c[a+88>>2]|0)==0){l=0}else{break}i=b;return l|0}}while(0);l=uqb(a)|0;i=b;return l|0}function Wqb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+152|0;e=d|0;if((b|0)<0){f=-22;i=d;return f|0}g=a+136|0;h=c[g>>2]|0;j=a+132|0;k=c[j>>2]|0;if(((1073741823/(h|0)|0|0)/(k|0)|0|0)<(b|0)){f=-22;i=d;return f|0}l=a+140|0;if((c[l>>2]|0)>=(b|0)){f=0;i=d;return f|0}m=b<<1;b=(ba(h,m)|0)+31&-32;UGb(e|0,a|0,152)|0;if((h|0)==0){yDb(0,0,2189904,(n=i,i=i+24|0,c[n>>2]=2130944,c[n+8>>2]=2163592,c[n+16>>2]=454,n)|0);i=n;Cd();return 0}if((k|0)==0){yDb(0,0,2189904,(n=i,i=i+24|0,c[n>>2]=2124504,c[n+8>>2]=2163592,c[n+16>>2]=455,n)|0);i=n;Cd();return 0}n=cEb(ba(k,b)|0)|0;k=a+128|0;c[k>>2]=n;if((n|0)==0){f=-12;i=d;return f|0}h=c[j>>2]|0;o=a+144|0;a:do{if((h|0)>0){p=0;q=n;while(1){if((c[o>>2]|0)==0){r=c[g>>2]|0}else{r=b}s=q+(ba(r,p)|0)|0;c[a+(p<<2)>>2]=s;if((c[o>>2]|0)!=0){UGb(s|0,c[e+(p<<2)>>2]|0,ba(c[g>>2]|0,c[l>>2]|0)|0)|0}s=p+1|0;t=c[j>>2]|0;if((s|0)>=(t|0)){u=t;break a}p=s;q=c[k>>2]|0}}else{u=h}}while(0);if((c[o>>2]|0)==0){o=ba(c[l>>2]|0,u)|0;UGb(c[a>>2]|0,c[e>>2]|0,ba(o,c[g>>2]|0)|0)|0}$Db(e+128|0);c[l>>2]=m;f=1;i=d;return f|0}function Xqb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;i=i+128|0;h=g|0;j=h;k=i;i=i+152|0;l=a+5708|0;m=a+6316|0;if((c[a+6600>>2]|0)==0){yDb(a,16,2119032,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}n=a+6960|0;p=c[n>>2]|0;a:do{if((p|0)>0){q=a+6772|0;r=h|0;s=a+6916|0;t=q|0;u=a+6904|0;v=a+6772|0;if((b|0)==0){w=f;x=p;while(1){y=Wqb(q,(x|0)>16384?16384:x)|0;if((y|0)<0){o=y;z=97;break}do{if((c[s>>2]|0)==0){c[r>>2]=c[t>>2]}else{y=c[u>>2]|0;if((y|0)<=0){break}UGb(j|0,v|0,y<<2)|0}}while(0);y=c[n>>2]|0;c[n>>2]=-y;A=Xqb(a,r,(y|0)>16384?16384:y,e,w)|0;y=-(c[n>>2]|0)|0;c[n>>2]=y;if((A|0)<=0){o=0;z=97;break}B=y-A|0;c[n>>2]=B;if((B|0)>0){w=0;x=B}else{C=0;break a}}if((z|0)==97){i=g;return o|0}}else{D=f;E=p}while(1){x=Wqb(q,(E|0)>16384?16384:E)|0;if((x|0)<0){o=x;z=97;break}do{if((c[s>>2]|0)==0){c[r>>2]=c[t>>2]}else{x=c[u>>2]|0;if((x|0)<=0){break}UGb(j|0,v|0,x<<2)|0}}while(0);x=c[n>>2]|0;c[n>>2]=-x;w=Xqb(a,r,(x|0)>16384?16384:x,e,D)|0;x=c[n>>2]|0;B=-x|0;c[n>>2]=B;if((w|0)>0){A=B-w|0;c[n>>2]=A;G=A}else{if((x|0)==0){G=B}else{o=0;z=97;break}}if((G|0)>0){D=0;E=G}else{C=0;break a}}if((z|0)==97){i=g;return o|0}}else{C=f}}while(0);b:do{if((e|0)==0){if((c[a+6976>>2]|0)==0){if((c[a+6928>>2]|0)==0){o=0}else{break}i=g;return o|0}f=a+6936|0;if((c[f>>2]|0)==0){re[c[(c[a+6980>>2]|0)+12>>2]&4095](a)|0}c[a+6932>>2]=0;c[f>>2]=1}else{f=a+5840|0;z=(c[f>>2]|0)>0;if((c[a+5852>>2]|0)!=0){if(z){H=0}else{break}while(1){c[a+5708+(H<<2)>>2]=c[e+(H<<2)>>2];H=H+1|0;if((H|0)>=(c[f>>2]|0)){break b}}}if(!z){break}G=a+5844|0;E=0;do{c[a+5708+(E<<2)>>2]=(c[e>>2]|0)+(ba(c[G>>2]|0,E)|0);E=E+1|0;}while((E|0)<(c[f>>2]|0))}}while(0);c:do{if((b|0)==0){TGb(m|0,0,128)|0}else{e=a+6448|0;H=(c[e>>2]|0)>0;if((c[a+6460>>2]|0)!=0){if(H){I=0}else{break}while(1){c[a+6316+(I<<2)>>2]=c[b+(I<<2)>>2];I=I+1|0;if((I|0)>=(c[e>>2]|0)){break c}}}if(!H){break}f=a+6452|0;E=0;do{c[a+6316+(E<<2)>>2]=(c[b>>2]|0)+(ba(c[f>>2]|0,E)|0);E=E+1|0;}while((E|0)<(c[e>>2]|0))}}while(0);if((c[a+6976>>2]|0)!=0){b=Yqb(a,m,d,l,C)|0;if((b|0)<=0){o=b;i=g;return o|0}if((c[n>>2]|0)!=0){o=b;i=g;return o|0}I=c[a+40>>2]|0;e=gHb(I,(I|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;I=a+6944|0;E=YGb(e,F,c[I>>2]|0,c[I+4>>2]|0)|0;c[I>>2]=E;c[I+4>>2]=F;o=b;i=g;return o|0}UGb(k|0,l|0,152)|0;b=a+6928|0;I=c[b>>2]|0;E=(I|0)<(d|0)?I:d;do{if((E|0)==0){J=0;K=d;L=I}else{e=a+6924|0;f=c[e>>2]|0;H=k+132|0;G=c[H>>2]|0;z=(G|0)>0;do{if((c[a+6612>>2]|0)==0){if(!z){break}D=k+136|0;j=G-1|0;p=c[a+6468>>2]|0;h=j+(ba(G,f)|0)|0;c[k+(j<<2)>>2]=p+(ba(h,c[D>>2]|0)|0);if((j|0)>0){M=j}else{break}do{M=M-1|0;j=M+(ba(c[H>>2]|0,f)|0)|0;c[k+(M<<2)>>2]=p+(ba(j,c[D>>2]|0)|0);}while((M|0)>0)}else{if(!z){break}D=k+136|0;p=0;do{c[k+(p<<2)>>2]=(c[a+6468+(p<<2)>>2]|0)+(ba(c[D>>2]|0,f)|0);p=p+1|0;}while((p|0)<(c[H>>2]|0))}}while(0);H=Yqb(a,m,E,k,E)|0;if((H|0)<0){o=H;i=g;return o|0}c[b>>2]=(c[b>>2]|0)-H;c[e>>2]=(c[e>>2]|0)+H;f=a+6448|0;z=c[f>>2]|0;G=(z|0)>0;do{if((c[a+6460>>2]|0)==0){if(!G){break}p=m|0;D=a+6452|0;j=z-1|0;h=j+(ba(z,H)|0)|0;c[a+6316+(j<<2)>>2]=(c[p>>2]|0)+(ba(h,c[D>>2]|0)|0);if((j|0)>0){N=j}else{break}do{N=N-1|0;j=N+(ba(c[f>>2]|0,H)|0)|0;c[a+6316+(N<<2)>>2]=(c[p>>2]|0)+(ba(j,c[D>>2]|0)|0);}while((N|0)>0)}else{if(!G){break}D=a+6452|0;p=0;do{j=a+6316+(p<<2)|0;c[j>>2]=(c[j>>2]|0)+(ba(c[D>>2]|0,H)|0);p=p+1|0;}while((p|0)<(c[f>>2]|0))}}while(0);f=d-H|0;G=c[b>>2]|0;if((G|0)!=0){J=H;K=f;L=G;break}c[e>>2]=0;J=H;K=f;L=0}}while(0);do{if((C|0)==0){O=J}else{d=a+6924|0;N=c[d>>2]|0;E=C-K|0;M=E+N+L|0;I=(C|0)>(K|0);do{if(I){f=a+6468|0;if((M|0)<=(c[a+6608>>2]|0)|(E+L|0)>(N|0)){G=Wqb(f,M)|0;if((G|0)<0){o=G}else{break}i=g;return o|0}G=k+132|0;z=c[G>>2]|0;p=(z|0)>0;do{if((c[a+6612>>2]|0)==0){if(!p){break}D=k+136|0;j=z-1|0;h=c[f>>2]|0;r=j+(ba(z,N)|0)|0;c[k+(j<<2)>>2]=h+(ba(r,c[D>>2]|0)|0);if((j|0)>0){P=j}else{break}do{P=P-1|0;j=P+(ba(c[G>>2]|0,N)|0)|0;c[k+(P<<2)>>2]=h+(ba(j,c[D>>2]|0)|0);}while((P|0)>0)}else{if(!p){break}D=k+136|0;h=0;do{c[k+(h<<2)>>2]=(c[a+6468+(h<<2)>>2]|0)+(ba(c[D>>2]|0,N)|0);h=h+1|0;}while((h|0)<(c[G>>2]|0))}}while(0);Zqb(f,k,L);c[d>>2]=0}}while(0);if((K|0)==0){Q=J;R=C}else{N=I?K:C;M=Yqb(a,m,N,l,N)|0;if((M|0)<0){o=M;i=g;return o|0}N=a+5840|0;E=c[N>>2]|0;H=(E|0)>0;do{if((c[a+5852>>2]|0)==0){if(!H){break}e=l|0;G=a+5844|0;p=E-1|0;z=p+(ba(E,M)|0)|0;c[a+5708+(p<<2)>>2]=(c[e>>2]|0)+(ba(z,c[G>>2]|0)|0);if((p|0)>0){S=p}else{break}do{S=S-1|0;p=S+(ba(c[N>>2]|0,M)|0)|0;c[a+5708+(S<<2)>>2]=(c[e>>2]|0)+(ba(p,c[G>>2]|0)|0);}while((S|0)>0)}else{if(!H){break}G=a+5844|0;e=0;do{f=a+5708+(e<<2)|0;c[f>>2]=(c[f>>2]|0)+(ba(c[G>>2]|0,M)|0);e=e+1|0;}while((e|0)<(c[N>>2]|0))}}while(0);Q=M+J|0;R=C-M|0}if((R|0)==0){O=Q;break}N=(c[b>>2]|0)+(c[d>>2]|0)|0;H=k+132|0;E=c[H>>2]|0;I=(E|0)>0;do{if((c[a+6612>>2]|0)==0){if(!I){break}e=k+136|0;G=E-1|0;f=c[a+6468>>2]|0;p=G+(ba(E,N)|0)|0;c[k+(G<<2)>>2]=f+(ba(p,c[e>>2]|0)|0);if((G|0)>0){T=G}else{break}do{T=T-1|0;G=T+(ba(c[H>>2]|0,N)|0)|0;c[k+(T<<2)>>2]=f+(ba(G,c[e>>2]|0)|0);}while((T|0)>0)}else{if(!I){break}e=k+136|0;f=0;do{c[k+(f<<2)>>2]=(c[a+6468+(f<<2)>>2]|0)+(ba(c[e>>2]|0,N)|0);f=f+1|0;}while((f|0)<(c[H>>2]|0))}}while(0);Zqb(k,l,R);c[b>>2]=(c[b>>2]|0)+R;O=Q}}while(0);if((O|0)<=0){o=O;i=g;return o|0}if((c[n>>2]|0)!=0){o=O;i=g;return o|0}n=c[a+40>>2]|0;Q=gHb(n,(n|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;n=a+6944|0;a=YGb(Q,F,c[n>>2]|0,c[n+4>>2]|0)|0;c[n>>2]=a;c[n+4>>2]=F;o=O;i=g;return o|0}function Yqb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+304|0;h=g|0;j=g+152|0;k=c[a+6972>>2]|0;if((k|0)!=0){if((c[a+6976>>2]|0)!=0){yDb(0,0,2189904,(l=i,i=i+24|0,c[l>>2]=2067296,c[l+8>>2]=2163592,c[l+16>>2]=616,l)|0);i=l;Cd();return 0}jrb(k,b,e,f)|0;m=d;i=g;return m|0}k=a+5860|0;n=Wqb(k,f)|0;if((n|0)<0){m=n;i=g;return m|0}n=a+5696|0;o=a+6012|0;p=c[a+6144>>2]|0;do{if((c[n>>2]|0)==0){if((p|0)!=(c[a+6448>>2]|0)){yDb(0,0,2189904,(l=i,i=i+24|0,c[l>>2]=2059320,c[l+8>>2]=2163592,c[l+16>>2]=631,l)|0);i=l;Cd();return 0}q=Wqb(o,f)|0;if((q|0)<0){m=q}else{break}i=g;return m|0}else{if((p|0)!=(c[a+80>>2]|0)){yDb(0,0,2189904,(l=i,i=i+24|0,c[l>>2]=2063080,c[l+8>>2]=2163592,c[l+16>>2]=627,l)|0);i=l;Cd();return 0}q=Wqb(o,d)|0;if((q|0)<0){m=q}else{break}i=g;return m|0}}while(0);p=a+6164|0;q=Wqb(p,d)|0;if((q|0)<0){m=q;i=g;return m|0}UGb(j|0,o|0,152)|0;UGb(h|0,p|0,152)|0;p=a+16|0;o=c[p>>2]|0;do{if((o|0)==(c[a+12>>2]|0)){if((c[a+5852>>2]|0)==0){r=k;break}r=(c[a+76>>2]|0)==0?e:k}else{r=k}}while(0);k=c[n>>2]|0;if((k|0)==0){q=(c[a+5700>>2]|0)==0?r:j;if((c[a+6976>>2]|0)==0){s=q;t=20}else{u=h;v=q}}else{q=(c[a+6976>>2]|0)==0?r:j;if((c[a+5700>>2]|0)==0){s=q;t=20}else{u=h;v=q}}if((t|0)==20){u=s;v=s}do{if((o|0)==(c[a+20>>2]|0)){if((c[a+6460>>2]|0)==0){w=r;x=u;y=v;break}if((o|0)==7){if((c[a+5624>>2]&31|0)!=0){w=r;x=u;y=v;break}}if((u|0)!=(e|0)){if((u|0)==(r|0)){w=b;x=b;y=b;break}w=r;x=b;y=(u|0)==(v|0)?b:v;break}s=(d|0)>(f|0)?f:d;if((c[a+5852>>2]|0)==0){yDb(0,0,2189904,(l=i,i=i+24|0,c[l>>2]=2053968,c[l+8>>2]=2163592,c[l+16>>2]=658,l)|0);i=l;Cd();return 0}Zqb(b,e,s);m=s;i=g;return m|0}else{w=r;x=u;y=v}}while(0);if((w|0)==(e|0)){z=k}else{jrb(c[a+6964>>2]|0,w,e,f)|0;z=c[n>>2]|0}n=(w|0)!=(y|0);do{if((z|0)==0){if(n){Eqb(a,y,w,f,(y|0)==(b|0)|0)|0}if((y|0)==(x|0)){A=d;break}A=brb(a,x,d,y,f)|0}else{if(n){B=brb(a,y,d,w,f)|0}else{B=d}if((y|0)==(x|0)){A=B;break}Eqb(a,x,y,B,(x|0)==(b|0)|0)|0;A=B}}while(0);if((x|0)==(b|0)|(A|0)==0){m=A;i=g;return m|0}B=a+88|0;if((c[B>>2]|0)==0){C=x}else{y=(A|0)>65536?A:65536;do{if((x|0)==(e|0)){d=a+5472|0;f=Wqb(d,y)|0;if((f|0)<0){m=f}else{D=d;break}i=g;return m|0}else{D=x}}while(0);e=a+5320|0;d=Wqb(e,y)|0;if((d|0)<0){m=d;i=g;return m|0}y=a+5452|0;f=c[y>>2]|0;if((d|0)!=0&(f|0)>0){d=a+5460|0;w=a+5468|0;n=0;while(1){z=c[a+5320+(n<<2)>>2]|0;k=c[d>>2]|0;v=_Gb(1942904875,2874,n|0)|0;Jrb(a,z,k,v,c[w>>2]|0);v=n+1|0;k=c[y>>2]|0;if((v|0)<(k|0)){n=v}else{E=k;break}}}else{E=f}f=x+132|0;if((E|0)!=(c[f>>2]|0)){yDb(0,0,2189904,(l=i,i=i+24|0,c[l>>2]=2043352,c[l+8>>2]=2163592,c[l+16>>2]=700,l)|0);i=l;Cd();return 0}l=a+92|0;E=c[l>>2]|0;if((E+A|0)>(c[a+5460>>2]|0)){c[l>>2]=0;F=0}else{F=E}a:do{if((c[B>>2]|0)>>>0<64>>>0){E=a+16260|0;n=c[E>>2]|0;if((n|0)==0){if((c[f>>2]|0)<=0){break}y=a+16256|0;w=a+5456|0;d=a+11084|0;k=0;v=F;while(1){z=(c[a+5320+(k<<2)>>2]|0)+(ba(v,c[w>>2]|0)|0)|0;Ke[c[y>>2]&1023](c[D+(k<<2)>>2]|0,c[x+(k<<2)>>2]|0,z,c[d>>2]|0,0,0,A);z=k+1|0;if((z|0)>=(c[f>>2]|0)){break a}k=z;v=c[l>>2]|0}}v=A&-16;k=ba(c[x+136>>2]|0,v)|0;b:do{if((v|0)!=0){if((c[f>>2]|0)<=0){break}d=a+5456|0;y=a+11088|0;w=0;z=n;u=F;while(1){r=(c[a+5320+(w<<2)>>2]|0)+(ba(u,c[d>>2]|0)|0)|0;Ke[z&1023](c[D+(w<<2)>>2]|0,c[x+(w<<2)>>2]|0,r,c[y>>2]|0,0,0,v);r=w+1|0;if((r|0)>=(c[f>>2]|0)){break b}w=r;z=c[E>>2]|0;u=c[l>>2]|0}}}while(0);if((A|0)==(v|0)){break}if((c[f>>2]|0)<=0){break}E=a+16256|0;n=a+5456|0;u=k+v|0;z=a+11084|0;w=A-v|0;y=0;do{d=(c[a+5320+(y<<2)>>2]|0)+(u+(ba(c[l>>2]|0,c[n>>2]|0)|0))|0;Ke[c[E>>2]&1023]((c[D+(y<<2)>>2]|0)+k|0,(c[x+(y<<2)>>2]|0)+k|0,d,c[z>>2]|0,0,0,w);y=y+1|0;}while((y|0)<(c[f>>2]|0))}else{y=c[p>>2]|0;if((y|0)==6){Lrb(a,D,x,e,A);break}else if((y|0)==8){Nrb(a,D,x,e,A);break}else if((y|0)==7){Mrb(a,D,x,e,A);break}else if((y|0)==9){Orb(a,D,x,e,A);break}else{break}}}while(0);c[l>>2]=(c[l>>2]|0)+A;C=D}jrb(c[a+6968>>2]|0,b,C,A)|0;m=A;i=g;return m|0}function Zqb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[a+144>>2]|0;if((f|0)!=(c[b+144>>2]|0)){yDb(0,0,2189904,(g=i,i=i+24|0,c[g>>2]=2082488,c[g+8>>2]=2163592,c[g+16>>2]=473,g)|0);i=g;Cd()}h=a+136|0;j=c[h>>2]|0;if((j|0)!=(c[b+136>>2]|0)){yDb(0,0,2189904,(g=i,i=i+24|0,c[g>>2]=2076696,c[g+8>>2]=2163592,c[g+16>>2]=474,g)|0);i=g;Cd()}k=a+132|0;l=c[k>>2]|0;if((l|0)!=(c[b+132>>2]|0)){yDb(0,0,2189904,(g=i,i=i+24|0,c[g>>2]=2072040,c[g+8>>2]=2163592,c[g+16>>2]=475,g)|0);i=g;Cd()}if((f|0)==0){UGb(c[a>>2]|0,c[b>>2]|0,ba(ba(j,d)|0,l)|0)|0;i=e;return}if((l|0)>0){m=0;n=j}else{i=e;return}while(1){UGb(c[a+(m<<2)>>2]|0,c[b+(m<<2)>>2]|0,ba(n,d)|0)|0;j=m+1|0;if((j|0)>=(c[k>>2]|0)){break}m=j;n=c[h>>2]|0}i=e;return}function _qb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+128|0;e=d|0;f=e;if((b|0)<1){g=0;i=d;return g|0}else{h=b}while(1){if((h|0)<=16384){break}b=_qb(a,16384)|0;if((b|0)<0){g=b;j=15;break}else{h=h-16384|0}}if((j|0)==15){i=d;return g|0}j=a+6620|0;b=Wqb(j,h)|0;if((b|0)<0){g=b;i=d;return g|0}b=a+6764|0;do{if((c[b>>2]|0)==0){k=c[a+6756>>2]|0;l=ba(k,h)|0;TGb(c[j>>2]|0,((k|0)==1?-128:0)|0,ba(l,c[a+6752>>2]|0)|0)|0}else{l=a+6752|0;if((c[l>>2]|0)<=0){break}k=a+6756|0;m=0;do{n=c[k>>2]|0;TGb(c[a+6620+(m<<2)>>2]|0,((n|0)==1?-128:0)|0,ba(n,h)|0)|0;m=m+1|0;}while((m|0)<(c[l>>2]|0))}}while(0);l=e|0;do{if((c[b>>2]|0)==0){c[l>>2]=c[j>>2]}else{e=c[a+6752>>2]|0;if((e|0)<=0){break}UGb(f|0,a+6620|0,e<<2)|0}}while(0);yDb(a,40,2098536,(f=i,i=i+8|0,c[f>>2]=h,f)|0);i=f;g=Xqb(a,0,0,l,h)|0;i=d;return g|0}function $qb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[a+6980>>2]|0;do{if((e|0)!=0){if((c[a+6976>>2]|0)==0){break}f=ze[c[e+20>>2]&511](a,b,d)|0;g=F;h=f;return(F=g,h)|0}}while(0);e=c[a+6928>>2]|0;f=gHb(e,(e|0)<0|0?-1:0,b,d)|0;d=c[a+40>>2]|0;a=d>>1;b=YGb(a,(a|0)<0|0?-1:0,f,F)|0;f=eHb(b,F,d,(d|0)<0|0?-1:0)|0;g=F;h=f;return(F=g,h)|0}function arb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,G=0.0,H=0.0,I=0,J=0,K=0,L=0;e=i;if((b|0)==0&(d|0)==(-2147483648|0)){f=a+6944|0;j=c[f+4>>2]|0;k=c[f>>2]|0;i=e;return(F=j,k)|0}f=a+6952|0;if((c[f>>2]|0)==0&(c[f+4>>2]|0)==(-2147483648|0)){c[f>>2]=b;c[f+4>>2]=d;l=a+6944|0;c[l>>2]=b;c[l+4>>2]=d}l=a+5668|0;m=+g[l>>2]<3.4028234663852886e+38;n=a+40|0;o=c[n>>2]|0;p=o;q=(o|0)<0|0?-1:0;r=a+44|0;s=c[r>>2]|0;t=gHb(s,(s|0)<0|0?-1:0,p,q)|0;s=F;u=a+6980|0;v=c[u>>2]|0;do{if((v|0)==0){w=8}else{if((c[a+6976>>2]|0)==0){w=8;break}x=ze[c[v+20>>2]&511](a,t,s)|0;y=F;z=x}}while(0);if((w|0)==8){w=c[a+6928>>2]|0;v=gHb(w,(w|0)<0|0?-1:0,t,s)|0;s=o>>1;o=YGb(s,(s|0)<0|0?-1:0,v,F)|0;v=eHb(o,F,p,q)|0;y=F;z=v}v=ZGb(b,d,z,y)|0;y=F;z=a+6944|0;if(!m){c[z>>2]=v;c[z+4>>2]=y;j=y;k=v;i=e;return(F=j,k)|0}m=c[z>>2]|0;d=c[z+4>>2]|0;b=ZGb(v,y,m,d)|0;y=F;v=a+6960|0;q=c[v>>2]|0;p=c[n>>2]|0;n=p;o=(p|0)<0|0?-1:0;s=gHb(n,o,q,(q|0)<0|0?-1:0)|0;t=YGb(s,F,b,y)|0;y=F;b=c[r>>2]|0;r=b;s=(b|0)<0|0?-1:0;w=gHb(r,s,n,o)|0;A=(+(t>>>0)+ +(y|0)*4294967296.0)/(+(w>>>0)+ +(F|0)*4294967296.0);B=+Q(+A);a:do{if(B>+g[l>>2]){do{if(!((m|0)==(c[f>>2]|0)&(d|0)==(c[f+4>>2]|0))){if(B>+g[a+5672>>2]){break}C=+g[a+5676>>2];if(!(C!=0.0)){break a}D=+g[a+5680>>2];if(!(D!=0.0)){break a}w=~~(+(b|0)*C);if(D<0.0){E=+(-p|0)}else{E=1.0}C=D/E;D=A;G=-0.0-C;if(D<G){H=G}else{H=D>C?C:D}x=~~(+(w|0)*H);yDb(a,40,2087064,(I=i,i=i+24|0,h[I>>3]=A,c[I+8>>2]=x,c[I+16>>2]=w,I)|0);i=I;if((a|0)==0|(w|0)<0){break a}if(!((w|0)!=0|(x|0)==0)){break a}J=a+6976|0;if((c[J>>2]|0)==0){K=a+48|0;c[K>>2]=c[K>>2]|1;if((Vqb(a)|0)<0){break a}}K=c[(c[u>>2]|0)+16>>2]|0;if((K|0)==0){break a}ze[K&511](c[J>>2]|0,x,w)|0;break a}}while(0);w=0;if((y|0)>(w|0)|(y|0)==(w|0)&t>>>0>0>>>0){w=eHb(t,y,r,s)|0;L=_qb(a,w)|0}else{w=ZGb(0,0,t,y)|0;x=eHb(w,F,n,o)|0;w=x;x=q+w|0;c[v>>2]=x;if((x|0)<1){break}yDb(a,40,2112664,(I=i,i=i+8|0,c[I>>2]=w,I)|0);i=I;L=Xqb(a,0,c[v>>2]|0,0,0)|0}if((L|0)>=0){break}yDb(a,16,2092368,(I=i,i=i+8|0,h[I>>3]=A,I)|0);i=I}}while(0);j=c[z+4>>2]|0;k=c[z>>2]|0;i=e;return(F=j,k)|0}function brb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;g=i;i=i+464|0;h=g|0;j=g+152|0;k=g+304|0;l=g+456|0;m=b;UGb(j|0,m|0,152)|0;UGb(k|0,m|0,152)|0;UGb(h|0,e|0,152)|0;e=a+6932|0;m=a+6928|0;b=a+6924|0;n=a+6612|0;o=k+132|0;p=a+6468|0;q=k+136|0;r=a+6980|0;s=a+6976|0;t=j+144|0;u=j+132|0;v=j|0;w=j+136|0;x=h+144|0;y=h+132|0;z=h|0;A=h+136|0;B=a+6936|0;C=a+6468|0;D=a+6608|0;E=C|0;F=0;G=0;H=f;f=d;d=(c[e>>2]|0)==0;a:while(1){do{if(d){I=c[m>>2]|0;if((I|0)==0){J=F;K=G;L=H;M=f;break}N=c[b>>2]|0;O=c[o>>2]|0;P=(O|0)>0;do{if((c[n>>2]|0)==0){if(!P){break}Q=O-1|0;R=c[p>>2]|0;S=Q+(ba(O,N)|0)|0;c[k+(Q<<2)>>2]=R+(ba(S,c[q>>2]|0)|0);if((Q|0)>0){T=Q}else{break}do{T=T-1|0;Q=T+(ba(c[o>>2]|0,N)|0)|0;c[k+(T<<2)>>2]=R+(ba(Q,c[q>>2]|0)|0);}while((T|0)>0)}else{if(P){U=0}else{break}do{c[k+(U<<2)>>2]=(c[a+6468+(U<<2)>>2]|0)+(ba(c[q>>2]|0,N)|0);U=U+1|0;}while((U|0)<(c[o>>2]|0))}}while(0);N=oe[c[(c[r>>2]|0)+8>>2]&63](c[s>>2]|0,j,f,k,I,l)|0;P=f-N|0;O=N+G|0;R=c[u>>2]|0;Q=(R|0)>0;do{if((c[t>>2]|0)==0){if(!Q){break}S=R-1|0;V=S+(ba(R,N)|0)|0;c[j+(S<<2)>>2]=(c[v>>2]|0)+(ba(V,c[w>>2]|0)|0);if((S|0)>0){W=S}else{break}do{W=W-1|0;S=W+(ba(c[u>>2]|0,N)|0)|0;c[j+(W<<2)>>2]=(c[v>>2]|0)+(ba(S,c[w>>2]|0)|0);}while((W|0)>0)}else{if(Q){X=0}else{break}do{S=j+(X<<2)|0;c[S>>2]=(c[S>>2]|0)+(ba(c[w>>2]|0,N)|0);X=X+1|0;}while((X|0)<(c[u>>2]|0))}}while(0);N=c[l>>2]|0;Q=(c[m>>2]|0)-N|0;c[m>>2]=Q;c[b>>2]=(c[b>>2]|0)+N;if((H|0)==0){Y=O;Z=P;break a}if((Q|0)>(F|0)){J=F;K=O;L=H;M=P;break}N=-Q|0;R=c[y>>2]|0;I=(R|0)>0;do{if((c[x>>2]|0)==0){if(!I){break}S=R-1|0;V=S+(ba(R,N)|0)|0;c[h+(S<<2)>>2]=(c[z>>2]|0)+(ba(V,c[A>>2]|0)|0);if((S|0)>0){_=S}else{break}do{_=_-1|0;S=_+(ba(c[y>>2]|0,N)|0)|0;c[h+(_<<2)>>2]=(c[z>>2]|0)+(ba(S,c[A>>2]|0)|0);}while((_|0)>0)}else{if(I){$=0}else{break}do{S=h+($<<2)|0;c[S>>2]=(c[S>>2]|0)+(ba(c[A>>2]|0,N)|0);$=$+1|0;}while(($|0)<(c[y>>2]|0))}}while(0);c[m>>2]=0;c[b>>2]=0;J=0;K=O;L=Q+H|0;M=P}else{J=F;K=G;L=H;M=f}}while(0);N=(L|0)>0;b:do{if((c[B>>2]|0)!=0|N){if((c[m>>2]|0)!=0){aa=K;ca=L;da=M;break}c[b>>2]=0;I=oe[c[(c[r>>2]|0)+8>>2]&63](c[s>>2]|0,j,M,h,N?L:0,l)|0;R=M-I|0;S=I+K|0;V=c[u>>2]|0;ea=(V|0)>0;do{if((c[t>>2]|0)==0){if(!ea){break}fa=V-1|0;ga=fa+(ba(V,I)|0)|0;c[j+(fa<<2)>>2]=(c[v>>2]|0)+(ba(ga,c[w>>2]|0)|0);if((fa|0)>0){ha=fa}else{break}do{ha=ha-1|0;fa=ha+(ba(c[u>>2]|0,I)|0)|0;c[j+(ha<<2)>>2]=(c[v>>2]|0)+(ba(fa,c[w>>2]|0)|0);}while((ha|0)>0)}else{if(ea){ia=0}else{break}do{fa=j+(ia<<2)|0;c[fa>>2]=(c[fa>>2]|0)+(ba(c[w>>2]|0,I)|0);ia=ia+1|0;}while((ia|0)<(c[u>>2]|0))}}while(0);I=c[l>>2]|0;ea=L-I|0;V=c[y>>2]|0;P=(V|0)>0;if((c[x>>2]|0)!=0){if(P){ja=0}else{aa=S;ca=ea;da=R;break}while(1){Q=h+(ja<<2)|0;c[Q>>2]=(c[Q>>2]|0)+(ba(c[A>>2]|0,I)|0);Q=ja+1|0;if((Q|0)<(c[y>>2]|0)){ja=Q}else{aa=S;ca=ea;da=R;break b}}}if(!P){aa=S;ca=ea;da=R;break}Q=V-1|0;O=Q+(ba(V,I)|0)|0;c[h+(Q<<2)>>2]=(c[z>>2]|0)+(ba(O,c[A>>2]|0)|0);if((Q|0)>0){ka=Q}else{aa=S;ca=ea;da=R;break}while(1){Q=ka-1|0;O=Q+(ba(c[y>>2]|0,I)|0)|0;c[h+(Q<<2)>>2]=(c[z>>2]|0)+(ba(O,c[A>>2]|0)|0);if((Q|0)>0){ka=Q}else{aa=S;ca=ea;da=R;break}}}else{aa=K;ca=L;da=M}}while(0);N=c[b>>2]|0;R=c[m>>2]|0;ea=N+ca+R|0;if((ea|0)<=(c[D>>2]|0)|(R+ca|0)>(N|0)){S=Wqb(C,ea)|0;if((S|0)<0){la=S;ma=65;break}}else{S=c[o>>2]|0;ea=(S|0)>0;do{if((c[n>>2]|0)==0){if(!ea){break}I=S-1|0;V=c[E>>2]|0;P=I+(ba(S,N)|0)|0;c[k+(I<<2)>>2]=V+(ba(P,c[q>>2]|0)|0);if((I|0)>0){na=I}else{break}do{na=na-1|0;I=na+(ba(c[o>>2]|0,N)|0)|0;c[k+(na<<2)>>2]=V+(ba(I,c[q>>2]|0)|0);}while((na|0)>0)}else{if(ea){oa=0}else{break}do{c[k+(oa<<2)>>2]=(c[a+6468+(oa<<2)>>2]|0)+(ba(c[q>>2]|0,N)|0);oa=oa+1|0;}while((oa|0)<(c[o>>2]|0))}}while(0);Zqb(C,k,R);c[b>>2]=0}if((ca|0)==0){Y=aa;Z=da;break}N=c[m>>2]|0;if((N|0)==0){pa=ca}else{ea=N+2|0;pa=(ea|0)>=(ca|0)|(da|0)==0?ca:ea}ea=N+(c[b>>2]|0)|0;N=c[o>>2]|0;S=(N|0)>0;do{if((c[n>>2]|0)==0){if(!S){break}V=N-1|0;I=c[E>>2]|0;P=V+(ba(N,ea)|0)|0;c[k+(V<<2)>>2]=I+(ba(P,c[q>>2]|0)|0);if((V|0)>0){qa=V}else{break}do{qa=qa-1|0;V=qa+(ba(c[o>>2]|0,ea)|0)|0;c[k+(qa<<2)>>2]=I+(ba(V,c[q>>2]|0)|0);}while((qa|0)>0)}else{if(S){ra=0}else{break}do{c[k+(ra<<2)>>2]=(c[a+6468+(ra<<2)>>2]|0)+(ba(c[q>>2]|0,ea)|0);ra=ra+1|0;}while((ra|0)<(c[o>>2]|0))}}while(0);Zqb(k,h,pa);ea=c[m>>2]|0;c[m>>2]=ea+pa;S=ca-pa|0;N=pa+J|0;R=c[y>>2]|0;I=(R|0)>0;do{if((c[x>>2]|0)==0){if(!I){break}V=R-1|0;P=V+(ba(R,pa)|0)|0;c[h+(V<<2)>>2]=(c[z>>2]|0)+(ba(P,c[A>>2]|0)|0);if((V|0)>0){sa=V}else{break}do{sa=sa-1|0;V=sa+(ba(c[y>>2]|0,pa)|0)|0;c[h+(sa<<2)>>2]=(c[z>>2]|0)+(ba(V,c[A>>2]|0)|0);}while((sa|0)>0)}else{if(I){ta=0}else{break}do{V=h+(ta<<2)|0;c[V>>2]=(c[V>>2]|0)+(ba(c[A>>2]|0,pa)|0);ta=ta+1|0;}while((ta|0)<(c[y>>2]|0))}}while(0);c[e>>2]=0;if((ea|0)==0&(ca|0)==(pa|0)){Y=aa;Z=da;break}else{F=N;G=aa;H=S;f=da;d=1}}if((ma|0)==65){i=g;return la|0}c[e>>2]=(Z|0)!=0;la=Y;i=g;return la|0}function crb(a){a=a|0;return 2246568}function drb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;g=yFb(b)|0;h=c[1048504+(((yFb(d)|0)*10|0)+g<<2)>>2]|0;if((h|0)==0){i=0;return i|0}g=cEb(32)|0;j=g;if((g|0)==0){i=0;return i|0}if((e|0)==1){k=zFb(d)|0;l=zFb(b)|0;m=k}else{l=b;m=d}c[g>>2]=e;c[g+12>>2]=h;c[g+20>>2]=f;if((m|0)==5|(m|0)==0){h=g+24|0;e=h|0;x=-2139062144;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=h+4|0;x=-2139062144;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x}if(!((l|0)==(m|0)&(f|0)==0)){i=j;return i|0}f=BFb(m)|0;if((f|0)==4){c[g+16>>2]=2054;i=j;return i|0}else if((f|0)==8){c[g+16>>2]=454;i=j;return i|0}else if((f|0)==1){c[g+16>>2]=2050;i=j;return i|0}else if((f|0)==2){c[g+16>>2]=2052;i=j;return i|0}else{i=j;return i|0}return 0}function erb(a,b,d){a=a|0;b=b|0;d=d|0;UGb(c[a>>2]|0,c[b>>2]|0,d)|0;return}function frb(a,b,d){a=a|0;b=b|0;d=d|0;UGb(c[a>>2]|0,c[b>>2]|0,d<<1)|0;return}function grb(a,b,d){a=a|0;b=b|0;d=d|0;UGb(c[a>>2]|0,c[b>>2]|0,d<<2)|0;return}function hrb(a,b,d){a=a|0;b=b|0;d=d|0;UGb(c[a>>2]|0,c[b>>2]|0,d<<3)|0;return}function irb(a){a=a|0;$Db(a);return}function jrb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;g=b+144|0;h=c[g>>2]|0;j=(h|0)==0;k=c[b+132>>2]|0;l=ba(c[b+136>>2]|0,j?k:1)|0;m=a|0;n=b+132|0;if((c[m>>2]|0)!=(k|0)){yDb(0,0,2168200,(o=i,i=i+24|0,c[o>>2]=2302176,c[o+8>>2]=2172552,c[o+16>>2]=175,o)|0);i=o;Cd();return 0}o=c[a+4>>2]|0;if((o|0)==0){p=0}else{if((c[d+144>>2]|0)==0){q=1;r=6}else{s=c[d+132>>2]|0;if((s|0)>0){q=s;r=6}else{t=0}}if((r|0)==6){s=0;u=0;while(1){v=c[d+(u<<2)>>2]|s;w=u+1|0;if((w|0)<(q|0)){s=v;u=w}else{t=v;break}}}p=o&t}t=c[a+8>>2]|0;if((t|0)==0){x=p}else{if(j){y=1;r=12}else{if((k|0)>0){y=k;r=12}else{z=0}}if((r|0)==12){r=0;o=0;while(1){u=c[b+(o<<2)>>2]|r;s=o+1|0;if((s|0)<(y|0)){r=u;o=s}else{z=u;break}}}x=t&z|p}p=a+16|0;z=c[p>>2]|0;do{if((z|0)==0){A=0;B=k}else{if(!((c[a+20>>2]|0)==0&(x|0)==0)){A=0;B=k;break}t=e&-16;a:do{if((t|0)>0){if((h|0)!=(c[d+144>>2]|0)){Xe[z&4095](b|0,d|0,t);break}if(j){C=1}else{if((k|0)>0){C=k}else{break}}o=0;r=z;y=h;while(1){if((y|0)==0){D=c[n>>2]|0}else{D=1}u=ba(D,t)|0;Xe[r&4095](b+(o<<2)|0,d+(o<<2)|0,u);u=o+1|0;if((u|0)>=(C|0)){break a}o=u;r=c[p>>2]|0;y=c[g>>2]|0}}}while(0);if((t|0)==(e|0)){i=f;return 0}else{A=t;B=c[m>>2]|0;break}}}while(0);if((B|0)<=0){i=f;return 0}g=a+20|0;p=a+24|0;C=ba(l,e)|0;e=a+12|0;a=ba(A,l)|0;D=d+144|0;n=d+132|0;h=d+136|0;z=0;k=B;while(1){B=c[g>>2]|0;if((B|0)==0){E=z}else{E=c[B+(z<<2)>>2]|0}if((E|0)<0){F=p;G=0}else{if((c[D>>2]|0)==0){H=ba(c[h>>2]|0,c[n>>2]|0)|0}else{H=c[h>>2]|0}F=c[d+(E<<2)>>2]|0;G=H}B=c[b+(z<<2)>>2]|0;if((B|0)==0){I=k}else{j=F+(ba(G,A)|0)|0;le[c[e>>2]&1023](B+a|0,j,G,l,B+C|0);I=c[m>>2]|0}B=z+1|0;if((B|0)<(I|0)){z=B;k=I}else{break}}i=f;return 0}function krb(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+(e*-3|0)|0;if(g>>>0>b>>>0){h=d<<1;i=e<<1;j=h+d|0;k=i+e|0;l=j+d|0;m=k+e|0;n=c;o=b;while(1){a[o]=a[n]|0;a[o+e|0]=a[n+d|0]|0;a[o+i|0]=a[n+h|0]|0;a[o+k|0]=a[n+j|0]|0;p=n+l|0;q=o+m|0;if(q>>>0<g>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=c;s=b}if(s>>>0<f>>>0){t=r;u=s}else{return}while(1){a[u]=a[t]|0;s=u+e|0;if(s>>>0<f>>>0){t=t+d|0;u=s}else{break}}return}function lrb(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>a>>>0){i=e<<1;j=f<<1;k=i+e|0;l=j+f|0;m=k+e|0;n=l+f|0;o=c;p=a;while(1){b[p>>1]=(d[o]|0)<<8^-32768;b[p+f>>1]=(d[o+e|0]|0)<<8^-32768;b[p+j>>1]=(d[o+i|0]|0)<<8^-32768;b[p+l>>1]=(d[o+k|0]|0)<<8^-32768;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=c;t=a}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){b[v>>1]=(d[u]|0)<<8^-32768;t=v+f|0;if(t>>>0<g>>>0){u=u+e|0;v=t}else{break}}return}function mrb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>a>>>0){i=e<<1;j=f<<1;k=i+e|0;l=j+f|0;m=k+e|0;n=l+f|0;o=b;p=a;while(1){c[p>>2]=(d[o]|0)<<24^-2147483648;c[p+f>>2]=(d[o+e|0]|0)<<24^-2147483648;c[p+j>>2]=(d[o+i|0]|0)<<24^-2147483648;c[p+l>>2]=(d[o+k|0]|0)<<24^-2147483648;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){c[v>>2]=(d[u]|0)<<24^-2147483648;t=v+f|0;if(t>>>0<g>>>0){u=u+e|0;v=t}else{break}}return}function nrb(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=c<<1;j=e<<1;k=i+c|0;l=j+e|0;m=k+c|0;n=l+e|0;o=b;p=a;while(1){g[p>>2]=+((d[o]|0)-128|0)*.0078125;g[p+e>>2]=+((d[o+c|0]|0)-128|0)*.0078125;g[p+j>>2]=+((d[o+i|0]|0)-128|0)*.0078125;g[p+l>>2]=+((d[o+k|0]|0)-128|0)*.0078125;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){g[v>>2]=+((d[u]|0)-128|0)*.0078125;t=v+e|0;if(t>>>0<f>>>0){u=u+c|0;v=t}else{break}}return}function orb(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=c<<1;j=e<<1;k=i+c|0;l=j+e|0;m=k+c|0;n=l+e|0;o=b;p=a;while(1){h[p>>3]=+((d[o]|0)-128|0)*.0078125;h[p+e>>3]=+((d[o+c|0]|0)-128|0)*.0078125;h[p+j>>3]=+((d[o+i|0]|0)-128|0)*.0078125;h[p+l>>3]=+((d[o+k|0]|0)-128|0)*.0078125;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){h[v>>3]=+((d[u]|0)-128|0)*.0078125;t=v+e|0;if(t>>>0<f>>>0){u=u+c|0;v=t}else{break}}return}function prb(b,c,d,f,g){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>b>>>0){i=d<<1;j=f<<1;k=i+d|0;l=j+f|0;m=k+d|0;n=l+f|0;o=c;p=b;while(1){a[p]=((e[o>>1]|0)>>>8)+128;a[p+f|0]=((e[o+d>>1]|0)>>>8)+128;a[p+j|0]=((e[o+i>>1]|0)>>>8)+128;a[p+l|0]=((e[o+k>>1]|0)>>>8)+128;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=c;t=b}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){a[v]=((e[u>>1]|0)>>>8)+128;t=v+f|0;if(t>>>0<g>>>0){u=u+d|0;v=t}else{break}}return}function qrb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){h=d<<1;i=e<<1;j=h+d|0;k=i+e|0;l=j+d|0;m=k+e|0;n=c;o=a;while(1){b[o>>1]=b[n>>1]|0;b[o+e>>1]=b[n+d>>1]|0;b[o+i>>1]=b[n+h>>1]|0;b[o+k>>1]=b[n+j>>1]|0;p=n+l|0;q=o+m|0;if(q>>>0<g>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=c;s=a}if(s>>>0<f>>>0){t=r;u=s}else{return}while(1){b[u>>1]=b[t>>1]|0;s=u+e|0;if(s>>>0<f>>>0){t=t+d|0;u=s}else{break}}return}function rrb(a,b,d,f,g){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=f<<1;k=i+d|0;l=j+f|0;m=k+d|0;n=l+f|0;o=b;p=a;while(1){c[p>>2]=(e[o>>1]|0)<<16;c[p+f>>2]=(e[o+d>>1]|0)<<16;c[p+j>>2]=(e[o+i>>1]|0)<<16;c[p+l>>2]=(e[o+k>>1]|0)<<16;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){c[v>>2]=(e[u>>1]|0)<<16;t=v+f|0;if(t>>>0<g>>>0){u=u+d|0;v=t}else{break}}return}function srb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=a;while(1){g[p>>2]=+(b[o>>1]|0)*30517578125.0e-15;g[p+e>>2]=+(b[o+d>>1]|0)*30517578125.0e-15;g[p+j>>2]=+(b[o+i>>1]|0)*30517578125.0e-15;g[p+l>>2]=+(b[o+k>>1]|0)*30517578125.0e-15;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=c;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){g[v>>2]=+(b[u>>1]|0)*30517578125.0e-15;t=v+e|0;if(t>>>0<f>>>0){u=u+d|0;v=t}else{break}}return}function trb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=a;while(1){h[p>>3]=+(b[o>>1]|0)*30517578125.0e-15;h[p+e>>3]=+(b[o+d>>1]|0)*30517578125.0e-15;h[p+j>>3]=+(b[o+i>>1]|0)*30517578125.0e-15;h[p+l>>3]=+(b[o+k>>1]|0)*30517578125.0e-15;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=c;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){h[v>>3]=+(b[u>>1]|0)*30517578125.0e-15;t=v+e|0;if(t>>>0<f>>>0){u=u+d|0;v=t}else{break}}return}function urb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>b>>>0){i=e<<1;j=f<<1;k=i+e|0;l=j+f|0;m=k+e|0;n=l+f|0;o=d;p=b;while(1){a[p]=((c[o>>2]|0)>>>24)+128;a[p+f|0]=((c[o+e>>2]|0)>>>24)+128;a[p+j|0]=((c[o+i>>2]|0)>>>24)+128;a[p+l|0]=((c[o+k>>2]|0)>>>24)+128;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=d;t=b}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){a[v]=((c[u>>2]|0)>>>24)+128;t=v+f|0;if(t>>>0<g>>>0){u=u+e|0;v=t}else{break}}return}function vrb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>a>>>0){i=e<<1;j=f<<1;k=i+e|0;l=j+f|0;m=k+e|0;n=l+f|0;o=d;p=a;while(1){b[p>>1]=(c[o>>2]|0)>>>16;b[p+f>>1]=(c[o+e>>2]|0)>>>16;b[p+j>>1]=(c[o+i>>2]|0)>>>16;b[p+l>>1]=(c[o+k>>2]|0)>>>16;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=d;t=a}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){b[v>>1]=(c[u>>2]|0)>>>16;t=v+f|0;if(t>>>0<g>>>0){u=u+e|0;v=t}else{break}}return}function wrb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){h=d<<1;i=e<<1;j=h+d|0;k=i+e|0;l=j+d|0;m=k+e|0;n=b;o=a;while(1){c[o>>2]=c[n>>2];c[o+e>>2]=c[n+d>>2];c[o+i>>2]=c[n+h>>2];c[o+k>>2]=c[n+j>>2];p=n+l|0;q=o+m|0;if(q>>>0<g>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=b;s=a}if(s>>>0<f>>>0){t=r;u=s}else{return}while(1){c[u>>2]=c[t>>2];s=u+e|0;if(s>>>0<f>>>0){t=t+d|0;u=s}else{break}}return}function xrb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=b;p=a;while(1){g[p>>2]=+(c[o>>2]|0)*4.656612873077393e-10;g[p+e>>2]=+(c[o+d>>2]|0)*4.656612873077393e-10;g[p+j>>2]=+(c[o+i>>2]|0)*4.656612873077393e-10;g[p+l>>2]=+(c[o+k>>2]|0)*4.656612873077393e-10;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){g[v>>2]=+(c[u>>2]|0)*4.656612873077393e-10;t=v+e|0;if(t>>>0<f>>>0){u=u+d|0;v=t}else{break}}return}function yrb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=b;p=a;while(1){h[p>>3]=+(c[o>>2]|0)*4.656612873077393e-10;h[p+e>>3]=+(c[o+d>>2]|0)*4.656612873077393e-10;h[p+j>>3]=+(c[o+i>>2]|0)*4.656612873077393e-10;h[p+l>>3]=+(c[o+k>>2]|0)*4.656612873077393e-10;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){h[v>>3]=+(c[u>>2]|0)*4.656612873077393e-10;t=v+e|0;if(t>>>0<f>>>0){u=u+d|0;v=t}else{break}}return}function zrb(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=f+(e*-3|0)|0;if(h>>>0>b>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=b;while(1){q=Gc(+(+g[o>>2]*128.0))|0;r=q+128|0;if(r>>>0>255>>>0){s=-128-q>>31&255}else{s=r&255}a[p]=s;r=Gc(+(+g[o+d>>2]*128.0))|0;q=r+128|0;if(q>>>0>255>>>0){t=-128-r>>31&255}else{t=q&255}a[p+e|0]=t;q=Gc(+(+g[o+i>>2]*128.0))|0;r=q+128|0;if(r>>>0>255>>>0){u=-128-q>>31&255}else{u=r&255}a[p+j|0]=u;r=Gc(+(+g[o+k>>2]*128.0))|0;q=r+128|0;if(q>>>0>255>>>0){v=-128-r>>31&255}else{v=q&255}a[p+l|0]=v;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{w=q;x=r;break}}}else{w=c;x=b}if(x>>>0<f>>>0){y=w;z=x}else{return}while(1){x=Gc(+(+g[y>>2]*128.0))|0;w=x+128|0;if(w>>>0>255>>>0){A=-128-x>>31&255}else{A=w&255}a[z]=A;w=z+e|0;if(w>>>0<f>>>0){y=y+d|0;z=w}else{break}}return}function Arb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=a;while(1){q=Gc(+(+g[o>>2]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){r=(q>>31^32767)&65535}else{r=q&65535}b[p>>1]=r;q=Gc(+(+g[o+d>>2]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){s=(q>>31^32767)&65535}else{s=q&65535}b[p+e>>1]=s;q=Gc(+(+g[o+i>>2]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){t=(q>>31^32767)&65535}else{t=q&65535}b[p+j>>1]=t;q=Gc(+(+g[o+k>>2]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){u=(q>>31^32767)&65535}else{u=q&65535}b[p+l>>1]=u;q=o+m|0;v=p+n|0;if(v>>>0<h>>>0){o=q;p=v}else{w=q;x=v;break}}}else{w=c;x=a}if(x>>>0<f>>>0){y=w;z=x}else{return}while(1){x=Gc(+(+g[y>>2]*32768.0))|0;if((x+32768|0)>>>0>65535>>>0){A=(x>>31^32767)&65535}else{A=x&65535}b[z>>1]=A;x=z+e|0;if(x>>>0<f>>>0){y=y+d|0;z=x}else{break}}return}function Brb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=b;p=a;while(1){q=ce(+(+g[o>>2]*2147483648.0))|0;r=F;s=YGb(q,r,-2147483648,0)|0;t=F;u=0;if(t>>>0>u>>>0|t>>>0==u>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;v=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{v=q}c[p>>2]=v;q=ce(+(+g[o+d>>2]*2147483648.0))|0;r=F;s=YGb(q,r,-2147483648,0)|0;u=F;t=0;if(u>>>0>t>>>0|u>>>0==t>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;w=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{w=q}c[p+e>>2]=w;q=ce(+(+g[o+i>>2]*2147483648.0))|0;r=F;s=YGb(q,r,-2147483648,0)|0;t=F;u=0;if(t>>>0>u>>>0|t>>>0==u>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;x=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{x=q}c[p+j>>2]=x;q=ce(+(+g[o+k>>2]*2147483648.0))|0;r=F;s=YGb(q,r,-2147483648,0)|0;u=F;t=0;if(u>>>0>t>>>0|u>>>0==t>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;y=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{y=q}c[p+l>>2]=y;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{z=q;A=r;break}}}else{z=b;A=a}if(A>>>0<f>>>0){B=z;C=A}else{return}while(1){A=ce(+(+g[B>>2]*2147483648.0))|0;z=F;a=YGb(A,z,-2147483648,0)|0;b=F;p=0;if(b>>>0>p>>>0|b>>>0==p>>>0&a>>>0>-1>>>0){((z|0)<0|0?-1:0)>>31|((z|0)<0|0?-1:0)<<1;D=(z>>31|((z|0)<0|0?-1:0)<<1)^2147483647}else{D=A}c[C>>2]=D;A=C+e|0;if(A>>>0<f>>>0){B=B+d|0;C=A}else{break}}return}function Crb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=e+(d*-3|0)|0;if(f>>>0>a>>>0){h=c<<1;i=d<<1;j=h+c|0;k=i+d|0;l=j+c|0;m=k+d|0;n=b;o=a;while(1){g[o>>2]=+g[n>>2];g[o+d>>2]=+g[n+c>>2];g[o+i>>2]=+g[n+h>>2];g[o+k>>2]=+g[n+j>>2];p=n+l|0;q=o+m|0;if(q>>>0<f>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=b;s=a}if(s>>>0<e>>>0){t=r;u=s}else{return}while(1){g[u>>2]=+g[t>>2];s=u+d|0;if(s>>>0<e>>>0){t=t+c|0;u=s}else{break}}return}function Drb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=e+(d*-3|0)|0;if(f>>>0>a>>>0){i=c<<1;j=d<<1;k=i+c|0;l=j+d|0;m=k+c|0;n=l+d|0;o=b;p=a;while(1){h[p>>3]=+g[o>>2];h[p+d>>3]=+g[o+c>>2];h[p+j>>3]=+g[o+i>>2];h[p+l>>3]=+g[o+k>>2];q=o+m|0;r=p+n|0;if(r>>>0<f>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<e>>>0){u=s;v=t}else{return}while(1){h[v>>3]=+g[u>>2];t=v+d|0;if(t>>>0<e>>>0){u=u+c|0;v=t}else{break}}return}function Erb(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=f+(e*-3|0)|0;if(g>>>0>b>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=b;while(1){q=Gc(+(+h[o>>3]*128.0))|0;r=q+128|0;if(r>>>0>255>>>0){s=-128-q>>31&255}else{s=r&255}a[p]=s;r=Gc(+(+h[o+d>>3]*128.0))|0;q=r+128|0;if(q>>>0>255>>>0){t=-128-r>>31&255}else{t=q&255}a[p+e|0]=t;q=Gc(+(+h[o+i>>3]*128.0))|0;r=q+128|0;if(r>>>0>255>>>0){u=-128-q>>31&255}else{u=r&255}a[p+j|0]=u;r=Gc(+(+h[o+k>>3]*128.0))|0;q=r+128|0;if(q>>>0>255>>>0){v=-128-r>>31&255}else{v=q&255}a[p+l|0]=v;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{w=q;x=r;break}}}else{w=c;x=b}if(x>>>0<f>>>0){y=w;z=x}else{return}while(1){x=Gc(+(+h[y>>3]*128.0))|0;w=x+128|0;if(w>>>0>255>>>0){A=-128-x>>31&255}else{A=w&255}a[z]=A;w=z+e|0;if(w>>>0<f>>>0){y=y+d|0;z=w}else{break}}return}function Frb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=a;while(1){q=Gc(+(+h[o>>3]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){r=(q>>31^32767)&65535}else{r=q&65535}b[p>>1]=r;q=Gc(+(+h[o+d>>3]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){s=(q>>31^32767)&65535}else{s=q&65535}b[p+e>>1]=s;q=Gc(+(+h[o+i>>3]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){t=(q>>31^32767)&65535}else{t=q&65535}b[p+j>>1]=t;q=Gc(+(+h[o+k>>3]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){u=(q>>31^32767)&65535}else{u=q&65535}b[p+l>>1]=u;q=o+m|0;v=p+n|0;if(v>>>0<g>>>0){o=q;p=v}else{w=q;x=v;break}}}else{w=c;x=a}if(x>>>0<f>>>0){y=w;z=x}else{return}while(1){x=Gc(+(+h[y>>3]*32768.0))|0;if((x+32768|0)>>>0>65535>>>0){A=(x>>31^32767)&65535}else{A=x&65535}b[z>>1]=A;x=z+e|0;if(x>>>0<f>>>0){y=y+d|0;z=x}else{break}}return}function Grb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=b;p=a;while(1){q=ce(+(+h[o>>3]*2147483648.0))|0;r=F;s=YGb(q,r,-2147483648,0)|0;t=F;u=0;if(t>>>0>u>>>0|t>>>0==u>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;v=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{v=q}c[p>>2]=v;q=ce(+(+h[o+d>>3]*2147483648.0))|0;r=F;s=YGb(q,r,-2147483648,0)|0;u=F;t=0;if(u>>>0>t>>>0|u>>>0==t>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;w=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{w=q}c[p+e>>2]=w;q=ce(+(+h[o+i>>3]*2147483648.0))|0;r=F;s=YGb(q,r,-2147483648,0)|0;t=F;u=0;if(t>>>0>u>>>0|t>>>0==u>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;x=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{x=q}c[p+j>>2]=x;q=ce(+(+h[o+k>>3]*2147483648.0))|0;r=F;s=YGb(q,r,-2147483648,0)|0;u=F;t=0;if(u>>>0>t>>>0|u>>>0==t>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;y=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{y=q}c[p+l>>2]=y;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{z=q;A=r;break}}}else{z=b;A=a}if(A>>>0<f>>>0){B=z;C=A}else{return}while(1){A=ce(+(+h[B>>3]*2147483648.0))|0;z=F;a=YGb(A,z,-2147483648,0)|0;b=F;p=0;if(b>>>0>p>>>0|b>>>0==p>>>0&a>>>0>-1>>>0){((z|0)<0|0?-1:0)>>31|((z|0)<0|0?-1:0)<<1;D=(z>>31|((z|0)<0|0?-1:0)<<1)^2147483647}else{D=A}c[C>>2]=D;A=C+e|0;if(A>>>0<f>>>0){B=B+d|0;C=A}else{break}}return}function Hrb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=e+(d*-3|0)|0;if(f>>>0>a>>>0){i=c<<1;j=d<<1;k=i+c|0;l=j+d|0;m=k+c|0;n=l+d|0;o=b;p=a;while(1){g[p>>2]=+h[o>>3];g[p+d>>2]=+h[o+c>>3];g[p+j>>2]=+h[o+i>>3];g[p+l>>2]=+h[o+k>>3];q=o+m|0;r=p+n|0;if(r>>>0<f>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<e>>>0){u=s;v=t}else{return}while(1){g[v>>2]=+h[u>>3];t=v+d|0;if(t>>>0<e>>>0){u=u+c|0;v=t}else{break}}return}function Irb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=e+(d*-3|0)|0;if(f>>>0>a>>>0){g=c<<1;i=d<<1;j=g+c|0;k=i+d|0;l=j+c|0;m=k+d|0;n=b;o=a;while(1){h[o>>3]=+h[n>>3];h[o+d>>3]=+h[n+c>>3];h[o+i>>3]=+h[n+g>>3];h[o+k>>3]=+h[n+j>>3];p=n+l|0;q=o+m|0;if(q>>>0<f>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=b;s=a}if(s>>>0<e>>>0){t=r;u=s}else{return}while(1){h[u>>3]=+h[t>>3];s=u+d|0;if(s>>>0<e>>>0){t=t+c|0;u=s}else{break}}return}function Jrb(a,d,e,f,j){a=a|0;d=d|0;e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0;k=i;l=a+88|0;m=+g[a+100>>2];a=e+2|0;if(a>>>0>268435454>>>0){n=0}else{n=WDb(a<<3)|0}o=n;a:do{if((a|0)>0){p=c[l>>2]|0;q=p>>>0<72>>>0;if((p|0)==1){p=f;r=0;while(1){p=(ba(p,1664525)|0)+1013904223|0;h[o+(r<<3)>>3]=+(p>>>0>>>0)/4294967295.0+-.5;r=r+1|0;if((r|0)>=(a|0)){break a}}}else{s=f;t=0}while(1){r=(ba(s,1664525)|0)+1013904223|0;if(!q){break}s=(ba(r,1664525)|0)+1013904223|0;h[o+(t<<3)>>3]=+(r>>>0>>>0)/4294967295.0- +(s>>>0>>>0)/4294967295.0;t=t+1|0;if((t|0)>=(a|0)){break a}}yDb(0,0,2168128,(u=i,i=i+24|0,c[u>>2]=2302104,c[u+8>>2]=2172528,c[u+16>>2]=39,u)|0);i=u;Cd()}}while(0);if((e|0)<=0){ZDb(n);i=k;return}a=c[l>>2]|0;l=d;t=d;s=d;f=d;if((a|0)==3){d=0;while(1){v=m*((+h[o+(d+1<<3)>>3]*2.0- +h[o+(d<<3)>>3]- +h[o+(d+2<<3)>>3])/2.449489742783178);if((j|0)==7){c[t+(d<<2)>>2]=~~v}else if((j|0)==9){h[f+(d<<3)>>3]=v}else if((j|0)==6){b[l+(d<<1)>>1]=~~v}else if((j|0)==8){g[s+(d<<2)>>2]=v}else{w=25;break}q=d+1|0;if((q|0)<(e|0)){d=q}else{w=26;break}}if((w|0)==25){yDb(0,0,2168128,(u=i,i=i+24|0,c[u>>2]=2098096,c[u+8>>2]=2172528,c[u+16>>2]=68,u)|0);i=u;Cd()}else if((w|0)==26){ZDb(n);i=k;return}}if(a>>>0<72>>>0){x=0}else{yDb(0,0,2168128,(u=i,i=i+24|0,c[u>>2]=2302104,c[u+8>>2]=2172528,c[u+16>>2]=53,u)|0);i=u;Cd()}while(1){v=m*+h[o+(x<<3)>>3];if((j|0)==8){g[s+(x<<2)>>2]=v}else if((j|0)==6){b[l+(x<<1)>>1]=~~v}else if((j|0)==9){h[f+(x<<3)>>3]=v}else if((j|0)==7){c[t+(x<<2)>>2]=~~v}else{w=25;break}a=x+1|0;if((a|0)<(e|0)){x=a}else{w=26;break}}if((w|0)==25){yDb(0,0,2168128,(u=i,i=i+24|0,c[u>>2]=2098096,c[u+8>>2]=2172528,c[u+16>>2]=68,u)|0);i=u;Cd()}else if((w|0)==26){ZDb(n);i=k;return}}function Krb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0;e=i;f=a+88|0;if(((c[f>>2]|0)-4|0)>>>0<61>>>0){j=-22;i=e;return j|0}k=yFb(b)|0;b=yFb(d)|0;do{if((b-3|0)>>>0<2>>>0){d=(k|0)==2;l=(k|0)==0?.0078125:(k|0)==1?30517578125.0e-15:d?-4.656612873077393e-10:0.0;m=0;n=d}else{d=(b|0)==2;o=(k|0)==2;if(!(d&o)){l=0.0;m=d;n=o;break}l=(c[a+5624>>2]&31|0)==0?0.0:1.0;m=1;n=1}}while(0);o=(k|0)==0;p=+g[a+96>>2]*((b|0)==1&o?256.0:m&o?16777216.0:m&(k|0)==1?65536.0:l);do{if(n){m=c[a+5624>>2]|0;if((m|0)==0){q=p;break}q=p*+(1<<32-m|0)}else{q=p}}while(0);c[a+116>>2]=0;p=q;n=a+100|0;g[n>>2]=p;g[a+108>>2]=p;if(q!=0.0){r=1.0/q}else{r=0.0}m=a+112|0;g[m>>2]=r;TGb(a+200|0,0,5120)|0;o=c[a+44>>2]|0;b=0;d=1058416;while(1){s=c[1058400+(b*24|0)>>2]|0;if(!(+Q(+(+(o-s|0)))/+(s|0)>.05)){if((c[1058420+(b*24|0)>>2]|0)==(c[f>>2]|0)){t=14;break}}s=b+1|0;if((s|0)==15){t=19;break}else{b=s;d=1058416+(s*24|0)|0}}do{if((t|0)==14){o=c[1058408+(b*24|0)>>2]|0;c[a+104>>2]=o;if((b|0)!=15){s=c[d>>2]|0;u=0;do{g[a+120+(u<<2)>>2]=+h[s+(u<<3)>>3];u=u+1|0;}while(u>>>0<o>>>0)}r=+_(+(c[1058412+(b*24|0)>>2]|0)*2.302585092994046*.005)*2.0;q=1.0-r/+(1<<((BFb(k)|0)<<3)|0);g[m>>2]=q*+g[m>>2]}else if((t|0)==19){if(!((c[f>>2]|0)>>>0>64>>>0)){break}yDb(a,24,2042792,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;c[f>>2]=3}}while(0);if((c[a+6304>>2]|0)!=0){yDb(0,0,2168128,(v=i,i=i+24|0,c[v>>2]=1997816,c[v+8>>2]=2172528,c[v+16>>2]=122,v)|0);i=v;Cd();return 0}v=a+6164|0;UGb(a+5320|0,v|0,152)|0;UGb(a+5472|0,v|0,152)|0;if(!((c[f>>2]|0)>>>0>64>>>0)){j=0;i=e;return j|0}c[a+5456>>2]=4;c[a+5468>>2]=8;g[n>>2]=1.0;j=0;i=e;return j|0}function Lrb(a,d,e,f,h){a=a|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0,G=0.0,H=0.0,I=0,J=0;i=a+116|0;j=c[i>>2]|0;k=c[a+104>>2]|0;l=+g[a+112>>2];m=c[e+132>>2]|0;if((m|0)<=0){n=j;c[i>>2]=n;return}o=a+92|0;p=(h|0)>0;q=k-2|0;r=(q|0)>0;s=+g[a+108>>2];t=0;u=j;while(1){j=c[f+(t<<2)>>2]|0;v=c[o>>2]|0;w=c[e+(t<<2)>>2]|0;x=c[d+(t<<2)>>2]|0;if(p){y=0;z=u;while(1){A=l*+(b[w+(y<<1)>>1]|0);if(r){B=0;C=A;while(1){D=B+z|0;E=C-(+g[a+120+(B<<2)>>2]*+g[a+200+(t*160|0)+(D<<2)>>2]+ +g[a+120+((B|1)<<2)>>2]*+g[a+200+(t*160|0)+(D+1<<2)>>2]+ +g[a+120+((B|2)<<2)>>2]*+g[a+200+(t*160|0)+(D+2<<2)>>2]+ +g[a+120+((B|3)<<2)>>2]*+g[a+200+(t*160|0)+(D+3<<2)>>2]);D=B+4|0;if((D|0)<(q|0)){B=D;C=E}else{F=D;G=E;break}}}else{F=0;G=A}if((F|0)<(k|0)){H=G- +g[a+120+(F<<2)>>2]*+g[a+200+(t*160|0)+(F+z<<2)>>2]}else{H=G}B=((z|0)!=0?z:k)-1|0;C=+Gc(+(H+ +g[j+(y+v<<2)>>2]));E=C-H;g[a+200+(t*160|0)+(B<<2)>>2]=E;g[a+200+(t*160|0)+(B+k<<2)>>2]=E;E=s*C;C=E>32767.0?32767.0:E;if(C>-32768.0){I=~~C}else{I=-32768}b[x+(y<<1)>>1]=I;D=y+1|0;if((D|0)<(h|0)){y=D;z=B}else{J=B;break}}}else{J=u}z=t+1|0;if((z|0)>=(m|0)){n=J;break}t=z;u=c[i>>2]|0}c[i>>2]=n;return}function Mrb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0,G=0.0,H=0.0,I=0,J=0,K=0;h=a+116|0;i=c[h>>2]|0;j=c[a+104>>2]|0;k=+g[a+112>>2];l=d+132|0;m=c[l>>2]|0;if((m|0)<=0){n=i;c[h>>2]=n;return}o=a+92|0;p=(f|0)>0;q=j-2|0;r=(q|0)>0;s=+g[a+108>>2];t=0;u=m;m=i;while(1){i=c[e+(t<<2)>>2]|0;v=c[o>>2]|0;w=c[d+(t<<2)>>2]|0;x=c[b+(t<<2)>>2]|0;if(p){y=0;z=m;do{A=k*+(c[w+(y<<2)>>2]|0);if(r){B=0;C=A;while(1){D=B+z|0;E=C-(+g[a+120+(B<<2)>>2]*+g[a+200+(t*160|0)+(D<<2)>>2]+ +g[a+120+((B|1)<<2)>>2]*+g[a+200+(t*160|0)+(D+1<<2)>>2]+ +g[a+120+((B|2)<<2)>>2]*+g[a+200+(t*160|0)+(D+2<<2)>>2]+ +g[a+120+((B|3)<<2)>>2]*+g[a+200+(t*160|0)+(D+3<<2)>>2]);D=B+4|0;if((D|0)<(q|0)){B=D;C=E}else{F=D;G=E;break}}}else{F=0;G=A}if((F|0)<(j|0)){H=G- +g[a+120+(F<<2)>>2]*+g[a+200+(t*160|0)+(F+z<<2)>>2]}else{H=G}z=((z|0)!=0?z:j)-1|0;C=+Gc(+(H+ +g[i+(y+v<<2)>>2]));E=C-H;g[a+200+(t*160|0)+(z<<2)>>2]=E;g[a+200+(t*160|0)+(z+j<<2)>>2]=E;E=s*C;C=E>2147483647.0?2147483647.0:E;if(C>-2147483648.0){I=~~C}else{I=-2147483648}c[x+(y<<2)>>2]=I;y=y+1|0;}while((y|0)<(f|0));J=z;K=c[l>>2]|0}else{J=m;K=u}y=t+1|0;if((y|0)>=(K|0)){n=J;break}t=y;u=K;m=c[h>>2]|0}c[h>>2]=n;return}function Nrb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0,E=0,F=0.0,G=0.0,H=0;h=a+116|0;i=c[h>>2]|0;j=c[a+104>>2]|0;k=+g[a+112>>2];l=c[d+132>>2]|0;if((l|0)<=0){m=i;c[h>>2]=m;return}n=a+92|0;o=(f|0)>0;p=j-2|0;q=(p|0)>0;r=+g[a+108>>2];s=0;t=i;while(1){i=c[e+(s<<2)>>2]|0;u=c[n>>2]|0;v=c[d+(s<<2)>>2]|0;w=c[b+(s<<2)>>2]|0;if(o){x=0;y=t;while(1){z=k*+g[v+(x<<2)>>2];if(q){A=0;B=z;while(1){C=A+y|0;D=B-(+g[a+120+(A<<2)>>2]*+g[a+200+(s*160|0)+(C<<2)>>2]+ +g[a+120+((A|1)<<2)>>2]*+g[a+200+(s*160|0)+(C+1<<2)>>2]+ +g[a+120+((A|2)<<2)>>2]*+g[a+200+(s*160|0)+(C+2<<2)>>2]+ +g[a+120+((A|3)<<2)>>2]*+g[a+200+(s*160|0)+(C+3<<2)>>2]);C=A+4|0;if((C|0)<(p|0)){A=C;B=D}else{E=C;F=D;break}}}else{E=0;F=z}if((E|0)<(j|0)){G=F- +g[a+120+(E<<2)>>2]*+g[a+200+(s*160|0)+(E+y<<2)>>2]}else{G=F}A=((y|0)!=0?y:j)-1|0;B=+Gc(+(G+ +g[i+(x+u<<2)>>2]));D=B-G;g[a+200+(s*160|0)+(A<<2)>>2]=D;g[a+200+(s*160|0)+(A+j<<2)>>2]=D;g[w+(x<<2)>>2]=r*B;C=x+1|0;if((C|0)<(f|0)){x=C;y=A}else{H=A;break}}}else{H=t}y=s+1|0;if((y|0)>=(l|0)){m=H;break}s=y;t=c[h>>2]|0}c[h>>2]=m;return}function Orb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0,G=0.0,H=0.0,I=0;i=a+116|0;j=c[i>>2]|0;k=c[a+104>>2]|0;l=c[d+132>>2]|0;if((l|0)<=0){m=j;c[i>>2]=m;return}n=a+92|0;o=(f|0)>0;p=+g[a+112>>2];q=k-2|0;r=(q|0)>0;s=+g[a+108>>2];t=0;u=j;while(1){j=c[e+(t<<2)>>2]|0;v=c[n>>2]|0;w=c[d+(t<<2)>>2]|0;x=c[b+(t<<2)>>2]|0;if(o){y=0;z=u;while(1){A=p*+h[w+(y<<3)>>3];if(r){B=0;C=A;while(1){D=B+z|0;E=C-(+g[a+120+(B<<2)>>2]*+g[a+200+(t*160|0)+(D<<2)>>2]+ +g[a+120+((B|1)<<2)>>2]*+g[a+200+(t*160|0)+(D+1<<2)>>2]+ +g[a+120+((B|2)<<2)>>2]*+g[a+200+(t*160|0)+(D+2<<2)>>2]+ +g[a+120+((B|3)<<2)>>2]*+g[a+200+(t*160|0)+(D+3<<2)>>2]);D=B+4|0;if((D|0)<(q|0)){B=D;C=E}else{F=D;G=E;break}}}else{F=0;G=A}if((F|0)<(k|0)){H=G- +g[a+120+(F<<2)>>2]*+g[a+200+(t*160|0)+(F+z<<2)>>2]}else{H=G}B=((z|0)!=0?z:k)-1|0;C=+Gc(+(H+ +g[j+(y+v<<2)>>2]));E=C-H;g[a+200+(t*160|0)+(B<<2)>>2]=E;g[a+200+(t*160|0)+(B+k<<2)>>2]=E;h[x+(y<<3)>>3]=s*C;D=y+1|0;if((D|0)<(f|0)){y=D;z=B}else{I=B;break}}}else{I=u}z=t+1|0;if((z|0)>=(l|0)){m=I;break}t=z;u=c[i>>2]|0}c[i>>2]=m;return}function Prb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;j=a+24|0;k=c[j>>2]|0;l=a+28|0;m=c[l>>2]|0;n=a+20|0;o=c[n>>2]|0;p=a+32|0;q=c[p>>2]|0;r=(o|0)%(q|0)|0;s=(o|0)/(q|0)|0;t=a+36|0;u=c[t>>2]|0;v=a+8|0;a:do{if((u|0)==0){w=c[v>>2]|0;do{if((w|0)==1){if((c[a+40>>2]|0)!=0){break}x=o;y=q;z=(q|0)<0|0?-1:0;A=eHb(0,x,y,z)|0;B=F;C=(h|0)<0|0?-1:0;D=g-1-k|0;E=gHb(y,z,D,(D|0)<0|0?-1:0)|0;D=eHb(E,F,x,(o|0)<0|0?-1:0)|0;x=F;E=(C|0)>(x|0)|(C|0)==(x|0)&h>>>0>D>>>0?D:h;if((E|0)>0){D=k;x=0;C=0;while(1){b[d+(C<<1)>>1]=b[e+(D<<1)>>1]|0;G=YGb(x,D,A,B)|0;H=C+1|0;if((H|0)<(E|0)){D=F;x=G;C=H}else{I=E;break}}}else{I=0}E=(ba(I,s)|0)+k|0;C=gHb(I,(I|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;x=YGb(C,F,m,(m|0)<0|0?-1:0)|0;C=F;D=eHb(x,C,y,z)|0;B=YGb(D,F,E,0)|0;E=B;B=fHb(x,C,y,z)|0;c[f>>2]=E;J=I;K=0;L=s;M=r;N=B;O=c[a+44>>2]&E;break a}}while(0);if(!((c[a+48>>2]|0)==0&(k|0)>-1)){P=0;Q=8;break}b:do{if((h|0)>0){E=c[a+40>>2]|0;B=c[a+44>>2]|0;C=c[a+4>>2]|0;x=c[a+12>>2]|0;D=k;A=m;H=0;G=0;while(1){R=(D>>E)+H|0;S=B&D;T=ba(x,S)|0;if((w+R|0)>(g|0)){U=R;V=S;W=A;X=G;break b}do{if((w|0)>0){Y=0;Z=0;do{Z=(ba(b[C+(Y+T<<1)>>1]|0,b[e+(Y+R<<1)>>1]|0)|0)+Z|0;Y=Y+1|0;}while((Y|0)<(w|0));Y=Z+16384|0;_=Y>>15;if(!((_+32768|0)>>>0>65535>>>0)){$=_&65535;break}$=(Y>>31^32767)&65535}else{$=0}}while(0);b[d+(G<<1)>>1]=$;T=A+r|0;Y=S+s|0;if((T|0)<(q|0)){aa=T;ca=Y}else{aa=T-q|0;ca=Y+1|0}Y=G+1|0;if((Y|0)<(h|0)){D=ca;A=aa;H=R;G=Y}else{U=R;V=ca;W=aa;X=Y;break}}}else{U=0;V=k;W=m;X=0}}while(0);c[f>>2]=U;J=X;K=0;L=s;M=r;N=W;O=V}else{P=u;Q=8}}while(0);if((Q|0)==8){u=a+40|0;V=a+44|0;W=a+4|0;X=a+12|0;U=a+48|0;aa=a+16|0;a=0;ca=0;$=P;P=s;s=r;r=m;m=k;c:while(1){k=a;da=ca;ea=r;I=m;while(1){if((da|0)>=(h|0)){fa=k;ga=I;break c}ha=(I>>c[u>>2])+k|0;o=c[V>>2]&I;w=c[W>>2]|0;G=c[X>>2]|0;H=ba(G,o)|0;A=c[v>>2]|0;if(!((A+ha|0)<=(g|0)&(-ha|0)<(g|0))){fa=ha;ga=o;break c}d:do{if((ha|0)<0){if((A|0)>0){ia=0;ja=0}else{ka=0;break}while(1){D=ia+ha|0;C=(ba(b[w+(ia+H<<1)>>1]|0,b[e+(((D|0)>-1?D:-D|0)<<1)>>1]|0)|0)+ja|0;D=ia+1|0;if((D|0)<(A|0)){ia=D;ja=C}else{la=C;Q=32;break}}}else{R=(A|0)>0;if((c[U>>2]|0)==0){if(R){ma=0;na=0}else{ka=0;break}while(1){S=(ba(b[w+(ma+H<<1)>>1]|0,b[e+(ma+ha<<1)>>1]|0)|0)+na|0;C=ma+1|0;if((C|0)<(A|0)){ma=C;na=S}else{la=S;Q=32;break d}}}if(R){S=0;C=0;D=0;while(1){x=b[e+(S+ha<<1)>>1]|0;B=S+H|0;E=(ba(b[w+(B<<1)>>1]|0,x)|0)+C|0;z=(ba(b[w+(B+G<<1)>>1]|0,x)|0)+D|0;x=S+1|0;if((x|0)<(A|0)){S=x;C=E;D=z}else{oa=E;pa=z;break}}}else{oa=0;pa=0}D=pa-oa|0;C=gHb(D,(D|0)<0|0?-1:0,ea,(ea|0)<0|0?-1:0)|0;D=eHb(C,F,q,(q|0)<0|0?-1:0)|0;C=YGb(D,F,oa,0)|0;la=C;Q=32}}while(0);do{if((Q|0)==32){Q=0;A=la+16384|0;G=A>>15;if(!((G+32768|0)>>>0>65535>>>0)){ka=G&65535;break}ka=(A>>31^32767)&65535}}while(0);b[d+(da<<1)>>1]=ka;A=s+ea|0;G=o+P|0;if((A|0)<(q|0)){qa=A;ra=G}else{qa=A-q|0;ra=G+1|0}G=da+1|0;if((G|0)==($|0)){break}else{k=ha;da=G;ea=qa;I=ra}}I=c[aa>>2]|0;a=ha;ca=$;$=0;P=(I|0)/(q|0)|0;s=(I|0)%(q|0)|0;r=qa;m=ra}ra=(fa|0)>0;c[f>>2]=ra?fa:0;J=da;K=($|0)==0?0:$-da|0;L=P;M=s;N=ea;O=((ra?0:fa)<<c[u>>2])+ga|0}if((i|0)==0){return J|0}c[l>>2]=N;c[j>>2]=O;c[n>>2]=(ba(c[p>>2]|0,L)|0)+M;c[t>>2]=K;return J|0}function Qrb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;i=a+24|0;j=c[i>>2]|0;k=a+28|0;l=c[k>>2]|0;m=a+20|0;n=c[m>>2]|0;o=a+32|0;p=c[o>>2]|0;q=(n|0)%(p|0)|0;r=(n|0)/(p|0)|0;s=a+36|0;t=c[s>>2]|0;u=a+8|0;a:do{if((t|0)==0){v=c[u>>2]|0;do{if((v|0)==1){w=a+40|0;if((c[w>>2]|0)!=0){break}x=n;y=p;z=(p|0)<0|0?-1:0;A=eHb(0,x,y,z)|0;B=F;C=(g|0)<0|0?-1:0;D=f-1-j|0;E=gHb(y,z,D,(D|0)<0|0?-1:0)|0;D=eHb(E,F,x,(n|0)<0|0?-1:0)|0;x=F;E=(C|0)>(x|0)|(C|0)==(x|0)&g>>>0>D>>>0?D:g;if((E|0)>0){D=j;x=0;C=0;while(1){c[b+(C<<2)>>2]=c[d+(D<<2)>>2];z=YGb(x,D,A,B)|0;y=C+1|0;if((y|0)<(E|0)){D=F;x=z;C=y}else{break}}G=E;H=c[o>>2]|0;I=c[w>>2]|0}else{G=0;H=p;I=0}C=(ba(G,r)|0)+j|0;x=gHb(G,(G|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;D=YGb(x,F,l,(l|0)<0|0?-1:0)|0;x=F;B=H;A=(H|0)<0|0?-1:0;y=eHb(D,x,B,A)|0;z=YGb(y,F,C,0)|0;C=z;z=fHb(D,x,B,A)|0;c[e>>2]=C>>I;J=G;K=0;L=r;M=q;N=z;O=c[a+44>>2]&C;break a}}while(0);if(!((c[a+48>>2]|0)==0&(j|0)>-1)){P=0;Q=9;break}C=a+40|0;b:do{if((g|0)>0){z=a+44|0;A=c[a+4>>2]|0;B=a+12|0;x=j;D=l;y=0;R=0;S=v;while(1){T=(x>>c[C>>2])+y|0;U=c[z>>2]&x;V=ba(c[B>>2]|0,U)|0;if((S+T|0)>(f|0)){W=T;X=U;Y=D;Z=R;break b}do{if((S|0)>0){_=0;$=0;aa=0;do{ca=c[d+(_+T<<2)>>2]|0;da=c[A+(_+V<<2)>>2]|0;ea=gHb(da,(da|0)<0|0?-1:0,ca,(ca|0)<0|0?-1:0)|0;aa=YGb(ea,F,aa,$)|0;$=F;_=_+1|0;}while((_|0)<(S|0));_=YGb(aa,$,536870912,0)|0;ea=F;ca=_>>>30|ea<<2;_=YGb(ca,ea>>30|((ea|0)<0|0?-1:0)<<2,-2147483648,0)|0;da=F;fa=0;if(!(da>>>0>fa>>>0|da>>>0==fa>>>0&_>>>0>-1>>>0)){ga=ca;break}((ea|0)<0|0?-1:0)>>31|((ea|0)<0|0?-1:0)<<1;ga=(ea>>31|((ea|0)<0|0?-1:0)<<1)^2147483647}else{ga=0}}while(0);c[b+(R<<2)>>2]=ga;V=D+q|0;ea=U+r|0;ca=c[o>>2]|0;if((V|0)<(ca|0)){ha=V;ia=ea}else{ha=V-ca|0;ia=ea+1|0}ea=R+1|0;if((ea|0)>=(g|0)){W=T;X=ia;Y=ha;Z=ea;break b}x=ia;D=ha;y=T;R=ea;S=c[u>>2]|0}}else{W=0;X=j;Y=l;Z=0}}while(0);c[e>>2]=W;J=Z;K=0;L=r;M=q;N=Y;O=X}else{P=t;Q=9}}while(0);if((Q|0)==9){t=a+40|0;X=a+44|0;Y=a+4|0;Z=a+12|0;W=a+48|0;ha=a+16|0;a=0;ia=0;ga=P;P=r;r=q;q=l;l=j;j=p;c:while(1){p=a;ja=ia;ka=q;G=l;I=j;while(1){if((ja|0)>=(g|0)){la=p;ma=G;break c}na=(G>>c[t>>2])+p|0;H=c[X>>2]&G;n=c[Y>>2]|0;C=c[Z>>2]|0;v=ba(C,H)|0;S=c[u>>2]|0;if(!((S+na|0)<=(f|0)&(-na|0)<(f|0))){la=na;ma=H;break c}d:do{if((na|0)<0){if((S|0)>0){oa=0;pa=0;qa=0}else{ra=0;break}while(1){R=oa+na|0;y=c[d+(((R|0)>-1?R:-R|0)<<2)>>2]|0;R=c[n+(oa+v<<2)>>2]|0;D=gHb(R,(R|0)<0|0?-1:0,y,(y|0)<0|0?-1:0)|0;y=YGb(D,F,qa,pa)|0;D=F;R=oa+1|0;if((R|0)<(S|0)){oa=R;pa=D;qa=y}else{sa=D;ta=y;Q=34;break}}}else{T=(S|0)>0;if((c[W>>2]|0)==0){if(T){ua=0;va=0;wa=0}else{ra=0;break}while(1){U=c[d+(ua+na<<2)>>2]|0;y=c[n+(ua+v<<2)>>2]|0;D=gHb(y,(y|0)<0|0?-1:0,U,(U|0)<0|0?-1:0)|0;U=YGb(D,F,wa,va)|0;D=F;y=ua+1|0;if((y|0)<(S|0)){ua=y;va=D;wa=U}else{sa=D;ta=U;Q=34;break d}}}if(T){U=0;D=0;y=0;R=0;x=0;while(1){A=c[d+(U+na<<2)>>2]|0;B=A;z=(A|0)<0|0?-1:0;A=U+v|0;w=c[n+(A<<2)>>2]|0;E=gHb(w,(w|0)<0|0?-1:0,B,z)|0;w=YGb(E,F,y,D)|0;E=F;ea=c[n+(A+C<<2)>>2]|0;A=gHb(ea,(ea|0)<0|0?-1:0,B,z)|0;z=YGb(A,F,x,R)|0;A=F;B=U+1|0;if((B|0)<(S|0)){U=B;D=E;y=w;R=A;x=z}else{xa=E;ya=w;za=A;Aa=z;break}}}else{xa=0;ya=0;za=0;Aa=0}x=ZGb(Aa,za,ya,xa)|0;R=gHb(x,F,ka,(ka|0)<0|0?-1:0)|0;x=eHb(R,F,I,(I|0)<0|0?-1:0)|0;R=YGb(x,F,ya,xa)|0;sa=F;ta=R;Q=34}}while(0);do{if((Q|0)==34){Q=0;S=YGb(ta,sa,536870912,0)|0;C=F;n=S>>>30|C<<2;S=YGb(n,C>>30|((C|0)<0|0?-1:0)<<2,-2147483648,0)|0;v=F;R=0;if(!(v>>>0>R>>>0|v>>>0==R>>>0&S>>>0>-1>>>0)){ra=n;break}((C|0)<0|0?-1:0)>>31|((C|0)<0|0?-1:0)<<1;ra=(C>>31|((C|0)<0|0?-1:0)<<1)^2147483647}}while(0);c[b+(ja<<2)>>2]=ra;C=r+ka|0;n=H+P|0;Ba=c[o>>2]|0;if((C|0)<(Ba|0)){Ca=C;Da=n}else{Ca=C-Ba|0;Da=n+1|0}n=ja+1|0;if((n|0)==(ga|0)){break}else{p=na;ja=n;ka=Ca;G=Da;I=Ba}}I=c[ha>>2]|0;a=na;ia=ga;ga=0;P=(I|0)/(Ba|0)|0;r=(I|0)%(Ba|0)|0;q=Ca;l=Da;j=Ba}Ba=(la|0)>0;c[e>>2]=Ba?la:0;J=ja;K=(ga|0)==0?0:ga-ja|0;L=P;M=r;N=ka;O=((Ba?0:la)<<c[t>>2])+ma|0}if((h|0)==0){return J|0}c[k>>2]=N;c[i>>2]=O;c[m>>2]=(ba(c[o>>2]|0,L)|0)+M;c[s>>2]=K;return J|0}function Rrb(a,b,d,e,f,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0.0,_=0.0,$=0,aa=0.0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0.0,ma=0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0,ta=0;j=a+24|0;k=c[j>>2]|0;l=a+28|0;m=c[l>>2]|0;n=a+20|0;o=c[n>>2]|0;p=a+32|0;q=c[p>>2]|0;r=(o|0)%(q|0)|0;s=(o|0)/(q|0)|0;t=a+36|0;u=c[t>>2]|0;v=a+8|0;a:do{if((u|0)==0){w=c[v>>2]|0;do{if((w|0)==1){if((c[a+40>>2]|0)!=0){break}x=o;y=q;z=(q|0)<0|0?-1:0;A=eHb(0,x,y,z)|0;B=F;C=(h|0)<0|0?-1:0;D=f-1-k|0;E=gHb(y,z,D,(D|0)<0|0?-1:0)|0;D=eHb(E,F,x,(o|0)<0|0?-1:0)|0;x=F;E=(C|0)>(x|0)|(C|0)==(x|0)&h>>>0>D>>>0?D:h;if((E|0)>0){D=k;x=0;C=0;while(1){g[b+(C<<2)>>2]=+g[d+(D<<2)>>2];G=YGb(x,D,A,B)|0;H=C+1|0;if((H|0)<(E|0)){D=F;x=G;C=H}else{I=E;break}}}else{I=0}E=(ba(I,s)|0)+k|0;C=gHb(I,(I|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;x=YGb(C,F,m,(m|0)<0|0?-1:0)|0;C=F;D=eHb(x,C,y,z)|0;B=YGb(D,F,E,0)|0;E=B;B=fHb(x,C,y,z)|0;c[e>>2]=E;J=I;K=0;L=s;M=r;N=B;O=c[a+44>>2]&E;break a}}while(0);if(!((c[a+48>>2]|0)==0&(k|0)>-1)){P=0;Q=8;break}b:do{if((h|0)>0){E=c[a+40>>2]|0;B=c[a+44>>2]|0;C=c[a+4>>2]|0;x=c[a+12>>2]|0;D=k;A=m;H=0;G=0;while(1){R=(D>>E)+H|0;S=B&D;T=ba(x,S)|0;if((w+R|0)>(f|0)){U=R;V=S;W=A;X=G;break b}if((w|0)>0){Y=0;Z=0.0;while(1){_=Z+ +g[d+(Y+R<<2)>>2]*+g[C+(Y+T<<2)>>2];$=Y+1|0;if(($|0)<(w|0)){Y=$;Z=_}else{aa=_;break}}}else{aa=0.0}g[b+(G<<2)>>2]=aa;Y=A+r|0;T=S+s|0;if((Y|0)<(q|0)){ca=Y;da=T}else{ca=Y-q|0;da=T+1|0}T=G+1|0;if((T|0)<(h|0)){D=da;A=ca;H=R;G=T}else{U=R;V=da;W=ca;X=T;break}}}else{U=0;V=k;W=m;X=0}}while(0);c[e>>2]=U;J=X;K=0;L=s;M=r;N=W;O=V}else{P=u;Q=8}}while(0);if((Q|0)==8){Q=a+40|0;u=a+44|0;V=a+4|0;W=a+12|0;X=a+48|0;U=a+16|0;a=0;ca=0;da=P;P=s;s=r;r=m;m=k;c:while(1){k=a;ea=ca;fa=r;I=m;while(1){if((ea|0)>=(h|0)){ga=k;ha=I;break c}ia=(I>>c[Q>>2])+k|0;o=c[u>>2]&I;w=c[V>>2]|0;G=c[W>>2]|0;H=ba(G,o)|0;A=c[v>>2]|0;if(!((A+ia|0)<=(f|0)&(-ia|0)<(f|0))){ga=ia;ha=o;break c}d:do{if((ia|0)<0){if((A|0)>0){ja=0;ka=0.0}else{la=0.0;break}while(1){D=ja+ia|0;aa=ka+ +g[d+(((D|0)>-1?D:-D|0)<<2)>>2]*+g[w+(ja+H<<2)>>2];D=ja+1|0;if((D|0)<(A|0)){ja=D;ka=aa}else{la=aa;break}}}else{R=(A|0)>0;if((c[X>>2]|0)==0){if(R){ma=0;na=0.0}else{la=0.0;break}while(1){aa=na+ +g[d+(ma+ia<<2)>>2]*+g[w+(ma+H<<2)>>2];S=ma+1|0;if((S|0)<(A|0)){ma=S;na=aa}else{la=aa;break d}}}if(R){S=0;aa=0.0;Z=0.0;while(1){_=+g[d+(S+ia<<2)>>2];D=S+H|0;oa=aa+_*+g[w+(D<<2)>>2];pa=Z+_*+g[w+(D+G<<2)>>2];D=S+1|0;if((D|0)<(A|0)){S=D;aa=oa;Z=pa}else{qa=oa;ra=pa;break}}}else{qa=0.0;ra=0.0}la=qa+ +(fa|0)*(ra-qa)/+(q|0)}}while(0);g[b+(ea<<2)>>2]=la;A=s+fa|0;G=o+P|0;if((A|0)<(q|0)){sa=A;ta=G}else{sa=A-q|0;ta=G+1|0}G=ea+1|0;if((G|0)==(da|0)){break}else{k=ia;ea=G;fa=sa;I=ta}}I=c[U>>2]|0;a=ia;ca=da;da=0;P=(I|0)/(q|0)|0;s=(I|0)%(q|0)|0;r=sa;m=ta}ta=(ga|0)>0;c[e>>2]=ta?ga:0;J=ea;K=(da|0)==0?0:da-ea|0;L=P;M=s;N=fa;O=((ta?0:ga)<<c[Q>>2])+ha|0}if((i|0)==0){return J|0}c[l>>2]=N;c[j>>2]=O;c[n>>2]=(ba(c[p>>2]|0,L)|0)+M;c[t>>2]=K;return J|0}function Srb(a,b,d,e,f,g,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0.0,_=0.0,$=0,aa=0.0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0.0,ma=0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0,ta=0;j=a+24|0;k=c[j>>2]|0;l=a+28|0;m=c[l>>2]|0;n=a+20|0;o=c[n>>2]|0;p=a+32|0;q=c[p>>2]|0;r=(o|0)%(q|0)|0;s=(o|0)/(q|0)|0;t=a+36|0;u=c[t>>2]|0;v=a+8|0;a:do{if((u|0)==0){w=c[v>>2]|0;do{if((w|0)==1){if((c[a+40>>2]|0)!=0){break}x=o;y=q;z=(q|0)<0|0?-1:0;A=eHb(0,x,y,z)|0;B=F;C=(g|0)<0|0?-1:0;D=f-1-k|0;E=gHb(y,z,D,(D|0)<0|0?-1:0)|0;D=eHb(E,F,x,(o|0)<0|0?-1:0)|0;x=F;E=(C|0)>(x|0)|(C|0)==(x|0)&g>>>0>D>>>0?D:g;if((E|0)>0){D=k;x=0;C=0;while(1){h[b+(C<<3)>>3]=+h[d+(D<<3)>>3];G=YGb(x,D,A,B)|0;H=C+1|0;if((H|0)<(E|0)){D=F;x=G;C=H}else{I=E;break}}}else{I=0}E=(ba(I,s)|0)+k|0;C=gHb(I,(I|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;x=YGb(C,F,m,(m|0)<0|0?-1:0)|0;C=F;D=eHb(x,C,y,z)|0;B=YGb(D,F,E,0)|0;E=B;B=fHb(x,C,y,z)|0;c[e>>2]=E;J=I;K=0;L=s;M=r;N=B;O=c[a+44>>2]&E;break a}}while(0);if(!((c[a+48>>2]|0)==0&(k|0)>-1)){P=0;Q=8;break}b:do{if((g|0)>0){E=c[a+40>>2]|0;B=c[a+44>>2]|0;C=c[a+4>>2]|0;x=c[a+12>>2]|0;D=k;A=m;H=0;G=0;while(1){R=(D>>E)+H|0;S=B&D;T=ba(x,S)|0;if((w+R|0)>(f|0)){U=R;V=S;W=A;X=G;break b}if((w|0)>0){Y=0;Z=0.0;while(1){_=Z+ +h[d+(Y+R<<3)>>3]*+h[C+(Y+T<<3)>>3];$=Y+1|0;if(($|0)<(w|0)){Y=$;Z=_}else{aa=_;break}}}else{aa=0.0}h[b+(G<<3)>>3]=aa;Y=A+r|0;T=S+s|0;if((Y|0)<(q|0)){ca=Y;da=T}else{ca=Y-q|0;da=T+1|0}T=G+1|0;if((T|0)<(g|0)){D=da;A=ca;H=R;G=T}else{U=R;V=da;W=ca;X=T;break}}}else{U=0;V=k;W=m;X=0}}while(0);c[e>>2]=U;J=X;K=0;L=s;M=r;N=W;O=V}else{P=u;Q=8}}while(0);if((Q|0)==8){Q=a+40|0;u=a+44|0;V=a+4|0;W=a+12|0;X=a+48|0;U=a+16|0;a=0;ca=0;da=P;P=s;s=r;r=m;m=k;c:while(1){k=a;ea=ca;fa=r;I=m;while(1){if((ea|0)>=(g|0)){ga=k;ha=I;break c}ia=(I>>c[Q>>2])+k|0;o=c[u>>2]&I;w=c[V>>2]|0;G=c[W>>2]|0;H=ba(G,o)|0;A=c[v>>2]|0;if(!((A+ia|0)<=(f|0)&(-ia|0)<(f|0))){ga=ia;ha=o;break c}d:do{if((ia|0)<0){if((A|0)>0){ja=0;ka=0.0}else{la=0.0;break}while(1){D=ja+ia|0;aa=ka+ +h[d+(((D|0)>-1?D:-D|0)<<3)>>3]*+h[w+(ja+H<<3)>>3];D=ja+1|0;if((D|0)<(A|0)){ja=D;ka=aa}else{la=aa;break}}}else{R=(A|0)>0;if((c[X>>2]|0)==0){if(R){ma=0;na=0.0}else{la=0.0;break}while(1){aa=na+ +h[d+(ma+ia<<3)>>3]*+h[w+(ma+H<<3)>>3];S=ma+1|0;if((S|0)<(A|0)){ma=S;na=aa}else{la=aa;break d}}}if(R){S=0;aa=0.0;Z=0.0;while(1){_=+h[d+(S+ia<<3)>>3];D=S+H|0;oa=aa+_*+h[w+(D<<3)>>3];pa=Z+_*+h[w+(D+G<<3)>>3];D=S+1|0;if((D|0)<(A|0)){S=D;aa=oa;Z=pa}else{qa=oa;ra=pa;break}}}else{qa=0.0;ra=0.0}la=qa+ +(fa|0)*(ra-qa)/+(q|0)}}while(0);h[b+(ea<<3)>>3]=la;A=s+fa|0;G=o+P|0;if((A|0)<(q|0)){sa=A;ta=G}else{sa=A-q|0;ta=G+1|0}G=ea+1|0;if((G|0)==(da|0)){break}else{k=ia;ea=G;fa=sa;I=ta}}I=c[U>>2]|0;a=ia;ca=da;da=0;P=(I|0)/(q|0)|0;s=(I|0)%(q|0)|0;r=sa;m=ta}ta=(ga|0)>0;c[e>>2]=ta?ga:0;J=ea;K=(da|0)==0?0:da-ea|0;L=P;M=s;N=fa;O=((ta?0:ga)<<c[Q>>2])+ha|0}if((i|0)==0){return J|0}c[l>>2]=N;c[j>>2]=O;c[n>>2]=(ba(c[p>>2]|0,L)|0)+M;c[t>>2]=K;return J|0}function Trb(a,d,e,f,j,k,l,m,n,o,p,q){a=a|0;d=d|0;e=e|0;f=f|0;j=j|0;k=k|0;l=+l;m=m|0;n=n|0;o=o|0;p=+p;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0.0,O=0,P=0,S=0,V=0,W=0,X=0.0,Y=0,Z=0.0,_=0.0,$=0.0,ca=0,da=0.0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;q=i;p=+(d|0)*(l!=0.0?l:.97)/+(e|0);l=p>1.0?1.0:p;r=1<<j;do{if((a|0)==0){s=9}else{if((c[a+40>>2]|0)!=(j|0)){s=9;break}if((c[a+48>>2]|0)!=(k|0)){s=9;break}if(+h[a+64>>3]!=l){s=9;break}t=~~+aa(+(f|0)/l);if((c[a+8>>2]|0)!=(((t|0)>1?t:1)|0)){s=9;break}if((c[a+72>>2]|0)!=(m|0)){s=9;break}if((c[a+52>>2]|0)!=(n|0)){s=9;break}if((c[a+56>>2]|0)==(o|0)){u=a;s=57}else{s=9}}}while(0);do{if((s|0)==9){a=cEb(88)|0;t=a;if((a|0)==0){v=0;i=q;return v|0}w=a+72|0;c[w>>2]=m;x=BFb(m)|0;y=a+76|0;c[y>>2]=x;z=c[w>>2]|0;if((z|0)==7){c[a+80>>2]=30}else if((z|0)==6){c[a+80>>2]=15}else if((z|0)==8|(z|0)==9){c[a+80>>2]=0}else{yDb(0,16,2098064,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;yDb(0,0,2167976,(A=i,i=i+24|0,c[A>>2]=2042784,c[A+8>>2]=2172448,c[A+16>>2]=229,A)|0);i=A;Cd();return 0}p=+(f|0)/l;if(p>8388607.0){yDb(0,16,1997784,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;B=t;break}c[a+40>>2]=j;c[a+44>>2]=r-1;c[a+48>>2]=k;h[a+64>>3]=l;z=~~+aa(p);C=(z|0)>1?z:1;z=a+8|0;c[z>>2]=C;D=C+7&-8;C=a+12|0;c[C>>2]=D;E=dEb(D,ba(x,r+1|0)|0)|0;x=a+4|0;c[x>>2]=E;c[a+52>>2]=n;c[a+56>>2]=o;if((E|0)==0){B=t;break}D=c[z>>2]|0;z=c[C>>2]|0;G=1<<c[a+80>>2];if(D>>>0>268435454>>>0){B=t;break}a=WDb(D<<3)|0;H=a;I=(D-1|0)/2|0;if((a|0)==0){B=t;break}a:do{if((r|0)>0){J=(D|0)>0;p=+(r|0);K=l*+(D|0);L=K*3.141592653589793;M=+(o|0);N=+(G|0);O=E;P=E;S=E;V=E;W=0;b:while(1){if(J){X=+(W|0)/p;if((n|0)==0){Y=0;Z=0.0;while(1){_=+Q(+(l*(+(Y-I|0)-X)));if(_<1.0){$=1.0-_*_*3.0+_*_*_*2.0+(_*(-0.0-_)+_*_*_)*-.5}else{$=(_*_*_+(_*8.0+-4.0-_*_*5.0))*-.5}h[H+(Y<<3)>>3]=$;_=Z+$;ca=Y+1|0;if((ca|0)<(D|0)){Y=ca;Z=_}else{da=_;break}}}else if((n|0)==2){Y=0;Z=0.0;while(1){_=l*(+(Y-I|0)-X)*3.141592653589793;if(_==0.0){ea=1.0}else{ea=+U(_)/_}fa=_*2.0/L;_=1.0-fa*fa;fa=M*+R(_>0.0?_:0.0);_=fa*fa*.25;fa=1.0;ga=1.0;ca=0;while(1){ha=ga*_*+h[1732992+(ca<<3)>>3];ia=fa+ha;if(ia!=fa){fa=ia;ga=ha;ca=ca+1|0}else{break}}ga=ea*ia;h[H+(Y<<3)>>3]=ga;fa=Z+ga;ca=Y+1|0;if((ca|0)<(D|0)){Y=ca;Z=fa}else{da=fa;break}}}else{Y=0;Z=0.0;while(1){fa=l*(+(Y-I|0)-X)*3.141592653589793;if(fa==0.0){ja=1.0}else{ja=+U(fa)/fa}if((n|0)!=1){break b}ga=fa*2.0/K+3.141592653589793;fa=ja*(.3635819- +T(ga)*.4891775+ +T(ga*2.0)*.1365995- +T(ga*3.0)*.0106411);h[H+(Y<<3)>>3]=fa;ga=Z+fa;ca=Y+1|0;if((ca|0)<(D|0)){Y=ca;Z=ga}else{da=ga;break}}}}else{da=0.0}Y=c[w>>2]|0;do{if((Y|0)==7){if(!J){break}ca=ba(W,z)|0;ka=0;do{la=ce(+(N*+h[H+(ka<<3)>>3]/da))|0;ma=F;na=YGb(la,ma,-2147483648,0)|0;oa=F;pa=0;if(oa>>>0>pa>>>0|oa>>>0==pa>>>0&na>>>0>-1>>>0){((ma|0)<0|0?-1:0)>>31|((ma|0)<0|0?-1:0)<<1;qa=(ma>>31|((ma|0)<0|0?-1:0)<<1)^2147483647}else{qa=la}c[S+(ka+ca<<2)>>2]=qa;ka=ka+1|0;}while((ka|0)<(D|0))}else if((Y|0)==8){if(!J){break}ka=ba(W,z)|0;ca=0;do{g[P+(ca+ka<<2)>>2]=N*+h[H+(ca<<3)>>3]/da;ca=ca+1|0;}while((ca|0)<(D|0))}else if((Y|0)==9){if(!J){break}ca=ba(W,z)|0;ka=0;do{h[O+(ka+ca<<3)>>3]=N*+h[H+(ka<<3)>>3]/da;ka=ka+1|0;}while((ka|0)<(D|0))}else if((Y|0)==6){if(!J){break}ka=ba(W,z)|0;ca=0;do{la=Gc(+(N*+h[H+(ca<<3)>>3]/da))|0;if((la|0)<-32768){ra=-32768}else{ra=(la|0)>32767?32767:la&65535}b[V+(ca+ka<<1)>>1]=ra;ca=ca+1|0;}while((ca|0)<(D|0))}}while(0);W=W+1|0;if((W|0)>=(r|0)){break a}}yDb(0,0,2167976,(A=i,i=i+24|0,c[A>>2]=2042784,c[A+8>>2]=2172448,c[A+16>>2]=130,A)|0);i=A;Cd();return 0}}while(0);ZDb(a);D=c[x>>2]|0;H=c[C>>2]|0;z=c[y>>2]|0;UGb(D+(ba((H<<j)+1|0,z)|0)|0,D|0,ba(H-1|0,z)|0)|0;z=c[x>>2]|0;H=c[C>>2]|0;D=c[y>>2]|0;UGb(z+(ba(H<<j,D)|0)|0,z+(ba(H-1|0,D)|0)|0,D)|0;u=t;s=57}}while(0);do{if((s|0)==57){c[u+36>>2]=0;j=u+20|0;A=gHb(r,(r|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;if((iFb(u+32|0,j,d,(d|0)<0|0?-1:0,A,F,1073741823,0)|0)==0){B=u;break}c[u+16>>2]=c[j>>2];c[u+24>>2]=ba(((c[u+8>>2]|0)-1|0)/2|0,-r|0)|0;c[u+28>>2]=0;v=u;i=q;return v|0}}while(0);$Db(B+4|0);ZDb(B);v=0;i=q;return v|0}function Urb(a){a=a|0;var b=0;b=c[a>>2]|0;if((b|0)==0){return}$Db(b+4|0);$Db(a);return}function Vrb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;qBb()|0;h=b+132|0;i=c[h>>2]|0;if((i|0)<=0){j=-1;return j|0}k=a+72|0;l=-1;m=0;n=i;while(1){i=c[k>>2]|0;if((i|0)==8){o=m+1|0;p=Rrb(a,c[b+(m<<2)>>2]|0,c[e+(m<<2)>>2]|0,g,f,d,(o|0)==(n|0)|0)|0;q=o}else if((i|0)==9){o=m+1|0;p=Srb(a,c[b+(m<<2)>>2]|0,c[e+(m<<2)>>2]|0,g,f,d,(o|0)==(n|0)|0)|0;q=o}else if((i|0)==7){o=m+1|0;p=Qrb(a,c[b+(m<<2)>>2]|0,c[e+(m<<2)>>2]|0,g,f,d,(o|0)==(n|0)|0)|0;q=o}else if((i|0)==6){i=m+1|0;p=Prb(a,c[b+(m<<2)>>2]|0,c[e+(m<<2)>>2]|0,g,f,d,(i|0)==(n|0)|0)|0;q=i}else{p=l;q=m+1|0}i=c[h>>2]|0;if((q|0)<(i|0)){l=p;m=q;n=i}else{j=p;break}}return j|0}function Wrb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;d=a+6924|0;e=a+6928|0;f=Wqb(a+6468|0,(c[e>>2]<<1)+(c[d>>2]|0)|0)|0;if((f|0)<0){g=f;i=b;return g|0}if((c[a+6612>>2]|0)==0){yDb(0,0,2167976,(f=i,i=i+24|0,c[f>>2]=2302040,c[f+8>>2]=2172448,c[f+16>>2]=359,f)|0);i=f;Cd();return 0}f=a+6600|0;h=c[f>>2]|0;if((h|0)>0){j=a+6604|0;k=0;l=c[e>>2]|0;m=h;while(1){if((l|0)>0){h=a+6468+(k<<2)|0;n=0;o=l;do{p=c[h>>2]|0;q=(c[d>>2]|0)+o|0;r=c[j>>2]|0;UGb(p+(ba(q+n|0,r)|0)|0,p+(ba(q+~n|0,r)|0)|0,r)|0;n=n+1|0;o=c[e>>2]|0;}while((n|0)<(o|0));s=o;t=c[f>>2]|0}else{s=l;t=m}n=k+1|0;if((n|0)<(t|0)){k=n;l=s;m=t}else{u=s;break}}}else{u=c[e>>2]|0}c[e>>2]=((u+1|0)/2|0)+u;g=0;i=b;return g|0}function Xrb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;c[a+36>>2]=d;e=c[a+16>>2]|0;if((d|0)==0){c[a+20>>2]=e;return 0}else{f=e;g=(e|0)<0|0?-1:0;e=gHb(f,g,b,(b|0)<0|0?-1:0)|0;b=eHb(e,F,d,(d|0)<0|0?-1:0)|0;d=ZGb(f,g,b,F)|0;c[a+20>>2]=d;return 0}return 0}function Yrb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[a+6976>>2]|0;f=(c[a+6928>>2]|0)-(((c[e+8>>2]|0)-1|0)/2|0)|0;g=c[e+40>>2]|0;h=_Gb(f|0,((f|0)<0|0?-1:0)|0,g|0)|0;f=c[e+24>>2]|0;i=ZGb(h,F,f,(f|0)<0|0?-1:0)|0;f=c[e+32>>2]|0;h=f;j=(f|0)<0|0?-1:0;f=gHb(i,F,h,j)|0;i=c[e+28>>2]|0;e=ZGb(f,F,i,(i|0)<0|0?-1:0)|0;i=F;f=c[a+40>>2]|0;a=gHb(f,(f|0)<0|0?-1:0,h,j)|0;j=_Gb(a|0,F|0,g|0)|0;g=IDb(e,i,b,d,j,F)|0;return(F=F,g)|0}function Zrb(a){a=a|0;return 1948304}function _rb(){return 402632}function $rb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=c[b+56>>2]|0;_ub(b,b+23892|0,b+23896|0,b+23900|0,b+23904|0,b+23908|0,b+23912|0,b+23916|0);Vsb(b);f=b+68|0;g=c[f>>2]|0;do{if((c[b+72>>2]|0)==8){h=b+23956|0;if((g|0)>=15){c[h>>2]=310;c[b+23952>>2]=310;break}c[h>>2]=628;c[b+23952>>2]=628;if((c[b+2284>>2]&1|0)==0){break}c[b+23944>>2]=174;c[b+23948>>2]=120}else{h=(g|0)>14?506:572;c[b+23956>>2]=h;c[b+23952>>2]=h}}while(0);g=b+11260|0;a:do{if((c[g>>2]|0)!=(c[b+11264>>2]|0)){h=c[b+52>>2]|0;switch(h|0){case 321:case 325:case 326:case 322:case 327:case 328:case 323:case 329:case 330:case 324:case 331:case 332:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 3:case 9:{break a;break};default:{}}j=bFb(h)|0;if((j|0)==0){yDb(0,0,2042712,(h=i,i=i+24|0,c[h>>2]=1997712,c[h+8>>2]=1961200,c[h+16>>2]=674,h)|0);i=h;Cd();return 0}if(!((a[j+7|0]&32)==0)){break}j=(c[g>>2]|0)!=0;h=b+23960|0;if((c[f>>2]|0)<15){if(j){c[h>>2]=432;c[b+23964>>2]=1492;break}else{c[h>>2]=352;c[b+23964>>2]=218;break}}else{if(j){c[h>>2]=224;c[b+23964>>2]=2134;break}else{c[h>>2]=480;c[b+23964>>2]=1014;break}}}}while(0);if((e|0)==66|(e|0)==32|(e|0)==31|(e|0)==8){i=d;return 70}f=c[b+52>>2]|0;if((f|0)==8|(f|0)==66|(f|0)==31|(f|0)==32){i=d;return 70}if((e-9|0)>>>0<2>>>0){i=d;return 70}c[b+23968>>2]=1;i=d;return 70}function asb(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0;n=i;i=i+104|0;o=n|0;p=n+8|0;q=n+16|0;r=n+24|0;s=n+32|0;t=n+40|0;u=n+48|0;v=n+56|0;w=n+72|0;y=n+88|0;z=c[f+8>>2]|0;A=c[f+19608>>2]|0;B=c[f+16>>2]|0;C=c[f+28>>2]|0;D=c[f+20>>2]|0;E=c[f+36>>2]|0;F=c[f+40>>2]|0;G=c[f+52>>2]|0;H=c[f+2284>>2]|0;I=c[f+2236>>2]|0;J=c[f+2240>>2]|0;K=c[f+2228>>2]|0;L=c[f+2232>>2]|0;M=c[f+2212>>2]|0;N=c[f+2216>>2]|0;O=f+11416|0;P=f+15512|0;Q=c[f+2252>>2]|0;R=c[f+2256>>2]|0;S=c[f+2244>>2]|0;T=c[f+2248>>2]|0;U=c[f+2168>>2]|0;V=c[f+2172>>2]|0;W=c[f+2176>>2]|0;X=c[f+2180>>2]|0;Y=c[f+2184>>2]|0;Z=c[f+2188>>2]|0;_=c[f+2208>>2]|0;$=f+120|0;c[o>>2]=c[f+23892>>2];c[p>>2]=c[f+23896>>2];c[q>>2]=c[f+23900>>2];aa=f+23904|0;c[r>>2]=c[aa>>2];ca=f+23908|0;c[s>>2]=c[ca>>2];c[t>>2]=c[f+23912>>2];c[u>>2]=c[f+23916>>2];da=f+80|0;ea=c[da>>2]|0;fa=j>>ea;ga=-k>>ea;ea=-ga|0;ha=f+56|0;ia=bFb(c[ha>>2]|0)|0;if((ia|0)==0){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=644,ja)|0);i=ja;Cd();return 0}do{if((((e[ia+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){ka=1}else{la=bFb(c[ha>>2]|0)|0;if((la|0)==0){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=637,ja)|0);i=ja;Cd();return 0}else{ka=(b[la+8>>1]&30720)==30720;break}}}while(0);ia=f+2280|0;la=c[ia>>2]|0;ma=f+2200|0;na=c[ma>>2]|0;oa=f+2204|0;pa=c[oa>>2]|0;qa=f+2192|0;ra=c[qa>>2]|0;sa=f+2196|0;ta=c[sa>>2]|0;ua=bFb(c[ha>>2]|0)|0;if((ua|0)==0){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=828,ja)|0);i=ja;Cd();return 0}va=d[ua+7|0]|0;if((va&2|0)==0){wa=(va&64|0)==0}else{wa=0}va=f+10496|0;ua=wa?va:$;switch(c[ha>>2]|0){case 11:case 1:case 17:case 66:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 3:case 9:{ha=c[g>>2]|0;c[g+12>>2]=ha;c[g+8>>2]=ha;c[g+4>>2]=ha;ha=c[h>>2]|0;c[h+12>>2]=ha;c[h+8>>2]=ha;c[h+4>>2]=ha;xa=ha;ya=ha;break};default:{xa=c[h+4>>2]|0;ya=c[h+8>>2]|0}}ha=f+92|0;$=h+4|0;c[$>>2]=xa<<c[ha>>2];xa=h+8|0;c[xa>>2]=ya<<c[ha>>2];do{if((c[m>>2]&15|0)==0){if((c[m+4>>2]&15|0)!=0){za=18;break}if((c[m+8>>2]&15|0)!=0){za=18;break}if((c[m+12>>2]&15|0)!=0){za=18}}else{za=18}}while(0);do{if((za|0)==18){if((H&4096|0)==0|a[400840]){break}yDb(f,24,1933352,(ja=i,i=i+1|0,i=i+7&-8,c[ja>>2]=0,ja)|0);i=ja;a[400840]=1}}while(0);do{if((c[l>>2]&15|0)==0){if((c[l+4>>2]&15|0)!=0){za=34;break}if((c[l+8>>2]&15|0)!=0){za=34;break}if((c[g>>2]&15|0)!=0){za=34;break}if((c[g+4>>2]&15|0)!=0){za=34;break}if((c[g+8>>2]&15|0)!=0){za=34;break}if((c[m>>2]&15|0)!=0){za=34;break}if((c[m+4>>2]&15|0)!=0){za=34;break}if((c[m+8>>2]&15|0)!=0){za=34;break}if((c[m+12>>2]&15|0)!=0){za=34;break}if((c[h>>2]&15|0)!=0){za=34;break}if((c[$>>2]&15|0)!=0){za=34;break}if((c[xa>>2]&15|0)!=0){za=34;break}if((c[h+12>>2]&15|0)!=0){za=34}}else{za=34}}while(0);if((za|0)==34){qBb()|0}H=(j|0)==0;ha=H?-1:ta;ta=H?-1:ra;ra=H?-1:pa;pa=H?-1:na;na=H?0:la;if(!ka){c[f+23820>>2]=402624;c[f+23816>>2]=402624}a:do{if((na|0)<(B|0)){la=f+88|0;H=v|0;ya=v+4|0;wa=l+4|0;Aa=m+4|0;Ba=v+8|0;Ca=l+8|0;Da=m+8|0;Ea=v+12|0;Fa=(X|0)!=0;Ga=l+12|0;Ha=m+12|0;Ia=f+23824|0;Ja=1-Q|0;Ka=B-1|0;La=1-R|0;Ma=f+12|0;Na=f+24|0;Oa=1-Y|0;Pa=1-Z|0;Qa=k+j|0;Ra=-Qa|0;Sa=fa+~ga|0;Ta=f+23816|0;Ua=f+23820|0;Va=B-2|0;Wa=f+2220|0;Xa=f+2224|0;Ya=(Q|0)==1;Za=(R|0)<3;_a=(R|0)==1;$a=(Q|0)==2;ab=(R|0)==2;bb=f+11428|0;cb=f+11424|0;db=f+15524|0;eb=f+15520|0;fb=(G|0)==11;gb=O;hb=P;ib=f+23760|0;jb=f+19656|0;kb=y|0;lb=y+4|0;mb=g+4|0;nb=y+8|0;ob=g+8|0;pb=y+12|0;qb=g+12|0;rb=h+12|0;sb=Z<<1;tb=f+23968|0;ub=f+23928|0;vb=f+23936|0;wb=_+((D<<1)+93&-16)|0;xb=f+23948|0;yb=f+23956|0;zb=f+23964|0;Ab=w|0;Bb=w+4|0;Cb=w+8|0;Db=w+12|0;Eb=Y<<1;Fb=f+23920|0;Gb=f+23960|0;Hb=f+23932|0;Ib=f+23944|0;Jb=f+23952|0;Kb=f+23924|0;Lb=f+23940|0;Mb=ha;Nb=ta;Ob=ra;Pb=pa;Qb=na;b:while(1){Rb=c[la>>2]|0;Sb=Qb>>Rb;c[H>>2]=(c[l>>2]|0)+(ba(c[m>>2]|0,Qb)|0);c[ya>>2]=(c[wa>>2]|0)+(ba(c[Aa>>2]|0,Sb)|0);c[Ba>>2]=(c[Ca>>2]|0)+(ba(c[Da>>2]|0,Sb)|0);if(Fa){Tb=(c[Ga>>2]|0)+(ba(c[Ha>>2]|0,Qb)|0)|0}else{Tb=0}c[Ea>>2]=Tb;Ub=c[Ia>>2]|0;Vb=c[I+(Qb<<2)>>2]|0;Wb=(Ja|0)>(Vb|0)?Ja:Vb;Vb=(1<<Rb)-1|Qb;Rb=c[I+(((Vb|0)>(Ka|0)?Ka:Vb)<<2)>>2]|0;Vb=c[J+(Sb<<2)>>2]|0;Xb=(La|0)>(Vb|0)?La:Vb;Vb=c[Ma>>2]|0;Yb=Wb+Q|0;Zb=(Vb|0)>(Yb|0)?Yb:Vb;Yb=((Ja|0)>(Rb|0)?Ja:Rb)+Q|0;Rb=c[Na>>2]|0;_b=Xb+R|0;$b=((Rb|0)>(_b|0)?_b:Rb)-1|0;Rb=(Wb|0)>(Nb|0)?Wb-1|0:Nb;_b=(Xb|0)>(Mb|0)?Xb-1|0:Mb;if((Wb|0)<(Oa+Rb|0)){za=42;break}if((Xb|0)<(Pa+_b|0)){za=44;break}if((((Vb|0)>(Yb|0)?Yb:Vb)-1|0)<(Qa|0)){if(($b|0)<(-(Ra>>c[da>>2])|0)){ac=Zb;bc=$b;cc=1}else{za=47}}else{za=47}if((za|0)==47){za=0;ac=Qa;bc=Sa;cc=0}$b=ac-1|0;if((Rb|0)<($b|0)){Zb=Rb;Vb=Pb;while(1){Yb=Zb+1|0;dc=Yb-j|0;ec=(c[g>>2]|0)+(ba(c[h>>2]|0,dc)|0)|0;c[Ab>>2]=ec;fc=(c[mb>>2]|0)+(ba(c[$>>2]|0,dc)|0)|0;c[Bb>>2]=fc;gc=(c[ob>>2]|0)+(ba(c[xa>>2]|0,dc)|0)|0;c[Cb>>2]=gc;c[Db>>2]=(c[qb>>2]|0)+(ba(c[rb>>2]|0,dc)|0);hc=Vb+1|0;if((hc|0)>=(Eb|0)){za=50;break b}if((dc|0)>=(k|0)){za=52;break b}if(!((dc|0)>-1)){za=54;break b}dc=c[U+(hc<<2)>>2]|0;ic=c[Fb>>2]|0;jc=c[Gb>>2]|0;do{if((ic|0)==0){kc=c[Hb>>2]|0;if((kc|0)==0){lc=ec;break}cf[kc&1023](_,Ab,z,va);lc=_}else{Se[ic&511](_,ec,fc,gc,z,ua);lc=_}}while(0);gc=c[Ib>>2]|0;if((gc|0)==0){Ke[c[Jb>>2]&1023](f,dc,A,lc,M,K,S)}else{Se[gc&511](f,dc,A,lc,z,E)}if((jc|0)!=0){ne[jc&1023](dc,A)}do{if(Fa){gc=c[X+(hc<<2)>>2]|0;fc=c[Kb>>2]|0;ec=c[Db>>2]|0;do{if((fc|0)==0){ic=c[Lb>>2]|0;if((ic|0)==0){mc=ec;break}cf[ic&1023](_,Ab,z,0);mc=_}else{Se[fc&511](_,ec,c[Bb>>2]|0,c[Cb>>2]|0,z,ua);mc=_}}while(0);ec=c[Ib>>2]|0;if((ec|0)==0){Ke[c[Jb>>2]&1023](f,gc,A,mc,M,K,S);break}else{Se[ec&511](f,gc,A,mc,z,E);break}}}while(0);if((Yb|0)<($b|0)){Zb=Yb;Vb=hc}else{nc=Yb;oc=hc;break}}}else{nc=Rb;oc=Pb}if((_b|0)<(bc|0)){Vb=_b;Zb=Ob;while(1){$b=Vb+1|0;dc=$b-fa|0;jc=(c[g>>2]|0)+(ba(c[h>>2]|0,dc)|0)|0;c[kb>>2]=jc;ec=(c[mb>>2]|0)+(ba(c[$>>2]|0,dc)|0)|0;c[lb>>2]=ec;fc=(c[ob>>2]|0)+(ba(c[xa>>2]|0,dc)|0)|0;c[nb>>2]=fc;c[pb>>2]=(c[qb>>2]|0)+(ba(c[rb>>2]|0,dc)|0);ic=Zb+1|0;if((ic|0)>=(sb|0)){za=75;break b}if((dc|0)>=(ea|0)){za=77;break b}if(!((dc|0)>-1)){za=79;break b}do{if((c[tb>>2]|0)!=0){dc=c[V+(ic<<2)>>2]|0;kc=c[W+(ic<<2)>>2]|0;pc=c[ub>>2]|0;do{if((pc|0)==0){qc=c[vb>>2]|0;if((qc|0)==0){rc=ec;sc=fc;break}le[qc&1023](_,wb,kb,D,va);rc=_;sc=wb}else{Ke[pc&1023](_,wb,jc,ec,fc,D,ua);rc=_;sc=wb}}while(0);pc=c[xb>>2]|0;if((pc|0)==0){Ke[c[yb>>2]&1023](f,dc,C,rc,N,L,T);Ke[c[yb>>2]&1023](f,kc,C,sc,N,L,T)}else{Be[pc&127](f,dc,kc,C,rc,sc,D,F)}pc=c[zb>>2]|0;if((pc|0)==0){break}Xe[pc&4095](dc,kc,C)}}while(0);if(($b|0)<(bc|0)){Vb=$b;Zb=ic}else{tc=$b;uc=ic;break}}}else{tc=_b;uc=Ob}Zb=oc-((oc|0)<(Y|0)?0:Y)|0;Vb=uc-((uc|0)<(Z|0)?0:Z)|0;if(!cc){vc=Zb;wc=Vb;xc=nc;yc=tc;zc=Qb;break a}if(ka){c[Ta>>2]=1232896+((Sb&7)<<3);c[Ua>>2]=1232896+((Qb&7)<<3)}if((Qb|0)<(Va|0)){Ac=Ub}else{_ub(f,o,p,q,r,s,t,u);Ac=0}Rb=Wb+Y-nc+Zb|0;fc=U+(Rb<<2)|0;ec=Xb+Z-tc+Vb|0;jc=V+(ec<<2)|0;hc=W+(ec<<2)|0;if(Fa){Bc=X+(Rb<<2)|0}else{Bc=0}Rb=c[Wa>>2]|0;ec=c[Xa>>2]|0;Yb=bFb(G)|0;if((Yb|0)==0){za=99;break}do{if((a[Yb+7|0]&16)==0){za=105}else{pc=bFb(G)|0;if((pc|0)==0){za=102;break b}if(!((a[pc+7|0]&32)==0)){za=105;break}if((d[pc+4|0]|0)>>>0>1>>>0){za=110}else{za=105}}}while(0);c:do{if((za|0)==105){za=0;do{if((G|0)==66|(G|0)==32|(G|0)==31|(G|0)==8){Yb=bFb(G)|0;if((Yb|0)==0){za=107;break b}if(fb){break}if((a[Yb+7|0]|0)>-1){za=110;break c}}}while(0);ic=c[t>>2]|0;if((ic|0)==0){$b=Rb+((ba(Qb,Q)|0)<<1)|0;Yb=ec+((ba(Qb,R)|0)<<1)|0;Ue[c[u>>2]&127](f,$b,fc,Q,Yb,jc,hc,R,Bc,H,A,Qb);break}if(!((c[aa>>2]|0)!=0&Ya&Za)){if((c[ca>>2]|0)!=0&$a&ab){Yb=Qb<<1;$b=Yb|1;Xb=b[Rb+($b<<1)>>1]|0;Wb=b[ec+($b<<1)>>1]|0;$b=(b[Rb+(Yb<<1)>>1]|0)*65537|0;c[bb>>2]=$b;c[cb>>2]=$b;$b=(b[ec+(Sb<<1<<1)>>1]|0)*65537|0;c[db>>2]=$b;c[eb>>2]=$b;Ne[c[s>>2]&127](f,fc,jc,hc,Fa?Bc:0,c[H>>2]|0,A,Xb,Wb,Qb);break}else{Wb=Rb+((ba(Qb,Q)|0)<<1)|0;Xb=ec+((ba(Qb,R)|0)<<1)|0;Ue[ic&127](f,Wb,fc,Q,Xb,jc,hc,R,Bc,c[H>>2]|0,A,Qb);break}}if(_a){Cc=0}else{Cc=b[ec+((Qb<<1|1)<<1)>>1]|0}if(Fa){Dc=c[Bc>>2]|0}else{Dc=0}Le[c[r>>2]&255](f,c[fc>>2]|0,jc,hc,Dc,c[H>>2]|0,A,Cc,Qb)}}while(0);do{if((za|0)==110){za=0;Xb=(1<<c[la>>2])-1|0;Wb=Rb+((ba(Qb,Q)|0)<<1)|0;ic=ec+((ba(Sb,R)|0)<<1)|0;$b=(Ac|0)!=0;Yb=$b?hb:ic;if(Ya){le[c[o>>2]&1023](c[fc>>2]|0,c[H>>2]|0,A,c[Ua>>2]|0,0)}else{Ke[c[p>>2]&1023]($b?gb:Wb,Q,fc,c[H>>2]|0,A,c[Ua>>2]|0,0)}do{if((Xb&Qb|0)==0){if((G|0)==66|(G|0)==32|(G|0)==31|(G|0)==8){break}ic=c[q>>2]|0;if((ic|0)!=0){Ke[ic&1023](f,Yb,R,jc,hc,c[ya>>2]|0,C);break}if(_a){le[c[o>>2]&1023](c[jc>>2]|0,c[ya>>2]|0,C,c[Ta>>2]|0,0);le[c[o>>2]&1023](c[hc>>2]|0,c[Ba>>2]|0,C,c[Ta>>2]|0,3);break}Ke[c[p>>2]&1023](Yb,R,jc,c[ya>>2]|0,C,c[Ta>>2]|0,0);if($b){Ec=c[ib>>2]>>1}else{Ec=3}Ke[c[p>>2]&1023](Yb,R,hc,c[Ba>>2]|0,C,c[Ta>>2]|0,Ec)}}while(0);if(!Fa){break}if(Ya){le[c[o>>2]&1023](c[Bc>>2]|0,c[Ea>>2]|0,A,c[Ua>>2]|0,0);break}else{Ke[c[p>>2]&1023]($b?jb:Wb,Q,Bc,c[Ea>>2]|0,A,c[Ua>>2]|0,0);break}}}while(0);hc=Qb+1|0;if((hc|0)<(B|0)){Mb=tc;Nb=nc;Ob=Vb;Pb=Zb;Qb=hc}else{vc=Zb;wc=Vb;xc=nc;yc=tc;zc=hc;break a}}if((za|0)==42){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1890104,c[ja+8>>2]=2347440,c[ja+16>>2]=484,ja)|0);i=ja;Cd();return 0}else if((za|0)==44){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=2327096,c[ja+8>>2]=2347440,c[ja+16>>2]=485,ja)|0);i=ja;Cd();return 0}else if((za|0)==50){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=2303128,c[ja+8>>2]=2347440,c[ja+16>>2]=513,ja)|0);i=ja;Cd();return 0}else if((za|0)==52){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=2285176,c[ja+8>>2]=2347440,c[ja+16>>2]=514,ja)|0);i=ja;Cd();return 0}else if((za|0)==54){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=2269640,c[ja+8>>2]=2347440,c[ja+16>>2]=515,ja)|0);i=ja;Cd();return 0}else if((za|0)==75){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=2254216,c[ja+8>>2]=2347440,c[ja+16>>2]=535,ja)|0);i=ja;Cd();return 0}else if((za|0)==77){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=2240048,c[ja+8>>2]=2347440,c[ja+16>>2]=536,ja)|0);i=ja;Cd();return 0}else if((za|0)==79){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=2227976,c[ja+8>>2]=2347440,c[ja+16>>2]=537,ja)|0);i=ja;Cd();return 0}else if((za|0)==99){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=667,ja)|0);i=ja;Cd();return 0}else if((za|0)==102){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=660,ja)|0);i=ja;Cd();return 0}else if((za|0)==107){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=778,ja)|0);i=ja;Cd();return 0}}else{vc=pa;wc=ra;xc=ta;yc=ha;zc=na}}while(0);ha=bFb(G)|0;if((ha|0)==0){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=806,ja)|0);i=ja;Cd();return 0}if(!((d[ha+4|0]|0)>>>0>1>>>0)){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}if((a[ha+7|0]&16)==0){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}ha=bFb(G)|0;if((ha|0)==0){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=778,ja)|0);i=ja;Cd();return 0}if((G|0)==11){Gc=1}else{Gc=(a[ha+7|0]|0)<0}if(!(Gc&(X|0)==0)){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}X=zc-na|0;Gc=bFb(G)|0;if((Gc|0)==0){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=637,ja)|0);i=ja;Cd();return 0}do{if(!((b[Gc+8>>1]&30720)==30720)){ha=bFb(G)|0;if((ha|0)==0){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=644,ja)|0);i=ja;Cd();return 0}if((((e[ha+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){break}ha=c[m+12>>2]|0;if((X|0)<=0){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}ta=0;ra=(c[l+12>>2]|0)+(ba(ha,na)|0)|0;while(1){TGb(ra|0,-1|0,A|0)|0;pa=ta+1|0;if((pa|0)<(X|0)){ta=pa;ra=ra+ha|0}else{break}}c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}}while(0);Gc=bFb(G)|0;ha=c[l+12>>2]|0;l=c[m+12>>2]|0;m=(e[Gc+14>>1]|0)>>>11&15;Gc=bFb(G)|0;if((Gc|0)==0){yDb(0,0,2042712,(ja=i,i=i+24|0,c[ja>>2]=1997712,c[ja+8>>2]=1961200,c[ja+16>>2]=653,ja)|0);i=ja;Cd();return 0}ja=ha+(ba(l,na)|0)|0;if((X|0)<=0){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}ha=(a[Gc+7|0]&1)==0;Gc=(A|0)>0;G=65535>>>((m^15)>>>0)&65535;m=de(G|0)|0;if(ha){if(Gc){Hc=ja;Ic=0}else{c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}while(1){ha=0;do{ra=Hc+(ha<<1)|0;x=G;a[ra]=x;x=x>>8;a[ra+1|0]=x;ha=ha+1|0;}while((ha|0)<(A|0));ha=Ic+1|0;if((ha|0)<(X|0)){Hc=Hc+l|0;Ic=ha}else{break}}c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}else{if(Gc){Jc=ja;Kc=0}else{c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}while(1){ja=0;do{Gc=Jc+(ja<<1)|0;x=m;a[Gc]=x;x=x>>8;a[Gc+1|0]=x;ja=ja+1|0;}while((ja|0)<(A|0));ja=Kc+1|0;if((ja|0)<(X|0)){Jc=Jc+l|0;Kc=ja}else{break}}c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}return 0}function bsb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;m=i;i=i+96|0;n=m|0;o=m+16|0;p=m+32|0;q=m+48|0;r=m+64|0;s=m+80|0;if((f|0)==0|(l|0)==0|(k|0)==0){yDb(e,16,2167616,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=0;i=m;return u|0}v=n;w=f;c[v>>2]=c[w>>2];c[v+4>>2]=c[w+4>>2];c[v+8>>2]=c[w+8>>2];c[v+12>>2]=c[w+12>>2];w=o;v=k;c[w>>2]=c[v>>2];c[w+4>>2]=c[v+4>>2];c[w+8>>2]=c[v+8>>2];c[w+12>>2]=c[v+12>>2];if((j|0)==0){u=0;i=m;return u|0}v=e+56|0;w=bFb(c[v>>2]|0)|0;y=0;while(1){if((y|0)>=4){break}z=b[w+8+(y<<1)>>1]&3;if((c[f+(z<<2)>>2]|0)==0){A=8;break}if((c[g+(z<<2)>>2]|0)==0){A=8;break}else{y=y+1|0}}if((A|0)==8){yDb(e,16,2301984,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=0;i=m;return u|0}y=e+52|0;w=bFb(c[y>>2]|0)|0;z=0;while(1){if((z|0)>=4){break}B=b[w+8+(z<<1)>>1]&3;if((c[k+(B<<2)>>2]|0)==0){A=13;break}if((c[l+(B<<2)>>2]|0)==0){A=13;break}else{z=z+1|0}}if((A|0)==13){yDb(e,16,2172392,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=0;i=m;return u|0}z=e+96|0;k=c[z>>2]|0;w=(h|0)==0;do{if((k|0)!=0|w){if((k|0)==0){A=18}}else{if((j+h|0)==(c[e+12>>2]|0)){A=18;break}yDb(e,16,2097984,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=0;i=m;return u|0}}while(0);do{if((A|0)==18){if(w){c[z>>2]=1;break}else{c[z>>2]=-1;break}}}while(0);w=bFb(c[v>>2]|0)|0;if((w|0)==0){yDb(0,0,2042712,(t=i,i=i+24|0,c[t>>2]=1997712,c[t+8>>2]=1961200,c[t+16>>2]=828,t)|0);i=t;Cd();return 0}a:do{if(!((a[w+7|0]&66)==0)){A=f+4|0;k=0;while(1){switch(c[v>>2]|0){case 11:{B=c[(c[A>>2]|0)+(k<<2)>>2]|0;C=B>>>24;D=B>>>16&255;E=B&255;F=B>>>8&255;break};case 22:{C=255;D=(k>>5)*36|0;E=(k&3)*85|0;F=(k>>>2&7)*36|0;break};case 19:{C=255;D=(k&7)*36|0;E=(k>>6)*85|0;F=(k>>>3&7)*36|0;break};case 24:{C=255;D=(k>>3)*255|0;E=-(k&1)&255;F=(k>>>1&3)*85|0;break};case 8:case 66:{C=255;D=k;E=k;F=k;break};default:{C=255;D=-(k&1)&255;E=(k>>3)*255|0;F=(k>>>1&3)*85|0}}B=(F*16519|0)+540672+(E*3208|0)+(D*8414|0)>>15;if(B>>>0>255>>>0){G=-B>>31&255}else{G=B&255}B=(F*-9528|0)+4210688+(E*14392|0)+(D*-4865|0)>>15;if(B>>>0>255>>>0){H=-B>>31&255}else{H=B&255}B=(F*-12061|0)+4210688+(E*-2332|0)+(D*14392|0)>>15;if(B>>>0>255>>>0){I=-B>>31&255}else{I=B&255}B=C<<24;c[e+120+(k<<2)>>2]=G&255|B|(H&255)<<8|(I&255)<<16;J=c[y>>2]|0;if((J|0)==27){c[e+1144+(k<<2)>>2]=(E<<24)+(F<<16)+(C|D<<8)}else if((J|0)==29){c[e+1144+(k<<2)>>2]=(D<<24)+(F<<16)+(C|E<<8)}else if((J|0)==28|(J|0)==2){c[e+1144+(k<<2)>>2]=D+(F<<8)+(E<<16)+B}else{c[e+1144+(k<<2)>>2]=E+(F<<8)+(D<<16)+B}k=k+1|0;if((k|0)>=256){break a}}}}while(0);D=e+11268|0;do{if((c[D>>2]|0)==0){K=0}else{if((c[e+11272>>2]|0)!=0){K=0;break}F=c[y>>2]|0;E=bFb(F)|0;if((E|0)==0){yDb(0,0,2042712,(t=i,i=i+24|0,c[t>>2]=1997712,c[t+8>>2]=1961200,c[t+16>>2]=778,t)|0);i=t;Cd();return 0}if((F|0)!=11){if((a[E+7|0]|0)>-1){K=0;break}}E=c[g>>2]|0;F=WDb((ba((E|0)>-1?E:-E|0,j)|0)+32|0)|0;if((F|0)==0){u=-12;i=m;return u|0}E=c[g>>2]|0;if((E|0)<0){L=F+(ba(1-j|0,E)|0)|0}else{L=F}C=n|0;if((j|0)>0){I=c[C>>2]|0;H=c[e+8>>2]|0;G=c[D>>2]|0;f=0;do{w=ba(E,f)|0;k=H<<2;UGb(L+w|0,I+w|0,k)|0;A=G-1|0;if((A|0)<(k|0)){B=A;do{a[L+(w+B)|0]=-1;B=B+4|0;}while((B|0)<(k|0))}f=f+1|0;}while((f|0)<(j|0))}c[C>>2]=L;K=F}}while(0);L=e+11276|0;b:do{if((c[L>>2]|0)==0){M=K}else{do{if((c[e+11280>>2]|0)!=0){if((c[e+8>>2]|0)!=(c[e+19608>>2]|0)){break}if((c[e+12>>2]|0)==(c[e+16>>2]|0)){M=K;break b}}}while(0);F=c[g>>2]|0;C=WDb((ba((F|0)>-1?F:-F|0,j)|0)+32|0)|0;if((C|0)==0){u=-12;i=m;return u|0}F=c[g>>2]|0;if((F|0)<0){N=C+(ba(1-j|0,F)|0)|0}else{N=C}D=n|0;f=c[D>>2]|0;G=(F|0)/2|0;I=bFb(c[v>>2]|0)|0;if((j|0)>0){H=(F|0)>5;F=I+7|0;I=e+23828|0;E=e+23844|0;k=e+23846|0;B=e+23848|0;w=e+23852|0;A=e+23854|0;J=e+23856|0;O=e+23860|0;P=e+23862|0;Q=e+23864|0;R=e+23832|0;S=0;T=f;f=N;while(1){if(H){U=0;while(1){V=(a[F]&1)==0;W=T+(U<<1)|0;X=(d[W]|d[W+1|0]<<8)<<16>>16;if(V){W=T+(U+1<<1)|0;Y=T+(U+2<<1)|0;Z=(d[Y]|d[Y+1|0]<<8)<<16>>16;_=(d[W]|d[W+1|0]<<8)<<16>>16;$=X}else{W=de(X|0)|0;X=T+(U+1<<1)|0;Y=de((d[X]|d[X+1|0]<<8)<<16>>16|0)|0;X=T+(U+2<<1)|0;Z=de((d[X]|d[X+1|0]<<8)<<16>>16|0)|0;_=Y;$=W}W=c[I>>2]|0;Y=b[W+(($&65535)>>>4<<1)>>1]|0;X=b[W+((_&65535)>>>4<<1)>>1]|0;aa=b[W+((Z&65535)>>>4<<1)>>1]|0;W=ba(b[E>>1]|0,Y)|0;ca=(ba(b[k>>1]|0,X)|0)+W|0;W=ca+(ba(b[B>>1]|0,aa)|0)>>12;ca=ba(b[w>>1]|0,Y)|0;da=(ba(b[A>>1]|0,X)|0)+ca|0;ca=da+(ba(b[J>>1]|0,aa)|0)>>12;da=ba(b[O>>1]|0,Y)|0;Y=(ba(b[P>>1]|0,X)|0)+da|0;da=Y+(ba(b[Q>>1]|0,aa)|0)>>12;if((W|0)<0){ea=0}else{ea=(W|0)>4095?4095:W}if((ca|0)<0){fa=0}else{fa=(ca|0)>4095?4095:ca}if((da|0)<0){ga=0}else{ga=(da|0)>4095?4095:da}da=b[(c[R>>2]|0)+(ea<<1)>>1]<<4;if(V){V=f+(U<<1)|0;x=da;a[V]=x;x=x>>8;a[V+1|0]=x;V=f+(U+1<<1)|0;x=b[(c[R>>2]|0)+(fa<<1)>>1]<<4;a[V]=x;x=x>>8;a[V+1|0]=x;V=f+(U+2<<1)|0;x=b[(c[R>>2]|0)+(ga<<1)>>1]<<4;a[V]=x;x=x>>8;a[V+1|0]=x}else{V=f+(U<<1)|0;x=de(da|0)|0;a[V]=x;x=x>>8;a[V+1|0]=x;V=f+(U+1<<1)|0;x=de(b[(c[R>>2]|0)+(fa<<1)>>1]<<4|0)|0;a[V]=x;x=x>>8;a[V+1|0]=x;V=f+(U+2<<1)|0;x=de(b[(c[R>>2]|0)+(ga<<1)>>1]<<4|0)|0;a[V]=x;x=x>>8;a[V+1|0]=x}if((U+5|0)<(G|0)){U=U+3|0}else{break}}}U=S+1|0;if((U|0)<(j|0)){S=U;T=T+(G<<1)|0;f=f+(G<<1)|0}else{break}}}c[D>>2]=N;M=C}}while(0);N=(h|0)!=0;do{if(!N){if((c[e+2284>>2]&524288|0)==0){break}if((c[e+23972>>2]|0)!=3){break}ga=c[e+11200>>2]|0;if((ga|0)==0){break}fa=e+19608|0;TGb(ga|0,0,(c[fa>>2]<<2)+8|0)|0;TGb(c[e+11204>>2]|0,0,(c[fa>>2]<<2)+8|0)|0;TGb(c[e+11208>>2]|0,0,(c[fa>>2]<<2)+8|0)|0;TGb(c[e+11212>>2]|0,0,(c[fa>>2]<<2)+8|0)|0}}while(0);if((c[z>>2]|0)==1){fa=p|0;c[fa>>2]=c[g>>2];c[p+4>>2]=c[g+4>>2];c[p+8>>2]=c[g+8>>2];c[p+12>>2]=c[g+12>>2];p=q|0;c[p>>2]=c[l>>2];c[q+4>>2]=c[l+4>>2];c[q+8>>2]=c[l+8>>2];c[q+12>>2]=c[l+12>>2];q=n|0;csb(q,c[v>>2]|0);ga=o|0;csb(ga,c[y>>2]|0);if((j+h|0)==(c[e+12>>2]|0)){c[z>>2]=0}ha=je[c[e+4>>2]&127](e,q,fa,h,j,ga,p)|0}else{p=r|0;ga=c[g>>2]|0;c[p>>2]=-ga;fa=g+4|0;c[r+4>>2]=-(c[fa>>2]|0);q=g+8|0;c[r+8>>2]=-(c[q>>2]|0);ea=g+12|0;c[r+12>>2]=-(c[ea>>2]|0);r=s|0;c[r>>2]=-(c[l>>2]|0);g=l+4|0;c[s+4>>2]=-(c[g>>2]|0);Z=l+8|0;c[s+8>>2]=-(c[Z>>2]|0);_=l+12|0;c[s+12>>2]=-(c[_>>2]|0);s=j-1|0;$=ba(ga,s)|0;ga=n|0;c[ga>>2]=(c[ga>>2]|0)+$;$=bFb(c[v>>2]|0)|0;if(($|0)==0){yDb(0,0,2042712,(t=i,i=i+24|0,c[t>>2]=1997712,c[t+8>>2]=1961200,c[t+16>>2]=828,t)|0);i=t;Cd();return 0}t=c[e+80>>2]|0;if((a[$+7|0]&66)==0){$=ba((j>>t)-1|0,c[fa>>2]|0)|0;fa=n+4|0;c[fa>>2]=(c[fa>>2]|0)+$}$=ba((j>>t)-1|0,c[q>>2]|0)|0;q=n+8|0;c[q>>2]=(c[q>>2]|0)+$;$=ba(c[ea>>2]|0,s)|0;s=n+12|0;c[s>>2]=(c[s>>2]|0)+$;$=c[e+16>>2]|0;s=$-1|0;n=ba(s,c[l>>2]|0)|0;ea=o|0;c[ea>>2]=(c[ea>>2]|0)+n;n=($>>c[e+88>>2])-1|0;$=ba(n,c[g>>2]|0)|0;g=o+4|0;c[g>>2]=(c[g>>2]|0)+$;$=ba(n,c[Z>>2]|0)|0;Z=o+8|0;c[Z>>2]=(c[Z>>2]|0)+$;$=ba(s,c[_>>2]|0)|0;_=o+12|0;c[_>>2]=(c[_>>2]|0)+$;csb(ga,c[v>>2]|0);csb(ea,c[y>>2]|0);if(!N){c[z>>2]=0}ha=je[c[e+4>>2]&127](e,ga,p,(c[e+12>>2]|0)-(j+h)|0,j,ea,r)|0}c:do{if((c[e+11280>>2]|0)!=0){do{if((c[L>>2]|0)!=0){if((c[e+8>>2]|0)!=(c[e+19608>>2]|0)){break}if((c[e+12>>2]|0)==(c[e+16>>2]|0)){break c}}}while(0);C=c[o>>2]|0;D=c[l>>2]|0;r=(D|0)/2|0;ea=bFb(c[y>>2]|0)|0;if((ha|0)<=0){break}j=(D|0)>5;D=ea+7|0;ea=e+23840|0;h=e+23868|0;p=e+23870|0;ga=e+23872|0;z=e+23876|0;N=e+23878|0;v=e+23880|0;$=e+23884|0;_=e+23886|0;s=e+23888|0;Z=e+23836|0;n=0;g=C;while(1){if(j){C=0;while(1){q=(a[D]&1)==0;t=g+(C<<1)|0;fa=(d[t]|d[t+1|0]<<8)<<16>>16;if(q){K=g+(C+1<<1)|0;G=g+(C+2<<1)|0;ia=(d[G]|d[G+1|0]<<8)<<16>>16;ja=(d[K]|d[K+1|0]<<8)<<16>>16;ka=fa}else{K=de(fa|0)|0;fa=g+(C+1<<1)|0;G=de((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0;fa=g+(C+2<<1)|0;ia=de((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0;ja=G;ka=K}K=c[ea>>2]|0;G=b[K+((ka&65535)>>>4<<1)>>1]|0;fa=b[K+((ja&65535)>>>4<<1)>>1]|0;f=b[K+((ia&65535)>>>4<<1)>>1]|0;K=ba(b[h>>1]|0,G)|0;T=(ba(b[p>>1]|0,fa)|0)+K|0;K=T+(ba(b[ga>>1]|0,f)|0)>>12;T=ba(b[z>>1]|0,G)|0;S=(ba(b[N>>1]|0,fa)|0)+T|0;T=S+(ba(b[v>>1]|0,f)|0)>>12;S=ba(b[$>>1]|0,G)|0;G=(ba(b[_>>1]|0,fa)|0)+S|0;S=G+(ba(b[s>>1]|0,f)|0)>>12;if((K|0)<0){la=0}else{la=(K|0)>4095?4095:K}if((T|0)<0){ma=0}else{ma=(T|0)>4095?4095:T}if((S|0)<0){na=0}else{na=(S|0)>4095?4095:S}S=b[(c[Z>>2]|0)+(la<<1)>>1]<<4;if(q){x=S;a[t]=x;x=x>>8;a[t+1|0]=x;q=g+(C+1<<1)|0;x=b[(c[Z>>2]|0)+(ma<<1)>>1]<<4;a[q]=x;x=x>>8;a[q+1|0]=x;q=g+(C+2<<1)|0;x=b[(c[Z>>2]|0)+(na<<1)>>1]<<4;a[q]=x;x=x>>8;a[q+1|0]=x}else{x=de(S|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;t=g+(C+1<<1)|0;x=de(b[(c[Z>>2]|0)+(ma<<1)>>1]<<4|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;t=g+(C+2<<1)|0;x=de(b[(c[Z>>2]|0)+(na<<1)>>1]<<4|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x}if((C+5|0)<(r|0)){C=C+3|0}else{break}}}C=n+1|0;if((C|0)<(ha|0)){n=C;g=g+(r<<1)|0}else{break}}}}while(0);ZDb(M);u=ha;i=m;return u|0}function csb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=bFb(e)|0;if((g|0)==0){yDb(0,0,2042712,(h=i,i=i+24|0,c[h>>2]=1997712,c[h+8>>2]=1961200,c[h+16>>2]=778,h)|0);i=h;Cd()}do{if((e|0)!=11){if(!((a[g+7|0]|0)>-1)){break}c[b+12>>2]=0}}while(0);g=bFb(e)|0;if((g|0)==0){yDb(0,0,2042712,(h=i,i=i+24|0,c[h>>2]=1997712,c[h+8>>2]=1961200,c[h+16>>2]=806,h)|0);i=h;Cd()}do{if((d[g+4|0]|0)>>>0>1>>>0){if((a[g+7|0]&16)==0){break}i=f;return}}while(0);c[b+8>>2]=0;c[b+12>>2]=0;g=bFb(e)|0;if((g|0)==0){yDb(0,0,2042712,(h=i,i=i+24|0,c[h>>2]=1997712,c[h+8>>2]=1961200,c[h+16>>2]=828,h)|0);i=h;Cd()}if(!((a[g+7|0]&66)==0)){i=f;return}c[b+4>>2]=0;i=f;return}function dsb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;if((f|0)<=0){return}a=(j|0)>0;k=0;do{l=c[i+(k<<2)>>2]|0;if(a){m=ba(k,j)|0;n=0;o=0;do{o=(ba(b[h+(n+m<<1)>>1]|0,d[g+(n+l)|0]|0)|0)+o|0;n=n+1|0;}while((n|0)<(j|0));p=o>>7}else{p=0}b[e+(k<<1)>>1]=(p|0)>32767?32767:p&65535;k=k+1|0;}while((k|0)<(f|0));return}function esb(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;if((e|0)>0){a=0;i=0;while(1){j=a>>>16;k=d[f+j|0]|0;b[c+(i<<1)>>1]=(ba((d[f+(j+1)|0]|0)-k|0,a>>>9&127)|0)+(k<<7);k=i+1|0;if((k|0)<(e|0)){a=a+h|0;i=k}else{break}}}i=e-1|0;e=g-1|0;if(((ba(i,h)|0)>>16|0)<(e|0)){return}g=f+e|0;f=i;do{b[c+(f<<1)>>1]=(d[g]|0)<<7;f=f-1|0;}while(((ba(f,h)|0)>>16|0)>=(e|0));return}function fsb(a,c,e,f,g,h,i,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;if((f|0)>0){a=0;k=0;while(1){l=a>>>16;m=a>>>9&127;n=m^127;o=ba(d[g+l|0]|0,n)|0;p=l+1|0;b[c+(k<<1)>>1]=(ba(d[g+p|0]|0,m)|0)+o;o=ba(d[h+l|0]|0,n)|0;b[e+(k<<1)>>1]=(ba(d[h+p|0]|0,m)|0)+o;o=k+1|0;if((o|0)<(f|0)){a=a+j|0;k=o}else{break}}}k=f-1|0;f=i-1|0;if(((ba(k,j)|0)>>16|0)<(f|0)){return}i=g+f|0;g=h+f|0;h=k;do{b[c+(h<<1)>>1]=(d[i]|0)<<7;b[e+(h<<1)>>1]=(d[g]|0)<<7;h=h-1|0;}while(((ba(h,j)|0)>>16|0)>=(f|0));return}function gsb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;a=e;if((f|0)<=0){return}e=(j|0)>0;k=0;do{l=c[i+(k<<2)>>2]|0;if(e){m=ba(k,j)|0;n=0;o=0;do{o=(ba(b[h+(n+m<<1)>>1]|0,d[g+(n+l)|0]|0)|0)+o|0;n=n+1|0;}while((n|0)<(j|0));p=o>>3}else{p=0}c[a+(k<<2)>>2]=(p|0)>524287?524287:p;k=k+1|0;}while((k|0)<(f|0));return}function hsb(d,f,g,h,j,k,l){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;m=i;n=d+56|0;d=f;f=h;h=(bFb(c[n>>2]|0)|0)+8|0;o=((e[h>>1]|0)>>>11&15)-4|0;p=c[n>>2]|0;a:do{switch(p|0){case 321:case 325:case 326:case 322:case 327:case 328:case 323:case 329:case 330:case 324:case 331:case 332:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 3:case 9:{q=6;break};default:{r=bFb(p)|0;if((r|0)==0){yDb(0,0,2042712,(s=i,i=i+24|0,c[s>>2]=1997712,c[s+8>>2]=1961200,c[s+16>>2]=674,s)|0);i=s;Cd()}if(!((a[r+7|0]&32)==0)){q=6;break a}if((c[n>>2]|0)==11){q=6}else{t=o}}}}while(0);if((q|0)==6){t=(b[h>>1]&30720)==30720?o:9}if((g|0)<=0){i=m;return}o=(l|0)>0;h=0;do{q=c[k+(h<<2)>>2]|0;if(o){n=ba(h,l)|0;p=0;r=0;while(1){s=(ba(b[j+(p+n<<1)>>1]|0,e[f+(p+q<<1)>>1]|0)|0)+r|0;u=p+1|0;if((u|0)<(l|0)){p=u;r=s}else{v=s;break}}}else{v=0}r=v>>t;c[d+(h<<2)>>2]=(r|0)>524287?524287:r;h=h+1|0;}while((h|0)<(g|0));i=m;return}function isb(d,f,g,h,j,k,l){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;m=i;n=d+56|0;d=h;h=(bFb(c[n>>2]|0)|0)+8|0;o=(e[h>>1]|0)>>>11&15;a:do{if(o<<16>>16==15){p=o&65535}else{q=c[n>>2]|0;switch(q|0){case 321:case 325:case 326:case 322:case 327:case 328:case 323:case 329:case 330:case 324:case 331:case 332:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 3:case 9:{p=13;break a;break};default:{}}r=bFb(q)|0;if((r|0)==0){yDb(0,0,2042712,(q=i,i=i+24|0,c[q>>2]=1997712,c[q+8>>2]=1961200,c[q+16>>2]=674,q)|0);i=q;Cd()}if(!((a[r+7|0]&32)==0)){p=13;break}if((c[n>>2]|0)==11){p=13;break}p=(e[h>>1]|0)>>>11&15}}while(0);if((g|0)<=0){i=m;return}h=(l|0)>0;n=0;do{o=c[k+(n<<2)>>2]|0;if(h){r=ba(n,l)|0;q=0;s=0;while(1){t=(ba(b[j+(q+r<<1)>>1]|0,e[d+(q+o<<1)>>1]|0)|0)+s|0;u=q+1|0;if((u|0)<(l|0)){q=u;s=t}else{v=t;break}}}else{v=0}s=v>>p;b[f+(n<<1)>>1]=(s|0)>32767?32767:s&65535;n=n+1|0;}while((n|0)<(g|0));i=m;return}function jsb(a,c){a=a|0;c=c|0;var d=0,e=0;if((c|0)>0){d=0}else{return}do{e=a+(d<<1)|0;b[e>>1]=(((b[e>>1]|0)*14071|0)+33561947|0)>>>14;d=d+1|0;}while((d|0)<(c|0));return}function ksb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;if((d|0)>0){e=0}else{return}do{f=a+(e<<1)|0;b[f>>1]=(((b[f>>1]|0)*1799|0)+4081085|0)>>>11;f=c+(e<<1)|0;b[f>>1]=(((b[f>>1]|0)*1799|0)+4081085|0)>>>11;e=e+1|0;}while((e|0)<(d|0));return}function lsb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;if((c|0)>0){d=0}else{return}do{e=a+(d<<1)|0;f=b[e>>1]|0;if(f<<16>>16>30189){g=32767}else{g=(((f<<16>>16)*19077|0)+1034684463|0)>>>14&65535}b[e>>1]=g;d=d+1|0;}while((d|0)<(c|0));return}function msb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)>0){e=0}else{return}do{f=a+(e<<1)|0;g=b[f>>1]|0;if(g<<16>>16>30775){h=32767}else{h=(((g<<16>>16)*4663|0)+259145464|0)>>>12&65535}b[f>>1]=h;f=c+(e<<1)|0;g=b[f>>1]|0;if(g<<16>>16>30775){i=32767}else{i=(((g<<16>>16)*4663|0)+259145464|0)>>>12&65535}b[f>>1]=i;e=e+1|0;}while((e|0)<(d|0));return}function nsb(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;if((b|0)>0){e=0}else{return}do{a=d+(e<<2)|0;c[a>>2]=((c[a>>2]|0)*3517|0)+134247788>>12;e=e+1|0;}while((e|0)<(b|0));return}function osb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=a;a=b;if((d|0)>0){f=0}else{return}do{b=e+(f<<2)|0;c[b>>2]=((c[b>>2]|0)*1799|0)+65297360>>11;b=a+(f<<2)|0;c[b>>2]=((c[b>>2]|0)*1799|0)+65297360>>11;f=f+1|0;}while((f|0)<(d|0));return}function psb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a;if((b|0)>0){e=0}else{return}do{a=d+(e<<2)|0;f=c[a>>2]|0;if((f|0)>483024){g=524246}else{g=(f*4769|0)-156229444>>12}c[a>>2]=g;e=e+1|0;}while((e|0)<(b|0));return}function qsb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a;a=b;if((d|0)>0){f=0}else{return}do{b=e+(f<<2)|0;g=c[b>>2]|0;if((g|0)>492400){h=524272}else{h=(g*4663|0)-148639872>>12}c[b>>2]=h;b=a+(f<<2)|0;g=c[b>>2]|0;if((g|0)>492400){i=524272}else{i=(g*4663|0)-148639872>>12}c[b>>2]=i;f=f+1|0;}while((f|0)<(d|0));return}function rsb(){return 132454}function ssb(){return 2167064}function tsb(b){b=b|0;var c=0;if(!(b>>>0<333>>>0)){c=0;return c|0}c=a[1048056+b|0]&1;return c|0}function usb(a){a=a|0;var b=0;if(!(a>>>0<333>>>0)){b=0;return b|0}b=(d[1048056+a|0]|0)>>>1&1;return b|0}function vsb(a){a=a|0;var b=0;if(!(a>>>0<333>>>0)){b=0;return b|0}b=(d[1048056+a|0]|0)>>>2&1;return b|0}function wsb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0;m=i;VGb(b+11228|0,e|0,16)|0;n=g;VGb(b+11244|0,n|0,16)|0;xsb(b);o=b+52|0;p=bFb(c[o>>2]|0)|0;q=b+56|0;r=bFb(c[q>>2]|0)|0;s=bFb(c[o>>2]|0)|0;if((s|0)==0){yDb(0,0,2240016,(t=i,i=i+24|0,c[t>>2]=2038784,c[t+8>>2]=2035608,c[t+16>>2]=660,t)|0);i=t;Cd();return 0}if((a[s+7|0]&32)==0){if((d[s+4|0]|0)>>>0>1>>>0){u=h}else{v=5}}else{v=5}do{if((v|0)==5){s=c[o>>2]|0;if((s|0)==8|(s|0)==66|(s|0)==31|(s|0)==32){u=h;break}u=0}}while(0);h=bFb(c[q>>2]|0)|0;if((h|0)==0){yDb(0,0,2240016,(t=i,i=i+24|0,c[t>>2]=2038784,c[t+8>>2]=2035608,c[t+16>>2]=660,t)|0);i=t;Cd();return 0}if((a[h+7|0]&32)==0){if((d[h+4|0]|0)>>>0>1>>>0){w=f}else{v=11}}else{v=11}do{if((v|0)==11){h=c[q>>2]|0;if((h|0)==8|(h|0)==66|(h|0)==31|(h|0)==32){w=f;break}w=0}}while(0);c[b+11220>>2]=j;c[b+11216>>2]=k;c[b+11224>>2]=l;c[b+11260>>2]=w;c[b+11264>>2]=u;u=bFb(c[o>>2]|0)|0;if((u|0)==0){yDb(0,0,2240016,(t=i,i=i+24|0,c[t>>2]=2038784,c[t+8>>2]=2035608,c[t+16>>2]=660,t)|0);i=t;Cd();return 0}if((a[u+7|0]&32)==0){if((d[u+4|0]|0)>>>0>1>>>0){v=18}else{v=17}}else{v=17}if((v|0)==17){u=c[o>>2]|0;if((u|0)==8|(u|0)==66|(u|0)==31|(u|0)==32){v=18}}do{if((v|0)==18){u=bFb(c[q>>2]|0)|0;if((u|0)==0){yDb(0,0,2240016,(t=i,i=i+24|0,c[t>>2]=2038784,c[t+8>>2]=2035608,c[t+16>>2]=660,t)|0);i=t;Cd();return 0}do{if((a[u+7|0]&32)==0){if((d[u+4|0]|0)>>>0>1>>>0){y=-1}else{break}i=m;return y|0}}while(0);u=c[q>>2]|0;if((u|0)==8|(u|0)==66|(u|0)==31|(u|0)==32){y=-1}else{break}i=m;return y|0}}while(0);c[b+60>>2]=$Eb(p)|0;c[b+64>>2]=$Eb(r)|0;r=bFb(c[o>>2]|0)|0;if((r|0)==0){yDb(0,0,2240016,(t=i,i=i+24|0,c[t>>2]=2038784,c[t+8>>2]=2035608,c[t+16>>2]=660,t)|0);i=t;Cd();return 0}if((a[r+7|0]&32)==0){if(!((d[r+4|0]|0)>>>0>1>>>0)){v=27}}else{v=27}do{if((v|0)==27){r=c[o>>2]|0;if((r|0)==8|(r|0)==66|(r|0)==31|(r|0)==32){break}Usb(b,e,w,j,k,l)|0}}while(0);l=c[g>>2]|0;k=l;j=(l|0)<0|0?-1:0;l=c[g+4>>2]|0;w=l;e=(l|0)<0|0?-1:0;l=-(c[g+8>>2]|0)|0;(l|0)<0|0?-1:0;o=-(c[g+12>>2]|0)|0;(o|0)<0|0?-1:0;g=b+10496|0;v=0;r=l;l=0;t=(r|0)>(l|0)|(r|0)==(l|0)&v>>>0>0>>>0;l=w>>>1|e<<31;p=e>>1|((e|0)<0|0?-1:0)<<31;q=ZGb(0,0,l,p)|0;u=YGb(t?l:q,t?p:F,v,r)|0;r=eHb(u,F,w,e)|0;u=F;v=0;p=o;o=0;t=(p|0)>(o|0)|(p|0)==(o|0)&v>>>0>0>>>0;o=k>>>1|j<<31;q=j>>1|((j|0)<0|0?-1:0)<<31;l=ZGb(0,0,o,q)|0;f=YGb(t?o:l,t?q:F,v,p)|0;p=eHb(f,F,k,j)|0;f=F;v=ZGb(0,1,r,u)|0;q=F;t=ZGb(v,q,p,f)|0;l=F;o=gHb(t,l,76309,0)|0;h=F;s=0;z=(h|0)>(s|0)|(h|0)==(s|0)&o>>>0>0>>>0;s=YGb(z?32768:-32768,z?0:-1,o,h)|0;h=eHb(s,F,65536,0)|0;s=F;o=gHb(t,l,w,e)|0;e=F;w=0;z=(e|0)>(w|0)|(e|0)==(w|0)&o>>>0>0>>>0;w=YGb(z?32768:-32768,z?0:-1,o,e)|0;e=eHb(w,F,65536,0)|0;w=F;o=gHb(t,l,k,j)|0;j=F;k=0;z=(j|0)>(k|0)|(j|0)==(k|0)&o>>>0>0>>>0;k=YGb(z?32768:-32768,z?0:-1,o,j)|0;j=eHb(k,F,65536,0)|0;k=F;o=p<<15|0>>>17;z=f<<15|p>>>17;p=0;f=(z|0)>(p|0)|(z|0)==(p|0)&o>>>0>0>>>0;p=h>>>1|s<<31;A=s>>1|((s|0)<0|0?-1:0)<<31;B=ZGb(0,0,p,A)|0;C=F;D=YGb(f?p:B,f?A:C,o,z)|0;E=eHb(D,F,h,s)|0;D=ZGb(0,0,E,F)|0;c[g>>2]=D;D=YGb(p,A,0,32768)|0;E=eHb(D,F,h,s)|0;D=b+10500|0;c[D>>2]=E;E=r<<15|0>>>17;G=u<<15|r>>>17;H=0;I=(G|0)>(H|0)|(G|0)==(H|0)&E>>>0>0>>>0;H=YGb(I?p:B,I?A:C,E,G)|0;C=eHb(H,F,h,s)|0;s=ZGb(0,0,C,F)|0;C=b+10504|0;c[C>>2]=s;s=e>>>1|w<<31;h=w>>1|((w|0)<0|0?-1:0)<<31;H=ZGb(0,0,s,h)|0;A=F;B=YGb(f?s:H,f?h:A,o,z)|0;z=eHb(B,F,e,w)|0;B=b+10508|0;c[B>>2]=z;z=YGb(s,h,0,32768)|0;o=eHb(z,F,e,w)|0;z=ZGb(0,0,o,F)|0;o=b+10512|0;c[o>>2]=z;z=YGb(t,l,r,u)|0;u=z<<15|0>>>17;r=F<<15|z>>>17;z=0;l=(r|0)>(z|0)|(r|0)==(z|0)&u>>>0>0>>>0;z=YGb(l?s:H,l?h:A,u,r)|0;r=eHb(z,F,e,w)|0;w=b+10516|0;c[w>>2]=r;r=v<<15|0>>>17;e=q<<15|v>>>17;v=0;q=(e|0)>(v|0)|(e|0)==(v|0)&r>>>0>0>>>0;v=j>>>1|k<<31;z=k>>1|((k|0)<0|0?-1:0)<<31;u=ZGb(0,0,v,z)|0;A=F;h=YGb(q?v:u,q?z:A,r,e)|0;e=eHb(h,F,j,k)|0;h=b+10520|0;c[h>>2]=e;e=YGb(v,z,0,32768)|0;r=eHb(e,F,j,k)|0;e=ZGb(0,0,r,F)|0;r=b+10524|0;c[r>>2]=e;e=YGb(I?v:u,I?z:A,E,G)|0;G=eHb(e,F,j,k)|0;k=b+10528|0;c[k>>2]=G;if((PGb(n,1076768,16)|0)==0){c[C>>2]=3208;c[k>>2]=-2332;c[w>>2]=14392;c[D>>2]=16519;c[r>>2]=-12061;c[o>>2]=-9528;c[g>>2]=8414;c[h>>2]=14392;c[B>>2]=-4865}B=b+10560|0;h=0;while(1){g=a[1068272+h|0]|0;if(g<<24>>24>-1){J=c[b+10496+(g<<24>>24<<2)>>2]&65535}else{J=0}g=B+(h<<1)|0;x=J;a[g]=x;x=x>>8;a[g+1|0]=x;g=h+1|0;if(g>>>0<280>>>0){h=g}else{y=0;break}}i=m;return y|0}function xsb(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0.0;d=a+56|0;e=c[d>>2]|0;if((e|0)==297){c[d>>2]=29;f=1;g=29}else if((e|0)==295){c[d>>2]=27;f=1;g=27}else if((e|0)==298){c[d>>2]=30;f=4;g=30}else if((e|0)==296){c[d>>2]=28;f=4;g=28}else{f=0;g=e}e=a+11268|0;c[e>>2]=c[e>>2]|f;f=a+52|0;e=c[f>>2]|0;if((e|0)==297){c[f>>2]=29;h=1;i=29}else if((e|0)==298){c[f>>2]=30;h=4;i=30}else if((e|0)==296){c[f>>2]=28;h=4;i=28}else if((e|0)==295){c[f>>2]=27;h=1;i=27}else{h=0;i=e}e=a+11272|0;c[e>>2]=c[e>>2]|h;if((g|0)==111){c[d>>2]=41;j=1}else if((g|0)==110){c[d>>2]=42;j=1}else{j=0}d=a+11276|0;g=c[d>>2]|j;c[d>>2]=g;if((i|0)==111){c[f>>2]=41;k=1}else if((i|0)==110){c[f>>2]=42;k=1}else{k=0}f=a+11280|0;i=c[f>>2]|k;c[f>>2]=i;if((g|i|0)==0){return}UGb(a+23844|0,1068224,24)|0;UGb(a+23868|0,1068248,24)|0;c[a+23828>>2]=5229720;c[a+23832>>2]=5246104;c[a+23836>>2]=5221528;c[a+23840>>2]=5237912;if((b[2627147]|0)==0){l=0}else{return}do{m=+(l|0)/4095.0;b[5229720+(l<<1)>>1]=Gc(+(+S(+m,2.5999999046325684)*4095.0))|0;b[5246104+(l<<1)>>1]=Gc(+(+S(+m,+.4545454446934474)*4095.0))|0;b[5221528+(l<<1)>>1]=Gc(+(+S(+m,+.3846153987229934)*4095.0))|0;b[5237912+(l<<1)>>1]=Gc(+(+S(+m,2.200000047683716)*4095.0))|0;l=l+1|0;}while((l|0)<4096);return}function ysb(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0;if((a|0)==0){j=-1;return j|0}c[b>>2]=a+11228;c[e>>2]=a+11244;c[d>>2]=c[a+11260>>2];c[f>>2]=c[a+11264>>2];c[g>>2]=c[a+11220>>2];c[h>>2]=c[a+11216>>2];c[i>>2]=c[a+11224>>2];j=0;return j|0}function zsb(){var a=0,b=0;a=cEb(23984)|0;b=a;if((a|0)==0){return b|0}c[a>>2]=402632;DEb(a);return b|0}function Asb(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;h=i;i=i+16|0;j=h|0;TGb(j|0,0,16)|0;k=d+8|0;l=c[k>>2]|0;m=d+12|0;n=c[m>>2]|0;o=d+19608|0;p=c[o>>2]|0;q=d+16|0;r=c[q>>2]|0;s=(p<<1)+81&-16;t=d+56|0;u=c[t>>2]|0;v=d+52|0;w=c[v>>2]|0;qBb()|0;x=d+2284|0;y=c[x>>2]|0;if((c[1149362]|0)==0){Exb()}z=(l|0)==(p|0);A=(n|0)==(r|0);B=z&A;C=c[t>>2]|0;switch(C|0){case 13:{c[t>>2]=4;D=1;E=4;break};case 8:case 32:case 31:{D=1;E=C;break};case 12:{c[t>>2]=0;D=1;E=0;break};case 14:{c[t>>2]=5;D=1;E=5;break};case 34:{c[t>>2]=33;D=1;E=33;break};case 320:{c[t>>2]=7;D=1;E=7;break};default:{D=0;E=C}}C=d+11260|0;c[C>>2]=c[C>>2]|D;D=c[v>>2]|0;switch(D|0){case 12:{c[v>>2]=0;G=1;H=0;break};case 8:case 32:case 31:{G=1;H=D;break};case 14:{c[v>>2]=5;G=1;H=5;break};case 320:{c[v>>2]=7;G=1;H=7;break};case 34:{c[v>>2]=33;G=1;H=33;break};case 13:{c[v>>2]=4;G=1;H=4;break};default:{G=0;H=D}}D=d+11264|0;c[D>>2]=c[D>>2]|G;if(!((u|0)==(E|0)&(w|0)==(H|0))){yDb(d,24,2097880,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}do{if((c[d+11216>>2]|0)==0){if((c[d+11224>>2]|0)!=0){break}if((c[d+60>>2]|0)!=0){break}wsb(d,1076768,c[C>>2]|0,1076768,c[D>>2]|0,0,65536,65536)|0}}while(0);xsb(d);H=c[t>>2]|0;w=c[v>>2]|0;E=bFb(H)|0;u=bFb(w)|0;G=H>>>0<333>>>0;do{if(B){if(!G){J=29;break}if((H-110|0)>>>0>1>>>0){J=28;break}if((gFb(H)|0)!=(w|0)){J=28}}else{if(G){J=28}else{J=29}}}while(0);do{if((J|0)==28){if((a[1048056+H|0]&1)==0){J=29;break}if(w>>>0<333>>>0){if(!((a[1048056+w|0]&2)==0)){break}}G=ZEb(w)|0;yDb(d,16,1997664,(I=i,i=i+8|0,c[I>>2]=G,I)|0);i=I;K=-22;i=h;return K|0}}while(0);if((J|0)==29){G=ZEb(H)|0;yDb(d,16,2042664,(I=i,i=i+8|0,c[I>>2]=G,I)|0);i=I;K=-22;i=h;return K|0}G=y&2047;do{if((G|0)==0){B=y|4;c[x>>2]=B;L=B}else{if((y+2047&G|0)==0){L=y;break}yDb(d,16,1961144,(I=i,i=i+8|0,c[I>>2]=G,I)|0);i=I;K=-22;i=h;return K|0}}while(0);if((l|0)<1|(n|0)<1|(p|0)<1|(r|0)<1){yDb(d,16,1933304,(I=i,i=i+32|0,c[I>>2]=l,c[I+8>>2]=n,c[I+16>>2]=p,c[I+24>>2]=r,I)|0);i=I;K=-22;i=h;return K|0}G=(g|0)==0?j:g;g=(f|0)==0?j:f;f=l;j=p>>1;y=YGb(j,(j|0)<0|0?-1:0,f<<16|0>>>16,((l|0)<0|0?-1:0)<<16|f>>>16)|0;f=eHb(y,F,p,(p|0)<0|0?-1:0)|0;y=d+36|0;c[y>>2]=f;f=n;j=r>>1;B=YGb(j,(j|0)<0|0?-1:0,f<<16|0>>>16,((n|0)<0|0?-1:0)<<16|f>>>16)|0;f=r;j=(r|0)<0|0?-1:0;M=eHb(B,F,f,j)|0;B=d+44|0;c[B>>2]=M;c[d+60>>2]=$Eb(u)|0;c[d+64>>2]=$Eb(E)|0;M=d+19624|0;c[M>>2]=262148;c[M+4>>2]=262148;M=g+4|0;N=c[M>>2]|0;if((N|0)==0){J=41}else{if((c[N+4>>2]|0)>1){O=1}else{J=41}}do{if((J|0)==41){N=c[g+12>>2]|0;if((N|0)!=0){if((c[N+4>>2]|0)>1){O=1;break}}N=c[G+4>>2]|0;if((N|0)!=0){if((c[N+4>>2]|0)>1){O=1;break}}N=c[G+12>>2]|0;if((N|0)==0){O=0;break}O=(c[N+4>>2]|0)>1}}while(0);N=g|0;P=c[N>>2]|0;if((P|0)==0){J=49}else{if((c[P+4>>2]|0)>1){Q=1}else{J=49}}do{if((J|0)==49){P=c[g+8>>2]|0;if((P|0)!=0){if((c[P+4>>2]|0)>1){Q=1;break}}P=c[G>>2]|0;if((P|0)!=0){if((c[P+4>>2]|0)>1){Q=1;break}}P=c[G+8>>2]|0;if((P|0)==0){Q=0;break}Q=(c[P+4>>2]|0)>1}}while(0);P=d+76|0;R=d+80|0;eFb(H,P,R)|0;S=d+84|0;T=d+88|0;eFb(w,S,T)|0;U=(w|0)==64;a:do{switch(w|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{J=59;break};default:{V=bFb(w)|0;if((V|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=674,I)|0);i=I;Cd();return 0}else{if((a[V+7|0]&32)==0){W=L;break a}else{J=59;break a}}}}}while(0);do{if((J|0)==59){if((L&8192|0)!=0){W=L;break}if((p&1|0)==0){X=L}else{yDb(d,48,1910392,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;V=L|8192;c[x>>2]=V;X=V}if((c[P>>2]|0)!=0){W=X;break}if((c[R>>2]|0)!=0){W=X;break}if((c[d+23972>>2]|0)==2){W=X;break}if((c[x>>2]&1|0)!=0){W=X;break}yDb(d,48,1890024,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;V=X|8192;c[x>>2]=V;W=V}}while(0);X=d+23972|0;L=c[X>>2]|0;do{if((L|0)==1){if((W&8388608|0)==0){Y=1;break}c[X>>2]=3;Y=3}else{Y=L}}while(0);do{if((w|0)==24|(w|0)==22|(w|0)==21|(w|0)==19){if((Y|0)==1){L=W>>>13&1|2;c[X>>2]=L;Z=L}else{Z=Y}if((W&8192|0)==0&(Z|0)==3){L=ZEb(w)|0;yDb(d,48,2347336,(I=i,i=i+8|0,c[I>>2]=L,I)|0);i=I;L=W|8192;c[x>>2]=L;_=L}else{_=W}if((_&8192|0)==0){$=_;break}if((c[X>>2]|0)!=2){$=_;break}L=ZEb(w)|0;yDb(d,48,2326992,(I=i,i=i+8|0,c[I>>2]=L,I)|0);i=I;c[X>>2]=3;$=_}else{$=W}}while(0);W=bFb(w)|0;if((W|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=820,I)|0);i=I;Cd();return 0}do{if((a[W+7|0]&48)==48){if(($&8192|0)!=0){aa=$;break}_=ZEb(w)|0;yDb(d,48,2303048,(I=i,i=i+8|0,c[I>>2]=_,I)|0);i=I;_=$|8192;c[x>>2]=_;aa=_}else{aa=$}}while(0);b:do{if((aa&8192|0)==0){ba=aa}else{c:do{switch(w|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{break};default:{$=bFb(w)|0;if(($|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=674,I)|0);i=I;Cd();return 0}else{if((a[$+7|0]&32)==0){ba=aa;break b}else{break c}}}}}while(0);$=bFb(w)|0;if(($|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=820,I)|0);i=I;Cd();return 0}if((a[$+7|0]&48)==48){ba=aa;break}switch(w|0){case 30:case 29:case 28:case 27:case 24:case 22:case 21:case 19:case 3:case 2:{ba=aa;break b;break};default:{}}$=ZEb(w)|0;yDb(d,24,2285096,(I=i,i=i+8|0,c[I>>2]=$,I)|0);i=I;$=aa&-8193;c[x>>2]=$;ba=$}}while(0);d:do{switch(w|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{J=97;break};default:{x=bFb(w)|0;if((x|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=674,I)|0);i=I;Cd();return 0}else{if((a[x+7|0]&32)==0){break d}else{J=97;break d}}}}}while(0);do{if((J|0)==97){if((ba&8192|0)!=0){break}c[S>>2]=1}}while(0);x=ba>>>16&3;c[d+92>>2]=x;c[R>>2]=(c[R>>2]|0)+x;e:do{switch(H|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{J=103;break};default:{x=bFb(H)|0;if((x|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=674,I)|0);i=I;Cd();return 0}else{if((a[x+7|0]&32)==0){break e}else{J=103;break e}}}}}while(0);f:do{if((J|0)==103){if((ba&16384|0)!=0){break}switch(H|0){case 316:case 315:case 314:case 313:case 88:case 87:case 86:case 85:case 84:case 83:case 24:case 23:case 22:case 21:case 20:case 19:{break f;break};default:{}}if((p>>c[S>>2]|0)>(l>>1|0)){if((ba&1|0)==0){break}}c[P>>2]=1}}while(0);x=d+20|0;c[x>>2]=-(-l>>c[P>>2]);aa=d+24|0;c[aa>>2]=-(-n>>c[R>>2]);$=d+28|0;c[$>>2]=-(-p>>c[S>>2]);W=d+32|0;c[W>>2]=-(-r>>c[T>>2]);_=(l<<2)+186&-32;X=WDb(_)|0;c[d+2208>>2]=X;if(!((X|0)!=0|(_|0)==0)){yDb(d,16,2269608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}g:do{if(!(Q|z&A^1|O)){h:do{if((c[C>>2]|0)!=(c[D>>2]|0)){switch(w|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{break h;break};default:{}}_=bFb(w)|0;if((_|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=674,I)|0);i=I;Cd();return 0}else{if((a[_+7|0]&32)==0){break g}else{break}}}}while(0);Fyb(d);if((c[d+4>>2]|0)==0){break}if((ba&4096|0)==0){K=0;i=h;return K|0}_=ZEb(H)|0;X=ZEb(w)|0;yDb(d,32,2254168,(I=i,i=i+16|0,c[I>>2]=_,c[I+8>>2]=X,I)|0);i=I;K=0;i=h;return K|0}}while(0);D=((e[E+8>>1]|0)>>>11&15)+1|0;E=d+72|0;c[E>>2]=D>>>0<8>>>0?8:D;D=u+8|0;u=((e[D>>1]|0)>>>11&15)+1|0;C=d+68|0;c[C>>2]=u>>>0<8>>>0?8:u;i:do{switch(H|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{J=123;break};default:{u=bFb(H)|0;if((u|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=674,I)|0);i=I;Cd();return 0}else{if((a[u+7|0]&32)!=0|(H|0)==11){J=123;break i}else{break i}}}}}while(0);if((J|0)==123){c[E>>2]=16}E=s<<((c[C>>2]|0)==16);c[d+2276>>2]=0;s=c[x>>2]|0;u=s;O=c[$>>2]|0;A=O>>1;z=YGb(A,(A|0)<0|0?-1:0,u<<16|0>>>16,((s|0)<0|0?-1:0)<<16|u>>>16)|0;u=eHb(z,F,O,(O|0)<0|0?-1:0)|0;O=d+40|0;c[O>>2]=u;u=c[aa>>2]|0;z=u;s=c[W>>2]|0;A=s>>1;Q=YGb(A,(A|0)<0|0?-1:0,z<<16|0>>>16,((u|0)<0|0?-1:0)<<16|z>>>16)|0;z=eHb(Q,F,s,(s|0)<0|0?-1:0)|0;s=d+48|0;c[s>>2]=z;z=(ba&64|0)!=0;Q=z?ba|4:ba;u=d+104|0;if((Bsb(d+2212|0,d+2228|0,d+2244|0,c[y>>2]|0,l,p,16384,Q,c[N>>2]|0,c[G>>2]|0,u,128,128)|0)<0){K=-1;i=h;return K|0}N=z?ba|2:ba;z=c[P>>2]|0;P=c[d+11284>>2]|0;if((P|0)<0){ca=(128<<z)-128|0}else{ca=P}P=c[S>>2]|0;S=c[d+11288>>2]|0;if((S|0)<0){da=(128<<P)-128|0}else{da=S}if((Bsb(d+2216|0,d+2232|0,d+2248|0,c[O>>2]|0,c[x>>2]|0,c[$>>2]|0,16384,N,c[g+8>>2]|0,c[G+8>>2]|0,u,ca+128>>z,da+128>>P)|0)<0){K=-1;i=h;return K|0}P=d+2236|0;da=d+2252|0;if((Bsb(d+2220|0,P,da,c[B>>2]|0,n,r,4096,Q,c[M>>2]|0,c[G+4>>2]|0,u,128,128)|0)<0){K=-1;i=h;return K|0}M=d+2240|0;Q=d+2256|0;z=c[R>>2]|0;ca=c[d+11292>>2]|0;if((ca|0)<0){ea=(128<<z)-128|0}else{ea=ca}ca=c[T>>2]|0;T=c[d+11296>>2]|0;if((T|0)<0){fa=(128<<ca)-128|0}else{fa=T}if((Bsb(d+2224|0,M,Q,c[s>>2]|0,c[aa>>2]|0,c[W>>2]|0,4096,N,c[g+12>>2]|0,c[G+12>>2]|0,u,ea+128>>z,fa+128>>ca)|0)<0){K=-1;i=h;return K|0}ca=c[da>>2]|0;da=d+2184|0;c[da>>2]=ca;fa=c[Q>>2]|0;Q=d+2188|0;c[Q>>2]=fa;if((r|0)>0){z=c[P>>2]|0;P=c[M>>2]|0;M=c[W>>2]|0;ea=c[R>>2]|0;R=0;u=ca;G=fa;while(1){g=gHb(M,(M|0)<0|0?-1:0,R,(R|0)<0|0?-1:0)|0;N=eHb(g,F,f,j)|0;g=c[z+(R<<2)>>2]|0;T=g-1+ca|0;S=P+(N<<2)|0;N=c[S>>2]|0;A=N-1+fa<<ea;X=((T|0)>(A|0)?T:A)>>ea<<ea;if((u+g|0)<(X|0)){A=X-g|0;c[da>>2]=A;ga=A;ha=c[S>>2]|0}else{ga=u;ha=N}N=X>>ea;if((G+ha|0)<(N|0)){X=N-ha|0;c[Q>>2]=X;ia=X}else{ia=G}X=R+1|0;if((X|0)<(r|0)){R=X;u=ga;G=ia}else{break}}}ia=cEb((c[o>>2]<<2)+8|0)|0;c[d+11200>>2]=ia;G=c[o>>2]|0;if((ia|0)==0){if((G&1073741823|0)==1073741822){J=146}}else{J=146}do{if((J|0)==146){ia=cEb((G<<2)+8|0)|0;c[d+11204>>2]=ia;ga=c[o>>2]|0;if((ia|0)==0){if((ga&1073741823|0)!=1073741822){break}}ia=cEb((ga<<2)+8|0)|0;c[d+11208>>2]=ia;ga=c[o>>2]|0;if((ia|0)==0){if((ga&1073741823|0)!=1073741822){break}}ia=cEb((ga<<2)+8|0)|0;c[d+11212>>2]=ia;if((ia|0)==0){if((c[o>>2]&1073741823|0)!=1073741822){break}}ia=WDb((c[da>>2]|0)*12|0)|0;ga=d+2168|0;c[ga>>2]=ia;do{if((ia|0)==0){if(((c[da>>2]|0)*12|0|0)==0){break}yDb(d,16,2269608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);ia=WDb((c[Q>>2]|0)*12|0)|0;u=d+2172|0;c[u>>2]=ia;R=c[Q>>2]|0;do{if((ia|0)==0){if((R*12|0|0)==0){break}yDb(d,16,2269608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);ia=WDb(R*12|0)|0;ha=d+2176|0;c[ha>>2]=ia;do{if((ia|0)==0){if(((c[Q>>2]|0)*12|0|0)==0){break}yDb(d,16,2269608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);ia=c[t>>2]|0;R=bFb(ia)|0;if((R|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=778,I)|0);i=I;Cd();return 0}if((ia|0)==11){J=159}else{if((a[R+7|0]|0)>-1){J=164}else{J=159}}do{if((J|0)==159){R=c[v>>2]|0;ia=bFb(R)|0;if((ia|0)==0){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2038784,c[I+8>>2]=2035608,c[I+16>>2]=778,I)|0);i=I;Cd();return 0}if((R|0)!=11){if((a[ia+7|0]|0)>-1){J=164;break}}ia=cEb((c[da>>2]|0)*12|0)|0;c[d+2180>>2]=ia;if((ia|0)!=0){J=164;break}ia=c[da>>2]|0;if((ia*12|0|0)==0){ja=ia;break}yDb(d,16,2269608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);if((J|0)==164){ja=c[da>>2]|0}ia=E+16|0;j:do{if((ja|0)>0){R=(ia|0)==0;ea=0;while(1){fa=cEb(ia)|0;P=c[da>>2]|0;ca=P+ea|0;c[(c[ga>>2]|0)+(ca<<2)>>2]=fa;fa=c[ga>>2]|0;z=c[fa+(ca<<2)>>2]|0;if(!((z|0)!=0|R)){break}c[fa+(ea<<2)>>2]=z;ea=ea+1|0;if((ea|0)>=(P|0)){break j}}yDb(d,16,2269608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);ga=E>>1;c[d+23752>>2]=(64/(c[C>>2]&-8|0)|0)+ga;c[d+23760>>2]=ia;ea=c[Q>>2]|0;k:do{if((ea|0)>0){R=(E<<1)+32|0;P=(R|0)==0;z=ga+8|0;fa=0;while(1){ca=WDb(R)|0;j=c[Q>>2]|0;f=j+fa|0;c[(c[u>>2]|0)+(f<<2)>>2]=ca;ca=c[u>>2]|0;M=c[ca+(f<<2)>>2]|0;if(!((M|0)!=0|P)){break}c[ca+(fa<<2)>>2]=M;M=(c[(c[u>>2]|0)+(fa<<2)>>2]|0)+(z<<1)|0;c[(c[ha>>2]|0)+(f<<2)>>2]=M;c[(c[ha>>2]|0)+(fa<<2)>>2]=M;M=fa+1|0;if((M|0)<(j|0)){fa=M}else{ka=j;break k}}yDb(d,16,2269608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}else{ka=ea}}while(0);ea=d+2180|0;do{if((c[ea>>2]|0)==0){la=ka}else{if((c[da>>2]|0)<=0){la=ka;break}ha=(ia|0)==0;ga=0;while(1){fa=cEb(ia)|0;z=c[da>>2]|0;P=z+ga|0;c[(c[ea>>2]|0)+(P<<2)>>2]=fa;fa=c[ea>>2]|0;R=c[fa+(P<<2)>>2]|0;if(!((R|0)!=0|ha)){break}c[fa+(ga<<2)>>2]=R;R=ga+1|0;if((R|0)<(z|0)){ga=R}else{J=180;break}}if((J|0)==180){la=c[Q>>2]|0;break}yDb(d,16,2269608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);l:do{if((la|0)>0){ea=((E|0)/2|0)+1|0;ia=(ea|0)>0;ga=E|1;ha=(ga|0)>0;R=0;z=la;m:while(1){do{if((b[D>>1]&30720)==30720){if((c[C>>2]|0)<=14){break m}if(!ia){ma=z;break}fa=c[(c[u>>2]|0)+(R<<2)>>2]|0;P=0;do{c[fa+(P<<2)>>2]=262144;P=P+1|0;}while((P|0)<(ea|0));ma=c[Q>>2]|0}else{if(!ha){ma=z;break}P=c[(c[u>>2]|0)+(R<<2)>>2]|0;fa=0;while(1){b[P+(fa<<1)>>1]=16384;j=fa+1|0;if((j|0)<(ga|0)){fa=j}else{ma=z;break}}}}while(0);fa=R+1|0;if((fa|0)<(ma|0)){R=fa;z=ma}else{break l}}yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2227960,c[I+8>>2]=2216352,c[I+16>>2]=1586,I)|0);i=I;Cd();return 0}}while(0);if((c[W>>2]|0)>(r|0)){yDb(0,0,2240016,(I=i,i=i+24|0,c[I>>2]=2206608,c[I+8>>2]=2216352,c[I+16>>2]=1593,I)|0);i=I;Cd();return 0}if((ba&4096|0)!=0){u=0;while(1){if(!(u>>>0<11>>>0)){na=0;break}if((c[479864+(u*12|0)>>2]&ba|0)==0){u=u+1|0}else{J=202;break}}if((J|0)==202){na=c[479868+(u*12|0)>>2]|0}z=d;R=ZEb(H)|0;switch(w|0){case 65:case 63:case 62:case 50:case 48:{oa=2173064;break};default:{oa=U?2173064:9203392}}ga=ZEb(w)|0;yDb(z,32,2189856,(I=i,i=i+32|0,c[I>>2]=(na|0)==0?2198736:na,c[I+8>>2]=R,c[I+16>>2]=oa,c[I+24>>2]=ga,I)|0);i=I;yDb(z,32,2149816,(I=i,i=i+8|0,c[I>>2]=2156664,I)|0);i=I;yDb(z,40,2142960,(I=i,i=i+32|0,c[I>>2]=l,c[I+8>>2]=n,c[I+16>>2]=p,c[I+24>>2]=r,I)|0);i=I;ga=c[m>>2]|0;R=c[o>>2]|0;ha=c[q>>2]|0;ea=c[y>>2]|0;ia=c[B>>2]|0;yDb(z,48,2137528,(I=i,i=i+48|0,c[I>>2]=c[k>>2],c[I+8>>2]=ga,c[I+16>>2]=R,c[I+24>>2]=ha,c[I+32>>2]=ea,c[I+40>>2]=ia,I)|0);i=I;ia=c[aa>>2]|0;ea=c[$>>2]|0;ha=c[W>>2]|0;R=c[O>>2]|0;ga=c[s>>2]|0;yDb(z,48,2130872,(I=i,i=i+48|0,c[I>>2]=c[x>>2],c[I+8>>2]=ia,c[I+16>>2]=ea,c[I+24>>2]=ha,c[I+32>>2]=R,c[I+40>>2]=ga,I)|0);i=I}c[d+4>>2]=$rb(d)|0;K=0;i=h;return K|0}}while(0);yDb(d,16,2269608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}function Bsb(a,e,f,g,j,k,l,m,n,o,p,q,r){a=a|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ca=0,da=0,ea=0,fa=0,ha=0.0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0.0,Na=0.0,Oa=0.0,Pa=0.0,Qa=0.0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0.0,Wa=0.0,Xa=0.0,Ya=0.0,Za=0.0,_a=0.0,$a=0.0,ab=0.0,bb=0.0,cb=0.0,db=0.0,eb=0.0,fb=0.0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0;s=i;i=i+8|0;t=s|0;c[t>>2]=0;u=(j|0)/(k|0)|0;v=u>>>0>65535>>>0;w=v?u>>>16:u;u=v?16:0;if((w&65280|0)==0){x=u;y=w}else{x=u|8;y=w>>>8}w=(d[1191992+y|0]|0)+x|0;x=(w|0)>8;y=x?46:54-w|0;x?0:0;x=_Gb(1,0,y|0)|0;w=F;u=k+3|0;v=u<<2;z=WDb(v)|0;c[e>>2]=z;a:do{if((z|0)!=0|(v|0)==0){A=g-65536|0;b:do{if((((A|0)>-1?A:65536-g|0)|0)<10&(q|0)==(r|0)){B=k<<3;C=cEb(B)|0;D=C;c[t>>2]=D;if(!((C|0)!=0|(B|0)==0)){yDb(0,16,2269608,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=0;break a}if((k|0)<=0){I=1;J=D;break}B=c[e>>2]|0;C=0;while(1){K=D+(C<<3)|0;c[K>>2]=x;c[K+4>>2]=w;c[B+(C<<2)>>2]=C;K=C+1|0;if((K|0)<(k|0)){C=K}else{I=1;J=D;break}}}else{if((m&16|0)!=0){D=k<<3;C=WDb(D)|0;B=C;c[t>>2]=B;if(!((C|0)!=0|(D|0)==0)){yDb(0,16,2269608,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=0;break a}D=g;C=(g|0)<0|0?-1:0;if((k|0)<=0){I=1;J=B;break}K=q;L=gHb(r,(r|0)<0|0?-1:0,D,C)|0;M=F;N=ZGb(L>>>8|M<<24,M>>8|((M|0)<0|0?-1:0)<<24,K<<8|0>>>24,((q|0)<0|0?-1:0)<<8|K>>>24)|0;K=c[e>>2]|0;M=F;L=N;N=0;while(1){O=YGb(L,M,32768,0)|0;c[K+(N<<2)>>2]=O>>>16|F<<16;O=B+(N<<3)|0;c[O>>2]=x;c[O+4>>2]=w;O=YGb(L,M,D,C)|0;R=N+1|0;if((R|0)<(k|0)){M=F;L=O;N=R}else{I=1;J=B;break b}}}B=(g|0)<65537;if(B){if((m&33|0)!=0){V=21}}else{if((m&1|0)!=0){V=21}}if((V|0)==21){N=k<<4;L=WDb(N)|0;M=L;c[t>>2]=M;if(!((L|0)!=0|(N|0)==0)){yDb(0,16,2269608,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=0;break a}N=g;L=(g|0)<0|0?-1:0;if((k|0)<=0){I=2;J=M;break}C=q;D=gHb(r,(r|0)<0|0?-1:0,N,L)|0;K=F;R=ZGb(D>>>8|K<<24,K>>8|((K|0)<0|0?-1:0)<<24,C<<8|0>>>24,((q|0)<0|0?-1:0)<<8|C>>>24)|0;C=c[e>>2]|0;K=x>>>16|w<<16;D=w>>16|((w|0)<0|0?-1:0)<<16;O=F;W=R;R=0;while(1){X=W>>>16|O<<16;c[C+(R<<2)>>2]=X;Y=R<<1;Z=X;_=ZGb(Z<<16|0>>>16,((X|0)<0|0?-1:0)<<16|Z>>>16,W,O)|0;Z=F;$=-1;ca=(Z|0)>($|0)|(Z|0)==($|0)&_>>>0>-1>>>0;$=ZGb(0,0,_,Z)|0;da=gHb(ca?_:$,ca?Z:F,K,D)|0;Z=ZGb(x,w,da,F)|0;da=F;ca=0;$=(da|0)<(ca|0)|(da|0)==(ca|0)&Z>>>0<0>>>0;ca=M+(Y<<3)|0;c[ca>>2]=$?0:Z;c[ca+4>>2]=$?0:da;da=X+1|0;X=da;$=ZGb(X<<16|0>>>16,((da|0)<0|0?-1:0)<<16|X>>>16,W,O)|0;X=F;da=-1;ca=(X|0)>(da|0)|(X|0)==(da|0)&$>>>0>-1>>>0;da=ZGb(0,0,$,X)|0;Z=gHb(ca?$:da,ca?X:F,K,D)|0;X=ZGb(x,w,Z,F)|0;Z=F;ca=0;da=(Z|0)<(ca|0)|(Z|0)==(ca|0)&X>>>0<0>>>0;ca=M+((Y|1)<<3)|0;c[ca>>2]=da?0:X;c[ca+4>>2]=da?0:Z;Z=YGb(W,O,N,L)|0;da=R+1|0;if((da|0)<(k|0)){O=F;W=Z;R=da}else{I=2;J=M;break b}}}M=(m&32|0)==0;do{if(M){if((m&4|0)!=0){ea=1;V=26;break}if((m&2|0)!=0){ea=3;V=26;break}if((m&128|0)!=0){ea=5;V=26;break}if((m&256|0)!=0){ea=8;V=26;break}if((m&1024|0)!=0){ea=9;V=26;break}if((m&8|0)==0){fa=-1}else{ea=10;V=26}}else{ea=0;V=26}}while(0);if((V|0)==26){fa=c[479872+(ea*12|0)>>2]|0}R=(m&512|0)!=0;do{if(R){ha=+h[p>>3];if(!(ha!=123456.0)){ia=6;break}ja=~~+aa(ha*2.0);V=31}else{ja=fa;V=31}}while(0);do{if((V|0)==31){if((ja|0)>0){ia=ja;break}yDb(0,0,2240016,(G=i,i=i+24|0,c[G>>2]=2031784,c[G+8>>2]=2216352,c[G+16>>2]=377,G)|0);i=G;Cd();return 0}}while(0);if(B){ka=ia}else{ka=(k-1+(ba(ia,j)|0)|0)/(k|0)|0}W=ka+1|0;O=j-2|0;L=(W|0)>(O|0)?O:W;W=(L|0)>1?L:1;L=ba(W,k<<3)|0;O=WDb(L)|0;N=O;c[t>>2]=N;if(!((O|0)!=0|(L|0)==0)){yDb(0,16,2269608,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=0;break a}L=g;O=(g|0)<0|0?-1:0;c:do{if((k|0)>0){D=q;K=gHb(r,(r|0)<0|0?-1:0,L,O)|0;C=F;da=ZGb(K>>>7|C<<25,C>>7|((C|0)<0|0?-1:0)<<25,D<<9|0>>>23,((q|0)<0|0?-1:0)<<9|D>>>23)|0;D=F;C=(W<<16)-131072|0;K=C;Z=(C|0)<0|0?-1:0;C=(W|0)>0;ca=g<<1;X=ca;Y=(ca|0)<0|0?-1:0;ca=(g|0)>65536;$=k;_=(k|0)<0|0?-1:0;la=j;ma=(j|0)<0|0?-1:0;na=(m&4|0)==0;oa=(m&8|0)==0;pa=(m&128|0)==0;qa=(m&256|0)==0;ha=+(x>>>0)+ +(w|0)*4294967296.0;ra=(m&2|0)==0;sa=(m&1024|0)==0;ta=x>>>30|w<<2;ua=w>>30|((w|0)<0|0?-1:0)<<2;va=w>>14|((w|0)<0|0?-1:0)<<18;wa=((w|0)<0|0?-1:0)>>14|((w|0)<0|0?-1:0)<<18;xa=p+8|0;ya=$Gb(0,4194304,y|0)|0;za=F;Aa=c[e>>2]|0;Ba=D;D=da;da=0;d:while(1){Ca=ZGb(D,Ba,K,Z)|0;Da=eHb(Ca,F,131072,0)|0;Ca=Da;c[Aa+(da<<2)>>2]=Ca;if(C){Da=ba(da,W)|0;Ea=Ca;Ca=0;while(1){Fa=Ea;Ga=ZGb(Fa<<17|0>>>15,((Ea|0)<0|0?-1:0)<<17|Fa>>>15,D,Ba)|0;Fa=F;Ha=-1;Ia=(Fa|0)>(Ha|0)|(Fa|0)==(Ha|0)&Ga>>>0>-1>>>0;Ha=ZGb(0,0,Ga,Fa)|0;Ja=Ia?Ga:Ha;Ha=Ja<<13|0>>>19;Ga=(Ia?Fa:F)<<13|Ja>>>19;if(ca){Ja=gHb(Ha,Ga,$,_)|0;Fa=eHb(Ja,F,la,ma)|0;Ka=F;La=Fa}else{Ka=Ga;La=Ha}Ma=(+(La>>>0)+ +(Ka|0)*4294967296.0)*9.313225746154785e-10;do{if(na){if(!oa){Na=+h[p>>3];Oa=Na!=123456.0?Na:1.0;do{if(Ma<1.0){Na=+T(Ma*3.141592653589793);if(Na<0.0){Pa=Na;V=56;break}Qa=+S(+Na,+Oa)}else{Pa=-1.0;V=56}}while(0);if((V|0)==56){V=0;Qa=-0.0- +S(+(-0.0-Pa),+Oa)}Na=ha*(Qa*.5+.5);Ra=(E=+Na,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Sa=~~+Na>>>0;break}if(!M){Ha=YGb(La,Ka,-536870912,-1)|0;Ga=gHb(Ha,F,L,O)|0;Ha=F;Fa=-8192;do{if((Ha|0)<(Fa|0)|(Ha|0)==(Fa|0)&Ga>>>0<0>>>0){Ta=16384;Ua=0}else{Ja=8192;if(!((Ha|0)<(Ja|0)|(Ha|0)==(Ja|0)&Ga>>>0<0>>>0)){Ta=0;Ua=0;break}Ja=ZGb(536870912,0,La,Ka)|0;Ia=gHb(Ja,F,L,O)|0;Ja=YGb(Ia,F,0,8192)|0;Ta=F;Ua=Ja}}while(0);Ga=gHb(Ua,Ta,va,wa)|0;Ra=F;Sa=Ga;break}if(!pa){Oa=+h[p>>3];Na=ha*+Wc(+(Ma*Ma*(-0.0-(Oa!=123456.0?Oa:3.0))));Ra=(E=+Na,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Sa=~~+Na>>>0;break}if(!qa){if((La|0)==0&(Ka|0)==0){Va=1.0}else{Na=Ma*3.141592653589793;Va=+U(Na)/Na}Na=ha*Va;Ra=(E=+Na,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Sa=~~+Na>>>0;break}if(R){Na=+h[p>>3];Oa=Na!=123456.0?Na:3.0;if((La|0)==0&(Ka|0)==0){Wa=1.0}else{Na=Ma*3.141592653589793;Wa=+U(Na)*+U(Na/Oa)/(Ma*Ma*3.141592653589793*3.141592653589793/Oa)}Na=ha*Wa;Ga=(E=+Na,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);if(!(Ma>Oa)){Ra=Ga;Sa=~~+Na>>>0;break}Ra=0;Sa=0;break}if(!ra){Ga=ZGb(1073741824,0,La,Ka)|0;Ha=F;Fa=0;Ja=(Ha|0)<(Fa|0)|(Ha|0)==(Fa|0)&Ga>>>0<0>>>0;Fa=gHb(Ja?0:Ga,Ja?0:Ha,ta,ua)|0;Ra=F;Sa=Fa;break}if(sa){break d}if(Ma>1.0){Na=0.0;Oa=-2.196152422706632;Xa=1.196152422706632;Ya=Ma;while(1){Za=Xa*3.0;_a=Za+(Na+Oa*2.0);$a=Oa+Za;Za=-0.0-Na-Oa*3.0-Xa*6.0;ab=Ya+-1.0;if(ab>1.0){Na=_a;Oa=$a;Xa=Za;Ya=ab}else{bb=0.0;cb=_a;db=$a;eb=Za;fb=ab;break}}}else{bb=1.0;cb=0.0;db=-2.196152422706632;eb=1.196152422706632;fb=Ma}Ya=ha*(bb+fb*(cb+fb*(db+fb*eb)));Ra=(E=+Ya,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Sa=~~+Ya>>>0}else{Ya=+h[p>>3];if(Ya!=123456.0){Xa=Ya*16777216.0;gb=(E=+Xa,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);hb=~~+Xa>>>0}else{gb=0;hb=0}Xa=+h[xa>>3];if(Xa!=123456.0){Ya=Xa*16777216.0;ib=(E=+Ya,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);jb=~~+Ya>>>0}else{ib=0;jb=10066329}Fa=0;do{if((Ka|0)>(Fa|0)|(Ka|0)==(Fa|0)&La>>>0>2147483647>>>0){kb=0;lb=0}else{Ha=gHb(La,Ka,La,Ka)|0;Ja=F;Ga=Ha>>>30|Ja<<2;Ha=Ja>>>30|0<<2;Ja=gHb(Ga,Ha,La,Ka)|0;Ia=F;mb=Ja>>>30|Ia<<2;Ja=Ia>>30|((Ia|0)<0|0?-1:0)<<2;Ia=0;if((Ka|0)<(Ia|0)|(Ka|0)==(Ia|0)&La>>>0<1073741824>>>0){Ia=gHb(hb,gb,-9,-1)|0;nb=YGb(Ia,F,201326592,0)|0;Ia=F;ob=gHb(jb,ib,6,0)|0;pb=F;qb=ZGb(nb,Ia,ob,pb)|0;Ia=gHb(qb,F,mb,Ja)|0;qb=F;nb=gHb(hb,gb,12,0)|0;rb=YGb(nb,F,-301989888,-1)|0;nb=YGb(rb,F,ob,pb)|0;pb=gHb(nb,F,Ga,Ha)|0;nb=F;ob=ZGb(100663296,0,hb<<1|0>>>31,gb<<1|hb>>>31)|0;rb=YGb(pb,nb,ob<<30|0>>>2,F<<30|ob>>>2)|0;ob=YGb(rb,F,Ia,qb)|0;kb=F;lb=ob;break}else{ob=gHb(jb,ib,-6,-1)|0;qb=ZGb(ob,F,hb,gb)|0;ob=gHb(qb,F,mb,Ja)|0;Ja=F;mb=gHb(hb,gb,6,0)|0;qb=F;Ia=gHb(jb,ib,30,0)|0;rb=YGb(Ia,F,mb,qb)|0;qb=gHb(rb,F,Ga,Ha)|0;Ha=YGb(ob,Ja,qb,F)|0;qb=F;Ja=gHb(hb,gb,-12,-1)|0;ob=F;Ga=gHb(jb,ib,-48,-1)|0;rb=YGb(Ga,F,Ja,ob)|0;ob=gHb(rb,F,La,Ka)|0;rb=YGb(Ha,qb,ob,F)|0;ob=F;qb=gHb(jb,ib,24,0)|0;Ha=YGb(qb,F,hb<<3|0>>>29,gb<<3|hb>>>29)|0;qb=YGb(rb,ob,Ha<<30|0>>>2,F<<30|Ha>>>2)|0;kb=F;lb=qb;break}}}while(0);Fa=eHb(lb,kb,ya,za)|0;Ra=F;Sa=Fa}}while(0);Fa=N+(Ca+Da<<3)|0;c[Fa>>2]=Sa;c[Fa+4>>2]=Ra;Fa=Ca+1|0;if((Fa|0)<(W|0)){Ea=Ea+1|0;Ca=Fa}else{break}}}Ca=YGb(D,Ba,X,Y)|0;Ea=da+1|0;if((Ea|0)<(k|0)){Ba=F;D=Ca;da=Ea}else{break c}}yDb(0,0,2240016,(G=i,i=i+24|0,c[G>>2]=2027560,c[G+8>>2]=2216352,c[G+16>>2]=475,G)|0);i=G;Cd();return 0}}while(0);if((W|0)>0){I=W;J=N;break}yDb(0,0,2240016,(G=i,i=i+24|0,c[G>>2]=2024088,c[G+8>>2]=2216352,c[G+16>>2]=488,G)|0);i=G;Cd();return 0}}while(0);A=(n|0)!=0;if(A){sb=I-1+(c[n+4>>2]|0)|0}else{sb=I}if((o|0)==0){tb=sb}else{tb=sb-1+(c[o+4>>2]|0)|0}if((tb|0)<=0){yDb(0,0,2240016,(G=i,i=i+24|0,c[G>>2]=2020688,c[G+8>>2]=2216352,c[G+16>>2]=494,G)|0);i=G;Cd();return 0}R=k<<3;O=ba(R,tb)|0;L=cEb(O)|0;M=L;if(!((L|0)!=0|(O|0)==0)){yDb(0,16,2269608,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=M;break}O=(k|0)>0;if(!O){$Db(t);yDb(0,0,2240016,(G=i,i=i+24|0,c[G>>2]=2016872,c[G+8>>2]=2216352,c[G+16>>2]=576,G)|0);i=G;Cd();return 0}L=n+4|0;B=(I|0)>0;da=n|0;D=((tb-1|0)/-2|0)+((I-1|0)/2|0)|0;Ba=c[e>>2]|0;Y=0;do{do{if(A){X=c[L>>2]|0;if((X|0)<=0){break}za=ba(Y,I)|0;ya=ba(Y,tb)|0;if(B){ub=0}else{break}do{ha=+h[(c[da>>2]|0)+(ub<<3)>>3];xa=ub+ya|0;sa=0;do{ua=J+(sa+za<<3)|0;ta=M+(xa+sa<<3)|0;Ma=+((c[ta>>2]|0)>>>0)+ +(c[ta+4>>2]|0)*4294967296.0+ha*(+((c[ua>>2]|0)>>>0)+ +(c[ua+4>>2]|0)*4294967296.0);ua=(E=+Ma,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[ta>>2]=~~+Ma>>>0;c[ta+4>>2]=ua;sa=sa+1|0;}while((sa|0)<(I|0));ub=ub+1|0;}while((ub|0)<(X|0))}else{if(!B){break}X=ba(Y,I)|0;za=ba(Y,tb)|0;ya=0;do{sa=J+(ya+X<<3)|0;xa=c[sa+4>>2]|0;ua=M+(ya+za<<3)|0;c[ua>>2]=c[sa>>2];c[ua+4>>2]=xa;ya=ya+1|0;}while((ya|0)<(I|0))}}while(0);N=Ba+(Y<<2)|0;c[N>>2]=D+(c[N>>2]|0);Y=Y+1|0;}while((Y|0)<(k|0));$Db(t);Y=k-1|0;if(!O){yDb(0,0,2240016,(G=i,i=i+24|0,c[G>>2]=2016872,c[G+8>>2]=2216352,c[G+16>>2]=576,G)|0);i=G;Cd();return 0}ha=(+(x>>>0)+ +(w|0)*4294967296.0)*.002;D=(tb|0)>1;Ba=0;B=Y;da=ba(tb,k)|0;while(1){L=ba(B,tb)|0;A=M+(L<<3)|0;N=(B|0)<(Y|0);W=B+1|0;ya=L+1|0;za=0;X=0;xa=0;while(1){ua=c[A>>2]|0;sa=c[A+4>>2]|0;ta=-1;ra=(sa|0)>(ta|0)|(sa|0)==(ta|0)&ua>>>0>-1>>>0;ta=ZGb(0,0,ua,sa)|0;qa=YGb(ra?ua:ta,ra?sa:F,xa,X)|0;sa=F;if(+(qa>>>0)+ +(sa|0)*4294967296.0>ha){vb=0;wb=0;xb=tb;break}if(N){ra=c[e>>2]|0;if((c[ra+(B<<2)>>2]|0)>=(c[ra+(W<<2)>>2]|0)){vb=0;wb=0;xb=tb;break}}if(D){ra=1;ta=ya;while(1){ua=M+(ta<<3)|0;pa=c[ua+4>>2]|0;wa=M+(ta-1<<3)|0;c[wa>>2]=c[ua>>2];c[wa+4>>2]=pa;pa=ra+1|0;if((pa|0)<(tb|0)){ra=pa;ta=pa+L|0}else{yb=da;break}}}else{yb=ya}ta=M+(yb-1<<3)|0;c[ta>>2]=0;c[ta+4>>2]=0;ta=(c[e>>2]|0)+(B<<2)|0;c[ta>>2]=(c[ta>>2]|0)+1;ta=za+1|0;if((ta|0)<(tb|0)){za=ta;X=sa;xa=qa}else{vb=0;wb=0;xb=tb;break}}while(1){xa=xb-1|0;if((xa|0)<=0){break}X=M+(xa+L<<3)|0;za=c[X>>2]|0;ya=c[X+4>>2]|0;X=-1;W=(ya|0)>(X|0)|(ya|0)==(X|0)&za>>>0>-1>>>0;X=ZGb(0,0,za,ya)|0;N=YGb(W?za:X,W?ya:F,wb,vb)|0;ya=F;if(+(N>>>0)+ +(ya|0)*4294967296.0>ha){break}else{vb=ya;wb=N;xb=xa}}zb=(xb|0)>(Ba|0)?xb:Ba;if((B|0)>0){Ba=zb;B=B-1|0;da=da-tb|0}else{break}}if((zb|0)<=0){yDb(0,0,2240016,(G=i,i=i+24|0,c[G>>2]=2016872,c[G+8>>2]=2216352,c[G+16>>2]=576,G)|0);i=G;Cd();return 0}da=WDb(ba(R,zb)|0)|0;c[t>>2]=da;if((zb|0)>255|(da|0)==0){yDb(0,16,2012944,(G=i,i=i+8|0,c[G>>2]=zb,G)|0);i=G;H=M;break}c[f>>2]=zb;if((m&4096|0)!=0){yDb(0,40,2008192,(G=i,i=i+16|0,c[G>>2]=tb,c[G+8>>2]=zb,G)|0);i=G}do{if(O){da=c[t>>2]|0;B=(m&524288|0)==0;Ba=0;do{D=ba(Ba,tb)|0;L=ba(Ba,zb)|0;if(B){xa=0;do{if((xa|0)<(tb|0)){N=M+(xa+D<<3)|0;ya=c[N+4>>2]|0;W=da+(xa+L<<3)|0;c[W>>2]=c[N>>2];c[W+4>>2]=ya}else{ya=da+(xa+L<<3)|0;c[ya>>2]=0;c[ya+4>>2]=0}xa=xa+1|0;}while((xa|0)<(zb|0))}else{xa=0;do{if((xa|0)<(tb|0)){qa=M+(xa+D<<3)|0;sa=c[qa+4>>2]|0;ya=da+(xa+L<<3)|0;c[ya>>2]=c[qa>>2];c[ya+4>>2]=sa}else{sa=da+(xa+L<<3)|0;c[sa>>2]=0;c[sa+4>>2]=0}xa=xa+1|0;}while((xa|0)<(zb|0))}Ba=Ba+1|0;}while((Ba|0)<(k|0));if(!O){break}Ba=c[e>>2]|0;da=zb-2|0;B=(da|0)>-1;xa=j-zb|0;L=zb-1|0;D=c[t>>2]|0;sa=(zb|0)>1;ya=0;do{qa=Ba+(ya<<2)|0;W=c[qa>>2]|0;if((W|0)<0){if(sa){N=ba(ya,zb)|0;X=1;do{za=W+X|0;A=D+(X+N<<3)|0;ta=D+(((za|0)>0?za:0)+N<<3)|0;za=YGb(c[ta>>2]|0,c[ta+4>>2]|0,c[A>>2]|0,c[A+4>>2]|0)|0;c[ta>>2]=za;c[ta+4>>2]=F;c[A>>2]=0;c[A+4>>2]=0;X=X+1|0;}while((X|0)<(zb|0))}c[qa>>2]=0;Ab=0}else{Ab=W}X=Ab+zb|0;if((X|0)>(j|0)){N=X-j|0;if(B){X=ba(ya,zb)|0;A=da;while(1){ta=A+N|0;za=D+(A+X<<3)|0;ra=D+(((ta|0)>(L|0)?L:ta)+X<<3)|0;ta=YGb(c[ra>>2]|0,c[ra+4>>2]|0,c[za>>2]|0,c[za+4>>2]|0)|0;c[ra>>2]=ta;c[ra+4>>2]=F;c[za>>2]=0;c[za+4>>2]=0;if((A|0)>0){A=A-1|0}else{break}}}c[qa>>2]=xa}ya=ya+1|0;}while((ya|0)<(k|0))}}while(0);R=cEb(ba(u<<1,c[f>>2]|0)|0)|0;c[a>>2]=R;do{if((R|0)==0){if(((ba(c[f>>2]|0,u)|0)&2147483647|0)==0){break}yDb(0,16,2269608,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=M;break a}}while(0);if(O){R=(l|0)/2|0;ya=R;xa=(R|0)<0|0?-1:0;R=l;L=(l|0)<0|0?-1:0;D=0;do{da=ba(D,zb)|0;B=c[t>>2]|0;sa=0;Ba=0;A=0;do{X=B+(sa+da<<3)|0;A=YGb(c[X>>2]|0,c[X+4>>2]|0,A,Ba)|0;Ba=F;sa=sa+1|0;}while((sa|0)<(zb|0));sa=YGb(ya,xa,A,Ba)|0;da=eHb(sa,F,R,L)|0;sa=F;if((da|0)==0&(sa|0)==0){yDb(0,24,1998160,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Bb=0;Cb=1}else{Bb=sa;Cb=da}da=c[f>>2]|0;if((da|0)>0){sa=ba(D,zb)|0;B=c[t>>2]|0;X=Cb>>>1|Bb<<31;N=Bb>>1|((Bb|0)<0|0?-1:0)<<31;W=ZGb(0,0,X,N)|0;za=F;ra=c[a>>2]|0;ta=0;pa=0;wa=0;while(1){ua=B+(ta+sa<<3)|0;va=YGb(c[ua>>2]|0,c[ua+4>>2]|0,wa,pa)|0;ua=F;oa=0;na=(ua|0)>(oa|0)|(ua|0)==(oa|0)&va>>>0>0>>>0;oa=YGb(na?X:W,na?N:za,va,ua)|0;na=eHb(oa,F,Cb,Bb)|0;b[ra+((ba(da,D)|0)+ta<<1)>>1]=na;oa=na;na=gHb(oa,(oa|0)<0|0?-1:0,Cb,Bb)|0;oa=ZGb(va,ua,na,F)|0;na=ta+1|0;if((na|0)<(da|0)){ta=na;pa=F;wa=oa}else{break}}}D=D+1|0;}while((D|0)<(k|0))}D=c[e>>2]|0;L=c[D+(Y<<2)>>2]|0;c[D+(k+2<<2)>>2]=L;c[D+(k+1<<2)>>2]=L;c[D+(k<<2)>>2]=L;L=c[f>>2]|0;if((L|0)<=0){Db=0;Eb=M;Fb=c[t>>2]|0;Gb=Fb;ZDb(Gb);Hb=Eb;ZDb(Hb);i=s;return Db|0}D=c[a>>2]|0;R=L<<1;xa=0;while(1){ya=(ba(L,Y)|0)+xa|0;O=b[D+(ya<<1)>>1]|0;b[D+(ya+(L*3|0)<<1)>>1]=O;b[D+(R+ya<<1)>>1]=O;b[D+(L+ya<<1)>>1]=O;O=xa+1|0;if((O|0)<(L|0)){xa=O}else{Db=0;Eb=M;break}}Fb=c[t>>2]|0;Gb=Fb;ZDb(Gb);Hb=Eb;ZDb(Hb);i=s;return Db|0}else{yDb(0,16,2269608,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=0}}while(0);yDb(0,16,1994312,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Db=-1;Eb=H;Fb=c[t>>2]|0;Gb=Fb;ZDb(Gb);Hb=Eb;ZDb(Hb);i=s;return Db|0}function Csb(a,b,d,e,f,g,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=cEb(23984)|0;n=m;if((m|0)==0){o=0;return o|0}c[m>>2]=402632;DEb(m);c[m+2284>>2]=i;c[m+8>>2]=a;c[m+12>>2]=b;c[m+19608>>2]=e;c[m+16>>2]=f;c[m+56>>2]=d;c[m+52>>2]=g;if((l|0)!=0){h[m+104>>3]=+h[l>>3];h[m+112>>3]=+h[l+8>>3]}if((Asb(n,j,k)|0)>=0){o=n;return o|0}Dsb(n);o=0;return o|0}function Dsb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;if((a|0)==0){return}b=a+2168|0;d=c[b>>2]|0;if((d|0)!=0){e=a+2184|0;a:do{if((c[e>>2]|0)>0){f=0;g=d;while(1){$Db(g+(f<<2)|0);h=f+1|0;if((h|0)>=(c[e>>2]|0)){break a}f=h;g=c[b>>2]|0}}}while(0);$Db(b)}b=a+2172|0;e=c[b>>2]|0;if((e|0)!=0){d=a+2188|0;b:do{if((c[d>>2]|0)>0){g=0;f=e;while(1){$Db(f+(g<<2)|0);h=g+1|0;if((h|0)>=(c[d>>2]|0)){break b}g=h;f=c[b>>2]|0}}}while(0);$Db(b);$Db(a+2176|0)}b=a+2180|0;d=c[b>>2]|0;if((d|0)!=0){e=a+2184|0;c:do{if((c[e>>2]|0)>0){f=0;g=d;while(1){$Db(g+(f<<2)|0);h=f+1|0;if((h|0)>=(c[e>>2]|0)){break c}f=h;g=c[b>>2]|0}}}while(0);$Db(b)}$Db(a+11200|0);$Db(a+11204|0);$Db(a+11208|0);$Db(a+11212|0);$Db(a+2220|0);$Db(a+2224|0);$Db(a+2212|0);$Db(a+2216|0);$Db(a+2236|0);$Db(a+2240|0);$Db(a+2228|0);$Db(a+2232|0);$Db(a+2288|0);$Db(a+2208|0);ZDb(a);return}function Esb(a){a=a|0;return 1076688+((a>>>0>7>>>0?5:a)<<4)|0}function Fsb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=b+56|0;f=ZEb(c[e>>2]|0)|0;g=b+52|0;h=ZEb(c[g>>2]|0)|0;yDb(b,24,2166680,(b=i,i=i+16|0,c[b>>2]=f,c[b+8>>2]=h,b)|0);i=b;a:do{switch(c[g>>2]|0){case 46:case 50:{j=66;break};case 41:case 42:{j=82;break};case 28:case 30:{k=7;break};case 67:case 68:{j=58;break};case 27:case 29:{h=c[e>>2]|0;f=bFb(h)|0;if((f|0)==0){yDb(0,0,2172264,(b=i,i=i+24|0,c[b>>2]=2097864,c[b+8>>2]=2042584,c[b+16>>2]=778,b)|0);i=b;Cd();return 0}if((h|0)==11){j=84;break a}if((a[f+7|0]|0)>-1){k=7}else{j=84}break};case 44:case 48:{j=78;break};case 10:{j=76;break};case 22:case 19:{j=34;break};case 62:case 64:{j=72;break};case 23:case 20:{j=16;break};case 2:{j=92;break};case 3:{j=44;break};case 24:case 21:{j=60;break};default:{j=0}}}while(0);do{if((k|0)==7){g=c[e>>2]|0;f=bFb(g)|0;if((f|0)==0){yDb(0,0,2172264,(b=i,i=i+24|0,c[b>>2]=2097864,c[b+8>>2]=2042584,c[b+16>>2]=778,b)|0);i=b;Cd();return 0}if((g|0)==11){j=18;break}j=(a[f+7|0]|0)<0?18:36}}while(0);i=d;return j|0}function Gsb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=g+1|0;q=g;r=1;s=0;while(1){t=c[i>>2]|0;u=s+g|0;v=c[j>>2]|0;w=t+(ba(v,u)|0)|0;x=t+(ba(v,u+1|0)|0)|0;u=c[e>>2]|0;y=c[f>>2]|0;z=ba(y,s)|0;A=u+z|0;B=u+(z+y)|0;C=c[k>>2]|0;D=s>>1;E=ba(c[l>>2]|0,D)|0;F=C+E|0;G=c[m>>2]|0;H=ba(c[n>>2]|0,D)|0;D=G+H|0;I=c[o>>2]|0;J=I>>3;if((J|0)==0){K=D;L=F;M=B;N=A;O=x;P=w;Q=I}else{I=J*48|0;R=(ba(v,p)|0)+I|0;S=(ba(v,q)|0)+I|0;I=J<<3;v=(ba(y,r)|0)+I|0;y=z+I|0;I=J<<2;z=H+I|0;H=E+I|0;I=D;D=J;J=F;F=B;B=A;A=x;x=w;while(1){w=D-1|0;E=(d[I]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B]|0;X=a[E+U|0]|0;a[x+1|0]=X;a[x]=X;X=a[V+(U+W)|0]|0;a[x+3|0]=X;a[x+2|0]=X;X=a[T+U|0]|0;a[x+5|0]=X;a[x+4|0]=X;X=d[B+1|0]|0;U=a[E+X|0]|0;a[x+7|0]=U;a[x+6|0]=U;U=a[V+(X+W)|0]|0;a[x+9|0]=U;a[x+8|0]=U;U=a[T+X|0]|0;a[x+11|0]=U;a[x+10|0]=U;U=d[F]|0;X=a[E+U|0]|0;a[A+1|0]=X;a[A]=X;X=a[V+(U+W)|0]|0;a[A+3|0]=X;a[A+2|0]=X;X=a[T+U|0]|0;a[A+5|0]=X;a[A+4|0]=X;X=d[F+1|0]|0;U=a[E+X|0]|0;a[A+7|0]=U;a[A+6|0]=U;U=a[V+(X+W)|0]|0;a[A+9|0]=U;a[A+8|0]=U;U=a[T+X|0]|0;a[A+11|0]=U;a[A+10|0]=U;U=(d[I+1|0]|0)+128|0;X=c[b+4352+(U<<2)>>2]|0;T=(d[J+1|0]|0)+128|0;W=c[b+6400+(T<<2)>>2]|0;V=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(T<<2)>>2]|0;T=d[F+2|0]|0;E=a[U+T|0]|0;a[A+13|0]=E;a[A+12|0]=E;E=a[W+(T+V)|0]|0;a[A+15|0]=E;a[A+14|0]=E;E=a[X+T|0]|0;a[A+17|0]=E;a[A+16|0]=E;E=d[F+3|0]|0;T=a[U+E|0]|0;a[A+19|0]=T;a[A+18|0]=T;T=a[W+(E+V)|0]|0;a[A+21|0]=T;a[A+20|0]=T;T=a[X+E|0]|0;a[A+23|0]=T;a[A+22|0]=T;T=d[B+2|0]|0;E=a[U+T|0]|0;a[x+13|0]=E;a[x+12|0]=E;E=a[W+(T+V)|0]|0;a[x+15|0]=E;a[x+14|0]=E;E=a[X+T|0]|0;a[x+17|0]=E;a[x+16|0]=E;E=d[B+3|0]|0;T=a[U+E|0]|0;a[x+19|0]=T;a[x+18|0]=T;T=a[W+(E+V)|0]|0;a[x+21|0]=T;a[x+20|0]=T;T=a[X+E|0]|0;a[x+23|0]=T;a[x+22|0]=T;T=(d[I+2|0]|0)+128|0;E=c[b+4352+(T<<2)>>2]|0;X=(d[J+2|0]|0)+128|0;V=c[b+6400+(X<<2)>>2]|0;W=c[b+2304+(T<<2)>>2]|0;T=c[b+8448+(X<<2)>>2]|0;X=d[B+4|0]|0;U=a[T+X|0]|0;a[x+25|0]=U;a[x+24|0]=U;U=a[V+(X+W)|0]|0;a[x+27|0]=U;a[x+26|0]=U;U=a[E+X|0]|0;a[x+29|0]=U;a[x+28|0]=U;U=d[B+5|0]|0;X=a[T+U|0]|0;a[x+31|0]=X;a[x+30|0]=X;X=a[V+(U+W)|0]|0;a[x+33|0]=X;a[x+32|0]=X;X=a[E+U|0]|0;a[x+35|0]=X;a[x+34|0]=X;X=d[F+4|0]|0;U=a[T+X|0]|0;a[A+25|0]=U;a[A+24|0]=U;U=a[V+(X+W)|0]|0;a[A+27|0]=U;a[A+26|0]=U;U=a[E+X|0]|0;a[A+29|0]=U;a[A+28|0]=U;U=d[F+5|0]|0;X=a[T+U|0]|0;a[A+31|0]=X;a[A+30|0]=X;X=a[V+(U+W)|0]|0;a[A+33|0]=X;a[A+32|0]=X;X=a[E+U|0]|0;a[A+35|0]=X;a[A+34|0]=X;X=(d[I+3|0]|0)+128|0;U=c[b+4352+(X<<2)>>2]|0;E=(d[J+3|0]|0)+128|0;W=c[b+6400+(E<<2)>>2]|0;V=c[b+2304+(X<<2)>>2]|0;X=c[b+8448+(E<<2)>>2]|0;E=d[F+6|0]|0;T=a[X+E|0]|0;a[A+37|0]=T;a[A+36|0]=T;T=a[W+(E+V)|0]|0;a[A+39|0]=T;a[A+38|0]=T;T=a[U+E|0]|0;a[A+41|0]=T;a[A+40|0]=T;T=d[F+7|0]|0;E=a[X+T|0]|0;a[A+43|0]=E;a[A+42|0]=E;E=a[W+(T+V)|0]|0;a[A+45|0]=E;a[A+44|0]=E;E=a[U+T|0]|0;a[A+47|0]=E;a[A+46|0]=E;E=d[B+6|0]|0;T=a[X+E|0]|0;a[x+37|0]=T;a[x+36|0]=T;T=a[W+(E+V)|0]|0;a[x+39|0]=T;a[x+38|0]=T;T=a[U+E|0]|0;a[x+41|0]=T;a[x+40|0]=T;T=d[B+7|0]|0;E=a[X+T|0]|0;a[x+43|0]=E;a[x+42|0]=E;E=a[W+(T+V)|0]|0;a[x+45|0]=E;a[x+44|0]=E;E=a[U+T|0]|0;a[x+47|0]=E;a[x+46|0]=E;if((w|0)==0){break}else{I=I+4|0;D=w;J=J+4|0;F=F+8|0;B=B+8|0;A=A+48|0;x=x+48|0}}K=G+z|0;L=C+H|0;M=u+v|0;N=u+y|0;O=t+R|0;P=t+S|0;Q=c[o>>2]|0}if((Q&4|0)==0){Y=P;Z=O;_=N;$=M;aa=L;ca=K;da=Q}else{x=(d[K]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[L]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[N]|0;D=a[x+B|0]|0;a[P+1|0]=D;a[P]=D;D=a[F+(B+J)|0]|0;a[P+3|0]=D;a[P+2|0]=D;D=a[A+B|0]|0;a[P+5|0]=D;a[P+4|0]=D;D=d[N+1|0]|0;B=a[x+D|0]|0;a[P+7|0]=B;a[P+6|0]=B;B=a[F+(D+J)|0]|0;a[P+9|0]=B;a[P+8|0]=B;B=a[A+D|0]|0;a[P+11|0]=B;a[P+10|0]=B;B=d[M]|0;D=a[x+B|0]|0;a[O+1|0]=D;a[O]=D;D=a[F+(B+J)|0]|0;a[O+3|0]=D;a[O+2|0]=D;D=a[A+B|0]|0;a[O+5|0]=D;a[O+4|0]=D;D=d[M+1|0]|0;B=a[x+D|0]|0;a[O+7|0]=B;a[O+6|0]=B;B=a[F+(D+J)|0]|0;a[O+9|0]=B;a[O+8|0]=B;B=a[A+D|0]|0;a[O+11|0]=B;a[O+10|0]=B;B=(d[K+1|0]|0)+128|0;D=c[b+4352+(B<<2)>>2]|0;A=(d[L+1|0]|0)+128|0;J=c[b+6400+(A<<2)>>2]|0;F=c[b+2304+(B<<2)>>2]|0;B=c[b+8448+(A<<2)>>2]|0;A=d[M+2|0]|0;x=a[B+A|0]|0;a[O+13|0]=x;a[O+12|0]=x;x=a[J+(A+F)|0]|0;a[O+15|0]=x;a[O+14|0]=x;x=a[D+A|0]|0;a[O+17|0]=x;a[O+16|0]=x;x=d[M+3|0]|0;A=a[B+x|0]|0;a[O+19|0]=A;a[O+18|0]=A;A=a[J+(x+F)|0]|0;a[O+21|0]=A;a[O+20|0]=A;A=a[D+x|0]|0;a[O+23|0]=A;a[O+22|0]=A;A=d[N+2|0]|0;x=a[B+A|0]|0;a[P+13|0]=x;a[P+12|0]=x;x=a[J+(A+F)|0]|0;a[P+15|0]=x;a[P+14|0]=x;x=a[D+A|0]|0;a[P+17|0]=x;a[P+16|0]=x;x=d[N+3|0]|0;A=a[B+x|0]|0;a[P+19|0]=A;a[P+18|0]=A;A=a[J+(x+F)|0]|0;a[P+21|0]=A;a[P+20|0]=A;A=a[D+x|0]|0;a[P+23|0]=A;a[P+22|0]=A;Y=P+24|0;Z=O+24|0;_=N+4|0;$=M+4|0;aa=L+2|0;ca=K+2|0;da=c[o>>2]|0}if((da&2|0)!=0){A=(d[ca]|0)+128|0;x=c[b+4352+(A<<2)>>2]|0;D=(d[aa]|0)+128|0;F=c[b+6400+(D<<2)>>2]|0;J=c[b+2304+(A<<2)>>2]|0;A=c[b+8448+(D<<2)>>2]|0;D=d[_]|0;B=a[A+D|0]|0;a[Y+1|0]=B;a[Y]=B;B=a[F+(D+J)|0]|0;a[Y+3|0]=B;a[Y+2|0]=B;B=a[x+D|0]|0;a[Y+5|0]=B;a[Y+4|0]=B;B=d[_+1|0]|0;D=a[A+B|0]|0;a[Y+7|0]=D;a[Y+6|0]=D;D=a[F+(B+J)|0]|0;a[Y+9|0]=D;a[Y+8|0]=D;D=a[x+B|0]|0;a[Y+11|0]=D;a[Y+10|0]=D;D=d[$]|0;B=a[A+D|0]|0;a[Z+1|0]=B;a[Z]=B;B=a[F+(D+J)|0]|0;a[Z+3|0]=B;a[Z+2|0]=B;B=a[x+D|0]|0;a[Z+5|0]=B;a[Z+4|0]=B;B=d[$+1|0]|0;D=a[A+B|0]|0;a[Z+7|0]=D;a[Z+6|0]=D;D=a[F+(B+J)|0]|0;a[Z+9|0]=D;a[Z+8|0]=D;D=a[x+B|0]|0;a[Z+11|0]=D;a[Z+10|0]=D}D=s+2|0;if((D|0)>=(h|0)){break}p=p+2|0;q=q+2|0;r=r+2|0;s=D}return h|0}function Hsb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=g+1|0;q=g;r=1;s=0;while(1){t=c[i>>2]|0;u=s+g|0;v=c[j>>2]|0;w=t+(ba(v,u)|0)|0;x=t+(ba(v,u+1|0)|0)|0;u=c[e>>2]|0;y=c[f>>2]|0;z=ba(y,s)|0;A=u+z|0;B=u+(z+y)|0;C=c[k>>2]|0;D=s>>1;E=ba(c[l>>2]|0,D)|0;F=C+E|0;G=c[m>>2]|0;H=ba(c[n>>2]|0,D)|0;D=G+H|0;I=c[o>>2]|0;J=I>>3;if((J|0)==0){K=D;L=F;M=B;N=A;O=x;P=w;Q=I}else{I=J*48|0;R=(ba(v,p)|0)+I|0;S=(ba(v,q)|0)+I|0;I=J<<3;v=(ba(y,r)|0)+I|0;y=z+I|0;I=J<<2;z=H+I|0;H=E+I|0;I=D;D=J;J=F;F=B;B=A;A=x;x=w;while(1){w=D-1|0;E=(d[I]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B]|0;X=a[T+U|0]|0;a[x+1|0]=X;a[x]=X;X=a[V+(U+W)|0]|0;a[x+3|0]=X;a[x+2|0]=X;X=a[E+U|0]|0;a[x+5|0]=X;a[x+4|0]=X;X=d[B+1|0]|0;U=a[T+X|0]|0;a[x+7|0]=U;a[x+6|0]=U;U=a[V+(X+W)|0]|0;a[x+9|0]=U;a[x+8|0]=U;U=a[E+X|0]|0;a[x+11|0]=U;a[x+10|0]=U;U=d[F]|0;X=a[T+U|0]|0;a[A+1|0]=X;a[A]=X;X=a[V+(U+W)|0]|0;a[A+3|0]=X;a[A+2|0]=X;X=a[E+U|0]|0;a[A+5|0]=X;a[A+4|0]=X;X=d[F+1|0]|0;U=a[T+X|0]|0;a[A+7|0]=U;a[A+6|0]=U;U=a[V+(X+W)|0]|0;a[A+9|0]=U;a[A+8|0]=U;U=a[E+X|0]|0;a[A+11|0]=U;a[A+10|0]=U;U=(d[I+1|0]|0)+128|0;X=c[b+4352+(U<<2)>>2]|0;E=(d[J+1|0]|0)+128|0;W=c[b+6400+(E<<2)>>2]|0;V=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(E<<2)>>2]|0;E=d[F+2|0]|0;T=a[X+E|0]|0;a[A+13|0]=T;a[A+12|0]=T;T=a[W+(E+V)|0]|0;a[A+15|0]=T;a[A+14|0]=T;T=a[U+E|0]|0;a[A+17|0]=T;a[A+16|0]=T;T=d[F+3|0]|0;E=a[X+T|0]|0;a[A+19|0]=E;a[A+18|0]=E;E=a[W+(T+V)|0]|0;a[A+21|0]=E;a[A+20|0]=E;E=a[U+T|0]|0;a[A+23|0]=E;a[A+22|0]=E;E=d[B+2|0]|0;T=a[X+E|0]|0;a[x+13|0]=T;a[x+12|0]=T;T=a[W+(E+V)|0]|0;a[x+15|0]=T;a[x+14|0]=T;T=a[U+E|0]|0;a[x+17|0]=T;a[x+16|0]=T;T=d[B+3|0]|0;E=a[X+T|0]|0;a[x+19|0]=E;a[x+18|0]=E;E=a[W+(T+V)|0]|0;a[x+21|0]=E;a[x+20|0]=E;E=a[U+T|0]|0;a[x+23|0]=E;a[x+22|0]=E;E=(d[I+2|0]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J+2|0]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B+4|0]|0;X=a[T+U|0]|0;a[x+25|0]=X;a[x+24|0]=X;X=a[V+(U+W)|0]|0;a[x+27|0]=X;a[x+26|0]=X;X=a[E+U|0]|0;a[x+29|0]=X;a[x+28|0]=X;X=d[B+5|0]|0;U=a[T+X|0]|0;a[x+31|0]=U;a[x+30|0]=U;U=a[V+(X+W)|0]|0;a[x+33|0]=U;a[x+32|0]=U;U=a[E+X|0]|0;a[x+35|0]=U;a[x+34|0]=U;U=d[F+4|0]|0;X=a[T+U|0]|0;a[A+25|0]=X;a[A+24|0]=X;X=a[V+(U+W)|0]|0;a[A+27|0]=X;a[A+26|0]=X;X=a[E+U|0]|0;a[A+29|0]=X;a[A+28|0]=X;X=d[F+5|0]|0;U=a[T+X|0]|0;a[A+31|0]=U;a[A+30|0]=U;U=a[V+(X+W)|0]|0;a[A+33|0]=U;a[A+32|0]=U;U=a[E+X|0]|0;a[A+35|0]=U;a[A+34|0]=U;U=(d[I+3|0]|0)+128|0;X=c[b+4352+(U<<2)>>2]|0;E=(d[J+3|0]|0)+128|0;W=c[b+6400+(E<<2)>>2]|0;V=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(E<<2)>>2]|0;E=d[F+6|0]|0;T=a[X+E|0]|0;a[A+37|0]=T;a[A+36|0]=T;T=a[W+(E+V)|0]|0;a[A+39|0]=T;a[A+38|0]=T;T=a[U+E|0]|0;a[A+41|0]=T;a[A+40|0]=T;T=d[F+7|0]|0;E=a[X+T|0]|0;a[A+43|0]=E;a[A+42|0]=E;E=a[W+(T+V)|0]|0;a[A+45|0]=E;a[A+44|0]=E;E=a[U+T|0]|0;a[A+47|0]=E;a[A+46|0]=E;E=d[B+6|0]|0;T=a[X+E|0]|0;a[x+37|0]=T;a[x+36|0]=T;T=a[W+(E+V)|0]|0;a[x+39|0]=T;a[x+38|0]=T;T=a[U+E|0]|0;a[x+41|0]=T;a[x+40|0]=T;T=d[B+7|0]|0;E=a[X+T|0]|0;a[x+43|0]=E;a[x+42|0]=E;E=a[W+(T+V)|0]|0;a[x+45|0]=E;a[x+44|0]=E;E=a[U+T|0]|0;a[x+47|0]=E;a[x+46|0]=E;if((w|0)==0){break}else{I=I+4|0;D=w;J=J+4|0;F=F+8|0;B=B+8|0;A=A+48|0;x=x+48|0}}K=G+z|0;L=C+H|0;M=u+v|0;N=u+y|0;O=t+R|0;P=t+S|0;Q=c[o>>2]|0}if((Q&4|0)==0){Y=P;Z=O;_=N;$=M;aa=L;ca=K;da=Q}else{x=(d[K]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[L]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[N]|0;D=a[A+B|0]|0;a[P+1|0]=D;a[P]=D;D=a[F+(B+J)|0]|0;a[P+3|0]=D;a[P+2|0]=D;D=a[x+B|0]|0;a[P+5|0]=D;a[P+4|0]=D;D=d[N+1|0]|0;B=a[A+D|0]|0;a[P+7|0]=B;a[P+6|0]=B;B=a[F+(D+J)|0]|0;a[P+9|0]=B;a[P+8|0]=B;B=a[x+D|0]|0;a[P+11|0]=B;a[P+10|0]=B;B=d[M]|0;D=a[A+B|0]|0;a[O+1|0]=D;a[O]=D;D=a[F+(B+J)|0]|0;a[O+3|0]=D;a[O+2|0]=D;D=a[x+B|0]|0;a[O+5|0]=D;a[O+4|0]=D;D=d[M+1|0]|0;B=a[A+D|0]|0;a[O+7|0]=B;a[O+6|0]=B;B=a[F+(D+J)|0]|0;a[O+9|0]=B;a[O+8|0]=B;B=a[x+D|0]|0;a[O+11|0]=B;a[O+10|0]=B;B=(d[K+1|0]|0)+128|0;D=c[b+4352+(B<<2)>>2]|0;x=(d[L+1|0]|0)+128|0;J=c[b+6400+(x<<2)>>2]|0;F=c[b+2304+(B<<2)>>2]|0;B=c[b+8448+(x<<2)>>2]|0;x=d[M+2|0]|0;A=a[D+x|0]|0;a[O+13|0]=A;a[O+12|0]=A;A=a[J+(x+F)|0]|0;a[O+15|0]=A;a[O+14|0]=A;A=a[B+x|0]|0;a[O+17|0]=A;a[O+16|0]=A;A=d[M+3|0]|0;x=a[D+A|0]|0;a[O+19|0]=x;a[O+18|0]=x;x=a[J+(A+F)|0]|0;a[O+21|0]=x;a[O+20|0]=x;x=a[B+A|0]|0;a[O+23|0]=x;a[O+22|0]=x;x=d[N+2|0]|0;A=a[D+x|0]|0;a[P+13|0]=A;a[P+12|0]=A;A=a[J+(x+F)|0]|0;a[P+15|0]=A;a[P+14|0]=A;A=a[B+x|0]|0;a[P+17|0]=A;a[P+16|0]=A;A=d[N+3|0]|0;x=a[D+A|0]|0;a[P+19|0]=x;a[P+18|0]=x;x=a[J+(A+F)|0]|0;a[P+21|0]=x;a[P+20|0]=x;x=a[B+A|0]|0;a[P+23|0]=x;a[P+22|0]=x;Y=P+24|0;Z=O+24|0;_=N+4|0;$=M+4|0;aa=L+2|0;ca=K+2|0;da=c[o>>2]|0}if((da&2|0)!=0){x=(d[ca]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[aa]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[_]|0;D=a[A+B|0]|0;a[Y+1|0]=D;a[Y]=D;D=a[F+(B+J)|0]|0;a[Y+3|0]=D;a[Y+2|0]=D;D=a[x+B|0]|0;a[Y+5|0]=D;a[Y+4|0]=D;D=d[_+1|0]|0;B=a[A+D|0]|0;a[Y+7|0]=B;a[Y+6|0]=B;B=a[F+(D+J)|0]|0;a[Y+9|0]=B;a[Y+8|0]=B;B=a[x+D|0]|0;a[Y+11|0]=B;a[Y+10|0]=B;B=d[$]|0;D=a[A+B|0]|0;a[Z+1|0]=D;a[Z]=D;D=a[F+(B+J)|0]|0;a[Z+3|0]=D;a[Z+2|0]=D;D=a[x+B|0]|0;a[Z+5|0]=D;a[Z+4|0]=D;D=d[$+1|0]|0;B=a[A+D|0]|0;a[Z+7|0]=B;a[Z+6|0]=B;B=a[F+(D+J)|0]|0;a[Z+9|0]=B;a[Z+8|0]=B;B=a[x+D|0]|0;a[Z+11|0]=B;a[Z+10|0]=B}B=s+2|0;if((B|0)>=(h|0)){break}p=p+2|0;q=q+2|0;r=r+2|0;s=B}return h|0}function Isb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;if((g|0)<=0){return g|0}j=e+4|0;k=e+8|0;l=a+19608|0;m=e+12|0;n=c[h>>2]|0;h=c[b>>2]|0;o=c[b+4>>2]|0;p=c[b+8>>2]|0;q=c[b+12>>2]|0;b=f+1|0;r=f;s=1;t=0;while(1){u=t+f|0;v=c[i>>2]|0;w=n+(ba(v,u)|0)|0;x=n+(ba(v,u+1|0)|0)|0;u=c[e>>2]|0;y=ba(u,t)|0;z=h+y|0;A=h+(y+u)|0;B=t>>1;C=ba(c[j>>2]|0,B)|0;D=o+C|0;E=ba(c[k>>2]|0,B)|0;B=p+E|0;F=c[l>>2]|0;G=F>>3;H=c[m>>2]|0;I=ba(H,t)|0;J=q+I|0;K=q+(I+H)|0;if((G|0)==0){L=B;M=J;N=K;O=D;P=A;Q=z;R=x;S=w;T=F}else{F=G<<5;U=n+((ba(v,b)|0)+F)|0;V=n+((ba(v,r)|0)+F)|0;F=G<<3;v=(ba(u,s)|0)+F|0;u=y+F|0;y=G<<2;W=E+y|0;E=C+y|0;y=(ba(H,s)|0)+F|0;H=I+F|0;F=B;B=J;J=K;K=G;G=D;D=A;A=z;z=x;x=w;while(1){w=K-1|0;I=(d[F]|0)+128|0;C=c[a+4352+(I<<2)>>2]|0;X=(d[G]|0)+128|0;Y=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(I<<2)>>2]|0)|0;I=c[a+8448+(X<<2)>>2]|0;X=d[A]|0;c[x>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[B]|0);X=d[A+1|0]|0;c[x+4>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[B+1|0]|0);X=d[D]|0;c[z>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[J]|0);X=d[D+1|0]|0;c[z+4>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[J+1|0]|0);X=(d[F+1|0]|0)+128|0;I=c[a+4352+(X<<2)>>2]|0;C=(d[G+1|0]|0)+128|0;Y=(c[a+6400+(C<<2)>>2]|0)+(c[a+2304+(X<<2)>>2]|0)|0;X=c[a+8448+(C<<2)>>2]|0;C=d[D+2|0]|0;c[z+8>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+(d[J+2|0]|0);C=d[D+3|0]|0;c[z+12>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+(d[J+3|0]|0);C=d[A+2|0]|0;c[x+8>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+(d[B+2|0]|0);C=d[A+3|0]|0;c[x+12>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+(d[B+3|0]|0);C=(d[F+2|0]|0)+128|0;X=c[a+4352+(C<<2)>>2]|0;I=(d[G+2|0]|0)+128|0;Y=(c[a+6400+(I<<2)>>2]|0)+(c[a+2304+(C<<2)>>2]|0)|0;C=c[a+8448+(I<<2)>>2]|0;I=d[A+4|0]|0;c[x+16>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+(d[B+4|0]|0);I=d[A+5|0]|0;c[x+20>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+(d[B+5|0]|0);I=d[D+4|0]|0;c[z+16>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+(d[J+4|0]|0);I=d[D+5|0]|0;c[z+20>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+(d[J+5|0]|0);I=(d[F+3|0]|0)+128|0;C=c[a+4352+(I<<2)>>2]|0;X=(d[G+3|0]|0)+128|0;Y=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(I<<2)>>2]|0)|0;I=c[a+8448+(X<<2)>>2]|0;X=d[D+6|0]|0;c[z+24>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[J+6|0]|0);X=d[D+7|0]|0;c[z+28>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[J+7|0]|0);X=d[A+6|0]|0;c[x+24>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[B+6|0]|0);X=d[A+7|0]|0;c[x+28>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[B+7|0]|0);if((w|0)==0){break}else{F=F+4|0;B=B+8|0;J=J+8|0;K=w;G=G+4|0;D=D+8|0;A=A+8|0;z=z+32|0;x=x+32|0}}L=p+W|0;M=q+H|0;N=q+y|0;O=o+E|0;P=h+v|0;Q=h+u|0;R=U;S=V;T=c[l>>2]|0}if((T&4|0)==0){Z=S;_=R;$=Q;aa=P;ca=O;da=N;ea=M;fa=L;ga=T}else{x=(d[L]|0)+128|0;z=c[a+4352+(x<<2)>>2]|0;A=(d[O]|0)+128|0;D=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(A<<2)>>2]|0;A=d[Q]|0;c[S>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+(d[M]|0);A=d[Q+1|0]|0;c[S+4>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+(d[M+1|0]|0);A=d[P]|0;c[R>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+(d[N]|0);A=d[P+1|0]|0;c[R+4>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+(d[N+1|0]|0);A=(d[L+1|0]|0)+128|0;x=c[a+4352+(A<<2)>>2]|0;z=(d[O+1|0]|0)+128|0;D=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;A=c[a+8448+(z<<2)>>2]|0;z=d[P+2|0]|0;c[R+8>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+(d[N+2|0]|0);z=d[P+3|0]|0;c[R+12>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+(d[N+3|0]|0);z=d[Q+2|0]|0;c[S+8>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+(d[M+2|0]|0);z=d[Q+3|0]|0;c[S+12>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+(d[M+3|0]|0);Z=S+16|0;_=R+16|0;$=Q+4|0;aa=P+4|0;ca=O+2|0;da=N+4|0;ea=M+4|0;fa=L+2|0;ga=c[l>>2]|0}if((ga&2|0)!=0){z=(d[fa]|0)+128|0;A=c[a+4352+(z<<2)>>2]|0;x=(d[ca]|0)+128|0;D=(c[a+6400+(x<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;z=c[a+8448+(x<<2)>>2]|0;x=d[$]|0;c[Z>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+(d[ea]|0);x=d[$+1|0]|0;c[Z+4>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+(d[ea+1|0]|0);x=d[aa]|0;c[_>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+(d[da]|0);x=d[aa+1|0]|0;c[_+4>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+(d[da+1|0]|0)}x=t+2|0;if((x|0)>=(g|0)){break}b=b+2|0;r=r+2|0;s=s+2|0;t=x}return g|0}function Jsb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;if((g|0)<=0){return g|0}j=e+4|0;k=e+8|0;l=a+19608|0;m=e+12|0;n=c[h>>2]|0;h=c[b>>2]|0;o=c[b+4>>2]|0;p=c[b+8>>2]|0;q=c[b+12>>2]|0;b=f+1|0;r=f;s=1;t=0;while(1){u=t+f|0;v=c[i>>2]|0;w=n+(ba(v,u)|0)|0;x=n+(ba(v,u+1|0)|0)|0;u=c[e>>2]|0;y=ba(u,t)|0;z=h+y|0;A=h+(y+u)|0;B=t>>1;C=ba(c[j>>2]|0,B)|0;D=o+C|0;E=ba(c[k>>2]|0,B)|0;B=p+E|0;F=c[l>>2]|0;G=F>>3;H=c[m>>2]|0;I=ba(H,t)|0;J=q+I|0;K=q+(I+H)|0;if((G|0)==0){L=B;M=J;N=K;O=D;P=A;Q=z;R=x;S=w;T=F}else{F=G<<5;U=n+((ba(v,b)|0)+F)|0;V=n+((ba(v,r)|0)+F)|0;F=G<<3;v=(ba(u,s)|0)+F|0;u=y+F|0;y=G<<2;W=E+y|0;E=C+y|0;y=(ba(H,s)|0)+F|0;H=I+F|0;F=B;B=J;J=K;K=G;G=D;D=A;A=z;z=x;x=w;while(1){w=K-1|0;I=(d[F]|0)+128|0;C=c[a+4352+(I<<2)>>2]|0;X=(d[G]|0)+128|0;Y=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(I<<2)>>2]|0)|0;I=c[a+8448+(X<<2)>>2]|0;X=d[A]|0;c[x>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[B]|0)<<24);X=d[A+1|0]|0;c[x+4>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[B+1|0]|0)<<24);X=d[D]|0;c[z>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[J]|0)<<24);X=d[D+1|0]|0;c[z+4>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[J+1|0]|0)<<24);X=(d[F+1|0]|0)+128|0;I=c[a+4352+(X<<2)>>2]|0;C=(d[G+1|0]|0)+128|0;Y=(c[a+6400+(C<<2)>>2]|0)+(c[a+2304+(X<<2)>>2]|0)|0;X=c[a+8448+(C<<2)>>2]|0;C=d[D+2|0]|0;c[z+8>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+((d[J+2|0]|0)<<24);C=d[D+3|0]|0;c[z+12>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+((d[J+3|0]|0)<<24);C=d[A+2|0]|0;c[x+8>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+((d[B+2|0]|0)<<24);C=d[A+3|0]|0;c[x+12>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+((d[B+3|0]|0)<<24);C=(d[F+2|0]|0)+128|0;X=c[a+4352+(C<<2)>>2]|0;I=(d[G+2|0]|0)+128|0;Y=(c[a+6400+(I<<2)>>2]|0)+(c[a+2304+(C<<2)>>2]|0)|0;C=c[a+8448+(I<<2)>>2]|0;I=d[A+4|0]|0;c[x+16>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+((d[B+4|0]|0)<<24);I=d[A+5|0]|0;c[x+20>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+((d[B+5|0]|0)<<24);I=d[D+4|0]|0;c[z+16>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+((d[J+4|0]|0)<<24);I=d[D+5|0]|0;c[z+20>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+((d[J+5|0]|0)<<24);I=(d[F+3|0]|0)+128|0;C=c[a+4352+(I<<2)>>2]|0;X=(d[G+3|0]|0)+128|0;Y=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(I<<2)>>2]|0)|0;I=c[a+8448+(X<<2)>>2]|0;X=d[D+6|0]|0;c[z+24>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[J+6|0]|0)<<24);X=d[D+7|0]|0;c[z+28>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[J+7|0]|0)<<24);X=d[A+6|0]|0;c[x+24>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[B+6|0]|0)<<24);X=d[A+7|0]|0;c[x+28>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[B+7|0]|0)<<24);if((w|0)==0){break}else{F=F+4|0;B=B+8|0;J=J+8|0;K=w;G=G+4|0;D=D+8|0;A=A+8|0;z=z+32|0;x=x+32|0}}L=p+W|0;M=q+H|0;N=q+y|0;O=o+E|0;P=h+v|0;Q=h+u|0;R=U;S=V;T=c[l>>2]|0}if((T&4|0)==0){Z=S;_=R;$=Q;aa=P;ca=O;da=N;ea=M;fa=L;ga=T}else{x=(d[L]|0)+128|0;z=c[a+4352+(x<<2)>>2]|0;A=(d[O]|0)+128|0;D=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(A<<2)>>2]|0;A=d[Q]|0;c[S>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+((d[M]|0)<<24);A=d[Q+1|0]|0;c[S+4>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+((d[M+1|0]|0)<<24);A=d[P]|0;c[R>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+((d[N]|0)<<24);A=d[P+1|0]|0;c[R+4>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+((d[N+1|0]|0)<<24);A=(d[L+1|0]|0)+128|0;x=c[a+4352+(A<<2)>>2]|0;z=(d[O+1|0]|0)+128|0;D=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;A=c[a+8448+(z<<2)>>2]|0;z=d[P+2|0]|0;c[R+8>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+((d[N+2|0]|0)<<24);z=d[P+3|0]|0;c[R+12>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+((d[N+3|0]|0)<<24);z=d[Q+2|0]|0;c[S+8>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+((d[M+2|0]|0)<<24);z=d[Q+3|0]|0;c[S+12>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+((d[M+3|0]|0)<<24);Z=S+16|0;_=R+16|0;$=Q+4|0;aa=P+4|0;ca=O+2|0;da=N+4|0;ea=M+4|0;fa=L+2|0;ga=c[l>>2]|0}if((ga&2|0)!=0){z=(d[fa]|0)+128|0;A=c[a+4352+(z<<2)>>2]|0;x=(d[ca]|0)+128|0;D=(c[a+6400+(x<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;z=c[a+8448+(x<<2)>>2]|0;x=d[$]|0;c[Z>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+((d[ea]|0)<<24);x=d[$+1|0]|0;c[Z+4>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+((d[ea+1|0]|0)<<24);x=d[aa]|0;c[_>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+((d[da]|0)<<24);x=d[aa+1|0]|0;c[_+4>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+((d[da+1|0]|0)<<24)}x=t+2|0;if((x|0)>=(g|0)){break}b=b+2|0;r=r+2|0;s=s+2|0;t=x}return g|0}function Ksb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;if((c[a+56>>2]|0)==4){j=e+4|0;c[j>>2]=c[j>>2]<<1;j=e+8|0;c[j>>2]=c[j>>2]<<1}if((g|0)<=0){return g|0}j=e+4|0;k=e+8|0;l=a+19608|0;m=c[h>>2]|0;h=c[b>>2]|0;n=c[b+4>>2]|0;o=c[b+8>>2]|0;b=f+1|0;p=f;q=1;r=0;while(1){s=r+f|0;t=c[i>>2]|0;u=m+(ba(t,s)|0)|0;v=m+(ba(t,s+1|0)|0)|0;s=c[e>>2]|0;w=ba(s,r)|0;x=h+w|0;y=h+(w+s)|0;z=r>>1;A=ba(c[j>>2]|0,z)|0;B=n+A|0;C=ba(c[k>>2]|0,z)|0;z=o+C|0;D=c[l>>2]|0;E=D>>3;if((E|0)==0){F=z;G=B;H=y;I=x;J=v;K=u;L=D}else{D=E<<5;M=m+((ba(t,b)|0)+D)|0;N=m+((ba(t,p)|0)+D)|0;D=E<<3;t=(ba(s,q)|0)+D|0;s=w+D|0;D=E<<2;w=C+D|0;C=A+D|0;D=z;z=E;E=B;B=y;y=x;x=v;v=u;while(1){u=z-1|0;A=(d[D]|0)+128|0;O=c[a+4352+(A<<2)>>2]|0;P=(d[E]|0)+128|0;Q=(c[a+6400+(P<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;A=c[a+8448+(P<<2)>>2]|0;P=d[y]|0;c[v>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[y+1|0]|0;c[v+4>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[B]|0;c[x>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[B+1|0]|0;c[x+4>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=(d[D+1|0]|0)+128|0;A=c[a+4352+(P<<2)>>2]|0;O=(d[E+1|0]|0)+128|0;Q=(c[a+6400+(O<<2)>>2]|0)+(c[a+2304+(P<<2)>>2]|0)|0;P=c[a+8448+(O<<2)>>2]|0;O=d[B+2|0]|0;c[x+8>>2]=(c[Q+(O<<2)>>2]|0)+(c[A+(O<<2)>>2]|0)+(c[P+(O<<2)>>2]|0);O=d[B+3|0]|0;c[x+12>>2]=(c[Q+(O<<2)>>2]|0)+(c[A+(O<<2)>>2]|0)+(c[P+(O<<2)>>2]|0);O=d[y+2|0]|0;c[v+8>>2]=(c[Q+(O<<2)>>2]|0)+(c[A+(O<<2)>>2]|0)+(c[P+(O<<2)>>2]|0);O=d[y+3|0]|0;c[v+12>>2]=(c[Q+(O<<2)>>2]|0)+(c[A+(O<<2)>>2]|0)+(c[P+(O<<2)>>2]|0);O=(d[D+2|0]|0)+128|0;P=c[a+4352+(O<<2)>>2]|0;A=(d[E+2|0]|0)+128|0;Q=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(O<<2)>>2]|0)|0;O=c[a+8448+(A<<2)>>2]|0;A=d[y+4|0]|0;c[v+16>>2]=(c[Q+(A<<2)>>2]|0)+(c[P+(A<<2)>>2]|0)+(c[O+(A<<2)>>2]|0);A=d[y+5|0]|0;c[v+20>>2]=(c[Q+(A<<2)>>2]|0)+(c[P+(A<<2)>>2]|0)+(c[O+(A<<2)>>2]|0);A=d[B+4|0]|0;c[x+16>>2]=(c[Q+(A<<2)>>2]|0)+(c[P+(A<<2)>>2]|0)+(c[O+(A<<2)>>2]|0);A=d[B+5|0]|0;c[x+20>>2]=(c[Q+(A<<2)>>2]|0)+(c[P+(A<<2)>>2]|0)+(c[O+(A<<2)>>2]|0);A=(d[D+3|0]|0)+128|0;O=c[a+4352+(A<<2)>>2]|0;P=(d[E+3|0]|0)+128|0;Q=(c[a+6400+(P<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;A=c[a+8448+(P<<2)>>2]|0;P=d[B+6|0]|0;c[x+24>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[B+7|0]|0;c[x+28>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[y+6|0]|0;c[v+24>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[y+7|0]|0;c[v+28>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);if((u|0)==0){break}else{D=D+4|0;z=u;E=E+4|0;B=B+8|0;y=y+8|0;x=x+32|0;v=v+32|0}}F=o+w|0;G=n+C|0;H=h+t|0;I=h+s|0;J=M;K=N;L=c[l>>2]|0}if((L&4|0)==0){R=K;S=J;T=I;U=H;V=G;W=F;X=L}else{v=(d[F]|0)+128|0;x=c[a+4352+(v<<2)>>2]|0;y=(d[G]|0)+128|0;B=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(v<<2)>>2]|0)|0;v=c[a+8448+(y<<2)>>2]|0;y=d[I]|0;c[K>>2]=(c[B+(y<<2)>>2]|0)+(c[x+(y<<2)>>2]|0)+(c[v+(y<<2)>>2]|0);y=d[I+1|0]|0;c[K+4>>2]=(c[B+(y<<2)>>2]|0)+(c[x+(y<<2)>>2]|0)+(c[v+(y<<2)>>2]|0);y=d[H]|0;c[J>>2]=(c[B+(y<<2)>>2]|0)+(c[x+(y<<2)>>2]|0)+(c[v+(y<<2)>>2]|0);y=d[H+1|0]|0;c[J+4>>2]=(c[B+(y<<2)>>2]|0)+(c[x+(y<<2)>>2]|0)+(c[v+(y<<2)>>2]|0);y=(d[F+1|0]|0)+128|0;v=c[a+4352+(y<<2)>>2]|0;x=(d[G+1|0]|0)+128|0;B=(c[a+6400+(x<<2)>>2]|0)+(c[a+2304+(y<<2)>>2]|0)|0;y=c[a+8448+(x<<2)>>2]|0;x=d[H+2|0]|0;c[J+8>>2]=(c[B+(x<<2)>>2]|0)+(c[v+(x<<2)>>2]|0)+(c[y+(x<<2)>>2]|0);x=d[H+3|0]|0;c[J+12>>2]=(c[B+(x<<2)>>2]|0)+(c[v+(x<<2)>>2]|0)+(c[y+(x<<2)>>2]|0);x=d[I+2|0]|0;c[K+8>>2]=(c[B+(x<<2)>>2]|0)+(c[v+(x<<2)>>2]|0)+(c[y+(x<<2)>>2]|0);x=d[I+3|0]|0;c[K+12>>2]=(c[B+(x<<2)>>2]|0)+(c[v+(x<<2)>>2]|0)+(c[y+(x<<2)>>2]|0);R=K+16|0;S=J+16|0;T=I+4|0;U=H+4|0;V=G+2|0;W=F+2|0;X=c[l>>2]|0}if((X&2|0)!=0){x=(d[W]|0)+128|0;y=c[a+4352+(x<<2)>>2]|0;v=(d[V]|0)+128|0;B=(c[a+6400+(v<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(v<<2)>>2]|0;v=d[T]|0;c[R>>2]=(c[B+(v<<2)>>2]|0)+(c[y+(v<<2)>>2]|0)+(c[x+(v<<2)>>2]|0);v=d[T+1|0]|0;c[R+4>>2]=(c[B+(v<<2)>>2]|0)+(c[y+(v<<2)>>2]|0)+(c[x+(v<<2)>>2]|0);v=d[U]|0;c[S>>2]=(c[B+(v<<2)>>2]|0)+(c[y+(v<<2)>>2]|0)+(c[x+(v<<2)>>2]|0);v=d[U+1|0]|0;c[S+4>>2]=(c[B+(v<<2)>>2]|0)+(c[y+(v<<2)>>2]|0)+(c[x+(v<<2)>>2]|0)}v=r+2|0;if((v|0)>=(g|0)){break}b=b+2|0;p=p+2|0;q=q+2|0;r=v}return g|0}function Lsb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=g+1|0;q=g;r=1;s=0;while(1){t=c[i>>2]|0;u=s+g|0;v=c[j>>2]|0;w=t+(ba(v,u)|0)|0;x=t+(ba(v,u+1|0)|0)|0;u=c[e>>2]|0;y=c[f>>2]|0;z=ba(y,s)|0;A=u+z|0;B=u+(z+y)|0;C=c[k>>2]|0;D=s>>1;E=ba(c[l>>2]|0,D)|0;F=C+E|0;G=c[m>>2]|0;H=ba(c[n>>2]|0,D)|0;D=G+H|0;I=c[o>>2]|0;J=I>>3;if((J|0)==0){K=D;L=F;M=B;N=A;O=x;P=w;Q=I}else{I=J*24|0;R=(ba(v,p)|0)+I|0;S=(ba(v,q)|0)+I|0;I=J<<3;v=(ba(y,r)|0)+I|0;y=z+I|0;I=J<<2;z=H+I|0;H=E+I|0;I=D;D=J;J=F;F=B;B=A;A=x;x=w;while(1){w=D-1|0;E=(d[I]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B]|0;a[x]=a[T+U|0]|0;a[x+1|0]=a[V+(U+W)|0]|0;a[x+2|0]=a[E+U|0]|0;U=d[B+1|0]|0;a[x+3|0]=a[T+U|0]|0;a[x+4|0]=a[V+(U+W)|0]|0;a[x+5|0]=a[E+U|0]|0;U=d[F]|0;a[A]=a[T+U|0]|0;a[A+1|0]=a[V+(U+W)|0]|0;a[A+2|0]=a[E+U|0]|0;U=d[F+1|0]|0;a[A+3|0]=a[T+U|0]|0;a[A+4|0]=a[V+(U+W)|0]|0;a[A+5|0]=a[E+U|0]|0;U=(d[I+1|0]|0)+128|0;E=c[b+4352+(U<<2)>>2]|0;W=(d[J+1|0]|0)+128|0;V=c[b+6400+(W<<2)>>2]|0;T=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(W<<2)>>2]|0;W=d[F+2|0]|0;a[A+6|0]=a[E+W|0]|0;a[A+7|0]=a[V+(W+T)|0]|0;a[A+8|0]=a[U+W|0]|0;W=d[F+3|0]|0;a[A+9|0]=a[E+W|0]|0;a[A+10|0]=a[V+(W+T)|0]|0;a[A+11|0]=a[U+W|0]|0;W=d[B+2|0]|0;a[x+6|0]=a[E+W|0]|0;a[x+7|0]=a[V+(W+T)|0]|0;a[x+8|0]=a[U+W|0]|0;W=d[B+3|0]|0;a[x+9|0]=a[E+W|0]|0;a[x+10|0]=a[V+(W+T)|0]|0;a[x+11|0]=a[U+W|0]|0;W=(d[I+2|0]|0)+128|0;U=c[b+4352+(W<<2)>>2]|0;T=(d[J+2|0]|0)+128|0;V=c[b+6400+(T<<2)>>2]|0;E=c[b+2304+(W<<2)>>2]|0;W=c[b+8448+(T<<2)>>2]|0;T=d[B+4|0]|0;a[x+12|0]=a[U+T|0]|0;a[x+13|0]=a[V+(T+E)|0]|0;a[x+14|0]=a[W+T|0]|0;T=d[B+5|0]|0;a[x+15|0]=a[U+T|0]|0;a[x+16|0]=a[V+(T+E)|0]|0;a[x+17|0]=a[W+T|0]|0;T=d[F+4|0]|0;a[A+12|0]=a[U+T|0]|0;a[A+13|0]=a[V+(T+E)|0]|0;a[A+14|0]=a[W+T|0]|0;T=d[F+5|0]|0;a[A+15|0]=a[U+T|0]|0;a[A+16|0]=a[V+(T+E)|0]|0;a[A+17|0]=a[W+T|0]|0;T=(d[I+3|0]|0)+128|0;W=c[b+4352+(T<<2)>>2]|0;E=(d[J+3|0]|0)+128|0;V=c[b+6400+(E<<2)>>2]|0;U=c[b+2304+(T<<2)>>2]|0;T=c[b+8448+(E<<2)>>2]|0;E=d[F+6|0]|0;a[A+18|0]=a[W+E|0]|0;a[A+19|0]=a[V+(E+U)|0]|0;a[A+20|0]=a[T+E|0]|0;E=d[F+7|0]|0;a[A+21|0]=a[W+E|0]|0;a[A+22|0]=a[V+(E+U)|0]|0;a[A+23|0]=a[T+E|0]|0;E=d[B+6|0]|0;a[x+18|0]=a[W+E|0]|0;a[x+19|0]=a[V+(E+U)|0]|0;a[x+20|0]=a[T+E|0]|0;E=d[B+7|0]|0;a[x+21|0]=a[W+E|0]|0;a[x+22|0]=a[V+(E+U)|0]|0;a[x+23|0]=a[T+E|0]|0;if((w|0)==0){break}else{I=I+4|0;D=w;J=J+4|0;F=F+8|0;B=B+8|0;A=A+24|0;x=x+24|0}}K=G+z|0;L=C+H|0;M=u+v|0;N=u+y|0;O=t+R|0;P=t+S|0;Q=c[o>>2]|0}if((Q&4|0)==0){X=P;Y=O;Z=N;_=M;$=L;aa=K;ca=Q}else{x=(d[K]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[L]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[N]|0;a[P]=a[A+B|0]|0;a[P+1|0]=a[F+(B+J)|0]|0;a[P+2|0]=a[x+B|0]|0;B=d[N+1|0]|0;a[P+3|0]=a[A+B|0]|0;a[P+4|0]=a[F+(B+J)|0]|0;a[P+5|0]=a[x+B|0]|0;B=d[M]|0;a[O]=a[A+B|0]|0;a[O+1|0]=a[F+(B+J)|0]|0;a[O+2|0]=a[x+B|0]|0;B=d[M+1|0]|0;a[O+3|0]=a[A+B|0]|0;a[O+4|0]=a[F+(B+J)|0]|0;a[O+5|0]=a[x+B|0]|0;B=(d[K+1|0]|0)+128|0;x=c[b+4352+(B<<2)>>2]|0;J=(d[L+1|0]|0)+128|0;F=c[b+6400+(J<<2)>>2]|0;A=c[b+2304+(B<<2)>>2]|0;B=c[b+8448+(J<<2)>>2]|0;J=d[M+2|0]|0;a[O+6|0]=a[x+J|0]|0;a[O+7|0]=a[F+(J+A)|0]|0;a[O+8|0]=a[B+J|0]|0;J=d[M+3|0]|0;a[O+9|0]=a[x+J|0]|0;a[O+10|0]=a[F+(J+A)|0]|0;a[O+11|0]=a[B+J|0]|0;J=d[N+2|0]|0;a[P+6|0]=a[x+J|0]|0;a[P+7|0]=a[F+(J+A)|0]|0;a[P+8|0]=a[B+J|0]|0;J=d[N+3|0]|0;a[P+9|0]=a[x+J|0]|0;a[P+10|0]=a[F+(J+A)|0]|0;a[P+11|0]=a[B+J|0]|0;X=P+12|0;Y=O+12|0;Z=N+4|0;_=M+4|0;$=L+2|0;aa=K+2|0;ca=c[o>>2]|0}if((ca&2|0)!=0){J=(d[aa]|0)+128|0;B=c[b+4352+(J<<2)>>2]|0;A=(d[$]|0)+128|0;F=c[b+6400+(A<<2)>>2]|0;x=c[b+2304+(J<<2)>>2]|0;J=c[b+8448+(A<<2)>>2]|0;A=d[Z]|0;a[X]=a[B+A|0]|0;a[X+1|0]=a[F+(A+x)|0]|0;a[X+2|0]=a[J+A|0]|0;A=d[Z+1|0]|0;a[X+3|0]=a[B+A|0]|0;a[X+4|0]=a[F+(A+x)|0]|0;a[X+5|0]=a[J+A|0]|0;A=d[_]|0;a[Y]=a[B+A|0]|0;a[Y+1|0]=a[F+(A+x)|0]|0;a[Y+2|0]=a[J+A|0]|0;A=d[_+1|0]|0;a[Y+3|0]=a[B+A|0]|0;a[Y+4|0]=a[F+(A+x)|0]|0;a[Y+5|0]=a[J+A|0]|0}A=s+2|0;if((A|0)>=(h|0)){break}p=p+2|0;q=q+2|0;r=r+2|0;s=A}return h|0}function Msb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=g+1|0;q=g;r=1;s=0;while(1){t=c[i>>2]|0;u=s+g|0;v=c[j>>2]|0;w=t+(ba(v,u)|0)|0;x=t+(ba(v,u+1|0)|0)|0;u=c[e>>2]|0;y=c[f>>2]|0;z=ba(y,s)|0;A=u+z|0;B=u+(z+y)|0;C=c[k>>2]|0;D=s>>1;E=ba(c[l>>2]|0,D)|0;F=C+E|0;G=c[m>>2]|0;H=ba(c[n>>2]|0,D)|0;D=G+H|0;I=c[o>>2]|0;J=I>>3;if((J|0)==0){K=D;L=F;M=B;N=A;O=x;P=w;Q=I}else{I=J*24|0;R=(ba(v,p)|0)+I|0;S=(ba(v,q)|0)+I|0;I=J<<3;v=(ba(y,r)|0)+I|0;y=z+I|0;I=J<<2;z=H+I|0;H=E+I|0;I=D;D=J;J=F;F=B;B=A;A=x;x=w;while(1){w=D-1|0;E=(d[I]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B]|0;a[x]=a[E+U|0]|0;a[x+1|0]=a[V+(U+W)|0]|0;a[x+2|0]=a[T+U|0]|0;U=d[B+1|0]|0;a[x+3|0]=a[E+U|0]|0;a[x+4|0]=a[V+(U+W)|0]|0;a[x+5|0]=a[T+U|0]|0;U=d[F]|0;a[A]=a[E+U|0]|0;a[A+1|0]=a[V+(U+W)|0]|0;a[A+2|0]=a[T+U|0]|0;U=d[F+1|0]|0;a[A+3|0]=a[E+U|0]|0;a[A+4|0]=a[V+(U+W)|0]|0;a[A+5|0]=a[T+U|0]|0;U=(d[I+1|0]|0)+128|0;T=c[b+4352+(U<<2)>>2]|0;W=(d[J+1|0]|0)+128|0;V=c[b+6400+(W<<2)>>2]|0;E=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(W<<2)>>2]|0;W=d[F+2|0]|0;a[A+6|0]=a[U+W|0]|0;a[A+7|0]=a[V+(W+E)|0]|0;a[A+8|0]=a[T+W|0]|0;W=d[F+3|0]|0;a[A+9|0]=a[U+W|0]|0;a[A+10|0]=a[V+(W+E)|0]|0;a[A+11|0]=a[T+W|0]|0;W=d[B+2|0]|0;a[x+6|0]=a[U+W|0]|0;a[x+7|0]=a[V+(W+E)|0]|0;a[x+8|0]=a[T+W|0]|0;W=d[B+3|0]|0;a[x+9|0]=a[U+W|0]|0;a[x+10|0]=a[V+(W+E)|0]|0;a[x+11|0]=a[T+W|0]|0;W=(d[I+2|0]|0)+128|0;T=c[b+4352+(W<<2)>>2]|0;E=(d[J+2|0]|0)+128|0;V=c[b+6400+(E<<2)>>2]|0;U=c[b+2304+(W<<2)>>2]|0;W=c[b+8448+(E<<2)>>2]|0;E=d[B+4|0]|0;a[x+12|0]=a[W+E|0]|0;a[x+13|0]=a[V+(E+U)|0]|0;a[x+14|0]=a[T+E|0]|0;E=d[B+5|0]|0;a[x+15|0]=a[W+E|0]|0;a[x+16|0]=a[V+(E+U)|0]|0;a[x+17|0]=a[T+E|0]|0;E=d[F+4|0]|0;a[A+12|0]=a[W+E|0]|0;a[A+13|0]=a[V+(E+U)|0]|0;a[A+14|0]=a[T+E|0]|0;E=d[F+5|0]|0;a[A+15|0]=a[W+E|0]|0;a[A+16|0]=a[V+(E+U)|0]|0;a[A+17|0]=a[T+E|0]|0;E=(d[I+3|0]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J+3|0]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[F+6|0]|0;a[A+18|0]=a[E+U|0]|0;a[A+19|0]=a[V+(U+W)|0]|0;a[A+20|0]=a[T+U|0]|0;U=d[F+7|0]|0;a[A+21|0]=a[E+U|0]|0;a[A+22|0]=a[V+(U+W)|0]|0;a[A+23|0]=a[T+U|0]|0;U=d[B+6|0]|0;a[x+18|0]=a[E+U|0]|0;a[x+19|0]=a[V+(U+W)|0]|0;a[x+20|0]=a[T+U|0]|0;U=d[B+7|0]|0;a[x+21|0]=a[E+U|0]|0;a[x+22|0]=a[V+(U+W)|0]|0;a[x+23|0]=a[T+U|0]|0;if((w|0)==0){break}else{I=I+4|0;D=w;J=J+4|0;F=F+8|0;B=B+8|0;A=A+24|0;x=x+24|0}}K=G+z|0;L=C+H|0;M=u+v|0;N=u+y|0;O=t+R|0;P=t+S|0;Q=c[o>>2]|0}if((Q&4|0)==0){X=P;Y=O;Z=N;_=M;$=L;aa=K;ca=Q}else{x=(d[K]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[L]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[N]|0;a[P]=a[x+B|0]|0;a[P+1|0]=a[F+(B+J)|0]|0;a[P+2|0]=a[A+B|0]|0;B=d[N+1|0]|0;a[P+3|0]=a[x+B|0]|0;a[P+4|0]=a[F+(B+J)|0]|0;a[P+5|0]=a[A+B|0]|0;B=d[M]|0;a[O]=a[x+B|0]|0;a[O+1|0]=a[F+(B+J)|0]|0;a[O+2|0]=a[A+B|0]|0;B=d[M+1|0]|0;a[O+3|0]=a[x+B|0]|0;a[O+4|0]=a[F+(B+J)|0]|0;a[O+5|0]=a[A+B|0]|0;B=(d[K+1|0]|0)+128|0;A=c[b+4352+(B<<2)>>2]|0;J=(d[L+1|0]|0)+128|0;F=c[b+6400+(J<<2)>>2]|0;x=c[b+2304+(B<<2)>>2]|0;B=c[b+8448+(J<<2)>>2]|0;J=d[M+2|0]|0;a[O+6|0]=a[B+J|0]|0;a[O+7|0]=a[F+(J+x)|0]|0;a[O+8|0]=a[A+J|0]|0;J=d[M+3|0]|0;a[O+9|0]=a[B+J|0]|0;a[O+10|0]=a[F+(J+x)|0]|0;a[O+11|0]=a[A+J|0]|0;J=d[N+2|0]|0;a[P+6|0]=a[B+J|0]|0;a[P+7|0]=a[F+(J+x)|0]|0;a[P+8|0]=a[A+J|0]|0;J=d[N+3|0]|0;a[P+9|0]=a[B+J|0]|0;a[P+10|0]=a[F+(J+x)|0]|0;a[P+11|0]=a[A+J|0]|0;X=P+12|0;Y=O+12|0;Z=N+4|0;_=M+4|0;$=L+2|0;aa=K+2|0;ca=c[o>>2]|0}if((ca&2|0)!=0){J=(d[aa]|0)+128|0;A=c[b+4352+(J<<2)>>2]|0;x=(d[$]|0)+128|0;F=c[b+6400+(x<<2)>>2]|0;B=c[b+2304+(J<<2)>>2]|0;J=c[b+8448+(x<<2)>>2]|0;x=d[Z]|0;a[X]=a[J+x|0]|0;a[X+1|0]=a[F+(x+B)|0]|0;a[X+2|0]=a[A+x|0]|0;x=d[Z+1|0]|0;a[X+3|0]=a[J+x|0]|0;a[X+4|0]=a[F+(x+B)|0]|0;a[X+5|0]=a[A+x|0]|0;x=d[_]|0;a[Y]=a[J+x|0]|0;a[Y+1|0]=a[F+(x+B)|0]|0;a[Y+2|0]=a[A+x|0]|0;x=d[_+1|0]|0;a[Y+3|0]=a[J+x|0]|0;a[Y+4|0]=a[F+(x+B)|0]|0;a[Y+5|0]=a[A+x|0]|0}x=s+2|0;if((x|0)>=(h|0)){break}p=p+2|0;q=q+2|0;r=r+2|0;s=x}return h|0}function Nsb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;if((c[a+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=d[1233008]|0;p=d[1233032]|0;q=d[1233016]|0;r=d[1233009]|0;s=d[1233033]|0;t=d[1233017]|0;u=d[1233040]|0;v=d[1233024]|0;w=d[1233041]|0;x=d[1233025]|0;y=d[1233018]|0;z=d[1233042]|0;A=d[1233026]|0;B=d[1233019]|0;C=d[1233043]|0;D=d[1233027]|0;E=d[1233010]|0;F=d[1233034]|0;G=d[1233011]|0;H=d[1233035]|0;I=d[1233012]|0;J=d[1233036]|0;K=d[1233020]|0;L=d[1233013]|0;M=d[1233037]|0;N=d[1233021]|0;O=d[1233044]|0;P=d[1233028]|0;Q=d[1233045]|0;R=d[1233029]|0;S=d[1233022]|0;T=d[1233046]|0;U=d[1233030]|0;V=d[1233023]|0;W=d[1233047]|0;X=d[1233031]|0;Y=d[1233014]|0;Z=d[1233038]|0;_=d[1233015]|0;$=d[1233039]|0;aa=c[i>>2]|0;i=c[j>>2]|0;j=c[e>>2]|0;e=c[f>>2]|0;f=c[a+19608>>2]|0;ca=0;do{da=ca+g|0;ea=ba(e,ca)|0;fa=ca>>1;ga=f>>3;if((ga|0)!=0){ha=ba(i,da+1|0)|0;ia=ba(i,da)|0;da=ba(c[n>>2]|0,fa)|0;ja=ba(c[l>>2]|0,fa)|0;fa=(c[m>>2]|0)+da|0;da=ga;ga=(c[k>>2]|0)+ja|0;ja=j+(ea+e)|0;ka=j+ea|0;ea=aa+ha|0;ha=aa+ia|0;while(1){ia=da-1|0;la=(d[fa]|0)+128|0;ma=c[a+4352+(la<<2)>>2]|0;na=(d[ga]|0)+128|0;oa=(c[a+6400+(na<<2)>>2]|0)+(c[a+2304+(la<<2)>>2]|0)|0;la=c[a+8448+(na<<2)>>2]|0;na=d[ka]|0;b[ha>>1]=((b[oa+(p+na<<1)>>1]|0)+(b[ma+(o+na<<1)>>1]|0)&65535)+(b[la+(q+na<<1)>>1]|0);na=d[ka+1|0]|0;b[ha+2>>1]=((b[oa+(s+na<<1)>>1]|0)+(b[ma+(r+na<<1)>>1]|0)&65535)+(b[la+(t+na<<1)>>1]|0);na=d[ja]|0;b[ea>>1]=((b[oa+(u+na<<1)>>1]|0)+(b[ma+(q+na<<1)>>1]|0)&65535)+(b[la+(v+na<<1)>>1]|0);na=d[ja+1|0]|0;b[ea+2>>1]=((b[oa+(w+na<<1)>>1]|0)+(b[ma+(t+na<<1)>>1]|0)&65535)+(b[la+(x+na<<1)>>1]|0);na=(d[fa+1|0]|0)+128|0;la=c[a+4352+(na<<2)>>2]|0;ma=(d[ga+1|0]|0)+128|0;oa=(c[a+6400+(ma<<2)>>2]|0)+(c[a+2304+(na<<2)>>2]|0)|0;na=c[a+8448+(ma<<2)>>2]|0;ma=d[ja+2|0]|0;b[ea+4>>1]=((b[oa+(z+ma<<1)>>1]|0)+(b[la+(y+ma<<1)>>1]|0)&65535)+(b[na+(A+ma<<1)>>1]|0);ma=d[ja+3|0]|0;b[ea+6>>1]=((b[oa+(C+ma<<1)>>1]|0)+(b[la+(B+ma<<1)>>1]|0)&65535)+(b[na+(D+ma<<1)>>1]|0);ma=d[ka+2|0]|0;b[ha+4>>1]=((b[oa+(F+ma<<1)>>1]|0)+(b[la+(E+ma<<1)>>1]|0)&65535)+(b[na+(y+ma<<1)>>1]|0);ma=d[ka+3|0]|0;b[ha+6>>1]=((b[oa+(H+ma<<1)>>1]|0)+(b[la+(G+ma<<1)>>1]|0)&65535)+(b[na+(B+ma<<1)>>1]|0);ma=(d[fa+2|0]|0)+128|0;na=c[a+4352+(ma<<2)>>2]|0;la=(d[ga+2|0]|0)+128|0;oa=(c[a+6400+(la<<2)>>2]|0)+(c[a+2304+(ma<<2)>>2]|0)|0;ma=c[a+8448+(la<<2)>>2]|0;la=d[ka+4|0]|0;b[ha+8>>1]=((b[oa+(J+la<<1)>>1]|0)+(b[na+(I+la<<1)>>1]|0)&65535)+(b[ma+(K+la<<1)>>1]|0);la=d[ka+5|0]|0;b[ha+10>>1]=((b[oa+(M+la<<1)>>1]|0)+(b[na+(L+la<<1)>>1]|0)&65535)+(b[ma+(N+la<<1)>>1]|0);la=d[ja+4|0]|0;b[ea+8>>1]=((b[oa+(O+la<<1)>>1]|0)+(b[na+(K+la<<1)>>1]|0)&65535)+(b[ma+(P+la<<1)>>1]|0);la=d[ja+5|0]|0;b[ea+10>>1]=((b[oa+(Q+la<<1)>>1]|0)+(b[na+(N+la<<1)>>1]|0)&65535)+(b[ma+(R+la<<1)>>1]|0);la=(d[fa+3|0]|0)+128|0;ma=c[a+4352+(la<<2)>>2]|0;na=(d[ga+3|0]|0)+128|0;oa=(c[a+6400+(na<<2)>>2]|0)+(c[a+2304+(la<<2)>>2]|0)|0;la=c[a+8448+(na<<2)>>2]|0;na=d[ja+6|0]|0;b[ea+12>>1]=((b[oa+(T+na<<1)>>1]|0)+(b[ma+(S+na<<1)>>1]|0)&65535)+(b[la+(U+na<<1)>>1]|0);na=d[ja+7|0]|0;b[ea+14>>1]=((b[oa+(W+na<<1)>>1]|0)+(b[ma+(V+na<<1)>>1]|0)&65535)+(b[la+(X+na<<1)>>1]|0);na=d[ka+6|0]|0;b[ha+12>>1]=((b[oa+(Z+na<<1)>>1]|0)+(b[ma+(Y+na<<1)>>1]|0)&65535)+(b[la+(S+na<<1)>>1]|0);na=d[ka+7|0]|0;b[ha+14>>1]=((b[oa+($+na<<1)>>1]|0)+(b[ma+(_+na<<1)>>1]|0)&65535)+(b[la+(V+na<<1)>>1]|0);if((ia|0)==0){break}else{fa=fa+4|0;da=ia;ga=ga+4|0;ja=ja+8|0;ka=ka+8|0;ea=ea+16|0;ha=ha+16|0}}}ca=ca+2|0;}while((ca|0)<(h|0));return h|0}function Osb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;if((c[a+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=d[1233008]|0;p=d[1233009]|0;q=d[1233016]|0;r=d[1233017]|0;s=d[1233024]|0;t=d[1233025]|0;u=d[1233018]|0;v=d[1233019]|0;w=d[1233026]|0;x=d[1233027]|0;y=d[1233010]|0;z=d[1233011]|0;A=d[1233012]|0;B=d[1233013]|0;C=d[1233020]|0;D=d[1233021]|0;E=d[1233028]|0;F=d[1233029]|0;G=d[1233022]|0;H=d[1233023]|0;I=d[1233030]|0;J=d[1233031]|0;K=d[1233014]|0;L=d[1233015]|0;M=c[i>>2]|0;i=c[j>>2]|0;j=c[e>>2]|0;e=c[f>>2]|0;f=c[a+19608>>2]|0;N=0;do{O=N+g|0;P=ba(e,N)|0;Q=N>>1;R=f>>3;if((R|0)!=0){S=ba(i,O+1|0)|0;T=ba(i,O)|0;O=ba(c[n>>2]|0,Q)|0;U=ba(c[l>>2]|0,Q)|0;Q=(c[k>>2]|0)+U|0;U=(c[m>>2]|0)+O|0;O=R;R=j+(P+e)|0;V=j+P|0;P=M+S|0;S=M+T|0;while(1){T=O-1|0;W=(d[U]|0)+128|0;X=c[a+4352+(W<<2)>>2]|0;Y=(d[Q]|0)+128|0;Z=(c[a+6400+(Y<<2)>>2]|0)+(c[a+2304+(W<<2)>>2]|0)|0;W=c[a+8448+(Y<<2)>>2]|0;Y=d[V]|0;b[S>>1]=((b[Z+(p+Y<<1)>>1]|0)+(b[X+(o+Y<<1)>>1]|0)&65535)+(b[W+(q+Y<<1)>>1]|0);Y=d[V+1|0]|0;b[S+2>>1]=((b[Z+(o+Y<<1)>>1]|0)+(b[X+(p+Y<<1)>>1]|0)&65535)+(b[W+(r+Y<<1)>>1]|0);Y=d[R]|0;b[P>>1]=((b[Z+(r+Y<<1)>>1]|0)+(b[X+(q+Y<<1)>>1]|0)&65535)+(b[W+(s+Y<<1)>>1]|0);Y=d[R+1|0]|0;b[P+2>>1]=((b[Z+(q+Y<<1)>>1]|0)+(b[X+(r+Y<<1)>>1]|0)&65535)+(b[W+(t+Y<<1)>>1]|0);Y=(d[U+1|0]|0)+128|0;W=c[a+4352+(Y<<2)>>2]|0;X=(d[Q+1|0]|0)+128|0;Z=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(Y<<2)>>2]|0)|0;Y=c[a+8448+(X<<2)>>2]|0;X=d[R+2|0]|0;b[P+4>>1]=((b[Z+(v+X<<1)>>1]|0)+(b[W+(u+X<<1)>>1]|0)&65535)+(b[Y+(w+X<<1)>>1]|0);X=d[R+3|0]|0;b[P+6>>1]=((b[Z+(u+X<<1)>>1]|0)+(b[W+(v+X<<1)>>1]|0)&65535)+(b[Y+(x+X<<1)>>1]|0);X=d[V+2|0]|0;b[S+4>>1]=((b[Z+(z+X<<1)>>1]|0)+(b[W+(y+X<<1)>>1]|0)&65535)+(b[Y+(u+X<<1)>>1]|0);X=d[V+3|0]|0;b[S+6>>1]=((b[Z+(y+X<<1)>>1]|0)+(b[W+(z+X<<1)>>1]|0)&65535)+(b[Y+(v+X<<1)>>1]|0);X=(d[U+2|0]|0)+128|0;Y=c[a+4352+(X<<2)>>2]|0;W=(d[Q+2|0]|0)+128|0;Z=(c[a+6400+(W<<2)>>2]|0)+(c[a+2304+(X<<2)>>2]|0)|0;X=c[a+8448+(W<<2)>>2]|0;W=d[V+4|0]|0;b[S+8>>1]=((b[Z+(B+W<<1)>>1]|0)+(b[Y+(A+W<<1)>>1]|0)&65535)+(b[X+(C+W<<1)>>1]|0);W=d[V+5|0]|0;b[S+10>>1]=((b[Z+(A+W<<1)>>1]|0)+(b[Y+(B+W<<1)>>1]|0)&65535)+(b[X+(D+W<<1)>>1]|0);W=d[R+4|0]|0;b[P+8>>1]=((b[Z+(D+W<<1)>>1]|0)+(b[Y+(C+W<<1)>>1]|0)&65535)+(b[X+(E+W<<1)>>1]|0);W=d[R+5|0]|0;b[P+10>>1]=((b[Z+(C+W<<1)>>1]|0)+(b[Y+(D+W<<1)>>1]|0)&65535)+(b[X+(F+W<<1)>>1]|0);W=(d[U+3|0]|0)+128|0;X=c[a+4352+(W<<2)>>2]|0;Y=(d[Q+3|0]|0)+128|0;Z=(c[a+6400+(Y<<2)>>2]|0)+(c[a+2304+(W<<2)>>2]|0)|0;W=c[a+8448+(Y<<2)>>2]|0;Y=d[R+6|0]|0;b[P+12>>1]=((b[Z+(H+Y<<1)>>1]|0)+(b[X+(G+Y<<1)>>1]|0)&65535)+(b[W+(I+Y<<1)>>1]|0);Y=d[R+7|0]|0;b[P+14>>1]=((b[Z+(G+Y<<1)>>1]|0)+(b[X+(H+Y<<1)>>1]|0)&65535)+(b[W+(J+Y<<1)>>1]|0);Y=d[V+6|0]|0;b[S+12>>1]=((b[Z+(L+Y<<1)>>1]|0)+(b[X+(K+Y<<1)>>1]|0)&65535)+(b[W+(G+Y<<1)>>1]|0);Y=d[V+7|0]|0;b[S+14>>1]=((b[Z+(K+Y<<1)>>1]|0)+(b[X+(L+Y<<1)>>1]|0)&65535)+(b[W+(H+Y<<1)>>1]|0);if((T|0)==0){break}else{Q=Q+4|0;U=U+4|0;O=T;R=R+8|0;V=V+8|0;P=P+16|0;S=S+16|0}}}N=N+2|0;}while((N|0)<(h|0));return h|0}function Psb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;if((c[a+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=c[i>>2]|0;i=c[j>>2]|0;j=c[e>>2]|0;e=c[f>>2]|0;f=c[a+19608>>2]|0;p=0;do{q=p+g|0;r=ba(e,p)|0;s=p>>1;t=f>>3;if((t|0)!=0){u=ba(i,q+1|0)|0;v=ba(i,q)|0;q=ba(c[n>>2]|0,s)|0;w=ba(c[l>>2]|0,s)|0;s=p&2;x=d[1232968+(s<<3)|0]|0;y=d[1232969+(s<<3)|0]|0;z=d[1232976+(s<<3)|0]|0;A=d[1232977+(s<<3)|0]|0;B=d[1232978+(s<<3)|0]|0;C=d[1232979+(s<<3)|0]|0;D=d[1232970+(s<<3)|0]|0;E=d[1232971+(s<<3)|0]|0;F=d[1232972+(s<<3)|0]|0;G=d[1232973+(s<<3)|0]|0;H=d[1232980+(s<<3)|0]|0;I=d[1232981+(s<<3)|0]|0;J=d[1232982+(s<<3)|0]|0;K=d[1232983+(s<<3)|0]|0;L=d[1232974+(s<<3)|0]|0;M=d[1232975+(s<<3)|0]|0;s=j+(r+e)|0;N=(c[k>>2]|0)+w|0;w=(c[m>>2]|0)+q|0;q=t;t=j+r|0;r=o+u|0;u=o+v|0;while(1){v=q-1|0;O=(d[w]|0)+128|0;P=c[a+4352+(O<<2)>>2]|0;Q=(d[N]|0)+128|0;R=(c[a+6400+(Q<<2)>>2]|0)+(c[a+2304+(O<<2)>>2]|0)|0;O=c[a+8448+(Q<<2)>>2]|0;Q=x+(d[t]|0)|0;b[u>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=y+(d[t+1|0]|0)|0;b[u+2>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=z+(d[s]|0)|0;b[r>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=A+(d[s+1|0]|0)|0;b[r+2>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=(d[w+1|0]|0)+128|0;O=c[a+4352+(Q<<2)>>2]|0;P=(d[N+1|0]|0)+128|0;R=(c[a+6400+(P<<2)>>2]|0)+(c[a+2304+(Q<<2)>>2]|0)|0;Q=c[a+8448+(P<<2)>>2]|0;P=B+(d[s+2|0]|0)|0;b[r+4>>1]=((b[R+(P<<1)>>1]|0)+(b[O+(P<<1)>>1]|0)&65535)+(b[Q+(P<<1)>>1]|0);P=C+(d[s+3|0]|0)|0;b[r+6>>1]=((b[R+(P<<1)>>1]|0)+(b[O+(P<<1)>>1]|0)&65535)+(b[Q+(P<<1)>>1]|0);P=D+(d[t+2|0]|0)|0;b[u+4>>1]=((b[R+(P<<1)>>1]|0)+(b[O+(P<<1)>>1]|0)&65535)+(b[Q+(P<<1)>>1]|0);P=E+(d[t+3|0]|0)|0;b[u+6>>1]=((b[R+(P<<1)>>1]|0)+(b[O+(P<<1)>>1]|0)&65535)+(b[Q+(P<<1)>>1]|0);P=(d[w+2|0]|0)+128|0;Q=c[a+4352+(P<<2)>>2]|0;O=(d[N+2|0]|0)+128|0;R=(c[a+6400+(O<<2)>>2]|0)+(c[a+2304+(P<<2)>>2]|0)|0;P=c[a+8448+(O<<2)>>2]|0;O=F+(d[t+4|0]|0)|0;b[u+8>>1]=((b[R+(O<<1)>>1]|0)+(b[Q+(O<<1)>>1]|0)&65535)+(b[P+(O<<1)>>1]|0);O=G+(d[t+5|0]|0)|0;b[u+10>>1]=((b[R+(O<<1)>>1]|0)+(b[Q+(O<<1)>>1]|0)&65535)+(b[P+(O<<1)>>1]|0);O=H+(d[s+4|0]|0)|0;b[r+8>>1]=((b[R+(O<<1)>>1]|0)+(b[Q+(O<<1)>>1]|0)&65535)+(b[P+(O<<1)>>1]|0);O=I+(d[s+5|0]|0)|0;b[r+10>>1]=((b[R+(O<<1)>>1]|0)+(b[Q+(O<<1)>>1]|0)&65535)+(b[P+(O<<1)>>1]|0);O=(d[w+3|0]|0)+128|0;P=c[a+4352+(O<<2)>>2]|0;Q=(d[N+3|0]|0)+128|0;R=(c[a+6400+(Q<<2)>>2]|0)+(c[a+2304+(O<<2)>>2]|0)|0;O=c[a+8448+(Q<<2)>>2]|0;Q=J+(d[s+6|0]|0)|0;b[r+12>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=K+(d[s+7|0]|0)|0;b[r+14>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=L+(d[t+6|0]|0)|0;b[u+12>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=M+(d[t+7|0]|0)|0;b[u+14>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);if((v|0)==0){break}else{s=s+8|0;N=N+4|0;w=w+4|0;q=v;t=t+8|0;r=r+16|0;u=u+16|0}}}p=p+2|0;}while((p|0)<(h|0));return h|0}function Qsb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=0;do{q=c[i>>2]|0;r=p+g|0;s=c[j>>2]|0;t=c[e>>2]|0;u=c[f>>2]|0;v=ba(u,p)|0;w=p>>1;x=c[o>>2]>>3;if((x|0)!=0){y=ba(c[n>>2]|0,w)|0;z=ba(c[l>>2]|0,w)|0;w=q+(ba(s,r+1|0)|0)|0;A=q+(ba(s,r)|0)|0;r=p&6;s=d[1232752+(r<<3)|0]|0;q=d[1232680+(r<<3)|0]|0;B=d[1232753+(r<<3)|0]|0;C=d[1232681+(r<<3)|0]|0;D=d[1232760+(r<<3)|0]|0;E=d[1232688+(r<<3)|0]|0;F=d[1232761+(r<<3)|0]|0;G=d[1232689+(r<<3)|0]|0;H=d[1232762+(r<<3)|0]|0;I=d[1232690+(r<<3)|0]|0;J=d[1232763+(r<<3)|0]|0;K=d[1232691+(r<<3)|0]|0;L=d[1232754+(r<<3)|0]|0;M=d[1232682+(r<<3)|0]|0;N=d[1232755+(r<<3)|0]|0;O=d[1232683+(r<<3)|0]|0;P=d[1232756+(r<<3)|0]|0;Q=d[1232684+(r<<3)|0]|0;R=d[1232757+(r<<3)|0]|0;S=d[1232685+(r<<3)|0]|0;T=d[1232764+(r<<3)|0]|0;U=d[1232692+(r<<3)|0]|0;V=d[1232765+(r<<3)|0]|0;W=d[1232693+(r<<3)|0]|0;X=d[1232766+(r<<3)|0]|0;Y=d[1232694+(r<<3)|0]|0;Z=d[1232767+(r<<3)|0]|0;_=d[1232695+(r<<3)|0]|0;$=d[1232758+(r<<3)|0]|0;aa=d[1232686+(r<<3)|0]|0;ca=d[1232759+(r<<3)|0]|0;da=d[1232687+(r<<3)|0]|0;r=(c[k>>2]|0)+z|0;z=(c[m>>2]|0)+y|0;y=x;x=t+(v+u)|0;u=t+v|0;v=w;w=A;while(1){A=y-1|0;t=(d[z]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[r]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[u]|0;ia=s+fa|0;a[w]=((a[ga+(ia+ha)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+(q+fa)|0]|0);fa=d[u+1|0]|0;ia=B+fa|0;a[w+1|0]=((a[ga+(ia+ha)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+(C+fa)|0]|0);fa=d[x]|0;ia=D+fa|0;a[v]=((a[ga+(ia+ha)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+(E+fa)|0]|0);fa=d[x+1|0]|0;ia=F+fa|0;a[v+1|0]=((a[ga+(ia+ha)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+(G+fa)|0]|0);fa=(d[z+1|0]|0)+128|0;t=c[b+4352+(fa<<2)>>2]|0;ia=(d[r+1|0]|0)+128|0;ea=c[b+6400+(ia<<2)>>2]|0;ha=c[b+2304+(fa<<2)>>2]|0;fa=c[b+8448+(ia<<2)>>2]|0;ia=d[x+2|0]|0;ga=H+ia|0;a[v+2|0]=((a[ea+(ga+ha)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+(I+ia)|0]|0);ia=d[x+3|0]|0;ga=J+ia|0;a[v+3|0]=((a[ea+(ga+ha)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+(K+ia)|0]|0);ia=d[u+2|0]|0;ga=L+ia|0;a[w+2|0]=((a[ea+(ga+ha)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+(M+ia)|0]|0);ia=d[u+3|0]|0;ga=N+ia|0;a[w+3|0]=((a[ea+(ga+ha)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+(O+ia)|0]|0);ia=(d[z+2|0]|0)+128|0;fa=c[b+4352+(ia<<2)>>2]|0;ga=(d[r+2|0]|0)+128|0;t=c[b+6400+(ga<<2)>>2]|0;ha=c[b+2304+(ia<<2)>>2]|0;ia=c[b+8448+(ga<<2)>>2]|0;ga=d[u+4|0]|0;ea=P+ga|0;a[w+4|0]=((a[t+(ea+ha)|0]|0)+(a[fa+ea|0]|0)&255)+(a[ia+(Q+ga)|0]|0);ga=d[u+5|0]|0;ea=R+ga|0;a[w+5|0]=((a[t+(ea+ha)|0]|0)+(a[fa+ea|0]|0)&255)+(a[ia+(S+ga)|0]|0);ga=d[x+4|0]|0;ea=T+ga|0;a[v+4|0]=((a[t+(ea+ha)|0]|0)+(a[fa+ea|0]|0)&255)+(a[ia+(U+ga)|0]|0);ga=d[x+5|0]|0;ea=V+ga|0;a[v+5|0]=((a[t+(ea+ha)|0]|0)+(a[fa+ea|0]|0)&255)+(a[ia+(W+ga)|0]|0);ga=(d[z+3|0]|0)+128|0;ia=c[b+4352+(ga<<2)>>2]|0;ea=(d[r+3|0]|0)+128|0;fa=c[b+6400+(ea<<2)>>2]|0;ha=c[b+2304+(ga<<2)>>2]|0;ga=c[b+8448+(ea<<2)>>2]|0;ea=d[x+6|0]|0;t=X+ea|0;a[v+6|0]=((a[fa+(t+ha)|0]|0)+(a[ia+t|0]|0)&255)+(a[ga+(Y+ea)|0]|0);ea=d[x+7|0]|0;t=Z+ea|0;a[v+7|0]=((a[fa+(t+ha)|0]|0)+(a[ia+t|0]|0)&255)+(a[ga+(_+ea)|0]|0);ea=d[u+6|0]|0;t=$+ea|0;a[w+6|0]=((a[fa+(t+ha)|0]|0)+(a[ia+t|0]|0)&255)+(a[ga+(aa+ea)|0]|0);ea=d[u+7|0]|0;t=ca+ea|0;a[w+7|0]=((a[fa+(t+ha)|0]|0)+(a[ia+t|0]|0)&255)+(a[ga+(da+ea)|0]|0);if((A|0)==0){break}else{r=r+4|0;z=z+4|0;y=A;x=x+8|0;u=u+8|0;v=v+8|0;w=w+8|0}}}p=p+2|0;}while((p|0)<(h|0));return h|0}function Rsb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=0;do{q=c[i>>2]|0;r=p+g|0;s=c[j>>2]|0;t=c[e>>2]|0;u=c[f>>2]|0;v=ba(u,p)|0;w=p>>1;x=c[o>>2]>>3;if((x|0)!=0){y=ba(c[n>>2]|0,w)|0;z=ba(c[l>>2]|0,w)|0;w=q+(ba(s,r+1|0)|0)|0;A=q+(ba(s,r)|0)|0;r=p&6;s=d[1232824+(r<<3)|0]|0;q=d[1232680+(r<<3)|0]|0;B=d[1232825+(r<<3)|0]|0;C=d[1232681+(r<<3)|0]|0;D=d[1232832+(r<<3)|0]|0;E=d[1232688+(r<<3)|0]|0;F=d[1232833+(r<<3)|0]|0;G=d[1232689+(r<<3)|0]|0;H=d[1232834+(r<<3)|0]|0;I=d[1232690+(r<<3)|0]|0;J=d[1232835+(r<<3)|0]|0;K=d[1232691+(r<<3)|0]|0;L=d[1232826+(r<<3)|0]|0;M=d[1232682+(r<<3)|0]|0;N=d[1232827+(r<<3)|0]|0;O=d[1232683+(r<<3)|0]|0;P=d[1232828+(r<<3)|0]|0;Q=d[1232684+(r<<3)|0]|0;R=d[1232829+(r<<3)|0]|0;S=d[1232685+(r<<3)|0]|0;T=d[1232836+(r<<3)|0]|0;U=d[1232692+(r<<3)|0]|0;V=d[1232837+(r<<3)|0]|0;W=d[1232693+(r<<3)|0]|0;X=d[1232838+(r<<3)|0]|0;Y=d[1232694+(r<<3)|0]|0;Z=d[1232839+(r<<3)|0]|0;_=d[1232695+(r<<3)|0]|0;$=d[1232830+(r<<3)|0]|0;aa=d[1232686+(r<<3)|0]|0;ca=d[1232831+(r<<3)|0]|0;da=d[1232687+(r<<3)|0]|0;r=(c[m>>2]|0)+y|0;y=x;x=(c[k>>2]|0)+z|0;z=t+(v+u)|0;u=t+v|0;v=w;w=A;while(1){A=y-1|0;t=(d[r]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[x]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[u]|0;ia=s+fa|0;ja=d[u+1|0]|0;ka=B+ja|0;a[w]=(((a[ga+(ja+ha+C)|0]|0)+(a[ea+ka|0]|0)&255)+(a[t+ka|0]|0)&255)<<4|((a[ga+(fa+ha+q)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0)&255;ia=d[z]|0;fa=D+ia|0;ka=d[z+1|0]|0;ja=F+ka|0;a[v]=(((a[ga+(ka+ha+G)|0]|0)+(a[ea+ja|0]|0)&255)+(a[t+ja|0]|0)&255)<<4|((a[ga+(ia+ha+E)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0)&255;fa=(d[r+1|0]|0)+128|0;t=c[b+4352+(fa<<2)>>2]|0;ea=(d[x+1|0]|0)+128|0;ha=c[b+6400+(ea<<2)>>2]|0;ia=c[b+2304+(fa<<2)>>2]|0;fa=c[b+8448+(ea<<2)>>2]|0;ea=d[z+2|0]|0;ga=H+ea|0;ja=d[z+3|0]|0;ka=J+ja|0;a[v+1|0]=(((a[ha+(ja+ia+K)|0]|0)+(a[t+ka|0]|0)&255)+(a[fa+ka|0]|0)&255)<<4|((a[ha+(ea+ia+I)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+ga|0]|0)&255;ga=d[u+2|0]|0;ea=L+ga|0;ka=d[u+3|0]|0;ja=N+ka|0;a[w+1|0]=(((a[ha+(ka+ia+O)|0]|0)+(a[t+ja|0]|0)&255)+(a[fa+ja|0]|0)&255)<<4|((a[ha+(ga+ia+M)|0]|0)+(a[t+ea|0]|0)&255)+(a[fa+ea|0]|0)&255;ea=(d[r+2|0]|0)+128|0;fa=c[b+4352+(ea<<2)>>2]|0;t=(d[x+2|0]|0)+128|0;ia=c[b+6400+(t<<2)>>2]|0;ga=c[b+2304+(ea<<2)>>2]|0;ea=c[b+8448+(t<<2)>>2]|0;t=d[u+4|0]|0;ha=P+t|0;ja=d[u+5|0]|0;ka=R+ja|0;a[w+2|0]=(((a[ia+(ja+ga+S)|0]|0)+(a[fa+ka|0]|0)&255)+(a[ea+ka|0]|0)&255)<<4|((a[ia+(t+ga+Q)|0]|0)+(a[fa+ha|0]|0)&255)+(a[ea+ha|0]|0)&255;ha=d[z+4|0]|0;t=T+ha|0;ka=d[z+5|0]|0;ja=V+ka|0;a[v+2|0]=(((a[ia+(ka+ga+W)|0]|0)+(a[fa+ja|0]|0)&255)+(a[ea+ja|0]|0)&255)<<4|((a[ia+(ha+ga+U)|0]|0)+(a[fa+t|0]|0)&255)+(a[ea+t|0]|0)&255;t=(d[r+3|0]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[x+3|0]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[z+6|0]|0;ia=X+fa|0;ja=d[z+7|0]|0;ka=Z+ja|0;a[v+3|0]=(((a[ga+(ja+ha+_)|0]|0)+(a[ea+ka|0]|0)&255)+(a[t+ka|0]|0)&255)<<4|((a[ga+(fa+ha+Y)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0)&255;ia=d[u+6|0]|0;fa=$+ia|0;ka=d[u+7|0]|0;ja=ca+ka|0;a[w+3|0]=(((a[ga+(ka+ha+da)|0]|0)+(a[ea+ja|0]|0)&255)+(a[t+ja|0]|0)&255)<<4|((a[ga+(ia+ha+aa)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0)&255;if((A|0)==0){break}else{r=r+4|0;y=A;x=x+4|0;z=z+8|0;u=u+8|0;v=v+4|0;w=w+4|0}}}p=p+2|0;}while((p|0)<(h|0));return h|0}function Ssb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=0;do{q=c[i>>2]|0;r=p+g|0;s=c[j>>2]|0;t=c[e>>2]|0;u=c[f>>2]|0;v=ba(u,p)|0;w=p>>1;x=c[o>>2]>>3;if((x|0)!=0){y=ba(c[n>>2]|0,w)|0;z=ba(c[l>>2]|0,w)|0;w=q+(ba(s,r+1|0)|0)|0;A=q+(ba(s,r)|0)|0;r=p&6;s=d[1232824+(r<<3)|0]|0;q=d[1232680+(r<<3)|0]|0;B=d[1232825+(r<<3)|0]|0;C=d[1232681+(r<<3)|0]|0;D=d[1232832+(r<<3)|0]|0;E=d[1232688+(r<<3)|0]|0;F=d[1232833+(r<<3)|0]|0;G=d[1232689+(r<<3)|0]|0;H=d[1232834+(r<<3)|0]|0;I=d[1232690+(r<<3)|0]|0;J=d[1232835+(r<<3)|0]|0;K=d[1232691+(r<<3)|0]|0;L=d[1232826+(r<<3)|0]|0;M=d[1232682+(r<<3)|0]|0;N=d[1232827+(r<<3)|0]|0;O=d[1232683+(r<<3)|0]|0;P=d[1232828+(r<<3)|0]|0;Q=d[1232684+(r<<3)|0]|0;R=d[1232829+(r<<3)|0]|0;S=d[1232685+(r<<3)|0]|0;T=d[1232836+(r<<3)|0]|0;U=d[1232692+(r<<3)|0]|0;V=d[1232837+(r<<3)|0]|0;W=d[1232693+(r<<3)|0]|0;X=d[1232838+(r<<3)|0]|0;Y=d[1232694+(r<<3)|0]|0;Z=d[1232839+(r<<3)|0]|0;_=d[1232695+(r<<3)|0]|0;$=d[1232830+(r<<3)|0]|0;aa=d[1232686+(r<<3)|0]|0;ca=d[1232831+(r<<3)|0]|0;da=d[1232687+(r<<3)|0]|0;r=(c[k>>2]|0)+z|0;z=(c[m>>2]|0)+y|0;y=x;x=t+(v+u)|0;u=t+v|0;v=w;w=A;while(1){A=y-1|0;t=(d[z]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[r]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[u]|0;ia=s+fa|0;a[w]=((a[ga+(fa+ha+q)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0);ia=d[u+1|0]|0;fa=B+ia|0;a[w+1|0]=((a[ga+(ia+ha+C)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0);fa=d[x]|0;ia=D+fa|0;a[v]=((a[ga+(fa+ha+E)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0);ia=d[x+1|0]|0;fa=F+ia|0;a[v+1|0]=((a[ga+(ia+ha+G)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0);fa=(d[z+1|0]|0)+128|0;t=c[b+4352+(fa<<2)>>2]|0;ea=(d[r+1|0]|0)+128|0;ha=c[b+6400+(ea<<2)>>2]|0;ia=c[b+2304+(fa<<2)>>2]|0;fa=c[b+8448+(ea<<2)>>2]|0;ea=d[x+2|0]|0;ga=H+ea|0;a[v+2|0]=((a[ha+(ea+ia+I)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+ga|0]|0);ga=d[x+3|0]|0;ea=J+ga|0;a[v+3|0]=((a[ha+(ga+ia+K)|0]|0)+(a[t+ea|0]|0)&255)+(a[fa+ea|0]|0);ea=d[u+2|0]|0;ga=L+ea|0;a[w+2|0]=((a[ha+(ea+ia+M)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+ga|0]|0);ga=d[u+3|0]|0;ea=N+ga|0;a[w+3|0]=((a[ha+(ga+ia+O)|0]|0)+(a[t+ea|0]|0)&255)+(a[fa+ea|0]|0);ea=(d[z+2|0]|0)+128|0;fa=c[b+4352+(ea<<2)>>2]|0;t=(d[r+2|0]|0)+128|0;ia=c[b+6400+(t<<2)>>2]|0;ga=c[b+2304+(ea<<2)>>2]|0;ea=c[b+8448+(t<<2)>>2]|0;t=d[u+4|0]|0;ha=P+t|0;a[w+4|0]=((a[ia+(t+ga+Q)|0]|0)+(a[fa+ha|0]|0)&255)+(a[ea+ha|0]|0);ha=d[u+5|0]|0;t=R+ha|0;a[w+5|0]=((a[ia+(ha+ga+S)|0]|0)+(a[fa+t|0]|0)&255)+(a[ea+t|0]|0);t=d[x+4|0]|0;ha=T+t|0;a[v+4|0]=((a[ia+(t+ga+U)|0]|0)+(a[fa+ha|0]|0)&255)+(a[ea+ha|0]|0);ha=d[x+5|0]|0;t=V+ha|0;a[v+5|0]=((a[ia+(ha+ga+W)|0]|0)+(a[fa+t|0]|0)&255)+(a[ea+t|0]|0);t=(d[z+3|0]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[r+3|0]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[x+6|0]|0;ia=X+fa|0;a[v+6|0]=((a[ga+(fa+ha+Y)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0);ia=d[x+7|0]|0;fa=Z+ia|0;a[v+7|0]=((a[ga+(ia+ha+_)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0);fa=d[u+6|0]|0;ia=$+fa|0;a[w+6|0]=((a[ga+(fa+ha+aa)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0);ia=d[u+7|0]|0;fa=ca+ia|0;a[w+7|0]=((a[ga+(ia+ha+da)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0);if((A|0)==0){break}else{r=r+4|0;z=z+4|0;y=A;x=x+8|0;u=u+8|0;v=v+8|0;w=w+8|0}}}p=p+2|0;}while((p|0)<(h|0));return h|0}function Tsb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=b+19608|0;l=b+7424|0;m=b+3328|0;b=0;do{n=c[i>>2]|0;o=b+g|0;p=c[j>>2]|0;q=c[e>>2]|0;r=c[f>>2]|0;s=ba(r,b)|0;t=c[k>>2]>>3;if((t|0)!=0){u=n+(ba(p,o+1|0)|0)|0;v=n+(ba(p,o)|0)|0;o=b&6;p=d[1232824+(o<<3)|0]|0;n=d[1232825+(o<<3)|0]|0;w=d[1232832+(o<<3)|0]|0;x=d[1232833+(o<<3)|0]|0;y=d[1232834+(o<<3)|0]|0;z=d[1232835+(o<<3)|0]|0;A=d[1232826+(o<<3)|0]|0;B=d[1232827+(o<<3)|0]|0;C=d[1232828+(o<<3)|0]|0;D=d[1232829+(o<<3)|0]|0;E=d[1232836+(o<<3)|0]|0;F=d[1232837+(o<<3)|0]|0;G=d[1232838+(o<<3)|0]|0;H=d[1232839+(o<<3)|0]|0;I=d[1232830+(o<<3)|0]|0;J=d[1232831+(o<<3)|0]|0;o=q+(s+r)|0;r=t;t=q+s|0;s=u;u=v;while(1){v=r-1|0;q=c[l>>2]|0;K=c[m>>2]|0;L=(((a[q+((d[o+6|0]|0)+K+G)|0]|0)+(((a[q+((d[o+5|0]|0)+K+F)|0]|0)+(((a[q+((d[o+4|0]|0)+K+E)|0]|0)+(((a[q+((d[o+3|0]|0)+K+z)|0]|0)+(((a[q+((d[o+2|0]|0)+K+y)|0]|0)+(((a[q+((d[o+1|0]|0)+K+x)|0]|0)+(a[q+((d[o]|0)+K+w)|0]<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)+(a[q+((d[o+7|0]|0)+K+H)|0]|0)&255;a[u]=(((a[q+((d[t+6|0]|0)+K+I)|0]|0)+(((a[q+((d[t+5|0]|0)+K+D)|0]|0)+(((a[q+((d[t+4|0]|0)+K+C)|0]|0)+(((a[q+((d[t+3|0]|0)+K+B)|0]|0)+(((a[q+((d[t+2|0]|0)+K+A)|0]|0)+(((a[q+((d[t+1|0]|0)+K+n)|0]|0)+(a[q+((d[t]|0)+K+p)|0]<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)+(a[q+((d[t+7|0]|0)+K+J)|0]|0);a[s]=L;if((v|0)==0){break}else{o=o+8|0;r=v;t=t+8|0;s=s+1|0;u=u+1|0}}}b=b+2|0;}while((b|0)<(h|0));return h|0}function Usb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0;l=i;m=e+52|0;n=c[m>>2]|0;switch(n|0){case 30:case 29:case 3:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:{o=1;break};default:{o=0}}switch(n|0){case 43:case 45:case 63:case 47:case 49:case 65:{p=1;break};default:{p=0}}n=c[e+60>>2]|0;q=(g|0)!=0;g=q?384:326;r=c[f>>2]|0;s=r;t=(r|0)<0|0?-1:0;r=c[f+4>>2]|0;u=r;v=(r|0)<0|0?-1:0;r=-(c[f+8>>2]|0)|0;w=r;x=(r|0)<0|0?-1:0;r=-(c[f+12>>2]|0)|0;f=r;y=(r|0)<0|0?-1:0;if(q){q=gHb(s,t,224,0)|0;r=eHb(q,F,255,0)|0;q=F;z=gHb(u,v,224,0)|0;A=eHb(z,F,255,0)|0;z=F;B=gHb(w,x,224,0)|0;C=eHb(B,F,255,0)|0;B=F;D=gHb(f,y,224,0)|0;E=eHb(D,F,255,0)|0;G=0;H=0;I=0;J=65536;K=F;L=E;M=B;N=C;O=z;P=A;Q=q;R=r}else{G=0;H=1048576;I=0;J=76309;K=y;L=f;M=x;N=w;O=v;P=u;Q=t;R=s}s=j;t=(j|0)<0|0?-1:0;j=gHb(J,I,s,t)|0;I=F;J=j>>>16|I<<16;j=I>>16|((I|0)<0|0?-1:0)<<16;I=gHb(k,(k|0)<0|0?-1:0,s,t)|0;t=F;gHb(I,t,R,Q)|0;Q=F;R=Q;s=(Q|0)<0|0?-1:0;gHb(I,t,P,O)|0;O=F;P=O;Q=(O|0)<0|0?-1:0;gHb(I,t,N,M)|0;M=F;N=M;O=(M|0)<0|0?-1:0;gHb(I,t,L,K)|0;K=F;L=K;t=(K|0)<0|0?-1:0;K=h<<8;h=ZGb(H,G,K,(K|0)<0|0?-1:0)|0;K=F;G=e+11400|0;c[G>>2]=67109888;c[G+4>>2]=67109888;G=e+11408|0;c[G>>2]=67109888;c[G+4>>2]=67109888;G=YGb(J<<13|0>>>19,j<<13|J>>>19,32768,0)|0;H=F;I=G>>>16|H<<16;G=I;M=(G|0)<-32767;if(M){S=-2147450880;T=-2147450880}else{k=(G|0)>32767;u=gHb(I&65535,(H>>>16|0<<16)&0,65537,65537)|0;S=k?2147450879:F;T=k?2147450879:u}u=e+11352|0;c[u>>2]=T;c[u+4>>2]=S;S=YGb(R<<13|0>>>19,s<<13|R>>>19,32768,0)|0;u=F;T=S>>>16|u<<16;S=T;k=(S|0)<-32767;if(k){U=-2147450880;V=-2147450880}else{H=(S|0)>32767;v=gHb(T&65535,(u>>>16|0<<16)&0,65537,65537)|0;U=H?2147450879:F;V=H?2147450879:v}v=e+11360|0;c[v>>2]=V;c[v+4>>2]=U;U=YGb(P<<13|0>>>19,Q<<13|P>>>19,32768,0)|0;v=F;V=U>>>16|v<<16;U=V;H=(U|0)<-32767;if(H){W=-2147450880;X=-2147450880}else{u=(U|0)>32767;w=gHb(V&65535,(v>>>16|0<<16)&0,65537,65537)|0;W=u?2147450879:F;X=u?2147450879:w}w=e+11368|0;c[w>>2]=X;c[w+4>>2]=W;W=YGb(L<<13|0>>>19,t<<13|L>>>19,32768,0)|0;w=F;X=W>>>16|w<<16;W=X;u=(W|0)<-32767;if(u){Y=-2147450880;Z=-2147450880}else{v=(W|0)>32767;x=gHb(X&65535,(w>>>16|0<<16)&0,65537,65537)|0;Y=v?2147450879:F;Z=v?2147450879:x}x=e+11376|0;c[x>>2]=Z;c[x+4>>2]=Y;Y=YGb(N<<13|0>>>19,O<<13|N>>>19,32768,0)|0;x=F;Z=Y>>>16|x<<16;Y=Z;v=(Y|0)<-32767;if(v){_=-2147450880;$=-2147450880}else{w=(Y|0)>32767;f=gHb(Z&65535,(x>>>16|0<<16)&0,65537,65537)|0;_=w?2147450879:F;$=w?2147450879:f}f=e+11384|0;c[f>>2]=$;c[f+4>>2]=_;_=YGb(h<<3|0>>>29,K<<3|h>>>29,32768,0)|0;f=F;$=_>>>16|f<<16;_=$;if((_|0)<-32767){aa=-2147450880;ba=-2147450880}else{w=(_|0)>32767;_=gHb($&65535,(f>>>16|0<<16)&0,65537,65537)|0;aa=w?2147450879:F;ba=w?2147450879:_}_=e+11392|0;c[_>>2]=ba;c[_+4>>2]=aa;if(M){ca=-32768}else{ca=(G|0)>32767?32767:(I&65535)<<16>>16}c[e+11304>>2]=ca;ca=h>>>7|K<<25;I=ca;if((I|0)<-32767){da=-32768}else{da=(I|0)>32767?32767:(ca&65535)<<16>>16}c[e+11300>>2]=da;if(k){ea=-32768}else{ea=(S|0)>32767?32767:(T&65535)<<16>>16}c[e+11308>>2]=ea;if(u){fa=-32768}else{fa=(W|0)>32767?32767:(X&65535)<<16>>16}c[e+11312>>2]=fa;if(v){ga=-32768}else{ga=(Y|0)>32767?32767:(Z&65535)<<16>>16}c[e+11316>>2]=ga;if(H){ha=-32768}else{ha=(U|0)>32767?32767:(V&65535)<<16>>16}c[e+11320>>2]=ha;ha=0;V=(j|0)>(ha|0)|(j|0)==(ha|0)&J>>>0>1>>>0;ha=V?J:1;U=V?j:0;V=eHb(R<<16|0>>>16|32768,s<<16|R>>>16|0,ha,U)|0;R=F;s=eHb(P<<16|0>>>16|32768,Q<<16|P>>>16|0,ha,U)|0;P=F;Q=eHb(N<<16|0>>>16|32768,O<<16|N>>>16|0,ha,U)|0;N=F;O=eHb(L<<16|0>>>16|32768,t<<16|L>>>16|0,ha,U)|0;U=F;ha=e+2288|0;$Db(ha);switch(n|0){case 24:case 48:{L=WDb(1024)|0;c[ha>>2]=L;t=ZGb(-25165824,-1,h,K)|0;H=F;ga=t;t=0;while(1){Z=YGb(ga,H,32768,0)|0;Y=Z>>>16|F<<16;Z=Y;if(Z>>>0>255>>>0){ia=-Z>>31&255}else{ia=Y&255}a[L+t|0]=ia;Y=YGb(ga,H,J,j)|0;Z=t+1|0;if((Z|0)<1024){H=F;ga=Y;t=Z}else{break}}t=g-(V>>>9|R<<23)|0;ga=0;do{H=ga-128|0;if((H|0)<0){ja=0;ka=0}else{ia=(H|0)>255;ja=ia?0:(H|0)<0|0?-1:0;ka=ia?255:H}H=gHb(ka,ja,V,R)|0;c[e+4352+(ga<<2)>>2]=L+(t+(H>>>16|F<<16));ga=ga+1|0;}while((ga|0)<512);ga=g-(Q>>>9|N<<23)|0;t=0;do{ja=t-128|0;if((ja|0)<0){la=0;ma=0}else{ka=(ja|0)>255;la=ka?0:(ja|0)<0|0?-1:0;ma=ka?255:ja}ja=gHb(ma,la,Q,N)|0;c[e+6400+(t<<2)>>2]=L+(ga+(ja>>>16|F<<16));t=t+1|0;}while((t|0)<512);t=g-(s>>>9|P<<23)|0;ga=0;do{la=ga-128|0;if((la|0)<0){na=0;oa=0}else{ma=(la|0)>255;na=ma?0:(la|0)<0|0?-1:0;oa=ma?255:la}la=gHb(oa,na,s,P)|0;c[e+8448+(ga<<2)>>2]=L+(t+(la>>>16|F<<16));ga=ga+1|0;}while((ga|0)<512);ga=O>>>9|U<<23;t=U>>>9|0<<23;L=0;while(1){na=L-128|0;if((na|0)<0){pa=0;qa=0}else{oa=(na|0)>255;pa=oa?0:(na|0)<0|0?-1:0;qa=oa?255:na}na=gHb(qa,pa,O,U)|0;oa=F;la=ZGb(na>>>16|oa<<16,oa>>>16|0<<16,ga,t)|0;c[e+2304+(L<<2)>>2]=la;la=L+1|0;if((la|0)<512){L=la}else{ra=0;break}}i=l;return ra|0};case 15:case 16:{L=n-5|0;t=o?L:0;ga=o?0:L;L=WDb(6144)|0;c[ha>>2]=L;pa=L;L=ZGb(-25165824,-1,h,K)|0;qa=18-n|0;la=F;oa=L;L=0;while(1){na=YGb(oa,la,32768,0)|0;ma=na>>>16|F<<16;na=ma;if(na>>>0>255>>>0){sa=-na>>31&255}else{sa=ma&255}ma=sa&255;na=ma>>>3;b[pa+(L<<1)>>1]=na<<t;b[pa+(L+1024<<1)>>1]=ma>>>(qa>>>0)<<5;b[pa+(L+2048<<1)>>1]=na<<ga;na=YGb(oa,la,J,j)|0;ma=L+1|0;if((ma|0)<1024){la=F;oa=na;L=ma}else{break}}if(p){L=0;do{oa=pa+(L<<1)|0;b[oa>>1]=de(b[oa>>1]|0)|0;L=L+1|0;}while((L|0)<3072)}L=pa+(g<<1)|0;R>>9|((R|0)<0|0?-1:0)<<23;oa=(V>>>9|R<<23)<<1|0>>>31;la=0;do{ga=la-128|0;if((ga|0)<0){ta=0;ua=0}else{qa=(ga|0)>255;ta=qa?0:(ga|0)<0|0?-1:0;ua=qa?255:ga}ga=gHb(ua,ta,V,R)|0;qa=F;qa>>16|((qa|0)<0|0?-1:0)<<16;c[e+4352+(la<<2)>>2]=L+(((ga>>>16|qa<<16)<<1|0>>>31)-oa);la=la+1|0;}while((la|0)<512);la=pa+((g|1024)<<1)|0;N>>9|((N|0)<0|0?-1:0)<<23;oa=(Q>>>9|N<<23)<<1|0>>>31;L=0;do{ta=L-128|0;if((ta|0)<0){va=0;wa=0}else{ua=(ta|0)>255;va=ua?0:(ta|0)<0|0?-1:0;wa=ua?255:ta}ta=gHb(wa,va,Q,N)|0;ua=F;ua>>16|((ua|0)<0|0?-1:0)<<16;c[e+6400+(L<<2)>>2]=la+(((ta>>>16|ua<<16)<<1|0>>>31)-oa);L=L+1|0;}while((L|0)<512);L=pa+((g|2048)<<1)|0;P>>9|((P|0)<0|0?-1:0)<<23;pa=(s>>>9|P<<23)<<1|0>>>31;oa=0;do{la=oa-128|0;if((la|0)<0){xa=0;ya=0}else{va=(la|0)>255;xa=va?0:(la|0)<0|0?-1:0;ya=va?255:la}la=gHb(ya,xa,s,P)|0;va=F;va>>16|((va|0)<0|0?-1:0)<<16;c[e+8448+(oa<<2)>>2]=L+(((la>>>16|va<<16)<<1|0>>>31)-pa);oa=oa+1|0;}while((oa|0)<512);oa=ZGb(0,0,O>>>9|U<<23,U>>>9|0<<23)|0;pa=oa;oa=pa;L=(pa|0)<0|0?-1:0;pa=0;while(1){xa=pa-128|0;if((xa|0)<0){za=0;Aa=0}else{ya=(xa|0)>255;za=ya?0:(xa|0)<0|0?-1:0;Aa=ya?255:xa}xa=gHb(Aa,za,O,U)|0;ya=F;va=YGb(xa>>>16|ya<<16,ya>>16|((ya|0)<0|0?-1:0)<<16,oa,L)|0;c[e+2304+(pa<<2)>>2]=va<<1|0>>>31;va=pa+1|0;if((va|0)<512){pa=va}else{ra=0;break}}i=l;return ra|0};case 8:{pa=o?5:0;L=o?2:3;oa=o?0:6;za=WDb(3072)|0;c[ha>>2]=za;Aa=ZGb(-25165824,-1,h,K)|0;va=F;ya=Aa;Aa=0;while(1){xa=YGb(ya,va,32768,0)|0;la=xa>>>16|F<<16;xa=la;if(xa>>>0>255>>>0){Ba=-xa>>31&255}else{Ba=la&255}la=Ba&255;xa=((la+18|0)>>>0)/36|0;a[za+(Aa+16)|0]=xa<<pa;a[za+(Aa+1040)|0]=xa<<L;a[za+(Aa+2085)|0]=(((la+43|0)>>>0)/85|0)<<oa;la=YGb(ya,va,J,j)|0;xa=Aa+1|0;if((xa|0)<986){va=F;ya=la;Aa=xa}else{break}}Aa=g-(V>>>9|R<<23)|0;ya=0;do{va=ya-128|0;if((va|0)<0){Ca=0;Da=0}else{oa=(va|0)>255;Ca=oa?0:(va|0)<0|0?-1:0;Da=oa?255:va}va=gHb(Da,Ca,V,R)|0;c[e+4352+(ya<<2)>>2]=za+(Aa+(va>>>16|F<<16));ya=ya+1|0;}while((ya|0)<512);ya=(g|1024)-(Q>>>9|N<<23)|0;Aa=0;do{Ca=Aa-128|0;if((Ca|0)<0){Ea=0;Fa=0}else{Da=(Ca|0)>255;Ea=Da?0:(Ca|0)<0|0?-1:0;Fa=Da?255:Ca}Ca=gHb(Fa,Ea,Q,N)|0;c[e+6400+(Aa<<2)>>2]=za+(ya+(Ca>>>16|F<<16));Aa=Aa+1|0;}while((Aa|0)<512);Aa=(g|2048)-(s>>>9|P<<23)|0;ya=0;do{Ea=ya-128|0;if((Ea|0)<0){Ga=0;Ha=0}else{Fa=(Ea|0)>255;Ga=Fa?0:(Ea|0)<0|0?-1:0;Ha=Fa?255:Ea}Ea=gHb(Ha,Ga,s,P)|0;c[e+8448+(ya<<2)>>2]=za+(Aa+(Ea>>>16|F<<16));ya=ya+1|0;}while((ya|0)<512);ya=O>>>9|U<<23;Aa=U>>>9|0<<23;za=0;while(1){Ga=za-128|0;if((Ga|0)<0){Ia=0;Ja=0}else{Ha=(Ga|0)>255;Ia=Ha?0:(Ga|0)<0|0?-1:0;Ja=Ha?255:Ga}Ga=gHb(Ja,Ia,O,U)|0;Ha=F;Ea=ZGb(Ga>>>16|Ha<<16,Ha>>>16|0<<16,ya,Aa)|0;c[e+2304+(za<<2)>>2]=Ea;Ea=za+1|0;if((Ea|0)<512){za=Ea}else{ra=0;break}}i=l;return ra|0};case 32:case 64:{za=c[m>>2]|0;if((za|0)==29){Ka=8}else{Ka=(za|0)==27?8:0}za=Ka|(o?16:0);Aa=Ka+8|0;ya=Ka|(o?0:16);Ia=c[e+56>>2]|0;Ja=bFb(Ia)|0;if((Ja|0)==0){yDb(0,0,2172264,(La=i,i=i+24|0,c[La>>2]=2097864,c[La+8>>2]=2042584,c[La+16>>2]=778,La)|0);i=La;Cd();return 0}do{if((Ia|0)==11){Ma=0;Na=1}else{if((a[Ja+7|0]|0)<0){Ma=0;Na=1;break}Ma=Ka+24&24;Na=0}}while(0);Ka=WDb(12288)|0;c[ha>>2]=Ka;Ja=Ka;Ka=ZGb(-25165824,-1,h,K)|0;Ia=Na?0:255<<Ma;Ma=F;Na=Ka;Ka=0;while(1){Ea=YGb(Na,Ma,32768,0)|0;Ha=Ea>>>16|F<<16;Ea=Ha;if(Ea>>>0>255>>>0){Oa=-Ea>>31&255}else{Oa=Ha&255}Ha=Oa&255;c[Ja+(Ka<<2)>>2]=(Ha<<za)+Ia;c[Ja+(Ka+1024<<2)>>2]=Ha<<Aa;c[Ja+(Ka+2048<<2)>>2]=Ha<<ya;Ha=YGb(Na,Ma,J,j)|0;Ea=Ka+1|0;if((Ea|0)<1024){Ma=F;Na=Ha;Ka=Ea}else{break}}Ka=Ja+(g<<2)|0;R>>9|((R|0)<0|0?-1:0)<<23;Na=(V>>>9|R<<23)<<2|0>>>30;Ma=0;do{ya=Ma-128|0;if((ya|0)<0){Pa=0;Qa=0}else{Aa=(ya|0)>255;Pa=Aa?0:(ya|0)<0|0?-1:0;Qa=Aa?255:ya}ya=gHb(Qa,Pa,V,R)|0;Aa=F;Aa>>16|((Aa|0)<0|0?-1:0)<<16;c[e+4352+(Ma<<2)>>2]=Ka+(((ya>>>16|Aa<<16)<<2|0>>>30)-Na);Ma=Ma+1|0;}while((Ma|0)<512);Ma=Ja+((g|1024)<<2)|0;N>>9|((N|0)<0|0?-1:0)<<23;Na=(Q>>>9|N<<23)<<2|0>>>30;Ka=0;do{Pa=Ka-128|0;if((Pa|0)<0){Ra=0;Sa=0}else{Qa=(Pa|0)>255;Ra=Qa?0:(Pa|0)<0|0?-1:0;Sa=Qa?255:Pa}Pa=gHb(Sa,Ra,Q,N)|0;Qa=F;Qa>>16|((Qa|0)<0|0?-1:0)<<16;c[e+6400+(Ka<<2)>>2]=Ma+(((Pa>>>16|Qa<<16)<<2|0>>>30)-Na);Ka=Ka+1|0;}while((Ka|0)<512);Ka=Ja+((g|2048)<<2)|0;P>>9|((P|0)<0|0?-1:0)<<23;Ja=(s>>>9|P<<23)<<2|0>>>30;Na=0;do{Ma=Na-128|0;if((Ma|0)<0){Ta=0;Ua=0}else{Ra=(Ma|0)>255;Ta=Ra?0:(Ma|0)<0|0?-1:0;Ua=Ra?255:Ma}Ma=gHb(Ua,Ta,s,P)|0;Ra=F;Ra>>16|((Ra|0)<0|0?-1:0)<<16;c[e+8448+(Na<<2)>>2]=Ka+(((Ma>>>16|Ra<<16)<<2|0>>>30)-Ja);Na=Na+1|0;}while((Na|0)<512);Na=ZGb(0,0,O>>>9|U<<23,U>>>9|0<<23)|0;Ja=Na;Na=Ja;Ka=(Ja|0)<0|0?-1:0;Ja=0;while(1){Ta=Ja-128|0;if((Ta|0)<0){Va=0;Wa=0}else{Ua=(Ta|0)>255;Va=Ua?0:(Ta|0)<0|0?-1:0;Wa=Ua?255:Ta}Ta=gHb(Wa,Va,O,U)|0;Ua=F;Ra=YGb(Ta>>>16|Ua<<16,Ua>>16|((Ua|0)<0|0?-1:0)<<16,Na,Ka)|0;c[e+2304+(Ja<<2)>>2]=Ra<<2|0>>>30;Ra=Ja+1|0;if((Ra|0)<512){Ja=Ra}else{ra=0;break}}i=l;return ra|0};case 12:{Ja=o?8:0;Ka=o?0:8;Na=WDb(6144)|0;c[ha>>2]=Na;Va=Na;Na=ZGb(-25165824,-1,h,K)|0;Wa=F;Ra=Na;Na=0;while(1){Ua=YGb(Ra,Wa,32768,0)|0;Ta=Ua>>>16|F<<16;Ua=Ta;if(Ua>>>0>255>>>0){Xa=-Ua>>31&255}else{Xa=Ta&255}Ta=(Xa&255)>>>4;b[Va+(Na<<1)>>1]=Ta<<Ja;b[Va+(Na+1024<<1)>>1]=Ta<<4;b[Va+(Na+2048<<1)>>1]=Ta<<Ka;Ta=YGb(Ra,Wa,J,j)|0;Ua=Na+1|0;if((Ua|0)<1024){Wa=F;Ra=Ta;Na=Ua}else{break}}if(p){p=0;do{Na=Va+(p<<1)|0;b[Na>>1]=de(b[Na>>1]|0)|0;p=p+1|0;}while((p|0)<3072)}p=Va+(g<<1)|0;R>>9|((R|0)<0|0?-1:0)<<23;Na=(V>>>9|R<<23)<<1|0>>>31;Ra=0;do{Wa=Ra-128|0;if((Wa|0)<0){Ya=0;Za=0}else{Ka=(Wa|0)>255;Ya=Ka?0:(Wa|0)<0|0?-1:0;Za=Ka?255:Wa}Wa=gHb(Za,Ya,V,R)|0;Ka=F;Ka>>16|((Ka|0)<0|0?-1:0)<<16;c[e+4352+(Ra<<2)>>2]=p+(((Wa>>>16|Ka<<16)<<1|0>>>31)-Na);Ra=Ra+1|0;}while((Ra|0)<512);Ra=Va+((g|1024)<<1)|0;N>>9|((N|0)<0|0?-1:0)<<23;Na=(Q>>>9|N<<23)<<1|0>>>31;p=0;do{Ya=p-128|0;if((Ya|0)<0){_a=0;$a=0}else{Za=(Ya|0)>255;_a=Za?0:(Ya|0)<0|0?-1:0;$a=Za?255:Ya}Ya=gHb($a,_a,Q,N)|0;Za=F;Za>>16|((Za|0)<0|0?-1:0)<<16;c[e+6400+(p<<2)>>2]=Ra+(((Ya>>>16|Za<<16)<<1|0>>>31)-Na);p=p+1|0;}while((p|0)<512);p=Va+((g|2048)<<1)|0;P>>9|((P|0)<0|0?-1:0)<<23;Va=(s>>>9|P<<23)<<1|0>>>31;Na=0;do{Ra=Na-128|0;if((Ra|0)<0){ab=0;bb=0}else{_a=(Ra|0)>255;ab=_a?0:(Ra|0)<0|0?-1:0;bb=_a?255:Ra}Ra=gHb(bb,ab,s,P)|0;_a=F;_a>>16|((_a|0)<0|0?-1:0)<<16;c[e+8448+(Na<<2)>>2]=p+(((Ra>>>16|_a<<16)<<1|0>>>31)-Va);Na=Na+1|0;}while((Na|0)<512);Na=ZGb(0,0,O>>>9|U<<23,U>>>9|0<<23)|0;Va=Na;Na=Va;p=(Va|0)<0|0?-1:0;Va=0;while(1){ab=Va-128|0;if((ab|0)<0){cb=0;db=0}else{bb=(ab|0)>255;cb=bb?0:(ab|0)<0|0?-1:0;db=bb?255:ab}ab=gHb(db,cb,O,U)|0;bb=F;_a=YGb(ab>>>16|bb<<16,bb>>16|((bb|0)<0|0?-1:0)<<16,Na,p)|0;c[e+2304+(Va<<2)>>2]=_a<<1|0>>>31;_a=Va+1|0;if((_a|0)<512){Va=_a}else{ra=0;break}}i=l;return ra|0};case 1:{Va=WDb(1024)|0;c[ha>>2]=Va;p=ZGb(-25165824,-1,h,K)|0;Na=F;cb=p;p=0;while(1){db=YGb(cb,Na,32768,0)|0;_a=db>>>16|F<<16;db=_a;if(db>>>0>255>>>0){eb=-db>>31&255}else{eb=_a&255}a[Va+(p+110)|0]=(eb&255)>>>7;_a=YGb(cb,Na,J,j)|0;db=p+1|0;if((db|0)<914){Na=F;cb=_a;p=db}else{break}}p=g-(Q>>>9|N<<23)|0;cb=0;do{Na=cb-128|0;if((Na|0)<0){fb=0;gb=0}else{eb=(Na|0)>255;fb=eb?0:(Na|0)<0|0?-1:0;gb=eb?255:Na}Na=gHb(gb,fb,Q,N)|0;c[e+6400+(cb<<2)>>2]=Va+(p+(Na>>>16|F<<16));cb=cb+1|0;}while((cb|0)<512);cb=O>>>9|U<<23;p=U>>>9|0<<23;Va=0;while(1){fb=Va-128|0;if((fb|0)<0){hb=0;ib=0}else{gb=(fb|0)>255;hb=gb?0:(fb|0)<0|0?-1:0;ib=gb?255:fb}fb=gHb(ib,hb,O,U)|0;gb=F;Na=ZGb(fb>>>16|gb<<16,gb>>>16|0<<16,cb,p)|0;c[e+2304+(Va<<2)>>2]=Na;Na=Va+1|0;if((Na|0)<512){Va=Na}else{ra=0;break}}i=l;return ra|0};case 4:case 132:{Va=o?3:0;p=o?0:3;o=WDb(3072)|0;c[ha>>2]=o;ha=ZGb(-25165824,-1,h,K)|0;K=F;h=ha;ha=0;while(1){cb=YGb(h,K,32768,0)|0;hb=cb>>>16|F<<16;cb=hb;if(cb>>>0>255>>>0){jb=-cb>>31&255}else{jb=hb&255}hb=jb&255;cb=hb>>>7;a[o+(ha+110)|0]=cb<<Va;a[o+(ha+1061)|0]=(((hb+43|0)>>>0)/85|0)<<1;a[o+(ha+2158)|0]=cb<<p;cb=YGb(h,K,J,j)|0;hb=ha+1|0;if((hb|0)<914){K=F;h=cb;ha=hb}else{break}}ha=g-(V>>>9|R<<23)|0;h=0;do{K=h-128|0;if((K|0)<0){kb=0;lb=0}else{j=(K|0)>255;kb=j?0:(K|0)<0|0?-1:0;lb=j?255:K}K=gHb(lb,kb,V,R)|0;c[e+4352+(h<<2)>>2]=o+(ha+(K>>>16|F<<16));h=h+1|0;}while((h|0)<512);h=(g|1024)-(Q>>>9|N<<23)|0;ha=0;do{R=ha-128|0;if((R|0)<0){mb=0;nb=0}else{V=(R|0)>255;mb=V?0:(R|0)<0|0?-1:0;nb=V?255:R}R=gHb(nb,mb,Q,N)|0;c[e+6400+(ha<<2)>>2]=o+(h+(R>>>16|F<<16));ha=ha+1|0;}while((ha|0)<512);ha=(g|2048)-(s>>>9|P<<23)|0;g=0;do{h=g-128|0;if((h|0)<0){ob=0;pb=0}else{N=(h|0)>255;ob=N?0:(h|0)<0|0?-1:0;pb=N?255:h}h=gHb(pb,ob,s,P)|0;c[e+8448+(g<<2)>>2]=o+(ha+(h>>>16|F<<16));g=g+1|0;}while((g|0)<512);g=O>>>9|U<<23;ha=U>>>9|0<<23;o=0;while(1){P=o-128|0;if((P|0)<0){qb=0;rb=0}else{s=(P|0)>255;qb=s?0:(P|0)<0|0?-1:0;rb=s?255:P}P=gHb(rb,qb,O,U)|0;s=F;ob=ZGb(P>>>16|s<<16,s>>>16|0<<16,g,ha)|0;c[e+2304+(o<<2)>>2]=ob;ob=o+1|0;if((ob|0)<512){o=ob}else{ra=0;break}}i=l;return ra|0};default:{o=bFb(c[m>>2]|0)|0;if((o|0)==0){yDb(0,0,2172264,(La=i,i=i+24|0,c[La>>2]=2097864,c[La+8>>2]=2042584,c[La+16>>2]=806,La)|0);i=La;Cd();return 0}do{if((d[o+4|0]|0)>>>0>1>>>0){if((a[o+7|0]&16)==0|(n|0)<25){break}else{ra=-1}i=l;return ra|0}}while(0);yDb(e,16,2301840,(La=i,i=i+8|0,c[La>>2]=n,La)|0);i=La;ra=-1;i=l;return ra|0}}return 0}function Vsb(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;f=i;g=c[d+56>>2]|0;h=d+23928|0;c[h>>2]=0;switch(g|0){case 313:{c[d+23936>>2]=216;break};case 315:{c[d+23936>>2]=304;break};case 86:{c[d+23936>>2]=100;break};case 84:{c[d+23936>>2]=186;break};case 316:{c[d+23936>>2]=446;break};case 85:{c[d+23936>>2]=464;break};case 1:{c[h>>2]=392;break};case 26:{c[h>>2]=434;break};case 83:{c[d+23936>>2]=468;break};case 317:case 82:{c[d+23936>>2]=458;break};case 75:case 79:case 69:case 77:case 73:case 71:case 309:case 305:case 301:case 311:case 307:case 303:case 55:case 57:case 59:case 95:case 93:case 91:case 101:case 99:case 97:case 103:case 105:case 107:{c[h>>2]=432;break};case 318:case 87:{c[d+23936>>2]=386;break};case 319:case 88:{c[d+23936>>2]=374;break};case 314:{c[d+23936>>2]=240;break};case 22:case 19:case 11:case 21:case 24:{c[h>>2]=136;break};case 25:{c[h>>2]=406;break};case 17:{c[h>>2]=350;break};default:{}}a:do{if((c[d+76>>2]|0)==0){switch(g|0){case 292:{j=470;k=46;break};case 291:{l=142;k=45;break};case 29:{m=512;k=38;break};case 67:{n=256;k=43;break};case 28:{o=556;k=39;break};case 30:{p=478;k=37;break};case 68:{q=28;k=44;break};case 3:{r=550;k=23;break};case 48:{s=464;k=24;break};case 47:{t=78;k=25;break};case 50:{u=348;k=26;break};case 49:{v=180;k=27;break};case 64:{w=80;k=28;break};case 65:{x=148;k=29;break};case 2:{y=96;k=30;break};case 44:{z=338;k=31;break};case 43:{A=94;k=32;break};case 46:{B=574;k=33;break};case 45:{C=394;k=34;break};case 62:{D=246;k=35;break};case 41:{E=218;k=41;break};case 63:{F=444;k=36;break};case 27:{G=196;k=40;break};case 42:{H=250;k=42;break};default:{k=47}}}else{switch(g|0){case 292:{j=42;k=46;break a;break};case 291:{l=146;k=45;break a;break};case 29:{m=604;k=38;break a;break};case 67:{n=208;k=43;break a;break};case 28:{o=342;k=39;break a;break};case 30:{p=126;k=37;break a;break};case 68:{q=24;k=44;break a;break};case 317:case 82:{break};case 3:{r=284;k=23;break a;break};case 48:{s=560;k=24;break a;break};case 47:{t=70;k=25;break a;break};case 50:{u=90;k=26;break a;break};case 49:{v=124;k=27;break a;break};case 64:{w=232;k=28;break a;break};case 65:{x=552;k=29;break a;break};case 2:{y=220;k=30;break a;break};case 44:{z=102;k=31;break a;break};case 43:{A=190;k=32;break a;break};case 46:{B=344;k=33;break a;break};case 45:{C=156;k=34;break a;break};case 62:{D=130;k=35;break a;break};case 41:{E=480;k=41;break a;break};case 63:{F=150;k=36;break a;break};case 27:{G=174;k=40;break a;break};case 42:{H=612;k=42;break a;break};default:{k=47;break a}}c[h>>2]=540;k=47}}while(0);b:do{if((k|0)==23){c[h>>2]=r;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;K=I;L=J;k=64}else if((k|0)==24){c[h>>2]=s;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;M=J;N=I;k=65}else if((k|0)==25){c[h>>2]=t;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;O=I;P=J;k=66}else if((k|0)==26){c[h>>2]=u;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;Q=J;R=I;k=67}else if((k|0)==27){c[h>>2]=v;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;S=I;T=J;k=68}else if((k|0)==28){c[h>>2]=w;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;U=J;V=I;k=69}else if((k|0)==29){c[h>>2]=x;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;W=I;X=J;k=70}else if((k|0)==30){c[h>>2]=y;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;Y=J;Z=I;k=71}else if((k|0)==31){c[h>>2]=z;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;_=I;$=J;k=72}else if((k|0)==32){c[h>>2]=A;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;aa=J;ba=I;k=73}else if((k|0)==33){c[h>>2]=B;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;ca=I;da=J;k=74}else if((k|0)==34){c[h>>2]=C;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ea=J;fa=I;k=75}else if((k|0)==35){c[h>>2]=D;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;ga=I;ha=J;k=76}else if((k|0)==36){c[h>>2]=F;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ia=J;ja=I;k=77}else if((k|0)==37){c[h>>2]=p;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;ka=I;la=J;k=81}else if((k|0)==38){c[h>>2]=m;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ma=J;na=I;k=82}else if((k|0)==39){c[h>>2]=o;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;oa=I;pa=J;k=83}else if((k|0)==40){c[h>>2]=G;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;qa=J;ra=I;k=84}else if((k|0)==41){c[h>>2]=E;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;sa=I;ta=J;k=85}else if((k|0)==42){c[h>>2]=H;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ua=J;va=I;k=86}else if((k|0)==43){c[h>>2]=n;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;wa=I;xa=J;k=87}else if((k|0)==44){c[h>>2]=q;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ya=J;za=I;k=88}else if((k|0)==45){c[h>>2]=l;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;Aa=I;Ba=J;k=89}else if((k|0)==46){c[h>>2]=j;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;Ca=J;Da=I;k=90}else if((k|0)==47){I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;switch(g|0){case 291:{Aa=I;Ba=J;k=89;break b;break};case 43:{aa=I;ba=J;k=73;break b;break};case 46:{ca=I;da=J;k=74;break b;break};case 47:{O=I;P=J;k=66;break b;break};case 50:{Q=I;R=J;k=67;break b;break};case 44:{_=I;$=J;k=72;break b;break};case 95:case 93:case 91:case 101:case 99:case 97:case 103:case 105:case 107:{c[I>>2]=208;c[J>>2]=208;Ea=J;break b;break};case 28:{oa=I;pa=J;k=83;break b;break};case 292:{Ca=I;Da=J;k=90;break b;break};case 3:{K=I;L=J;k=64;break b;break};case 48:{M=I;N=J;k=65;break b;break};case 9:{c[I>>2]=124;Ea=J;break b;break};case 49:{S=I;T=J;k=68;break b;break};case 27:{qa=I;ra=J;k=84;break b;break};case 41:{sa=I;ta=J;k=85;break b;break};case 318:case 87:{c[d+23932>>2]=254;Ea=J;break b;break};case 313:{c[d+23932>>2]=114;Ea=J;break b;break};case 85:{c[d+23932>>2]=326;Ea=J;break b;break};case 316:{c[d+23932>>2]=220;Ea=J;break b;break};case 75:case 79:case 69:case 77:case 73:case 71:case 309:case 305:case 301:case 311:case 307:case 303:case 55:case 57:case 59:case 31:{c[I>>2]=208;Ea=J;break b;break};case 319:case 88:{c[d+23932>>2]=658;Ea=J;break b;break};case 22:case 19:case 11:case 21:case 24:{c[I>>2]=122;Ea=J;break b;break};case 10:{c[I>>2]=194;Ea=J;break b;break};case 64:{U=I;V=J;k=69;break b;break};case 65:{W=I;X=J;k=70;break b;break};case 1:case 66:{c[I>>2]=278;Ea=J;break b;break};case 17:{c[I>>2]=254;Ea=J;break b;break};case 315:{c[d+23932>>2]=44;Ea=J;break b;break};case 82:{break};case 45:{ea=I;fa=J;k=75;break b;break};case 62:{ga=I;ha=J;k=76;break b;break};case 314:{c[d+23932>>2]=438;Ea=J;break b;break};case 86:{c[d+23932>>2]=16;Ea=J;break b;break};case 30:{ka=I;la=J;k=81;break b;break};case 29:{ma=I;na=J;k=82;break b;break};case 84:{c[d+23932>>2]=690;Ea=J;break b;break};case 42:{ua=I;va=J;k=86;break b;break};case 63:{ia=I;ja=J;k=77;break b;break};case 317:{c[d+23940>>2]=290;break};case 2:{Y=I;Z=J;k=71;break b;break};case 83:{c[d+23932>>2]=688;Ea=J;break b;break};case 67:{wa=I;xa=J;k=87;break b;break};case 68:{ya=I;za=J;k=88;break b;break};default:{Ea=J;break b}}c[d+23932>>2]=292;Ea=J}}while(0);if((k|0)==64){c[K>>2]=26;Ea=L}else if((k|0)==65){c[M>>2]=112;Ea=N}else if((k|0)==66){c[O>>2]=86;Ea=P}else if((k|0)==67){c[Q>>2]=232;Ea=R}else if((k|0)==68){c[S>>2]=138;Ea=T}else if((k|0)==69){c[U>>2]=14;Ea=V}else if((k|0)==70){c[W>>2]=38;Ea=X}else if((k|0)==71){c[Y>>2]=128;Ea=Z}else if((k|0)==72){c[_>>2]=282;Ea=$}else if((k|0)==73){c[aa>>2]=286;Ea=ba}else if((k|0)==74){c[ca>>2]=150;Ea=da}else if((k|0)==75){c[ea>>2]=62;Ea=fa}else if((k|0)==76){c[ga>>2]=184;Ea=ha}else if((k|0)==77){c[ia>>2]=164;Ea=ja}else if((k|0)==81){c[ka>>2]=48;Ea=la}else if((k|0)==82){c[ma>>2]=98;Ea=na}else if((k|0)==83){c[oa>>2]=288;Ea=pa}else if((k|0)==84){c[qa>>2]=242;Ea=ra}else if((k|0)==85){c[sa>>2]=230;Ea=ta}else if((k|0)==86){c[ua>>2]=118;Ea=va}else if((k|0)==87){c[wa>>2]=244;Ea=xa}else if((k|0)==88){c[ya>>2]=292;Ea=za}else if((k|0)==89){c[Aa>>2]=146;Ea=Ba}else if((k|0)==90){c[Ca>>2]=222;Ea=Da}if((c[d+2180>>2]|0)==0){i=f;return}d=bFb(g)|0;if((d|0)==0){yDb(0,0,2166584,(Fa=i,i=i+24|0,c[Fa>>2]=2301768,c[Fa+8>>2]=2172224,c[Fa+16>>2]=637,Fa)|0);i=Fa;Cd()}do{if((b[d+8>>1]&30720)==30720){k=98}else{Da=bFb(g)|0;if((Da|0)==0){yDb(0,0,2166584,(Fa=i,i=i+24|0,c[Fa>>2]=2301768,c[Fa+8>>2]=2172224,c[Fa+16>>2]=644,Fa)|0);i=Fa;Cd()}else{if((((e[Da+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){k=98;break}else{break}}}}while(0);do{if((k|0)==98){d=bFb(g)|0;if((d|0)==0){yDb(0,0,2166584,(Fa=i,i=i+24|0,c[Fa>>2]=2301768,c[Fa+8>>2]=2172224,c[Fa+16>>2]=653,Fa)|0);i=Fa;Cd()}if((a[d+7|0]&1)==0){break}c[Ea>>2]=208}}while(0);switch(g|0){case 66:{c[Ea>>2]=254;i=f;return};case 11:{c[Ea>>2]=284;i=f;return};case 292:case 291:{c[Ea>>2]=106;i=f;return};case 30:case 28:{c[Ea>>2]=8;i=f;return};case 29:case 27:{c[Ea>>2]=218;i=f;return};default:{i=f;return}}}function Wsb(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((g|0)>0){i=0}else{return}do{h=i<<2;a[b+i|0]=a[e+(h|1)|0]|0;a[c+i|0]=a[e+(h|3)|0]|0;i=i+1|0;}while((i|0)<(g|0));return}function Xsb(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((g|0)>0){i=0}else{return}do{h=i<<2;a[b+i|0]=a[e+h|0]|0;a[c+i|0]=a[e+(h|2)|0]|0;i=i+1|0;}while((i|0)<(g|0));return}function Ysb(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((g|0)>0){i=0}else{return}do{h=i<<1;a[b+i|0]=a[e+h|0]|0;a[c+i|0]=a[e+(h|1)|0]|0;i=i+1|0;}while((i|0)<(g|0));return}function Zsb(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((g|0)>0){i=0}else{return}do{h=i<<1;a[c+i|0]=a[e+h|0]|0;a[b+i|0]=a[e+(h|1)|0]|0;i=i+1|0;}while((i|0)<(g|0));return}function _sb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0;h=a;a=e;if((i|0)>0){k=0}else{return}do{e=c[j+((d[g+k|0]|0)<<2)>>2]|0;b[h+(k<<1)>>1]=e>>>8<<6&16320;b[a+(k<<1)>>1]=e>>>16<<6&16320;k=k+1|0;}while((k|0)<(i|0));return}function $sb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ba(t,j)|0)+8421376+(ba(q,k)|0)+(ba(r,e)|0)|0)>>>10;b[a+(p<<1)>>1]=((ba(t,m)|0)+8421376+(ba(q,n)|0)+(ba(r,l)|0)|0)>>>10;p=p+1|0;}while((p|0)<(g|0));return}function atb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ba(t,j)|0)+16842752+(ba(q,k)|0)+(ba(r,e)|0)|0)>>>11;b[a+(p<<1)>>1]=((ba(t,m)|0)+16842752+(ba(q,n)|0)+(ba(r,l)|0)|0)>>>11;p=p+1|0;}while((p|0)<(g|0));return}function btb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ba(t,j)|0)+67371008+(ba(q,k)|0)+(ba(r,e)|0)|0)>>>13;b[a+(p<<1)>>1]=((ba(t,m)|0)+67371008+(ba(q,n)|0)+(ba(r,l)|0)|0)>>>13;p=p+1|0;}while((p|0)<(g|0));return}function ctb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ba(t,j)|0)+269484032+(ba(q,k)|0)+(ba(r,e)|0)|0)>>>15;b[a+(p<<1)>>1]=((ba(t,m)|0)+269484032+(ba(q,n)|0)+(ba(r,l)|0)|0)>>>15;p=p+1|0;}while((p|0)<(g|0));return}function dtb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ba(t,j)|0)+1077936128+(ba(q,k)|0)+(ba(r,e)|0)|0)>>>15;b[a+(p<<1)>>1]=((ba(t,m)|0)+1077936128+(ba(q,n)|0)+(ba(r,l)|0)|0)>>>15;p=p+1|0;}while((p|0)<(g|0));return}function etb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ba(q,j)|0)+8421376+(ba(t,k)|0)+(ba(s,e)|0)|0)>>>10;b[a+(p<<1)>>1]=((ba(q,m)|0)+8421376+(ba(t,n)|0)+(ba(s,l)|0)|0)>>>10;p=p+1|0;}while((p|0)<(g|0));return}function ftb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ba(q,j)|0)+16842752+(ba(t,k)|0)+(ba(s,e)|0)|0)>>>11;b[a+(p<<1)>>1]=((ba(q,m)|0)+16842752+(ba(t,n)|0)+(ba(s,l)|0)|0)>>>11;p=p+1|0;}while((p|0)<(g|0));return}function gtb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ba(q,j)|0)+67371008+(ba(t,k)|0)+(ba(s,e)|0)|0)>>>13;b[a+(p<<1)>>1]=((ba(q,m)|0)+67371008+(ba(t,n)|0)+(ba(s,l)|0)|0)>>>13;p=p+1|0;}while((p|0)<(g|0));return}function htb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ba(q,j)|0)+269484032+(ba(t,k)|0)+(ba(s,e)|0)|0)>>>15;b[a+(p<<1)>>1]=((ba(q,m)|0)+269484032+(ba(t,n)|0)+(ba(s,l)|0)|0)>>>15;p=p+1|0;}while((p|0)<(g|0));return}function itb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ba(q,j)|0)+1077936128+(ba(t,k)|0)+(ba(s,e)|0)|0)>>>15;b[a+(p<<1)>>1]=((ba(q,m)|0)+1077936128+(ba(t,n)|0)+(ba(s,l)|0)|0)>>>15;p=p+1|0;}while((p|0)<(g|0));return}function jtb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=c[f>>2]|0;o=c[f+4>>2]|0;p=c[f+8>>2]|0;f=0;do{q=d[h+f|0]|0;r=d[o+f|0]|0;s=d[p+f|0]|0;b[i+(f<<1)>>1]=((ba(q,j)|0)+4194560+(ba(r,k)|0)+(ba(s,e)|0)|0)>>>9;b[a+(f<<1)>>1]=((ba(q,m)|0)+4194560+(ba(r,n)|0)+(ba(s,l)|0)|0)>>>9;f=f+1|0;}while((f|0)<(g|0));return}function ktb(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=e;e=f;f=a;a=c;if((g|0)>0){i=0}else{return}do{b[f+(i<<1)>>1]=de(b[h+(i<<1)>>1]|0)|0;b[a+(i<<1)>>1]=de(b[e+(i<<1)>>1]|0)|0;i=i+1|0;}while((i|0)<(g|0));return}function ltb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(291)|0;if((l|0)==0){s=3;break}t=r<<3;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=bFb(291)|0;if((v|0)==0){s=7;break}l=g+((t|4)<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=de(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=bFb(291)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=de(y|0)|0}y=bFb(291)|0;if((y|0)==0){s=15;break}v=g+((t|5)<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=de(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=bFb(291)|0;if((y|0)==0){s=19;break}v=g+((t|2)<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=de(B|0)|0}B=bFb(291)|0;if((B|0)==0){s=23;break}y=g+((t|6)<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=de(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ba(u,f)|0)+1073758208+(ba(l,m)|0)+(ba(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(u,o)|0)+1073758208+(ba(l,p)|0)+(ba(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==7){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==11){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==15){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==19){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==23){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==27){i=j;return}}function mtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(292)|0;if((l|0)==0){s=3;break}t=r<<3;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=bFb(292)|0;if((v|0)==0){s=7;break}l=g+((t|4)<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=de(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=bFb(292)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=de(y|0)|0}y=bFb(292)|0;if((y|0)==0){s=15;break}v=g+((t|5)<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=de(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=bFb(292)|0;if((y|0)==0){s=19;break}v=g+((t|2)<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=de(B|0)|0}B=bFb(292)|0;if((B|0)==0){s=23;break}y=g+((t|6)<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=de(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ba(u,f)|0)+1073758208+(ba(l,m)|0)+(ba(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(u,o)|0)+1073758208+(ba(l,p)|0)+(ba(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==7){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==11){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==15){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==19){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==23){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==27){i=j;return}}function ntb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(41)|0;if((l|0)==0){s=3;break}t=r*6|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=bFb(41)|0;if((v|0)==0){s=7;break}l=g+(t+3<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=de(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=bFb(41)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=de(y|0)|0}y=bFb(41)|0;if((y|0)==0){s=15;break}v=g+(t+4<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=de(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=bFb(41)|0;if((y|0)==0){s=19;break}v=g+(t+2<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=de(B|0)|0}B=bFb(41)|0;if((B|0)==0){s=23;break}y=g+(t+5<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=de(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ba(u,f)|0)+1073758208+(ba(l,m)|0)+(ba(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(u,o)|0)+1073758208+(ba(l,p)|0)+(ba(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==7){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==11){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==15){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==19){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==23){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==27){i=j;return}}function otb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(42)|0;if((l|0)==0){s=3;break}t=r*6|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=bFb(42)|0;if((v|0)==0){s=7;break}l=g+(t+3<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=de(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=bFb(42)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=de(y|0)|0}y=bFb(42)|0;if((y|0)==0){s=15;break}v=g+(t+4<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=de(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=bFb(42)|0;if((y|0)==0){s=19;break}v=g+(t+2<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=de(B|0)|0}B=bFb(42)|0;if((B|0)==0){s=23;break}y=g+(t+5<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=de(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ba(u,f)|0)+1073758208+(ba(l,m)|0)+(ba(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(u,o)|0)+1073758208+(ba(l,p)|0)+(ba(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==7){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==11){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==15){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==19){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==23){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==27){i=j;return}}function ptb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(67)|0;if((l|0)==0){s=3;break}t=r*6|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=bFb(67)|0;if((v|0)==0){s=7;break}l=g+(t+3<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=de(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=bFb(67)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=de(y|0)|0}y=bFb(67)|0;if((y|0)==0){s=15;break}v=g+(t+4<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=de(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=bFb(67)|0;if((y|0)==0){s=19;break}v=g+(t+2<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=de(B|0)|0}B=bFb(67)|0;if((B|0)==0){s=23;break}y=g+(t+5<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=de(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ba(u,n)|0)+1073758208+(ba(l,m)|0)+(ba(t,f)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(u,q)|0)+1073758208+(ba(l,p)|0)+(ba(t,o)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==7){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==11){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==15){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==19){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==23){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==27){i=j;return}}function qtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(68)|0;if((l|0)==0){s=3;break}t=r*6|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=bFb(68)|0;if((v|0)==0){s=7;break}l=g+(t+3<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=de(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=bFb(68)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=de(y|0)|0}y=bFb(68)|0;if((y|0)==0){s=15;break}v=g+(t+4<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=de(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=bFb(68)|0;if((y|0)==0){s=19;break}v=g+(t+2<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=de(B|0)|0}B=bFb(68)|0;if((B|0)==0){s=23;break}y=g+(t+5<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=de(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ba(u,n)|0)+1073758208+(ba(l,m)|0)+(ba(t,f)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(u,q)|0)+1073758208+(ba(l,p)|0)+(ba(t,o)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==7){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==11){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==15){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==19){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==23){yDb(0,0,2166584,(E=i,i=i+24|0,c[E>>2]=2301768,c[E+8>>2]=2172224,c[E+16>>2]=653,E)|0);i=E;Cd()}else if((s|0)==27){i=j;return}}function rtb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=n<<3;o=c[f+i>>2]|0;p=c[f+(i|4)>>2]|0;i=(p&-16711936)+(o&-16711936)|0;q=p+o-i|0;o=q&511;p=i&130816;i=q>>>16&511;b[g+(n<<1)>>1]=((ba(p,e)|0)-2147352576+((ba(i,d)|0)+(ba(o,j)|0)<<8)|0)>>>18;b[a+(n<<1)>>1]=((ba(p,l)|0)-2147352576+((ba(i,k)|0)+(ba(o,m)|0)<<8)|0)>>>18;n=n+1|0;}while((n|0)<(h|0));return}function stb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=n<<3;o=(c[f+i>>2]|0)>>>8;p=(c[f+(i|4)>>2]|0)>>>8;i=(p&65280)+(o&65280)|0;q=p+o-i|0;o=q&511;p=q>>>16&511;b[g+(n<<1)>>1]=((ba(i,e)|0)-2147352576+((ba(p,d)|0)+(ba(o,j)|0)<<8)|0)>>>18;b[a+(n<<1)>>1]=((ba(i,l)|0)-2147352576+((ba(p,k)|0)+(ba(o,m)|0)<<8)|0)>>>18;n=n+1|0;}while((n|0)<(h|0));return}function ttb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=a;a=e;e=c[j+12>>2]|0;f=c[j+16>>2]|0;k=c[j+20>>2]|0;l=c[j+24>>2]|0;m=c[j+28>>2]|0;n=c[j+32>>2]|0;if((i|0)>0){o=0}else{return}do{j=o*6|0;p=(d[g+(j+3)|0]|0)+(d[g+j|0]|0)|0;q=(d[g+(j+4)|0]|0)+(d[g+(j|1)|0]|0)|0;r=(d[g+(j+5)|0]|0)+(d[g+(j+2)|0]|0)|0;b[h+(o<<1)>>1]=((ba(p,k)|0)+8389120+(ba(q,f)|0)+(ba(r,e)|0)|0)>>>10;b[a+(o<<1)>>1]=((ba(p,n)|0)+8389120+(ba(q,m)|0)+(ba(r,l)|0)|0)>>>10;o=o+1|0;}while((o|0)<(i|0));return}function utb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<11;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<11;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(48)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(48)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&2016)+(v&2016)|0;u=t+v-l|0;v=u&129024;t=u&63;b[g+(r<<1)>>1]=((ba(m,l)|0)-2147352576+(ba(f,t)|0)+(ba(v,n)|0)|0)>>>18;b[e+(r<<1)>>1]=((ba(p,l)|0)-2147352576+(ba(o,t)|0)+(ba(v,q)|0)|0)>>>18;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function vtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<11;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<11;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(47)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(47)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&2016)+(v&2016)|0;u=t+v-l|0;v=u&129024;t=u&63;b[g+(r<<1)>>1]=((ba(m,l)|0)-2147352576+(ba(f,t)|0)+(ba(v,n)|0)|0)>>>18;b[e+(r<<1)>>1]=((ba(p,l)|0)-2147352576+(ba(o,t)|0)+(ba(v,q)|0)|0)>>>18;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function wtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<10;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<10;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(50)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(50)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&33760)+(v&33760)|0;u=t+v-l|0;v=u&64512;t=l&2016;l=u&63;b[g+(r<<1)>>1]=((ba(m,t)|0)+1073807360+(ba(f,l)|0)+(ba(v,n)|0)|0)>>>17;b[e+(r<<1)>>1]=((ba(p,t)|0)+1073807360+(ba(o,l)|0)+(ba(v,q)|0)|0)>>>17;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function xtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<10;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<10;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(49)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(49)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&33760)+(v&33760)|0;u=t+v-l|0;v=u&64512;t=l&2016;l=u&63;b[g+(r<<1)>>1]=((ba(m,t)|0)+1073807360+(ba(f,l)|0)+(ba(v,n)|0)|0)>>>17;b[e+(r<<1)>>1]=((ba(p,t)|0)+1073807360+(ba(o,l)|0)+(ba(v,q)|0)|0)>>>17;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function ytb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=a;a=e;e=c[j+12>>2]|0;l=c[j+16>>2]|0;m=c[j+20>>2]|0;n=c[j+24>>2]|0;o=c[j+28>>2]|0;p=c[j+32>>2]|0;if((i|0)>0){q=0}else{return}do{j=q<<1;r=j|1;s=(d[f+r|0]|0)+(d[f+j|0]|0)|0;t=(d[g+r|0]|0)+(d[g+j|0]|0)|0;u=(d[h+r|0]|0)+(d[h+j|0]|0)|0;b[k+(q<<1)>>1]=((ba(s,l)|0)+8389120+(ba(t,m)|0)+(ba(u,e)|0)|0)>>>10;b[a+(q<<1)>>1]=((ba(s,o)|0)+8389120+(ba(t,p)|0)+(ba(u,n)|0)|0)>>>10;q=q+1|0;}while((q|0)<(i|0));return}function ztb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<8;m=c[l+16>>2]<<4;n=c[l+20>>2]|0;o=c[l+24>>2]<<8;p=c[l+28>>2]<<4;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(64)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(64)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&61680)+(v&61680)|0;u=t+v-l|0;v=u&7936;t=l&496;l=u&31;b[g+(r<<1)>>1]=((ba(m,t)|0)+134225920+(ba(f,l)|0)+(ba(v,n)|0)|0)>>>14;b[e+(r<<1)>>1]=((ba(p,t)|0)+134225920+(ba(o,l)|0)+(ba(v,q)|0)|0)>>>14;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function Atb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<8;m=c[l+16>>2]<<4;n=c[l+20>>2]|0;o=c[l+24>>2]<<8;p=c[l+28>>2]<<4;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(65)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(65)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&61680)+(v&61680)|0;u=t+v-l|0;v=u&7936;t=l&496;l=u&31;b[g+(r<<1)>>1]=((ba(m,t)|0)+134225920+(ba(f,l)|0)+(ba(v,n)|0)|0)>>>14;b[e+(r<<1)>>1]=((ba(p,t)|0)+134225920+(ba(o,l)|0)+(ba(v,q)|0)|0)>>>14;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function Btb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=n<<3;o=c[f+i>>2]|0;p=c[f+(i|4)>>2]|0;i=(p&-16711936)+(o&-16711936)|0;q=p+o-i|0;o=q>>>16&511;p=i&130816;i=q&511;b[g+(n<<1)>>1]=((ba(p,e)|0)-2147352576+((ba(o,j)|0)+(ba(i,d)|0)<<8)|0)>>>18;b[a+(n<<1)>>1]=((ba(p,l)|0)-2147352576+((ba(o,m)|0)+(ba(i,k)|0)<<8)|0)>>>18;n=n+1|0;}while((n|0)<(h|0));return}function Ctb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=n<<3;o=(c[f+i>>2]|0)>>>8;p=(c[f+(i|4)>>2]|0)>>>8;i=(p&65280)+(o&65280)|0;q=p+o-i|0;o=q>>>16&511;p=q&511;b[g+(n<<1)>>1]=((ba(i,e)|0)-2147352576+((ba(o,j)|0)+(ba(p,d)|0)<<8)|0)>>>18;b[a+(n<<1)>>1]=((ba(i,l)|0)-2147352576+((ba(o,m)|0)+(ba(p,k)|0)<<8)|0)>>>18;n=n+1|0;}while((n|0)<(h|0));return}function Dtb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=a;a=e;e=c[j+12>>2]|0;f=c[j+16>>2]|0;k=c[j+20>>2]|0;l=c[j+24>>2]|0;m=c[j+28>>2]|0;n=c[j+32>>2]|0;if((i|0)>0){o=0}else{return}do{j=o*6|0;p=(d[g+(j+3)|0]|0)+(d[g+j|0]|0)|0;q=(d[g+(j+4)|0]|0)+(d[g+(j|1)|0]|0)|0;r=(d[g+(j+5)|0]|0)+(d[g+(j+2)|0]|0)|0;b[h+(o<<1)>>1]=((ba(p,e)|0)+8389120+(ba(q,f)|0)+(ba(r,k)|0)|0)>>>10;b[a+(o<<1)>>1]=((ba(p,l)|0)+8389120+(ba(q,m)|0)+(ba(r,n)|0)|0)>>>10;o=o+1|0;}while((o|0)<(i|0));return}function Etb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<11;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<11;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(44)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(44)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&2016)+(v&2016)|0;u=t+v-l|0;v=u&63;t=u&129024;b[g+(r<<1)>>1]=((ba(m,l)|0)-2147352576+(ba(t,f)|0)+(ba(n,v)|0)|0)>>>18;b[e+(r<<1)>>1]=((ba(p,l)|0)-2147352576+(ba(t,o)|0)+(ba(q,v)|0)|0)>>>18;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function Ftb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<11;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<11;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(43)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(43)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&2016)+(v&2016)|0;u=t+v-l|0;v=u&63;t=u&129024;b[g+(r<<1)>>1]=((ba(m,l)|0)-2147352576+(ba(t,f)|0)+(ba(n,v)|0)|0)>>>18;b[e+(r<<1)>>1]=((ba(p,l)|0)-2147352576+(ba(t,o)|0)+(ba(q,v)|0)|0)>>>18;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function Gtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<10;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<10;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(46)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(46)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&33760)+(v&33760)|0;u=t+v-l|0;v=u&63;t=l&2016;l=u&64512;b[g+(r<<1)>>1]=((ba(m,t)|0)+1073807360+(ba(l,f)|0)+(ba(n,v)|0)|0)>>>17;b[e+(r<<1)>>1]=((ba(p,t)|0)+1073807360+(ba(l,o)|0)+(ba(q,v)|0)|0)>>>17;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function Htb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<10;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<10;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(45)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(45)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&33760)+(v&33760)|0;u=t+v-l|0;v=u&63;t=l&2016;l=u&64512;b[g+(r<<1)>>1]=((ba(m,t)|0)+1073807360+(ba(l,f)|0)+(ba(n,v)|0)|0)>>>17;b[e+(r<<1)>>1]=((ba(p,t)|0)+1073807360+(ba(l,o)|0)+(ba(q,v)|0)|0)>>>17;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function Itb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<4;n=c[l+20>>2]<<8;o=c[l+24>>2]|0;p=c[l+28>>2]<<4;q=c[l+32>>2]<<8;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(62)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(62)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&61680)+(v&61680)|0;u=t+v-l|0;v=u&31;t=l&496;l=u&7936;b[g+(r<<1)>>1]=((ba(m,t)|0)+134225920+(ba(l,f)|0)+(ba(n,v)|0)|0)>>>14;b[e+(r<<1)>>1]=((ba(p,t)|0)+134225920+(ba(l,o)|0)+(ba(q,v)|0)|0)>>>14;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function Jtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<4;n=c[l+20>>2]<<8;o=c[l+24>>2]|0;p=c[l+28>>2]<<4;q=c[l+32>>2]<<8;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(63)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(63)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=de(t|0)|0}t=x&65535;l=(t&61680)+(v&61680)|0;u=t+v-l|0;v=u&31;t=l&496;l=u&7936;b[g+(r<<1)>>1]=((ba(m,t)|0)+134225920+(ba(l,f)|0)+(ba(n,v)|0)|0)>>>14;b[e+(r<<1)>>1]=((ba(p,t)|0)+134225920+(ba(l,o)|0)+(ba(q,v)|0)|0)>>>14;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==7){yDb(0,0,2166584,(y=i,i=i+24|0,c[y>>2]=2301768,c[y+8>>2]=2172224,c[y+16>>2]=653,y)|0);i=y;Cd()}else if((s|0)==11){i=j;return}}function Ktb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(291)|0;if((l|0)==0){s=3;break}t=r<<2;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(291)|0;if((l|0)==0){s=7;break}u=g+((t|1)<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=de(x|0)|0}x=y&65535;l=bFb(291)|0;if((l|0)==0){s=11;break}u=g+((t|2)<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=de(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ba(v,f)|0)+1073758208+(ba(x,m)|0)+(ba(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(v,o)|0)+1073758208+(ba(x,p)|0)+(ba(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==7){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==11){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==15){i=j;return}}function Ltb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(292)|0;if((l|0)==0){s=3;break}t=r<<2;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(292)|0;if((l|0)==0){s=7;break}u=g+((t|1)<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=de(x|0)|0}x=y&65535;l=bFb(292)|0;if((l|0)==0){s=11;break}u=g+((t|2)<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=de(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ba(v,f)|0)+1073758208+(ba(x,m)|0)+(ba(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(v,o)|0)+1073758208+(ba(x,p)|0)+(ba(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==7){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==11){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==15){i=j;return}}function Mtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(41)|0;if((l|0)==0){s=3;break}t=r*3|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(41)|0;if((l|0)==0){s=7;break}u=g+(t+1<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=de(x|0)|0}x=y&65535;l=bFb(41)|0;if((l|0)==0){s=11;break}u=g+(t+2<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=de(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ba(v,f)|0)+1073758208+(ba(x,m)|0)+(ba(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(v,o)|0)+1073758208+(ba(x,p)|0)+(ba(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==7){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==11){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==15){i=j;return}}function Ntb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(42)|0;if((l|0)==0){s=3;break}t=r*3|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(42)|0;if((l|0)==0){s=7;break}u=g+(t+1<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=de(x|0)|0}x=y&65535;l=bFb(42)|0;if((l|0)==0){s=11;break}u=g+(t+2<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=de(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ba(v,f)|0)+1073758208+(ba(x,m)|0)+(ba(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(v,o)|0)+1073758208+(ba(x,p)|0)+(ba(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==7){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==11){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==15){i=j;return}}function Otb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(67)|0;if((l|0)==0){s=3;break}t=r*3|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(67)|0;if((l|0)==0){s=7;break}u=g+(t+1<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=de(x|0)|0}x=y&65535;l=bFb(67)|0;if((l|0)==0){s=11;break}u=g+(t+2<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=de(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ba(v,n)|0)+1073758208+(ba(x,m)|0)+(ba(t,f)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(v,q)|0)+1073758208+(ba(x,p)|0)+(ba(t,o)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==7){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==11){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==15){i=j;return}}function Ptb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(68)|0;if((l|0)==0){s=3;break}t=r*3|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=de(v|0)|0}v=w&65535;l=bFb(68)|0;if((l|0)==0){s=7;break}u=g+(t+1<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=de(x|0)|0}x=y&65535;l=bFb(68)|0;if((l|0)==0){s=11;break}u=g+(t+2<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=de(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ba(v,n)|0)+1073758208+(ba(x,m)|0)+(ba(t,f)|0)|0)>>>15;b[e+(r<<1)>>1]=((ba(v,q)|0)+1073758208+(ba(x,p)|0)+(ba(t,o)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==7){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==11){yDb(0,0,2166584,(A=i,i=i+24|0,c[A>>2]=2301768,c[A+8>>2]=2172224,c[A+16>>2]=653,A)|0);i=A;Cd()}else if((s|0)==15){i=j;return}}function Qtb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=c[f+(n<<2)>>2]|0;o=i&255;p=i&65280;q=i>>>16&255;b[g+(n<<1)>>1]=((ba(p,e)|0)+1073807360+((ba(q,d)|0)+(ba(o,j)|0)<<8)|0)>>>17;b[a+(n<<1)>>1]=((ba(p,l)|0)+1073807360+((ba(q,k)|0)+(ba(o,m)|0)<<8)|0)>>>17;n=n+1|0;}while((n|0)<(h|0));return}function Rtb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=c[f+(n<<2)>>2]|0;o=i>>>8;p=o&255;q=o&65280;o=i>>>24;b[g+(n<<1)>>1]=((ba(q,e)|0)+1073807360+((ba(p,j)|0)+(ba(o,d)|0)<<8)|0)>>>17;b[a+(n<<1)>>1]=((ba(q,l)|0)+1073807360+((ba(p,m)|0)+(ba(o,k)|0)<<8)|0)>>>17;n=n+1|0;}while((n|0)<(h|0));return}function Stb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=a;a=e;e=c[j+12>>2]|0;f=c[j+16>>2]|0;k=c[j+20>>2]|0;l=c[j+24>>2]|0;m=c[j+28>>2]|0;n=c[j+32>>2]|0;if((i|0)>0){o=0}else{return}do{j=o*3|0;p=d[g+j|0]|0;q=d[g+(j+1)|0]|0;r=d[g+(j+2)|0]|0;b[h+(o<<1)>>1]=((ba(p,k)|0)+4194560+(ba(q,f)|0)+(ba(r,e)|0)|0)>>>9;b[a+(o<<1)>>1]=((ba(p,n)|0)+4194560+(ba(q,m)|0)+(ba(r,l)|0)|0)>>>9;o=o+1|0;}while((o|0)<(i|0));return}function Ttb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<11;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<11;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(48)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&63488;t=u&2016;w=u&31;b[g+(r<<1)>>1]=((ba(m,t)|0)+1073807360+(ba(f,w)|0)+(ba(l,n)|0)|0)>>>17;b[e+(r<<1)>>1]=((ba(p,t)|0)+1073807360+(ba(o,w)|0)+(ba(l,q)|0)|0)>>>17;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function Utb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<11;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<11;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(47)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&63488;t=u&2016;w=u&31;b[g+(r<<1)>>1]=((ba(m,t)|0)+1073807360+(ba(f,w)|0)+(ba(l,n)|0)|0)>>>17;b[e+(r<<1)>>1]=((ba(p,t)|0)+1073807360+(ba(o,w)|0)+(ba(l,q)|0)|0)>>>17;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function Vtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<10;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<10;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(50)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&31744;t=u&992;w=u&31;b[g+(r<<1)>>1]=((ba(m,t)|0)+536903680+(ba(f,w)|0)+(ba(l,n)|0)|0)>>>16;b[e+(r<<1)>>1]=((ba(p,t)|0)+536903680+(ba(o,w)|0)+(ba(l,q)|0)|0)>>>16;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function Wtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<10;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<10;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(49)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&31744;t=u&992;w=u&31;b[g+(r<<1)>>1]=((ba(m,t)|0)+536903680+(ba(f,w)|0)+(ba(l,n)|0)|0)>>>16;b[e+(r<<1)>>1]=((ba(p,t)|0)+536903680+(ba(o,w)|0)+(ba(l,q)|0)|0)>>>16;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function Xtb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<8;m=c[l+16>>2]<<4;n=c[l+20>>2]|0;o=c[l+24>>2]<<8;p=c[l+28>>2]<<4;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(64)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&3840;t=u&240;w=u&15;b[g+(r<<1)>>1]=((ba(m,t)|0)+67112960+(ba(f,w)|0)+(ba(l,n)|0)|0)>>>13;b[e+(r<<1)>>1]=((ba(p,t)|0)+67112960+(ba(o,w)|0)+(ba(l,q)|0)|0)>>>13;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function Ytb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<8;m=c[l+16>>2]<<4;n=c[l+20>>2]|0;o=c[l+24>>2]<<8;p=c[l+28>>2]<<4;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(65)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&3840;t=u&240;w=u&15;b[g+(r<<1)>>1]=((ba(m,t)|0)+67112960+(ba(f,w)|0)+(ba(l,n)|0)|0)>>>13;b[e+(r<<1)>>1]=((ba(p,t)|0)+67112960+(ba(o,w)|0)+(ba(l,q)|0)|0)>>>13;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function Ztb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=c[f+(n<<2)>>2]|0;o=i>>>16&255;p=i&65280;q=i&255;b[g+(n<<1)>>1]=((ba(p,e)|0)+1073807360+((ba(o,j)|0)+(ba(q,d)|0)<<8)|0)>>>17;b[a+(n<<1)>>1]=((ba(p,l)|0)+1073807360+((ba(o,m)|0)+(ba(q,k)|0)<<8)|0)>>>17;n=n+1|0;}while((n|0)<(h|0));return}function _tb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=c[f+(n<<2)>>2]|0;o=i>>>8;p=i>>>24;i=o&65280;q=o&255;b[g+(n<<1)>>1]=((ba(i,e)|0)+1073807360+((ba(q,d)|0)+(ba(p,j)|0)<<8)|0)>>>17;b[a+(n<<1)>>1]=((ba(i,l)|0)+1073807360+((ba(q,k)|0)+(ba(p,m)|0)<<8)|0)>>>17;n=n+1|0;}while((n|0)<(h|0));return}function $tb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=a;a=e;e=c[j+12>>2]|0;f=c[j+16>>2]|0;k=c[j+20>>2]|0;l=c[j+24>>2]|0;m=c[j+28>>2]|0;n=c[j+32>>2]|0;if((i|0)>0){o=0}else{return}do{j=o*3|0;p=d[g+j|0]|0;q=d[g+(j+1)|0]|0;r=d[g+(j+2)|0]|0;b[h+(o<<1)>>1]=((ba(p,e)|0)+4194560+(ba(q,f)|0)+(ba(r,k)|0)|0)>>>9;b[a+(o<<1)>>1]=((ba(p,l)|0)+4194560+(ba(q,m)|0)+(ba(r,n)|0)|0)>>>9;o=o+1|0;}while((o|0)<(i|0));return}function aub(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<11;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<11;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(44)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&31;t=u&2016;w=u&63488;b[g+(r<<1)>>1]=((ba(m,t)|0)+1073807360+(ba(w,f)|0)+(ba(n,l)|0)|0)>>>17;b[e+(r<<1)>>1]=((ba(p,t)|0)+1073807360+(ba(w,o)|0)+(ba(q,l)|0)|0)>>>17;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function bub(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<11;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<11;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(43)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&31;t=u&2016;w=u&63488;b[g+(r<<1)>>1]=((ba(m,t)|0)+1073807360+(ba(w,f)|0)+(ba(n,l)|0)|0)>>>17;b[e+(r<<1)>>1]=((ba(p,t)|0)+1073807360+(ba(w,o)|0)+(ba(q,l)|0)|0)>>>17;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function cub(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<10;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<10;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(46)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&31;t=u&992;w=u&31744;b[g+(r<<1)>>1]=((ba(m,t)|0)+536903680+(ba(w,f)|0)+(ba(n,l)|0)|0)>>>16;b[e+(r<<1)>>1]=((ba(p,t)|0)+536903680+(ba(w,o)|0)+(ba(q,l)|0)|0)>>>16;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function dub(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<10;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<10;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(45)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&31;t=u&992;w=u&31744;b[g+(r<<1)>>1]=((ba(m,t)|0)+536903680+(ba(w,f)|0)+(ba(n,l)|0)|0)>>>16;b[e+(r<<1)>>1]=((ba(p,t)|0)+536903680+(ba(w,o)|0)+(ba(q,l)|0)|0)>>>16;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function eub(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<4;n=c[l+20>>2]<<8;o=c[l+24>>2]|0;p=c[l+28>>2]<<4;q=c[l+32>>2]<<8;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(62)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&15;t=u&240;w=u&3840;b[g+(r<<1)>>1]=((ba(m,t)|0)+67112960+(ba(w,f)|0)+(ba(n,l)|0)|0)>>>13;b[e+(r<<1)>>1]=((ba(p,t)|0)+67112960+(ba(w,o)|0)+(ba(q,l)|0)|0)>>>13;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function fub(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<4;n=c[l+20>>2]<<8;o=c[l+24>>2]|0;p=c[l+28>>2]<<4;q=c[l+32>>2]<<8;if((k|0)>0){r=0}else{i=j;return}while(1){l=bFb(63)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=de(u|0)|0}u=v&65535;l=u&15;t=u&240;w=u&3840;b[g+(r<<1)>>1]=((ba(m,t)|0)+67112960+(ba(w,f)|0)+(ba(n,l)|0)|0)>>>13;b[e+(r<<1)>>1]=((ba(p,t)|0)+67112960+(ba(w,o)|0)+(ba(q,l)|0)|0)>>>13;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){yDb(0,0,2166584,(r=i,i=i+24|0,c[r>>2]=2301768,c[r+8>>2]=2172224,c[r+16>>2]=653,r)|0);i=r;Cd()}else if((s|0)==7){i=j;return}}function gub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+1081344+(ba((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ba((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>10;l=l+1|0;}while((l|0)<(f|0));return}function hub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+2162688+(ba((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ba((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>11;l=l+1|0;}while((l|0)<(f|0));return}function iub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+8650752+(ba((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ba((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>13;l=l+1|0;}while((l|0)<(f|0));return}function jub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+34603008+(ba((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ba((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>15;l=l+1|0;}while((l|0)<(f|0));return}function kub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+138412032+(ba((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ba((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>15;l=l+1|0;}while((l|0)<(f|0));return}function lub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba(n&65535,i)|0)+1081344+(ba(o&65535,j)|0)+(ba((de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>10;l=l+1|0;}while((l|0)<(f|0));return}function mub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba(n&65535,i)|0)+2162688+(ba(o&65535,j)|0)+(ba((de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>11;l=l+1|0;}while((l|0)<(f|0));return}function nub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba(n&65535,i)|0)+8650752+(ba(o&65535,j)|0)+(ba((de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>13;l=l+1|0;}while((l|0)<(f|0));return}function oub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba(n&65535,i)|0)+34603008+(ba(o&65535,j)|0)+(ba((de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>15;l=l+1|0;}while((l|0)<(f|0));return}function pub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ba(n&65535,i)|0)+138412032+(ba(o&65535,j)|0)+(ba((de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>15;l=l+1|0;}while((l|0)<(f|0));return}function qub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;g=a;if((f|0)<=0){return}a=c[e+12>>2]|0;e=0;do{b[g+(e<<1)>>1]=(d[a+e|0]|0)<<6;e=e+1|0;}while((e|0)<(f|0));return}function rub(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=a;a=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;if((f|0)<=0){return}g=c[e>>2]|0;k=c[e+4>>2]|0;l=c[e+8>>2]|0;e=0;do{b[h+(e<<1)>>1]=((ba(d[g+e|0]|0,i)|0)+524544+(ba(d[k+e|0]|0,j)|0)+(ba(d[l+e|0]|0,a)|0)|0)>>>9;e=e+1|0;}while((e|0)<(f|0));return}function sub(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=c;c=a;if((f|0)>0){h=0}else{return}do{b[c+(h<<1)>>1]=de(b[g+(h<<1)>>1]|0)|0;h=h+1|0;}while((h|0)<(f|0));return}function tub(b,c,d,e,f,g){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;if((f|0)>0){h=0}else{return}do{a[b+h|0]=a[c+(h<<1)|0]|0;h=h+1|0;}while((h|0)<(f|0));return}function uub(b,c,d,e,f,g){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;if((f|0)>0){h=0}else{return}do{a[b+h|0]=a[c+(h<<1|1)|0]|0;h=h+1|0;}while((h|0)<(f|0));return}function vub(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;g=a;a=c[i>>2]|0;f=c[i+4>>2]|0;j=c[i+8>>2]|0;if((h|0)>0){k=0}else{return}do{i=k*3|0;b[g+(k<<1)>>1]=((ba(d[e+i|0]|0,j)|0)+524544+(ba(d[e+(i+1)|0]|0,f)|0)+(ba(d[e+(i+2)|0]|0,a)|0)|0)>>>9;k=k+1|0;}while((k|0)<(h|0));return}function wub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<11;m=c[k+4>>2]<<5;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(48)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(m,q&2016)|0)+134283264+(ba(l,q&31)|0)+(ba(q&63488,e)|0)|0)>>>17;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function xub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<11;m=c[k+4>>2]<<5;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(47)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(m,q&2016)|0)+134283264+(ba(l,q&31)|0)+(ba(q&63488,e)|0)|0)>>>17;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function yub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<10;m=c[k+4>>2]<<5;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(50)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(m,q&992)|0)+67141632+(ba(l,q&31)|0)+(ba(q&31744,e)|0)|0)>>>16;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function zub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<10;m=c[k+4>>2]<<5;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(49)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(m,q&992)|0)+67141632+(ba(l,q&31)|0)+(ba(q&31744,e)|0)|0)>>>16;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function Aub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<8;m=c[k+4>>2]<<4;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(64)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(m,q&240)|0)+8392704+(ba(l,q&15)|0)+(ba(q&3840,e)|0)|0)>>>13;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function Bub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<8;m=c[k+4>>2]<<4;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(65)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(m,q&240)|0)+8392704+(ba(l,q&15)|0)+(ba(q&3840,e)|0)|0)>>>13;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function Cub(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;g=a;a=c[i>>2]|0;f=c[i+4>>2]|0;j=c[i+8>>2]|0;if((h|0)>0){k=0}else{return}do{i=k*3|0;b[g+(k<<1)>>1]=((ba(d[e+i|0]|0,a)|0)+524544+(ba(d[e+(i+1)|0]|0,f)|0)+(ba(d[e+(i+2)|0]|0,j)|0)|0)>>>9;k=k+1|0;}while((k|0)<(h|0));return}function Dub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<5;m=c[k+8>>2]<<11;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(44)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(l,q&2016)|0)+134283264+(ba(q&63488,e)|0)+(ba(m,q&31)|0)|0)>>>17;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function Eub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<5;m=c[k+8>>2]<<11;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(43)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(l,q&2016)|0)+134283264+(ba(q&63488,e)|0)+(ba(m,q&31)|0)|0)>>>17;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function Fub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<5;m=c[k+8>>2]<<10;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(46)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(l,q&992)|0)+67141632+(ba(q&31744,e)|0)+(ba(m,q&31)|0)|0)>>>16;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function Gub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<5;m=c[k+8>>2]<<10;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(45)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(l,q&992)|0)+67141632+(ba(q&31744,e)|0)+(ba(m,q&31)|0)|0)>>>16;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function Hub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<4;m=c[k+8>>2]<<8;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(62)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(l,q&240)|0)+8392704+(ba(q&3840,e)|0)+(ba(m,q&15)|0)|0)>>>13;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function Iub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<4;m=c[k+8>>2]<<8;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(63)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=de(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ba(l,q&240)|0)+8392704+(ba(q&3840,e)|0)+(ba(m,q&15)|0)|0)>>>13;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){yDb(0,0,2166584,(n=i,i=i+24|0,c[n>>2]=2301768,c[n+8>>2]=2172224,c[n+16>>2]=653,n)|0);i=n;Cd()}else if((o|0)==7){i=h;return}}function Jub(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0;g=a;if((h|0)>0){j=0}else{return}do{b[g+(j<<1)>>1]=c[i+((d[e+j|0]|0)<<2)>>2]<<6&16320;j=j+1|0;}while((j|0)<(h|0));return}function Kub(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=a;a=g+7>>3;if((a|0)>0){g=0;while(1){f=d[c+g|0]|0;e=g<<3;b[h+(e<<1)>>1]=-(f>>>7)&16383;b[h+((e|1)<<1)>>1]=-(f>>>6&1)&16383;b[h+((e|2)<<1)>>1]=-(f>>>5&1)&16383;b[h+((e|3)<<1)>>1]=-(f>>>4&1)&16383;b[h+((e|4)<<1)>>1]=-(f>>>3&1)&16383;b[h+((e|5)<<1)>>1]=-(f>>>2&1)&16383;b[h+((e|6)<<1)>>1]=-(f>>>1&1)&16383;b[h+((e|7)<<1)>>1]=-(f&1)&16383;f=g+1|0;if((f|0)<(a|0)){g=f}else{i=a;break}}}else{i=0}g=a&7;if((g|0)==0){return}a=d[c+i|0]|0;c=i<<3;i=0;do{b[h+(i+c<<1)>>1]=-(a>>>((7-i|0)>>>0)&1)&16383;i=i+1|0;}while((i|0)<(g|0));return}function Lub(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=a;a=g+7>>3;if((a|0)>0){g=0;while(1){f=~(d[c+g|0]|0);e=g<<3;b[h+(e<<1)>>1]=-(f>>>7&1)&16383;b[h+((e|1)<<1)>>1]=-(f>>>6&1)&16383;b[h+((e|2)<<1)>>1]=-(f>>>5&1)&16383;b[h+((e|3)<<1)>>1]=-(f>>>4&1)&16383;b[h+((e|4)<<1)>>1]=-(f>>>3&1)&16383;b[h+((e|5)<<1)>>1]=-(f>>>2&1)&16383;b[h+((e|6)<<1)>>1]=-(f>>>1&1)&16383;b[h+((e|7)<<1)>>1]=-(f&1)&16383;f=g+1|0;if((f|0)<(a|0)){g=f}else{i=a;break}}}else{i=0}g=a&7;if((g|0)==0){return}a=~(d[c+i|0]|0);c=i<<3;i=0;do{b[h+(i+c<<1)>>1]=-(a>>>((7-i|0)>>>0)&1)&16383;i=i+1|0;}while((i|0)<(g|0));return}function Mub(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;f=a;a=c[h>>2]|0;e=c[h+4>>2]|0;i=c[h+8>>2]|0;if((g|0)>0){j=0}else{return}do{h=c[d+(j<<2)>>2]|0;b[f+(j<<1)>>1]=((ba(h&65280,e)|0)+134283264+((ba(h>>>16&255,a)|0)+(ba(h&255,i)|0)<<8)|0)>>>17;j=j+1|0;}while((j|0)<(g|0));return}function Nub(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;f=a;a=c[h>>2]|0;e=c[h+4>>2]|0;i=c[h+8>>2]|0;if((g|0)>0){j=0}else{return}do{h=c[d+(j<<2)>>2]|0;k=h>>>8;b[f+(j<<1)>>1]=((ba(k&65280,e)|0)+134283264+((ba(k&255,i)|0)+(ba(h>>>24,a)|0)<<8)|0)>>>17;j=j+1|0;}while((j|0)<(g|0));return}function Oub(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;f=a;a=c[h>>2]|0;e=c[h+4>>2]|0;i=c[h+8>>2]|0;if((g|0)>0){j=0}else{return}do{h=c[d+(j<<2)>>2]|0;b[f+(j<<1)>>1]=((ba(h&65280,e)|0)+134283264+((ba(h>>>16&255,i)|0)+(ba(h&255,a)|0)<<8)|0)>>>17;j=j+1|0;}while((j|0)<(g|0));return}function Pub(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;f=a;a=c[h>>2]|0;e=c[h+4>>2]|0;i=c[h+8>>2]|0;if((g|0)>0){j=0}else{return}do{h=c[d+(j<<2)>>2]|0;k=h>>>8;b[f+(j<<1)>>1]=((ba(k&65280,e)|0)+134283264+((ba(k&255,a)|0)+(ba(h>>>24,i)|0)<<8)|0)>>>17;j=j+1|0;}while((j|0)<(g|0));return}function Qub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(41)|0;if((k|0)==0){o=3;break}p=n*3|0;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=de(r|0)|0}r=bFb(41)|0;if((r|0)==0){o=7;break}k=g+(p+1<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=de(q|0)|0}q=bFb(41)|0;if((q|0)==0){o=11;break}r=g+(p+2<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=de(p|0)|0}b[f+(n<<1)>>1]=((ba(s&65535,e)|0)+134234112+(ba(t&65535,l)|0)+(ba(u&65535,m)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==7){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==11){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==15){i=h;return}}function Rub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(42)|0;if((k|0)==0){o=3;break}p=n*3|0;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=de(r|0)|0}r=bFb(42)|0;if((r|0)==0){o=7;break}k=g+(p+1<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=de(q|0)|0}q=bFb(42)|0;if((q|0)==0){o=11;break}r=g+(p+2<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=de(p|0)|0}b[f+(n<<1)>>1]=((ba(s&65535,e)|0)+134234112+(ba(t&65535,l)|0)+(ba(u&65535,m)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==7){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==11){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==15){i=h;return}}function Sub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(67)|0;if((k|0)==0){o=3;break}p=n*3|0;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=de(r|0)|0}r=bFb(67)|0;if((r|0)==0){o=7;break}k=g+(p+1<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=de(q|0)|0}q=bFb(67)|0;if((q|0)==0){o=11;break}r=g+(p+2<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=de(p|0)|0}b[f+(n<<1)>>1]=((ba(s&65535,m)|0)+134234112+(ba(t&65535,l)|0)+(ba(u&65535,e)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==7){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==11){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==15){i=h;return}}function Tub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(68)|0;if((k|0)==0){o=3;break}p=n*3|0;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=de(r|0)|0}r=bFb(68)|0;if((r|0)==0){o=7;break}k=g+(p+1<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=de(q|0)|0}q=bFb(68)|0;if((q|0)==0){o=11;break}r=g+(p+2<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=de(p|0)|0}b[f+(n<<1)>>1]=((ba(s&65535,m)|0)+134234112+(ba(t&65535,l)|0)+(ba(u&65535,e)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==7){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==11){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==15){i=h;return}}function Uub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(291)|0;if((k|0)==0){o=3;break}p=n<<2;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=de(r|0)|0}r=bFb(291)|0;if((r|0)==0){o=7;break}k=g+((p|1)<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=de(q|0)|0}q=bFb(291)|0;if((q|0)==0){o=11;break}r=g+((p|2)<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=de(p|0)|0}b[f+(n<<1)>>1]=((ba(s&65535,e)|0)+134234112+(ba(t&65535,l)|0)+(ba(u&65535,m)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==7){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==11){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==15){i=h;return}}function Vub(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=bFb(292)|0;if((k|0)==0){o=3;break}p=n<<2;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=de(r|0)|0}r=bFb(292)|0;if((r|0)==0){o=7;break}k=g+((p|1)<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=de(q|0)|0}q=bFb(292)|0;if((q|0)==0){o=11;break}r=g+((p|2)<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=de(p|0)|0}b[f+(n<<1)>>1]=((ba(s&65535,e)|0)+134234112+(ba(t&65535,l)|0)+(ba(u&65535,m)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==7){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==11){yDb(0,0,2166584,(v=i,i=i+24|0,c[v>>2]=2301768,c[v+8>>2]=2172224,c[v+16>>2]=653,v)|0);i=v;Cd()}else if((o|0)==15){i=h;return}}function Wub(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=a;a=c;if((f|0)>0){h=0}else{return}do{b[g+(h<<1)>>1]=b[a+((h<<2|3)<<1)>>1]|0;h=h+1|0;}while((h|0)<(f|0));return}function Xub(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=a;if((g|0)>0){i=0}else{return}do{b[h+(i<<1)>>1]=(d[c+(i<<2|3)|0]|0)<<6;i=i+1|0;}while((i|0)<(g|0));return}function Yub(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=a;if((g|0)>0){i=0}else{return}do{b[h+(i<<1)>>1]=(d[c+(i<<2)|0]|0)<<6;i=i+1|0;}while((i|0)<(g|0));return}function Zub(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0;g=a;if((h|0)>0){j=0}else{return}do{b[g+(j<<1)>>1]=(c[i+((d[e+j|0]|0)<<2)>>2]|0)>>>24<<6;j=j+1|0;}while((j|0)<(h|0));return}function _ub(d,f,g,h,j,k,l,m){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=i;o=c[d+52>>2]|0;p=bFb(o)|0;q=bFb(o)|0;if((q|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=637,r)|0);i=r;Cd()}s=(b[q+8>>1]&30720)==30720;q=bFb(o)|0;t=(q|0)==0;do{if(s){if(t){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}c[g>>2]=(a[q+7|0]&1)!=0?446:620;u=bFb(o)|0;if((u|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}else{c[f>>2]=(a[u+7|0]&1)!=0?260:254;break}}else{if(t){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=644,r)|0);i=r;Cd()}if(!((((e[q+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0)){c[f>>2]=370;c[g>>2]=30;if(!((o-25|0)>>>0<2>>>0)){break}c[h>>2]=64;break}u=(e[p+8>>1]|0)>>>11&15;if((u<<16>>16|0)==13){v=bFb(o)|0;if((v|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}c[g>>2]=(a[v+7|0]&1)!=0?264:164;v=bFb(o)|0;if((v|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}else{c[f>>2]=(a[v+7|0]&1)!=0?436:128;break}}else if((u<<16>>16|0)==8){v=bFb(o)|0;if((v|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}c[g>>2]=(a[v+7|0]&1)!=0?622:240;v=bFb(o)|0;if((v|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}else{c[f>>2]=(a[v+7|0]&1)!=0?506:176;break}}else if((u<<16>>16|0)==11){v=bFb(o)|0;if((v|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}c[g>>2]=(a[v+7|0]&1)!=0?472:104;v=bFb(o)|0;if((v|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}else{c[f>>2]=(a[v+7|0]&1)!=0?356:222;break}}else if((u<<16>>16|0)==9){u=bFb(o)|0;if((u|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}c[g>>2]=(a[u+7|0]&1)!=0?390:76;u=bFb(o)|0;if((u|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}else{c[f>>2]=(a[u+7|0]&1)!=0?512:336;break}}else{yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2301760,c[r+8>>2]=2172184,c[r+16>>2]=1829,r)|0);i=r;Cd()}}}while(0);do{if((c[d+2284>>2]&8192|0)==0){w=59}else{a:do{switch(o|0){case 19:{c[l>>2]=50;c[k>>2]=68;c[j>>2]=22;break};case 28:{if((c[d+2180>>2]|0)==0){c[l>>2]=34;c[k>>2]=14;c[j>>2]=116;break a}else{c[l>>2]=58;c[k>>2]=80;c[j>>2]=34;break a}break};case 27:{if((c[d+2180>>2]|0)==0){c[l>>2]=84;c[k>>2]=58;c[j>>2]=52;break a}else{c[l>>2]=76;c[k>>2]=46;c[j>>2]=140;break a}break};case 30:{if((c[d+2180>>2]|0)==0){c[l>>2]=82;c[k>>2]=12;c[j>>2]=28;break a}else{c[l>>2]=6;c[k>>2]=62;c[j>>2]=112;break a}break};case 22:{c[l>>2]=86;c[k>>2]=20;c[j>>2]=10;break};case 29:{if((c[d+2180>>2]|0)==0){c[l>>2]=52;c[k>>2]=18;c[j>>2]=48;break a}else{c[l>>2]=22;c[k>>2]=40;c[j>>2]=122;break a}break};case 2:{c[l>>2]=46;c[k>>2]=26;c[j>>2]=120;break};case 82:case 83:case 84:case 85:case 86:case 313:case 314:case 315:case 316:case 87:case 88:case 317:{c[m>>2]=20;break};case 3:{c[l>>2]=8;c[k>>2]=76;c[j>>2]=54;break};case 21:{c[l>>2]=28;c[k>>2]=4;c[j>>2]=102;break};case 24:{c[l>>2]=2;c[k>>2]=22;c[j>>2]=60;break};default:{}}}while(0);if((c[l>>2]|0)!=0){w=84;break}if((c[m>>2]|0)==0){w=59}else{w=84}}}while(0);b:do{if((w|0)==59){switch(o|0){case 29:case 27:{if((c[d+2180>>2]|0)==0){c[j>>2]=16;c[k>>2]=2;c[l>>2]=74;w=84;break b}else{c[j>>2]=114;c[k>>2]=64;c[l>>2]=32;w=84;break b}break};case 68:{c[j>>2]=154;c[k>>2]=34;c[l>>2]=4;i=n;return};case 24:case 21:{c[j>>2]=58;c[k>>2]=78;c[l>>2]=48;w=84;break b;break};case 292:{if((c[d+2180>>2]|0)==0){c[j>>2]=74;c[k>>2]=70;c[l>>2]=54;w=84;break b}c[j>>2]=38;c[k>>2]=30;c[l>>2]=42;i=n;return};case 291:{if((c[d+2180>>2]|0)==0){c[j>>2]=82;c[k>>2]=82;c[l>>2]=12;w=84;break b}c[j>>2]=56;c[k>>2]=84;c[l>>2]=78;i=n;return};case 46:case 45:case 50:case 49:{c[j>>2]=104;c[k>>2]=28;c[l>>2]=44;w=84;break b;break};case 10:{w=86;break b;break};case 23:case 20:{c[j>>2]=8;c[k>>2]=52;c[l>>2]=38;w=84;break b;break};case 67:{c[j>>2]=46;c[k>>2]=54;c[l>>2]=40;i=n;return};case 9:{w=85;break b;break};case 62:case 63:case 64:case 65:{c[j>>2]=138;c[k>>2]=72;c[l>>2]=10;w=84;break b;break};case 3:{c[j>>2]=42;c[k>>2]=66;c[l>>2]=68;i=n;return};case 17:{w=88;break b;break};case 41:{c[j>>2]=94;c[k>>2]=44;c[l>>2]=24;i=n;return};case 42:{c[j>>2]=66;c[k>>2]=32;c[l>>2]=36;i=n;return};case 30:case 28:{if((c[d+2180>>2]|0)==0){c[j>>2]=78;c[k>>2]=74;c[l>>2]=60;w=84;break b}else{c[j>>2]=2;c[k>>2]=10;c[l>>2]=30;w=84;break b}break};case 2:{c[j>>2]=142;c[k>>2]=42;c[l>>2]=80;i=n;return};case 1:{w=87;break b;break};case 44:case 43:case 48:case 47:{c[j>>2]=4;c[k>>2]=36;c[l>>2]=64;w=84;break b;break};case 22:case 19:{c[j>>2]=90;c[k>>2]=56;c[l>>2]=56;w=84;break b;break};default:{i=n;return}}}}while(0);do{if((w|0)==84){if((o|0)==10){w=86;break}else if((o|0)==9){w=85;break}else if((o|0)==17){w=88;break}else if((o|0)==1){w=87;break}i=n;return}}while(0);if((w|0)==85){c[j>>2]=12;c[k>>2]=88;c[l>>2]=26;i=n;return}else if((w|0)==86){c[j>>2]=96;c[k>>2]=86;c[l>>2]=70;i=n;return}else if((w|0)==87){c[j>>2]=158;c[k>>2]=50;c[l>>2]=72;i=n;return}else if((w|0)==88){c[j>>2]=144;c[k>>2]=8;c[l>>2]=66;i=n;return}}function $ub(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;j=g;if((h|0)<=0){return}if((e|0)>0){k=0}else{TGb(g|0,0,h<<1|0)|0;return}do{g=-1073725440;i=0;do{g=(ba(b[d+(i<<1)>>1]|0,c[(c[f+(i<<2)>>2]|0)+(k<<2)>>2]|0)|0)+g|0;i=i+1|0;}while((i|0)<(e|0));i=g>>15;if((i+32768|0)>>>0>65535>>>0){l=(g>>31^32767)&65535}else{l=i&65535}i=j+(k<<1)|0;x=de(l^-32768|0)|0;a[i]=x;x=x>>8;a[i+1|0]=x;k=k+1|0;}while((k|0)<(h|0));return}function avb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;j=g;if((h|0)<=0){return}if((e|0)>0){k=0}else{TGb(g|0,0,h<<1|0)|0;return}do{g=-1073725440;i=0;do{g=(ba(b[d+(i<<1)>>1]|0,c[(c[f+(i<<2)>>2]|0)+(k<<2)>>2]|0)|0)+g|0;i=i+1|0;}while((i|0)<(e|0));i=g>>15;if((i+32768|0)>>>0>65535>>>0){l=(g>>31^32767)&65535}else{l=i&65535}i=j+(k<<1)|0;x=l^-32768;a[i]=x;x=x>>8;a[i+1|0]=x;k=k+1|0;}while((k|0)<(h|0));return}function bvb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=b;b=d;if((e|0)>0){h=0}else{return}do{d=(c[g+(h<<2)>>2]|0)+4>>3;if(d>>>0>65535>>>0){i=-d>>31&65535}else{i=d&65535}d=b+(h<<1)|0;x=de(i|0)|0;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function cvb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=b;b=d;if((e|0)>0){h=0}else{return}do{d=(c[g+(h<<2)>>2]|0)+4>>3;if(d>>>0>65535>>>0){i=-d>>31&65535}else{i=d&65535}d=b+(h<<1)|0;x=i;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function dvb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=131072;l=0;do{k=(ba(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>18;if(l>>>0<512>>>0){m=l&65535;break}m=-l>>31&511}else{m=0}}while(0);l=j+(i<<1)|0;x=de(m|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;i=i+1|0;}while((i|0)<(h|0));return}function evb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=131072;l=0;do{k=(ba(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>18;if(l>>>0<512>>>0){m=l&65535;break}m=-l>>31&511}else{m=0}}while(0);l=j+(i<<1)|0;x=m;a[l]=x;x=x>>8;a[l+1|0]=x;i=i+1|0;}while((i|0)<(h|0));return}function fvb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+32>>6;if(d>>>0<512>>>0){i=d&65535}else{i=-d>>31&511}d=g+(h<<1)|0;x=de(i|0)|0;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function gvb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+32>>6;if(d>>>0<512>>>0){i=d&65535}else{i=-d>>31&511}d=g+(h<<1)|0;x=i;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function hvb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=65536;l=0;do{k=(ba(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>17;if(l>>>0<1024>>>0){m=l&65535;break}m=-l>>31&1023}else{m=0}}while(0);l=j+(i<<1)|0;x=de(m|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;i=i+1|0;}while((i|0)<(h|0));return}function ivb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=65536;l=0;do{k=(ba(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>17;if(l>>>0<1024>>>0){m=l&65535;break}m=-l>>31&1023}else{m=0}}while(0);l=j+(i<<1)|0;x=m;a[l]=x;x=x>>8;a[l+1|0]=x;i=i+1|0;}while((i|0)<(h|0));return}function jvb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+16>>5;if(d>>>0<1024>>>0){i=d&65535}else{i=-d>>31&1023}d=g+(h<<1)|0;x=de(i|0)|0;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function kvb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+16>>5;if(d>>>0<1024>>>0){i=d&65535}else{i=-d>>31&1023}d=g+(h<<1)|0;x=i;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function lvb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=16384;l=0;do{k=(ba(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>15;if(l>>>0<4096>>>0){m=l&65535;break}m=-l>>31&4095}else{m=0}}while(0);l=j+(i<<1)|0;x=de(m|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;i=i+1|0;}while((i|0)<(h|0));return}function mvb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=16384;l=0;do{k=(ba(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>15;if(l>>>0<4096>>>0){m=l&65535;break}m=-l>>31&4095}else{m=0}}while(0);l=j+(i<<1)|0;x=m;a[l]=x;x=x>>8;a[l+1|0]=x;i=i+1|0;}while((i|0)<(h|0));return}function nvb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+4>>3;if(d>>>0<4096>>>0){i=d&65535}else{i=-d>>31&4095}d=g+(h<<1)|0;x=de(i|0)|0;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function ovb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+4>>3;if(d>>>0<4096>>>0){i=d&65535}else{i=-d>>31&4095}d=g+(h<<1)|0;x=i;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function pvb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=4096;l=0;do{k=(ba(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>13;if(l>>>0<16384>>>0){m=l&65535;break}m=-l>>31&16383}else{m=0}}while(0);l=j+(i<<1)|0;x=de(m|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;i=i+1|0;}while((i|0)<(h|0));return}function qvb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=4096;l=0;do{k=(ba(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>13;if(l>>>0<16384>>>0){m=l&65535;break}m=-l>>31&16383}else{m=0}}while(0);l=j+(i<<1)|0;x=m;a[l]=x;x=x>>8;a[l+1|0]=x;i=i+1|0;}while((i|0)<(h|0));return}function rvb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+1>>1;if(d>>>0<16384>>>0){i=d&65535}else{i=-d>>31&16383}d=g+(h<<1)|0;x=de(i|0)|0;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function svb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+1>>1;if(d>>>0<16384>>>0){i=d&65535}else{i=-d>>31&16383}d=g+(h<<1)|0;x=i;a[d]=x;x=x>>8;a[d+1|0]=x;h=h+1|0;}while((h|0)<(e|0));return}function tvb(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;if((f|0)>0){i=0}else{return}do{j=(d[g+(i+h&7)|0]|0)+(b[c+(i<<1)>>1]|0)>>7;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[e+i|0]=k;i=i+1|0;}while((i|0)<(f|0));return}function uvb(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((i|0)<=0){return}l=(f|0)>0;m=0;do{n=d[j+(m+k&7)|0]<<12;if(l){o=n;p=0;while(1){q=(ba(b[e+(p<<1)>>1]|0,b[(c[g+(p<<2)>>2]|0)+(m<<1)>>1]|0)|0)+o|0;r=p+1|0;if((r|0)<(f|0)){o=q;p=r}else{s=q;break}}}else{s=n}p=s>>19;if(p>>>0>255>>>0){t=-p>>31&255}else{t=p&255}a[h+m|0]=t;m=m+1|0;}while((m|0)<(i|0));return}function vvb(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;l=c[e+23816>>2]|0;m=(k|0)>0;if((c[e+52>>2]|0)==25){if(!m){return}e=(g|0)>0;n=0;do{o=d[l+(n&7)|0]<<12;p=d[l+(n+3&7)|0]<<12;if(e){q=o;r=p;s=0;while(1){t=b[f+(s<<1)>>1]|0;u=(ba(t,b[(c[h+(s<<2)>>2]|0)+(n<<1)>>1]|0)|0)+q|0;v=(ba(b[(c[i+(s<<2)>>2]|0)+(n<<1)>>1]|0,t)|0)+r|0;t=s+1|0;if((t|0)<(g|0)){q=u;r=v;s=t}else{w=u;x=v;break}}}else{w=o;x=p}s=w>>19;if(s>>>0>255>>>0){y=-s>>31&255}else{y=s&255}s=n<<1;a[j+s|0]=y;r=x>>19;if(r>>>0>255>>>0){z=-r>>31&255}else{z=r&255}a[j+(s|1)|0]=z;n=n+1|0;}while((n|0)<(k|0));return}else{if(!m){return}m=(g|0)>0;n=0;do{z=d[l+(n&7)|0]<<12;x=d[l+(n+3&7)|0]<<12;if(m){y=z;w=x;e=0;while(1){s=b[f+(e<<1)>>1]|0;r=(ba(s,b[(c[h+(e<<2)>>2]|0)+(n<<1)>>1]|0)|0)+y|0;q=(ba(b[(c[i+(e<<2)>>2]|0)+(n<<1)>>1]|0,s)|0)+w|0;s=e+1|0;if((s|0)<(g|0)){y=r;w=q;e=s}else{A=r;B=q;break}}}else{A=z;B=x}e=B>>19;if(e>>>0>255>>>0){C=-e>>31&255}else{C=e&255}e=n<<1;a[j+e|0]=C;w=A>>19;if(w>>>0>255>>>0){D=-w>>31&255}else{D=w&255}a[j+(e|1)|0]=D;n=n+1|0;}while((n|0)<(k|0));return}}function wvb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;z=(k|0)>0;A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=m;m=0;while(1){if(o){H=0;I=512;do{I=(ba(b[e+(H<<1)>>1]|0,b[(c[f+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+I|0;H=H+1|0;}while((H|0)<(g|0));J=I>>10}else{J=0}if(z){H=0;K=-67108352;L=-67108352;do{M=b[h+(H<<1)>>1]|0;K=(ba(M,b[(c[i+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+K|0;L=(ba(b[(c[j+(H<<2)>>2]|0)+(m<<1)>>1]|0,M)|0)+L|0;H=H+1|0;}while((H|0)<(k|0));N=K>>10;O=L>>10}else{N=-65536;O=-65536}do{if(o){H=262144;I=0;do{H=(ba(b[e+(I<<1)>>1]|0,b[(c[l+(I<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;I=I+1|0;}while((I|0)<(g|0));I=H>>19;if(!((I&256|0)!=0&I>>>0>255>>>0)){P=I&255;break}P=-I>>31&255}else{P=0}}while(0);L=(ba(J-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;K=L+(ba(c[C>>2]|0,O)|0)|0;I=(ba(c[D>>2]|0,O)|0)+L|0;M=I+(ba(c[E>>2]|0,N)|0)|0;I=(ba(c[F>>2]|0,N)|0)+L|0;L=K>>>22&255;Q=M>>>22&255;R=I>>>22&255;do{if((M|K|I)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){S=L}else{S=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){T=Q}else{T=-M>>31>>>22&255}if(I>>>0<1073741824>>>0){U=R;V=T;W=S;break}U=-I>>31>>>22&255;V=T;W=S}else{U=R;V=Q;W=L}}while(0);a[G]=W;a[G+1|0]=V;a[G+2|0]=U;a[G+3|0]=P;L=m+1|0;if((L|0)<(n|0)){G=G+4|0;m=L}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function xvb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-k|0;r=4096-l|0;if((j|0)<=0){s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=0;J=i;while(1){i=ba(b[m+(I<<1)>>1]|0,h)|0;K=(ba(b[n+(I<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(I<<1)>>1]|0,r)|0;L=i-67108864+(ba(b[o+(I<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(I<<1)>>1]|0,r)|0;M=i-67108864+(ba(b[p+(I<<1)>>1]|0,l)|0)>>10;i=ba(b[g+(I<<1)>>1]|0,h)|0;N=i+262144+(ba(b[q+(I<<1)>>1]|0,k)|0)>>19;if((N&256|0)!=0&N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}N=(ba(K-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;K=N+(ba(c[E>>2]|0,M)|0)|0;i=(ba(c[F>>2]|0,M)|0)+N|0;M=i+(ba(c[G>>2]|0,L)|0)|0;i=(ba(c[H>>2]|0,L)|0)+N|0;N=K>>>22&255;L=M>>>22&255;P=i>>>22&255;do{if((M|K|i)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){Q=N}else{Q=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){R=L}else{R=-M>>31>>>22&255}if(i>>>0<1073741824>>>0){S=P;T=R;U=Q;break}S=-i>>31>>>22&255;T=R;U=Q}else{S=P;T=L;U=N}}while(0);a[J]=U;a[J+1|0]=T;a[J+2|0]=S;a[J+3|0]=O;N=I+1|0;if((N|0)<(j|0)){I=N;J=J+4|0}else{s=j;break}}t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}function yvb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}k=d+11300|0;x=d+11304|0;y=d+11308|0;z=d+11312|0;A=d+11316|0;B=d+11320|0;C=0;D=i;while(1){E=(b[l+(C<<1)>>1]<<2)-65536|0;F=(b[m+(C<<1)>>1]<<2)-65536|0;G=(b[h+(C<<1)>>1]|0)+64>>7;if((G&256|0)!=0&G>>>0>255>>>0){H=-G>>31&255}else{H=G&255}G=(ba((b[e+(C<<1)>>1]<<2)-(c[k>>2]|0)|0,c[x>>2]|0)|0)+2097152|0;I=G+(ba(c[y>>2]|0,F)|0)|0;J=(ba(c[z>>2]|0,F)|0)+G|0;F=J+(ba(c[A>>2]|0,E)|0)|0;J=(ba(c[B>>2]|0,E)|0)+G|0;G=I>>>22&255;E=F>>>22&255;K=J>>>22&255;do{if((F|I|J)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){L=G}else{L=-I>>31>>>22&255}if(F>>>0<1073741824>>>0){M=E}else{M=-F>>31>>>22&255}if(J>>>0<1073741824>>>0){N=K;O=M;P=L;break}N=-J>>31>>>22&255;O=M;P=L}else{N=K;O=E;P=G}}while(0);a[D]=P;a[D+1|0]=O;a[D+2|0]=N;a[D+3|0]=H;G=C+1|0;if((G|0)<(j|0)){C=G;D=D+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}else{D=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}g=d+11300|0;C=d+11304|0;H=d+11308|0;N=d+11312|0;O=d+11316|0;P=d+11320|0;L=0;M=i;while(1){i=((b[D+(L<<1)>>1]|0)+(b[l+(L<<1)>>1]|0)<<1)-65536|0;B=((b[f+(L<<1)>>1]|0)+(b[m+(L<<1)>>1]|0)<<1)-65536|0;A=(b[h+(L<<1)>>1]|0)+64>>7;if((A&256|0)!=0&A>>>0>255>>>0){Q=-A>>31&255}else{Q=A&255}A=(ba((b[e+(L<<1)>>1]<<2)-(c[g>>2]|0)|0,c[C>>2]|0)|0)+2097152|0;z=A+(ba(c[H>>2]|0,B)|0)|0;y=(ba(c[N>>2]|0,B)|0)+A|0;B=y+(ba(c[O>>2]|0,i)|0)|0;y=(ba(c[P>>2]|0,i)|0)+A|0;A=z>>>22&255;i=B>>>22&255;x=y>>>22&255;do{if((B|z|y)>>>0>1073741823>>>0){if(z>>>0<1073741824>>>0){R=A}else{R=-z>>31>>>22&255}if(B>>>0<1073741824>>>0){S=i}else{S=-B>>31>>>22&255}if(y>>>0<1073741824>>>0){T=x;U=S;V=R;break}T=-y>>31>>>22&255;U=S;V=R}else{T=x;U=i;V=A}}while(0);a[M]=V;a[M+1|0]=U;a[M+2|0]=T;a[M+3|0]=Q;A=L+1|0;if((A|0)<(j|0)){L=A;M=M+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}}function zvb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ba(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ba(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ba(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ba(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ba(c[B>>2]|0,N)|0)|0;L=(ba(c[C>>2]|0,N)|0)+G|0;O=L+(ba(c[D>>2]|0,M)|0)|0;L=(ba(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=V;a[F+1|0]=U;a[F+2|0]=T;a[F+3|0]=-1;G=m+1|0;if((G|0)<(n|0)){F=F+4|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function Avb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ba(b[m+(G<<1)>>1]|0,g)|0;I=(ba(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ba(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ba(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ba(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ba(K,c[C>>2]|0)|0)+i|0;L=(ba(c[D>>2]|0,K)|0)+i|0;K=L+(ba(c[E>>2]|0,J)|0)|0;L=(ba(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=R;a[H+1|0]=Q;a[H+2|0]=P;a[H+3|0]=-1;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+4|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function Bvb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ba((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ba(c[p>>2]|0,w)|0)|0;z=(ba(c[q>>2]|0,w)|0)+x|0;w=z+(ba(c[r>>2]|0,v)|0)|0;z=(ba(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=F;a[u+1|0]=E;a[u+2|0]=D;a[u+3|0]=-1;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+4|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ba((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ba(z,c[q>>2]|0)|0)+w|0;G=(ba(c[p>>2]|0,z)|0)+w|0;z=G+(ba(c[o>>2]|0,A)|0)|0;G=(ba(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=M;a[v+1|0]=L;a[v+2|0]=K;a[v+3|0]=-1;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+4|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function Cvb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;z=(k|0)>0;A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=m;m=0;while(1){if(o){H=0;I=512;do{I=(ba(b[e+(H<<1)>>1]|0,b[(c[f+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+I|0;H=H+1|0;}while((H|0)<(g|0));J=I>>10}else{J=0}if(z){H=0;K=-67108352;L=-67108352;do{M=b[h+(H<<1)>>1]|0;K=(ba(M,b[(c[i+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+K|0;L=(ba(b[(c[j+(H<<2)>>2]|0)+(m<<1)>>1]|0,M)|0)+L|0;H=H+1|0;}while((H|0)<(k|0));N=K>>10;O=L>>10}else{N=-65536;O=-65536}do{if(o){H=262144;I=0;do{H=(ba(b[e+(I<<1)>>1]|0,b[(c[l+(I<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;I=I+1|0;}while((I|0)<(g|0));I=H>>19;if(!((I&256|0)!=0&I>>>0>255>>>0)){P=I&255;break}P=-I>>31&255}else{P=0}}while(0);L=(ba(J-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;K=L+(ba(c[C>>2]|0,O)|0)|0;I=(ba(c[D>>2]|0,O)|0)+L|0;M=I+(ba(c[E>>2]|0,N)|0)|0;I=(ba(c[F>>2]|0,N)|0)+L|0;L=K>>>22&255;Q=M>>>22&255;R=I>>>22&255;do{if((M|K|I)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){S=L}else{S=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){T=Q}else{T=-M>>31>>>22&255}if(I>>>0<1073741824>>>0){U=R;V=T;W=S;break}U=-I>>31>>>22&255;V=T;W=S}else{U=R;V=Q;W=L}}while(0);a[G]=P;a[G+1|0]=W;a[G+2|0]=V;a[G+3|0]=U;L=m+1|0;if((L|0)<(n|0)){G=G+4|0;m=L}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function Dvb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-k|0;r=4096-l|0;if((j|0)<=0){s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=0;J=i;while(1){i=ba(b[m+(I<<1)>>1]|0,h)|0;K=(ba(b[n+(I<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(I<<1)>>1]|0,r)|0;L=i-67108864+(ba(b[o+(I<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(I<<1)>>1]|0,r)|0;M=i-67108864+(ba(b[p+(I<<1)>>1]|0,l)|0)>>10;i=ba(b[g+(I<<1)>>1]|0,h)|0;N=i+262144+(ba(b[q+(I<<1)>>1]|0,k)|0)>>19;if((N&256|0)!=0&N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}N=(ba(K-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;K=N+(ba(c[E>>2]|0,M)|0)|0;i=(ba(c[F>>2]|0,M)|0)+N|0;M=i+(ba(c[G>>2]|0,L)|0)|0;i=(ba(c[H>>2]|0,L)|0)+N|0;N=K>>>22&255;L=M>>>22&255;P=i>>>22&255;do{if((M|K|i)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){Q=N}else{Q=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){R=L}else{R=-M>>31>>>22&255}if(i>>>0<1073741824>>>0){S=P;T=R;U=Q;break}S=-i>>31>>>22&255;T=R;U=Q}else{S=P;T=L;U=N}}while(0);a[J]=O;a[J+1|0]=U;a[J+2|0]=T;a[J+3|0]=S;N=I+1|0;if((N|0)<(j|0)){I=N;J=J+4|0}else{s=j;break}}t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}function Evb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}k=d+11300|0;x=d+11304|0;y=d+11308|0;z=d+11312|0;A=d+11316|0;B=d+11320|0;C=0;D=i;while(1){E=(b[l+(C<<1)>>1]<<2)-65536|0;F=(b[m+(C<<1)>>1]<<2)-65536|0;G=(b[h+(C<<1)>>1]|0)+64>>7;if((G&256|0)!=0&G>>>0>255>>>0){H=-G>>31&255}else{H=G&255}G=(ba((b[e+(C<<1)>>1]<<2)-(c[k>>2]|0)|0,c[x>>2]|0)|0)+2097152|0;I=G+(ba(c[y>>2]|0,F)|0)|0;J=(ba(c[z>>2]|0,F)|0)+G|0;F=J+(ba(c[A>>2]|0,E)|0)|0;J=(ba(c[B>>2]|0,E)|0)+G|0;G=I>>>22&255;E=F>>>22&255;K=J>>>22&255;do{if((F|I|J)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){L=G}else{L=-I>>31>>>22&255}if(F>>>0<1073741824>>>0){M=E}else{M=-F>>31>>>22&255}if(J>>>0<1073741824>>>0){N=K;O=M;P=L;break}N=-J>>31>>>22&255;O=M;P=L}else{N=K;O=E;P=G}}while(0);a[D]=H;a[D+1|0]=P;a[D+2|0]=O;a[D+3|0]=N;G=C+1|0;if((G|0)<(j|0)){C=G;D=D+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}else{D=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}g=d+11300|0;C=d+11304|0;N=d+11308|0;O=d+11312|0;P=d+11316|0;H=d+11320|0;L=0;M=i;while(1){i=((b[D+(L<<1)>>1]|0)+(b[l+(L<<1)>>1]|0)<<1)-65536|0;B=((b[f+(L<<1)>>1]|0)+(b[m+(L<<1)>>1]|0)<<1)-65536|0;A=(b[h+(L<<1)>>1]|0)+64>>7;if((A&256|0)!=0&A>>>0>255>>>0){Q=-A>>31&255}else{Q=A&255}A=(ba((b[e+(L<<1)>>1]<<2)-(c[g>>2]|0)|0,c[C>>2]|0)|0)+2097152|0;z=A+(ba(c[N>>2]|0,B)|0)|0;y=(ba(c[O>>2]|0,B)|0)+A|0;B=y+(ba(c[P>>2]|0,i)|0)|0;y=(ba(c[H>>2]|0,i)|0)+A|0;A=z>>>22&255;i=B>>>22&255;x=y>>>22&255;do{if((B|z|y)>>>0>1073741823>>>0){if(z>>>0<1073741824>>>0){R=A}else{R=-z>>31>>>22&255}if(B>>>0<1073741824>>>0){S=i}else{S=-B>>31>>>22&255}if(y>>>0<1073741824>>>0){T=x;U=S;V=R;break}T=-y>>31>>>22&255;U=S;V=R}else{T=x;U=i;V=A}}while(0);a[M]=Q;a[M+1|0]=V;a[M+2|0]=U;a[M+3|0]=T;A=L+1|0;if((A|0)<(j|0)){L=A;M=M+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}}function Fvb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ba(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ba(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ba(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ba(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ba(c[B>>2]|0,N)|0)|0;L=(ba(c[C>>2]|0,N)|0)+G|0;O=L+(ba(c[D>>2]|0,M)|0)|0;L=(ba(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=-1;a[F+1|0]=V;a[F+2|0]=U;a[F+3|0]=T;G=m+1|0;if((G|0)<(n|0)){F=F+4|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function Gvb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ba(b[m+(G<<1)>>1]|0,g)|0;I=(ba(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ba(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ba(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ba(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ba(K,c[C>>2]|0)|0)+i|0;L=(ba(c[D>>2]|0,K)|0)+i|0;K=L+(ba(c[E>>2]|0,J)|0)|0;L=(ba(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=-1;a[H+1|0]=R;a[H+2|0]=Q;a[H+3|0]=P;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+4|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function Hvb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ba((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ba(c[p>>2]|0,w)|0)|0;z=(ba(c[q>>2]|0,w)|0)+x|0;w=z+(ba(c[r>>2]|0,v)|0)|0;z=(ba(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=-1;a[u+1|0]=F;a[u+2|0]=E;a[u+3|0]=D;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+4|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ba((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ba(z,c[q>>2]|0)|0)+w|0;G=(ba(c[p>>2]|0,z)|0)+w|0;z=G+(ba(c[o>>2]|0,A)|0)|0;G=(ba(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=-1;a[v+1|0]=M;a[v+2|0]=L;a[v+3|0]=K;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+4|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function Ivb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;z=(k|0)>0;A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=m;m=0;while(1){if(o){H=0;I=512;do{I=(ba(b[e+(H<<1)>>1]|0,b[(c[f+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+I|0;H=H+1|0;}while((H|0)<(g|0));J=I>>10}else{J=0}if(z){H=0;K=-67108352;L=-67108352;do{M=b[h+(H<<1)>>1]|0;K=(ba(M,b[(c[i+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+K|0;L=(ba(b[(c[j+(H<<2)>>2]|0)+(m<<1)>>1]|0,M)|0)+L|0;H=H+1|0;}while((H|0)<(k|0));N=K>>10;O=L>>10}else{N=-65536;O=-65536}do{if(o){H=262144;I=0;do{H=(ba(b[e+(I<<1)>>1]|0,b[(c[l+(I<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;I=I+1|0;}while((I|0)<(g|0));I=H>>19;if(!((I&256|0)!=0&I>>>0>255>>>0)){P=I&255;break}P=-I>>31&255}else{P=0}}while(0);L=(ba(J-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;K=L+(ba(c[C>>2]|0,O)|0)|0;I=(ba(c[D>>2]|0,O)|0)+L|0;M=I+(ba(c[E>>2]|0,N)|0)|0;I=(ba(c[F>>2]|0,N)|0)+L|0;L=K>>>22&255;Q=M>>>22&255;R=I>>>22&255;do{if((M|K|I)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){S=L}else{S=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){T=Q}else{T=-M>>31>>>22&255}if(I>>>0<1073741824>>>0){U=R;V=T;W=S;break}U=-I>>31>>>22&255;V=T;W=S}else{U=R;V=Q;W=L}}while(0);a[G]=U;a[G+1|0]=V;a[G+2|0]=W;a[G+3|0]=P;L=m+1|0;if((L|0)<(n|0)){G=G+4|0;m=L}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function Jvb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-k|0;r=4096-l|0;if((j|0)<=0){s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=0;J=i;while(1){i=ba(b[m+(I<<1)>>1]|0,h)|0;K=(ba(b[n+(I<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(I<<1)>>1]|0,r)|0;L=i-67108864+(ba(b[o+(I<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(I<<1)>>1]|0,r)|0;M=i-67108864+(ba(b[p+(I<<1)>>1]|0,l)|0)>>10;i=ba(b[g+(I<<1)>>1]|0,h)|0;N=i+262144+(ba(b[q+(I<<1)>>1]|0,k)|0)>>19;if((N&256|0)!=0&N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}N=(ba(K-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;K=N+(ba(c[E>>2]|0,M)|0)|0;i=(ba(c[F>>2]|0,M)|0)+N|0;M=i+(ba(c[G>>2]|0,L)|0)|0;i=(ba(c[H>>2]|0,L)|0)+N|0;N=K>>>22&255;L=M>>>22&255;P=i>>>22&255;do{if((M|K|i)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){Q=N}else{Q=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){R=L}else{R=-M>>31>>>22&255}if(i>>>0<1073741824>>>0){S=P;T=R;U=Q;break}S=-i>>31>>>22&255;T=R;U=Q}else{S=P;T=L;U=N}}while(0);a[J]=S;a[J+1|0]=T;a[J+2|0]=U;a[J+3|0]=O;N=I+1|0;if((N|0)<(j|0)){I=N;J=J+4|0}else{s=j;break}}t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}function Kvb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}k=d+11300|0;x=d+11304|0;y=d+11308|0;z=d+11312|0;A=d+11316|0;B=d+11320|0;C=0;D=i;while(1){E=(b[l+(C<<1)>>1]<<2)-65536|0;F=(b[m+(C<<1)>>1]<<2)-65536|0;G=(b[h+(C<<1)>>1]|0)+64>>7;if((G&256|0)!=0&G>>>0>255>>>0){H=-G>>31&255}else{H=G&255}G=(ba((b[e+(C<<1)>>1]<<2)-(c[k>>2]|0)|0,c[x>>2]|0)|0)+2097152|0;I=G+(ba(c[y>>2]|0,F)|0)|0;J=(ba(c[z>>2]|0,F)|0)+G|0;F=J+(ba(c[A>>2]|0,E)|0)|0;J=(ba(c[B>>2]|0,E)|0)+G|0;G=I>>>22&255;E=F>>>22&255;K=J>>>22&255;do{if((F|I|J)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){L=G}else{L=-I>>31>>>22&255}if(F>>>0<1073741824>>>0){M=E}else{M=-F>>31>>>22&255}if(J>>>0<1073741824>>>0){N=K;O=M;P=L;break}N=-J>>31>>>22&255;O=M;P=L}else{N=K;O=E;P=G}}while(0);a[D]=N;a[D+1|0]=O;a[D+2|0]=P;a[D+3|0]=H;G=C+1|0;if((G|0)<(j|0)){C=G;D=D+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}else{D=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}g=d+11300|0;C=d+11304|0;H=d+11308|0;P=d+11312|0;O=d+11316|0;N=d+11320|0;L=0;M=i;while(1){i=((b[D+(L<<1)>>1]|0)+(b[l+(L<<1)>>1]|0)<<1)-65536|0;B=((b[f+(L<<1)>>1]|0)+(b[m+(L<<1)>>1]|0)<<1)-65536|0;A=(b[h+(L<<1)>>1]|0)+64>>7;if((A&256|0)!=0&A>>>0>255>>>0){Q=-A>>31&255}else{Q=A&255}A=(ba((b[e+(L<<1)>>1]<<2)-(c[g>>2]|0)|0,c[C>>2]|0)|0)+2097152|0;z=A+(ba(c[H>>2]|0,B)|0)|0;y=(ba(c[P>>2]|0,B)|0)+A|0;B=y+(ba(c[O>>2]|0,i)|0)|0;y=(ba(c[N>>2]|0,i)|0)+A|0;A=z>>>22&255;i=B>>>22&255;x=y>>>22&255;do{if((B|z|y)>>>0>1073741823>>>0){if(z>>>0<1073741824>>>0){R=A}else{R=-z>>31>>>22&255}if(B>>>0<1073741824>>>0){S=i}else{S=-B>>31>>>22&255}if(y>>>0<1073741824>>>0){T=x;U=S;V=R;break}T=-y>>31>>>22&255;U=S;V=R}else{T=x;U=i;V=A}}while(0);a[M]=T;a[M+1|0]=U;a[M+2|0]=V;a[M+3|0]=Q;A=L+1|0;if((A|0)<(j|0)){L=A;M=M+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}}function Lvb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ba(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ba(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ba(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ba(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ba(c[B>>2]|0,N)|0)|0;L=(ba(c[C>>2]|0,N)|0)+G|0;O=L+(ba(c[D>>2]|0,M)|0)|0;L=(ba(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=T;a[F+1|0]=U;a[F+2|0]=V;a[F+3|0]=-1;G=m+1|0;if((G|0)<(n|0)){F=F+4|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function Mvb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ba(b[m+(G<<1)>>1]|0,g)|0;I=(ba(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ba(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ba(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ba(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ba(K,c[C>>2]|0)|0)+i|0;L=(ba(c[D>>2]|0,K)|0)+i|0;K=L+(ba(c[E>>2]|0,J)|0)|0;L=(ba(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=P;a[H+1|0]=Q;a[H+2|0]=R;a[H+3|0]=-1;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+4|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function Nvb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ba((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ba(c[p>>2]|0,w)|0)|0;z=(ba(c[q>>2]|0,w)|0)+x|0;w=z+(ba(c[r>>2]|0,v)|0)|0;z=(ba(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=D;a[u+1|0]=E;a[u+2|0]=F;a[u+3|0]=-1;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+4|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ba((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ba(z,c[q>>2]|0)|0)+w|0;G=(ba(c[p>>2]|0,z)|0)+w|0;z=G+(ba(c[o>>2]|0,A)|0)|0;G=(ba(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=K;a[v+1|0]=L;a[v+2|0]=M;a[v+3|0]=-1;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+4|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function Ovb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;z=(k|0)>0;A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=m;m=0;while(1){if(o){H=0;I=512;do{I=(ba(b[e+(H<<1)>>1]|0,b[(c[f+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+I|0;H=H+1|0;}while((H|0)<(g|0));J=I>>10}else{J=0}if(z){H=0;K=-67108352;L=-67108352;do{M=b[h+(H<<1)>>1]|0;K=(ba(M,b[(c[i+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+K|0;L=(ba(b[(c[j+(H<<2)>>2]|0)+(m<<1)>>1]|0,M)|0)+L|0;H=H+1|0;}while((H|0)<(k|0));N=K>>10;O=L>>10}else{N=-65536;O=-65536}do{if(o){H=262144;I=0;do{H=(ba(b[e+(I<<1)>>1]|0,b[(c[l+(I<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;I=I+1|0;}while((I|0)<(g|0));I=H>>19;if(!((I&256|0)!=0&I>>>0>255>>>0)){P=I&255;break}P=-I>>31&255}else{P=0}}while(0);L=(ba(J-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;K=L+(ba(c[C>>2]|0,O)|0)|0;I=(ba(c[D>>2]|0,O)|0)+L|0;M=I+(ba(c[E>>2]|0,N)|0)|0;I=(ba(c[F>>2]|0,N)|0)+L|0;L=K>>>22&255;Q=M>>>22&255;R=I>>>22&255;do{if((M|K|I)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){S=L}else{S=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){T=Q}else{T=-M>>31>>>22&255}if(I>>>0<1073741824>>>0){U=R;V=T;W=S;break}U=-I>>31>>>22&255;V=T;W=S}else{U=R;V=Q;W=L}}while(0);a[G]=P;a[G+1|0]=U;a[G+2|0]=V;a[G+3|0]=W;L=m+1|0;if((L|0)<(n|0)){G=G+4|0;m=L}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function Pvb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-k|0;r=4096-l|0;if((j|0)<=0){s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=0;J=i;while(1){i=ba(b[m+(I<<1)>>1]|0,h)|0;K=(ba(b[n+(I<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(I<<1)>>1]|0,r)|0;L=i-67108864+(ba(b[o+(I<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(I<<1)>>1]|0,r)|0;M=i-67108864+(ba(b[p+(I<<1)>>1]|0,l)|0)>>10;i=ba(b[g+(I<<1)>>1]|0,h)|0;N=i+262144+(ba(b[q+(I<<1)>>1]|0,k)|0)>>19;if((N&256|0)!=0&N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}N=(ba(K-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;K=N+(ba(c[E>>2]|0,M)|0)|0;i=(ba(c[F>>2]|0,M)|0)+N|0;M=i+(ba(c[G>>2]|0,L)|0)|0;i=(ba(c[H>>2]|0,L)|0)+N|0;N=K>>>22&255;L=M>>>22&255;P=i>>>22&255;do{if((M|K|i)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){Q=N}else{Q=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){R=L}else{R=-M>>31>>>22&255}if(i>>>0<1073741824>>>0){S=P;T=R;U=Q;break}S=-i>>31>>>22&255;T=R;U=Q}else{S=P;T=L;U=N}}while(0);a[J]=O;a[J+1|0]=S;a[J+2|0]=T;a[J+3|0]=U;N=I+1|0;if((N|0)<(j|0)){I=N;J=J+4|0}else{s=j;break}}t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}function Qvb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}k=d+11300|0;x=d+11304|0;y=d+11308|0;z=d+11312|0;A=d+11316|0;B=d+11320|0;C=0;D=i;while(1){E=(b[l+(C<<1)>>1]<<2)-65536|0;F=(b[m+(C<<1)>>1]<<2)-65536|0;G=(b[h+(C<<1)>>1]|0)+64>>7;if((G&256|0)!=0&G>>>0>255>>>0){H=-G>>31&255}else{H=G&255}G=(ba((b[e+(C<<1)>>1]<<2)-(c[k>>2]|0)|0,c[x>>2]|0)|0)+2097152|0;I=G+(ba(c[y>>2]|0,F)|0)|0;J=(ba(c[z>>2]|0,F)|0)+G|0;F=J+(ba(c[A>>2]|0,E)|0)|0;J=(ba(c[B>>2]|0,E)|0)+G|0;G=I>>>22&255;E=F>>>22&255;K=J>>>22&255;do{if((F|I|J)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){L=G}else{L=-I>>31>>>22&255}if(F>>>0<1073741824>>>0){M=E}else{M=-F>>31>>>22&255}if(J>>>0<1073741824>>>0){N=K;O=M;P=L;break}N=-J>>31>>>22&255;O=M;P=L}else{N=K;O=E;P=G}}while(0);a[D]=H;a[D+1|0]=N;a[D+2|0]=O;a[D+3|0]=P;G=C+1|0;if((G|0)<(j|0)){C=G;D=D+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}else{D=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}g=d+11300|0;C=d+11304|0;P=d+11308|0;O=d+11312|0;N=d+11316|0;H=d+11320|0;L=0;M=i;while(1){i=((b[D+(L<<1)>>1]|0)+(b[l+(L<<1)>>1]|0)<<1)-65536|0;B=((b[f+(L<<1)>>1]|0)+(b[m+(L<<1)>>1]|0)<<1)-65536|0;A=(b[h+(L<<1)>>1]|0)+64>>7;if((A&256|0)!=0&A>>>0>255>>>0){Q=-A>>31&255}else{Q=A&255}A=(ba((b[e+(L<<1)>>1]<<2)-(c[g>>2]|0)|0,c[C>>2]|0)|0)+2097152|0;z=A+(ba(c[P>>2]|0,B)|0)|0;y=(ba(c[O>>2]|0,B)|0)+A|0;B=y+(ba(c[N>>2]|0,i)|0)|0;y=(ba(c[H>>2]|0,i)|0)+A|0;A=z>>>22&255;i=B>>>22&255;x=y>>>22&255;do{if((B|z|y)>>>0>1073741823>>>0){if(z>>>0<1073741824>>>0){R=A}else{R=-z>>31>>>22&255}if(B>>>0<1073741824>>>0){S=i}else{S=-B>>31>>>22&255}if(y>>>0<1073741824>>>0){T=x;U=S;V=R;break}T=-y>>31>>>22&255;U=S;V=R}else{T=x;U=i;V=A}}while(0);a[M]=Q;a[M+1|0]=T;a[M+2|0]=U;a[M+3|0]=V;A=L+1|0;if((A|0)<(j|0)){L=A;M=M+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}}function Rvb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ba(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ba(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ba(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ba(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ba(c[B>>2]|0,N)|0)|0;L=(ba(c[C>>2]|0,N)|0)+G|0;O=L+(ba(c[D>>2]|0,M)|0)|0;L=(ba(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=-1;a[F+1|0]=T;a[F+2|0]=U;a[F+3|0]=V;G=m+1|0;if((G|0)<(n|0)){F=F+4|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function Svb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ba(b[m+(G<<1)>>1]|0,g)|0;I=(ba(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ba(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ba(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ba(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ba(K,c[C>>2]|0)|0)+i|0;L=(ba(c[D>>2]|0,K)|0)+i|0;K=L+(ba(c[E>>2]|0,J)|0)|0;L=(ba(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=-1;a[H+1|0]=P;a[H+2|0]=Q;a[H+3|0]=R;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+4|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function Tvb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ba((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ba(c[p>>2]|0,w)|0)|0;z=(ba(c[q>>2]|0,w)|0)+x|0;w=z+(ba(c[r>>2]|0,v)|0)|0;z=(ba(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=-1;a[u+1|0]=D;a[u+2|0]=E;a[u+3|0]=F;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+4|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ba((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ba(z,c[q>>2]|0)|0)+w|0;G=(ba(c[p>>2]|0,z)|0)+w|0;z=G+(ba(c[o>>2]|0,A)|0)|0;G=(ba(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=-1;a[v+1|0]=K;a[v+2|0]=L;a[v+3|0]=M;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+4|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function Uvb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ba(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ba(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ba(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ba(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ba(c[B>>2]|0,N)|0)|0;L=(ba(c[C>>2]|0,N)|0)+G|0;O=L+(ba(c[D>>2]|0,M)|0)|0;L=(ba(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=V;a[F+1|0]=U;a[F+2|0]=T;G=m+1|0;if((G|0)<(n|0)){F=F+3|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function Vvb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ba(b[m+(G<<1)>>1]|0,g)|0;I=(ba(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ba(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ba(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ba(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ba(K,c[C>>2]|0)|0)+i|0;L=(ba(c[D>>2]|0,K)|0)+i|0;K=L+(ba(c[E>>2]|0,J)|0)|0;L=(ba(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=R;a[H+1|0]=Q;a[H+2|0]=P;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+3|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function Wvb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ba((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ba(c[p>>2]|0,w)|0)|0;z=(ba(c[q>>2]|0,w)|0)+x|0;w=z+(ba(c[r>>2]|0,v)|0)|0;z=(ba(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=F;a[u+1|0]=E;a[u+2|0]=D;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+3|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ba((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ba(z,c[q>>2]|0)|0)+w|0;G=(ba(c[p>>2]|0,z)|0)+w|0;z=G+(ba(c[o>>2]|0,A)|0)|0;G=(ba(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=M;a[v+1|0]=L;a[v+2|0]=K;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+3|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function Xvb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ba(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ba(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ba(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ba(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ba(c[B>>2]|0,N)|0)|0;L=(ba(c[C>>2]|0,N)|0)+G|0;O=L+(ba(c[D>>2]|0,M)|0)|0;L=(ba(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=T;a[F+1|0]=U;a[F+2|0]=V;G=m+1|0;if((G|0)<(n|0)){F=F+3|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function Yvb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ba(b[m+(G<<1)>>1]|0,g)|0;I=(ba(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ba(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ba(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ba(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ba(K,c[C>>2]|0)|0)+i|0;L=(ba(c[D>>2]|0,K)|0)+i|0;K=L+(ba(c[E>>2]|0,J)|0)|0;L=(ba(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=P;a[H+1|0]=Q;a[H+2|0]=R;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+3|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function Zvb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ba((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ba(c[p>>2]|0,w)|0)|0;z=(ba(c[q>>2]|0,w)|0)+x|0;w=z+(ba(c[r>>2]|0,v)|0)|0;z=(ba(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=D;a[u+1|0]=E;a[u+2|0]=F;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+3|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ba((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ba(z,c[q>>2]|0)|0)+w|0;G=(ba(c[p>>2]|0,z)|0)+w|0;z=G+(ba(c[o>>2]|0,A)|0)|0;G=(ba(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=K;a[v+1|0]=L;a[v+2|0]=M;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+3|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function _vb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;if((n|0)<=0){p=0;q=0;r=0;s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}o=(g|0)>0;l=(k|0)>0;C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=d+11200|0;J=d+11204|0;K=d+11208|0;d=0;L=0;M=0;N=m;m=0;while(1){if(o){O=0;P=512;do{P=(ba(b[e+(O<<1)>>1]|0,b[(c[f+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+P|0;O=O+1|0;}while((O|0)<(g|0));Q=P>>10}else{Q=0}if(l){O=0;R=-67108352;S=-67108352;do{T=b[h+(O<<1)>>1]|0;R=(ba(T,b[(c[i+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+R|0;S=(ba(b[(c[j+(O<<2)>>2]|0)+(m<<1)>>1]|0,T)|0)+S|0;O=O+1|0;}while((O|0)<(k|0));U=R>>10;V=S>>10}else{U=-65536;V=-65536}O=(ba(Q-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;P=O+(ba(c[E>>2]|0,V)|0)|0;T=(ba(c[F>>2]|0,V)|0)+O|0;W=T+(ba(c[G>>2]|0,U)|0)|0;T=(ba(c[H>>2]|0,U)|0)+O|0;do{if((W|P|T)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){X=P}else{X=-P>>31&1073741823}if(W>>>0<1073741824>>>0){Y=W}else{Y=-W>>31&1073741823}if(T>>>0<1073741824>>>0){Z=T;_=Y;$=X;break}Z=-T>>31&1073741823;_=Y;$=X}else{Z=T;_=W;$=P}}while(0);P=c[I>>2]|0;W=P+(m<<2)|0;T=m+1|0;S=m+2|0;R=((c[W>>2]|0)+(M*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+($>>22)|0;P=c[J>>2]|0;O=P+(m<<2)|0;aa=((c[O>>2]|0)+(L*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(_>>22)|0;P=c[K>>2]|0;ca=P+(m<<2)|0;da=((c[ca>>2]|0)+(d*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(Z>>22)|0;c[W>>2]=M;c[O>>2]=L;c[ca>>2]=d;ca=R>>7;O=aa>>6;W=da>>7;if((ca|0)<0){ea=0}else{ea=(ca|0)>1?1:ca}if((O|0)<0){fa=0}else{fa=(O|0)>3?3:O}if((W|0)<0){ga=0}else{ga=(W|0)>1?1:W}W=(ea*-255|0)+R|0;R=(fa*-85|0)+aa|0;aa=(ga*-255|0)+da|0;a[N]=(fa<<1)+ea+(ga<<3);if((T|0)<(n|0)){d=aa;L=R;M=W;N=N+1|0;m=T}else{p=aa;q=R;r=W;s=n;t=I;u=J;v=K;break}}w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}function $vb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=0;s=0;t=0;u=d+11200|0;v=d+11204|0;w=d+11208|0;x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}D=d+11300|0;E=d+11304|0;F=d+11308|0;G=d+11312|0;H=d+11316|0;I=d+11320|0;J=d+11200|0;K=d+11204|0;L=d+11208|0;d=0;M=0;N=0;O=0;P=i;while(1){i=ba(b[m+(O<<1)>>1]|0,g)|0;Q=(ba(b[h+(O<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(O<<1)>>1]|0,p)|0;R=i-67108864+(ba(b[n+(O<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(O<<1)>>1]|0,p)|0;S=i-67108864+(ba(b[o+(O<<1)>>1]|0,l)|0)>>10;i=(ba(Q-(c[D>>2]|0)|0,c[E>>2]|0)|0)+2097152|0;Q=(ba(S,c[F>>2]|0)|0)+i|0;T=(ba(c[G>>2]|0,S)|0)+i|0;S=T+(ba(c[H>>2]|0,R)|0)|0;T=(ba(c[I>>2]|0,R)|0)+i|0;do{if((S|Q|T)>>>0>1073741823>>>0){if(Q>>>0<1073741824>>>0){U=Q}else{U=-Q>>31&1073741823}if(S>>>0<1073741824>>>0){V=S}else{V=-S>>31&1073741823}if(T>>>0<1073741824>>>0){W=T;X=V;Y=U;break}W=-T>>31&1073741823;X=V;Y=U}else{W=T;X=S;Y=Q}}while(0);Q=c[J>>2]|0;S=Q+(O<<2)|0;T=O+1|0;i=O+2|0;R=((c[S>>2]|0)+(N*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(Y>>22)|0;Q=c[K>>2]|0;Z=Q+(O<<2)|0;_=((c[Z>>2]|0)+(M*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(X>>22)|0;Q=c[L>>2]|0;$=Q+(O<<2)|0;aa=((c[$>>2]|0)+(d*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(W>>22)|0;c[S>>2]=N;c[Z>>2]=M;c[$>>2]=d;$=R>>7;Z=_>>6;S=aa>>7;if(($|0)<0){ca=0}else{ca=($|0)>1?1:$}if((Z|0)<0){da=0}else{da=(Z|0)>3?3:Z}if((S|0)<0){ea=0}else{ea=(S|0)>1?1:S}S=(ca*-255|0)+R|0;R=(da*-85|0)+_|0;_=(ea*-255|0)+aa|0;a[P]=(da<<1)+ca+(ea<<3);if((T|0)<(j|0)){d=_;M=R;N=S;O=T;P=P+1|0}else{q=_;r=R;s=S;t=j;u=J;v=K;w=L;break}}x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}function awb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}k=d+11300|0;z=d+11304|0;A=d+11308|0;B=d+11312|0;C=d+11316|0;D=d+11320|0;E=d+11200|0;F=d+11204|0;G=d+11208|0;H=0;I=0;J=0;K=0;L=i;while(1){M=(b[l+(K<<1)>>1]<<2)-65536|0;N=(b[h+(K<<1)>>1]<<2)-65536|0;O=(ba((b[e+(K<<1)>>1]<<2)-(c[k>>2]|0)|0,c[z>>2]|0)|0)+2097152|0;P=O+(ba(c[A>>2]|0,N)|0)|0;Q=(ba(c[B>>2]|0,N)|0)+O|0;N=Q+(ba(c[C>>2]|0,M)|0)|0;Q=(ba(c[D>>2]|0,M)|0)+O|0;do{if((N|P|Q)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){R=P}else{R=-P>>31&1073741823}if(N>>>0<1073741824>>>0){S=N}else{S=-N>>31&1073741823}if(Q>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-Q>>31&1073741823;U=S;V=R}else{T=Q;U=N;V=P}}while(0);P=c[E>>2]|0;N=P+(K<<2)|0;Q=K+1|0;O=K+2|0;M=((c[N>>2]|0)+(J*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(V>>22)|0;P=c[F>>2]|0;W=P+(K<<2)|0;X=((c[W>>2]|0)+(I*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(U>>22)|0;P=c[G>>2]|0;Y=P+(K<<2)|0;Z=((c[Y>>2]|0)+(H*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(T>>22)|0;c[N>>2]=J;c[W>>2]=I;c[Y>>2]=H;Y=M>>7;W=X>>6;N=Z>>7;if((Y|0)<0){_=0}else{_=(Y|0)>1?1:Y}if((W|0)<0){$=0}else{$=(W|0)>3?3:W}if((N|0)<0){aa=0}else{aa=(N|0)>1?1:N}N=(_*-255|0)+M|0;M=($*-85|0)+X|0;X=(aa*-255|0)+Z|0;a[L]=($<<1)+_+(aa<<3);if((Q|0)<(j|0)){H=X;I=M;J=N;K=Q;L=L+1|0}else{m=j;n=N;o=M;p=X;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}else{L=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}g=d+11300|0;K=d+11304|0;J=d+11308|0;I=d+11312|0;H=d+11316|0;aa=d+11320|0;_=d+11200|0;$=d+11204|0;T=d+11208|0;G=0;U=0;F=0;V=0;E=i;while(1){i=((b[L+(V<<1)>>1]|0)+(b[l+(V<<1)>>1]|0)<<1)-65536|0;R=((b[f+(V<<1)>>1]|0)+(b[h+(V<<1)>>1]|0)<<1)-65536|0;S=(ba((b[e+(V<<1)>>1]<<2)-(c[g>>2]|0)|0,c[K>>2]|0)|0)+2097152|0;D=(ba(R,c[J>>2]|0)|0)+S|0;C=(ba(c[I>>2]|0,R)|0)+S|0;R=C+(ba(c[H>>2]|0,i)|0)|0;C=(ba(c[aa>>2]|0,i)|0)+S|0;do{if((R|D|C)>>>0>1073741823>>>0){if(D>>>0<1073741824>>>0){ca=D}else{ca=-D>>31&1073741823}if(R>>>0<1073741824>>>0){da=R}else{da=-R>>31&1073741823}if(C>>>0<1073741824>>>0){ea=C;fa=da;ga=ca;break}ea=-C>>31&1073741823;fa=da;ga=ca}else{ea=C;fa=R;ga=D}}while(0);D=c[_>>2]|0;R=D+(V<<2)|0;C=V+1|0;S=V+2|0;i=((c[R>>2]|0)+(F*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ga>>22)|0;D=c[$>>2]|0;B=D+(V<<2)|0;A=((c[B>>2]|0)+(U*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(fa>>22)|0;D=c[T>>2]|0;z=D+(V<<2)|0;k=((c[z>>2]|0)+(G*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ea>>22)|0;c[R>>2]=F;c[B>>2]=U;c[z>>2]=G;z=i>>7;B=A>>6;R=k>>7;if((z|0)<0){ha=0}else{ha=(z|0)>1?1:z}if((B|0)<0){ia=0}else{ia=(B|0)>3?3:B}if((R|0)<0){ja=0}else{ja=(R|0)>1?1:R}R=(ha*-255|0)+i|0;i=(ia*-85|0)+A|0;A=(ja*-255|0)+k|0;a[E]=(ia<<1)+ha+(ja<<3);if((C|0)<(j|0)){G=A;U=i;F=R;V=C;E=E+1|0}else{m=j;n=R;o=i;p=A;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}}function bwb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;if((n|0)<=0){p=0;q=0;r=0;s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}o=(g|0)>0;l=(k|0)>0;C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=d+11200|0;J=d+11204|0;K=d+11208|0;d=0;L=0;M=0;N=m;m=0;while(1){if(o){O=0;P=512;do{P=(ba(b[e+(O<<1)>>1]|0,b[(c[f+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+P|0;O=O+1|0;}while((O|0)<(g|0));Q=P>>10}else{Q=0}if(l){O=0;R=-67108352;S=-67108352;do{T=b[h+(O<<1)>>1]|0;R=(ba(T,b[(c[i+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+R|0;S=(ba(b[(c[j+(O<<2)>>2]|0)+(m<<1)>>1]|0,T)|0)+S|0;O=O+1|0;}while((O|0)<(k|0));U=R>>10;V=S>>10}else{U=-65536;V=-65536}O=(ba(Q-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;P=O+(ba(c[E>>2]|0,V)|0)|0;T=(ba(c[F>>2]|0,V)|0)+O|0;W=T+(ba(c[G>>2]|0,U)|0)|0;T=(ba(c[H>>2]|0,U)|0)+O|0;do{if((W|P|T)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){X=P}else{X=-P>>31&1073741823}if(W>>>0<1073741824>>>0){Y=W}else{Y=-W>>31&1073741823}if(T>>>0<1073741824>>>0){Z=T;_=Y;$=X;break}Z=-T>>31&1073741823;_=Y;$=X}else{Z=T;_=W;$=P}}while(0);P=c[I>>2]|0;W=P+(m<<2)|0;T=m+1|0;S=m+2|0;R=((c[W>>2]|0)+(M*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+($>>22)|0;P=c[J>>2]|0;O=P+(m<<2)|0;aa=((c[O>>2]|0)+(L*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(_>>22)|0;P=c[K>>2]|0;ca=P+(m<<2)|0;da=((c[ca>>2]|0)+(d*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(Z>>22)|0;c[W>>2]=M;c[O>>2]=L;c[ca>>2]=d;ca=R>>7;O=aa>>6;W=da>>7;if((ca|0)<0){ea=0}else{ea=(ca|0)>1?1:ca}if((O|0)<0){fa=0}else{fa=(O|0)>3?3:O}if((W|0)<0){ga=0}else{ga=(W|0)>1?1:W}W=(ea*-255|0)+R|0;R=(fa*-85|0)+aa|0;aa=(ga*-255|0)+da|0;a[N]=(fa<<1)+(ea<<3)+ga;if((T|0)<(n|0)){d=aa;L=R;M=W;N=N+1|0;m=T}else{p=aa;q=R;r=W;s=n;t=I;u=J;v=K;break}}w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}function cwb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=0;s=0;t=0;u=d+11200|0;v=d+11204|0;w=d+11208|0;x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}D=d+11300|0;E=d+11304|0;F=d+11308|0;G=d+11312|0;H=d+11316|0;I=d+11320|0;J=d+11200|0;K=d+11204|0;L=d+11208|0;d=0;M=0;N=0;O=0;P=i;while(1){i=ba(b[m+(O<<1)>>1]|0,g)|0;Q=(ba(b[h+(O<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(O<<1)>>1]|0,p)|0;R=i-67108864+(ba(b[n+(O<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(O<<1)>>1]|0,p)|0;S=i-67108864+(ba(b[o+(O<<1)>>1]|0,l)|0)>>10;i=(ba(Q-(c[D>>2]|0)|0,c[E>>2]|0)|0)+2097152|0;Q=(ba(S,c[F>>2]|0)|0)+i|0;T=(ba(c[G>>2]|0,S)|0)+i|0;S=T+(ba(c[H>>2]|0,R)|0)|0;T=(ba(c[I>>2]|0,R)|0)+i|0;do{if((S|Q|T)>>>0>1073741823>>>0){if(Q>>>0<1073741824>>>0){U=Q}else{U=-Q>>31&1073741823}if(S>>>0<1073741824>>>0){V=S}else{V=-S>>31&1073741823}if(T>>>0<1073741824>>>0){W=T;X=V;Y=U;break}W=-T>>31&1073741823;X=V;Y=U}else{W=T;X=S;Y=Q}}while(0);Q=c[J>>2]|0;S=Q+(O<<2)|0;T=O+1|0;i=O+2|0;R=((c[S>>2]|0)+(N*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(Y>>22)|0;Q=c[K>>2]|0;Z=Q+(O<<2)|0;_=((c[Z>>2]|0)+(M*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(X>>22)|0;Q=c[L>>2]|0;$=Q+(O<<2)|0;aa=((c[$>>2]|0)+(d*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(W>>22)|0;c[S>>2]=N;c[Z>>2]=M;c[$>>2]=d;$=R>>7;Z=_>>6;S=aa>>7;if(($|0)<0){ca=0}else{ca=($|0)>1?1:$}if((Z|0)<0){da=0}else{da=(Z|0)>3?3:Z}if((S|0)<0){ea=0}else{ea=(S|0)>1?1:S}S=(ca*-255|0)+R|0;R=(da*-85|0)+_|0;_=(ea*-255|0)+aa|0;a[P]=(da<<1)+(ca<<3)+ea;if((T|0)<(j|0)){d=_;M=R;N=S;O=T;P=P+1|0}else{q=_;r=R;s=S;t=j;u=J;v=K;w=L;break}}x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}function dwb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}k=d+11300|0;z=d+11304|0;A=d+11308|0;B=d+11312|0;C=d+11316|0;D=d+11320|0;E=d+11200|0;F=d+11204|0;G=d+11208|0;H=0;I=0;J=0;K=0;L=i;while(1){M=(b[l+(K<<1)>>1]<<2)-65536|0;N=(b[h+(K<<1)>>1]<<2)-65536|0;O=(ba((b[e+(K<<1)>>1]<<2)-(c[k>>2]|0)|0,c[z>>2]|0)|0)+2097152|0;P=O+(ba(c[A>>2]|0,N)|0)|0;Q=(ba(c[B>>2]|0,N)|0)+O|0;N=Q+(ba(c[C>>2]|0,M)|0)|0;Q=(ba(c[D>>2]|0,M)|0)+O|0;do{if((N|P|Q)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){R=P}else{R=-P>>31&1073741823}if(N>>>0<1073741824>>>0){S=N}else{S=-N>>31&1073741823}if(Q>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-Q>>31&1073741823;U=S;V=R}else{T=Q;U=N;V=P}}while(0);P=c[E>>2]|0;N=P+(K<<2)|0;Q=K+1|0;O=K+2|0;M=((c[N>>2]|0)+(J*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(V>>22)|0;P=c[F>>2]|0;W=P+(K<<2)|0;X=((c[W>>2]|0)+(I*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(U>>22)|0;P=c[G>>2]|0;Y=P+(K<<2)|0;Z=((c[Y>>2]|0)+(H*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(T>>22)|0;c[N>>2]=J;c[W>>2]=I;c[Y>>2]=H;Y=M>>7;W=X>>6;N=Z>>7;if((Y|0)<0){_=0}else{_=(Y|0)>1?1:Y}if((W|0)<0){$=0}else{$=(W|0)>3?3:W}if((N|0)<0){aa=0}else{aa=(N|0)>1?1:N}N=(_*-255|0)+M|0;M=($*-85|0)+X|0;X=(aa*-255|0)+Z|0;a[L]=($<<1)+(_<<3)+aa;if((Q|0)<(j|0)){H=X;I=M;J=N;K=Q;L=L+1|0}else{m=j;n=N;o=M;p=X;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}else{L=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}g=d+11300|0;K=d+11304|0;J=d+11308|0;I=d+11312|0;H=d+11316|0;aa=d+11320|0;_=d+11200|0;$=d+11204|0;T=d+11208|0;G=0;U=0;F=0;V=0;E=i;while(1){i=((b[L+(V<<1)>>1]|0)+(b[l+(V<<1)>>1]|0)<<1)-65536|0;R=((b[f+(V<<1)>>1]|0)+(b[h+(V<<1)>>1]|0)<<1)-65536|0;S=(ba((b[e+(V<<1)>>1]<<2)-(c[g>>2]|0)|0,c[K>>2]|0)|0)+2097152|0;D=(ba(R,c[J>>2]|0)|0)+S|0;C=(ba(c[I>>2]|0,R)|0)+S|0;R=C+(ba(c[H>>2]|0,i)|0)|0;C=(ba(c[aa>>2]|0,i)|0)+S|0;do{if((R|D|C)>>>0>1073741823>>>0){if(D>>>0<1073741824>>>0){ca=D}else{ca=-D>>31&1073741823}if(R>>>0<1073741824>>>0){da=R}else{da=-R>>31&1073741823}if(C>>>0<1073741824>>>0){ea=C;fa=da;ga=ca;break}ea=-C>>31&1073741823;fa=da;ga=ca}else{ea=C;fa=R;ga=D}}while(0);D=c[_>>2]|0;R=D+(V<<2)|0;C=V+1|0;S=V+2|0;i=((c[R>>2]|0)+(F*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ga>>22)|0;D=c[$>>2]|0;B=D+(V<<2)|0;A=((c[B>>2]|0)+(U*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(fa>>22)|0;D=c[T>>2]|0;z=D+(V<<2)|0;k=((c[z>>2]|0)+(G*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ea>>22)|0;c[R>>2]=F;c[B>>2]=U;c[z>>2]=G;z=i>>7;B=A>>6;R=k>>7;if((z|0)<0){ha=0}else{ha=(z|0)>1?1:z}if((B|0)<0){ia=0}else{ia=(B|0)>3?3:B}if((R|0)<0){ja=0}else{ja=(R|0)>1?1:R}R=(ha*-255|0)+i|0;i=(ia*-85|0)+A|0;A=(ja*-255|0)+k|0;a[E]=(ia<<1)+(ha<<3)+ja;if((C|0)<(j|0)){G=A;U=i;F=R;V=C;E=E+1|0}else{m=j;n=R;o=i;p=A;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}}function ewb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;if((n|0)<=0){p=0;q=0;r=0;s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}o=(g|0)>0;l=(k|0)>0;C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=d+11200|0;J=d+11204|0;K=d+11208|0;d=0;L=0;M=0;N=m;m=0;while(1){if(o){O=0;P=512;do{P=(ba(b[e+(O<<1)>>1]|0,b[(c[f+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+P|0;O=O+1|0;}while((O|0)<(g|0));Q=P>>10}else{Q=0}if(l){O=0;R=-67108352;S=-67108352;do{T=b[h+(O<<1)>>1]|0;R=(ba(T,b[(c[i+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+R|0;S=(ba(b[(c[j+(O<<2)>>2]|0)+(m<<1)>>1]|0,T)|0)+S|0;O=O+1|0;}while((O|0)<(k|0));U=R>>10;V=S>>10}else{U=-65536;V=-65536}O=(ba(Q-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;P=O+(ba(c[E>>2]|0,V)|0)|0;T=(ba(c[F>>2]|0,V)|0)+O|0;W=T+(ba(c[G>>2]|0,U)|0)|0;T=(ba(c[H>>2]|0,U)|0)+O|0;do{if((W|P|T)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){X=P}else{X=-P>>31&1073741823}if(W>>>0<1073741824>>>0){Y=W}else{Y=-W>>31&1073741823}if(T>>>0<1073741824>>>0){Z=T;_=Y;$=X;break}Z=-T>>31&1073741823;_=Y;$=X}else{Z=T;_=W;$=P}}while(0);P=c[I>>2]|0;W=P+(m<<2)|0;T=m+1|0;S=m+2|0;R=((c[W>>2]|0)+(M*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+($>>22)|0;P=c[J>>2]|0;O=P+(m<<2)|0;aa=((c[O>>2]|0)+(L*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(_>>22)|0;P=c[K>>2]|0;ca=P+(m<<2)|0;da=((c[ca>>2]|0)+(d*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(Z>>22)|0;c[W>>2]=M;c[O>>2]=L;c[ca>>2]=d;ca=R>>5;O=aa>>5;W=da>>6;if((ca|0)<0){ea=0}else{ea=(ca|0)>7?7:ca}if((O|0)<0){fa=0}else{fa=(O|0)>7?7:O}if((W|0)<0){ga=0}else{ga=(W|0)>3?3:W}W=(ea*-36|0)+R|0;R=(fa*-36|0)+aa|0;aa=(ga*-85|0)+da|0;a[N]=(fa<<3)+ea+(ga<<6);if((T|0)<(n|0)){d=aa;L=R;M=W;N=N+1|0;m=T}else{p=aa;q=R;r=W;s=n;t=I;u=J;v=K;break}}w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}function fwb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=0;s=0;t=0;u=d+11200|0;v=d+11204|0;w=d+11208|0;x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}D=d+11300|0;E=d+11304|0;F=d+11308|0;G=d+11312|0;H=d+11316|0;I=d+11320|0;J=d+11200|0;K=d+11204|0;L=d+11208|0;d=0;M=0;N=0;O=0;P=i;while(1){i=ba(b[m+(O<<1)>>1]|0,g)|0;Q=(ba(b[h+(O<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(O<<1)>>1]|0,p)|0;R=i-67108864+(ba(b[n+(O<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(O<<1)>>1]|0,p)|0;S=i-67108864+(ba(b[o+(O<<1)>>1]|0,l)|0)>>10;i=(ba(Q-(c[D>>2]|0)|0,c[E>>2]|0)|0)+2097152|0;Q=(ba(S,c[F>>2]|0)|0)+i|0;T=(ba(c[G>>2]|0,S)|0)+i|0;S=T+(ba(c[H>>2]|0,R)|0)|0;T=(ba(c[I>>2]|0,R)|0)+i|0;do{if((S|Q|T)>>>0>1073741823>>>0){if(Q>>>0<1073741824>>>0){U=Q}else{U=-Q>>31&1073741823}if(S>>>0<1073741824>>>0){V=S}else{V=-S>>31&1073741823}if(T>>>0<1073741824>>>0){W=T;X=V;Y=U;break}W=-T>>31&1073741823;X=V;Y=U}else{W=T;X=S;Y=Q}}while(0);Q=c[J>>2]|0;S=Q+(O<<2)|0;T=O+1|0;i=O+2|0;R=((c[S>>2]|0)+(N*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(Y>>22)|0;Q=c[K>>2]|0;Z=Q+(O<<2)|0;_=((c[Z>>2]|0)+(M*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(X>>22)|0;Q=c[L>>2]|0;$=Q+(O<<2)|0;aa=((c[$>>2]|0)+(d*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(W>>22)|0;c[S>>2]=N;c[Z>>2]=M;c[$>>2]=d;$=R>>5;Z=_>>5;S=aa>>6;if(($|0)<0){ca=0}else{ca=($|0)>7?7:$}if((Z|0)<0){da=0}else{da=(Z|0)>7?7:Z}if((S|0)<0){ea=0}else{ea=(S|0)>3?3:S}S=(ca*-36|0)+R|0;R=(da*-36|0)+_|0;_=(ea*-85|0)+aa|0;a[P]=(da<<3)+ca+(ea<<6);if((T|0)<(j|0)){d=_;M=R;N=S;O=T;P=P+1|0}else{q=_;r=R;s=S;t=j;u=J;v=K;w=L;break}}x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}function gwb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}k=d+11300|0;z=d+11304|0;A=d+11308|0;B=d+11312|0;C=d+11316|0;D=d+11320|0;E=d+11200|0;F=d+11204|0;G=d+11208|0;H=0;I=0;J=0;K=0;L=i;while(1){M=(b[l+(K<<1)>>1]<<2)-65536|0;N=(b[h+(K<<1)>>1]<<2)-65536|0;O=(ba((b[e+(K<<1)>>1]<<2)-(c[k>>2]|0)|0,c[z>>2]|0)|0)+2097152|0;P=O+(ba(c[A>>2]|0,N)|0)|0;Q=(ba(c[B>>2]|0,N)|0)+O|0;N=Q+(ba(c[C>>2]|0,M)|0)|0;Q=(ba(c[D>>2]|0,M)|0)+O|0;do{if((N|P|Q)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){R=P}else{R=-P>>31&1073741823}if(N>>>0<1073741824>>>0){S=N}else{S=-N>>31&1073741823}if(Q>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-Q>>31&1073741823;U=S;V=R}else{T=Q;U=N;V=P}}while(0);P=c[E>>2]|0;N=P+(K<<2)|0;Q=K+1|0;O=K+2|0;M=((c[N>>2]|0)+(J*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(V>>22)|0;P=c[F>>2]|0;W=P+(K<<2)|0;X=((c[W>>2]|0)+(I*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(U>>22)|0;P=c[G>>2]|0;Y=P+(K<<2)|0;Z=((c[Y>>2]|0)+(H*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(T>>22)|0;c[N>>2]=J;c[W>>2]=I;c[Y>>2]=H;Y=M>>5;W=X>>5;N=Z>>6;if((Y|0)<0){_=0}else{_=(Y|0)>7?7:Y}if((W|0)<0){$=0}else{$=(W|0)>7?7:W}if((N|0)<0){aa=0}else{aa=(N|0)>3?3:N}N=(_*-36|0)+M|0;M=($*-36|0)+X|0;X=(aa*-85|0)+Z|0;a[L]=($<<3)+_+(aa<<6);if((Q|0)<(j|0)){H=X;I=M;J=N;K=Q;L=L+1|0}else{m=j;n=N;o=M;p=X;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}else{L=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}g=d+11300|0;K=d+11304|0;J=d+11308|0;I=d+11312|0;H=d+11316|0;aa=d+11320|0;_=d+11200|0;$=d+11204|0;T=d+11208|0;G=0;U=0;F=0;V=0;E=i;while(1){i=((b[L+(V<<1)>>1]|0)+(b[l+(V<<1)>>1]|0)<<1)-65536|0;R=((b[f+(V<<1)>>1]|0)+(b[h+(V<<1)>>1]|0)<<1)-65536|0;S=(ba((b[e+(V<<1)>>1]<<2)-(c[g>>2]|0)|0,c[K>>2]|0)|0)+2097152|0;D=(ba(R,c[J>>2]|0)|0)+S|0;C=(ba(c[I>>2]|0,R)|0)+S|0;R=C+(ba(c[H>>2]|0,i)|0)|0;C=(ba(c[aa>>2]|0,i)|0)+S|0;do{if((R|D|C)>>>0>1073741823>>>0){if(D>>>0<1073741824>>>0){ca=D}else{ca=-D>>31&1073741823}if(R>>>0<1073741824>>>0){da=R}else{da=-R>>31&1073741823}if(C>>>0<1073741824>>>0){ea=C;fa=da;ga=ca;break}ea=-C>>31&1073741823;fa=da;ga=ca}else{ea=C;fa=R;ga=D}}while(0);D=c[_>>2]|0;R=D+(V<<2)|0;C=V+1|0;S=V+2|0;i=((c[R>>2]|0)+(F*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ga>>22)|0;D=c[$>>2]|0;B=D+(V<<2)|0;A=((c[B>>2]|0)+(U*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(fa>>22)|0;D=c[T>>2]|0;z=D+(V<<2)|0;k=((c[z>>2]|0)+(G*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ea>>22)|0;c[R>>2]=F;c[B>>2]=U;c[z>>2]=G;z=i>>5;B=A>>5;R=k>>6;if((z|0)<0){ha=0}else{ha=(z|0)>7?7:z}if((B|0)<0){ia=0}else{ia=(B|0)>7?7:B}if((R|0)<0){ja=0}else{ja=(R|0)>3?3:R}R=(ha*-36|0)+i|0;i=(ia*-36|0)+A|0;A=(ja*-85|0)+k|0;a[E]=(ia<<3)+ha+(ja<<6);if((C|0)<(j|0)){G=A;U=i;F=R;V=C;E=E+1|0}else{m=j;n=R;o=i;p=A;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}}function hwb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;if((n|0)<=0){p=0;q=0;r=0;s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}o=(g|0)>0;l=(k|0)>0;C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=d+11200|0;J=d+11204|0;K=d+11208|0;d=0;L=0;M=0;N=m;m=0;while(1){if(o){O=0;P=512;do{P=(ba(b[e+(O<<1)>>1]|0,b[(c[f+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+P|0;O=O+1|0;}while((O|0)<(g|0));Q=P>>10}else{Q=0}if(l){O=0;R=-67108352;S=-67108352;do{T=b[h+(O<<1)>>1]|0;R=(ba(T,b[(c[i+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+R|0;S=(ba(b[(c[j+(O<<2)>>2]|0)+(m<<1)>>1]|0,T)|0)+S|0;O=O+1|0;}while((O|0)<(k|0));U=R>>10;V=S>>10}else{U=-65536;V=-65536}O=(ba(Q-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;P=O+(ba(c[E>>2]|0,V)|0)|0;T=(ba(c[F>>2]|0,V)|0)+O|0;W=T+(ba(c[G>>2]|0,U)|0)|0;T=(ba(c[H>>2]|0,U)|0)+O|0;do{if((W|P|T)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){X=P}else{X=-P>>31&1073741823}if(W>>>0<1073741824>>>0){Y=W}else{Y=-W>>31&1073741823}if(T>>>0<1073741824>>>0){Z=T;_=Y;$=X;break}Z=-T>>31&1073741823;_=Y;$=X}else{Z=T;_=W;$=P}}while(0);P=c[I>>2]|0;W=P+(m<<2)|0;T=m+1|0;S=m+2|0;R=((c[W>>2]|0)+(M*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+($>>22)|0;P=c[J>>2]|0;O=P+(m<<2)|0;aa=((c[O>>2]|0)+(L*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(_>>22)|0;P=c[K>>2]|0;ca=P+(m<<2)|0;da=((c[ca>>2]|0)+(d*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(Z>>22)|0;c[W>>2]=M;c[O>>2]=L;c[ca>>2]=d;ca=R>>5;O=aa>>5;W=da>>6;if((ca|0)<0){ea=0}else{ea=(ca|0)>7?7:ca}if((O|0)<0){fa=0}else{fa=(O|0)>7?7:O}if((W|0)<0){ga=0}else{ga=(W|0)>3?3:W}W=(ea*-36|0)+R|0;R=(fa*-36|0)+aa|0;aa=(ga*-85|0)+da|0;a[N]=(fa<<2)+(ea<<5)+ga;if((T|0)<(n|0)){d=aa;L=R;M=W;N=N+1|0;m=T}else{p=aa;q=R;r=W;s=n;t=I;u=J;v=K;break}}w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}function iwb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=0;s=0;t=0;u=d+11200|0;v=d+11204|0;w=d+11208|0;x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}D=d+11300|0;E=d+11304|0;F=d+11308|0;G=d+11312|0;H=d+11316|0;I=d+11320|0;J=d+11200|0;K=d+11204|0;L=d+11208|0;d=0;M=0;N=0;O=0;P=i;while(1){i=ba(b[m+(O<<1)>>1]|0,g)|0;Q=(ba(b[h+(O<<1)>>1]|0,k)|0)+i>>10;i=ba(b[e+(O<<1)>>1]|0,p)|0;R=i-67108864+(ba(b[n+(O<<1)>>1]|0,l)|0)>>10;i=ba(b[f+(O<<1)>>1]|0,p)|0;S=i-67108864+(ba(b[o+(O<<1)>>1]|0,l)|0)>>10;i=(ba(Q-(c[D>>2]|0)|0,c[E>>2]|0)|0)+2097152|0;Q=(ba(S,c[F>>2]|0)|0)+i|0;T=(ba(c[G>>2]|0,S)|0)+i|0;S=T+(ba(c[H>>2]|0,R)|0)|0;T=(ba(c[I>>2]|0,R)|0)+i|0;do{if((S|Q|T)>>>0>1073741823>>>0){if(Q>>>0<1073741824>>>0){U=Q}else{U=-Q>>31&1073741823}if(S>>>0<1073741824>>>0){V=S}else{V=-S>>31&1073741823}if(T>>>0<1073741824>>>0){W=T;X=V;Y=U;break}W=-T>>31&1073741823;X=V;Y=U}else{W=T;X=S;Y=Q}}while(0);Q=c[J>>2]|0;S=Q+(O<<2)|0;T=O+1|0;i=O+2|0;R=((c[S>>2]|0)+(N*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(Y>>22)|0;Q=c[K>>2]|0;Z=Q+(O<<2)|0;_=((c[Z>>2]|0)+(M*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(X>>22)|0;Q=c[L>>2]|0;$=Q+(O<<2)|0;aa=((c[$>>2]|0)+(d*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(W>>22)|0;c[S>>2]=N;c[Z>>2]=M;c[$>>2]=d;$=R>>5;Z=_>>5;S=aa>>6;if(($|0)<0){ca=0}else{ca=($|0)>7?7:$}if((Z|0)<0){da=0}else{da=(Z|0)>7?7:Z}if((S|0)<0){ea=0}else{ea=(S|0)>3?3:S}S=(ca*-36|0)+R|0;R=(da*-36|0)+_|0;_=(ea*-85|0)+aa|0;a[P]=(da<<2)+(ca<<5)+ea;if((T|0)<(j|0)){d=_;M=R;N=S;O=T;P=P+1|0}else{q=_;r=R;s=S;t=j;u=J;v=K;w=L;break}}x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}function jwb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}k=d+11300|0;z=d+11304|0;A=d+11308|0;B=d+11312|0;C=d+11316|0;D=d+11320|0;E=d+11200|0;F=d+11204|0;G=d+11208|0;H=0;I=0;J=0;K=0;L=i;while(1){M=(b[l+(K<<1)>>1]<<2)-65536|0;N=(b[h+(K<<1)>>1]<<2)-65536|0;O=(ba((b[e+(K<<1)>>1]<<2)-(c[k>>2]|0)|0,c[z>>2]|0)|0)+2097152|0;P=O+(ba(c[A>>2]|0,N)|0)|0;Q=(ba(c[B>>2]|0,N)|0)+O|0;N=Q+(ba(c[C>>2]|0,M)|0)|0;Q=(ba(c[D>>2]|0,M)|0)+O|0;do{if((N|P|Q)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){R=P}else{R=-P>>31&1073741823}if(N>>>0<1073741824>>>0){S=N}else{S=-N>>31&1073741823}if(Q>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-Q>>31&1073741823;U=S;V=R}else{T=Q;U=N;V=P}}while(0);P=c[E>>2]|0;N=P+(K<<2)|0;Q=K+1|0;O=K+2|0;M=((c[N>>2]|0)+(J*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(V>>22)|0;P=c[F>>2]|0;W=P+(K<<2)|0;X=((c[W>>2]|0)+(I*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(U>>22)|0;P=c[G>>2]|0;Y=P+(K<<2)|0;Z=((c[Y>>2]|0)+(H*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(T>>22)|0;c[N>>2]=J;c[W>>2]=I;c[Y>>2]=H;Y=M>>5;W=X>>5;N=Z>>6;if((Y|0)<0){_=0}else{_=(Y|0)>7?7:Y}if((W|0)<0){$=0}else{$=(W|0)>7?7:W}if((N|0)<0){aa=0}else{aa=(N|0)>3?3:N}N=(_*-36|0)+M|0;M=($*-36|0)+X|0;X=(aa*-85|0)+Z|0;a[L]=($<<2)+(_<<5)+aa;if((Q|0)<(j|0)){H=X;I=M;J=N;K=Q;L=L+1|0}else{m=j;n=N;o=M;p=X;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}else{L=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}g=d+11300|0;K=d+11304|0;J=d+11308|0;I=d+11312|0;H=d+11316|0;aa=d+11320|0;_=d+11200|0;$=d+11204|0;T=d+11208|0;G=0;U=0;F=0;V=0;E=i;while(1){i=((b[L+(V<<1)>>1]|0)+(b[l+(V<<1)>>1]|0)<<1)-65536|0;R=((b[f+(V<<1)>>1]|0)+(b[h+(V<<1)>>1]|0)<<1)-65536|0;S=(ba((b[e+(V<<1)>>1]<<2)-(c[g>>2]|0)|0,c[K>>2]|0)|0)+2097152|0;D=(ba(R,c[J>>2]|0)|0)+S|0;C=(ba(c[I>>2]|0,R)|0)+S|0;R=C+(ba(c[H>>2]|0,i)|0)|0;C=(ba(c[aa>>2]|0,i)|0)+S|0;do{if((R|D|C)>>>0>1073741823>>>0){if(D>>>0<1073741824>>>0){ca=D}else{ca=-D>>31&1073741823}if(R>>>0<1073741824>>>0){da=R}else{da=-R>>31&1073741823}if(C>>>0<1073741824>>>0){ea=C;fa=da;ga=ca;break}ea=-C>>31&1073741823;fa=da;ga=ca}else{ea=C;fa=R;ga=D}}while(0);D=c[_>>2]|0;R=D+(V<<2)|0;C=V+1|0;S=V+2|0;i=((c[R>>2]|0)+(F*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ga>>22)|0;D=c[$>>2]|0;B=D+(V<<2)|0;A=((c[B>>2]|0)+(U*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(fa>>22)|0;D=c[T>>2]|0;z=D+(V<<2)|0;k=((c[z>>2]|0)+(G*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ea>>22)|0;c[R>>2]=F;c[B>>2]=U;c[z>>2]=G;z=i>>5;B=A>>5;R=k>>6;if((z|0)<0){ha=0}else{ha=(z|0)>7?7:z}if((B|0)<0){ia=0}else{ia=(B|0)>7?7:B}if((R|0)<0){ja=0}else{ja=(R|0)>3?3:R}R=(ha*-36|0)+i|0;i=(ia*-36|0)+A|0;A=(ja*-85|0)+k|0;a[E]=(ia<<2)+(ha<<5)+ja;if((C|0)<(j|0)){G=A;U=i;F=R;V=C;E=E+1|0}else{m=j;n=R;o=i;p=A;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}}function kwb(d,f,g,h,j,k,l,m,n,o,p,q){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;q=i;r=d+52|0;s=bFb(c[r>>2]|0)|0;t=(a[s+7|0]|0)<0&(n|0)!=0;u=29-((e[s+8>>1]|0)>>>11&15)|0;s=(p|0)>0;if(s){v=(h|0)>0;w=(m|0)>0;x=d+11300|0;y=d+11304|0;z=d+11308|0;A=d+11312|0;B=d+11316|0;C=d+11320|0;d=(u|0)==22;D=o+4|0;E=o+8|0;F=o+12|0;G=0;H=0;I=0;while(1){if(v){J=0;K=512;do{K=(ba(b[f+(J<<1)>>1]|0,b[(c[g+(J<<2)>>2]|0)+(G<<1)>>1]|0)|0)+K|0;J=J+1|0;}while((J|0)<(h|0));L=K>>10}else{L=0}if(w){J=0;M=-67108352;N=-67108352;do{O=b[j+(J<<1)>>1]|0;M=(ba(O,b[(c[k+(J<<2)>>2]|0)+(G<<1)>>1]|0)|0)+M|0;N=(ba(b[(c[l+(J<<2)>>2]|0)+(G<<1)>>1]|0,O)|0)+N|0;J=J+1|0;}while((J|0)<(m|0));P=M>>10;Q=N>>10}else{P=-65536;Q=-65536}a:do{if(t){do{if(v){J=262144;K=0;do{J=(ba(b[f+(K<<1)>>1]|0,b[(c[n+(K<<2)>>2]|0)+(G<<1)>>1]|0)|0)+J|0;K=K+1|0;}while((K|0)<(h|0));K=J>>19;O=K&255;if((K&256|0)==0){R=K&65535;S=O;break}if(K>>>0>255>>>0){T=-K>>31&255}else{T=O}U=T&255;V=T;break a}else{R=0;S=0}}while(0);U=R;V=S}else{U=I;V=H}}while(0);N=(ba(L-(c[x>>2]|0)|0,c[y>>2]|0)|0)+2097152|0;M=N+(ba(c[z>>2]|0,Q)|0)|0;O=(ba(c[A>>2]|0,Q)|0)+N|0;K=O+(ba(c[B>>2]|0,P)|0)|0;O=(ba(c[C>>2]|0,P)|0)+N|0;do{if((K|M|O)>>>0>1073741823>>>0){if(M>>>0<1073741824>>>0){W=M}else{W=-M>>31&1073741823}if(K>>>0<1073741824>>>0){X=K}else{X=-K>>31&1073741823}if(O>>>0<1073741824>>>0){Y=O;Z=X;_=W;break}Y=-O>>31&1073741823;Z=X;_=W}else{Y=O;Z=K;_=M}}while(0);do{if(d){a[(c[o>>2]|0)+G|0]=Z>>>22;a[(c[D>>2]|0)+G|0]=Y>>>22;a[(c[E>>2]|0)+G|0]=_>>>22;if(!t){break}a[(c[F>>2]|0)+G|0]=V}else{b[(c[o>>2]|0)+(G<<1)>>1]=Z>>u;b[(c[D>>2]|0)+(G<<1)>>1]=Y>>u;b[(c[E>>2]|0)+(G<<1)>>1]=_>>u;if(!t){break}b[(c[F>>2]|0)+(G<<1)>>1]=U}}while(0);M=G+1|0;if((M|0)<(p|0)){G=M;H=V;I=U}else{break}}}if((u|0)==22){i=q;return}u=bFb(c[r>>2]|0)|0;if((u|0)==0){yDb(0,0,2166496,(r=i,i=i+24|0,c[r>>2]=2097816,c[r+8>>2]=2042544,c[r+16>>2]=653,r)|0);i=r;Cd()}if((a[u+7|0]&1)==0|s^1){i=q;return}s=o+4|0;u=o+8|0;r=o+12|0;U=0;do{I=(c[o>>2]|0)+(U<<1)|0;b[I>>1]=de(b[I>>1]|0)|0;I=(c[s>>2]|0)+(U<<1)|0;b[I>>1]=de(b[I>>1]|0)|0;I=(c[u>>2]|0)+(U<<1)|0;b[I>>1]=de(b[I>>1]|0)|0;if(t){I=(c[r>>2]|0)+(U<<1)|0;b[I>>1]=de(b[I>>1]|0)|0}U=U+1|0;}while((U|0)<(p|0));i=q;return}function lwb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;l=i;m=d;d=g;g=h;h=c[e>>2]|0;n=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}o=b+11300|0;p=b+11304|0;q=b+11308|0;r=b+11312|0;s=b+11316|0;t=b+11320|0;u=0;v=g;while(1){w=u<<1;y=w|1;z=(c[h+(u<<2)>>2]|0)-262144>>2;A=(c[n+(u<<2)>>2]|0)-262144>>2;B=c[o>>2]|0;C=c[p>>2]|0;D=(ba((c[m+(w<<2)>>2]>>2)-B|0,C)|0)+8192|0;E=(ba((c[m+(y<<2)>>2]>>2)-B|0,C)|0)+8192|0;C=c[d+(w<<2)>>2]<<11;w=c[d+(y<<2)>>2]<<11;y=C+8192|0;B=w+8192|0;F=ba(c[q>>2]|0,A)|0;G=ba(c[r>>2]|0,A)|0;A=(ba(c[s>>2]|0,z)|0)+G|0;G=ba(c[t>>2]|0,z)|0;z=bFb(292)|0;if((z|0)==0){H=5;break}I=F+D|0;if(I>>>0<1073741824>>>0){J=I>>>14&65535}else{J=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){K=J}else{K=de(J|0)|0}x=K;a[v]=x;x=x>>8;a[v+1|0]=x;z=bFb(292)|0;if((z|0)==0){H=11;break}I=A+D|0;if(I>>>0<1073741824>>>0){L=I>>>14&65535}else{L=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+2|0;x=L;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+2|0;x=de(L|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(292)|0;if((z|0)==0){H=18;break}I=G+D|0;if(I>>>0<1073741824>>>0){M=I>>>14&65535}else{M=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+4|0;x=M;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+4|0;x=de(M|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(292)|0;if((z|0)==0){H=25;break}if(y>>>0<1073741824>>>0){N=y>>>14&65535}else{N=-8192-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+6|0;x=N;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+6|0;x=de(N|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(292)|0;if((z|0)==0){H=32;break}C=F+E|0;if(C>>>0<1073741824>>>0){O=C>>>14&65535}else{O=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+8|0;x=O;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+8|0;x=de(O|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(292)|0;if((z|0)==0){H=39;break}C=A+E|0;if(C>>>0<1073741824>>>0){P=C>>>14&65535}else{P=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+10|0;x=P;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+10|0;x=de(P|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(292)|0;if((z|0)==0){H=46;break}C=G+E|0;if(C>>>0<1073741824>>>0){Q=C>>>14&65535}else{Q=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+12|0;x=Q;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+12|0;x=de(Q|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(292)|0;if((z|0)==0){H=53;break}if(B>>>0<1073741824>>>0){R=B>>>14&65535}else{R=-8192-w>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+14|0;x=R;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+14|0;x=de(R|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=u+1|0;if((z|0)<(k|0)){u=z;v=v+16|0}else{H=118;break}}if((H|0)==5){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==11){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==18){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==25){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==32){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==39){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==46){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==53){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==118){i=l;return}}else{v=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;u=b+11304|0;k=b+11308|0;R=b+11312|0;Q=b+11316|0;P=b+11320|0;b=0;O=g;while(1){g=b<<1;N=g|1;M=(c[h+(b<<2)>>2]|0)-524288+(c[v+(b<<2)>>2]|0)>>3;L=(c[n+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;K=c[j>>2]|0;J=c[u>>2]|0;t=(ba((c[m+(g<<2)>>2]>>2)-K|0,J)|0)+8192|0;s=(ba((c[m+(N<<2)>>2]>>2)-K|0,J)|0)+8192|0;J=c[d+(g<<2)>>2]<<11;g=c[d+(N<<2)>>2]<<11;N=J+8192|0;K=g+8192|0;r=ba(c[k>>2]|0,L)|0;q=ba(c[R>>2]|0,L)|0;L=(ba(c[Q>>2]|0,M)|0)+q|0;q=ba(c[P>>2]|0,M)|0;M=bFb(292)|0;if((M|0)==0){H=63;break}p=r+t|0;if(p>>>0<1073741824>>>0){T=p>>>14&65535}else{T=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){U=T}else{U=de(T|0)|0}x=U;a[O]=x;x=x>>8;a[O+1|0]=x;M=bFb(292)|0;if((M|0)==0){H=69;break}p=L+t|0;if(p>>>0<1073741824>>>0){V=p>>>14&65535}else{V=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+2|0;x=V;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+2|0;x=de(V|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(292)|0;if((M|0)==0){H=76;break}p=q+t|0;if(p>>>0<1073741824>>>0){W=p>>>14&65535}else{W=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+4|0;x=W;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+4|0;x=de(W|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(292)|0;if((M|0)==0){H=83;break}if(N>>>0<1073741824>>>0){X=N>>>14&65535}else{X=-8192-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+6|0;x=X;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+6|0;x=de(X|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(292)|0;if((M|0)==0){H=90;break}J=r+s|0;if(J>>>0<1073741824>>>0){Y=J>>>14&65535}else{Y=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+8|0;x=Y;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+8|0;x=de(Y|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(292)|0;if((M|0)==0){H=97;break}J=L+s|0;if(J>>>0<1073741824>>>0){Z=J>>>14&65535}else{Z=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+10|0;x=Z;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+10|0;x=de(Z|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(292)|0;if((M|0)==0){H=104;break}J=q+s|0;if(J>>>0<1073741824>>>0){_=J>>>14&65535}else{_=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+12|0;x=_;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+12|0;x=de(_|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(292)|0;if((M|0)==0){H=111;break}if(K>>>0<1073741824>>>0){$=K>>>14&65535}else{$=-8192-g>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+14|0;x=$;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+14|0;x=de($|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=b+1|0;if((M|0)<(f|0)){b=M;O=O+16|0}else{H=118;break}}if((H|0)==63){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==69){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==76){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==83){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==90){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==97){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==104){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==111){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==118){i=l;return}}}function mwb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;m=i;n=c[d>>2]|0;o=c[d+4>>2]|0;d=c[e>>2]|0;p=c[e+4>>2]|0;e=c[f>>2]|0;q=c[f+4>>2]|0;f=c[g>>2]|0;r=c[g+4>>2]|0;g=4096-k|0;s=4096-l|0;t=j+1>>1;if((t|0)<=0){i=m;return}j=b+11300|0;u=b+11304|0;v=b+11308|0;w=b+11312|0;y=b+11316|0;z=b+11320|0;b=0;A=h;while(1){h=b<<1;B=ba(c[n+(h<<2)>>2]|0,g)|0;C=(ba(c[o+(h<<2)>>2]|0,k)|0)+B>>14;B=h|1;D=ba(c[n+(B<<2)>>2]|0,g)|0;E=(ba(c[o+(B<<2)>>2]|0,k)|0)+D>>14;D=ba(c[d+(b<<2)>>2]|0,s)|0;F=D-1073741824+(ba(c[p+(b<<2)>>2]|0,l)|0)>>14;D=ba(c[e+(b<<2)>>2]|0,s)|0;G=D-1073741824+(ba(c[q+(b<<2)>>2]|0,l)|0)>>14;D=c[j>>2]|0;H=c[u>>2]|0;I=(ba(C-D|0,H)|0)+8192|0;C=(ba(E-D|0,H)|0)+8192|0;H=ba(G,c[v>>2]|0)|0;D=ba(c[w>>2]|0,G)|0;G=(ba(c[y>>2]|0,F)|0)+D|0;D=ba(c[z>>2]|0,F)|0;F=ba(c[f+(h<<2)>>2]|0,g)|0;E=(ba(c[r+(h<<2)>>2]|0,k)|0)+F>>1;F=ba(c[f+(B<<2)>>2]|0,g)|0;h=(ba(c[r+(B<<2)>>2]|0,k)|0)+F>>1;F=E+8192|0;B=h+8192|0;J=bFb(292)|0;if((J|0)==0){K=4;break}L=H+I|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[A]=x;x=x>>8;a[A+1|0]=x;J=bFb(292)|0;if((J|0)==0){K=10;break}L=G+I|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+2|0;x=O;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+2|0;x=de(O|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(292)|0;if((J|0)==0){K=17;break}L=D+I|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+4|0;x=P;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+4|0;x=de(P|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(292)|0;if((J|0)==0){K=24;break}if(F>>>0<1073741824>>>0){Q=F>>>14&65535}else{Q=-8192-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+6|0;x=Q;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+6|0;x=de(Q|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(292)|0;if((J|0)==0){K=31;break}E=H+C|0;if(E>>>0<1073741824>>>0){R=E>>>14&65535}else{R=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+8|0;x=R;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+8|0;x=de(R|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(292)|0;if((J|0)==0){K=38;break}E=G+C|0;if(E>>>0<1073741824>>>0){S=E>>>14&65535}else{S=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+10|0;x=S;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+10|0;x=de(S|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(292)|0;if((J|0)==0){K=45;break}E=D+C|0;if(E>>>0<1073741824>>>0){T=E>>>14&65535}else{T=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+12|0;x=T;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+12|0;x=de(T|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(292)|0;if((J|0)==0){K=52;break}if(B>>>0<1073741824>>>0){U=B>>>14&65535}else{U=-8192-h>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+14|0;x=U;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+14|0;x=de(U|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=b+1|0;if((J|0)<(t|0)){b=J;A=A+16|0}else{K=59;break}}if((K|0)==4){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==10){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==17){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==24){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==31){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==38){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==45){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==52){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==59){i=m;return}}function nwb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;p=i;q=o+1>>1;if((q|0)<=0){i=p;return}o=(g|0)>0;r=(l|0)>0;s=d+11300|0;t=d+11304|0;u=d+11308|0;v=d+11312|0;w=d+11316|0;y=d+11320|0;d=0;z=n;while(1){if(o){n=d<<1;A=n|1;B=0;C=-1073741824;D=-1073741824;do{E=c[f+(B<<2)>>2]|0;F=b[e+(B<<1)>>1]|0;C=(ba(F,c[E+(n<<2)>>2]|0)|0)+C|0;D=(ba(c[E+(A<<2)>>2]|0,F)|0)+D|0;B=B+1|0;}while((B|0)<(g|0));G=(C>>14)+65536|0;H=(D>>14)+65536|0}else{G=0;H=0}if(r){B=0;A=-1073741824;n=-1073741824;do{F=b[h+(B<<1)>>1]|0;A=(ba(F,c[(c[j+(B<<2)>>2]|0)+(d<<2)>>2]|0)|0)+A|0;n=(ba(c[(c[k+(B<<2)>>2]|0)+(d<<2)>>2]|0,F)|0)+n|0;B=B+1|0;}while((B|0)<(l|0));I=A>>14;J=n>>14}else{I=-65536;J=-65536}if(o){B=d<<1;D=B|1;C=-1073741824;F=0;E=-1073741824;do{K=c[m+(F<<2)>>2]|0;L=b[e+(F<<1)>>1]|0;E=(ba(L,c[K+(B<<2)>>2]|0)|0)+E|0;C=(ba(c[K+(D<<2)>>2]|0,L)|0)+C|0;F=F+1|0;}while((F|0)<(g|0));M=(E>>1)+536879104|0;N=(C>>1)+536879104|0}else{M=8192;N=8192}F=c[s>>2]|0;D=c[t>>2]|0;B=(ba(G-F|0,D)|0)+8192|0;n=(ba(H-F|0,D)|0)+8192|0;D=ba(c[u>>2]|0,J)|0;F=ba(c[v>>2]|0,J)|0;A=(ba(c[w>>2]|0,I)|0)+F|0;F=ba(c[y>>2]|0,I)|0;L=bFb(292)|0;if((L|0)==0){O=15;break}K=D+B|0;if(K>>>0<1073741824>>>0){P=K>>>14&65535}else{P=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){Q=P}else{Q=de(P|0)|0}x=Q;a[z]=x;x=x>>8;a[z+1|0]=x;L=bFb(292)|0;if((L|0)==0){O=21;break}K=A+B|0;if(K>>>0<1073741824>>>0){R=K>>>14&65535}else{R=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+2|0;x=R;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+2|0;x=de(R|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(292)|0;if((L|0)==0){O=28;break}K=F+B|0;if(K>>>0<1073741824>>>0){S=K>>>14&65535}else{S=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+4|0;x=S;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+4|0;x=de(S|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(292)|0;if((L|0)==0){O=35;break}if(M>>>0<1073741824>>>0){T=M>>>14&65535}else{T=-M>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+6|0;x=T;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+6|0;x=de(T|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(292)|0;if((L|0)==0){O=42;break}K=D+n|0;if(K>>>0<1073741824>>>0){U=K>>>14&65535}else{U=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+8|0;x=U;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+8|0;x=de(U|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(292)|0;if((L|0)==0){O=49;break}K=A+n|0;if(K>>>0<1073741824>>>0){V=K>>>14&65535}else{V=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+10|0;x=V;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+10|0;x=de(V|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(292)|0;if((L|0)==0){O=56;break}K=F+n|0;if(K>>>0<1073741824>>>0){W=K>>>14&65535}else{W=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+12|0;x=W;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+12|0;x=de(W|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(292)|0;if((L|0)==0){O=63;break}if(N>>>0<1073741824>>>0){X=N>>>14&65535}else{X=-N>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+14|0;x=X;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+14|0;x=de(X|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=d+1|0;if((L|0)<(q|0)){d=L;z=z+16|0}else{O=70;break}}if((O|0)==15){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==21){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==28){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==35){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==42){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==49){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==56){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==63){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==70){i=p;return}}function owb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;y=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ba((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ba((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ba(c[p>>2]|0,y)|0;z=ba(c[q>>2]|0,y)|0;y=(ba(c[r>>2]|0,w)|0)+z|0;z=ba(c[s>>2]|0,w)|0;w=bFb(292)|0;if((w|0)==0){D=5;break}v=A+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=de(E|0)|0}x=F;a[u]=x;x=x>>8;a[u+1|0]=x;w=bFb(292)|0;if((w|0)==0){D=11;break}v=y+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;x=G;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+2|0;x=de(G|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(292)|0;if((w|0)==0){D=18;break}v=z+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;x=H;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+4|0;x=de(H|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}if((bFb(292)|0)==0){D=25;break}w=u+6|0;x=-1;a[w]=x;x=x>>8;a[w+1|0]=x;w=bFb(292)|0;if((w|0)==0){D=27;break}v=A+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;x=I;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+8|0;x=de(I|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(292)|0;if((w|0)==0){D=34;break}v=y+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;x=J;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+10|0;x=de(J|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(292)|0;if((w|0)==0){D=41;break}v=z+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+12|0;x=K;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+12|0;x=de(K|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}if((bFb(292)|0)==0){D=48;break}w=u+14|0;x=-1;a[w]=x;x=x>>8;a[w+1|0]=x;w=t+1|0;if((w|0)<(k|0)){t=w;u=u+16|0}else{D=98;break}}if((D|0)==5){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==11){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==18){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==25){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==27){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==34){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==41){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==48){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==98){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ba((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ba((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ba(c[k>>2]|0,F)|0;E=ba(c[K>>2]|0,F)|0;F=(ba(c[J>>2]|0,G)|0)+E|0;E=ba(c[I>>2]|0,G)|0;G=bFb(292)|0;if((G|0)==0){D=53;break}d=s+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[H]=x;x=x>>8;a[H+1|0]=x;G=bFb(292)|0;if((G|0)==0){D=59;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;x=O;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+2|0;x=de(O|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(292)|0;if((G|0)==0){D=66;break}d=E+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;x=P;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+4|0;x=de(P|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}if((bFb(292)|0)==0){D=73;break}G=H+6|0;x=-1;a[G]=x;x=x>>8;a[G+1|0]=x;G=bFb(292)|0;if((G|0)==0){D=75;break}d=s+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;x=Q;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+8|0;x=de(Q|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(292)|0;if((G|0)==0){D=82;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;x=R;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+10|0;x=de(R|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(292)|0;if((G|0)==0){D=89;break}d=E+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+12|0;x=S;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+12|0;x=de(S|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}if((bFb(292)|0)==0){D=96;break}G=H+14|0;x=-1;a[G]=x;x=x>>8;a[G+1|0]=x;G=b+1|0;if((G|0)<(f|0)){b=G;H=H+16|0}else{D=98;break}}if((D|0)==53){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==59){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==66){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==73){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==75){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==82){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==89){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==96){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==98){i=l;return}}}function pwb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;y=h;while(1){h=b<<1;z=ba(c[g+(h<<2)>>2]|0,f)|0;A=(ba(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ba(c[g+(z<<2)>>2]|0,f)|0;B=(ba(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ba(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ba(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ba(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ba(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ba(A-h|0,D)|0)+8192|0;A=(ba(B-h|0,D)|0)+8192|0;D=ba(C,c[t>>2]|0)|0;h=ba(c[u>>2]|0,C)|0;C=(ba(c[v>>2]|0,z)|0)+h|0;h=ba(c[w>>2]|0,z)|0;z=bFb(292)|0;if((z|0)==0){F=4;break}B=D+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=de(G|0)|0}x=H;a[y]=x;x=x>>8;a[y+1|0]=x;z=bFb(292)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+2|0;x=I;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+2|0;x=de(I|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(292)|0;if((z|0)==0){F=17;break}B=h+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+4|0;x=J;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+4|0;x=de(J|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}if((bFb(292)|0)==0){F=24;break}z=y+6|0;x=-1;a[z]=x;x=x>>8;a[z+1|0]=x;z=bFb(292)|0;if((z|0)==0){F=26;break}B=D+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+8|0;x=K;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+8|0;x=de(K|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(292)|0;if((z|0)==0){F=33;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+10|0;x=L;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+10|0;x=de(L|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(292)|0;if((z|0)==0){F=40;break}B=h+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+12|0;x=M;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+12|0;x=de(M|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}if((bFb(292)|0)==0){F=47;break}z=y+14|0;x=-1;a[z]=x;x=x>>8;a[z+1|0]=x;z=b+1|0;if((z|0)<(r|0)){b=z;y=y+16|0}else{F=49;break}}if((F|0)==4){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==10){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==17){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==24){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==26){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==33){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==40){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==47){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==49){i=m;return}}function qwb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;y=n;while(1){if(o){n=d<<1;z=n|1;A=0;B=-1073741824;C=-1073741824;do{D=c[f+(A<<2)>>2]|0;E=b[e+(A<<1)>>1]|0;B=(ba(E,c[D+(n<<2)>>2]|0)|0)+B|0;C=(ba(c[D+(z<<2)>>2]|0,E)|0)+C|0;A=A+1|0;}while((A|0)<(g|0));F=(B>>14)+65536|0;G=(C>>14)+65536|0}else{F=0;G=0}if(q){A=0;z=-1073741824;n=-1073741824;do{E=b[h+(A<<1)>>1]|0;z=(ba(E,c[(c[j+(A<<2)>>2]|0)+(d<<2)>>2]|0)|0)+z|0;n=(ba(c[(c[k+(A<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+n|0;A=A+1|0;}while((A|0)<(l|0));H=z>>14;I=n>>14}else{H=-65536;I=-65536}A=c[r>>2]|0;C=c[s>>2]|0;B=(ba(F-A|0,C)|0)+8192|0;E=(ba(G-A|0,C)|0)+8192|0;C=ba(c[t>>2]|0,I)|0;A=ba(c[u>>2]|0,I)|0;D=(ba(c[v>>2]|0,H)|0)+A|0;A=ba(c[w>>2]|0,H)|0;J=bFb(292)|0;if((J|0)==0){K=11;break}L=C+B|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[y]=x;x=x>>8;a[y+1|0]=x;J=bFb(292)|0;if((J|0)==0){K=17;break}L=D+B|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+2|0;x=O;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+2|0;x=de(O|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(292)|0;if((J|0)==0){K=24;break}L=A+B|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+4|0;x=P;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+4|0;x=de(P|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}if((bFb(292)|0)==0){K=31;break}J=y+6|0;x=-1;a[J]=x;x=x>>8;a[J+1|0]=x;J=bFb(292)|0;if((J|0)==0){K=33;break}L=C+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+8|0;x=Q;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+8|0;x=de(Q|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(292)|0;if((J|0)==0){K=40;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+10|0;x=R;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+10|0;x=de(R|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(292)|0;if((J|0)==0){K=47;break}L=A+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+12|0;x=S;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+12|0;x=de(S|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}if((bFb(292)|0)==0){K=54;break}J=y+14|0;x=-1;a[J]=x;x=x>>8;a[J+1|0]=x;J=d+1|0;if((J|0)<(m|0)){d=J;y=y+16|0}else{K=56;break}}if((K|0)==11){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==17){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==24){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==31){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==33){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==40){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==47){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==54){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==56){i=p;return}}function rwb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;l=i;m=d;d=g;g=h;h=c[e>>2]|0;n=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}o=b+11300|0;p=b+11304|0;q=b+11308|0;r=b+11312|0;s=b+11316|0;t=b+11320|0;u=0;v=g;while(1){w=u<<1;y=w|1;z=(c[h+(u<<2)>>2]|0)-262144>>2;A=(c[n+(u<<2)>>2]|0)-262144>>2;B=c[o>>2]|0;C=c[p>>2]|0;D=(ba((c[m+(w<<2)>>2]>>2)-B|0,C)|0)+8192|0;E=(ba((c[m+(y<<2)>>2]>>2)-B|0,C)|0)+8192|0;C=c[d+(w<<2)>>2]<<11;w=c[d+(y<<2)>>2]<<11;y=C+8192|0;B=w+8192|0;F=ba(c[q>>2]|0,A)|0;G=ba(c[r>>2]|0,A)|0;A=(ba(c[s>>2]|0,z)|0)+G|0;G=ba(c[t>>2]|0,z)|0;z=bFb(291)|0;if((z|0)==0){H=5;break}I=F+D|0;if(I>>>0<1073741824>>>0){J=I>>>14&65535}else{J=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){K=J}else{K=de(J|0)|0}x=K;a[v]=x;x=x>>8;a[v+1|0]=x;z=bFb(291)|0;if((z|0)==0){H=11;break}I=A+D|0;if(I>>>0<1073741824>>>0){L=I>>>14&65535}else{L=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+2|0;x=L;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+2|0;x=de(L|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(291)|0;if((z|0)==0){H=18;break}I=G+D|0;if(I>>>0<1073741824>>>0){M=I>>>14&65535}else{M=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+4|0;x=M;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+4|0;x=de(M|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(291)|0;if((z|0)==0){H=25;break}if(y>>>0<1073741824>>>0){N=y>>>14&65535}else{N=-8192-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+6|0;x=N;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+6|0;x=de(N|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(291)|0;if((z|0)==0){H=32;break}C=F+E|0;if(C>>>0<1073741824>>>0){O=C>>>14&65535}else{O=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+8|0;x=O;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+8|0;x=de(O|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(291)|0;if((z|0)==0){H=39;break}C=A+E|0;if(C>>>0<1073741824>>>0){P=C>>>14&65535}else{P=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+10|0;x=P;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+10|0;x=de(P|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(291)|0;if((z|0)==0){H=46;break}C=G+E|0;if(C>>>0<1073741824>>>0){Q=C>>>14&65535}else{Q=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+12|0;x=Q;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+12|0;x=de(Q|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(291)|0;if((z|0)==0){H=53;break}if(B>>>0<1073741824>>>0){R=B>>>14&65535}else{R=-8192-w>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+14|0;x=R;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=v+14|0;x=de(R|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=u+1|0;if((z|0)<(k|0)){u=z;v=v+16|0}else{H=118;break}}if((H|0)==5){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==11){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==18){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==25){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==32){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==39){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==46){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==53){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==118){i=l;return}}else{v=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;u=b+11304|0;k=b+11308|0;R=b+11312|0;Q=b+11316|0;P=b+11320|0;b=0;O=g;while(1){g=b<<1;N=g|1;M=(c[h+(b<<2)>>2]|0)-524288+(c[v+(b<<2)>>2]|0)>>3;L=(c[n+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;K=c[j>>2]|0;J=c[u>>2]|0;t=(ba((c[m+(g<<2)>>2]>>2)-K|0,J)|0)+8192|0;s=(ba((c[m+(N<<2)>>2]>>2)-K|0,J)|0)+8192|0;J=c[d+(g<<2)>>2]<<11;g=c[d+(N<<2)>>2]<<11;N=J+8192|0;K=g+8192|0;r=ba(c[k>>2]|0,L)|0;q=ba(c[R>>2]|0,L)|0;L=(ba(c[Q>>2]|0,M)|0)+q|0;q=ba(c[P>>2]|0,M)|0;M=bFb(291)|0;if((M|0)==0){H=63;break}p=r+t|0;if(p>>>0<1073741824>>>0){T=p>>>14&65535}else{T=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){U=T}else{U=de(T|0)|0}x=U;a[O]=x;x=x>>8;a[O+1|0]=x;M=bFb(291)|0;if((M|0)==0){H=69;break}p=L+t|0;if(p>>>0<1073741824>>>0){V=p>>>14&65535}else{V=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+2|0;x=V;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+2|0;x=de(V|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(291)|0;if((M|0)==0){H=76;break}p=q+t|0;if(p>>>0<1073741824>>>0){W=p>>>14&65535}else{W=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+4|0;x=W;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+4|0;x=de(W|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(291)|0;if((M|0)==0){H=83;break}if(N>>>0<1073741824>>>0){X=N>>>14&65535}else{X=-8192-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+6|0;x=X;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+6|0;x=de(X|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(291)|0;if((M|0)==0){H=90;break}J=r+s|0;if(J>>>0<1073741824>>>0){Y=J>>>14&65535}else{Y=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+8|0;x=Y;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+8|0;x=de(Y|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(291)|0;if((M|0)==0){H=97;break}J=L+s|0;if(J>>>0<1073741824>>>0){Z=J>>>14&65535}else{Z=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+10|0;x=Z;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+10|0;x=de(Z|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(291)|0;if((M|0)==0){H=104;break}J=q+s|0;if(J>>>0<1073741824>>>0){_=J>>>14&65535}else{_=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+12|0;x=_;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+12|0;x=de(_|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=bFb(291)|0;if((M|0)==0){H=111;break}if(K>>>0<1073741824>>>0){$=K>>>14&65535}else{$=-8192-g>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+14|0;x=$;a[M]=x;x=x>>8;a[M+1|0]=x}else{M=O+14|0;x=de($|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x}M=b+1|0;if((M|0)<(f|0)){b=M;O=O+16|0}else{H=118;break}}if((H|0)==63){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==69){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==76){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==83){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==90){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==97){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==104){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==111){yDb(0,0,2166496,(S=i,i=i+24|0,c[S>>2]=2097816,c[S+8>>2]=2042544,c[S+16>>2]=653,S)|0);i=S;Cd()}else if((H|0)==118){i=l;return}}}function swb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;m=i;n=c[d>>2]|0;o=c[d+4>>2]|0;d=c[e>>2]|0;p=c[e+4>>2]|0;e=c[f>>2]|0;q=c[f+4>>2]|0;f=c[g>>2]|0;r=c[g+4>>2]|0;g=4096-k|0;s=4096-l|0;t=j+1>>1;if((t|0)<=0){i=m;return}j=b+11300|0;u=b+11304|0;v=b+11308|0;w=b+11312|0;y=b+11316|0;z=b+11320|0;b=0;A=h;while(1){h=b<<1;B=ba(c[n+(h<<2)>>2]|0,g)|0;C=(ba(c[o+(h<<2)>>2]|0,k)|0)+B>>14;B=h|1;D=ba(c[n+(B<<2)>>2]|0,g)|0;E=(ba(c[o+(B<<2)>>2]|0,k)|0)+D>>14;D=ba(c[d+(b<<2)>>2]|0,s)|0;F=D-1073741824+(ba(c[p+(b<<2)>>2]|0,l)|0)>>14;D=ba(c[e+(b<<2)>>2]|0,s)|0;G=D-1073741824+(ba(c[q+(b<<2)>>2]|0,l)|0)>>14;D=c[j>>2]|0;H=c[u>>2]|0;I=(ba(C-D|0,H)|0)+8192|0;C=(ba(E-D|0,H)|0)+8192|0;H=ba(G,c[v>>2]|0)|0;D=ba(c[w>>2]|0,G)|0;G=(ba(c[y>>2]|0,F)|0)+D|0;D=ba(c[z>>2]|0,F)|0;F=ba(c[f+(h<<2)>>2]|0,g)|0;E=(ba(c[r+(h<<2)>>2]|0,k)|0)+F>>1;F=ba(c[f+(B<<2)>>2]|0,g)|0;h=(ba(c[r+(B<<2)>>2]|0,k)|0)+F>>1;F=E+8192|0;B=h+8192|0;J=bFb(291)|0;if((J|0)==0){K=4;break}L=H+I|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[A]=x;x=x>>8;a[A+1|0]=x;J=bFb(291)|0;if((J|0)==0){K=10;break}L=G+I|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+2|0;x=O;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+2|0;x=de(O|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(291)|0;if((J|0)==0){K=17;break}L=D+I|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+4|0;x=P;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+4|0;x=de(P|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(291)|0;if((J|0)==0){K=24;break}if(F>>>0<1073741824>>>0){Q=F>>>14&65535}else{Q=-8192-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+6|0;x=Q;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+6|0;x=de(Q|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(291)|0;if((J|0)==0){K=31;break}E=H+C|0;if(E>>>0<1073741824>>>0){R=E>>>14&65535}else{R=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+8|0;x=R;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+8|0;x=de(R|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(291)|0;if((J|0)==0){K=38;break}E=G+C|0;if(E>>>0<1073741824>>>0){S=E>>>14&65535}else{S=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+10|0;x=S;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+10|0;x=de(S|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(291)|0;if((J|0)==0){K=45;break}E=D+C|0;if(E>>>0<1073741824>>>0){T=E>>>14&65535}else{T=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+12|0;x=T;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+12|0;x=de(T|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(291)|0;if((J|0)==0){K=52;break}if(B>>>0<1073741824>>>0){U=B>>>14&65535}else{U=-8192-h>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+14|0;x=U;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=A+14|0;x=de(U|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=b+1|0;if((J|0)<(t|0)){b=J;A=A+16|0}else{K=59;break}}if((K|0)==4){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==10){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==17){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==24){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==31){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==38){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==45){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==52){yDb(0,0,2166496,(V=i,i=i+24|0,c[V>>2]=2097816,c[V+8>>2]=2042544,c[V+16>>2]=653,V)|0);i=V;Cd()}else if((K|0)==59){i=m;return}}function twb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;p=i;q=o+1>>1;if((q|0)<=0){i=p;return}o=(g|0)>0;r=(l|0)>0;s=d+11300|0;t=d+11304|0;u=d+11308|0;v=d+11312|0;w=d+11316|0;y=d+11320|0;d=0;z=n;while(1){if(o){n=d<<1;A=n|1;B=0;C=-1073741824;D=-1073741824;do{E=c[f+(B<<2)>>2]|0;F=b[e+(B<<1)>>1]|0;C=(ba(F,c[E+(n<<2)>>2]|0)|0)+C|0;D=(ba(c[E+(A<<2)>>2]|0,F)|0)+D|0;B=B+1|0;}while((B|0)<(g|0));G=(C>>14)+65536|0;H=(D>>14)+65536|0}else{G=0;H=0}if(r){B=0;A=-1073741824;n=-1073741824;do{F=b[h+(B<<1)>>1]|0;A=(ba(F,c[(c[j+(B<<2)>>2]|0)+(d<<2)>>2]|0)|0)+A|0;n=(ba(c[(c[k+(B<<2)>>2]|0)+(d<<2)>>2]|0,F)|0)+n|0;B=B+1|0;}while((B|0)<(l|0));I=A>>14;J=n>>14}else{I=-65536;J=-65536}if(o){B=d<<1;D=B|1;C=-1073741824;F=0;E=-1073741824;do{K=c[m+(F<<2)>>2]|0;L=b[e+(F<<1)>>1]|0;E=(ba(L,c[K+(B<<2)>>2]|0)|0)+E|0;C=(ba(c[K+(D<<2)>>2]|0,L)|0)+C|0;F=F+1|0;}while((F|0)<(g|0));M=(E>>1)+536879104|0;N=(C>>1)+536879104|0}else{M=8192;N=8192}F=c[s>>2]|0;D=c[t>>2]|0;B=(ba(G-F|0,D)|0)+8192|0;n=(ba(H-F|0,D)|0)+8192|0;D=ba(c[u>>2]|0,J)|0;F=ba(c[v>>2]|0,J)|0;A=(ba(c[w>>2]|0,I)|0)+F|0;F=ba(c[y>>2]|0,I)|0;L=bFb(291)|0;if((L|0)==0){O=15;break}K=D+B|0;if(K>>>0<1073741824>>>0){P=K>>>14&65535}else{P=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){Q=P}else{Q=de(P|0)|0}x=Q;a[z]=x;x=x>>8;a[z+1|0]=x;L=bFb(291)|0;if((L|0)==0){O=21;break}K=A+B|0;if(K>>>0<1073741824>>>0){R=K>>>14&65535}else{R=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+2|0;x=R;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+2|0;x=de(R|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(291)|0;if((L|0)==0){O=28;break}K=F+B|0;if(K>>>0<1073741824>>>0){S=K>>>14&65535}else{S=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+4|0;x=S;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+4|0;x=de(S|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(291)|0;if((L|0)==0){O=35;break}if(M>>>0<1073741824>>>0){T=M>>>14&65535}else{T=-M>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+6|0;x=T;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+6|0;x=de(T|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(291)|0;if((L|0)==0){O=42;break}K=D+n|0;if(K>>>0<1073741824>>>0){U=K>>>14&65535}else{U=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+8|0;x=U;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+8|0;x=de(U|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(291)|0;if((L|0)==0){O=49;break}K=A+n|0;if(K>>>0<1073741824>>>0){V=K>>>14&65535}else{V=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+10|0;x=V;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+10|0;x=de(V|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(291)|0;if((L|0)==0){O=56;break}K=F+n|0;if(K>>>0<1073741824>>>0){W=K>>>14&65535}else{W=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+12|0;x=W;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+12|0;x=de(W|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=bFb(291)|0;if((L|0)==0){O=63;break}if(N>>>0<1073741824>>>0){X=N>>>14&65535}else{X=-N>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+14|0;x=X;a[L]=x;x=x>>8;a[L+1|0]=x}else{L=z+14|0;x=de(X|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x}L=d+1|0;if((L|0)<(q|0)){d=L;z=z+16|0}else{O=70;break}}if((O|0)==15){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==21){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==28){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==35){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==42){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==49){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==56){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==63){yDb(0,0,2166496,(Y=i,i=i+24|0,c[Y>>2]=2097816,c[Y+8>>2]=2042544,c[Y+16>>2]=653,Y)|0);i=Y;Cd()}else if((O|0)==70){i=p;return}}function uwb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;y=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ba((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ba((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ba(c[p>>2]|0,y)|0;z=ba(c[q>>2]|0,y)|0;y=(ba(c[r>>2]|0,w)|0)+z|0;z=ba(c[s>>2]|0,w)|0;w=bFb(291)|0;if((w|0)==0){D=5;break}v=A+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=de(E|0)|0}x=F;a[u]=x;x=x>>8;a[u+1|0]=x;w=bFb(291)|0;if((w|0)==0){D=11;break}v=y+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;x=G;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+2|0;x=de(G|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(291)|0;if((w|0)==0){D=18;break}v=z+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;x=H;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+4|0;x=de(H|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}if((bFb(291)|0)==0){D=25;break}w=u+6|0;x=-1;a[w]=x;x=x>>8;a[w+1|0]=x;w=bFb(291)|0;if((w|0)==0){D=27;break}v=A+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;x=I;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+8|0;x=de(I|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(291)|0;if((w|0)==0){D=34;break}v=y+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;x=J;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+10|0;x=de(J|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(291)|0;if((w|0)==0){D=41;break}v=z+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+12|0;x=K;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+12|0;x=de(K|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}if((bFb(291)|0)==0){D=48;break}w=u+14|0;x=-1;a[w]=x;x=x>>8;a[w+1|0]=x;w=t+1|0;if((w|0)<(k|0)){t=w;u=u+16|0}else{D=98;break}}if((D|0)==5){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==11){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==18){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==25){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==27){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==34){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==41){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==48){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==98){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ba((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ba((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ba(c[k>>2]|0,F)|0;E=ba(c[K>>2]|0,F)|0;F=(ba(c[J>>2]|0,G)|0)+E|0;E=ba(c[I>>2]|0,G)|0;G=bFb(291)|0;if((G|0)==0){D=53;break}d=s+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[H]=x;x=x>>8;a[H+1|0]=x;G=bFb(291)|0;if((G|0)==0){D=59;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;x=O;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+2|0;x=de(O|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(291)|0;if((G|0)==0){D=66;break}d=E+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;x=P;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+4|0;x=de(P|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}if((bFb(291)|0)==0){D=73;break}G=H+6|0;x=-1;a[G]=x;x=x>>8;a[G+1|0]=x;G=bFb(291)|0;if((G|0)==0){D=75;break}d=s+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;x=Q;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+8|0;x=de(Q|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(291)|0;if((G|0)==0){D=82;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;x=R;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+10|0;x=de(R|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(291)|0;if((G|0)==0){D=89;break}d=E+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+12|0;x=S;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+12|0;x=de(S|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}if((bFb(291)|0)==0){D=96;break}G=H+14|0;x=-1;a[G]=x;x=x>>8;a[G+1|0]=x;G=b+1|0;if((G|0)<(f|0)){b=G;H=H+16|0}else{D=98;break}}if((D|0)==53){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==59){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==66){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==73){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==75){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==82){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==89){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==96){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==98){i=l;return}}}function vwb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;y=h;while(1){h=b<<1;z=ba(c[g+(h<<2)>>2]|0,f)|0;A=(ba(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ba(c[g+(z<<2)>>2]|0,f)|0;B=(ba(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ba(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ba(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ba(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ba(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ba(A-h|0,D)|0)+8192|0;A=(ba(B-h|0,D)|0)+8192|0;D=ba(C,c[t>>2]|0)|0;h=ba(c[u>>2]|0,C)|0;C=(ba(c[v>>2]|0,z)|0)+h|0;h=ba(c[w>>2]|0,z)|0;z=bFb(291)|0;if((z|0)==0){F=4;break}B=D+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=de(G|0)|0}x=H;a[y]=x;x=x>>8;a[y+1|0]=x;z=bFb(291)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+2|0;x=I;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+2|0;x=de(I|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(291)|0;if((z|0)==0){F=17;break}B=h+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+4|0;x=J;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+4|0;x=de(J|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}if((bFb(291)|0)==0){F=24;break}z=y+6|0;x=-1;a[z]=x;x=x>>8;a[z+1|0]=x;z=bFb(291)|0;if((z|0)==0){F=26;break}B=D+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+8|0;x=K;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+8|0;x=de(K|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(291)|0;if((z|0)==0){F=33;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+10|0;x=L;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+10|0;x=de(L|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(291)|0;if((z|0)==0){F=40;break}B=h+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+12|0;x=M;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+12|0;x=de(M|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}if((bFb(291)|0)==0){F=47;break}z=y+14|0;x=-1;a[z]=x;x=x>>8;a[z+1|0]=x;z=b+1|0;if((z|0)<(r|0)){b=z;y=y+16|0}else{F=49;break}}if((F|0)==4){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==10){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==17){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==24){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==26){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==33){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==40){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==47){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==49){i=m;return}}function wwb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;y=n;while(1){if(o){n=d<<1;z=n|1;A=0;B=-1073741824;C=-1073741824;do{D=c[f+(A<<2)>>2]|0;E=b[e+(A<<1)>>1]|0;B=(ba(E,c[D+(n<<2)>>2]|0)|0)+B|0;C=(ba(c[D+(z<<2)>>2]|0,E)|0)+C|0;A=A+1|0;}while((A|0)<(g|0));F=(B>>14)+65536|0;G=(C>>14)+65536|0}else{F=0;G=0}if(q){A=0;z=-1073741824;n=-1073741824;do{E=b[h+(A<<1)>>1]|0;z=(ba(E,c[(c[j+(A<<2)>>2]|0)+(d<<2)>>2]|0)|0)+z|0;n=(ba(c[(c[k+(A<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+n|0;A=A+1|0;}while((A|0)<(l|0));H=z>>14;I=n>>14}else{H=-65536;I=-65536}A=c[r>>2]|0;C=c[s>>2]|0;B=(ba(F-A|0,C)|0)+8192|0;E=(ba(G-A|0,C)|0)+8192|0;C=ba(c[t>>2]|0,I)|0;A=ba(c[u>>2]|0,I)|0;D=(ba(c[v>>2]|0,H)|0)+A|0;A=ba(c[w>>2]|0,H)|0;J=bFb(291)|0;if((J|0)==0){K=11;break}L=C+B|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[y]=x;x=x>>8;a[y+1|0]=x;J=bFb(291)|0;if((J|0)==0){K=17;break}L=D+B|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+2|0;x=O;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+2|0;x=de(O|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(291)|0;if((J|0)==0){K=24;break}L=A+B|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+4|0;x=P;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+4|0;x=de(P|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}if((bFb(291)|0)==0){K=31;break}J=y+6|0;x=-1;a[J]=x;x=x>>8;a[J+1|0]=x;J=bFb(291)|0;if((J|0)==0){K=33;break}L=C+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+8|0;x=Q;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+8|0;x=de(Q|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(291)|0;if((J|0)==0){K=40;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+10|0;x=R;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+10|0;x=de(R|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(291)|0;if((J|0)==0){K=47;break}L=A+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+12|0;x=S;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+12|0;x=de(S|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}if((bFb(291)|0)==0){K=54;break}J=y+14|0;x=-1;a[J]=x;x=x>>8;a[J+1|0]=x;J=d+1|0;if((J|0)<(m|0)){d=J;y=y+16|0}else{K=56;break}}if((K|0)==11){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==17){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==24){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==31){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==33){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==40){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==47){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==54){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==56){i=p;return}}function xwb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;y=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ba((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ba((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ba(c[p>>2]|0,y)|0;z=ba(c[q>>2]|0,y)|0;y=(ba(c[r>>2]|0,w)|0)+z|0;z=ba(c[s>>2]|0,w)|0;w=bFb(42)|0;if((w|0)==0){D=5;break}v=A+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=de(E|0)|0}x=F;a[u]=x;x=x>>8;a[u+1|0]=x;w=bFb(42)|0;if((w|0)==0){D=11;break}v=y+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;x=G;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+2|0;x=de(G|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(42)|0;if((w|0)==0){D=18;break}v=z+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;x=H;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+4|0;x=de(H|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(42)|0;if((w|0)==0){D=25;break}v=A+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+6|0;x=I;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+6|0;x=de(I|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(42)|0;if((w|0)==0){D=32;break}v=y+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;x=J;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+8|0;x=de(J|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(42)|0;if((w|0)==0){D=39;break}v=z+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;x=K;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+10|0;x=de(K|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=t+1|0;if((w|0)<(k|0)){t=w;u=u+12|0}else{D=90;break}}if((D|0)==5){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==11){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==18){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==25){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==32){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==39){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==90){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ba((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ba((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ba(c[k>>2]|0,F)|0;E=ba(c[K>>2]|0,F)|0;F=(ba(c[J>>2]|0,G)|0)+E|0;E=ba(c[I>>2]|0,G)|0;G=bFb(42)|0;if((G|0)==0){D=49;break}d=s+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[H]=x;x=x>>8;a[H+1|0]=x;G=bFb(42)|0;if((G|0)==0){D=55;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;x=O;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+2|0;x=de(O|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(42)|0;if((G|0)==0){D=62;break}d=E+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;x=P;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+4|0;x=de(P|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(42)|0;if((G|0)==0){D=69;break}d=s+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+6|0;x=Q;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+6|0;x=de(Q|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(42)|0;if((G|0)==0){D=76;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;x=R;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+8|0;x=de(R|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(42)|0;if((G|0)==0){D=83;break}d=E+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;x=S;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+10|0;x=de(S|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=b+1|0;if((G|0)<(f|0)){b=G;H=H+12|0}else{D=90;break}}if((D|0)==49){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==55){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==62){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==69){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==76){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==83){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==90){i=l;return}}}function ywb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;y=h;while(1){h=b<<1;z=ba(c[g+(h<<2)>>2]|0,f)|0;A=(ba(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ba(c[g+(z<<2)>>2]|0,f)|0;B=(ba(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ba(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ba(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ba(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ba(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ba(A-h|0,D)|0)+8192|0;A=(ba(B-h|0,D)|0)+8192|0;D=ba(C,c[t>>2]|0)|0;h=ba(c[u>>2]|0,C)|0;C=(ba(c[v>>2]|0,z)|0)+h|0;h=ba(c[w>>2]|0,z)|0;z=bFb(42)|0;if((z|0)==0){F=4;break}B=D+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=de(G|0)|0}x=H;a[y]=x;x=x>>8;a[y+1|0]=x;z=bFb(42)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+2|0;x=I;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+2|0;x=de(I|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(42)|0;if((z|0)==0){F=17;break}B=h+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+4|0;x=J;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+4|0;x=de(J|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(42)|0;if((z|0)==0){F=24;break}B=D+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+6|0;x=K;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+6|0;x=de(K|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(42)|0;if((z|0)==0){F=31;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+8|0;x=L;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+8|0;x=de(L|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(42)|0;if((z|0)==0){F=38;break}B=h+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+10|0;x=M;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+10|0;x=de(M|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=b+1|0;if((z|0)<(r|0)){b=z;y=y+12|0}else{F=45;break}}if((F|0)==4){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==10){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==17){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==24){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==31){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==38){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==45){i=m;return}}function zwb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;y=n;while(1){if(o){n=d<<1;z=n|1;A=-1073741824;B=-1073741824;C=0;do{D=c[f+(C<<2)>>2]|0;E=b[e+(C<<1)>>1]|0;A=(ba(E,c[D+(n<<2)>>2]|0)|0)+A|0;B=(ba(c[D+(z<<2)>>2]|0,E)|0)+B|0;C=C+1|0;}while((C|0)<(g|0));F=(A>>14)+65536|0;G=(B>>14)+65536|0}else{F=0;G=0}if(q){C=-1073741824;z=-1073741824;n=0;do{E=b[h+(n<<1)>>1]|0;C=(ba(E,c[(c[j+(n<<2)>>2]|0)+(d<<2)>>2]|0)|0)+C|0;z=(ba(c[(c[k+(n<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+z|0;n=n+1|0;}while((n|0)<(l|0));H=C>>14;I=z>>14}else{H=-65536;I=-65536}n=c[r>>2]|0;B=c[s>>2]|0;A=(ba(F-n|0,B)|0)+8192|0;E=(ba(G-n|0,B)|0)+8192|0;B=ba(c[t>>2]|0,I)|0;n=ba(c[u>>2]|0,I)|0;D=(ba(c[v>>2]|0,H)|0)+n|0;n=ba(c[w>>2]|0,H)|0;J=bFb(42)|0;if((J|0)==0){K=11;break}L=B+A|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[y]=x;x=x>>8;a[y+1|0]=x;J=bFb(42)|0;if((J|0)==0){K=17;break}L=D+A|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+2|0;x=O;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+2|0;x=de(O|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(42)|0;if((J|0)==0){K=24;break}L=n+A|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+4|0;x=P;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+4|0;x=de(P|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(42)|0;if((J|0)==0){K=31;break}L=B+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+6|0;x=Q;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+6|0;x=de(Q|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(42)|0;if((J|0)==0){K=38;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+8|0;x=R;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+8|0;x=de(R|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(42)|0;if((J|0)==0){K=45;break}L=n+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+10|0;x=S;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+10|0;x=de(S|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=d+1|0;if((J|0)<(m|0)){d=J;y=y+12|0}else{K=52;break}}if((K|0)==11){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==17){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==24){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==31){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==38){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==45){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==52){i=p;return}}function _epzs_motion_search2$0(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0;b=c[a+16>>2]|0;f=c[a+24>>2]|0;g=c[a+32>>2]|0;h=c[a+48>>2]|0;j=c[a+56>>2]|0;k=c[a+72>>2]|0;l=c[a+80>>2]|0;m=c[a+168>>2]|0;n=c[a+184>>2]|0;o=c[a+6136>>2]|0;p=c[a+6144>>2]|0;q=c[a+6152>>2]|0;r=c[a+6160>>2]|0;s=c[a+6168>>2]|0;t=c[a+19096>>2]|0;u=c[a+19104>>2]|0;v=c[a+19112>>2]|0;w=c[a+19120>>2]|0;a:do{if((s|0)<2){x=c[(b+12220|0)>>2]|0;y=c[(b+12264|0)>>2]|0;z=c[(b+12272|0)>>2]|0;A=c[(b+12268|0)>>2]|0;B=c[(b+12276|0)>>2]|0;C=c[(b+12464|0)>>2]|0;D=c[(b+12280|0)>>2]|0;E=c[(b+12284|0)>>2]|0;F=c[(b+12216|0)>>2]|0;G=c[(b+12224|0)>>2]|0;H=c[(b+10468|0)>>2]|0;I=c[(b+10472|0)>>2]|0;J=p+G+(o<<11)|0;K=(o<<3)+p&63;if((c[(F+(K<<2)|0)>>2]|0)!=(J|0)){do{if((m&4|0)==0){L=c[b+12416>>2]|0;M=c[b+12420>>2]|0;N=(c[b+12352+(j<<4)>>2]|0)+((ba(L,o)|0)+p)|0;O=Pe[H&255](b,c[b+12288+(h<<4)>>2]|0,N,L,8)|0;if((m&2|0)==0){P=O;break}N=o<<1&2|p&1;Q=c[b+12208>>2]|0;R=(ba(M,o>>1)|0)+(p>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(N<<2)>>2]&1023](Q+(L<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+R|0,M,4);cf[c[(c[(b+12444|0)>>2]|0)+16+(N<<2)>>2]&1023](Q+(L<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+R|0,M,4);R=(Pe[I&255](b,Q+(L<<4)|0,c[b+12288+(h<<4)+4>>2]|0,M,4)|0)+O|0;P=R+(Pe[I&255](b,Q+(L<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,M,4)|0)|0}else{M=c[b+12416>>2]|0;L=p<<n;Q=o<<n;if((y|0)>(p|0)){P=536870912;break}if((L|0)>(A<<n|0)|(z|0)>(o|0)){P=536870912;break}if((Q|0)>(B<<n|0)){P=536870912;break}R=e[b+13872>>1]|0;O=e[b+13874>>1]|0;N=(m&1)<<1|1;b:do{if((c[b+11740>>2]|0)==1){if((L|0)==0){S=0;while(1){T=c[b+12160+(S<<3)>>2]|0;U=(c[b+12160+(S<<3)+4>>2]|0)+Q|0;V=((ba(c[b+12128+(S<<3)>>2]|0,O-R|0)|0)/(R|0)|0)+((S&1)<<(m&1|4))|0;W=c[b+12128+(S<<3)+4>>2]|0;if((Q|0)==0){X=S>>1;Y=((ba(W,O-R|0)|0)/(R|0)|0)+(X<<(m&1|4))|0;Z=X}else{Y=U-W|0;Z=S>>1}W=((Y&N)<<n)+(V&N)|0;X=(c[(b+12208|0)>>2]|0)+((ba(Z,M<<3)|0)+(S<<3&8))|0;if((m&1|0)==0){_=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,M)|0)+(T>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(T&N)|0)<<2)>>2]&1023](X,_,M,8);_=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Y>>1,M)|0)+(V>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(W<<2)>>2]&1023](X,_,M,8)}else{_=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,M)|0)+(T>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(T&N)|0)<<2)>>2]&4095](X,_,M);_=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Y>>2,M)|0)+(V>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](X,_,M)}S=S+1|0;if((S|0)>=4){break b}}}if((Q|0)==0){S=0;do{_=(c[b+12160+(S<<3)>>2]|0)+L|0;X=c[b+12160+(S<<3)+4>>2]|0;W=_-(c[b+12128+(S<<3)>>2]|0)|0;V=S>>1;T=((ba(c[b+12128+(S<<3)+4>>2]|0,O-R|0)|0)/(R|0)|0)+(V<<(m&1|4))|0;U=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ba(V,M<<3)|0))|0;if((m&1|0)==0){V=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(X>>1,M)|0)+(_>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((X&N)<<n)+(_&N)|0)<<2)>>2]&1023](U,V,M,8);V=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(T>>1,M)|0)+(W>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((T&N)<<n)+(W&N)|0)<<2)>>2]&1023](U,V,M,8)}else{V=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(X>>2,M)|0)+(_>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(_&N)|0)<<2)>>2]&4095](U,V,M);V=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(T>>2,M)|0)+(W>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((T&N)<<n)+(W&N)|0)<<2)>>2]&4095](U,V,M)}S=S+1|0;}while((S|0)<4)}else{S=0;do{V=(c[b+12160+(S<<3)>>2]|0)+L|0;U=(c[b+12160+(S<<3)+4>>2]|0)+Q|0;W=V-(c[b+12128+(S<<3)>>2]|0)|0;T=U-(c[b+12128+(S<<3)+4>>2]|0)|0;_=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ba(S>>1,M<<3)|0))|0;if((m&1|0)==0){X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,M)|0)+(V>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(V&N)|0)<<2)>>2]&1023](_,X,M,8);X=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(T>>1,M)|0)+(W>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((T&N)<<n)+(W&N)|0)<<2)>>2]&1023](_,X,M,8)}else{X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,M)|0)+(V>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(V&N)|0)<<2)>>2]&4095](_,X,M);X=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(T>>2,M)|0)+(W>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((T&N)<<n)+(W&N)|0)<<2)>>2]&4095](_,X,M)}S=S+1|0;}while((S|0)<4)}}else{S=(c[b+12160>>2]|0)+L|0;X=(c[b+12164>>2]|0)+Q|0;_=c[b+12128>>2]|0;if((L|0)==0){$=(ba(_,O-R|0)|0)/(R|0)|0}else{$=S-_|0}_=c[b+12132>>2]|0;if((Q|0)==0){aa=(ba(_,O-R|0)|0)/(R|0)|0}else{aa=X-_|0}_=((aa&N)<<n)+($&N)|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(X>>1,M)|0)+(S>>1))|0;cf[c[(c[b+12444>>2]|0)+((((X&N)<<n)+(S&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,W,M,16);W=(c[b+12352+(j<<4)+32>>2]|0)+((ba(aa>>1,M)|0)+($>>1))|0;cf[c[(c[b+12448>>2]|0)+(_<<2)>>2]&1023](c[(b+12208|0)>>2]|0,W,M,16);break}else{W=(ba(X>>2,M)|0)+(S>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+W|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(W+8|0)|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(W+(M<<3))|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((W+8|0)+(M<<3))|0,M);W=(ba(aa>>2,M)|0)+($>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+W|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(W+8|0)|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(W+(M<<3))|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((W+8|0)+(M<<3))|0,M);break}}}while(0);P=Pe[H&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,M,16)|0}}while(0);c[x+(K<<2)>>2]=P;c[(F+(K<<2)|0)>>2]=J}N=(m&1)<<1|1;R=m&1|4;O=(m&1|0)==0;Q=q;L=-1;W=p;_=o;c:while(1){do{if((L|0)!=2&(W|0)>(y|0)){S=W-1|0;X=S+G+(_<<11)|0;T=(_<<3)+S&63;if((c[(F+(T<<2)|0)>>2]|0)==(X|0)){ca=Q;da=-1;ea=W;break}V=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){U=c[(b+12420|0)>>2]|0;fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(V,_)|0)+S)|0;ga=Pe[H&255](b,c[(b+12288+(h<<4)|0)>>2]|0,fa,V,8)|0;if((m&2|0)==0){ha=ga;break}fa=_<<1&2|S&1;ia=c[(b+12208|0)>>2]|0;ja=(ba(U,_>>1)|0)+(S>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(fa<<2)>>2]&1023](ia+(V<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ja|0,U,4);cf[c[(c[(b+12444|0)>>2]|0)+16+(fa<<2)>>2]&1023](ia+(V<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ja|0,U,4);ja=(Pe[I&255](b,ia+(V<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,U,4)|0)+ga|0;ha=ja+(Pe[I&255](b,ia+(V<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,U,4)|0)|0}else{U=_<<n;if((c[(b+12264|0)>>2]|0)>(S|0)){ha=536870912;break}if((S<<n|0)>(c[(b+12268|0)>>2]<<n|0)){ha=536870912;break}if((c[(b+12272|0)>>2]|0)>(_|0)){ha=536870912;break}if((U|0)>(c[(b+12276|0)>>2]<<n|0)){ha=536870912;break}ia=e[(b+13872|0)>>1]|0;ja=e[(b+13874|0)>>1]|0;d:do{if((c[(b+11740|0)>>2]|0)==1){if((S<<n|0)==0){ga=0;while(1){fa=c[b+12160+(ga<<3)>>2]|0;ka=(c[b+12160+(ga<<3)+4>>2]|0)+U|0;la=((ba(c[b+12128+(ga<<3)>>2]|0,ja-ia|0)|0)/(ia|0)|0)+((ga&1)<<R)|0;ma=c[b+12128+(ga<<3)+4>>2]|0;if((U|0)==0){na=ga>>1;oa=((ba(ma,ja-ia|0)|0)/(ia|0)|0)+(na<<R)|0;pa=na}else{oa=ka-ma|0;pa=ga>>1}ma=((oa&N)<<n)+(la&N)|0;na=(c[(b+12208|0)>>2]|0)+((ba(pa,V<<3)|0)+(ga<<3&8))|0;if(O){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,V)|0)+(fa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&N)<<n)+(fa&N)|0)<<2)>>2]&1023](na,qa,V,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(oa>>1,V)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ma<<2)>>2]&1023](na,qa,V,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>2,V)|0)+(fa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&N)<<n)+(fa&N)|0)<<2)>>2]&4095](na,qa,V);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(oa>>2,V)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](na,qa,V)}ga=ga+1|0;if((ga|0)>=4){break d}}}if((U|0)==0){ga=0;do{qa=(c[b+12160+(ga<<3)>>2]|0)+(S<<n)|0;na=c[b+12160+(ga<<3)+4>>2]|0;ma=qa-(c[b+12128+(ga<<3)>>2]|0)|0;la=ga>>1;fa=((ba(c[b+12128+(ga<<3)+4>>2]|0,ja-ia|0)|0)/(ia|0)|0)+(la<<R)|0;ka=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(la,V<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,V)|0)+(qa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((na&N)<<n)+(qa&N)|0)<<2)>>2]&1023](ka,la,V,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(fa>>1,V)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&1023](ka,la,V,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>2,V)|0)+(qa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(qa&N)|0)<<2)>>2]&4095](ka,la,V);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(fa>>2,V)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](ka,la,V)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{la=(c[b+12160+(ga<<3)>>2]|0)+(S<<n)|0;ka=(c[b+12160+(ga<<3)+4>>2]|0)+U|0;ma=la-(c[b+12128+(ga<<3)>>2]|0)|0;fa=ka-(c[b+12128+(ga<<3)+4>>2]|0)|0;qa=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(ga>>1,V<<3)|0))|0;if(O){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,V)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&N)<<n)+(la&N)|0)<<2)>>2]&1023](qa,na,V,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(fa>>1,V)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&1023](qa,na,V,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>2,V)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&N)<<n)+(la&N)|0)<<2)>>2]&4095](qa,na,V);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(fa>>2,V)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](qa,na,V)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+(S<<n)|0;na=(c[(b+12164|0)>>2]|0)+U|0;qa=c[(b+12128|0)>>2]|0;if((S<<n|0)==0){ra=(ba(qa,ja-ia|0)|0)/(ia|0)|0}else{ra=ga-qa|0}qa=c[(b+12132|0)>>2]|0;if((U|0)==0){sa=(ba(qa,ja-ia|0)|0)/(ia|0)|0}else{sa=na-qa|0}qa=((sa&N)<<n)+(ra&N)|0;if(O){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,V)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ma,V,16);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(sa>>1,V)|0)+(ra>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(qa<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ma,V,16);break}else{ma=(ba(na>>2,V)|0)+(ga>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ma|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+8|0)|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+(V<<3))|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ma+8|0)+(V<<3))|0,V);ma=(ba(sa>>2,V)|0)+(ra>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ma|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+8|0)|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+(V<<3))|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ma+8|0)+(V<<3))|0,V);break}}}while(0);ha=Pe[H&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,V,16)|0}}while(0);c[(F+(T<<2)|0)>>2]=X;c[x+(T<<2)>>2]=ha;V=(ba((d[C+((_<<n)-E)|0]|0)+(d[C+((S<<n)-D)|0]|0)|0,l)|0)+ha|0;if((V|0)>=(Q|0)){ca=Q;da=-1;ea=W;break}c[r>>2]=S;c[(r+4|0)>>2]=_;ca=V;da=0;ea=S}else{ca=Q;da=-1;ea=W}}while(0);do{if((L|0)!=3&(_|0)>(z|0)){M=_-1|0;V=W+G+(M<<11)|0;ia=(M<<3)+W&63;if((c[(F+(ia<<2)|0)>>2]|0)==(V|0)){ta=ca;ua=da;va=ea;wa=_;break}ja=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){U=c[(b+12420|0)>>2]|0;ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja,M)|0)+W)|0;qa=Pe[H&255](b,c[(b+12288+(h<<4)|0)>>2]|0,ma,ja,8)|0;if((m&2|0)==0){xa=qa;break}ma=M<<1&2|W&1;ga=c[(b+12208|0)>>2]|0;na=(ba(U,M>>1)|0)+(W>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(ma<<2)>>2]&1023](ga+(ja<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+na|0,U,4);cf[c[(c[(b+12444|0)>>2]|0)+16+(ma<<2)>>2]&1023](ga+(ja<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+na|0,U,4);na=(Pe[I&255](b,ga+(ja<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,U,4)|0)+qa|0;xa=na+(Pe[I&255](b,ga+(ja<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,U,4)|0)|0}else{U=W<<n;if((c[(b+12264|0)>>2]|0)>(W|0)){xa=536870912;break}if((U|0)>(c[(b+12268|0)>>2]<<n|0)){xa=536870912;break}if((c[(b+12272|0)>>2]|0)>(M|0)){xa=536870912;break}if((M<<n|0)>(c[(b+12276|0)>>2]<<n|0)){xa=536870912;break}ga=e[(b+13872|0)>>1]|0;na=e[(b+13874|0)>>1]|0;e:do{if((c[(b+11740|0)>>2]|0)==1){if((U|0)==0){qa=0;while(1){ma=c[b+12160+(qa<<3)>>2]|0;fa=(c[b+12160+(qa<<3)+4>>2]|0)+(M<<n)|0;la=((ba(c[b+12128+(qa<<3)>>2]|0,na-ga|0)|0)/(ga|0)|0)+((qa&1)<<R)|0;ka=c[b+12128+(qa<<3)+4>>2]|0;if((M<<n|0)==0){ya=qa>>1;za=((ba(ka,na-ga|0)|0)/(ga|0)|0)+(ya<<R)|0;Aa=ya}else{za=fa-ka|0;Aa=qa>>1}ka=((za&N)<<n)+(la&N)|0;ya=(c[(b+12208|0)>>2]|0)+((ba(Aa,ja<<3)|0)+(qa<<3&8))|0;if(O){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>1,ja)|0)+(ma>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&1023](ya,Ba,ja,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(za>>1,ja)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&1023](ya,Ba,ja,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>2,ja)|0)+(ma>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](ya,Ba,ja);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(za>>2,ja)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](ya,Ba,ja)}qa=qa+1|0;if((qa|0)>=4){break e}}}if((M<<n|0)==0){qa=0;do{Ba=(c[b+12160+(qa<<3)>>2]|0)+U|0;ya=c[b+12160+(qa<<3)+4>>2]|0;ka=Ba-(c[b+12128+(qa<<3)>>2]|0)|0;la=qa>>1;ma=((ba(c[b+12128+(qa<<3)+4>>2]|0,na-ga|0)|0)/(ga|0)|0)+(la<<R)|0;fa=(c[(b+12208|0)>>2]|0)+((qa<<3&8)+(ba(la,ja<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,ja)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&N)<<n)+(Ba&N)|0)<<2)>>2]&1023](fa,la,ja,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ma>>1,ja)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&1023](fa,la,ja,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>2,ja)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(Ba&N)|0)<<2)>>2]&4095](fa,la,ja);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ma>>2,ja)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&4095](fa,la,ja)}qa=qa+1|0;}while((qa|0)<4)}else{qa=0;do{la=(c[b+12160+(qa<<3)>>2]|0)+U|0;fa=(c[b+12160+(qa<<3)+4>>2]|0)+(M<<n)|0;ka=la-(c[b+12128+(qa<<3)>>2]|0)|0;ma=fa-(c[b+12128+(qa<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((qa<<3&8)+(ba(qa>>1,ja<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>1,ja)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&N)<<n)+(la&N)|0)<<2)>>2]&1023](Ba,ya,ja,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ma>>1,ja)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&1023](Ba,ya,ja,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>2,ja)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((fa&N)<<n)+(la&N)|0)<<2)>>2]&4095](Ba,ya,ja);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ma>>2,ja)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&4095](Ba,ya,ja)}qa=qa+1|0;}while((qa|0)<4)}}else{qa=(c[(b+12160|0)>>2]|0)+U|0;ya=(c[(b+12164|0)>>2]|0)+(M<<n)|0;Ba=c[(b+12128|0)>>2]|0;if((U|0)==0){Ca=(ba(Ba,na-ga|0)|0)/(ga|0)|0}else{Ca=qa-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((M<<n|0)==0){Da=(ba(Ba,na-ga|0)|0)/(ga|0)|0}else{Da=ya-Ba|0}Ba=((Da&N)<<n)+(Ca&N)|0;if(O){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,ja)|0)+(qa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,ja,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Da>>1,ja)|0)+(Ca>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,ja,16);break}else{ka=(ba(ya>>2,ja)|0)+(qa>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,ja);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,ja);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ja<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(ja<<3))|0,ja);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(ja<<3))|0,ja);ka=(ba(Da>>2,ja)|0)+(Ca>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,ja);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,ja);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ja<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(ja<<3))|0,ja);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(ja<<3))|0,ja);break}}}while(0);xa=Pe[H&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ja,16)|0}}while(0);c[(F+(ia<<2)|0)>>2]=V;c[x+(ia<<2)>>2]=xa;ja=(ba((d[C+((M<<n)-E)|0]|0)+(d[C+((W<<n)-D)|0]|0)|0,l)|0)+xa|0;if((ja|0)>=(ca|0)){ta=ca;ua=da;va=ea;wa=_;break}c[r>>2]=W;c[(r+4|0)>>2]=M;ta=ja;ua=1;va=W;wa=M}else{ta=ca;ua=da;va=ea;wa=_}}while(0);do{if((L|0)!=0&(W|0)<(A|0)){ja=W+1|0;S=ja+G+(_<<11)|0;T=(_<<3)+ja&63;if((c[(F+(T<<2)|0)>>2]|0)==(S|0)){Ea=ta;Fa=ua;Ga=va;Ha=wa;break}X=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ga=c[(b+12420|0)>>2]|0;na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(X,_)|0)+ja)|0;U=Pe[H&255](b,c[(b+12288+(h<<4)|0)>>2]|0,na,X,8)|0;if((m&2|0)==0){Ia=U;break}na=_<<1&2|ja&1;ka=c[(b+12208|0)>>2]|0;Ba=(ba(ga,_>>1)|0)+(ja>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(na<<2)>>2]&1023](ka+(X<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+Ba|0,ga,4);cf[c[(c[(b+12444|0)>>2]|0)+16+(na<<2)>>2]&1023](ka+(X<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+Ba|0,ga,4);Ba=(Pe[I&255](b,ka+(X<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ga,4)|0)+U|0;Ia=Ba+(Pe[I&255](b,ka+(X<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ga,4)|0)|0}else{ga=_<<n;if((c[(b+12264|0)>>2]|0)>(ja|0)){Ia=536870912;break}if((ja<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Ia=536870912;break}if((c[(b+12272|0)>>2]|0)>(_|0)){Ia=536870912;break}if((ga|0)>(c[(b+12276|0)>>2]<<n|0)){Ia=536870912;break}ka=e[(b+13872|0)>>1]|0;Ba=e[(b+13874|0)>>1]|0;f:do{if((c[(b+11740|0)>>2]|0)==1){if((ja<<n|0)==0){U=0;while(1){na=c[b+12160+(U<<3)>>2]|0;qa=(c[b+12160+(U<<3)+4>>2]|0)+ga|0;ya=((ba(c[b+12128+(U<<3)>>2]|0,Ba-ka|0)|0)/(ka|0)|0)+((U&1)<<R)|0;ma=c[b+12128+(U<<3)+4>>2]|0;if((ga|0)==0){la=U>>1;Ja=((ba(ma,Ba-ka|0)|0)/(ka|0)|0)+(la<<R)|0;Ka=la}else{Ja=qa-ma|0;Ka=U>>1}ma=((Ja&N)<<n)+(ya&N)|0;la=(c[(b+12208|0)>>2]|0)+((ba(Ka,X<<3)|0)+(U<<3&8))|0;if(O){fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa>>1,X)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((qa&N)<<n)+(na&N)|0)<<2)>>2]&1023](la,fa,X,8);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ja>>1,X)|0)+(ya>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ma<<2)>>2]&1023](la,fa,X,8)}else{fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa>>2,X)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((qa&N)<<n)+(na&N)|0)<<2)>>2]&4095](la,fa,X);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ja>>2,X)|0)+(ya>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](la,fa,X)}U=U+1|0;if((U|0)>=4){break f}}}if((ga|0)==0){U=0;do{fa=(c[b+12160+(U<<3)>>2]|0)+(ja<<n)|0;la=c[b+12160+(U<<3)+4>>2]|0;ma=fa-(c[b+12128+(U<<3)>>2]|0)|0;ya=U>>1;na=((ba(c[b+12128+(U<<3)+4>>2]|0,Ba-ka|0)|0)/(ka|0)|0)+(ya<<R)|0;qa=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(ya,X<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(la>>1,X)|0)+(fa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((la&N)<<n)+(fa&N)|0)<<2)>>2]&1023](qa,ya,X,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>1,X)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&1023](qa,ya,X,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(la>>2,X)|0)+(fa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(fa&N)|0)<<2)>>2]&4095](qa,ya,X);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>2,X)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&4095](qa,ya,X)}U=U+1|0;}while((U|0)<4)}else{U=0;do{ya=(c[b+12160+(U<<3)>>2]|0)+(ja<<n)|0;qa=(c[b+12160+(U<<3)+4>>2]|0)+ga|0;ma=ya-(c[b+12128+(U<<3)>>2]|0)|0;na=qa-(c[b+12128+(U<<3)+4>>2]|0)|0;fa=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(U>>1,X<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa>>1,X)|0)+(ya>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((qa&N)<<n)+(ya&N)|0)<<2)>>2]&1023](fa,la,X,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>1,X)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&1023](fa,la,X,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa>>2,X)|0)+(ya>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((qa&N)<<n)+(ya&N)|0)<<2)>>2]&4095](fa,la,X);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>2,X)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&4095](fa,la,X)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(ja<<n)|0;la=(c[(b+12164|0)>>2]|0)+ga|0;fa=c[(b+12128|0)>>2]|0;if((ja<<n|0)==0){La=(ba(fa,Ba-ka|0)|0)/(ka|0)|0}else{La=U-fa|0}fa=c[(b+12132|0)>>2]|0;if((ga|0)==0){Ma=(ba(fa,Ba-ka|0)|0)/(ka|0)|0}else{Ma=la-fa|0}fa=((Ma&N)<<n)+(La&N)|0;if(O){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(la>>1,X)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((la&N)<<n)+(U&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ma,X,16);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ma>>1,X)|0)+(La>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(fa<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ma,X,16);break}else{ma=(ba(la>>2,X)|0)+(U>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ma|0,X);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+8|0)|0,X);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(X<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+(X<<3))|0,X);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((X<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ma+8|0)+(X<<3))|0,X);ma=(ba(Ma>>2,X)|0)+(La>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ma|0,X);Xe[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+8|0)|0,X);Xe[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(X<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+(X<<3))|0,X);Xe[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((X<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ma+8|0)+(X<<3))|0,X);break}}}while(0);Ia=Pe[H&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,X,16)|0}}while(0);c[(F+(T<<2)|0)>>2]=S;c[x+(T<<2)>>2]=Ia;X=(ba((d[C+((_<<n)-E)|0]|0)+(d[C+((ja<<n)-D)|0]|0)|0,l)|0)+Ia|0;if((X|0)>=(ta|0)){Ea=ta;Fa=ua;Ga=va;Ha=wa;break}c[r>>2]=ja;c[(r+4|0)>>2]=_;Ea=X;Fa=2;Ga=ja;Ha=_}else{Ea=ta;Fa=ua;Ga=va;Ha=wa}}while(0);do{if((L|0)!=1&(_|0)<(B|0)){X=_+1|0;M=W+G+(X<<11)|0;ia=(X<<3)+W&63;if((c[(F+(ia<<2)|0)>>2]|0)==(M|0)){break}V=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ka=c[(b+12420|0)>>2]|0;Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(V,X)|0)+W)|0;ga=Pe[H&255](b,c[(b+12288+(h<<4)|0)>>2]|0,Ba,V,8)|0;if((m&2|0)==0){Na=ga;break}Ba=X<<1&2|W&1;ma=c[(b+12208|0)>>2]|0;fa=(ba(ka,X>>1)|0)+(W>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(Ba<<2)>>2]&1023](ma+(V<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+fa|0,ka,4);cf[c[(c[(b+12444|0)>>2]|0)+16+(Ba<<2)>>2]&1023](ma+(V<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+fa|0,ka,4);fa=(Pe[I&255](b,ma+(V<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ka,4)|0)+ga|0;Na=fa+(Pe[I&255](b,ma+(V<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ka,4)|0)|0}else{ka=W<<n;if((c[(b+12264|0)>>2]|0)>(W|0)){Na=536870912;break}if((ka|0)>(c[(b+12268|0)>>2]<<n|0)){Na=536870912;break}if((c[(b+12272|0)>>2]|0)>(X|0)){Na=536870912;break}if((X<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Na=536870912;break}ma=e[(b+13872|0)>>1]|0;fa=e[(b+13874|0)>>1]|0;g:do{if((c[(b+11740|0)>>2]|0)==1){if((ka|0)==0){ga=0;while(1){Ba=c[b+12160+(ga<<3)>>2]|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(X<<n)|0;la=((ba(c[b+12128+(ga<<3)>>2]|0,fa-ma|0)|0)/(ma|0)|0)+((ga&1)<<R)|0;na=c[b+12128+(ga<<3)+4>>2]|0;if((X<<n|0)==0){ya=ga>>1;Oa=((ba(na,fa-ma|0)|0)/(ma|0)|0)+(ya<<R)|0;Pa=ya}else{Oa=U-na|0;Pa=ga>>1}na=((Oa&N)<<n)+(la&N)|0;ya=(c[(b+12208|0)>>2]|0)+((ba(Pa,V<<3)|0)+(ga<<3&8))|0;if(O){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,V)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(Ba&N)|0)<<2)>>2]&1023](ya,qa,V,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Oa>>1,V)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(na<<2)>>2]&1023](ya,qa,V,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,V)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(Ba&N)|0)<<2)>>2]&4095](ya,qa,V);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Oa>>2,V)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](ya,qa,V)}ga=ga+1|0;if((ga|0)>=4){break g}}}if((X<<n|0)==0){ga=0;do{qa=(c[b+12160+(ga<<3)>>2]|0)+ka|0;ya=c[b+12160+(ga<<3)+4>>2]|0;na=qa-(c[b+12128+(ga<<3)>>2]|0)|0;la=ga>>1;Ba=((ba(c[b+12128+(ga<<3)+4>>2]|0,fa-ma|0)|0)/(ma|0)|0)+(la<<R)|0;U=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(la,V<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,V)|0)+(qa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&1023](U,la,V,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ba>>1,V)|0)+(na>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&1023](U,la,V,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>2,V)|0)+(qa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095](U,la,V);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ba>>2,V)|0)+(na>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&4095](U,la,V)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{la=(c[b+12160+(ga<<3)>>2]|0)+ka|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(X<<n)|0;na=la-(c[b+12128+(ga<<3)>>2]|0)|0;Ba=U-(c[b+12128+(ga<<3)+4>>2]|0)|0;qa=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(ga>>1,V<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,V)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(la&N)|0)<<2)>>2]&1023](qa,ya,V,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ba>>1,V)|0)+(na>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&1023](qa,ya,V,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,V)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(la&N)|0)<<2)>>2]&4095](qa,ya,V);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ba>>2,V)|0)+(na>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&4095](qa,ya,V)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+ka|0;ya=(c[(b+12164|0)>>2]|0)+(X<<n)|0;qa=c[(b+12128|0)>>2]|0;if((ka|0)==0){Qa=(ba(qa,fa-ma|0)|0)/(ma|0)|0}else{Qa=ga-qa|0}qa=c[(b+12132|0)>>2]|0;if((X<<n|0)==0){Ra=(ba(qa,fa-ma|0)|0)/(ma|0)|0}else{Ra=ya-qa|0}qa=((Ra&N)<<n)+(Qa&N)|0;if(O){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,V)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,na,V,16);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ra>>1,V)|0)+(Qa>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(qa<<2)>>2]&1023](c[(b+12208|0)>>2]|0,na,V,16);break}else{na=(ba(ya>>2,V)|0)+(ga>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+na|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(na+8|0)|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(na+(V<<3))|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((na+8|0)+(V<<3))|0,V);na=(ba(Ra>>2,V)|0)+(Qa>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+na|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(na+8|0)|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(na+(V<<3))|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((na+8|0)+(V<<3))|0,V);break}}}while(0);Na=Pe[H&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,V,16)|0}}while(0);c[(F+(ia<<2)|0)>>2]=M;c[x+(ia<<2)>>2]=Na;V=(ba((d[C+((X<<n)-E)|0]|0)+(d[C+((W<<n)-D)|0]|0)|0,l)|0)+Na|0;if((V|0)>=(Ea|0)){break}c[r>>2]=W;c[(r+4|0)>>2]=X;Q=V;L=3;W=W;_=X;continue c}}while(0);if((Fa|0)==-1){t=Ea;break}else{Q=Ea;L=Fa;W=Ga;_=Ha}}u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}if((s|0)>1024){t=Gmb(b,r,q,h,j,l,0,8,m)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}if((s|0)>768){_=c[(b+12220|0)>>2]|0;W=c[(b+12264|0)>>2]|0;L=c[(b+12272|0)>>2]|0;Q=c[(b+12268|0)>>2]|0;D=c[(b+12276|0)>>2]|0;C=c[(b+12464|0)>>2]|0;E=c[(b+12280|0)>>2]|0;x=c[(b+12284|0)>>2]|0;F=c[(b+12216|0)>>2]|0;H=c[(b+12224|0)>>2]|0;N=c[(b+10468|0)>>2]|0;O=c[(b+10472|0)>>2]|0;R=p-(s&254)+1|0;I=(R|0)>(W|0)?R:W;R=(s&254)-1+p|0;G=(R|0)>(Q|0)?Q:R;if((I|0)>(G|0)){Sa=q;Ta=p;Ua=o}else{R=(o<<11)+H|0;B=o<<3;A=o<<1&2;z=o>>1;y=o<<n;J=(m&1)<<1|1;K=I;I=q;V=p;ja=o;while(1){T=R+K|0;S=K+B&63;do{if((c[(F+(S<<2)|0)>>2]|0)==(T|0)){Va=I;Wa=V;Xa=ja}else{ma=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){fa=c[(b+12420|0)>>2]|0;ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma,o)|0)+K)|0;na=Pe[N&255](b,c[(b+12288+(h<<4)|0)>>2]|0,ka,ma,8)|0;if((m&2|0)==0){Ya=na;break}ka=K&1|A;qa=c[(b+12208|0)>>2]|0;ga=(ba(fa,z)|0)+(K>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(ka<<2)>>2]&1023](qa+(ma<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ga|0,fa,4);cf[c[(c[(b+12444|0)>>2]|0)+16+(ka<<2)>>2]&1023](qa+(ma<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ga|0,fa,4);ga=(Pe[O&255](b,qa+(ma<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,fa,4)|0)+na|0;Ya=ga+(Pe[O&255](b,qa+(ma<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,fa,4)|0)|0}else{fa=K<<n;if((c[(b+12264|0)>>2]|0)>(K|0)){Ya=536870912;break}if((fa|0)>(c[(b+12268|0)>>2]<<n|0)){Ya=536870912;break}if((c[(b+12272|0)>>2]|0)>(o|0)){Ya=536870912;break}if((y|0)>(c[(b+12276|0)>>2]<<n|0)){Ya=536870912;break}qa=e[(b+13872|0)>>1]|0;ga=e[(b+13874|0)>>1]|0;h:do{if((c[(b+11740|0)>>2]|0)==1){if((fa|0)==0){na=0;while(1){ka=c[b+12160+(na<<3)>>2]|0;ya=(c[b+12160+(na<<3)+4>>2]|0)+y|0;Ba=((ba(c[b+12128+(na<<3)>>2]|0,ga-qa|0)|0)/(qa|0)|0)+((na&1)<<(m&1|4))|0;la=c[b+12128+(na<<3)+4>>2]|0;if((y|0)==0){U=na>>1;Za=((ba(la,ga-qa|0)|0)/(qa|0)|0)+(U<<(m&1|4))|0;_a=U}else{Za=ya-la|0;_a=na>>1}la=((Za&J)<<n)+(Ba&J)|0;U=(c[(b+12208|0)>>2]|0)+((ba(_a,ma<<3)|0)+(na<<3&8))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,ma)|0)+(ka>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&J)<<n)+(ka&J)|0)<<2)>>2]&1023](U,$a,ma,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Za>>1,ma)|0)+(Ba>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&1023](U,$a,ma,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>2,ma)|0)+(ka>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&J)<<n)+(ka&J)|0)<<2)>>2]&4095](U,$a,ma);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Za>>2,ma)|0)+(Ba>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](U,$a,ma)}na=na+1|0;if((na|0)>=4){break h}}}if((y|0)==0){na=0;do{$a=(c[b+12160+(na<<3)>>2]|0)+fa|0;U=c[b+12160+(na<<3)+4>>2]|0;la=$a-(c[b+12128+(na<<3)>>2]|0)|0;Ba=na>>1;ka=((ba(c[b+12128+(na<<3)+4>>2]|0,ga-qa|0)|0)/(qa|0)|0)+(Ba<<(m&1|4))|0;ya=(c[(b+12208|0)>>2]|0)+((na<<3&8)+(ba(Ba,ma<<3)|0))|0;if((m&1|0)==0){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,ma)|0)+($a>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&J)<<n)+($a&J)|0)<<2)>>2]&1023](ya,Ba,ma,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,ma)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&1023](ya,Ba,ma,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,ma)|0)+($a>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+($a&J)|0)<<2)>>2]&4095](ya,Ba,ma);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,ma)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&4095](ya,Ba,ma)}na=na+1|0;}while((na|0)<4)}else{na=0;do{Ba=(c[b+12160+(na<<3)>>2]|0)+fa|0;ya=(c[b+12160+(na<<3)+4>>2]|0)+y|0;la=Ba-(c[b+12128+(na<<3)>>2]|0)|0;ka=ya-(c[b+12128+(na<<3)+4>>2]|0)|0;$a=(c[(b+12208|0)>>2]|0)+((na<<3&8)+(ba(na>>1,ma<<3)|0))|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,ma)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&J)<<n)+(Ba&J)|0)<<2)>>2]&1023]($a,U,ma,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,ma)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&1023]($a,U,ma,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>2,ma)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&J)<<n)+(Ba&J)|0)<<2)>>2]&4095]($a,U,ma);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,ma)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&4095]($a,U,ma)}na=na+1|0;}while((na|0)<4)}}else{na=(c[(b+12160|0)>>2]|0)+fa|0;U=(c[(b+12164|0)>>2]|0)+y|0;$a=c[(b+12128|0)>>2]|0;if((fa|0)==0){ab=(ba($a,ga-qa|0)|0)/(qa|0)|0}else{ab=na-$a|0}$a=c[(b+12132|0)>>2]|0;if((y|0)==0){bb=(ba($a,ga-qa|0)|0)/(qa|0)|0}else{bb=U-$a|0}$a=((bb&J)<<n)+(ab&J)|0;if((m&1|0)==0){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,ma)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((U&J)<<n)+(na&J)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,ma,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(bb>>1,ma)|0)+(ab>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+($a<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,ma,16);break}else{la=(ba(U>>2,ma)|0)+(na>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(ma<<3))|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(ma<<3))|0,ma);la=(ba(bb>>2,ma)|0)+(ab>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(ma<<3))|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(ma<<3))|0,ma);break}}}while(0);Ya=Pe[N&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(F+(S<<2)|0)>>2]=T;c[_+(S<<2)>>2]=Ya;ma=(ba((d[C+(y-x)|0]|0)+(d[C+((K<<n)-E)|0]|0)|0,l)|0)+Ya|0;if((ma|0)>=(I|0)){Va=I;Wa=V;Xa=ja;break}c[r>>2]=K;c[(r+4|0)>>2]=o;Va=ma;Wa=K;Xa=o}}while(0);S=K+2|0;if((S|0)>(G|0)){Sa=Va;Ta=Wa;Ua=Xa;break}else{K=S;I=Va;V=Wa;ja=Xa}}}ja=o-((s&254)>>>1)+1|0;V=(ja|0)>(L|0)?ja:L;ja=((s&254)>>>1)-1+o|0;I=(ja|0)>(D|0)?D:ja;if((V|0)>(I|0)){cb=Sa;db=Ta;eb=Ua}else{ja=p+H|0;K=p&1;G=p>>1;y=p<<n;J=(m&1)<<1|1;z=V;V=Sa;A=Ta;B=Ua;while(1){R=ja+(z<<11)|0;S=(z<<3)+p&63;do{if((c[(F+(S<<2)|0)>>2]|0)==(R|0)){fb=V;gb=A;hb=B}else{T=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ma=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(T,z)|0)+p)|0;ia=Pe[N&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,T,8)|0;if((m&2|0)==0){ib=ia;break}X=z<<1&2|K;M=c[(b+12208|0)>>2]|0;qa=(ba(ma,z>>1)|0)+G|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(X<<2)>>2]&1023](M+(T<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+qa|0,ma,4);cf[c[(c[(b+12444|0)>>2]|0)+16+(X<<2)>>2]&1023](M+(T<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+qa|0,ma,4);qa=(Pe[O&255](b,M+(T<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ma,4)|0)+ia|0;ib=qa+(Pe[O&255](b,M+(T<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ma,4)|0)|0}else{ma=z<<n;if((c[(b+12264|0)>>2]|0)>(p|0)){ib=536870912;break}if((y|0)>(c[(b+12268|0)>>2]<<n|0)){ib=536870912;break}if((c[(b+12272|0)>>2]|0)>(z|0)){ib=536870912;break}if((ma|0)>(c[(b+12276|0)>>2]<<n|0)){ib=536870912;break}M=e[(b+13872|0)>>1]|0;qa=e[(b+13874|0)>>1]|0;i:do{if((c[(b+11740|0)>>2]|0)==1){if((y|0)==0){ia=0;while(1){X=c[b+12160+(ia<<3)>>2]|0;ga=(c[b+12160+(ia<<3)+4>>2]|0)+ma|0;fa=((ba(c[b+12128+(ia<<3)>>2]|0,qa-M|0)|0)/(M|0)|0)+((ia&1)<<(m&1|4))|0;la=c[b+12128+(ia<<3)+4>>2]|0;if((ma|0)==0){$a=ia>>1;jb=((ba(la,qa-M|0)|0)/(M|0)|0)+($a<<(m&1|4))|0;kb=$a}else{jb=ga-la|0;kb=ia>>1}la=((jb&J)<<n)+(fa&J)|0;$a=(c[(b+12208|0)>>2]|0)+((ba(kb,T<<3)|0)+(ia<<3&8))|0;if((m&1|0)==0){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,T)|0)+(X>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&J)<<n)+(X&J)|0)<<2)>>2]&1023]($a,na,T,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(jb>>1,T)|0)+(fa>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&1023]($a,na,T,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,T)|0)+(X>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&J)<<n)+(X&J)|0)<<2)>>2]&4095]($a,na,T);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(jb>>2,T)|0)+(fa>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]($a,na,T)}ia=ia+1|0;if((ia|0)>=4){break i}}}if((ma|0)==0){ia=0;do{na=(c[b+12160+(ia<<3)>>2]|0)+y|0;$a=c[b+12160+(ia<<3)+4>>2]|0;la=na-(c[b+12128+(ia<<3)>>2]|0)|0;fa=ia>>1;X=((ba(c[b+12128+(ia<<3)+4>>2]|0,qa-M|0)|0)/(M|0)|0)+(fa<<(m&1|4))|0;ga=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ba(fa,T<<3)|0))|0;if((m&1|0)==0){fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>1,T)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(((($a&J)<<n)+(na&J)|0)<<2)>>2]&1023](ga,fa,T,8);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>1,T)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((X&J)<<n)+(la&J)|0)<<2)>>2]&1023](ga,fa,T,8)}else{fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>2,T)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(na&J)|0)<<2)>>2]&4095](ga,fa,T);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>2,T)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((X&J)<<n)+(la&J)|0)<<2)>>2]&4095](ga,fa,T)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{fa=(c[b+12160+(ia<<3)>>2]|0)+y|0;ga=(c[b+12160+(ia<<3)+4>>2]|0)+ma|0;la=fa-(c[b+12128+(ia<<3)>>2]|0)|0;X=ga-(c[b+12128+(ia<<3)+4>>2]|0)|0;na=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ba(ia>>1,T<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,T)|0)+(fa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&J)<<n)+(fa&J)|0)<<2)>>2]&1023](na,$a,T,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>1,T)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((X&J)<<n)+(la&J)|0)<<2)>>2]&1023](na,$a,T,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,T)|0)+(fa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&J)<<n)+(fa&J)|0)<<2)>>2]&4095](na,$a,T);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>2,T)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((X&J)<<n)+(la&J)|0)<<2)>>2]&4095](na,$a,T)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[(b+12160|0)>>2]|0)+y|0;$a=(c[(b+12164|0)>>2]|0)+ma|0;na=c[(b+12128|0)>>2]|0;if((y|0)==0){lb=(ba(na,qa-M|0)|0)/(M|0)|0}else{lb=ia-na|0}na=c[(b+12132|0)>>2]|0;if((ma|0)==0){mb=(ba(na,qa-M|0)|0)/(M|0)|0}else{mb=$a-na|0}na=((mb&J)<<n)+(lb&J)|0;if((m&1|0)==0){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>1,T)|0)+(ia>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,T,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(mb>>1,T)|0)+(lb>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(na<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,T,16);break}else{la=(ba($a>>2,T)|0)+(ia>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,T);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,T);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(T<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(T<<3))|0,T);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(T<<3))|0,T);la=(ba(mb>>2,T)|0)+(lb>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,T);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,T);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(T<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(T<<3))|0,T);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(T<<3))|0,T);break}}}while(0);ib=Pe[N&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,T,16)|0}}while(0);c[(F+(S<<2)|0)>>2]=R;c[_+(S<<2)>>2]=ib;T=(ba((d[C+((z<<n)-x)|0]|0)+(d[C+(y-E)|0]|0)|0,l)|0)+ib|0;if((T|0)>=(V|0)){fb=V;gb=A;hb=B;break}c[r>>2]=p;c[(r+4|0)>>2]=z;fb=T;gb=p;hb=z}}while(0);S=z+2|0;if((S|0)>(I|0)){cb=fb;db=gb;eb=hb;break}else{z=S;V=fb;A=gb;B=hb}}}B=eb-2|0;A=(B|0)>(L|0)?B:L;B=eb+2|0;V=(B|0)>(D|0)?D:B;if((A|0)>(V|0)){nb=cb}else{B=db-2|0;z=(B|0)>(W|0)?B:W;B=db+2|0;I=(B|0)>(Q|0)?Q:B;B=(m&1)<<1|1;y=A;A=cb;while(1){if((z|0)>(I|0)){ob=A}else{J=(y<<11)+H|0;G=y<<3;K=y<<1&2;ja=y>>1;S=y<<n;R=z;T=A;while(1){M=J+R|0;qa=R+G&63;do{if((c[(F+(qa<<2)|0)>>2]|0)==(M|0)){pb=T}else{ma=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){la=c[(b+12420|0)>>2]|0;na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma,y)|0)+R)|0;ia=Pe[N&255](b,c[(b+12288+(h<<4)|0)>>2]|0,na,ma,8)|0;if((m&2|0)==0){qb=ia;break}na=R&1|K;$a=c[(b+12208|0)>>2]|0;X=(ba(la,ja)|0)+(R>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(na<<2)>>2]&1023]($a+(ma<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+X|0,la,4);cf[c[(c[(b+12444|0)>>2]|0)+16+(na<<2)>>2]&1023]($a+(ma<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+X|0,la,4);X=(Pe[O&255](b,$a+(ma<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,la,4)|0)+ia|0;qb=X+(Pe[O&255](b,$a+(ma<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,la,4)|0)|0}else{la=R<<n;if((c[(b+12264|0)>>2]|0)>(R|0)){qb=536870912;break}if((la|0)>(c[(b+12268|0)>>2]<<n|0)){qb=536870912;break}if((c[(b+12272|0)>>2]|0)>(y|0)){qb=536870912;break}if((S|0)>(c[(b+12276|0)>>2]<<n|0)){qb=536870912;break}$a=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;j:do{if((c[(b+11740|0)>>2]|0)==1){if((la|0)==0){ia=0;while(1){na=c[b+12160+(ia<<3)>>2]|0;fa=(c[b+12160+(ia<<3)+4>>2]|0)+S|0;ga=((ba(c[b+12128+(ia<<3)>>2]|0,X-$a|0)|0)/($a|0)|0)+((ia&1)<<(m&1|4))|0;U=c[b+12128+(ia<<3)+4>>2]|0;if((S|0)==0){ka=ia>>1;rb=((ba(U,X-$a|0)|0)/($a|0)|0)+(ka<<(m&1|4))|0;sb=ka}else{rb=fa-U|0;sb=ia>>1}U=((rb&B)<<n)+(ga&B)|0;ka=(c[(b+12208|0)>>2]|0)+((ba(sb,ma<<3)|0)+(ia<<3&8))|0;if((m&1|0)==0){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>1,ma)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&B)<<n)+(na&B)|0)<<2)>>2]&1023](ka,Ba,ma,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(rb>>1,ma)|0)+(ga>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(U<<2)>>2]&1023](ka,Ba,ma,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>2,ma)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((fa&B)<<n)+(na&B)|0)<<2)>>2]&4095](ka,Ba,ma);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(rb>>2,ma)|0)+(ga>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](ka,Ba,ma)}ia=ia+1|0;if((ia|0)>=4){break j}}}if((S|0)==0){ia=0;do{Ba=(c[b+12160+(ia<<3)>>2]|0)+la|0;ka=c[b+12160+(ia<<3)+4>>2]|0;U=Ba-(c[b+12128+(ia<<3)>>2]|0)|0;ga=ia>>1;na=((ba(c[b+12128+(ia<<3)+4>>2]|0,X-$a|0)|0)/($a|0)|0)+(ga<<(m&1|4))|0;fa=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ba(ga,ma<<3)|0))|0;if((m&1|0)==0){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,ma)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&B)<<n)+(Ba&B)|0)<<2)>>2]&1023](fa,ga,ma,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>1,ma)|0)+(U>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((na&B)<<n)+(U&B)|0)<<2)>>2]&1023](fa,ga,ma,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>2,ma)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(Ba&B)|0)<<2)>>2]&4095](fa,ga,ma);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>2,ma)|0)+(U>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((na&B)<<n)+(U&B)|0)<<2)>>2]&4095](fa,ga,ma)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{ga=(c[b+12160+(ia<<3)>>2]|0)+la|0;fa=(c[b+12160+(ia<<3)+4>>2]|0)+S|0;U=ga-(c[b+12128+(ia<<3)>>2]|0)|0;na=fa-(c[b+12128+(ia<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ba(ia>>1,ma<<3)|0))|0;if((m&1|0)==0){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>1,ma)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&B)<<n)+(ga&B)|0)<<2)>>2]&1023](Ba,ka,ma,8);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>1,ma)|0)+(U>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((na&B)<<n)+(U&B)|0)<<2)>>2]&1023](Ba,ka,ma,8)}else{ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>2,ma)|0)+(ga>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((fa&B)<<n)+(ga&B)|0)<<2)>>2]&4095](Ba,ka,ma);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>2,ma)|0)+(U>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((na&B)<<n)+(U&B)|0)<<2)>>2]&4095](Ba,ka,ma)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[(b+12160|0)>>2]|0)+la|0;ka=(c[(b+12164|0)>>2]|0)+S|0;Ba=c[(b+12128|0)>>2]|0;if((la|0)==0){tb=(ba(Ba,X-$a|0)|0)/($a|0)|0}else{tb=ia-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((S|0)==0){ub=(ba(Ba,X-$a|0)|0)/($a|0)|0}else{ub=ka-Ba|0}Ba=((ub&B)<<n)+(tb&B)|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,ma)|0)+(ia>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,U,ma,16);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ub>>1,ma)|0)+(tb>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&1023](c[(b+12208|0)>>2]|0,U,ma,16);break}else{U=(ba(ka>>2,ma)|0)+(ia>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+U|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(U+8|0)|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(U+(ma<<3))|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((U+8|0)+(ma<<3))|0,ma);U=(ba(ub>>2,ma)|0)+(tb>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+U|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(U+8|0)|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(U+(ma<<3))|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((U+8|0)+(ma<<3))|0,ma);break}}}while(0);qb=Pe[N&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(F+(qa<<2)|0)>>2]=M;c[_+(qa<<2)>>2]=qb;ma=(ba((d[C+(S-x)|0]|0)+(d[C+((R<<n)-E)|0]|0)|0,l)|0)+qb|0;if((ma|0)>=(T|0)){pb=T;break}c[r>>2]=R;c[(r+4|0)>>2]=y;pb=ma}}while(0);qa=R+1|0;if((qa|0)>(I|0)){ob=pb;break}else{R=qa;T=pb}}}T=y+1|0;if((T|0)>(V|0)){nb=ob;break}else{y=T;A=ob}}}if(((s&254)>>>2|0)==0){vb=nb}else{A=(m&1)<<1|1;y=1;V=nb;while(1){I=0;B=V;while(1){z=(ba(c[163152+(I<<3)>>2]|0,y)|0)+db|0;T=(ba(c[163156+(I<<3)>>2]|0,y)|0)+eb|0;R=(z|0)>(Q|0)?Q:z;z=(W|0)>(R|0)?W:R;R=(T|0)>(D|0)?D:T;T=(L|0)>(R|0)?L:R;do{if((c[(F+(((T<<3)+z&63)<<2)|0)>>2]|0)==(z+H+(T<<11)|0|0)){wb=B}else{R=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){S=c[(b+12420|0)>>2]|0;ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(R,T)|0)+z)|0;K=Pe[N&255](b,c[(b+12288+(h<<4)|0)>>2]|0,ja,R,8)|0;if((m&2|0)==0){xb=K;break}ja=c[(b+12208|0)>>2]|0;G=(ba(S,T>>1)|0)+(z>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((T<<1&2|z&1)<<2)>>2]&1023](ja+(R<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+G|0,S,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((T<<1&2|z&1)<<2)>>2]&1023](ja+(R<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+G|0,S,4);G=(Pe[O&255](b,ja+(R<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,S,4)|0)+K|0;xb=G+(Pe[O&255](b,ja+(R<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,S,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(z|0)){xb=536870912;break}if((z<<n|0)>(c[(b+12268|0)>>2]<<n|0)){xb=536870912;break}if((c[(b+12272|0)>>2]|0)>(T|0)){xb=536870912;break}if((T<<n|0)>(c[(b+12276|0)>>2]<<n|0)){xb=536870912;break}S=e[(b+13872|0)>>1]|0;ja=e[(b+13874|0)>>1]|0;k:do{if((c[(b+11740|0)>>2]|0)==1){if((z<<n|0)==0){G=0;while(1){K=c[b+12160+(G<<3)>>2]|0;J=(c[b+12160+(G<<3)+4>>2]|0)+(T<<n)|0;qa=((ba(c[b+12128+(G<<3)>>2]|0,ja-S|0)|0)/(S|0)|0)+((G&1)<<(m&1|4))|0;M=c[b+12128+(G<<3)+4>>2]|0;if((T<<n|0)==0){ma=G>>1;yb=((ba(M,ja-S|0)|0)/(S|0)|0)+(ma<<(m&1|4))|0;zb=ma}else{yb=J-M|0;zb=G>>1}M=((yb&A)<<n)+(qa&A)|0;ma=(c[(b+12208|0)>>2]|0)+((ba(zb,R<<3)|0)+(G<<3&8))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(J>>1,R)|0)+(K>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((J&A)<<n)+(K&A)|0)<<2)>>2]&1023](ma,$a,R,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(yb>>1,R)|0)+(qa>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(M<<2)>>2]&1023](ma,$a,R,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(J>>2,R)|0)+(K>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((J&A)<<n)+(K&A)|0)<<2)>>2]&4095](ma,$a,R);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(yb>>2,R)|0)+(qa>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(M<<2)>>2]&4095](ma,$a,R)}G=G+1|0;if((G|0)>=4){break k}}}if((T<<n|0)==0){G=0;do{$a=(c[b+12160+(G<<3)>>2]|0)+(z<<n)|0;ma=c[b+12160+(G<<3)+4>>2]|0;M=$a-(c[b+12128+(G<<3)>>2]|0)|0;qa=G>>1;K=((ba(c[b+12128+(G<<3)+4>>2]|0,ja-S|0)|0)/(S|0)|0)+(qa<<(m&1|4))|0;J=(c[(b+12208|0)>>2]|0)+((G<<3&8)+(ba(qa,R<<3)|0))|0;if((m&1|0)==0){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,R)|0)+($a>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&A)<<n)+($a&A)|0)<<2)>>2]&1023](J,qa,R,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,R)|0)+(M>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&A)<<n)+(M&A)|0)<<2)>>2]&1023](J,qa,R,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>2,R)|0)+($a>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+($a&A)|0)<<2)>>2]&4095](J,qa,R);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,R)|0)+(M>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&A)<<n)+(M&A)|0)<<2)>>2]&4095](J,qa,R)}G=G+1|0;}while((G|0)<4)}else{G=0;do{qa=(c[b+12160+(G<<3)>>2]|0)+(z<<n)|0;J=(c[b+12160+(G<<3)+4>>2]|0)+(T<<n)|0;M=qa-(c[b+12128+(G<<3)>>2]|0)|0;K=J-(c[b+12128+(G<<3)+4>>2]|0)|0;$a=(c[(b+12208|0)>>2]|0)+((G<<3&8)+(ba(G>>1,R<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(J>>1,R)|0)+(qa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((J&A)<<n)+(qa&A)|0)<<2)>>2]&1023]($a,ma,R,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,R)|0)+(M>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&A)<<n)+(M&A)|0)<<2)>>2]&1023]($a,ma,R,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(J>>2,R)|0)+(qa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((J&A)<<n)+(qa&A)|0)<<2)>>2]&4095]($a,ma,R);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,R)|0)+(M>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&A)<<n)+(M&A)|0)<<2)>>2]&4095]($a,ma,R)}G=G+1|0;}while((G|0)<4)}}else{G=(c[(b+12160|0)>>2]|0)+(z<<n)|0;ma=(c[(b+12164|0)>>2]|0)+(T<<n)|0;$a=c[(b+12128|0)>>2]|0;if((z<<n|0)==0){Ab=(ba($a,ja-S|0)|0)/(S|0)|0}else{Ab=G-$a|0}$a=c[(b+12132|0)>>2]|0;if((T<<n|0)==0){Bb=(ba($a,ja-S|0)|0)/(S|0)|0}else{Bb=ma-$a|0}$a=((Bb&A)<<n)+(Ab&A)|0;if((m&1|0)==0){M=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,R)|0)+(G>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,M,R,16);M=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Bb>>1,R)|0)+(Ab>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+($a<<2)>>2]&1023](c[(b+12208|0)>>2]|0,M,R,16);break}else{M=(ba(ma>>2,R)|0)+(G>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+M|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(M+8|0)|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(M+(R<<3))|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((M+8|0)+(R<<3))|0,R);M=(ba(Bb>>2,R)|0)+(Ab>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+M|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(M+8|0)|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(M+(R<<3))|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((M+8|0)+(R<<3))|0,R);break}}}while(0);xb=Pe[N&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,R,16)|0}}while(0);c[(F+(((T<<3)+z&63)<<2)|0)>>2]=z+H+(T<<11)|0;c[_+(((T<<3)+z&63)<<2)>>2]=xb;R=(ba((d[C+((T<<n)-x)|0]|0)+(d[C+((z<<n)-E)|0]|0)|0,l)|0)+xb|0;if((R|0)>=(B|0)){wb=B;break}c[r>>2]=z;c[(r+4|0)>>2]=T;wb=R}}while(0);T=I+1|0;if((T|0)<16){I=T;B=wb}else{break}}B=y+1|0;if((B|0)>((s&254)>>>2|0)){vb=wb;break}else{y=B;V=wb}}}t=Hmb(b,r,vb,h,j,l,0,8,m,2)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}if((s|0)>512){t=Hmb(b,r,q,h,j,l,0,8,m,s&255)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}V=c[(b+12220|0)>>2]|0;y=c[(b+12264|0)>>2]|0;E=c[(b+12272|0)>>2]|0;C=c[(b+12268|0)>>2]|0;x=c[(b+12276|0)>>2]|0;_=c[(b+12464|0)>>2]|0;H=c[(b+12280|0)>>2]|0;F=c[(b+12284|0)>>2]|0;N=c[(b+12216|0)>>2]|0;A=c[(b+12224|0)>>2]|0;if((s|0)<=256){O=c[(b+10468|0)>>2]|0;L=c[(b+10472|0)>>2]|0;D=(m&1)<<1|1;W=m&1|4;Q=(m&1|0)==0;B=1;I=q;T=p;z=o;while(1){R=z+B|0;S=(R-x|0|0)<0?0:R-x|0;ja=C-T+1|0;M=(B|0)>(ja|0)?ja:B;if((S|0)<(M|0)){ja=S;S=I;$a=z;G=T;while(1){ma=R-ja|0;K=ja+T|0;do{if((c[(N+(((ma<<3)+K&63)<<2)|0)>>2]|0)==(K+A+(ma<<11)|0|0)){Cb=S;Db=$a;Eb=G}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa,ma)|0)+K)|0;la=Pe[O&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){Fb=la;break}X=c[(b+12208|0)>>2]|0;U=(ba(J,ma>>1)|0)+(K>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|K&1)<<2)>>2]&1023](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+U|0,J,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|K&1)<<2)>>2]&1023](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+U|0,J,4);U=(Pe[L&255](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+la|0;Fb=U+(Pe[L&255](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(K|0)){Fb=536870912;break}if((K<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Fb=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){Fb=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Fb=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;l:do{if((c[(b+11740|0)>>2]|0)==1){if((K<<n|0)==0){U=0;while(1){la=c[b+12160+(U<<3)>>2]|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(ma<<n)|0;ia=((ba(c[b+12128+(U<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((U&1)<<W)|0;ka=c[b+12128+(U<<3)+4>>2]|0;if((ma<<n|0)==0){na=U>>1;Gb=((ba(ka,X-J|0)|0)/(J|0)|0)+(na<<W)|0;Hb=na}else{Gb=Ba-ka|0;Hb=U>>1}ka=((Gb&D)<<n)+(ia&D)|0;na=(c[(b+12208|0)>>2]|0)+((ba(Hb,qa<<3)|0)+(U<<3&8))|0;if(Q){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(la&D)|0)<<2)>>2]&1023](na,ga,qa,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Gb>>1,qa)|0)+(ia>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&1023](na,ga,qa,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(la&D)|0)<<2)>>2]&4095](na,ga,qa);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Gb>>2,qa)|0)+(ia>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](na,ga,qa)}U=U+1|0;if((U|0)>=4){break l}}}if((ma<<n|0)==0){U=0;do{ga=(c[b+12160+(U<<3)>>2]|0)+(K<<n)|0;na=c[b+12160+(U<<3)+4>>2]|0;ka=ga-(c[b+12128+(U<<3)>>2]|0)|0;ia=U>>1;la=((ba(c[b+12128+(U<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;Ba=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(ia,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,qa)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((na&D)<<n)+(ga&D)|0)<<2)>>2]&1023](Ba,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&1023](Ba,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>2,qa)|0)+(ga>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(ga&D)|0)<<2)>>2]&4095](Ba,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](Ba,ia,qa)}U=U+1|0;}while((U|0)<4)}else{U=0;do{ia=(c[b+12160+(U<<3)>>2]|0)+(K<<n)|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(ma<<n)|0;ka=ia-(c[b+12128+(U<<3)>>2]|0)|0;la=Ba-(c[b+12128+(U<<3)+4>>2]|0)|0;ga=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(U>>1,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>1,qa)|0)+(ia>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(ia&D)|0)<<2)>>2]&1023](ga,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&1023](ga,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>2,qa)|0)+(ia>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(ia&D)|0)<<2)>>2]&4095](ga,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ga,na,qa)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(K<<n)|0;na=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;ga=c[(b+12128|0)>>2]|0;if((K<<n|0)==0){Ib=(ba(ga,X-J|0)|0)/(J|0)|0}else{Ib=U-ga|0}ga=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){Jb=(ba(ga,X-J|0)|0)/(J|0)|0}else{Jb=na-ga|0}ga=((Jb&D)<<n)+(Ib&D)|0;if(Q){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,qa)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((na&D)<<n)+(U&D)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,qa,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Jb>>1,qa)|0)+(Ib>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(ga<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,qa,16);break}else{ka=(ba(na>>2,qa)|0)+(U>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(qa<<3))|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);ka=(ba(Jb>>2,qa)|0)+(Ib>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(qa<<3))|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);break}}}while(0);Fb=Pe[O&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((ma<<3)+K&63)<<2)|0)>>2]=K+A+(ma<<11)|0;c[V+(((ma<<3)+K&63)<<2)>>2]=Fb;qa=(ba((d[_+((ma<<n)-F)|0]|0)+(d[_+((K<<n)-H)|0]|0)|0,l)|0)+Fb|0;if((qa|0)>=(S|0)){Cb=S;Db=$a;Eb=G;break}c[r>>2]=K;c[(r+4|0)>>2]=ma;Cb=qa;Db=ma;Eb=K}}while(0);K=ja+1|0;if((K|0)<(M|0)){ja=K;S=Cb;$a=Db;G=Eb}else{Kb=Cb;Lb=Db;Mb=Eb;break}}}else{Kb=I;Lb=z;Mb=T}G=B+T|0;$a=(G-C|0|0)<0?0:G-C|0;S=z-E+1|0;ja=(B|0)>(S|0)?S:B;if(($a|0)<(ja|0)){S=$a;$a=Kb;M=Lb;R=Mb;while(1){K=z-S|0;ma=G-S|0;do{if((c[(N+(((K<<3)+ma&63)<<2)|0)>>2]|0)==(ma+A+(K<<11)|0|0)){Nb=$a;Ob=M;Pb=R}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa,K)|0)+ma)|0;ka=Pe[O&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){Qb=ka;break}X=c[(b+12208|0)>>2]|0;ga=(ba(J,K>>1)|0)+(ma>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((K<<1&2|ma&1)<<2)>>2]&1023](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ga|0,J,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((K<<1&2|ma&1)<<2)>>2]&1023](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ga|0,J,4);ga=(Pe[L&255](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+ka|0;Qb=ga+(Pe[L&255](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(ma|0)){Qb=536870912;break}if((ma<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Qb=536870912;break}if((c[(b+12272|0)>>2]|0)>(K|0)){Qb=536870912;break}if((K<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Qb=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;m:do{if((c[(b+11740|0)>>2]|0)==1){if((ma<<n|0)==0){ga=0;while(1){ka=c[b+12160+(ga<<3)>>2]|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(K<<n)|0;na=((ba(c[b+12128+(ga<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((ga&1)<<W)|0;la=c[b+12128+(ga<<3)+4>>2]|0;if((K<<n|0)==0){ia=ga>>1;Rb=((ba(la,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;Sb=ia}else{Rb=U-la|0;Sb=ga>>1}la=((Rb&D)<<n)+(na&D)|0;ia=(c[(b+12208|0)>>2]|0)+((ba(Sb,qa<<3)|0)+(ga<<3&8))|0;if(Q){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&D)<<n)+(ka&D)|0)<<2)>>2]&1023](ia,Ba,qa,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Rb>>1,qa)|0)+(na>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&1023](ia,Ba,qa,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ia,Ba,qa);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Rb>>2,qa)|0)+(na>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](ia,Ba,qa)}ga=ga+1|0;if((ga|0)>=4){break m}}}if((K<<n|0)==0){ga=0;do{Ba=(c[b+12160+(ga<<3)>>2]|0)+(ma<<n)|0;ia=c[b+12160+(ga<<3)+4>>2]|0;la=Ba-(c[b+12128+(ga<<3)>>2]|0)|0;na=ga>>1;ka=((ba(c[b+12128+(ga<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(na<<W)|0;U=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(na,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>1,qa)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ia&D)<<n)+(Ba&D)|0)<<2)>>2]&1023](U,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&1023](U,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>2,qa)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(Ba&D)|0)<<2)>>2]&4095](U,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](U,na,qa)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{na=(c[b+12160+(ga<<3)>>2]|0)+(ma<<n)|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(K<<n)|0;la=na-(c[b+12128+(ga<<3)>>2]|0)|0;ka=U-(c[b+12128+(ga<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(ga>>1,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,qa)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&D)<<n)+(na&D)|0)<<2)>>2]&1023](Ba,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&1023](Ba,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,qa)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&D)<<n)+(na&D)|0)<<2)>>2]&4095](Ba,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](Ba,ia,qa)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+(ma<<n)|0;ia=(c[(b+12164|0)>>2]|0)+(K<<n)|0;Ba=c[(b+12128|0)>>2]|0;if((ma<<n|0)==0){Tb=(ba(Ba,X-J|0)|0)/(J|0)|0}else{Tb=ga-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((K<<n|0)==0){Ub=(ba(Ba,X-J|0)|0)/(J|0)|0}else{Ub=ia-Ba|0}Ba=((Ub&D)<<n)+(Tb&D)|0;if(Q){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>1,qa)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,qa,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ub>>1,qa)|0)+(Tb>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,qa,16);break}else{la=(ba(ia>>2,qa)|0)+(ga>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(qa<<3))|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);la=(ba(Ub>>2,qa)|0)+(Tb>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(qa<<3))|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);break}}}while(0);Qb=Pe[O&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((K<<3)+ma&63)<<2)|0)>>2]=ma+A+(K<<11)|0;c[V+(((K<<3)+ma&63)<<2)>>2]=Qb;qa=(ba((d[_+((K<<n)-F)|0]|0)+(d[_+((ma<<n)-H)|0]|0)|0,l)|0)+Qb|0;if((qa|0)>=($a|0)){Nb=$a;Ob=M;Pb=R;break}c[r>>2]=ma;c[(r+4|0)>>2]=K;Nb=qa;Ob=K;Pb=ma}}while(0);ma=S+1|0;if((ma|0)<(ja|0)){S=ma;$a=Nb;M=Ob;R=Pb}else{Vb=Nb;Wb=Ob;Xb=Pb;break}}}else{Vb=Kb;Wb=Lb;Xb=Mb}R=B-z+E|0;M=(R|0)<0?0:R;R=T-y+1|0;$a=(B|0)>(R|0)?R:B;if((M|0)<($a|0)){R=z-B|0;S=M;M=Vb;ja=Wb;G=Xb;while(1){ma=S+R|0;K=T-S|0;do{if((c[(N+(((ma<<3)+K&63)<<2)|0)>>2]|0)==(K+A+(ma<<11)|0|0)){Yb=M;Zb=ja;_b=G}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa,ma)|0)+K)|0;la=Pe[O&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){$b=la;break}X=c[(b+12208|0)>>2]|0;Ba=(ba(J,ma>>1)|0)+(K>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|K&1)<<2)>>2]&1023](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+Ba|0,J,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|K&1)<<2)>>2]&1023](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+Ba|0,J,4);Ba=(Pe[L&255](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+la|0;$b=Ba+(Pe[L&255](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(K|0)){$b=536870912;break}if((K<<n|0)>(c[(b+12268|0)>>2]<<n|0)){$b=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){$b=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){$b=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;n:do{if((c[(b+11740|0)>>2]|0)==1){if((K<<n|0)==0){Ba=0;while(1){la=c[b+12160+(Ba<<3)>>2]|0;ga=(c[b+12160+(Ba<<3)+4>>2]|0)+(ma<<n)|0;ia=((ba(c[b+12128+(Ba<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((Ba&1)<<W)|0;ka=c[b+12128+(Ba<<3)+4>>2]|0;if((ma<<n|0)==0){na=Ba>>1;ac=((ba(ka,X-J|0)|0)/(J|0)|0)+(na<<W)|0;bc=na}else{ac=ga-ka|0;bc=Ba>>1}ka=((ac&D)<<n)+(ia&D)|0;na=(c[(b+12208|0)>>2]|0)+((ba(bc,qa<<3)|0)+(Ba<<3&8))|0;if(Q){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&D)<<n)+(la&D)|0)<<2)>>2]&1023](na,U,qa,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ac>>1,qa)|0)+(ia>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&1023](na,U,qa,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&D)<<n)+(la&D)|0)<<2)>>2]&4095](na,U,qa);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ac>>2,qa)|0)+(ia>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](na,U,qa)}Ba=Ba+1|0;if((Ba|0)>=4){break n}}}if((ma<<n|0)==0){Ba=0;do{U=(c[b+12160+(Ba<<3)>>2]|0)+(K<<n)|0;na=c[b+12160+(Ba<<3)+4>>2]|0;ka=U-(c[b+12128+(Ba<<3)>>2]|0)|0;ia=Ba>>1;la=((ba(c[b+12128+(Ba<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;ga=(c[(b+12208|0)>>2]|0)+((Ba<<3&8)+(ba(ia,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,qa)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((na&D)<<n)+(U&D)|0)<<2)>>2]&1023](ga,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&1023](ga,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>2,qa)|0)+(U>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095](ga,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ga,ia,qa)}Ba=Ba+1|0;}while((Ba|0)<4)}else{Ba=0;do{ia=(c[b+12160+(Ba<<3)>>2]|0)+(K<<n)|0;ga=(c[b+12160+(Ba<<3)+4>>2]|0)+(ma<<n)|0;ka=ia-(c[b+12128+(Ba<<3)>>2]|0)|0;la=ga-(c[b+12128+(Ba<<3)+4>>2]|0)|0;U=(c[(b+12208|0)>>2]|0)+((Ba<<3&8)+(ba(Ba>>1,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,qa)|0)+(ia>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&D)<<n)+(ia&D)|0)<<2)>>2]&1023](U,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&1023](U,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,qa)|0)+(ia>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&D)<<n)+(ia&D)|0)<<2)>>2]&4095](U,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](U,na,qa)}Ba=Ba+1|0;}while((Ba|0)<4)}}else{Ba=(c[(b+12160|0)>>2]|0)+(K<<n)|0;na=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;U=c[(b+12128|0)>>2]|0;if((K<<n|0)==0){cc=(ba(U,X-J|0)|0)/(J|0)|0}else{cc=Ba-U|0}U=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){dc=(ba(U,X-J|0)|0)/(J|0)|0}else{dc=na-U|0}U=((dc&D)<<n)+(cc&D)|0;if(Q){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,qa)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,qa,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(dc>>1,qa)|0)+(cc>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(U<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,qa,16);break}else{ka=(ba(na>>2,qa)|0)+(Ba>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(qa<<3))|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);ka=(ba(dc>>2,qa)|0)+(cc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(qa<<3))|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);break}}}while(0);$b=Pe[O&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((ma<<3)+K&63)<<2)|0)>>2]=K+A+(ma<<11)|0;c[V+(((ma<<3)+K&63)<<2)>>2]=$b;qa=(ba((d[_+((ma<<n)-F)|0]|0)+(d[_+((K<<n)-H)|0]|0)|0,l)|0)+$b|0;if((qa|0)>=(M|0)){Yb=M;Zb=ja;_b=G;break}c[r>>2]=K;c[(r+4|0)>>2]=ma;Yb=qa;Zb=ma;_b=K}}while(0);K=S+1|0;if((K|0)<($a|0)){S=K;M=Yb;ja=Zb;G=_b}else{ec=Yb;fc=Zb;gc=_b;break}}}else{ec=Vb;fc=Wb;gc=Xb}G=B-T+y|0;ja=(G|0)<0?0:G;G=x-z+1|0;M=(B|0)>(G|0)?G:B;if((ja|0)<(M|0)){G=T-B|0;S=ja;ja=ec;$a=fc;R=gc;while(1){K=S+z|0;ma=S+G|0;do{if((c[(N+(((K<<3)+ma&63)<<2)|0)>>2]|0)==(ma+A+(K<<11)|0|0)){hc=ja;ic=$a;jc=R}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa,K)|0)+ma)|0;ka=Pe[O&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){kc=ka;break}X=c[(b+12208|0)>>2]|0;U=(ba(J,K>>1)|0)+(ma>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((K<<1&2|ma&1)<<2)>>2]&1023](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+U|0,J,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((K<<1&2|ma&1)<<2)>>2]&1023](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+U|0,J,4);U=(Pe[L&255](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+ka|0;kc=U+(Pe[L&255](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(ma|0)){kc=536870912;break}if((ma<<n|0)>(c[(b+12268|0)>>2]<<n|0)){kc=536870912;break}if((c[(b+12272|0)>>2]|0)>(K|0)){kc=536870912;break}if((K<<n|0)>(c[(b+12276|0)>>2]<<n|0)){kc=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;o:do{if((c[(b+11740|0)>>2]|0)==1){if((ma<<n|0)==0){U=0;while(1){ka=c[b+12160+(U<<3)>>2]|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(K<<n)|0;na=((ba(c[b+12128+(U<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((U&1)<<W)|0;la=c[b+12128+(U<<3)+4>>2]|0;if((K<<n|0)==0){ia=U>>1;lc=((ba(la,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;mc=ia}else{lc=Ba-la|0;mc=U>>1}la=((lc&D)<<n)+(na&D)|0;ia=(c[(b+12208|0)>>2]|0)+((ba(mc,qa<<3)|0)+(U<<3&8))|0;if(Q){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(ka&D)|0)<<2)>>2]&1023](ia,ga,qa,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(lc>>1,qa)|0)+(na>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&1023](ia,ga,qa,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ia,ga,qa);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(lc>>2,qa)|0)+(na>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](ia,ga,qa)}U=U+1|0;if((U|0)>=4){break o}}}if((K<<n|0)==0){U=0;do{ga=(c[b+12160+(U<<3)>>2]|0)+(ma<<n)|0;ia=c[b+12160+(U<<3)+4>>2]|0;la=ga-(c[b+12128+(U<<3)>>2]|0)|0;na=U>>1;ka=((ba(c[b+12128+(U<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(na<<W)|0;Ba=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(na,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>1,qa)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&1023](Ba,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&1023](Ba,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>2,qa)|0)+(ga>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095](Ba,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](Ba,na,qa)}U=U+1|0;}while((U|0)<4)}else{U=0;do{na=(c[b+12160+(U<<3)>>2]|0)+(ma<<n)|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(K<<n)|0;la=na-(c[b+12128+(U<<3)>>2]|0)|0;ka=Ba-(c[b+12128+(U<<3)+4>>2]|0)|0;ga=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(U>>1,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>1,qa)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(na&D)|0)<<2)>>2]&1023](ga,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&1023](ga,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>2,qa)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(na&D)|0)<<2)>>2]&4095](ga,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](ga,ia,qa)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(ma<<n)|0;ia=(c[(b+12164|0)>>2]|0)+(K<<n)|0;ga=c[(b+12128|0)>>2]|0;if((ma<<n|0)==0){nc=(ba(ga,X-J|0)|0)/(J|0)|0}else{nc=U-ga|0}ga=c[(b+12132|0)>>2]|0;if((K<<n|0)==0){oc=(ba(ga,X-J|0)|0)/(J|0)|0}else{oc=ia-ga|0}ga=((oc&D)<<n)+(nc&D)|0;if(Q){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>1,qa)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,qa,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(oc>>1,qa)|0)+(nc>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(ga<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,qa,16);break}else{la=(ba(ia>>2,qa)|0)+(U>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(qa<<3))|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);la=(ba(oc>>2,qa)|0)+(nc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(qa<<3))|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);break}}}while(0);kc=Pe[O&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((K<<3)+ma&63)<<2)|0)>>2]=ma+A+(K<<11)|0;c[V+(((K<<3)+ma&63)<<2)>>2]=kc;qa=(ba((d[_+((K<<n)-F)|0]|0)+(d[_+((ma<<n)-H)|0]|0)|0,l)|0)+kc|0;if((qa|0)>=(ja|0)){hc=ja;ic=$a;jc=R;break}c[r>>2]=ma;c[(r+4|0)>>2]=K;hc=qa;ic=K;jc=ma}}while(0);ma=S+1|0;if((ma|0)<(M|0)){S=ma;ja=hc;$a=ic;R=jc}else{pc=hc;qc=ic;rc=jc;break}}}else{pc=ec;qc=fc;rc=gc}R=(T|0)==(rc|0)&(z|0)==(qc|0);$a=R?B+1|0:1;if(($a|0)>(c[(b+12260|0)>>2]|0)){t=pc;break}else{B=$a;I=pc;T=rc;z=R?z:qc}}u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}z=c[(b+10468|0)>>2]|0;T=c[(b+10472|0)>>2]|0;if((s&255|0)==0){sc=q;tc=p;uc=o}else{I=(m&1)<<1|1;B=s&255;O=q;D=o;Q=p;while(1){W=O;L=D;R=Q;while(1){$a=0;ja=W;S=L;M=R;while(1){G=(ba(c[862288+($a<<3)>>2]|0,B)|0)+R|0;ma=(ba(c[862292+($a<<3)>>2]|0,B)|0)+L|0;K=(G|0)>(C|0)?C:G;G=(y|0)>(K|0)?y:K;K=(ma|0)>(x|0)?x:ma;ma=(E|0)>(K|0)?E:K;do{if((c[(N+(((ma<<3)+G&63)<<2)|0)>>2]|0)==(G+A+(ma<<11)|0|0)){vc=ja;wc=S;xc=M}else{K=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){qa=c[(b+12420|0)>>2]|0;J=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(K,ma)|0)+G)|0;X=Pe[z&255](b,c[(b+12288+(h<<4)|0)>>2]|0,J,K,8)|0;if((m&2|0)==0){yc=X;break}J=c[(b+12208|0)>>2]|0;la=(ba(qa,ma>>1)|0)+(G>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|G&1)<<2)>>2]&1023](J+(K<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+la|0,qa,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|G&1)<<2)>>2]&1023](J+(K<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+la|0,qa,4);la=(Pe[T&255](b,J+(K<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,qa,4)|0)+X|0;yc=la+(Pe[T&255](b,J+(K<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,qa,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(G|0)){yc=536870912;break}if((G<<n|0)>(c[(b+12268|0)>>2]<<n|0)){yc=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){yc=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){yc=536870912;break}qa=e[(b+13872|0)>>1]|0;J=e[(b+13874|0)>>1]|0;p:do{if((c[(b+11740|0)>>2]|0)==1){if((G<<n|0)==0){la=0;while(1){X=c[b+12160+(la<<3)>>2]|0;ga=(c[b+12160+(la<<3)+4>>2]|0)+(ma<<n)|0;U=((ba(c[b+12128+(la<<3)>>2]|0,J-qa|0)|0)/(qa|0)|0)+((la&1)<<(m&1|4))|0;ia=c[b+12128+(la<<3)+4>>2]|0;if((ma<<n|0)==0){ka=la>>1;zc=((ba(ia,J-qa|0)|0)/(qa|0)|0)+(ka<<(m&1|4))|0;Ac=ka}else{zc=ga-ia|0;Ac=la>>1}ia=((zc&I)<<n)+(U&I)|0;ka=(c[(b+12208|0)>>2]|0)+((ba(Ac,K<<3)|0)+(la<<3&8))|0;if((m&1|0)==0){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,K)|0)+(X>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&I)<<n)+(X&I)|0)<<2)>>2]&1023](ka,na,K,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(zc>>1,K)|0)+(U>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ia<<2)>>2]&1023](ka,na,K,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,K)|0)+(X>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&I)<<n)+(X&I)|0)<<2)>>2]&4095](ka,na,K);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(zc>>2,K)|0)+(U>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ia<<2)>>2]&4095](ka,na,K)}la=la+1|0;if((la|0)>=4){break p}}}if((ma<<n|0)==0){la=0;do{na=(c[b+12160+(la<<3)>>2]|0)+(G<<n)|0;ka=c[b+12160+(la<<3)+4>>2]|0;ia=na-(c[b+12128+(la<<3)>>2]|0)|0;U=la>>1;X=((ba(c[b+12128+(la<<3)+4>>2]|0,J-qa|0)|0)/(qa|0)|0)+(U<<(m&1|4))|0;ga=(c[(b+12208|0)>>2]|0)+((la<<3&8)+(ba(U,K<<3)|0))|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,K)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&I)<<n)+(na&I)|0)<<2)>>2]&1023](ga,U,K,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>1,K)|0)+(ia>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&1023](ga,U,K,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>2,K)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(na&I)|0)<<2)>>2]&4095](ga,U,K);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>2,K)|0)+(ia>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&4095](ga,U,K)}la=la+1|0;}while((la|0)<4)}else{la=0;do{U=(c[b+12160+(la<<3)>>2]|0)+(G<<n)|0;ga=(c[b+12160+(la<<3)+4>>2]|0)+(ma<<n)|0;ia=U-(c[b+12128+(la<<3)>>2]|0)|0;X=ga-(c[b+12128+(la<<3)+4>>2]|0)|0;na=(c[(b+12208|0)>>2]|0)+((la<<3&8)+(ba(la>>1,K<<3)|0))|0;if((m&1|0)==0){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,K)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&I)<<n)+(U&I)|0)<<2)>>2]&1023](na,ka,K,8);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>1,K)|0)+(ia>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&1023](na,ka,K,8)}else{ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,K)|0)+(U>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&I)<<n)+(U&I)|0)<<2)>>2]&4095](na,ka,K);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>2,K)|0)+(ia>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&4095](na,ka,K)}la=la+1|0;}while((la|0)<4)}}else{la=(c[(b+12160|0)>>2]|0)+(G<<n)|0;ka=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;na=c[(b+12128|0)>>2]|0;if((G<<n|0)==0){Bc=(ba(na,J-qa|0)|0)/(qa|0)|0}else{Bc=la-na|0}na=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){Cc=(ba(na,J-qa|0)|0)/(qa|0)|0}else{Cc=ka-na|0}na=((Cc&I)<<n)+(Bc&I)|0;if((m&1|0)==0){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,K)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ia,K,16);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Cc>>1,K)|0)+(Bc>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(na<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ia,K,16);break}else{ia=(ba(ka>>2,K)|0)+(la>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ia|0,K);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ia+8|0)|0,K);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(K<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ia+(K<<3))|0,K);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ia+8|0)+(K<<3))|0,K);ia=(ba(Cc>>2,K)|0)+(Bc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ia|0,K);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ia+8|0)|0,K);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(K<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ia+(K<<3))|0,K);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ia+8|0)+(K<<3))|0,K);break}}}while(0);yc=Pe[z&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,K,16)|0}}while(0);c[(N+(((ma<<3)+G&63)<<2)|0)>>2]=G+A+(ma<<11)|0;c[V+(((ma<<3)+G&63)<<2)>>2]=yc;K=(ba((d[_+((ma<<n)-F)|0]|0)+(d[_+((G<<n)-H)|0]|0)|0,l)|0)+yc|0;if((K|0)>=(ja|0)){vc=ja;wc=S;xc=M;break}c[r>>2]=G;c[(r+4|0)>>2]=ma;vc=K;wc=ma;xc=G}}while(0);G=$a+1|0;if((G|0)<8){$a=G;ja=vc;S=wc;M=xc}else{break}}if((xc|0)==(R|0)&(wc|0)==(L|0)){break}else{W=vc;L=wc;R=xc}}W=(s+255&(s&255)|0)!=0?B-1|0:B>>1;if((W|0)==0){sc=vc;tc=R;uc=L;break}else{B=W;O=vc;D=L;Q=R}}}Q=tc+1|0;D=(Q|0)>(C|0)?C:Q;Q=(y|0)>(D|0)?y:D;D=(uc|0)>(x|0)?x:uc;O=(E|0)>(D|0)?E:D;do{if((c[(N+((Q+(O<<3)&63)<<2)|0)>>2]|0)==(((O<<11)+A|0)+Q|0|0)){Dc=sc}else{do{if((m&4|0)==0){D=c[b+12416>>2]|0;B=c[b+12420>>2]|0;I=(c[b+12352+(j<<4)>>2]|0)+((ba(D,O)|0)+Q)|0;W=Pe[z&255](b,c[b+12288+(h<<4)>>2]|0,I,D,8)|0;if((m&2|0)==0){Ec=W;break}I=c[b+12208>>2]|0;M=(ba(B,O>>1)|0)+(Q>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((Q&1|O<<1&2)<<2)>>2]&1023](I+(D<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+M|0,B,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((Q&1|O<<1&2)<<2)>>2]&1023](I+(D<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+M|0,B,4);M=(Pe[T&255](b,I+(D<<4)|0,c[b+12288+(h<<4)+4>>2]|0,B,4)|0)+W|0;Ec=M+(Pe[T&255](b,I+(D<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,B,4)|0)|0}else{B=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(Q|0)){Ec=536870912;break}if((Q<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Ec=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Ec=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Ec=536870912;break}D=e[b+13872>>1]|0;I=e[b+13874>>1]|0;M=(m&1)<<1|1;q:do{if((c[b+11740>>2]|0)==1){if((Q<<n|0)==0){W=0;while(1){S=c[b+12160+(W<<3)>>2]|0;ja=(c[b+12160+(W<<3)+4>>2]|0)+(O<<n)|0;$a=((ba(c[b+12128+(W<<3)>>2]|0,I-D|0)|0)/(D|0)|0)+((W&1)<<(m&1|4))|0;G=c[b+12128+(W<<3)+4>>2]|0;if((O<<n|0)==0){ma=W>>1;Fc=((ba(G,I-D|0)|0)/(D|0)|0)+(ma<<(m&1|4))|0;Gc=ma}else{Fc=ja-G|0;Gc=W>>1}G=((Fc&M)<<n)+($a&M)|0;ma=(c[(b+12208|0)>>2]|0)+((ba(Gc,B<<3)|0)+(W<<3&8))|0;if((m&1|0)==0){K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja>>1,B)|0)+(S>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ja&M)<<n)+(S&M)|0)<<2)>>2]&1023](ma,K,B,8);K=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Fc>>1,B)|0)+($a>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(G<<2)>>2]&1023](ma,K,B,8)}else{K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja>>2,B)|0)+(S>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ja&M)<<n)+(S&M)|0)<<2)>>2]&4095](ma,K,B);K=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Fc>>2,B)|0)+($a>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(G<<2)>>2]&4095](ma,K,B)}W=W+1|0;if((W|0)>=4){break q}}}if((O<<n|0)==0){W=0;do{K=(c[b+12160+(W<<3)>>2]|0)+(Q<<n)|0;ma=c[b+12160+(W<<3)+4>>2]|0;G=K-(c[b+12128+(W<<3)>>2]|0)|0;$a=W>>1;S=((ba(c[b+12128+(W<<3)+4>>2]|0,I-D|0)|0)/(D|0)|0)+($a<<(m&1|4))|0;ja=(c[(b+12208|0)>>2]|0)+((W<<3&8)+(ba($a,B<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,B)|0)+(K>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&M)<<n)+(K&M)|0)<<2)>>2]&1023](ja,$a,B,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(S>>1,B)|0)+(G>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((S&M)<<n)+(G&M)|0)<<2)>>2]&1023](ja,$a,B,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>2,B)|0)+(K>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(K&M)|0)<<2)>>2]&4095](ja,$a,B);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(S>>2,B)|0)+(G>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((S&M)<<n)+(G&M)|0)<<2)>>2]&4095](ja,$a,B)}W=W+1|0;}while((W|0)<4)}else{W=0;do{$a=(c[b+12160+(W<<3)>>2]|0)+(Q<<n)|0;ja=(c[b+12160+(W<<3)+4>>2]|0)+(O<<n)|0;G=$a-(c[b+12128+(W<<3)>>2]|0)|0;S=ja-(c[b+12128+(W<<3)+4>>2]|0)|0;K=(c[(b+12208|0)>>2]|0)+((W<<3&8)+(ba(W>>1,B<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja>>1,B)|0)+($a>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ja&M)<<n)+($a&M)|0)<<2)>>2]&1023](K,ma,B,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(S>>1,B)|0)+(G>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((S&M)<<n)+(G&M)|0)<<2)>>2]&1023](K,ma,B,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja>>2,B)|0)+($a>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ja&M)<<n)+($a&M)|0)<<2)>>2]&4095](K,ma,B);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(S>>2,B)|0)+(G>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((S&M)<<n)+(G&M)|0)<<2)>>2]&4095](K,ma,B)}W=W+1|0;}while((W|0)<4)}}else{W=(c[b+12160>>2]|0)+(Q<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;K=c[b+12128>>2]|0;if((Q<<n|0)==0){Hc=(ba(K,I-D|0)|0)/(D|0)|0}else{Hc=W-K|0}K=c[b+12132>>2]|0;if((O<<n|0)==0){Ic=(ba(K,I-D|0)|0)/(D|0)|0}else{Ic=ma-K|0}K=((Ic&M)<<n)+(Hc&M)|0;if((m&1|0)==0){G=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,B)|0)+(W>>1))|0;cf[c[(c[b+12444>>2]|0)+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,G,B,16);G=(c[b+12352+(j<<4)+32>>2]|0)+((ba(Ic>>1,B)|0)+(Hc>>1))|0;cf[c[(c[b+12448>>2]|0)+(K<<2)>>2]&1023](c[(b+12208|0)>>2]|0,G,B,16);break}else{G=(ba(ma>>2,B)|0)+(W>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+G|0,B);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(G+8|0)|0,B);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(B<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(G+(B<<3))|0,B);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((B<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((G+8|0)+(B<<3))|0,B);G=(ba(Ic>>2,B)|0)+(Hc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+G|0,B);Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(G+8|0)|0,B);Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(B<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(G+(B<<3))|0,B);Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((B<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((G+8|0)+(B<<3))|0,B);break}}}while(0);Ec=Pe[z&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,B,16)|0}}while(0);c[(N+((Q+(O<<3)&63)<<2)|0)>>2]=((O<<11)+A|0)+Q|0;c[V+((Q+(O<<3)&63)<<2)>>2]=Ec;R=(ba((d[_+((O<<n)-F)|0]|0)+(d[_+((Q<<n)-H)|0]|0)|0,l)|0)+Ec|0;if((R|0)>=(sc|0)){Dc=sc;break}c[r>>2]=Q;c[(r+4|0)>>2]=O;Dc=R}}while(0);Q=uc+1|0;R=(tc|0)>(C|0)?C:tc;L=(y|0)>(R|0)?y:R;R=(Q|0)>(x|0)?x:Q;Q=(E|0)>(R|0)?E:R;do{if((c[(N+(((Q<<3)+L&63)<<2)|0)>>2]|0)==((L+A|0)+(Q<<11)|0|0)){Jc=Dc}else{do{if((m&4|0)==0){R=c[b+12416>>2]|0;M=c[b+12420>>2]|0;D=(c[b+12352+(j<<4)>>2]|0)+((ba(R,Q)|0)+L)|0;I=Pe[z&255](b,c[b+12288+(h<<4)>>2]|0,D,R,8)|0;if((m&2|0)==0){Kc=I;break}D=c[b+12208>>2]|0;G=(ba(M,Q>>1)|0)+(L>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((Q<<1&2|L&1)<<2)>>2]&1023](D+(R<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+G|0,M,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((Q<<1&2|L&1)<<2)>>2]&1023](D+(R<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+G|0,M,4);G=(Pe[T&255](b,D+(R<<4)|0,c[b+12288+(h<<4)+4>>2]|0,M,4)|0)+I|0;Kc=G+(Pe[T&255](b,D+(R<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,M,4)|0)|0}else{M=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(L|0)){Kc=536870912;break}if((L<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Kc=536870912;break}if((c[(b+12272|0)>>2]|0)>(Q|0)){Kc=536870912;break}if((Q<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Kc=536870912;break}R=e[b+13872>>1]|0;D=e[b+13874>>1]|0;G=(m&1)<<1|1;r:do{if((c[b+11740>>2]|0)==1){if((L<<n|0)==0){I=0;while(1){K=c[b+12160+(I<<3)>>2]|0;W=(c[b+12160+(I<<3)+4>>2]|0)+(Q<<n)|0;ma=((ba(c[b+12128+(I<<3)>>2]|0,D-R|0)|0)/(R|0)|0)+((I&1)<<(m&1|4))|0;S=c[b+12128+(I<<3)+4>>2]|0;if((Q<<n|0)==0){$a=I>>1;Lc=((ba(S,D-R|0)|0)/(R|0)|0)+($a<<(m&1|4))|0;Mc=$a}else{Lc=W-S|0;Mc=I>>1}S=((Lc&G)<<n)+(ma&G)|0;$a=(c[(b+12208|0)>>2]|0)+((ba(Mc,M<<3)|0)+(I<<3&8))|0;if((m&1|0)==0){ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(W>>1,M)|0)+(K>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((W&G)<<n)+(K&G)|0)<<2)>>2]&1023]($a,ja,M,8);ja=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Lc>>1,M)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(S<<2)>>2]&1023]($a,ja,M,8)}else{ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(W>>2,M)|0)+(K>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((W&G)<<n)+(K&G)|0)<<2)>>2]&4095]($a,ja,M);ja=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Lc>>2,M)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]($a,ja,M)}I=I+1|0;if((I|0)>=4){break r}}}if((Q<<n|0)==0){I=0;do{ja=(c[b+12160+(I<<3)>>2]|0)+(L<<n)|0;$a=c[b+12160+(I<<3)+4>>2]|0;S=ja-(c[b+12128+(I<<3)>>2]|0)|0;ma=I>>1;K=((ba(c[b+12128+(I<<3)+4>>2]|0,D-R|0)|0)/(R|0)|0)+(ma<<(m&1|4))|0;W=(c[(b+12208|0)>>2]|0)+((I<<3&8)+(ba(ma,M<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>1,M)|0)+(ja>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(((($a&G)<<n)+(ja&G)|0)<<2)>>2]&1023](W,ma,M,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,M)|0)+(S>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(S&G)|0)<<2)>>2]&1023](W,ma,M,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>2,M)|0)+(ja>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(ja&G)|0)<<2)>>2]&4095](W,ma,M);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,M)|0)+(S>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(S&G)|0)<<2)>>2]&4095](W,ma,M)}I=I+1|0;}while((I|0)<4)}else{I=0;do{ma=(c[b+12160+(I<<3)>>2]|0)+(L<<n)|0;W=(c[b+12160+(I<<3)+4>>2]|0)+(Q<<n)|0;S=ma-(c[b+12128+(I<<3)>>2]|0)|0;K=W-(c[b+12128+(I<<3)+4>>2]|0)|0;ja=(c[(b+12208|0)>>2]|0)+((I<<3&8)+(ba(I>>1,M<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(W>>1,M)|0)+(ma>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((W&G)<<n)+(ma&G)|0)<<2)>>2]&1023](ja,$a,M,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,M)|0)+(S>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(S&G)|0)<<2)>>2]&1023](ja,$a,M,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(W>>2,M)|0)+(ma>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((W&G)<<n)+(ma&G)|0)<<2)>>2]&4095](ja,$a,M);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,M)|0)+(S>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(S&G)|0)<<2)>>2]&4095](ja,$a,M)}I=I+1|0;}while((I|0)<4)}}else{I=(c[b+12160>>2]|0)+(L<<n)|0;$a=(c[b+12164>>2]|0)+(Q<<n)|0;ja=c[b+12128>>2]|0;if((L<<n|0)==0){Nc=(ba(ja,D-R|0)|0)/(R|0)|0}else{Nc=I-ja|0}ja=c[b+12132>>2]|0;if((Q<<n|0)==0){Oc=(ba(ja,D-R|0)|0)/(R|0)|0}else{Oc=$a-ja|0}ja=((Oc&G)<<n)+(Nc&G)|0;if((m&1|0)==0){S=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>1,M)|0)+(I>>1))|0;cf[c[(c[b+12444>>2]|0)+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,S,M,16);S=(c[b+12352+(j<<4)+32>>2]|0)+((ba(Oc>>1,M)|0)+(Nc>>1))|0;cf[c[(c[b+12448>>2]|0)+(ja<<2)>>2]&1023](c[(b+12208|0)>>2]|0,S,M,16);break}else{S=(ba($a>>2,M)|0)+(I>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+S|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(S+8|0)|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(S+(M<<3))|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((S+8|0)+(M<<3))|0,M);S=(ba(Oc>>2,M)|0)+(Nc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+S|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(S+8|0)|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(S+(M<<3))|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((S+8|0)+(M<<3))|0,M);break}}}while(0);Kc=Pe[z&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,M,16)|0}}while(0);c[(N+(((Q<<3)+L&63)<<2)|0)>>2]=(L+A|0)+(Q<<11)|0;c[V+(((Q<<3)+L&63)<<2)>>2]=Kc;G=(ba((d[_+((Q<<n)-F)|0]|0)+(d[_+((L<<n)-H)|0]|0)|0,l)|0)+Kc|0;if((G|0)>=(Dc|0)){Jc=Dc;break}c[r>>2]=L;c[(r+4|0)>>2]=Q;Jc=G}}while(0);Q=tc-1|0;G=(Q|0)>(C|0)?C:Q;Q=(y|0)>(G|0)?y:G;do{if((c[(N+((Q+(O<<3)&63)<<2)|0)>>2]|0)==(((O<<11)+A|0)+Q|0|0)){Pc=Jc}else{do{if((m&4|0)==0){G=c[b+12416>>2]|0;R=c[b+12420>>2]|0;D=(c[b+12352+(j<<4)>>2]|0)+((ba(G,O)|0)+Q)|0;B=Pe[z&255](b,c[b+12288+(h<<4)>>2]|0,D,G,8)|0;if((m&2|0)==0){Qc=B;break}D=c[b+12208>>2]|0;S=(ba(R,O>>1)|0)+(Q>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((Q&1|O<<1&2)<<2)>>2]&1023](D+(G<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+S|0,R,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((Q&1|O<<1&2)<<2)>>2]&1023](D+(G<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+S|0,R,4);S=(Pe[T&255](b,D+(G<<4)|0,c[b+12288+(h<<4)+4>>2]|0,R,4)|0)+B|0;Qc=S+(Pe[T&255](b,D+(G<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,R,4)|0)|0}else{R=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(Q|0)){Qc=536870912;break}if((Q<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Qc=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Qc=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Qc=536870912;break}G=e[b+13872>>1]|0;D=e[b+13874>>1]|0;S=(m&1)<<1|1;s:do{if((c[b+11740>>2]|0)==1){if((Q<<n|0)==0){B=0;while(1){ja=c[b+12160+(B<<3)>>2]|0;I=(c[b+12160+(B<<3)+4>>2]|0)+(O<<n)|0;$a=((ba(c[b+12128+(B<<3)>>2]|0,D-G|0)|0)/(G|0)|0)+((B&1)<<(m&1|4))|0;K=c[b+12128+(B<<3)+4>>2]|0;if((O<<n|0)==0){ma=B>>1;Rc=((ba(K,D-G|0)|0)/(G|0)|0)+(ma<<(m&1|4))|0;Sc=ma}else{Rc=I-K|0;Sc=B>>1}K=((Rc&S)<<n)+($a&S)|0;ma=(c[(b+12208|0)>>2]|0)+((ba(Sc,R<<3)|0)+(B<<3&8))|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(I>>1,R)|0)+(ja>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((I&S)<<n)+(ja&S)|0)<<2)>>2]&1023](ma,W,R,8);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Rc>>1,R)|0)+($a>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(K<<2)>>2]&1023](ma,W,R,8)}else{W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(I>>2,R)|0)+(ja>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((I&S)<<n)+(ja&S)|0)<<2)>>2]&4095](ma,W,R);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Rc>>2,R)|0)+($a>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095](ma,W,R)}B=B+1|0;if((B|0)>=4){break s}}}if((O<<n|0)==0){B=0;do{W=(c[b+12160+(B<<3)>>2]|0)+(Q<<n)|0;ma=c[b+12160+(B<<3)+4>>2]|0;K=W-(c[b+12128+(B<<3)>>2]|0)|0;$a=B>>1;ja=((ba(c[b+12128+(B<<3)+4>>2]|0,D-G|0)|0)/(G|0)|0)+($a<<(m&1|4))|0;I=(c[(b+12208|0)>>2]|0)+((B<<3&8)+(ba($a,R<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,R)|0)+(W>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&S)<<n)+(W&S)|0)<<2)>>2]&1023](I,$a,R,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ja>>1,R)|0)+(K>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&1023](I,$a,R,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>2,R)|0)+(W>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(W&S)|0)<<2)>>2]&4095](I,$a,R);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ja>>2,R)|0)+(K>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&4095](I,$a,R)}B=B+1|0;}while((B|0)<4)}else{B=0;do{$a=(c[b+12160+(B<<3)>>2]|0)+(Q<<n)|0;I=(c[b+12160+(B<<3)+4>>2]|0)+(O<<n)|0;K=$a-(c[b+12128+(B<<3)>>2]|0)|0;ja=I-(c[b+12128+(B<<3)+4>>2]|0)|0;W=(c[(b+12208|0)>>2]|0)+((B<<3&8)+(ba(B>>1,R<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(I>>1,R)|0)+($a>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((I&S)<<n)+($a&S)|0)<<2)>>2]&1023](W,ma,R,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ja>>1,R)|0)+(K>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&1023](W,ma,R,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(I>>2,R)|0)+($a>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((I&S)<<n)+($a&S)|0)<<2)>>2]&4095](W,ma,R);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ja>>2,R)|0)+(K>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&4095](W,ma,R)}B=B+1|0;}while((B|0)<4)}}else{B=(c[b+12160>>2]|0)+(Q<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;W=c[b+12128>>2]|0;if((Q<<n|0)==0){Tc=(ba(W,D-G|0)|0)/(G|0)|0}else{Tc=B-W|0}W=c[b+12132>>2]|0;if((O<<n|0)==0){Uc=(ba(W,D-G|0)|0)/(G|0)|0}else{Uc=ma-W|0}W=((Uc&S)<<n)+(Tc&S)|0;if((m&1|0)==0){K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,R)|0)+(B>>1))|0;cf[c[(c[b+12444>>2]|0)+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,K,R,16);K=(c[b+12352+(j<<4)+32>>2]|0)+((ba(Uc>>1,R)|0)+(Tc>>1))|0;cf[c[(c[b+12448>>2]|0)+(W<<2)>>2]&1023](c[(b+12208|0)>>2]|0,K,R,16);break}else{K=(ba(ma>>2,R)|0)+(B>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+K|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(K+8|0)|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(K+(R<<3))|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((K+8|0)+(R<<3))|0,R);K=(ba(Uc>>2,R)|0)+(Tc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+K|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(K+8|0)|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(K+(R<<3))|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((K+8|0)+(R<<3))|0,R);break}}}while(0);Qc=Pe[z&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,R,16)|0}}while(0);c[(N+((Q+(O<<3)&63)<<2)|0)>>2]=((O<<11)+A|0)+Q|0;c[V+((Q+(O<<3)&63)<<2)>>2]=Qc;S=(ba((d[_+((O<<n)-F)|0]|0)+(d[_+((Q<<n)-H)|0]|0)|0,l)|0)+Qc|0;if((S|0)>=(Jc|0)){Pc=Jc;break}c[r>>2]=Q;c[(r+4|0)>>2]=O;Pc=S}}while(0);O=uc-1|0;Q=(O|0)>(x|0)?x:O;O=(E|0)>(Q|0)?E:Q;if((c[(N+(((O<<3)+L&63)<<2)|0)>>2]|0)==((L+A|0)+(O<<11)|0|0)){t=Pc;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}do{if((m&4|0)==0){Q=c[b+12416>>2]|0;y=c[b+12420>>2]|0;C=(c[b+12352+(j<<4)>>2]|0)+((ba(Q,O)|0)+L)|0;S=Pe[z&255](b,c[b+12288+(h<<4)>>2]|0,C,Q,8)|0;if((m&2|0)==0){Vc=S;break}C=c[b+12208>>2]|0;G=(ba(y,O>>1)|0)+(L>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((O<<1&2|L&1)<<2)>>2]&1023](C+(Q<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+G|0,y,4);cf[c[(c[(b+12444|0)>>2]|0)+16+((O<<1&2|L&1)<<2)>>2]&1023](C+(Q<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+G|0,y,4);G=(Pe[T&255](b,C+(Q<<4)|0,c[b+12288+(h<<4)+4>>2]|0,y,4)|0)+S|0;Vc=G+(Pe[T&255](b,C+(Q<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,y,4)|0)|0}else{y=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(L|0)){Vc=536870912;break}if((L<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Vc=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Vc=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Vc=536870912;break}Q=e[b+13872>>1]|0;C=e[b+13874>>1]|0;G=(m&1)<<1|1;t:do{if((c[b+11740>>2]|0)==1){if((L<<n|0)==0){S=0;while(1){D=c[b+12160+(S<<3)>>2]|0;M=(c[b+12160+(S<<3)+4>>2]|0)+(O<<n)|0;K=((ba(c[b+12128+(S<<3)>>2]|0,C-Q|0)|0)/(Q|0)|0)+((S&1)<<(m&1|4))|0;W=c[b+12128+(S<<3)+4>>2]|0;if((O<<n|0)==0){B=S>>1;Wc=((ba(W,C-Q|0)|0)/(Q|0)|0)+(B<<(m&1|4))|0;Xc=B}else{Wc=M-W|0;Xc=S>>1}W=((Wc&G)<<n)+(K&G)|0;B=(c[(b+12208|0)>>2]|0)+((ba(Xc,y<<3)|0)+(S<<3&8))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(M>>1,y)|0)+(D>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((M&G)<<n)+(D&G)|0)<<2)>>2]&1023](B,ma,y,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Wc>>1,y)|0)+(K>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(W<<2)>>2]&1023](B,ma,y,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(M>>2,y)|0)+(D>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((M&G)<<n)+(D&G)|0)<<2)>>2]&4095](B,ma,y);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Wc>>2,y)|0)+(K>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](B,ma,y)}S=S+1|0;if((S|0)>=4){break t}}}if((O<<n|0)==0){S=0;do{R=(c[b+12160+(S<<3)>>2]|0)+(L<<n)|0;ma=c[b+12160+(S<<3)+4>>2]|0;B=R-(c[b+12128+(S<<3)>>2]|0)|0;W=S>>1;K=((ba(c[b+12128+(S<<3)+4>>2]|0,C-Q|0)|0)/(Q|0)|0)+(W<<(m&1|4))|0;D=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ba(W,y<<3)|0))|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,y)|0)+(R>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&G)<<n)+(R&G)|0)<<2)>>2]&1023](D,W,y,8);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,y)|0)+(B>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(B&G)|0)<<2)>>2]&1023](D,W,y,8)}else{W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>2,y)|0)+(R>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(R&G)|0)<<2)>>2]&4095](D,W,y);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,y)|0)+(B>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(B&G)|0)<<2)>>2]&4095](D,W,y)}S=S+1|0;}while((S|0)<4)}else{S=0;do{W=(c[b+12160+(S<<3)>>2]|0)+(L<<n)|0;D=(c[b+12160+(S<<3)+4>>2]|0)+(O<<n)|0;B=W-(c[b+12128+(S<<3)>>2]|0)|0;K=D-(c[b+12128+(S<<3)+4>>2]|0)|0;R=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ba(S>>1,y<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(D>>1,y)|0)+(W>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((D&G)<<n)+(W&G)|0)<<2)>>2]&1023](R,ma,y,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,y)|0)+(B>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(B&G)|0)<<2)>>2]&1023](R,ma,y,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(D>>2,y)|0)+(W>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((D&G)<<n)+(W&G)|0)<<2)>>2]&4095](R,ma,y);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,y)|0)+(B>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(B&G)|0)<<2)>>2]&4095](R,ma,y)}S=S+1|0;}while((S|0)<4)}}else{S=(c[b+12160>>2]|0)+(L<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;R=c[b+12128>>2]|0;if((L<<n|0)==0){Yc=(ba(R,C-Q|0)|0)/(Q|0)|0}else{Yc=S-R|0}R=c[b+12132>>2]|0;if((O<<n|0)==0){Zc=(ba(R,C-Q|0)|0)/(Q|0)|0}else{Zc=ma-R|0}R=((Zc&G)<<n)+(Yc&G)|0;if((m&1|0)==0){B=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,y)|0)+(S>>1))|0;cf[c[(c[b+12444>>2]|0)+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,B,y,16);B=(c[b+12352+(j<<4)+32>>2]|0)+((ba(Zc>>1,y)|0)+(Yc>>1))|0;cf[c[(c[b+12448>>2]|0)+(R<<2)>>2]&1023](c[(b+12208|0)>>2]|0,B,y,16);break}else{B=(ba(ma>>2,y)|0)+(S>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+B|0,y);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(B+8|0)|0,y);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(y<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(B+(y<<3))|0,y);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((y<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((B+8|0)+(y<<3))|0,y);B=(ba(Zc>>2,y)|0)+(Yc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+B|0,y);Xe[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(B+8|0)|0,y);Xe[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(y<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(B+(y<<3))|0,y);Xe[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((y<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((B+8|0)+(y<<3))|0,y);break}}}while(0);Vc=Pe[z&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,y,16)|0}}while(0);c[(N+(((O<<3)+L&63)<<2)|0)>>2]=(L+A|0)+(O<<11)|0;c[V+(((O<<3)+L&63)<<2)>>2]=Vc;z=(ba((d[_+((O<<n)-F)|0]|0)+(d[_+((L<<n)-H)|0]|0)|0,l)|0)+Vc|0;if((z|0)>=(Pc|0)){t=Pc;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}c[r>>2]=L;c[(r+4|0)>>2]=O;t=z;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}while(0);c[a+19096>>2]=t;c[a+19104>>2]=u;c[a+19112>>2]=v;c[a+19120>>2]=w}function _epzs_motion_search4$0(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0;b=c[a+16>>2]|0;f=c[a+24>>2]|0;g=c[a+32>>2]|0;h=c[a+48>>2]|0;j=c[a+56>>2]|0;k=c[a+80>>2]|0;l=c[a+88>>2]|0;m=c[a+176>>2]|0;n=c[a+192>>2]|0;o=c[a+6144>>2]|0;p=c[a+6152>>2]|0;q=c[a+6160>>2]|0;r=c[a+6168>>2]|0;s=c[a+6176>>2]|0;t=c[a+19104>>2]|0;u=c[a+19112>>2]|0;v=c[a+19120>>2]|0;w=c[a+19128>>2]|0;a:do{if((s|0)<2){x=c[(b+12220|0)>>2]|0;y=c[(b+12264|0)>>2]|0;z=c[(b+12272|0)>>2]|0;A=c[(b+12268|0)>>2]|0;B=c[(b+12276|0)>>2]|0;C=c[(b+12464|0)>>2]|0;D=c[(b+12280|0)>>2]|0;E=c[(b+12284|0)>>2]|0;F=c[(b+12216|0)>>2]|0;G=c[(b+12224|0)>>2]|0;H=c[(b+10472|0)>>2]|0;I=c[(b+10476|0)>>2]|0;J=p+G+(o<<11)|0;K=(o<<3)+p&63;if((c[(F+(K<<2)|0)>>2]|0)!=(J|0)){do{if((m&4|0)==0){L=c[b+12416>>2]|0;M=c[b+12420>>2]|0;N=(c[b+12352+(j<<4)>>2]|0)+((ba(L,o)|0)+p)|0;O=Pe[H&255](b,c[b+12288+(h<<4)>>2]|0,N,L,8)|0;if((m&2|0)==0){P=O;break}N=o<<1&2|p&1;Q=c[b+12208>>2]|0;R=(ba(M,o>>1)|0)+(p>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+(N<<2)>>2]&1023](Q+(L<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+R|0,M,4);cf[c[(c[(b+12444|0)>>2]|0)+32+(N<<2)>>2]&1023](Q+(L<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+R|0,M,4);R=(Pe[I&255](b,Q+(L<<4)|0,c[b+12288+(h<<4)+4>>2]|0,M,4)|0)+O|0;P=R+(Pe[I&255](b,Q+(L<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,M,4)|0)|0}else{M=c[b+12416>>2]|0;L=p<<n;Q=o<<n;if((y|0)>(p|0)){P=536870912;break}if((L|0)>(A<<n|0)|(z|0)>(o|0)){P=536870912;break}if((Q|0)>(B<<n|0)){P=536870912;break}R=e[b+13872>>1]|0;O=e[b+13874>>1]|0;N=(m&1)<<1|1;b:do{if((c[b+11740>>2]|0)==1){if((L|0)==0){S=0;while(1){T=c[b+12160+(S<<3)>>2]|0;U=(c[b+12160+(S<<3)+4>>2]|0)+Q|0;V=((ba(c[b+12128+(S<<3)>>2]|0,O-R|0)|0)/(R|0)|0)+((S&1)<<(m&1|4))|0;W=c[b+12128+(S<<3)+4>>2]|0;if((Q|0)==0){X=S>>1;Y=((ba(W,O-R|0)|0)/(R|0)|0)+(X<<(m&1|4))|0;Z=X}else{Y=U-W|0;Z=S>>1}W=((Y&N)<<n)+(V&N)|0;X=(c[(b+12208|0)>>2]|0)+((ba(Z,M<<3)|0)+(S<<3&8))|0;if((m&1|0)==0){_=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,M)|0)+(T>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(T&N)|0)<<2)>>2]&1023](X,_,M,8);_=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Y>>1,M)|0)+(V>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(W<<2)>>2]&1023](X,_,M,8)}else{_=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,M)|0)+(T>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(T&N)|0)<<2)>>2]&4095](X,_,M);_=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Y>>2,M)|0)+(V>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](X,_,M)}S=S+1|0;if((S|0)>=4){break b}}}if((Q|0)==0){S=0;do{_=(c[b+12160+(S<<3)>>2]|0)+L|0;X=c[b+12160+(S<<3)+4>>2]|0;W=_-(c[b+12128+(S<<3)>>2]|0)|0;V=S>>1;T=((ba(c[b+12128+(S<<3)+4>>2]|0,O-R|0)|0)/(R|0)|0)+(V<<(m&1|4))|0;U=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ba(V,M<<3)|0))|0;if((m&1|0)==0){V=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(X>>1,M)|0)+(_>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((X&N)<<n)+(_&N)|0)<<2)>>2]&1023](U,V,M,8);V=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(T>>1,M)|0)+(W>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((T&N)<<n)+(W&N)|0)<<2)>>2]&1023](U,V,M,8)}else{V=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(X>>2,M)|0)+(_>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(_&N)|0)<<2)>>2]&4095](U,V,M);V=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(T>>2,M)|0)+(W>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((T&N)<<n)+(W&N)|0)<<2)>>2]&4095](U,V,M)}S=S+1|0;}while((S|0)<4)}else{S=0;do{V=(c[b+12160+(S<<3)>>2]|0)+L|0;U=(c[b+12160+(S<<3)+4>>2]|0)+Q|0;W=V-(c[b+12128+(S<<3)>>2]|0)|0;T=U-(c[b+12128+(S<<3)+4>>2]|0)|0;_=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ba(S>>1,M<<3)|0))|0;if((m&1|0)==0){X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,M)|0)+(V>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(V&N)|0)<<2)>>2]&1023](_,X,M,8);X=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(T>>1,M)|0)+(W>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((T&N)<<n)+(W&N)|0)<<2)>>2]&1023](_,X,M,8)}else{X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,M)|0)+(V>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(V&N)|0)<<2)>>2]&4095](_,X,M);X=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(T>>2,M)|0)+(W>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((T&N)<<n)+(W&N)|0)<<2)>>2]&4095](_,X,M)}S=S+1|0;}while((S|0)<4)}}else{S=(c[b+12160>>2]|0)+L|0;X=(c[b+12164>>2]|0)+Q|0;_=c[b+12128>>2]|0;if((L|0)==0){$=(ba(_,O-R|0)|0)/(R|0)|0}else{$=S-_|0}_=c[b+12132>>2]|0;if((Q|0)==0){aa=(ba(_,O-R|0)|0)/(R|0)|0}else{aa=X-_|0}_=((aa&N)<<n)+($&N)|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(X>>1,M)|0)+(S>>1))|0;cf[c[(c[b+12444>>2]|0)+((((X&N)<<n)+(S&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,W,M,16);W=(c[b+12352+(j<<4)+32>>2]|0)+((ba(aa>>1,M)|0)+($>>1))|0;cf[c[(c[b+12448>>2]|0)+(_<<2)>>2]&1023](c[(b+12208|0)>>2]|0,W,M,16);break}else{W=(ba(X>>2,M)|0)+(S>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+W|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(W+8|0)|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(W+(M<<3))|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((W+8|0)+(M<<3))|0,M);W=(ba(aa>>2,M)|0)+($>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+W|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(W+8|0)|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(W+(M<<3))|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((W+8|0)+(M<<3))|0,M);break}}}while(0);P=Pe[H&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,M,16)|0}}while(0);c[x+(K<<2)>>2]=P;c[(F+(K<<2)|0)>>2]=J}N=(m&1)<<1|1;R=m&1|4;O=(m&1|0)==0;Q=q;L=-1;W=p;_=o;c:while(1){do{if((L|0)!=2&(W|0)>(y|0)){S=W-1|0;X=S+G+(_<<11)|0;T=(_<<3)+S&63;if((c[(F+(T<<2)|0)>>2]|0)==(X|0)){ca=Q;da=-1;ea=W;break}V=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){U=c[(b+12420|0)>>2]|0;fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(V,_)|0)+S)|0;ga=Pe[H&255](b,c[(b+12288+(h<<4)|0)>>2]|0,fa,V,8)|0;if((m&2|0)==0){ha=ga;break}fa=_<<1&2|S&1;ia=c[(b+12208|0)>>2]|0;ja=(ba(U,_>>1)|0)+(S>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+(fa<<2)>>2]&1023](ia+(V<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ja|0,U,4);cf[c[(c[(b+12444|0)>>2]|0)+32+(fa<<2)>>2]&1023](ia+(V<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ja|0,U,4);ja=(Pe[I&255](b,ia+(V<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,U,4)|0)+ga|0;ha=ja+(Pe[I&255](b,ia+(V<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,U,4)|0)|0}else{U=_<<n;if((c[(b+12264|0)>>2]|0)>(S|0)){ha=536870912;break}if((S<<n|0)>(c[(b+12268|0)>>2]<<n|0)){ha=536870912;break}if((c[(b+12272|0)>>2]|0)>(_|0)){ha=536870912;break}if((U|0)>(c[(b+12276|0)>>2]<<n|0)){ha=536870912;break}ia=e[(b+13872|0)>>1]|0;ja=e[(b+13874|0)>>1]|0;d:do{if((c[(b+11740|0)>>2]|0)==1){if((S<<n|0)==0){ga=0;while(1){fa=c[b+12160+(ga<<3)>>2]|0;ka=(c[b+12160+(ga<<3)+4>>2]|0)+U|0;la=((ba(c[b+12128+(ga<<3)>>2]|0,ja-ia|0)|0)/(ia|0)|0)+((ga&1)<<R)|0;ma=c[b+12128+(ga<<3)+4>>2]|0;if((U|0)==0){na=ga>>1;oa=((ba(ma,ja-ia|0)|0)/(ia|0)|0)+(na<<R)|0;pa=na}else{oa=ka-ma|0;pa=ga>>1}ma=((oa&N)<<n)+(la&N)|0;na=(c[(b+12208|0)>>2]|0)+((ba(pa,V<<3)|0)+(ga<<3&8))|0;if(O){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,V)|0)+(fa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&N)<<n)+(fa&N)|0)<<2)>>2]&1023](na,qa,V,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(oa>>1,V)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ma<<2)>>2]&1023](na,qa,V,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>2,V)|0)+(fa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&N)<<n)+(fa&N)|0)<<2)>>2]&4095](na,qa,V);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(oa>>2,V)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](na,qa,V)}ga=ga+1|0;if((ga|0)>=4){break d}}}if((U|0)==0){ga=0;do{qa=(c[b+12160+(ga<<3)>>2]|0)+(S<<n)|0;na=c[b+12160+(ga<<3)+4>>2]|0;ma=qa-(c[b+12128+(ga<<3)>>2]|0)|0;la=ga>>1;fa=((ba(c[b+12128+(ga<<3)+4>>2]|0,ja-ia|0)|0)/(ia|0)|0)+(la<<R)|0;ka=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(la,V<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,V)|0)+(qa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((na&N)<<n)+(qa&N)|0)<<2)>>2]&1023](ka,la,V,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(fa>>1,V)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&1023](ka,la,V,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>2,V)|0)+(qa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(qa&N)|0)<<2)>>2]&4095](ka,la,V);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(fa>>2,V)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](ka,la,V)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{la=(c[b+12160+(ga<<3)>>2]|0)+(S<<n)|0;ka=(c[b+12160+(ga<<3)+4>>2]|0)+U|0;ma=la-(c[b+12128+(ga<<3)>>2]|0)|0;fa=ka-(c[b+12128+(ga<<3)+4>>2]|0)|0;qa=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(ga>>1,V<<3)|0))|0;if(O){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,V)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&N)<<n)+(la&N)|0)<<2)>>2]&1023](qa,na,V,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(fa>>1,V)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&1023](qa,na,V,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>2,V)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&N)<<n)+(la&N)|0)<<2)>>2]&4095](qa,na,V);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(fa>>2,V)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](qa,na,V)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+(S<<n)|0;na=(c[(b+12164|0)>>2]|0)+U|0;qa=c[(b+12128|0)>>2]|0;if((S<<n|0)==0){ra=(ba(qa,ja-ia|0)|0)/(ia|0)|0}else{ra=ga-qa|0}qa=c[(b+12132|0)>>2]|0;if((U|0)==0){sa=(ba(qa,ja-ia|0)|0)/(ia|0)|0}else{sa=na-qa|0}qa=((sa&N)<<n)+(ra&N)|0;if(O){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,V)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ma,V,16);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(sa>>1,V)|0)+(ra>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(qa<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ma,V,16);break}else{ma=(ba(na>>2,V)|0)+(ga>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ma|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+8|0)|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+(V<<3))|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ma+8|0)+(V<<3))|0,V);ma=(ba(sa>>2,V)|0)+(ra>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ma|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+8|0)|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+(V<<3))|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ma+8|0)+(V<<3))|0,V);break}}}while(0);ha=Pe[H&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,V,16)|0}}while(0);c[(F+(T<<2)|0)>>2]=X;c[x+(T<<2)>>2]=ha;V=(ba((d[C+((_<<n)-E)|0]|0)+(d[C+((S<<n)-D)|0]|0)|0,l)|0)+ha|0;if((V|0)>=(Q|0)){ca=Q;da=-1;ea=W;break}c[r>>2]=S;c[(r+4|0)>>2]=_;ca=V;da=0;ea=S}else{ca=Q;da=-1;ea=W}}while(0);do{if((L|0)!=3&(_|0)>(z|0)){M=_-1|0;V=W+G+(M<<11)|0;ia=(M<<3)+W&63;if((c[(F+(ia<<2)|0)>>2]|0)==(V|0)){ta=ca;ua=da;va=ea;wa=_;break}ja=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){U=c[(b+12420|0)>>2]|0;ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja,M)|0)+W)|0;qa=Pe[H&255](b,c[(b+12288+(h<<4)|0)>>2]|0,ma,ja,8)|0;if((m&2|0)==0){xa=qa;break}ma=M<<1&2|W&1;ga=c[(b+12208|0)>>2]|0;na=(ba(U,M>>1)|0)+(W>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+(ma<<2)>>2]&1023](ga+(ja<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+na|0,U,4);cf[c[(c[(b+12444|0)>>2]|0)+32+(ma<<2)>>2]&1023](ga+(ja<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+na|0,U,4);na=(Pe[I&255](b,ga+(ja<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,U,4)|0)+qa|0;xa=na+(Pe[I&255](b,ga+(ja<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,U,4)|0)|0}else{U=W<<n;if((c[(b+12264|0)>>2]|0)>(W|0)){xa=536870912;break}if((U|0)>(c[(b+12268|0)>>2]<<n|0)){xa=536870912;break}if((c[(b+12272|0)>>2]|0)>(M|0)){xa=536870912;break}if((M<<n|0)>(c[(b+12276|0)>>2]<<n|0)){xa=536870912;break}ga=e[(b+13872|0)>>1]|0;na=e[(b+13874|0)>>1]|0;e:do{if((c[(b+11740|0)>>2]|0)==1){if((U|0)==0){qa=0;while(1){ma=c[b+12160+(qa<<3)>>2]|0;fa=(c[b+12160+(qa<<3)+4>>2]|0)+(M<<n)|0;la=((ba(c[b+12128+(qa<<3)>>2]|0,na-ga|0)|0)/(ga|0)|0)+((qa&1)<<R)|0;ka=c[b+12128+(qa<<3)+4>>2]|0;if((M<<n|0)==0){ya=qa>>1;za=((ba(ka,na-ga|0)|0)/(ga|0)|0)+(ya<<R)|0;Aa=ya}else{za=fa-ka|0;Aa=qa>>1}ka=((za&N)<<n)+(la&N)|0;ya=(c[(b+12208|0)>>2]|0)+((ba(Aa,ja<<3)|0)+(qa<<3&8))|0;if(O){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>1,ja)|0)+(ma>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&1023](ya,Ba,ja,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(za>>1,ja)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&1023](ya,Ba,ja,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>2,ja)|0)+(ma>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](ya,Ba,ja);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(za>>2,ja)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](ya,Ba,ja)}qa=qa+1|0;if((qa|0)>=4){break e}}}if((M<<n|0)==0){qa=0;do{Ba=(c[b+12160+(qa<<3)>>2]|0)+U|0;ya=c[b+12160+(qa<<3)+4>>2]|0;ka=Ba-(c[b+12128+(qa<<3)>>2]|0)|0;la=qa>>1;ma=((ba(c[b+12128+(qa<<3)+4>>2]|0,na-ga|0)|0)/(ga|0)|0)+(la<<R)|0;fa=(c[(b+12208|0)>>2]|0)+((qa<<3&8)+(ba(la,ja<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,ja)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&N)<<n)+(Ba&N)|0)<<2)>>2]&1023](fa,la,ja,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ma>>1,ja)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&1023](fa,la,ja,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>2,ja)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(Ba&N)|0)<<2)>>2]&4095](fa,la,ja);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ma>>2,ja)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&4095](fa,la,ja)}qa=qa+1|0;}while((qa|0)<4)}else{qa=0;do{la=(c[b+12160+(qa<<3)>>2]|0)+U|0;fa=(c[b+12160+(qa<<3)+4>>2]|0)+(M<<n)|0;ka=la-(c[b+12128+(qa<<3)>>2]|0)|0;ma=fa-(c[b+12128+(qa<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((qa<<3&8)+(ba(qa>>1,ja<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>1,ja)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&N)<<n)+(la&N)|0)<<2)>>2]&1023](Ba,ya,ja,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ma>>1,ja)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&1023](Ba,ya,ja,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>2,ja)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((fa&N)<<n)+(la&N)|0)<<2)>>2]&4095](Ba,ya,ja);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ma>>2,ja)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&4095](Ba,ya,ja)}qa=qa+1|0;}while((qa|0)<4)}}else{qa=(c[(b+12160|0)>>2]|0)+U|0;ya=(c[(b+12164|0)>>2]|0)+(M<<n)|0;Ba=c[(b+12128|0)>>2]|0;if((U|0)==0){Ca=(ba(Ba,na-ga|0)|0)/(ga|0)|0}else{Ca=qa-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((M<<n|0)==0){Da=(ba(Ba,na-ga|0)|0)/(ga|0)|0}else{Da=ya-Ba|0}Ba=((Da&N)<<n)+(Ca&N)|0;if(O){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,ja)|0)+(qa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,ja,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Da>>1,ja)|0)+(Ca>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,ja,16);break}else{ka=(ba(ya>>2,ja)|0)+(qa>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,ja);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,ja);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ja<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(ja<<3))|0,ja);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(ja<<3))|0,ja);ka=(ba(Da>>2,ja)|0)+(Ca>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,ja);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,ja);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ja<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(ja<<3))|0,ja);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(ja<<3))|0,ja);break}}}while(0);xa=Pe[H&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ja,16)|0}}while(0);c[(F+(ia<<2)|0)>>2]=V;c[x+(ia<<2)>>2]=xa;ja=(ba((d[C+((M<<n)-E)|0]|0)+(d[C+((W<<n)-D)|0]|0)|0,l)|0)+xa|0;if((ja|0)>=(ca|0)){ta=ca;ua=da;va=ea;wa=_;break}c[r>>2]=W;c[(r+4|0)>>2]=M;ta=ja;ua=1;va=W;wa=M}else{ta=ca;ua=da;va=ea;wa=_}}while(0);do{if((L|0)!=0&(W|0)<(A|0)){ja=W+1|0;S=ja+G+(_<<11)|0;T=(_<<3)+ja&63;if((c[(F+(T<<2)|0)>>2]|0)==(S|0)){Ea=ta;Fa=ua;Ga=va;Ha=wa;break}X=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ga=c[(b+12420|0)>>2]|0;na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(X,_)|0)+ja)|0;U=Pe[H&255](b,c[(b+12288+(h<<4)|0)>>2]|0,na,X,8)|0;if((m&2|0)==0){Ia=U;break}na=_<<1&2|ja&1;ka=c[(b+12208|0)>>2]|0;Ba=(ba(ga,_>>1)|0)+(ja>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+(na<<2)>>2]&1023](ka+(X<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+Ba|0,ga,4);cf[c[(c[(b+12444|0)>>2]|0)+32+(na<<2)>>2]&1023](ka+(X<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+Ba|0,ga,4);Ba=(Pe[I&255](b,ka+(X<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ga,4)|0)+U|0;Ia=Ba+(Pe[I&255](b,ka+(X<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ga,4)|0)|0}else{ga=_<<n;if((c[(b+12264|0)>>2]|0)>(ja|0)){Ia=536870912;break}if((ja<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Ia=536870912;break}if((c[(b+12272|0)>>2]|0)>(_|0)){Ia=536870912;break}if((ga|0)>(c[(b+12276|0)>>2]<<n|0)){Ia=536870912;break}ka=e[(b+13872|0)>>1]|0;Ba=e[(b+13874|0)>>1]|0;f:do{if((c[(b+11740|0)>>2]|0)==1){if((ja<<n|0)==0){U=0;while(1){na=c[b+12160+(U<<3)>>2]|0;qa=(c[b+12160+(U<<3)+4>>2]|0)+ga|0;ya=((ba(c[b+12128+(U<<3)>>2]|0,Ba-ka|0)|0)/(ka|0)|0)+((U&1)<<R)|0;ma=c[b+12128+(U<<3)+4>>2]|0;if((ga|0)==0){la=U>>1;Ja=((ba(ma,Ba-ka|0)|0)/(ka|0)|0)+(la<<R)|0;Ka=la}else{Ja=qa-ma|0;Ka=U>>1}ma=((Ja&N)<<n)+(ya&N)|0;la=(c[(b+12208|0)>>2]|0)+((ba(Ka,X<<3)|0)+(U<<3&8))|0;if(O){fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa>>1,X)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((qa&N)<<n)+(na&N)|0)<<2)>>2]&1023](la,fa,X,8);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ja>>1,X)|0)+(ya>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ma<<2)>>2]&1023](la,fa,X,8)}else{fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa>>2,X)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((qa&N)<<n)+(na&N)|0)<<2)>>2]&4095](la,fa,X);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ja>>2,X)|0)+(ya>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](la,fa,X)}U=U+1|0;if((U|0)>=4){break f}}}if((ga|0)==0){U=0;do{fa=(c[b+12160+(U<<3)>>2]|0)+(ja<<n)|0;la=c[b+12160+(U<<3)+4>>2]|0;ma=fa-(c[b+12128+(U<<3)>>2]|0)|0;ya=U>>1;na=((ba(c[b+12128+(U<<3)+4>>2]|0,Ba-ka|0)|0)/(ka|0)|0)+(ya<<R)|0;qa=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(ya,X<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(la>>1,X)|0)+(fa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((la&N)<<n)+(fa&N)|0)<<2)>>2]&1023](qa,ya,X,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>1,X)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&1023](qa,ya,X,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(la>>2,X)|0)+(fa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(fa&N)|0)<<2)>>2]&4095](qa,ya,X);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>2,X)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&4095](qa,ya,X)}U=U+1|0;}while((U|0)<4)}else{U=0;do{ya=(c[b+12160+(U<<3)>>2]|0)+(ja<<n)|0;qa=(c[b+12160+(U<<3)+4>>2]|0)+ga|0;ma=ya-(c[b+12128+(U<<3)>>2]|0)|0;na=qa-(c[b+12128+(U<<3)+4>>2]|0)|0;fa=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(U>>1,X<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa>>1,X)|0)+(ya>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((qa&N)<<n)+(ya&N)|0)<<2)>>2]&1023](fa,la,X,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>1,X)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&1023](fa,la,X,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa>>2,X)|0)+(ya>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((qa&N)<<n)+(ya&N)|0)<<2)>>2]&4095](fa,la,X);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>2,X)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&4095](fa,la,X)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(ja<<n)|0;la=(c[(b+12164|0)>>2]|0)+ga|0;fa=c[(b+12128|0)>>2]|0;if((ja<<n|0)==0){La=(ba(fa,Ba-ka|0)|0)/(ka|0)|0}else{La=U-fa|0}fa=c[(b+12132|0)>>2]|0;if((ga|0)==0){Ma=(ba(fa,Ba-ka|0)|0)/(ka|0)|0}else{Ma=la-fa|0}fa=((Ma&N)<<n)+(La&N)|0;if(O){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(la>>1,X)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((la&N)<<n)+(U&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ma,X,16);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ma>>1,X)|0)+(La>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(fa<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ma,X,16);break}else{ma=(ba(la>>2,X)|0)+(U>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ma|0,X);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+8|0)|0,X);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(X<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+(X<<3))|0,X);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((X<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ma+8|0)+(X<<3))|0,X);ma=(ba(Ma>>2,X)|0)+(La>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ma|0,X);Xe[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+8|0)|0,X);Xe[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(X<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+(X<<3))|0,X);Xe[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((X<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ma+8|0)+(X<<3))|0,X);break}}}while(0);Ia=Pe[H&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,X,16)|0}}while(0);c[(F+(T<<2)|0)>>2]=S;c[x+(T<<2)>>2]=Ia;X=(ba((d[C+((_<<n)-E)|0]|0)+(d[C+((ja<<n)-D)|0]|0)|0,l)|0)+Ia|0;if((X|0)>=(ta|0)){Ea=ta;Fa=ua;Ga=va;Ha=wa;break}c[r>>2]=ja;c[(r+4|0)>>2]=_;Ea=X;Fa=2;Ga=ja;Ha=_}else{Ea=ta;Fa=ua;Ga=va;Ha=wa}}while(0);do{if((L|0)!=1&(_|0)<(B|0)){X=_+1|0;M=W+G+(X<<11)|0;ia=(X<<3)+W&63;if((c[(F+(ia<<2)|0)>>2]|0)==(M|0)){break}V=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ka=c[(b+12420|0)>>2]|0;Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(V,X)|0)+W)|0;ga=Pe[H&255](b,c[(b+12288+(h<<4)|0)>>2]|0,Ba,V,8)|0;if((m&2|0)==0){Na=ga;break}Ba=X<<1&2|W&1;ma=c[(b+12208|0)>>2]|0;fa=(ba(ka,X>>1)|0)+(W>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+(Ba<<2)>>2]&1023](ma+(V<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+fa|0,ka,4);cf[c[(c[(b+12444|0)>>2]|0)+32+(Ba<<2)>>2]&1023](ma+(V<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+fa|0,ka,4);fa=(Pe[I&255](b,ma+(V<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ka,4)|0)+ga|0;Na=fa+(Pe[I&255](b,ma+(V<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ka,4)|0)|0}else{ka=W<<n;if((c[(b+12264|0)>>2]|0)>(W|0)){Na=536870912;break}if((ka|0)>(c[(b+12268|0)>>2]<<n|0)){Na=536870912;break}if((c[(b+12272|0)>>2]|0)>(X|0)){Na=536870912;break}if((X<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Na=536870912;break}ma=e[(b+13872|0)>>1]|0;fa=e[(b+13874|0)>>1]|0;g:do{if((c[(b+11740|0)>>2]|0)==1){if((ka|0)==0){ga=0;while(1){Ba=c[b+12160+(ga<<3)>>2]|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(X<<n)|0;la=((ba(c[b+12128+(ga<<3)>>2]|0,fa-ma|0)|0)/(ma|0)|0)+((ga&1)<<R)|0;na=c[b+12128+(ga<<3)+4>>2]|0;if((X<<n|0)==0){ya=ga>>1;Oa=((ba(na,fa-ma|0)|0)/(ma|0)|0)+(ya<<R)|0;Pa=ya}else{Oa=U-na|0;Pa=ga>>1}na=((Oa&N)<<n)+(la&N)|0;ya=(c[(b+12208|0)>>2]|0)+((ba(Pa,V<<3)|0)+(ga<<3&8))|0;if(O){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,V)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(Ba&N)|0)<<2)>>2]&1023](ya,qa,V,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Oa>>1,V)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(na<<2)>>2]&1023](ya,qa,V,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,V)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(Ba&N)|0)<<2)>>2]&4095](ya,qa,V);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Oa>>2,V)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](ya,qa,V)}ga=ga+1|0;if((ga|0)>=4){break g}}}if((X<<n|0)==0){ga=0;do{qa=(c[b+12160+(ga<<3)>>2]|0)+ka|0;ya=c[b+12160+(ga<<3)+4>>2]|0;na=qa-(c[b+12128+(ga<<3)>>2]|0)|0;la=ga>>1;Ba=((ba(c[b+12128+(ga<<3)+4>>2]|0,fa-ma|0)|0)/(ma|0)|0)+(la<<R)|0;U=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(la,V<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,V)|0)+(qa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&1023](U,la,V,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ba>>1,V)|0)+(na>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&1023](U,la,V,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>2,V)|0)+(qa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095](U,la,V);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ba>>2,V)|0)+(na>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&4095](U,la,V)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{la=(c[b+12160+(ga<<3)>>2]|0)+ka|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(X<<n)|0;na=la-(c[b+12128+(ga<<3)>>2]|0)|0;Ba=U-(c[b+12128+(ga<<3)+4>>2]|0)|0;qa=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(ga>>1,V<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,V)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(la&N)|0)<<2)>>2]&1023](qa,ya,V,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ba>>1,V)|0)+(na>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&1023](qa,ya,V,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,V)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(la&N)|0)<<2)>>2]&4095](qa,ya,V);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ba>>2,V)|0)+(na>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&4095](qa,ya,V)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+ka|0;ya=(c[(b+12164|0)>>2]|0)+(X<<n)|0;qa=c[(b+12128|0)>>2]|0;if((ka|0)==0){Qa=(ba(qa,fa-ma|0)|0)/(ma|0)|0}else{Qa=ga-qa|0}qa=c[(b+12132|0)>>2]|0;if((X<<n|0)==0){Ra=(ba(qa,fa-ma|0)|0)/(ma|0)|0}else{Ra=ya-qa|0}qa=((Ra&N)<<n)+(Qa&N)|0;if(O){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,V)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,na,V,16);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ra>>1,V)|0)+(Qa>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(qa<<2)>>2]&1023](c[(b+12208|0)>>2]|0,na,V,16);break}else{na=(ba(ya>>2,V)|0)+(ga>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+na|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(na+8|0)|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(na+(V<<3))|0,V);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((na+8|0)+(V<<3))|0,V);na=(ba(Ra>>2,V)|0)+(Qa>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+na|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(na+8|0)|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(na+(V<<3))|0,V);Xe[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((na+8|0)+(V<<3))|0,V);break}}}while(0);Na=Pe[H&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,V,16)|0}}while(0);c[(F+(ia<<2)|0)>>2]=M;c[x+(ia<<2)>>2]=Na;V=(ba((d[C+((X<<n)-E)|0]|0)+(d[C+((W<<n)-D)|0]|0)|0,l)|0)+Na|0;if((V|0)>=(Ea|0)){break}c[r>>2]=W;c[(r+4|0)>>2]=X;Q=V;L=3;W=W;_=X;continue c}}while(0);if((Fa|0)==-1){t=Ea;break}else{Q=Ea;L=Fa;W=Ga;_=Ha}}u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}if((s|0)>1024){t=Gmb(b,r,q,h,j,l,1,8,m)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}if((s|0)>768){_=c[(b+12220|0)>>2]|0;W=c[(b+12264|0)>>2]|0;L=c[(b+12272|0)>>2]|0;Q=c[(b+12268|0)>>2]|0;D=c[(b+12276|0)>>2]|0;C=c[(b+12464|0)>>2]|0;E=c[(b+12280|0)>>2]|0;x=c[(b+12284|0)>>2]|0;F=c[(b+12216|0)>>2]|0;H=c[(b+12224|0)>>2]|0;N=c[(b+10472|0)>>2]|0;O=c[(b+10476|0)>>2]|0;R=p-(s&254)+1|0;I=(R|0)>(W|0)?R:W;R=(s&254)-1+p|0;G=(R|0)>(Q|0)?Q:R;if((I|0)>(G|0)){Sa=q;Ta=p;Ua=o}else{R=(o<<11)+H|0;B=o<<3;A=o<<1&2;z=o>>1;y=o<<n;J=(m&1)<<1|1;K=I;I=q;V=p;ja=o;while(1){T=R+K|0;S=K+B&63;do{if((c[(F+(S<<2)|0)>>2]|0)==(T|0)){Va=I;Wa=V;Xa=ja}else{ma=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){fa=c[(b+12420|0)>>2]|0;ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma,o)|0)+K)|0;na=Pe[N&255](b,c[(b+12288+(h<<4)|0)>>2]|0,ka,ma,8)|0;if((m&2|0)==0){Ya=na;break}ka=K&1|A;qa=c[(b+12208|0)>>2]|0;ga=(ba(fa,z)|0)+(K>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+(ka<<2)>>2]&1023](qa+(ma<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ga|0,fa,4);cf[c[(c[(b+12444|0)>>2]|0)+32+(ka<<2)>>2]&1023](qa+(ma<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ga|0,fa,4);ga=(Pe[O&255](b,qa+(ma<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,fa,4)|0)+na|0;Ya=ga+(Pe[O&255](b,qa+(ma<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,fa,4)|0)|0}else{fa=K<<n;if((c[(b+12264|0)>>2]|0)>(K|0)){Ya=536870912;break}if((fa|0)>(c[(b+12268|0)>>2]<<n|0)){Ya=536870912;break}if((c[(b+12272|0)>>2]|0)>(o|0)){Ya=536870912;break}if((y|0)>(c[(b+12276|0)>>2]<<n|0)){Ya=536870912;break}qa=e[(b+13872|0)>>1]|0;ga=e[(b+13874|0)>>1]|0;h:do{if((c[(b+11740|0)>>2]|0)==1){if((fa|0)==0){na=0;while(1){ka=c[b+12160+(na<<3)>>2]|0;ya=(c[b+12160+(na<<3)+4>>2]|0)+y|0;Ba=((ba(c[b+12128+(na<<3)>>2]|0,ga-qa|0)|0)/(qa|0)|0)+((na&1)<<(m&1|4))|0;la=c[b+12128+(na<<3)+4>>2]|0;if((y|0)==0){U=na>>1;Za=((ba(la,ga-qa|0)|0)/(qa|0)|0)+(U<<(m&1|4))|0;_a=U}else{Za=ya-la|0;_a=na>>1}la=((Za&J)<<n)+(Ba&J)|0;U=(c[(b+12208|0)>>2]|0)+((ba(_a,ma<<3)|0)+(na<<3&8))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,ma)|0)+(ka>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&J)<<n)+(ka&J)|0)<<2)>>2]&1023](U,$a,ma,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Za>>1,ma)|0)+(Ba>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&1023](U,$a,ma,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>2,ma)|0)+(ka>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&J)<<n)+(ka&J)|0)<<2)>>2]&4095](U,$a,ma);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Za>>2,ma)|0)+(Ba>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](U,$a,ma)}na=na+1|0;if((na|0)>=4){break h}}}if((y|0)==0){na=0;do{$a=(c[b+12160+(na<<3)>>2]|0)+fa|0;U=c[b+12160+(na<<3)+4>>2]|0;la=$a-(c[b+12128+(na<<3)>>2]|0)|0;Ba=na>>1;ka=((ba(c[b+12128+(na<<3)+4>>2]|0,ga-qa|0)|0)/(qa|0)|0)+(Ba<<(m&1|4))|0;ya=(c[(b+12208|0)>>2]|0)+((na<<3&8)+(ba(Ba,ma<<3)|0))|0;if((m&1|0)==0){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,ma)|0)+($a>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&J)<<n)+($a&J)|0)<<2)>>2]&1023](ya,Ba,ma,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,ma)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&1023](ya,Ba,ma,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,ma)|0)+($a>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+($a&J)|0)<<2)>>2]&4095](ya,Ba,ma);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,ma)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&4095](ya,Ba,ma)}na=na+1|0;}while((na|0)<4)}else{na=0;do{Ba=(c[b+12160+(na<<3)>>2]|0)+fa|0;ya=(c[b+12160+(na<<3)+4>>2]|0)+y|0;la=Ba-(c[b+12128+(na<<3)>>2]|0)|0;ka=ya-(c[b+12128+(na<<3)+4>>2]|0)|0;$a=(c[(b+12208|0)>>2]|0)+((na<<3&8)+(ba(na>>1,ma<<3)|0))|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>1,ma)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&J)<<n)+(Ba&J)|0)<<2)>>2]&1023]($a,U,ma,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,ma)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&1023]($a,U,ma,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ya>>2,ma)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ya&J)<<n)+(Ba&J)|0)<<2)>>2]&4095]($a,U,ma);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,ma)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&4095]($a,U,ma)}na=na+1|0;}while((na|0)<4)}}else{na=(c[(b+12160|0)>>2]|0)+fa|0;U=(c[(b+12164|0)>>2]|0)+y|0;$a=c[(b+12128|0)>>2]|0;if((fa|0)==0){ab=(ba($a,ga-qa|0)|0)/(qa|0)|0}else{ab=na-$a|0}$a=c[(b+12132|0)>>2]|0;if((y|0)==0){bb=(ba($a,ga-qa|0)|0)/(qa|0)|0}else{bb=U-$a|0}$a=((bb&J)<<n)+(ab&J)|0;if((m&1|0)==0){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,ma)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((U&J)<<n)+(na&J)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,ma,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(bb>>1,ma)|0)+(ab>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+($a<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,ma,16);break}else{la=(ba(U>>2,ma)|0)+(na>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(ma<<3))|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(ma<<3))|0,ma);la=(ba(bb>>2,ma)|0)+(ab>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(ma<<3))|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(ma<<3))|0,ma);break}}}while(0);Ya=Pe[N&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(F+(S<<2)|0)>>2]=T;c[_+(S<<2)>>2]=Ya;ma=(ba((d[C+(y-x)|0]|0)+(d[C+((K<<n)-E)|0]|0)|0,l)|0)+Ya|0;if((ma|0)>=(I|0)){Va=I;Wa=V;Xa=ja;break}c[r>>2]=K;c[(r+4|0)>>2]=o;Va=ma;Wa=K;Xa=o}}while(0);S=K+2|0;if((S|0)>(G|0)){Sa=Va;Ta=Wa;Ua=Xa;break}else{K=S;I=Va;V=Wa;ja=Xa}}}ja=o-((s&254)>>>1)+1|0;V=(ja|0)>(L|0)?ja:L;ja=((s&254)>>>1)-1+o|0;I=(ja|0)>(D|0)?D:ja;if((V|0)>(I|0)){cb=Sa;db=Ta;eb=Ua}else{ja=p+H|0;K=p&1;G=p>>1;y=p<<n;J=(m&1)<<1|1;z=V;V=Sa;A=Ta;B=Ua;while(1){R=ja+(z<<11)|0;S=(z<<3)+p&63;do{if((c[(F+(S<<2)|0)>>2]|0)==(R|0)){fb=V;gb=A;hb=B}else{T=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ma=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(T,z)|0)+p)|0;ia=Pe[N&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,T,8)|0;if((m&2|0)==0){ib=ia;break}X=z<<1&2|K;M=c[(b+12208|0)>>2]|0;qa=(ba(ma,z>>1)|0)+G|0;cf[c[(c[(b+12444|0)>>2]|0)+32+(X<<2)>>2]&1023](M+(T<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+qa|0,ma,4);cf[c[(c[(b+12444|0)>>2]|0)+32+(X<<2)>>2]&1023](M+(T<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+qa|0,ma,4);qa=(Pe[O&255](b,M+(T<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ma,4)|0)+ia|0;ib=qa+(Pe[O&255](b,M+(T<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ma,4)|0)|0}else{ma=z<<n;if((c[(b+12264|0)>>2]|0)>(p|0)){ib=536870912;break}if((y|0)>(c[(b+12268|0)>>2]<<n|0)){ib=536870912;break}if((c[(b+12272|0)>>2]|0)>(z|0)){ib=536870912;break}if((ma|0)>(c[(b+12276|0)>>2]<<n|0)){ib=536870912;break}M=e[(b+13872|0)>>1]|0;qa=e[(b+13874|0)>>1]|0;i:do{if((c[(b+11740|0)>>2]|0)==1){if((y|0)==0){ia=0;while(1){X=c[b+12160+(ia<<3)>>2]|0;ga=(c[b+12160+(ia<<3)+4>>2]|0)+ma|0;fa=((ba(c[b+12128+(ia<<3)>>2]|0,qa-M|0)|0)/(M|0)|0)+((ia&1)<<(m&1|4))|0;la=c[b+12128+(ia<<3)+4>>2]|0;if((ma|0)==0){$a=ia>>1;jb=((ba(la,qa-M|0)|0)/(M|0)|0)+($a<<(m&1|4))|0;kb=$a}else{jb=ga-la|0;kb=ia>>1}la=((jb&J)<<n)+(fa&J)|0;$a=(c[(b+12208|0)>>2]|0)+((ba(kb,T<<3)|0)+(ia<<3&8))|0;if((m&1|0)==0){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,T)|0)+(X>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&J)<<n)+(X&J)|0)<<2)>>2]&1023]($a,na,T,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(jb>>1,T)|0)+(fa>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&1023]($a,na,T,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,T)|0)+(X>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&J)<<n)+(X&J)|0)<<2)>>2]&4095]($a,na,T);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(jb>>2,T)|0)+(fa>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]($a,na,T)}ia=ia+1|0;if((ia|0)>=4){break i}}}if((ma|0)==0){ia=0;do{na=(c[b+12160+(ia<<3)>>2]|0)+y|0;$a=c[b+12160+(ia<<3)+4>>2]|0;la=na-(c[b+12128+(ia<<3)>>2]|0)|0;fa=ia>>1;X=((ba(c[b+12128+(ia<<3)+4>>2]|0,qa-M|0)|0)/(M|0)|0)+(fa<<(m&1|4))|0;ga=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ba(fa,T<<3)|0))|0;if((m&1|0)==0){fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>1,T)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(((($a&J)<<n)+(na&J)|0)<<2)>>2]&1023](ga,fa,T,8);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>1,T)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((X&J)<<n)+(la&J)|0)<<2)>>2]&1023](ga,fa,T,8)}else{fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>2,T)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(na&J)|0)<<2)>>2]&4095](ga,fa,T);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>2,T)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((X&J)<<n)+(la&J)|0)<<2)>>2]&4095](ga,fa,T)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{fa=(c[b+12160+(ia<<3)>>2]|0)+y|0;ga=(c[b+12160+(ia<<3)+4>>2]|0)+ma|0;la=fa-(c[b+12128+(ia<<3)>>2]|0)|0;X=ga-(c[b+12128+(ia<<3)+4>>2]|0)|0;na=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ba(ia>>1,T<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,T)|0)+(fa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&J)<<n)+(fa&J)|0)<<2)>>2]&1023](na,$a,T,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>1,T)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((X&J)<<n)+(la&J)|0)<<2)>>2]&1023](na,$a,T,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,T)|0)+(fa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&J)<<n)+(fa&J)|0)<<2)>>2]&4095](na,$a,T);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>2,T)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((X&J)<<n)+(la&J)|0)<<2)>>2]&4095](na,$a,T)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[(b+12160|0)>>2]|0)+y|0;$a=(c[(b+12164|0)>>2]|0)+ma|0;na=c[(b+12128|0)>>2]|0;if((y|0)==0){lb=(ba(na,qa-M|0)|0)/(M|0)|0}else{lb=ia-na|0}na=c[(b+12132|0)>>2]|0;if((ma|0)==0){mb=(ba(na,qa-M|0)|0)/(M|0)|0}else{mb=$a-na|0}na=((mb&J)<<n)+(lb&J)|0;if((m&1|0)==0){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>1,T)|0)+(ia>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,T,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(mb>>1,T)|0)+(lb>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(na<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,T,16);break}else{la=(ba($a>>2,T)|0)+(ia>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,T);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,T);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(T<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(T<<3))|0,T);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(T<<3))|0,T);la=(ba(mb>>2,T)|0)+(lb>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,T);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,T);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(T<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(T<<3))|0,T);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(T<<3))|0,T);break}}}while(0);ib=Pe[N&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,T,16)|0}}while(0);c[(F+(S<<2)|0)>>2]=R;c[_+(S<<2)>>2]=ib;T=(ba((d[C+((z<<n)-x)|0]|0)+(d[C+(y-E)|0]|0)|0,l)|0)+ib|0;if((T|0)>=(V|0)){fb=V;gb=A;hb=B;break}c[r>>2]=p;c[(r+4|0)>>2]=z;fb=T;gb=p;hb=z}}while(0);S=z+2|0;if((S|0)>(I|0)){cb=fb;db=gb;eb=hb;break}else{z=S;V=fb;A=gb;B=hb}}}B=eb-2|0;A=(B|0)>(L|0)?B:L;B=eb+2|0;V=(B|0)>(D|0)?D:B;if((A|0)>(V|0)){nb=cb}else{B=db-2|0;z=(B|0)>(W|0)?B:W;B=db+2|0;I=(B|0)>(Q|0)?Q:B;B=(m&1)<<1|1;y=A;A=cb;while(1){if((z|0)>(I|0)){ob=A}else{J=(y<<11)+H|0;G=y<<3;K=y<<1&2;ja=y>>1;S=y<<n;R=z;T=A;while(1){M=J+R|0;qa=R+G&63;do{if((c[(F+(qa<<2)|0)>>2]|0)==(M|0)){pb=T}else{ma=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){la=c[(b+12420|0)>>2]|0;na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma,y)|0)+R)|0;ia=Pe[N&255](b,c[(b+12288+(h<<4)|0)>>2]|0,na,ma,8)|0;if((m&2|0)==0){qb=ia;break}na=R&1|K;$a=c[(b+12208|0)>>2]|0;X=(ba(la,ja)|0)+(R>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+(na<<2)>>2]&1023]($a+(ma<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+X|0,la,4);cf[c[(c[(b+12444|0)>>2]|0)+32+(na<<2)>>2]&1023]($a+(ma<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+X|0,la,4);X=(Pe[O&255](b,$a+(ma<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,la,4)|0)+ia|0;qb=X+(Pe[O&255](b,$a+(ma<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,la,4)|0)|0}else{la=R<<n;if((c[(b+12264|0)>>2]|0)>(R|0)){qb=536870912;break}if((la|0)>(c[(b+12268|0)>>2]<<n|0)){qb=536870912;break}if((c[(b+12272|0)>>2]|0)>(y|0)){qb=536870912;break}if((S|0)>(c[(b+12276|0)>>2]<<n|0)){qb=536870912;break}$a=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;j:do{if((c[(b+11740|0)>>2]|0)==1){if((la|0)==0){ia=0;while(1){na=c[b+12160+(ia<<3)>>2]|0;fa=(c[b+12160+(ia<<3)+4>>2]|0)+S|0;ga=((ba(c[b+12128+(ia<<3)>>2]|0,X-$a|0)|0)/($a|0)|0)+((ia&1)<<(m&1|4))|0;U=c[b+12128+(ia<<3)+4>>2]|0;if((S|0)==0){ka=ia>>1;rb=((ba(U,X-$a|0)|0)/($a|0)|0)+(ka<<(m&1|4))|0;sb=ka}else{rb=fa-U|0;sb=ia>>1}U=((rb&B)<<n)+(ga&B)|0;ka=(c[(b+12208|0)>>2]|0)+((ba(sb,ma<<3)|0)+(ia<<3&8))|0;if((m&1|0)==0){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>1,ma)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&B)<<n)+(na&B)|0)<<2)>>2]&1023](ka,Ba,ma,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(rb>>1,ma)|0)+(ga>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(U<<2)>>2]&1023](ka,Ba,ma,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>2,ma)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((fa&B)<<n)+(na&B)|0)<<2)>>2]&4095](ka,Ba,ma);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(rb>>2,ma)|0)+(ga>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](ka,Ba,ma)}ia=ia+1|0;if((ia|0)>=4){break j}}}if((S|0)==0){ia=0;do{Ba=(c[b+12160+(ia<<3)>>2]|0)+la|0;ka=c[b+12160+(ia<<3)+4>>2]|0;U=Ba-(c[b+12128+(ia<<3)>>2]|0)|0;ga=ia>>1;na=((ba(c[b+12128+(ia<<3)+4>>2]|0,X-$a|0)|0)/($a|0)|0)+(ga<<(m&1|4))|0;fa=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ba(ga,ma<<3)|0))|0;if((m&1|0)==0){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,ma)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&B)<<n)+(Ba&B)|0)<<2)>>2]&1023](fa,ga,ma,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>1,ma)|0)+(U>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((na&B)<<n)+(U&B)|0)<<2)>>2]&1023](fa,ga,ma,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>2,ma)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(Ba&B)|0)<<2)>>2]&4095](fa,ga,ma);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>2,ma)|0)+(U>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((na&B)<<n)+(U&B)|0)<<2)>>2]&4095](fa,ga,ma)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{ga=(c[b+12160+(ia<<3)>>2]|0)+la|0;fa=(c[b+12160+(ia<<3)+4>>2]|0)+S|0;U=ga-(c[b+12128+(ia<<3)>>2]|0)|0;na=fa-(c[b+12128+(ia<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ba(ia>>1,ma<<3)|0))|0;if((m&1|0)==0){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>1,ma)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&B)<<n)+(ga&B)|0)<<2)>>2]&1023](Ba,ka,ma,8);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>1,ma)|0)+(U>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((na&B)<<n)+(U&B)|0)<<2)>>2]&1023](Ba,ka,ma,8)}else{ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(fa>>2,ma)|0)+(ga>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((fa&B)<<n)+(ga&B)|0)<<2)>>2]&4095](Ba,ka,ma);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(na>>2,ma)|0)+(U>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((na&B)<<n)+(U&B)|0)<<2)>>2]&4095](Ba,ka,ma)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[(b+12160|0)>>2]|0)+la|0;ka=(c[(b+12164|0)>>2]|0)+S|0;Ba=c[(b+12128|0)>>2]|0;if((la|0)==0){tb=(ba(Ba,X-$a|0)|0)/($a|0)|0}else{tb=ia-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((S|0)==0){ub=(ba(Ba,X-$a|0)|0)/($a|0)|0}else{ub=ka-Ba|0}Ba=((ub&B)<<n)+(tb&B)|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,ma)|0)+(ia>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,U,ma,16);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ub>>1,ma)|0)+(tb>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&1023](c[(b+12208|0)>>2]|0,U,ma,16);break}else{U=(ba(ka>>2,ma)|0)+(ia>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+U|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(U+8|0)|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(U+(ma<<3))|0,ma);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((U+8|0)+(ma<<3))|0,ma);U=(ba(ub>>2,ma)|0)+(tb>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+U|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(U+8|0)|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(U+(ma<<3))|0,ma);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((U+8|0)+(ma<<3))|0,ma);break}}}while(0);qb=Pe[N&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(F+(qa<<2)|0)>>2]=M;c[_+(qa<<2)>>2]=qb;ma=(ba((d[C+(S-x)|0]|0)+(d[C+((R<<n)-E)|0]|0)|0,l)|0)+qb|0;if((ma|0)>=(T|0)){pb=T;break}c[r>>2]=R;c[(r+4|0)>>2]=y;pb=ma}}while(0);qa=R+1|0;if((qa|0)>(I|0)){ob=pb;break}else{R=qa;T=pb}}}T=y+1|0;if((T|0)>(V|0)){nb=ob;break}else{y=T;A=ob}}}if(((s&254)>>>2|0)==0){vb=nb}else{A=(m&1)<<1|1;y=1;V=nb;while(1){I=0;B=V;while(1){z=(ba(c[163152+(I<<3)>>2]|0,y)|0)+db|0;T=(ba(c[163156+(I<<3)>>2]|0,y)|0)+eb|0;R=(z|0)>(Q|0)?Q:z;z=(W|0)>(R|0)?W:R;R=(T|0)>(D|0)?D:T;T=(L|0)>(R|0)?L:R;do{if((c[(F+(((T<<3)+z&63)<<2)|0)>>2]|0)==(z+H+(T<<11)|0|0)){wb=B}else{R=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){S=c[(b+12420|0)>>2]|0;ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(R,T)|0)+z)|0;K=Pe[N&255](b,c[(b+12288+(h<<4)|0)>>2]|0,ja,R,8)|0;if((m&2|0)==0){xb=K;break}ja=c[(b+12208|0)>>2]|0;G=(ba(S,T>>1)|0)+(z>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((T<<1&2|z&1)<<2)>>2]&1023](ja+(R<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+G|0,S,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((T<<1&2|z&1)<<2)>>2]&1023](ja+(R<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+G|0,S,4);G=(Pe[O&255](b,ja+(R<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,S,4)|0)+K|0;xb=G+(Pe[O&255](b,ja+(R<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,S,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(z|0)){xb=536870912;break}if((z<<n|0)>(c[(b+12268|0)>>2]<<n|0)){xb=536870912;break}if((c[(b+12272|0)>>2]|0)>(T|0)){xb=536870912;break}if((T<<n|0)>(c[(b+12276|0)>>2]<<n|0)){xb=536870912;break}S=e[(b+13872|0)>>1]|0;ja=e[(b+13874|0)>>1]|0;k:do{if((c[(b+11740|0)>>2]|0)==1){if((z<<n|0)==0){G=0;while(1){K=c[b+12160+(G<<3)>>2]|0;J=(c[b+12160+(G<<3)+4>>2]|0)+(T<<n)|0;qa=((ba(c[b+12128+(G<<3)>>2]|0,ja-S|0)|0)/(S|0)|0)+((G&1)<<(m&1|4))|0;M=c[b+12128+(G<<3)+4>>2]|0;if((T<<n|0)==0){ma=G>>1;yb=((ba(M,ja-S|0)|0)/(S|0)|0)+(ma<<(m&1|4))|0;zb=ma}else{yb=J-M|0;zb=G>>1}M=((yb&A)<<n)+(qa&A)|0;ma=(c[(b+12208|0)>>2]|0)+((ba(zb,R<<3)|0)+(G<<3&8))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(J>>1,R)|0)+(K>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((J&A)<<n)+(K&A)|0)<<2)>>2]&1023](ma,$a,R,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(yb>>1,R)|0)+(qa>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(M<<2)>>2]&1023](ma,$a,R,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(J>>2,R)|0)+(K>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((J&A)<<n)+(K&A)|0)<<2)>>2]&4095](ma,$a,R);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(yb>>2,R)|0)+(qa>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(M<<2)>>2]&4095](ma,$a,R)}G=G+1|0;if((G|0)>=4){break k}}}if((T<<n|0)==0){G=0;do{$a=(c[b+12160+(G<<3)>>2]|0)+(z<<n)|0;ma=c[b+12160+(G<<3)+4>>2]|0;M=$a-(c[b+12128+(G<<3)>>2]|0)|0;qa=G>>1;K=((ba(c[b+12128+(G<<3)+4>>2]|0,ja-S|0)|0)/(S|0)|0)+(qa<<(m&1|4))|0;J=(c[(b+12208|0)>>2]|0)+((G<<3&8)+(ba(qa,R<<3)|0))|0;if((m&1|0)==0){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,R)|0)+($a>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&A)<<n)+($a&A)|0)<<2)>>2]&1023](J,qa,R,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,R)|0)+(M>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&A)<<n)+(M&A)|0)<<2)>>2]&1023](J,qa,R,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>2,R)|0)+($a>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+($a&A)|0)<<2)>>2]&4095](J,qa,R);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,R)|0)+(M>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&A)<<n)+(M&A)|0)<<2)>>2]&4095](J,qa,R)}G=G+1|0;}while((G|0)<4)}else{G=0;do{qa=(c[b+12160+(G<<3)>>2]|0)+(z<<n)|0;J=(c[b+12160+(G<<3)+4>>2]|0)+(T<<n)|0;M=qa-(c[b+12128+(G<<3)>>2]|0)|0;K=J-(c[b+12128+(G<<3)+4>>2]|0)|0;$a=(c[(b+12208|0)>>2]|0)+((G<<3&8)+(ba(G>>1,R<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(J>>1,R)|0)+(qa>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((J&A)<<n)+(qa&A)|0)<<2)>>2]&1023]($a,ma,R,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,R)|0)+(M>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&A)<<n)+(M&A)|0)<<2)>>2]&1023]($a,ma,R,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(J>>2,R)|0)+(qa>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((J&A)<<n)+(qa&A)|0)<<2)>>2]&4095]($a,ma,R);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,R)|0)+(M>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&A)<<n)+(M&A)|0)<<2)>>2]&4095]($a,ma,R)}G=G+1|0;}while((G|0)<4)}}else{G=(c[(b+12160|0)>>2]|0)+(z<<n)|0;ma=(c[(b+12164|0)>>2]|0)+(T<<n)|0;$a=c[(b+12128|0)>>2]|0;if((z<<n|0)==0){Ab=(ba($a,ja-S|0)|0)/(S|0)|0}else{Ab=G-$a|0}$a=c[(b+12132|0)>>2]|0;if((T<<n|0)==0){Bb=(ba($a,ja-S|0)|0)/(S|0)|0}else{Bb=ma-$a|0}$a=((Bb&A)<<n)+(Ab&A)|0;if((m&1|0)==0){M=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,R)|0)+(G>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,M,R,16);M=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Bb>>1,R)|0)+(Ab>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+($a<<2)>>2]&1023](c[(b+12208|0)>>2]|0,M,R,16);break}else{M=(ba(ma>>2,R)|0)+(G>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+M|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(M+8|0)|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(M+(R<<3))|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((M+8|0)+(R<<3))|0,R);M=(ba(Bb>>2,R)|0)+(Ab>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+M|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(M+8|0)|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(M+(R<<3))|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((M+8|0)+(R<<3))|0,R);break}}}while(0);xb=Pe[N&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,R,16)|0}}while(0);c[(F+(((T<<3)+z&63)<<2)|0)>>2]=z+H+(T<<11)|0;c[_+(((T<<3)+z&63)<<2)>>2]=xb;R=(ba((d[C+((T<<n)-x)|0]|0)+(d[C+((z<<n)-E)|0]|0)|0,l)|0)+xb|0;if((R|0)>=(B|0)){wb=B;break}c[r>>2]=z;c[(r+4|0)>>2]=T;wb=R}}while(0);T=I+1|0;if((T|0)<16){I=T;B=wb}else{break}}B=y+1|0;if((B|0)>((s&254)>>>2|0)){vb=wb;break}else{y=B;V=wb}}}t=Hmb(b,r,vb,h,j,l,1,8,m,2)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}if((s|0)>512){t=Hmb(b,r,q,h,j,l,1,8,m,s&255)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}V=c[(b+12220|0)>>2]|0;y=c[(b+12264|0)>>2]|0;E=c[(b+12272|0)>>2]|0;C=c[(b+12268|0)>>2]|0;x=c[(b+12276|0)>>2]|0;_=c[(b+12464|0)>>2]|0;H=c[(b+12280|0)>>2]|0;F=c[(b+12284|0)>>2]|0;N=c[(b+12216|0)>>2]|0;A=c[(b+12224|0)>>2]|0;if((s|0)<=256){O=c[(b+10472|0)>>2]|0;L=c[(b+10476|0)>>2]|0;D=(m&1)<<1|1;W=m&1|4;Q=(m&1|0)==0;B=1;I=q;T=p;z=o;while(1){R=z+B|0;S=(R-x|0|0)<0?0:R-x|0;ja=C-T+1|0;M=(B|0)>(ja|0)?ja:B;if((S|0)<(M|0)){ja=S;S=I;$a=z;G=T;while(1){ma=R-ja|0;K=ja+T|0;do{if((c[(N+(((ma<<3)+K&63)<<2)|0)>>2]|0)==(K+A+(ma<<11)|0|0)){Cb=S;Db=$a;Eb=G}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa,ma)|0)+K)|0;la=Pe[O&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){Fb=la;break}X=c[(b+12208|0)>>2]|0;U=(ba(J,ma>>1)|0)+(K>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|K&1)<<2)>>2]&1023](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+U|0,J,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|K&1)<<2)>>2]&1023](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+U|0,J,4);U=(Pe[L&255](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+la|0;Fb=U+(Pe[L&255](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(K|0)){Fb=536870912;break}if((K<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Fb=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){Fb=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Fb=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;l:do{if((c[(b+11740|0)>>2]|0)==1){if((K<<n|0)==0){U=0;while(1){la=c[b+12160+(U<<3)>>2]|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(ma<<n)|0;ia=((ba(c[b+12128+(U<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((U&1)<<W)|0;ka=c[b+12128+(U<<3)+4>>2]|0;if((ma<<n|0)==0){na=U>>1;Gb=((ba(ka,X-J|0)|0)/(J|0)|0)+(na<<W)|0;Hb=na}else{Gb=Ba-ka|0;Hb=U>>1}ka=((Gb&D)<<n)+(ia&D)|0;na=(c[(b+12208|0)>>2]|0)+((ba(Hb,qa<<3)|0)+(U<<3&8))|0;if(Q){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(la&D)|0)<<2)>>2]&1023](na,ga,qa,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Gb>>1,qa)|0)+(ia>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&1023](na,ga,qa,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(la&D)|0)<<2)>>2]&4095](na,ga,qa);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Gb>>2,qa)|0)+(ia>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](na,ga,qa)}U=U+1|0;if((U|0)>=4){break l}}}if((ma<<n|0)==0){U=0;do{ga=(c[b+12160+(U<<3)>>2]|0)+(K<<n)|0;na=c[b+12160+(U<<3)+4>>2]|0;ka=ga-(c[b+12128+(U<<3)>>2]|0)|0;ia=U>>1;la=((ba(c[b+12128+(U<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;Ba=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(ia,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,qa)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((na&D)<<n)+(ga&D)|0)<<2)>>2]&1023](Ba,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&1023](Ba,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>2,qa)|0)+(ga>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(ga&D)|0)<<2)>>2]&4095](Ba,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](Ba,ia,qa)}U=U+1|0;}while((U|0)<4)}else{U=0;do{ia=(c[b+12160+(U<<3)>>2]|0)+(K<<n)|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(ma<<n)|0;ka=ia-(c[b+12128+(U<<3)>>2]|0)|0;la=Ba-(c[b+12128+(U<<3)+4>>2]|0)|0;ga=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(U>>1,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>1,qa)|0)+(ia>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(ia&D)|0)<<2)>>2]&1023](ga,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&1023](ga,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>2,qa)|0)+(ia>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(ia&D)|0)<<2)>>2]&4095](ga,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ga,na,qa)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(K<<n)|0;na=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;ga=c[(b+12128|0)>>2]|0;if((K<<n|0)==0){Ib=(ba(ga,X-J|0)|0)/(J|0)|0}else{Ib=U-ga|0}ga=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){Jb=(ba(ga,X-J|0)|0)/(J|0)|0}else{Jb=na-ga|0}ga=((Jb&D)<<n)+(Ib&D)|0;if(Q){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,qa)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((na&D)<<n)+(U&D)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,qa,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Jb>>1,qa)|0)+(Ib>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(ga<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,qa,16);break}else{ka=(ba(na>>2,qa)|0)+(U>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(qa<<3))|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);ka=(ba(Jb>>2,qa)|0)+(Ib>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(qa<<3))|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);break}}}while(0);Fb=Pe[O&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((ma<<3)+K&63)<<2)|0)>>2]=K+A+(ma<<11)|0;c[V+(((ma<<3)+K&63)<<2)>>2]=Fb;qa=(ba((d[_+((ma<<n)-F)|0]|0)+(d[_+((K<<n)-H)|0]|0)|0,l)|0)+Fb|0;if((qa|0)>=(S|0)){Cb=S;Db=$a;Eb=G;break}c[r>>2]=K;c[(r+4|0)>>2]=ma;Cb=qa;Db=ma;Eb=K}}while(0);K=ja+1|0;if((K|0)<(M|0)){ja=K;S=Cb;$a=Db;G=Eb}else{Kb=Cb;Lb=Db;Mb=Eb;break}}}else{Kb=I;Lb=z;Mb=T}G=B+T|0;$a=(G-C|0|0)<0?0:G-C|0;S=z-E+1|0;ja=(B|0)>(S|0)?S:B;if(($a|0)<(ja|0)){S=$a;$a=Kb;M=Lb;R=Mb;while(1){K=z-S|0;ma=G-S|0;do{if((c[(N+(((K<<3)+ma&63)<<2)|0)>>2]|0)==(ma+A+(K<<11)|0|0)){Nb=$a;Ob=M;Pb=R}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa,K)|0)+ma)|0;ka=Pe[O&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){Qb=ka;break}X=c[(b+12208|0)>>2]|0;ga=(ba(J,K>>1)|0)+(ma>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((K<<1&2|ma&1)<<2)>>2]&1023](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ga|0,J,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((K<<1&2|ma&1)<<2)>>2]&1023](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ga|0,J,4);ga=(Pe[L&255](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+ka|0;Qb=ga+(Pe[L&255](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(ma|0)){Qb=536870912;break}if((ma<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Qb=536870912;break}if((c[(b+12272|0)>>2]|0)>(K|0)){Qb=536870912;break}if((K<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Qb=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;m:do{if((c[(b+11740|0)>>2]|0)==1){if((ma<<n|0)==0){ga=0;while(1){ka=c[b+12160+(ga<<3)>>2]|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(K<<n)|0;na=((ba(c[b+12128+(ga<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((ga&1)<<W)|0;la=c[b+12128+(ga<<3)+4>>2]|0;if((K<<n|0)==0){ia=ga>>1;Rb=((ba(la,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;Sb=ia}else{Rb=U-la|0;Sb=ga>>1}la=((Rb&D)<<n)+(na&D)|0;ia=(c[(b+12208|0)>>2]|0)+((ba(Sb,qa<<3)|0)+(ga<<3&8))|0;if(Q){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&D)<<n)+(ka&D)|0)<<2)>>2]&1023](ia,Ba,qa,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Rb>>1,qa)|0)+(na>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&1023](ia,Ba,qa,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ia,Ba,qa);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Rb>>2,qa)|0)+(na>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](ia,Ba,qa)}ga=ga+1|0;if((ga|0)>=4){break m}}}if((K<<n|0)==0){ga=0;do{Ba=(c[b+12160+(ga<<3)>>2]|0)+(ma<<n)|0;ia=c[b+12160+(ga<<3)+4>>2]|0;la=Ba-(c[b+12128+(ga<<3)>>2]|0)|0;na=ga>>1;ka=((ba(c[b+12128+(ga<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(na<<W)|0;U=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(na,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>1,qa)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ia&D)<<n)+(Ba&D)|0)<<2)>>2]&1023](U,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&1023](U,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>2,qa)|0)+(Ba>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(Ba&D)|0)<<2)>>2]&4095](U,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](U,na,qa)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{na=(c[b+12160+(ga<<3)>>2]|0)+(ma<<n)|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(K<<n)|0;la=na-(c[b+12128+(ga<<3)>>2]|0)|0;ka=U-(c[b+12128+(ga<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ba(ga>>1,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>1,qa)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((U&D)<<n)+(na&D)|0)<<2)>>2]&1023](Ba,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&1023](Ba,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(U>>2,qa)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((U&D)<<n)+(na&D)|0)<<2)>>2]&4095](Ba,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](Ba,ia,qa)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+(ma<<n)|0;ia=(c[(b+12164|0)>>2]|0)+(K<<n)|0;Ba=c[(b+12128|0)>>2]|0;if((ma<<n|0)==0){Tb=(ba(Ba,X-J|0)|0)/(J|0)|0}else{Tb=ga-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((K<<n|0)==0){Ub=(ba(Ba,X-J|0)|0)/(J|0)|0}else{Ub=ia-Ba|0}Ba=((Ub&D)<<n)+(Tb&D)|0;if(Q){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>1,qa)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,qa,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Ub>>1,qa)|0)+(Tb>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,qa,16);break}else{la=(ba(ia>>2,qa)|0)+(ga>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(qa<<3))|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);la=(ba(Ub>>2,qa)|0)+(Tb>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(qa<<3))|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);break}}}while(0);Qb=Pe[O&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((K<<3)+ma&63)<<2)|0)>>2]=ma+A+(K<<11)|0;c[V+(((K<<3)+ma&63)<<2)>>2]=Qb;qa=(ba((d[_+((K<<n)-F)|0]|0)+(d[_+((ma<<n)-H)|0]|0)|0,l)|0)+Qb|0;if((qa|0)>=($a|0)){Nb=$a;Ob=M;Pb=R;break}c[r>>2]=ma;c[(r+4|0)>>2]=K;Nb=qa;Ob=K;Pb=ma}}while(0);ma=S+1|0;if((ma|0)<(ja|0)){S=ma;$a=Nb;M=Ob;R=Pb}else{Vb=Nb;Wb=Ob;Xb=Pb;break}}}else{Vb=Kb;Wb=Lb;Xb=Mb}R=B-z+E|0;M=(R|0)<0?0:R;R=T-y+1|0;$a=(B|0)>(R|0)?R:B;if((M|0)<($a|0)){R=z-B|0;S=M;M=Vb;ja=Wb;G=Xb;while(1){ma=S+R|0;K=T-S|0;do{if((c[(N+(((ma<<3)+K&63)<<2)|0)>>2]|0)==(K+A+(ma<<11)|0|0)){Yb=M;Zb=ja;_b=G}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa,ma)|0)+K)|0;la=Pe[O&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){$b=la;break}X=c[(b+12208|0)>>2]|0;Ba=(ba(J,ma>>1)|0)+(K>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|K&1)<<2)>>2]&1023](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+Ba|0,J,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|K&1)<<2)>>2]&1023](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+Ba|0,J,4);Ba=(Pe[L&255](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+la|0;$b=Ba+(Pe[L&255](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(K|0)){$b=536870912;break}if((K<<n|0)>(c[(b+12268|0)>>2]<<n|0)){$b=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){$b=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){$b=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;n:do{if((c[(b+11740|0)>>2]|0)==1){if((K<<n|0)==0){Ba=0;while(1){la=c[b+12160+(Ba<<3)>>2]|0;ga=(c[b+12160+(Ba<<3)+4>>2]|0)+(ma<<n)|0;ia=((ba(c[b+12128+(Ba<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((Ba&1)<<W)|0;ka=c[b+12128+(Ba<<3)+4>>2]|0;if((ma<<n|0)==0){na=Ba>>1;ac=((ba(ka,X-J|0)|0)/(J|0)|0)+(na<<W)|0;bc=na}else{ac=ga-ka|0;bc=Ba>>1}ka=((ac&D)<<n)+(ia&D)|0;na=(c[(b+12208|0)>>2]|0)+((ba(bc,qa<<3)|0)+(Ba<<3&8))|0;if(Q){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&D)<<n)+(la&D)|0)<<2)>>2]&1023](na,U,qa,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ac>>1,qa)|0)+(ia>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&1023](na,U,qa,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&D)<<n)+(la&D)|0)<<2)>>2]&4095](na,U,qa);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ac>>2,qa)|0)+(ia>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](na,U,qa)}Ba=Ba+1|0;if((Ba|0)>=4){break n}}}if((ma<<n|0)==0){Ba=0;do{U=(c[b+12160+(Ba<<3)>>2]|0)+(K<<n)|0;na=c[b+12160+(Ba<<3)+4>>2]|0;ka=U-(c[b+12128+(Ba<<3)>>2]|0)|0;ia=Ba>>1;la=((ba(c[b+12128+(Ba<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;ga=(c[(b+12208|0)>>2]|0)+((Ba<<3&8)+(ba(ia,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,qa)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((na&D)<<n)+(U&D)|0)<<2)>>2]&1023](ga,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&1023](ga,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>2,qa)|0)+(U>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095](ga,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ga,ia,qa)}Ba=Ba+1|0;}while((Ba|0)<4)}else{Ba=0;do{ia=(c[b+12160+(Ba<<3)>>2]|0)+(K<<n)|0;ga=(c[b+12160+(Ba<<3)+4>>2]|0)+(ma<<n)|0;ka=ia-(c[b+12128+(Ba<<3)>>2]|0)|0;la=ga-(c[b+12128+(Ba<<3)+4>>2]|0)|0;U=(c[(b+12208|0)>>2]|0)+((Ba<<3&8)+(ba(Ba>>1,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,qa)|0)+(ia>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&D)<<n)+(ia&D)|0)<<2)>>2]&1023](U,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&1023](U,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,qa)|0)+(ia>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&D)<<n)+(ia&D)|0)<<2)>>2]&4095](U,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(la>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](U,na,qa)}Ba=Ba+1|0;}while((Ba|0)<4)}}else{Ba=(c[(b+12160|0)>>2]|0)+(K<<n)|0;na=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;U=c[(b+12128|0)>>2]|0;if((K<<n|0)==0){cc=(ba(U,X-J|0)|0)/(J|0)|0}else{cc=Ba-U|0}U=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){dc=(ba(U,X-J|0)|0)/(J|0)|0}else{dc=na-U|0}U=((dc&D)<<n)+(cc&D)|0;if(Q){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(na>>1,qa)|0)+(Ba>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,qa,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(dc>>1,qa)|0)+(cc>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(U<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ka,qa,16);break}else{ka=(ba(na>>2,qa)|0)+(Ba>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(qa<<3))|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);ka=(ba(dc>>2,qa)|0)+(cc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(qa<<3))|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);break}}}while(0);$b=Pe[O&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((ma<<3)+K&63)<<2)|0)>>2]=K+A+(ma<<11)|0;c[V+(((ma<<3)+K&63)<<2)>>2]=$b;qa=(ba((d[_+((ma<<n)-F)|0]|0)+(d[_+((K<<n)-H)|0]|0)|0,l)|0)+$b|0;if((qa|0)>=(M|0)){Yb=M;Zb=ja;_b=G;break}c[r>>2]=K;c[(r+4|0)>>2]=ma;Yb=qa;Zb=ma;_b=K}}while(0);K=S+1|0;if((K|0)<($a|0)){S=K;M=Yb;ja=Zb;G=_b}else{ec=Yb;fc=Zb;gc=_b;break}}}else{ec=Vb;fc=Wb;gc=Xb}G=B-T+y|0;ja=(G|0)<0?0:G;G=x-z+1|0;M=(B|0)>(G|0)?G:B;if((ja|0)<(M|0)){G=T-B|0;S=ja;ja=ec;$a=fc;R=gc;while(1){K=S+z|0;ma=S+G|0;do{if((c[(N+(((K<<3)+ma&63)<<2)|0)>>2]|0)==(ma+A+(K<<11)|0|0)){hc=ja;ic=$a;jc=R}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(qa,K)|0)+ma)|0;ka=Pe[O&255](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){kc=ka;break}X=c[(b+12208|0)>>2]|0;U=(ba(J,K>>1)|0)+(ma>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((K<<1&2|ma&1)<<2)>>2]&1023](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+U|0,J,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((K<<1&2|ma&1)<<2)>>2]&1023](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+U|0,J,4);U=(Pe[L&255](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+ka|0;kc=U+(Pe[L&255](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(ma|0)){kc=536870912;break}if((ma<<n|0)>(c[(b+12268|0)>>2]<<n|0)){kc=536870912;break}if((c[(b+12272|0)>>2]|0)>(K|0)){kc=536870912;break}if((K<<n|0)>(c[(b+12276|0)>>2]<<n|0)){kc=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;o:do{if((c[(b+11740|0)>>2]|0)==1){if((ma<<n|0)==0){U=0;while(1){ka=c[b+12160+(U<<3)>>2]|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(K<<n)|0;na=((ba(c[b+12128+(U<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((U&1)<<W)|0;la=c[b+12128+(U<<3)+4>>2]|0;if((K<<n|0)==0){ia=U>>1;lc=((ba(la,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;mc=ia}else{lc=Ba-la|0;mc=U>>1}la=((lc&D)<<n)+(na&D)|0;ia=(c[(b+12208|0)>>2]|0)+((ba(mc,qa<<3)|0)+(U<<3&8))|0;if(Q){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>1,qa)|0)+(ka>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(ka&D)|0)<<2)>>2]&1023](ia,ga,qa,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(lc>>1,qa)|0)+(na>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&1023](ia,ga,qa,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>2,qa)|0)+(ka>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ia,ga,qa);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(lc>>2,qa)|0)+(na>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](ia,ga,qa)}U=U+1|0;if((U|0)>=4){break o}}}if((K<<n|0)==0){U=0;do{ga=(c[b+12160+(U<<3)>>2]|0)+(ma<<n)|0;ia=c[b+12160+(U<<3)+4>>2]|0;la=ga-(c[b+12128+(U<<3)>>2]|0)|0;na=U>>1;ka=((ba(c[b+12128+(U<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(na<<W)|0;Ba=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(na,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>1,qa)|0)+(ga>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&1023](Ba,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&1023](Ba,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>2,qa)|0)+(ga>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095](Ba,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](Ba,na,qa)}U=U+1|0;}while((U|0)<4)}else{U=0;do{na=(c[b+12160+(U<<3)>>2]|0)+(ma<<n)|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(K<<n)|0;la=na-(c[b+12128+(U<<3)>>2]|0)|0;ka=Ba-(c[b+12128+(U<<3)+4>>2]|0)|0;ga=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ba(U>>1,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>1,qa)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(na&D)|0)<<2)>>2]&1023](ga,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>1,qa)|0)+(la>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&1023](ga,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(Ba>>2,qa)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(na&D)|0)<<2)>>2]&4095](ga,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ka>>2,qa)|0)+(la>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](ga,ia,qa)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(ma<<n)|0;ia=(c[(b+12164|0)>>2]|0)+(K<<n)|0;ga=c[(b+12128|0)>>2]|0;if((ma<<n|0)==0){nc=(ba(ga,X-J|0)|0)/(J|0)|0}else{nc=U-ga|0}ga=c[(b+12132|0)>>2]|0;if((K<<n|0)==0){oc=(ba(ga,X-J|0)|0)/(J|0)|0}else{oc=ia-ga|0}ga=((oc&D)<<n)+(nc&D)|0;if(Q){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ia>>1,qa)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,qa,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(oc>>1,qa)|0)+(nc>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(ga<<2)>>2]&1023](c[(b+12208|0)>>2]|0,la,qa,16);break}else{la=(ba(ia>>2,qa)|0)+(U>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(qa<<3))|0,qa);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);la=(ba(oc>>2,qa)|0)+(nc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(qa<<3))|0,qa);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);break}}}while(0);kc=Pe[O&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((K<<3)+ma&63)<<2)|0)>>2]=ma+A+(K<<11)|0;c[V+(((K<<3)+ma&63)<<2)>>2]=kc;qa=(ba((d[_+((K<<n)-F)|0]|0)+(d[_+((ma<<n)-H)|0]|0)|0,l)|0)+kc|0;if((qa|0)>=(ja|0)){hc=ja;ic=$a;jc=R;break}c[r>>2]=ma;c[(r+4|0)>>2]=K;hc=qa;ic=K;jc=ma}}while(0);ma=S+1|0;if((ma|0)<(M|0)){S=ma;ja=hc;$a=ic;R=jc}else{pc=hc;qc=ic;rc=jc;break}}}else{pc=ec;qc=fc;rc=gc}R=(T|0)==(rc|0)&(z|0)==(qc|0);$a=R?B+1|0:1;if(($a|0)>(c[(b+12260|0)>>2]|0)){t=pc;break}else{B=$a;I=pc;T=rc;z=R?z:qc}}u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}z=c[(b+10472|0)>>2]|0;T=c[(b+10476|0)>>2]|0;if((s&255|0)==0){sc=q;tc=p;uc=o}else{I=(m&1)<<1|1;B=s&255;O=q;D=o;Q=p;while(1){W=O;L=D;R=Q;while(1){$a=0;ja=W;S=L;M=R;while(1){G=(ba(c[862288+($a<<3)>>2]|0,B)|0)+R|0;ma=(ba(c[862292+($a<<3)>>2]|0,B)|0)+L|0;K=(G|0)>(C|0)?C:G;G=(y|0)>(K|0)?y:K;K=(ma|0)>(x|0)?x:ma;ma=(E|0)>(K|0)?E:K;do{if((c[(N+(((ma<<3)+G&63)<<2)|0)>>2]|0)==(G+A+(ma<<11)|0|0)){vc=ja;wc=S;xc=M}else{K=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){qa=c[(b+12420|0)>>2]|0;J=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(K,ma)|0)+G)|0;X=Pe[z&255](b,c[(b+12288+(h<<4)|0)>>2]|0,J,K,8)|0;if((m&2|0)==0){yc=X;break}J=c[(b+12208|0)>>2]|0;la=(ba(qa,ma>>1)|0)+(G>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|G&1)<<2)>>2]&1023](J+(K<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+la|0,qa,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|G&1)<<2)>>2]&1023](J+(K<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+la|0,qa,4);la=(Pe[T&255](b,J+(K<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,qa,4)|0)+X|0;yc=la+(Pe[T&255](b,J+(K<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,qa,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(G|0)){yc=536870912;break}if((G<<n|0)>(c[(b+12268|0)>>2]<<n|0)){yc=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){yc=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){yc=536870912;break}qa=e[(b+13872|0)>>1]|0;J=e[(b+13874|0)>>1]|0;p:do{if((c[(b+11740|0)>>2]|0)==1){if((G<<n|0)==0){la=0;while(1){X=c[b+12160+(la<<3)>>2]|0;ga=(c[b+12160+(la<<3)+4>>2]|0)+(ma<<n)|0;U=((ba(c[b+12128+(la<<3)>>2]|0,J-qa|0)|0)/(qa|0)|0)+((la&1)<<(m&1|4))|0;ia=c[b+12128+(la<<3)+4>>2]|0;if((ma<<n|0)==0){ka=la>>1;zc=((ba(ia,J-qa|0)|0)/(qa|0)|0)+(ka<<(m&1|4))|0;Ac=ka}else{zc=ga-ia|0;Ac=la>>1}ia=((zc&I)<<n)+(U&I)|0;ka=(c[(b+12208|0)>>2]|0)+((ba(Ac,K<<3)|0)+(la<<3&8))|0;if((m&1|0)==0){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,K)|0)+(X>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&I)<<n)+(X&I)|0)<<2)>>2]&1023](ka,na,K,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(zc>>1,K)|0)+(U>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(ia<<2)>>2]&1023](ka,na,K,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,K)|0)+(X>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&I)<<n)+(X&I)|0)<<2)>>2]&4095](ka,na,K);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(zc>>2,K)|0)+(U>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ia<<2)>>2]&4095](ka,na,K)}la=la+1|0;if((la|0)>=4){break p}}}if((ma<<n|0)==0){la=0;do{na=(c[b+12160+(la<<3)>>2]|0)+(G<<n)|0;ka=c[b+12160+(la<<3)+4>>2]|0;ia=na-(c[b+12128+(la<<3)>>2]|0)|0;U=la>>1;X=((ba(c[b+12128+(la<<3)+4>>2]|0,J-qa|0)|0)/(qa|0)|0)+(U<<(m&1|4))|0;ga=(c[(b+12208|0)>>2]|0)+((la<<3&8)+(ba(U,K<<3)|0))|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,K)|0)+(na>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&I)<<n)+(na&I)|0)<<2)>>2]&1023](ga,U,K,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>1,K)|0)+(ia>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&1023](ga,U,K,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>2,K)|0)+(na>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(na&I)|0)<<2)>>2]&4095](ga,U,K);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>2,K)|0)+(ia>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&4095](ga,U,K)}la=la+1|0;}while((la|0)<4)}else{la=0;do{U=(c[b+12160+(la<<3)>>2]|0)+(G<<n)|0;ga=(c[b+12160+(la<<3)+4>>2]|0)+(ma<<n)|0;ia=U-(c[b+12128+(la<<3)>>2]|0)|0;X=ga-(c[b+12128+(la<<3)+4>>2]|0)|0;na=(c[(b+12208|0)>>2]|0)+((la<<3&8)+(ba(la>>1,K<<3)|0))|0;if((m&1|0)==0){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>1,K)|0)+(U>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&I)<<n)+(U&I)|0)<<2)>>2]&1023](na,ka,K,8);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>1,K)|0)+(ia>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&1023](na,ka,K,8)}else{ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ga>>2,K)|0)+(U>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ga&I)<<n)+(U&I)|0)<<2)>>2]&4095](na,ka,K);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(X>>2,K)|0)+(ia>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&4095](na,ka,K)}la=la+1|0;}while((la|0)<4)}}else{la=(c[(b+12160|0)>>2]|0)+(G<<n)|0;ka=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;na=c[(b+12128|0)>>2]|0;if((G<<n|0)==0){Bc=(ba(na,J-qa|0)|0)/(qa|0)|0}else{Bc=la-na|0}na=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){Cc=(ba(na,J-qa|0)|0)/(qa|0)|0}else{Cc=ka-na|0}na=((Cc&I)<<n)+(Bc&I)|0;if((m&1|0)==0){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ka>>1,K)|0)+(la>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ia,K,16);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Cc>>1,K)|0)+(Bc>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+(na<<2)>>2]&1023](c[(b+12208|0)>>2]|0,ia,K,16);break}else{ia=(ba(ka>>2,K)|0)+(la>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ia|0,K);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ia+8|0)|0,K);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(K<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ia+(K<<3))|0,K);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ia+8|0)+(K<<3))|0,K);ia=(ba(Cc>>2,K)|0)+(Bc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ia|0,K);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ia+8|0)|0,K);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(K<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ia+(K<<3))|0,K);Xe[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ia+8|0)+(K<<3))|0,K);break}}}while(0);yc=Pe[z&255](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,K,16)|0}}while(0);c[(N+(((ma<<3)+G&63)<<2)|0)>>2]=G+A+(ma<<11)|0;c[V+(((ma<<3)+G&63)<<2)>>2]=yc;K=(ba((d[_+((ma<<n)-F)|0]|0)+(d[_+((G<<n)-H)|0]|0)|0,l)|0)+yc|0;if((K|0)>=(ja|0)){vc=ja;wc=S;xc=M;break}c[r>>2]=G;c[(r+4|0)>>2]=ma;vc=K;wc=ma;xc=G}}while(0);G=$a+1|0;if((G|0)<8){$a=G;ja=vc;S=wc;M=xc}else{break}}if((xc|0)==(R|0)&(wc|0)==(L|0)){break}else{W=vc;L=wc;R=xc}}W=(s+255&(s&255)|0)!=0?B-1|0:B>>1;if((W|0)==0){sc=vc;tc=R;uc=L;break}else{B=W;O=vc;D=L;Q=R}}}Q=tc+1|0;D=(Q|0)>(C|0)?C:Q;Q=(y|0)>(D|0)?y:D;D=(uc|0)>(x|0)?x:uc;O=(E|0)>(D|0)?E:D;do{if((c[(N+((Q+(O<<3)&63)<<2)|0)>>2]|0)==(((O<<11)+A|0)+Q|0|0)){Dc=sc}else{do{if((m&4|0)==0){D=c[b+12416>>2]|0;B=c[b+12420>>2]|0;I=(c[b+12352+(j<<4)>>2]|0)+((ba(D,O)|0)+Q)|0;W=Pe[z&255](b,c[b+12288+(h<<4)>>2]|0,I,D,8)|0;if((m&2|0)==0){Ec=W;break}I=c[b+12208>>2]|0;M=(ba(B,O>>1)|0)+(Q>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((Q&1|O<<1&2)<<2)>>2]&1023](I+(D<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+M|0,B,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((Q&1|O<<1&2)<<2)>>2]&1023](I+(D<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+M|0,B,4);M=(Pe[T&255](b,I+(D<<4)|0,c[b+12288+(h<<4)+4>>2]|0,B,4)|0)+W|0;Ec=M+(Pe[T&255](b,I+(D<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,B,4)|0)|0}else{B=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(Q|0)){Ec=536870912;break}if((Q<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Ec=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Ec=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Ec=536870912;break}D=e[b+13872>>1]|0;I=e[b+13874>>1]|0;M=(m&1)<<1|1;q:do{if((c[b+11740>>2]|0)==1){if((Q<<n|0)==0){W=0;while(1){S=c[b+12160+(W<<3)>>2]|0;ja=(c[b+12160+(W<<3)+4>>2]|0)+(O<<n)|0;$a=((ba(c[b+12128+(W<<3)>>2]|0,I-D|0)|0)/(D|0)|0)+((W&1)<<(m&1|4))|0;G=c[b+12128+(W<<3)+4>>2]|0;if((O<<n|0)==0){ma=W>>1;Fc=((ba(G,I-D|0)|0)/(D|0)|0)+(ma<<(m&1|4))|0;Gc=ma}else{Fc=ja-G|0;Gc=W>>1}G=((Fc&M)<<n)+($a&M)|0;ma=(c[(b+12208|0)>>2]|0)+((ba(Gc,B<<3)|0)+(W<<3&8))|0;if((m&1|0)==0){K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja>>1,B)|0)+(S>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ja&M)<<n)+(S&M)|0)<<2)>>2]&1023](ma,K,B,8);K=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Fc>>1,B)|0)+($a>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(G<<2)>>2]&1023](ma,K,B,8)}else{K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja>>2,B)|0)+(S>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ja&M)<<n)+(S&M)|0)<<2)>>2]&4095](ma,K,B);K=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Fc>>2,B)|0)+($a>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(G<<2)>>2]&4095](ma,K,B)}W=W+1|0;if((W|0)>=4){break q}}}if((O<<n|0)==0){W=0;do{K=(c[b+12160+(W<<3)>>2]|0)+(Q<<n)|0;ma=c[b+12160+(W<<3)+4>>2]|0;G=K-(c[b+12128+(W<<3)>>2]|0)|0;$a=W>>1;S=((ba(c[b+12128+(W<<3)+4>>2]|0,I-D|0)|0)/(D|0)|0)+($a<<(m&1|4))|0;ja=(c[(b+12208|0)>>2]|0)+((W<<3&8)+(ba($a,B<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,B)|0)+(K>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&M)<<n)+(K&M)|0)<<2)>>2]&1023](ja,$a,B,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(S>>1,B)|0)+(G>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((S&M)<<n)+(G&M)|0)<<2)>>2]&1023](ja,$a,B,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>2,B)|0)+(K>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(K&M)|0)<<2)>>2]&4095](ja,$a,B);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(S>>2,B)|0)+(G>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((S&M)<<n)+(G&M)|0)<<2)>>2]&4095](ja,$a,B)}W=W+1|0;}while((W|0)<4)}else{W=0;do{$a=(c[b+12160+(W<<3)>>2]|0)+(Q<<n)|0;ja=(c[b+12160+(W<<3)+4>>2]|0)+(O<<n)|0;G=$a-(c[b+12128+(W<<3)>>2]|0)|0;S=ja-(c[b+12128+(W<<3)+4>>2]|0)|0;K=(c[(b+12208|0)>>2]|0)+((W<<3&8)+(ba(W>>1,B<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja>>1,B)|0)+($a>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ja&M)<<n)+($a&M)|0)<<2)>>2]&1023](K,ma,B,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(S>>1,B)|0)+(G>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((S&M)<<n)+(G&M)|0)<<2)>>2]&1023](K,ma,B,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ja>>2,B)|0)+($a>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ja&M)<<n)+($a&M)|0)<<2)>>2]&4095](K,ma,B);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(S>>2,B)|0)+(G>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((S&M)<<n)+(G&M)|0)<<2)>>2]&4095](K,ma,B)}W=W+1|0;}while((W|0)<4)}}else{W=(c[b+12160>>2]|0)+(Q<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;K=c[b+12128>>2]|0;if((Q<<n|0)==0){Hc=(ba(K,I-D|0)|0)/(D|0)|0}else{Hc=W-K|0}K=c[b+12132>>2]|0;if((O<<n|0)==0){Ic=(ba(K,I-D|0)|0)/(D|0)|0}else{Ic=ma-K|0}K=((Ic&M)<<n)+(Hc&M)|0;if((m&1|0)==0){G=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,B)|0)+(W>>1))|0;cf[c[(c[b+12444>>2]|0)+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,G,B,16);G=(c[b+12352+(j<<4)+32>>2]|0)+((ba(Ic>>1,B)|0)+(Hc>>1))|0;cf[c[(c[b+12448>>2]|0)+(K<<2)>>2]&1023](c[(b+12208|0)>>2]|0,G,B,16);break}else{G=(ba(ma>>2,B)|0)+(W>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+G|0,B);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(G+8|0)|0,B);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(B<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(G+(B<<3))|0,B);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((B<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((G+8|0)+(B<<3))|0,B);G=(ba(Ic>>2,B)|0)+(Hc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+G|0,B);Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(G+8|0)|0,B);Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(B<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(G+(B<<3))|0,B);Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((B<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((G+8|0)+(B<<3))|0,B);break}}}while(0);Ec=Pe[z&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,B,16)|0}}while(0);c[(N+((Q+(O<<3)&63)<<2)|0)>>2]=((O<<11)+A|0)+Q|0;c[V+((Q+(O<<3)&63)<<2)>>2]=Ec;R=(ba((d[_+((O<<n)-F)|0]|0)+(d[_+((Q<<n)-H)|0]|0)|0,l)|0)+Ec|0;if((R|0)>=(sc|0)){Dc=sc;break}c[r>>2]=Q;c[(r+4|0)>>2]=O;Dc=R}}while(0);Q=uc+1|0;R=(tc|0)>(C|0)?C:tc;L=(y|0)>(R|0)?y:R;R=(Q|0)>(x|0)?x:Q;Q=(E|0)>(R|0)?E:R;do{if((c[(N+(((Q<<3)+L&63)<<2)|0)>>2]|0)==((L+A|0)+(Q<<11)|0|0)){Jc=Dc}else{do{if((m&4|0)==0){R=c[b+12416>>2]|0;M=c[b+12420>>2]|0;D=(c[b+12352+(j<<4)>>2]|0)+((ba(R,Q)|0)+L)|0;I=Pe[z&255](b,c[b+12288+(h<<4)>>2]|0,D,R,8)|0;if((m&2|0)==0){Kc=I;break}D=c[b+12208>>2]|0;G=(ba(M,Q>>1)|0)+(L>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((Q<<1&2|L&1)<<2)>>2]&1023](D+(R<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+G|0,M,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((Q<<1&2|L&1)<<2)>>2]&1023](D+(R<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+G|0,M,4);G=(Pe[T&255](b,D+(R<<4)|0,c[b+12288+(h<<4)+4>>2]|0,M,4)|0)+I|0;Kc=G+(Pe[T&255](b,D+(R<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,M,4)|0)|0}else{M=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(L|0)){Kc=536870912;break}if((L<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Kc=536870912;break}if((c[(b+12272|0)>>2]|0)>(Q|0)){Kc=536870912;break}if((Q<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Kc=536870912;break}R=e[b+13872>>1]|0;D=e[b+13874>>1]|0;G=(m&1)<<1|1;r:do{if((c[b+11740>>2]|0)==1){if((L<<n|0)==0){I=0;while(1){K=c[b+12160+(I<<3)>>2]|0;W=(c[b+12160+(I<<3)+4>>2]|0)+(Q<<n)|0;ma=((ba(c[b+12128+(I<<3)>>2]|0,D-R|0)|0)/(R|0)|0)+((I&1)<<(m&1|4))|0;S=c[b+12128+(I<<3)+4>>2]|0;if((Q<<n|0)==0){$a=I>>1;Lc=((ba(S,D-R|0)|0)/(R|0)|0)+($a<<(m&1|4))|0;Mc=$a}else{Lc=W-S|0;Mc=I>>1}S=((Lc&G)<<n)+(ma&G)|0;$a=(c[(b+12208|0)>>2]|0)+((ba(Mc,M<<3)|0)+(I<<3&8))|0;if((m&1|0)==0){ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(W>>1,M)|0)+(K>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((W&G)<<n)+(K&G)|0)<<2)>>2]&1023]($a,ja,M,8);ja=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Lc>>1,M)|0)+(ma>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(S<<2)>>2]&1023]($a,ja,M,8)}else{ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(W>>2,M)|0)+(K>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((W&G)<<n)+(K&G)|0)<<2)>>2]&4095]($a,ja,M);ja=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Lc>>2,M)|0)+(ma>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]($a,ja,M)}I=I+1|0;if((I|0)>=4){break r}}}if((Q<<n|0)==0){I=0;do{ja=(c[b+12160+(I<<3)>>2]|0)+(L<<n)|0;$a=c[b+12160+(I<<3)+4>>2]|0;S=ja-(c[b+12128+(I<<3)>>2]|0)|0;ma=I>>1;K=((ba(c[b+12128+(I<<3)+4>>2]|0,D-R|0)|0)/(R|0)|0)+(ma<<(m&1|4))|0;W=(c[(b+12208|0)>>2]|0)+((I<<3&8)+(ba(ma,M<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>1,M)|0)+(ja>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+(((($a&G)<<n)+(ja&G)|0)<<2)>>2]&1023](W,ma,M,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,M)|0)+(S>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(S&G)|0)<<2)>>2]&1023](W,ma,M,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>2,M)|0)+(ja>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(ja&G)|0)<<2)>>2]&4095](W,ma,M);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,M)|0)+(S>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(S&G)|0)<<2)>>2]&4095](W,ma,M)}I=I+1|0;}while((I|0)<4)}else{I=0;do{ma=(c[b+12160+(I<<3)>>2]|0)+(L<<n)|0;W=(c[b+12160+(I<<3)+4>>2]|0)+(Q<<n)|0;S=ma-(c[b+12128+(I<<3)>>2]|0)|0;K=W-(c[b+12128+(I<<3)+4>>2]|0)|0;ja=(c[(b+12208|0)>>2]|0)+((I<<3&8)+(ba(I>>1,M<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(W>>1,M)|0)+(ma>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((W&G)<<n)+(ma&G)|0)<<2)>>2]&1023](ja,$a,M,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,M)|0)+(S>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(S&G)|0)<<2)>>2]&1023](ja,$a,M,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(W>>2,M)|0)+(ma>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((W&G)<<n)+(ma&G)|0)<<2)>>2]&4095](ja,$a,M);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,M)|0)+(S>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(S&G)|0)<<2)>>2]&4095](ja,$a,M)}I=I+1|0;}while((I|0)<4)}}else{I=(c[b+12160>>2]|0)+(L<<n)|0;$a=(c[b+12164>>2]|0)+(Q<<n)|0;ja=c[b+12128>>2]|0;if((L<<n|0)==0){Nc=(ba(ja,D-R|0)|0)/(R|0)|0}else{Nc=I-ja|0}ja=c[b+12132>>2]|0;if((Q<<n|0)==0){Oc=(ba(ja,D-R|0)|0)/(R|0)|0}else{Oc=$a-ja|0}ja=((Oc&G)<<n)+(Nc&G)|0;if((m&1|0)==0){S=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba($a>>1,M)|0)+(I>>1))|0;cf[c[(c[b+12444>>2]|0)+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,S,M,16);S=(c[b+12352+(j<<4)+32>>2]|0)+((ba(Oc>>1,M)|0)+(Nc>>1))|0;cf[c[(c[b+12448>>2]|0)+(ja<<2)>>2]&1023](c[(b+12208|0)>>2]|0,S,M,16);break}else{S=(ba($a>>2,M)|0)+(I>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+S|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(S+8|0)|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(S+(M<<3))|0,M);Xe[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((S+8|0)+(M<<3))|0,M);S=(ba(Oc>>2,M)|0)+(Nc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+S|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(S+8|0)|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(S+(M<<3))|0,M);Xe[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((S+8|0)+(M<<3))|0,M);break}}}while(0);Kc=Pe[z&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,M,16)|0}}while(0);c[(N+(((Q<<3)+L&63)<<2)|0)>>2]=(L+A|0)+(Q<<11)|0;c[V+(((Q<<3)+L&63)<<2)>>2]=Kc;G=(ba((d[_+((Q<<n)-F)|0]|0)+(d[_+((L<<n)-H)|0]|0)|0,l)|0)+Kc|0;if((G|0)>=(Dc|0)){Jc=Dc;break}c[r>>2]=L;c[(r+4|0)>>2]=Q;Jc=G}}while(0);Q=tc-1|0;G=(Q|0)>(C|0)?C:Q;Q=(y|0)>(G|0)?y:G;do{if((c[(N+((Q+(O<<3)&63)<<2)|0)>>2]|0)==(((O<<11)+A|0)+Q|0|0)){Pc=Jc}else{do{if((m&4|0)==0){G=c[b+12416>>2]|0;R=c[b+12420>>2]|0;D=(c[b+12352+(j<<4)>>2]|0)+((ba(G,O)|0)+Q)|0;B=Pe[z&255](b,c[b+12288+(h<<4)>>2]|0,D,G,8)|0;if((m&2|0)==0){Qc=B;break}D=c[b+12208>>2]|0;S=(ba(R,O>>1)|0)+(Q>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((Q&1|O<<1&2)<<2)>>2]&1023](D+(G<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+S|0,R,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((Q&1|O<<1&2)<<2)>>2]&1023](D+(G<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+S|0,R,4);S=(Pe[T&255](b,D+(G<<4)|0,c[b+12288+(h<<4)+4>>2]|0,R,4)|0)+B|0;Qc=S+(Pe[T&255](b,D+(G<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,R,4)|0)|0}else{R=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(Q|0)){Qc=536870912;break}if((Q<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Qc=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Qc=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Qc=536870912;break}G=e[b+13872>>1]|0;D=e[b+13874>>1]|0;S=(m&1)<<1|1;s:do{if((c[b+11740>>2]|0)==1){if((Q<<n|0)==0){B=0;while(1){ja=c[b+12160+(B<<3)>>2]|0;I=(c[b+12160+(B<<3)+4>>2]|0)+(O<<n)|0;$a=((ba(c[b+12128+(B<<3)>>2]|0,D-G|0)|0)/(G|0)|0)+((B&1)<<(m&1|4))|0;K=c[b+12128+(B<<3)+4>>2]|0;if((O<<n|0)==0){ma=B>>1;Rc=((ba(K,D-G|0)|0)/(G|0)|0)+(ma<<(m&1|4))|0;Sc=ma}else{Rc=I-K|0;Sc=B>>1}K=((Rc&S)<<n)+($a&S)|0;ma=(c[(b+12208|0)>>2]|0)+((ba(Sc,R<<3)|0)+(B<<3&8))|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(I>>1,R)|0)+(ja>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((I&S)<<n)+(ja&S)|0)<<2)>>2]&1023](ma,W,R,8);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Rc>>1,R)|0)+($a>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(K<<2)>>2]&1023](ma,W,R,8)}else{W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(I>>2,R)|0)+(ja>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((I&S)<<n)+(ja&S)|0)<<2)>>2]&4095](ma,W,R);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Rc>>2,R)|0)+($a>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095](ma,W,R)}B=B+1|0;if((B|0)>=4){break s}}}if((O<<n|0)==0){B=0;do{W=(c[b+12160+(B<<3)>>2]|0)+(Q<<n)|0;ma=c[b+12160+(B<<3)+4>>2]|0;K=W-(c[b+12128+(B<<3)>>2]|0)|0;$a=B>>1;ja=((ba(c[b+12128+(B<<3)+4>>2]|0,D-G|0)|0)/(G|0)|0)+($a<<(m&1|4))|0;I=(c[(b+12208|0)>>2]|0)+((B<<3&8)+(ba($a,R<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,R)|0)+(W>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&S)<<n)+(W&S)|0)<<2)>>2]&1023](I,$a,R,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ja>>1,R)|0)+(K>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&1023](I,$a,R,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>2,R)|0)+(W>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(W&S)|0)<<2)>>2]&4095](I,$a,R);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ja>>2,R)|0)+(K>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&4095](I,$a,R)}B=B+1|0;}while((B|0)<4)}else{B=0;do{$a=(c[b+12160+(B<<3)>>2]|0)+(Q<<n)|0;I=(c[b+12160+(B<<3)+4>>2]|0)+(O<<n)|0;K=$a-(c[b+12128+(B<<3)>>2]|0)|0;ja=I-(c[b+12128+(B<<3)+4>>2]|0)|0;W=(c[(b+12208|0)>>2]|0)+((B<<3&8)+(ba(B>>1,R<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(I>>1,R)|0)+($a>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((I&S)<<n)+($a&S)|0)<<2)>>2]&1023](W,ma,R,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ja>>1,R)|0)+(K>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&1023](W,ma,R,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(I>>2,R)|0)+($a>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((I&S)<<n)+($a&S)|0)<<2)>>2]&4095](W,ma,R);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(ja>>2,R)|0)+(K>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&4095](W,ma,R)}B=B+1|0;}while((B|0)<4)}}else{B=(c[b+12160>>2]|0)+(Q<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;W=c[b+12128>>2]|0;if((Q<<n|0)==0){Tc=(ba(W,D-G|0)|0)/(G|0)|0}else{Tc=B-W|0}W=c[b+12132>>2]|0;if((O<<n|0)==0){Uc=(ba(W,D-G|0)|0)/(G|0)|0}else{Uc=ma-W|0}W=((Uc&S)<<n)+(Tc&S)|0;if((m&1|0)==0){K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,R)|0)+(B>>1))|0;cf[c[(c[b+12444>>2]|0)+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,K,R,16);K=(c[b+12352+(j<<4)+32>>2]|0)+((ba(Uc>>1,R)|0)+(Tc>>1))|0;cf[c[(c[b+12448>>2]|0)+(W<<2)>>2]&1023](c[(b+12208|0)>>2]|0,K,R,16);break}else{K=(ba(ma>>2,R)|0)+(B>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+K|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(K+8|0)|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(K+(R<<3))|0,R);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((K+8|0)+(R<<3))|0,R);K=(ba(Uc>>2,R)|0)+(Tc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+K|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(K+8|0)|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(K+(R<<3))|0,R);Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((K+8|0)+(R<<3))|0,R);break}}}while(0);Qc=Pe[z&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,R,16)|0}}while(0);c[(N+((Q+(O<<3)&63)<<2)|0)>>2]=((O<<11)+A|0)+Q|0;c[V+((Q+(O<<3)&63)<<2)>>2]=Qc;S=(ba((d[_+((O<<n)-F)|0]|0)+(d[_+((Q<<n)-H)|0]|0)|0,l)|0)+Qc|0;if((S|0)>=(Jc|0)){Pc=Jc;break}c[r>>2]=Q;c[(r+4|0)>>2]=O;Pc=S}}while(0);O=uc-1|0;Q=(O|0)>(x|0)?x:O;O=(E|0)>(Q|0)?E:Q;if((c[(N+(((O<<3)+L&63)<<2)|0)>>2]|0)==((L+A|0)+(O<<11)|0|0)){t=Pc;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}do{if((m&4|0)==0){Q=c[b+12416>>2]|0;y=c[b+12420>>2]|0;C=(c[b+12352+(j<<4)>>2]|0)+((ba(Q,O)|0)+L)|0;S=Pe[z&255](b,c[b+12288+(h<<4)>>2]|0,C,Q,8)|0;if((m&2|0)==0){Vc=S;break}C=c[b+12208>>2]|0;G=(ba(y,O>>1)|0)+(L>>1)|0;cf[c[(c[(b+12444|0)>>2]|0)+32+((O<<1&2|L&1)<<2)>>2]&1023](C+(Q<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+G|0,y,4);cf[c[(c[(b+12444|0)>>2]|0)+32+((O<<1&2|L&1)<<2)>>2]&1023](C+(Q<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+G|0,y,4);G=(Pe[T&255](b,C+(Q<<4)|0,c[b+12288+(h<<4)+4>>2]|0,y,4)|0)+S|0;Vc=G+(Pe[T&255](b,C+(Q<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,y,4)|0)|0}else{y=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(L|0)){Vc=536870912;break}if((L<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Vc=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Vc=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Vc=536870912;break}Q=e[b+13872>>1]|0;C=e[b+13874>>1]|0;G=(m&1)<<1|1;t:do{if((c[b+11740>>2]|0)==1){if((L<<n|0)==0){S=0;while(1){D=c[b+12160+(S<<3)>>2]|0;M=(c[b+12160+(S<<3)+4>>2]|0)+(O<<n)|0;K=((ba(c[b+12128+(S<<3)>>2]|0,C-Q|0)|0)/(Q|0)|0)+((S&1)<<(m&1|4))|0;W=c[b+12128+(S<<3)+4>>2]|0;if((O<<n|0)==0){B=S>>1;Wc=((ba(W,C-Q|0)|0)/(Q|0)|0)+(B<<(m&1|4))|0;Xc=B}else{Wc=M-W|0;Xc=S>>1}W=((Wc&G)<<n)+(K&G)|0;B=(c[(b+12208|0)>>2]|0)+((ba(Xc,y<<3)|0)+(S<<3&8))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(M>>1,y)|0)+(D>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((M&G)<<n)+(D&G)|0)<<2)>>2]&1023](B,ma,y,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Wc>>1,y)|0)+(K>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+(W<<2)>>2]&1023](B,ma,y,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(M>>2,y)|0)+(D>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((M&G)<<n)+(D&G)|0)<<2)>>2]&4095](B,ma,y);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(Wc>>2,y)|0)+(K>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](B,ma,y)}S=S+1|0;if((S|0)>=4){break t}}}if((O<<n|0)==0){S=0;do{R=(c[b+12160+(S<<3)>>2]|0)+(L<<n)|0;ma=c[b+12160+(S<<3)+4>>2]|0;B=R-(c[b+12128+(S<<3)>>2]|0)|0;W=S>>1;K=((ba(c[b+12128+(S<<3)+4>>2]|0,C-Q|0)|0)/(Q|0)|0)+(W<<(m&1|4))|0;D=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ba(W,y<<3)|0))|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,y)|0)+(R>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&G)<<n)+(R&G)|0)<<2)>>2]&1023](D,W,y,8);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,y)|0)+(B>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(B&G)|0)<<2)>>2]&1023](D,W,y,8)}else{W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>2,y)|0)+(R>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(R&G)|0)<<2)>>2]&4095](D,W,y);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,y)|0)+(B>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(B&G)|0)<<2)>>2]&4095](D,W,y)}S=S+1|0;}while((S|0)<4)}else{S=0;do{W=(c[b+12160+(S<<3)>>2]|0)+(L<<n)|0;D=(c[b+12160+(S<<3)+4>>2]|0)+(O<<n)|0;B=W-(c[b+12128+(S<<3)>>2]|0)|0;K=D-(c[b+12128+(S<<3)+4>>2]|0)|0;R=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ba(S>>1,y<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(D>>1,y)|0)+(W>>1))|0;cf[c[(c[(b+12444|0)>>2]|0)+16+((((D&G)<<n)+(W&G)|0)<<2)>>2]&1023](R,ma,y,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>1,y)|0)+(B>>1))|0;cf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(B&G)|0)<<2)>>2]&1023](R,ma,y,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(D>>2,y)|0)+(W>>2))|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((D&G)<<n)+(W&G)|0)<<2)>>2]&4095](R,ma,y);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ba(K>>2,y)|0)+(B>>2))|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(B&G)|0)<<2)>>2]&4095](R,ma,y)}S=S+1|0;}while((S|0)<4)}}else{S=(c[b+12160>>2]|0)+(L<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;R=c[b+12128>>2]|0;if((L<<n|0)==0){Yc=(ba(R,C-Q|0)|0)/(Q|0)|0}else{Yc=S-R|0}R=c[b+12132>>2]|0;if((O<<n|0)==0){Zc=(ba(R,C-Q|0)|0)/(Q|0)|0}else{Zc=ma-R|0}R=((Zc&G)<<n)+(Yc&G)|0;if((m&1|0)==0){B=(c[(b+12352+(j<<4)|0)>>2]|0)+((ba(ma>>1,y)|0)+(S>>1))|0;cf[c[(c[b+12444>>2]|0)+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&1023](c[(b+12208|0)>>2]|0,B,y,16);B=(c[b+12352+(j<<4)+32>>2]|0)+((ba(Zc>>1,y)|0)+(Yc>>1))|0;cf[c[(c[b+12448>>2]|0)+(R<<2)>>2]&1023](c[(b+12208|0)>>2]|0,B,y,16);break}else{B=(ba(ma>>2,y)|0)+(S>>2)|0;Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+B|0,y);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(B+8|0)|0,y);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(y<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(B+(y<<3))|0,y);Xe[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((y<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((B+8|0)+(y<<3))|0,y);B=(ba(Zc>>2,y)|0)+(Yc>>2)|0;Xe[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+B|0,y);Xe[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(B+8|0)|0,y);Xe[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(y<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(B+(y<<3))|0,y);Xe[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((y<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((B+8|0)+(y<<3))|0,y);break}}}while(0);Vc=Pe[z&255](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,y,16)|0}}while(0);c[(N+(((O<<3)+L&63)<<2)|0)>>2]=(L+A|0)+(O<<11)|0;c[V+(((O<<3)+L&63)<<2)>>2]=Vc;z=(ba((d[_+((O<<n)-F)|0]|0)+(d[_+((L<<n)-H)|0]|0)|0,l)|0)+Vc|0;if((z|0)>=(Pc|0)){t=Pc;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}c[r>>2]=L;c[(r+4|0)>>2]=O;t=z;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}while(0);c[a+19104>>2]=t;c[a+19112>>2]=u;c[a+19120>>2]=v;c[a+19128>>2]=w}



function d2(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;g=i;i=i+128|0;h=g|0;j=c[f+60>>2]|0;k=j;l=c[f+140>>2]|0;if((l|0)==4){m=8}else if((l|0)==74){m=10}else{yDb(f,16,2112872,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}l=W1(f,m)|0;m=j+14680|0;c[m>>2]=l;p=f;if((l|0)==0){yDb(p,16,2054232,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;X1(f,16);o=-22;i=g;return o|0}yDb(p,48,2008472,(n=i,i=i+8|0,c[n>>2]=l,n)|0);i=n;l=U1(c[m>>2]|0)|0;if(!((l|0)>-1)){yDb(0,0,1970264,(n=i,i=i+24|0,c[n>>2]=1941624,c[n+8>>2]=1917472,c[n+16>>2]=277,n)|0);i=n;Cd();return 0}m=j+14684|0;c[m>>2]=1231136+(l*140|0);q=j+8|0;r=j+12|0;c[r>>2]=f;c[j+12496>>2]=1;c[j+236>>2]=1;c[f+796>>2]=c[1231164+(l*140|0)>>2];qOa(q)|0;lPa(q)|0;q=j+14400|0;if((c[q>>2]|0)==0){c[q>>2]=2}if((c[(c[m>>2]|0)+28>>2]|0)==10){c[q>>2]=106;c[j+15964>>2]=1474;c[j+14836>>2]=4}else{c[j+15964>>2]=1762;c[j+14836>>2]=3}q=(c[f+124>>2]|0)+15|0;l=(q|0)/16|0;s=j+128|0;c[s>>2]=l;t=((c[f+120>>2]|0)+15|0)/16|0;c[j+124>>2]=t;if((c[f+88>>2]&262144|0)==0){u=l}else{c[j+14840>>2]=1;l=(q|0)/32|0;c[s>>2]=l;u=l}l=j+152|0;c[l>>2]=ba(t,u)|0;u=c[f+280>>2]|0;if((u|0)!=999999){c[j+13080>>2]=u}TGb(h|0,0,128)|0;u=h|0;b[u>>1]=1;t=c[m>>2]|0;q=c[t+36>>2]|0;v=c[t+40>>2]|0;t=cEb((c[(c[r>>2]|0)+504>>2]<<8)+256|0)|0;w=j+15892|0;c[w>>2]=t;x=c[r>>2]|0;y=c[x+504>>2]|0;do{if((t|0)==0){if((y&16777215|0)==16777215){break}yDb(x,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);x=cEb((y<<8)+256|0)|0;y=j+15888|0;c[y>>2]=x;t=c[r>>2]|0;z=c[t+504>>2]|0;do{if((x|0)==0){if((z&16777215|0)==16777215){break}yDb(t,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);t=cEb((z<<8)+256|0)|0;z=j+15896|0;c[z>>2]=t;x=c[r>>2]|0;A=c[x+504>>2]|0;do{if((t|0)==0){if((A&16777215|0)==16777215){break}yDb(x,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);x=cEb((A<<8)+256|0)|0;A=x;t=j+15900|0;c[t>>2]=A;do{if((x|0)==0){B=c[r>>2]|0;if((c[B+504>>2]&16777215|0)==16777215){break}yDb(B,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);x=c[m>>2]|0;do{if((c[x+28>>2]|0)==8){B=c[x+36>>2]|0;C=1;do{b[h+((d[(d[1075976+C|0]|0)+(k+11192)|0]|0)<<1)>>1]=d[B+C|0]|0;C=C+1|0;}while((C|0)<64);C=j+10064|0;B=j+13080|0;iPa(C,c[w>>2]|0,c[z>>2]|0,u,c[B>>2]|0,1,c[(c[r>>2]|0)+504>>2]|0,1);D=c[(c[m>>2]|0)+40>>2]|0;E=1;do{b[h+((d[(d[1075976+E|0]|0)+(k+11192)|0]|0)<<1)>>1]=d[D+E|0]|0;E=E+1|0;}while((E|0)<64);iPa(C,c[y>>2]|0,c[t>>2]|0,u,c[B>>2]|0,1,c[(c[r>>2]|0)+504>>2]|0,1);E=(c[r>>2]|0)+504|0;if((c[E>>2]|0)<1){F=c[t>>2]|0;break}D=c[w>>2]|0;G=c[y>>2]|0;H=c[z>>2]|0;I=c[t>>2]|0;J=1;while(1){K=0;do{L=D+(J<<8)+(K<<2)|0;c[L>>2]=c[L>>2]<<2;L=G+(J<<8)+(K<<2)|0;c[L>>2]=c[L>>2]<<2;L=H+(J<<8)+(K<<1)|0;b[L>>1]=b[L>>1]<<2;L=H+(J<<8)+128+(K<<1)|0;b[L>>1]=b[L>>1]<<2;L=I+(J<<8)+(K<<1)|0;b[L>>1]=b[L>>1]<<2;L=I+(J<<8)+128+(K<<1)|0;b[L>>1]=b[L>>1]<<2;K=K+1|0;}while((K|0)<64);K=J+1|0;if((K|0)>(c[E>>2]|0)){F=I;break}else{J=K}}}else{J=(c[r>>2]|0)+504|0;if((c[J>>2]|0)<1){F=A;break}I=c[w>>2]|0;E=c[y>>2]|0;H=1;while(1){G=1;do{D=d[(d[1075976+G|0]|0)+(k+11192)|0]|0;c[I+(H<<8)+(D<<2)>>2]=524288/(ba(d[q+G|0]|0,H)|0)|0;c[E+(H<<8)+(D<<2)>>2]=524288/(ba(d[v+G|0]|0,H)|0)|0;G=G+1|0;}while((G|0)<64);G=H+1|0;if((G|0)>(c[J>>2]|0)){F=A;break}else{H=G}}}}while(0);c[j+13184>>2]=F;c[j+13172>>2]=c[y>>2];c[j+13180>>2]=c[z>>2];c[j+13168>>2]=c[w>>2];if((c[j+14848>>2]|0)!=0){c[j+14852>>2]=1600}w=1<<(c[(c[m>>2]|0)+28>>2]|0)+2;z=w<<4;y=cEb(z)|0;F=j+15920|0;c[F>>2]=y;if(!((y|0)!=0|(z|0)==0)){yDb(c[r>>2]|0,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}z=cEb(w<<2)|0;y=j+15924|0;c[y>>2]=z;if((z|0)==0){yDb(c[r>>2]|0,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}z=cEb(126)|0;A=j+15928|0;c[A>>2]=z;if((z|0)==0){yDb(c[r>>2]|0,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}z=cEb(63)|0;v=j+15932|0;c[v>>2]=z;if((z|0)==0){yDb(c[r>>2]|0,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}z=w<<1;c[F>>2]=(c[F>>2]|0)+(z<<2);c[y>>2]=(c[y>>2]|0)+z;z=-w|0;a:do{if((w|0)>(z|0)){q=z;b:while(1){t=q<<1;u=q>>31;h=(u^q)-u|0;x=(h|0)>64;H=h-1>>6;J=u&1;u=x?H:0;E=x?H<<6:0;H=h-E|0;x=(u|0)==0;I=(h|0)==(E|0);E=0;do{h=E|t;G=c[m>>2]|0;D=c[G+60>>2]|0;B=G+64|0;C=(E|0)!=0;K=C^1;c:do{if(x){L=0;while(1){if(((d[D+L|0]|0)>>>1|0)==(H|0)){if(!C){M=L;N=70;break c}if(!((a[(c[B>>2]|0)+L|0]&2)==0|K)){M=L;N=70;break c}}O=L+1|0;if((O|0)<257){L=O}else{N=73;break}}}else{if(C){P=0}else{L=0;while(1){if(((d[D+L|0]|0)>>>1|0)==(H|0)){if(!((a[(c[B>>2]|0)+L|0]&1)==0)){M=L;N=70;break c}}O=L+1|0;if((O|0)<257){L=O}else{N=73;break c}}}while(1){do{if(((d[D+P|0]|0)>>>1|0)==(H|0)){L=a[(c[B>>2]|0)+P|0]|0;if((L&1)==0){break}if(!((L&2)==0|K)){M=P;N=70;break c}}}while(0);L=P+1|0;if((L|0)<257){P=L}else{N=73;break}}}}while(0);do{if((N|0)==70){N=0;K=e[(c[G+52>>2]|0)+(M<<1)>>1]|0;if(I){c[(c[F>>2]|0)+(h<<2)>>2]=K;a[(c[y>>2]|0)+h|0]=a[(c[G+56>>2]|0)+M|0]|0;break}else{c[(c[F>>2]|0)+(h<<2)>>2]=K<<1|J;a[(c[y>>2]|0)+h|0]=(a[(c[G+56>>2]|0)+M|0]|0)+1;break}}else if((N|0)==73){N=0;if(!I){break b}}}while(0);if(!x){G=(c[F>>2]|0)+(h<<2)|0;K=(c[m>>2]|0)+24|0;c[G>>2]=c[G>>2]<<c[K>>2]|u;G=(c[y>>2]|0)+h|0;a[G]=(d[G]|0)+(c[K>>2]|0)}E=E+1|0;}while((E|0)<2);E=q+1|0;if((E|0)<(w|0)){q=E}else{Q=0;break a}}yDb(0,0,1970264,(n=i,i=i+24|0,c[n>>2]=2309136,c[n+8>>2]=1917472,c[n+16>>2]=155,n)|0);i=n;Cd();return 0}else{Q=0}}while(0);do{w=c[m>>2]|0;y=a[(c[w+76>>2]|0)+Q|0]|0;F=y&255;if(!((y&255)>>>0<63>>>0)){N=80;break}b[(c[A>>2]|0)+(F<<1)>>1]=b[(c[w+68>>2]|0)+(Q<<1)>>1]|0;a[(c[v>>2]|0)+F|0]=a[(c[w+72>>2]|0)+Q|0]|0;Q=Q+1|0;}while((Q|0)<62);if((N|0)==80){yDb(0,0,1970264,(n=i,i=i+24|0,c[n>>2]=2290424,c[n+8>>2]=1917472,c[n+16>>2]=164,n)|0);i=n;Cd();return 0}N=cEb(((c[(c[r>>2]|0)+504>>2]|0)*65280|0)+65280|0)|0;c[j+15960>>2]=N;Q=c[r>>2]|0;do{if((N|0)==0){if(((c[Q+504>>2]|0)*65280|0|0)==-65280){break}yDb(Q,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);do{if((c[Q+296>>2]|0)!=2){N=cEb(c[l>>2]<<3)|0;c[j+15956>>2]=N;if((N|0)!=0){break}if((c[l>>2]&536870911|0)==0){break}yDb(c[r>>2]|0,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);c[j+15904>>2]=(c[(c[m>>2]|0)+20>>2]|0)+536870268-(c[j+14852>>2]|0)<<3;c[j+15940>>2]=1;c[j+15944>>2]=2048;m=cEb(c[s>>2]<<2)|0;c[j+14692>>2]=m;Q=c[s>>2]|0;do{if((m|0)==0){if((Q&1073741823|0)==0){break}yDb(c[r>>2]|0,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);m=cEb(Q<<2)|0;c[j+14696>>2]=m;do{if((m|0)==0){if((c[s>>2]&1073741823|0)==0){break}yDb(c[r>>2]|0,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);s=cEb(c[l>>2]<<1)|0;c[j+15948>>2]=s;m=c[l>>2]|0;do{if((s|0)==0){if((m&2147483647|0)==0){break}yDb(c[r>>2]|0,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);s=cEb(m)|0;c[j+15952>>2]=s;do{if((s|0)==0){if((c[l>>2]|0)==0){break}yDb(c[r>>2]|0,16,1896640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);r=ICb()|0;c[f+804>>2]=r;if((r|0)==0){o=-12;i=g;return o|0}c[r+84>>2]=1;c[r+88>>2]=1;r=f+808|0;l=c[r>>2]|0;if((l|0)>32){yDb(p,16,2353800,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}if((c[f+504>>2]|0)<2){yDb(p,16,2333792,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}n=j+14700|0;p=n;c[n>>2]=k;if((l|0)>1){R=1}else{o=0;i=g;return o|0}while(1){l=WDb(15968)|0;c[p+(R<<2)>>2]=l;UGb(l|0,j|0,15968)|0;l=R+1|0;if((l|0)<(c[r>>2]|0)){R=l}else{o=0;break}}i=g;return o|0}function e2(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0;j=i;i=i+4096|0;k=j|0;l=d+60|0;m=c[l>>2]|0;n=m;o=m+14684|0;p=r0a(d,f,c[(c[o>>2]|0)+16>>2]|0,0)|0;if((p|0)<0){q=p;i=j;return q|0}p=c[f+24>>2]|0;r=m+12|0;s=c[r>>2]|0;t=s+808|0;if((c[t>>2]|0)>0){u=g+32|0;v=m+14840|0;w=g+36|0;y=m+156|0;z=m+160|0;A=0;do{B=c[n+14700+(A<<2)>>2]|0;c[B+156>>2]=c[u>>2]<<c[v>>2];c[B+160>>2]=c[w>>2]<<c[v>>2];c[B+14828>>2]=c[y>>2]<<3;c[B+14832>>2]=c[z>>2]<<3;A=A+1|0;}while((A|0)<(c[t>>2]|0))}t=g+296|0;c[(c[s+804>>2]|0)+296>>2]=c[t>>2];if((c[t>>2]|0)==0){C=0}else{C=(c[g+300>>2]|0)==0|0}t=m+14844|0;c[t>>2]=C;s=m+15908|0;A=m+14840|0;z=d+124|0;y=d+120|0;v=d+296|0;w=d+504|0;u=m+15940|0;n=d+828|0;B=m+128|0;D=m+15944|0;E=m+124|0;G=m+15904|0;H=m+15960|0;I=m+15952|0;J=m+15948|0;K=m+14696|0;L=m+14692|0;M=m+14688|0;N=m+15956|0;O=m+152|0;P=k;Q=k+3068|0;R=k+4092|0;S=p;p=1;T=c[A>>2]|0;U=C;a:while(1){C=c[g>>2]|0;V=s;c[V>>2]=C;do{if((T|0)==0){c[m+15912>>2]=c[g+4>>2];c[m+15916>>2]=c[g+8>>2]}else{if((U|0)==0){c[m+15912>>2]=c[g+4>>2];c[m+15916>>2]=c[g+8>>2];break}else{c[V>>2]=C+(c[g+32>>2]|0);c[m+15912>>2]=(c[g+4>>2]|0)+(c[g+36>>2]|0);c[m+15916>>2]=(c[g+8>>2]|0)+(c[g+40>>2]|0);break}}}while(0);C=c[l>>2]|0;TGb(S|0,0,640)|0;a[S]=a[1349888]|0;a[S+1|0]=a[1349889]|0;a[S+2|0]=a[1349890]|0;a[S+3|0]=a[1349891]|0;a[S+4|0]=a[1349892]|0;V=C+14840|0;if((c[V>>2]|0)==0){W=1}else{W=(c[C+14844>>2]|0)+2&255}a[S+5|0]=W;a[S+6|0]=-128;a[S+7|0]=-96;X=S+24|0;x=de(c[z>>2]>>c[V>>2]&65535|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;X=S+26|0;x=de(c[y>>2]&65535|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;X=S+29|0;x=de(c[z>>2]>>c[V>>2]&65535|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;a[S+33|0]=(c[(c[C+14684>>2]|0)+28>>2]|0)==10?88:56;a[S+34|0]=(c[V>>2]<<2)+136;X=S+40|0;x=fe(c[C+14680>>2]|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;a[S+44|0]=(c[V>>2]|0)!=0?0:-128;a[S+95|0]=1;a[S+359|0]=2;V=C+128|0;X=S+362|0;x=de((c[V>>2]<<2)+4&65535|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;a[S+365|0]=c[V>>2];a[S+367|0]=16;c[C+14688>>2]=S+368;b:do{if((c[v>>2]|0)==2){if((c[w>>2]|0)>1){C=1;do{c[u>>2]=C;Pe[c[n>>2]&255](d,724,0,0,c[B>>2]|0)|0;C=C+1|0;}while((C|0)<(c[w>>2]|0))}C=c[D>>2]|0;V=0;X=2147483647;Y=2048;Z=2048;c:while(1){_=(X|0)==2147483647;$=C;aa=V;ca=Y;da=Z;while(1){ea=($|0)==(aa|0);fa=(ea&1)+$|0;ga=0;ha=0;while(1){if((ha|0)>=(c[B>>2]|0)){ia=19;break}ja=c[E>>2]|0;if((ja|0)>0){ka=0;la=ga;ma=ja;ja=c[H>>2]|0;while(1){na=ka+(ba(ma,ha)|0)|0;oa=c[w>>2]|0;if((oa|0)>1){pa=1;qa=-1;ra=1;while(1){sa=ba(c[ja+(pa*65280|0)+(na<<3)+4>>2]|0,fa)|0;ta=(c[ja+(pa*65280|0)+(na<<3)>>2]<<10)+sa|0;sa=ta>>>0<qa>>>0;ua=sa?pa:ra;va=pa+1|0;if((va|0)<(oa|0)){pa=va;qa=sa?ta:qa;ra=ua}else{wa=ua;break}}}else{wa=1}ra=(c[ja+(wa*65280|0)+(na<<3)+4>>2]|0)+la|0;a[(c[I>>2]|0)+na|0]=wa;qa=c[H>>2]|0;b[(c[J>>2]|0)+(na<<1)>>1]=c[qa+(wa*65280|0)+(na<<3)+4>>2];pa=ka+1|0;oa=c[E>>2]|0;if((pa|0)<(oa|0)){ka=pa;la=ra;ma=oa;ja=qa}else{xa=ra;break}}}else{xa=ga}ja=xa+31&-32;ma=c[G>>2]|0;if(ja>>>0>ma>>>0){ya=ja;za=ma;break}ga=ja;ha=ha+1|0}if((ia|0)==19){ia=0;ya=ga;za=c[G>>2]|0}if(ea){ia=28;break c}if(ya>>>0<za>>>0){break}ha=(fa|0)>(aa|0)?fa:aa;if(_){ja=da;ma=(da|0)<0|0?-1:0;la=YGb(fa,(fa|0)<0|0?-1:0,ja,ma)|0;ka=F;ra=0;if((ka|0)>(ra|0)|(ka|0)==(ra|0)&la>>>0>2147483647>>>0){ia=88;break a}Aa=fa+da|0;Ba=ma;Ca=ja}else{Aa=fa+X>>1;Ba=(da|0)<0|0?-1:0;Ca=da}ja=gHb(Ca,Ba,5,0)|0;ma=F;la=0;$=Aa;aa=ha;ca=1024;da=(ma|0)>(la|0)|(ma|0)==(la|0)&ja>>>0>2147483647>>>0?2147483647:ja}da=(fa|0)>(X|0)?X:fa;if((aa|0)==0){Da=fa-ca|0}else{Da=fa+aa>>1}$=gHb(ca,(ca|0)<0|0?-1:0,5,0)|0;_=F;ja=0;la=(Da|0)<1?1:Da;if((la|0)==(da|0)){Ea=da;break}else{C=la;V=aa;X=da;Y=(_|0)>(ja|0)|(_|0)==(ja|0)&$>>>0>2147483647>>>0?2147483647:$;Z=1024}}if((ia|0)==28){ia=0;if(ya>>>0>za>>>0){ia=88;break a}else{Ea=fa}}c[D>>2]=Ea}else{Z=c[u>>2]|0;Y=2147483647;X=0;V=1;C=c[B>>2]|0;d:while(1){$=(X|0)==0;ja=Z;_=Y;da=1;la=V;ma=C;while(1){c[u>>2]=ja;ha=c[r>>2]|0;Pe[c[ha+828>>2]&255](ha,724,0,0,ma)|0;Fa=c[B>>2]|0;ha=0;ra=0;while(1){if((ha|0)>=(Fa|0)){ia=44;break}ka=c[E>>2]|0;if((ka|0)>0){qa=c[H>>2]|0;oa=ba(ka,ha)|0;pa=ra;ua=0;while(1){ta=(c[qa+(ja*65280|0)+(ua+oa<<3)+4>>2]|0)+pa|0;sa=ua+1|0;if((sa|0)<(ka|0)){pa=ta;ua=sa}else{Ga=ta;break}}}else{Ga=ra}ua=Ga+31&-32;pa=c[G>>2]|0;if(ua>>>0>pa>>>0){Ha=ua;Ia=pa;break}else{ha=ha+1|0;ra=ua}}if((ia|0)==44){ia=0;Ha=ra;Ia=c[G>>2]|0}if(!(Ha>>>0<Ia>>>0)){break}if((ja|0)==1){Ja=1;break d}if((X|0)==(ja-1|0)){Ka=X;ia=61;break d}ha=(ja|0)>(_|0)?_:ja;if($){La=ja-da|0;Ma=da+1|0}else{La=ja+X>>1;Ma=da}ja=(La|0)<1?1:La;_=ha;da=Ma;la=1;ma=Fa}if((_|0)==(ja+1|0)){Ka=ja;ia=61;break}if((_|0)==2147483647){Na=ja+la|0;Oa=la+1|0}else{Na=ja+_>>1;Oa=la}if((Na|0)<(c[(c[r>>2]|0)+504>>2]|0)){Z=Na;Y=_;X=(ja|0)>(X|0)?ja:X;V=Oa;C=Fa}else{ia=88;break a}}if((ia|0)==61){ia=0;c[u>>2]=Ka;Ja=0}if((Fa|0)>0){C=0;V=0;X=c[E>>2]|0;Y=Fa;while(1){if((X|0)>0){Z=0;ma=V;da=X;$=c[u>>2]&255;while(1){aa=Z+(ba(da,C)|0)|0;a[(c[I>>2]|0)+aa|0]=$;ca=c[u>>2]|0;ha=c[(c[H>>2]|0)+(ca*65280|0)+(aa<<3)+4>>2]|0;b[(c[J>>2]|0)+(aa<<1)>>1]=ha;Pa=ha+ma|0;ha=Z+1|0;Qa=c[E>>2]|0;if((ha|0)<(Qa|0)){Z=ha;ma=Pa;da=Qa;$=ca&255}else{break}}Ra=Pa;Sa=Qa;Ta=c[B>>2]|0}else{Ra=V;Sa=X;Ta=Y}$=Ra+31|0;da=C+1|0;if((da|0)<(Ta|0)){C=da;V=$;X=Sa;Y=Ta}else{Ua=$;Va=Ta;break}}}else{Ua=0;Va=Fa}if((Ja|0)!=0){break}Pe[c[n>>2]&255](d,2,0,0,Va)|0;Y=c[N>>2]|0;X=c[O>>2]|0;V=WDb(X<<3)|0;C=V;TGb(P|0,0,4096)|0;$=(X|0)>0;if($){da=0;while(1){ma=c[Y+(da<<3)+4>>2]|0;Z=k+((ma&255^255)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;Z=k+1024+((ma>>>8&255^255)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;Z=k+2048+((ma>>>16&255^255)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;Z=k+3072+((ma>>>24^255)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;Z=da+1|0;if((Z|0)<(X|0)){da=Z}else{Wa=255;Xa=X;break}}}else{Wa=255;Xa=X}while(1){da=k+(Wa<<2)|0;Z=Xa-(c[da>>2]|0)|0;c[da>>2]=Z;if((Wa|0)>0){Wa=Wa-1|0;Xa=Z}else{Ya=255;Za=X;break}}while(1){Z=k+1024+(Ya<<2)|0;da=Za-(c[Z>>2]|0)|0;c[Z>>2]=da;if((Ya|0)>0){Ya=Ya-1|0;Za=da}else{_a=255;$a=X;break}}while(1){da=k+2048+(_a<<2)|0;Z=$a-(c[da>>2]|0)|0;c[da>>2]=Z;if((_a|0)>0){_a=_a-1|0;$a=Z}else{ab=255;bb=X;break}}while(1){Z=k+3072+(ab<<2)|0;da=bb-(c[Z>>2]|0)|0;c[Z>>2]=da;if((ab|0)>0){ab=ab-1|0;bb=da}else{break}}if($){da=0;while(1){Z=k+((c[Y+(da<<3)+4>>2]&255^255)<<2)|0;ma=c[Z>>2]|0;c[Z>>2]=ma+1;Z=Y+(da<<3)|0;ja=C+(ma<<3)|0;ma=c[Z+4>>2]|0;c[ja>>2]=c[Z>>2];c[ja+4>>2]=ma;ma=da+1|0;if((ma|0)<(X|0)){da=ma}else{cb=0;break}}do{da=k+1024+(((c[C+(cb<<3)+4>>2]|0)>>>8&255^255)<<2)|0;ma=c[da>>2]|0;c[da>>2]=ma+1;da=C+(cb<<3)|0;ja=Y+(ma<<3)|0;ma=c[da+4>>2]|0;c[ja>>2]=c[da>>2];c[ja+4>>2]=ma;cb=cb+1|0;}while((cb|0)<(X|0))}if((c[Q>>2]|0)==0){if(!((c[R>>2]|0)==0|$^1)){db=0;ia=82}}else{if($){db=0;ia=82}}do{if((ia|0)==82){while(1){ia=0;ma=k+2048+(((c[Y+(db<<3)+4>>2]|0)>>>16&255^255)<<2)|0;ja=c[ma>>2]|0;c[ma>>2]=ja+1;ma=Y+(db<<3)|0;da=C+(ja<<3)|0;ja=c[ma+4>>2]|0;c[da>>2]=c[ma>>2];c[da+4>>2]=ja;ja=db+1|0;if((ja|0)<(X|0)){db=ja;ia=82}else{break}}if($){eb=0}else{break}do{ja=k+3072+(((c[C+(eb<<3)+4>>2]|0)>>>24^255)<<2)|0;da=c[ja>>2]|0;c[ja>>2]=da+1;ja=C+(eb<<3)|0;ma=Y+(da<<3)|0;da=c[ja+4>>2]|0;c[ma>>2]=c[ja>>2];c[ma+4>>2]=da;eb=eb+1|0;}while((eb|0)<(X|0))}}while(0);ZDb(V);if((c[O>>2]|0)>0){fb=0;gb=Ua}else{break}do{if(!(gb>>>0>(c[G>>2]|0)>>>0)){break b}X=e[(c[N>>2]|0)+(fb<<3)>>1]|0;Y=c[u>>2]|0;C=c[H>>2]|0;$=Y+1|0;gb=gb-(c[C+(Y*65280|0)+(X<<3)+4>>2]|0)+(c[C+($*65280|0)+(X<<3)+4>>2]|0)|0;a[(c[I>>2]|0)+X|0]=$;b[(c[J>>2]|0)+(X<<1)>>1]=c[(c[H>>2]|0)+(((c[u>>2]|0)+1|0)*65280|0)+(X<<3)+4>>2];fb=fb+1|0;}while((fb|0)<(c[O>>2]|0))}}while(0);V=c[B>>2]|0;do{if((V|0)>0){X=c[K>>2]|0;$=c[L>>2]|0;C=0;Y=0;while(1){c[X+(Y<<2)>>2]=C;da=$+(Y<<2)|0;c[da>>2]=0;ma=c[E>>2]|0;if((ma|0)>0){ja=c[J>>2]|0;Z=0;_=ma;ma=0;do{ma=(e[ja+((ba(_,Y)|0)+Z<<1)>>1]|0)+ma|0;c[da>>2]=ma;Z=Z+1|0;_=c[E>>2]|0;}while((Z|0)<(_|0));hb=(ma+31|0)>>>3&536870908}else{hb=0}c[da>>2]=hb;_=Y+1|0;ib=c[B>>2]|0;if((_|0)<(ib|0)){C=hb+C|0;Y=_}else{break}}if((ib|0)>0){jb=0;kb=0}else{lb=0;mb=ib;break}while(1){Y=fe(jb|0)|0;C=(c[M>>2]|0)+(kb<<2)|0;x=Y;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=(c[(c[L>>2]|0)+(kb<<2)>>2]|0)+jb|0;Y=kb+1|0;$=c[B>>2]|0;if((Y|0)<($|0)){jb=C;kb=Y}else{lb=C;mb=$;break}}}else{lb=0;mb=V}}while(0);Pe[c[n>>2]&255](d,602,S,0,mb)|0;TGb(S+(lb+640)|0,0,-644-lb+(c[(c[o>>2]|0)+20>>2]|0)|0)|0;V=S+((c[(c[o>>2]|0)+20>>2]|0)-4)|0;x=-557839008;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=c[A>>2]|0;if((V|0)==0|(p|0)==0){ia=100;break}$=c[t>>2]^1;c[t>>2]=$;S=S+(c[(c[o>>2]|0)+20>>2]|0)|0;p=0;T=V;U=$}if((ia|0)==88){yDb(d,16,2190064,(U=i,i=i+1|0,i=i+7&-8,c[U>>2]=0,U)|0);i=U;q=-22;i=j;return q|0}else if((ia|0)==100){c[(c[d+804>>2]|0)+168>>2]=(c[u>>2]|0)*118|0;u=f+36|0;c[u>>2]=c[u>>2]|1;c[h>>2]=1;q=0;i=j;return q|0}return 0}function f2(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;d=-2<<(c[(c[b+14684>>2]|0)+28>>2]|0)+2;ZDb((c[b+15920>>2]|0)+(d<<2)|0);ZDb((c[b+15924>>2]|0)+d|0);$Db(b+15928|0);$Db(b+15932|0);$Db(b+15948|0);$Db(b+15952|0);$Db(b+15960|0);$Db(b+15956|0);$Db(b+14692|0);$Db(b+14696|0);$Db(b+15888|0);$Db(b+15892|0);$Db(b+15900|0);$Db(b+15896|0);d=a+808|0;if((c[d>>2]|0)<=1){e=a+804|0;JCb(e);return 0}f=b+14700|0;b=1;do{$Db(f+(b<<2)|0);b=b+1|0;}while((b|0)<(c[d>>2]|0));e=a+804|0;JCb(e);return 0}function g2(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;k=i;i=i+8|0;l=k|0;m=c[(c[f+60>>2]|0)+14700+(j<<2)>>2]|0;j=m+8|0;f=c[(c[m+14692>>2]|0)+(h<<2)>>2]|0;n=(f|0)<0;o=n?0:g+((c[(c[m+14696>>2]|0)+(h<<2)>>2]|0)+640)|0;g=n?0:f;c[m+812>>2]=g<<3;f=m+800|0;c[f>>2]=o;c[m+808>>2]=o+g;g=m+804|0;c[g>>2]=o;n=m+796|0;c[n>>2]=32;p=m+792|0;c[p>>2]=0;q=m+14684|0;r=1<<(c[(c[q>>2]|0)+28>>2]|0)+2;c[m+9876>>2]=r;c[m+9872>>2]=r;c[m+9868>>2]=r;r=m+124|0;s=c[r>>2]|0;if((s|0)>0){t=m+15952|0;u=m+14836|0;v=m+14700|0;w=h<<4;y=m+156|0;z=m+160|0;A=m+10064|0;B=m+14864|0;C=m+14992|0;D=m+15120|0;E=m+15248|0;F=h+1|0;G=m+128|0;H=m+12|0;I=m+14840|0;J=m+10100|0;K=m+15376|0;L=m+15504|0;M=m+15632|0;N=m+15760|0;O=m+15964|0;P=m+14828|0;Q=m+14832|0;R=m+14400|0;S=m+15924|0;T=m+15920|0;U=m+15932|0;V=m+15928|0;W=0;X=s;s=0;Y=32;while(1){Z=(ba(X,h)|0)+W|0;_=d[(c[t>>2]|0)+Z|0]|0;Z=_<<1;if((Y|0)>12){$=Y-12|0;aa=s<<12|Z}else{ca=fe(Z>>>((12-Y|0)>>>0)|s<<Y|0)|0;da=c[g>>2]|0;x=ca;a[da]=x;x=x>>8;a[da+1|0]=x;x=x>>8;a[da+2|0]=x;x=x>>8;a[da+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;$=Y+20|0;aa=Z}c[p>>2]=aa;c[n>>2]=$;Z=c[u>>2]|0;da=c[v>>2]|0;ca=c[da+15908>>2]|0;ea=c[y>>2]|0;fa=(ba(ea,w)|0)+(W<<Z+1)|0;ga=c[da+15912>>2]|0;ha=(ba(c[z>>2]|0,w)|0)+(W<<Z)|0;ia=c[da+15916>>2]|0;Xe[c[A>>2]&4095](B,ca+fa|0,ea);ea=fa+(1<<Z)|0;Xe[c[A>>2]&4095](C,ca+ea|0,c[y>>2]|0);Xe[c[A>>2]&4095](D,ga+ha|0,c[z>>2]|0);Xe[c[A>>2]&4095](E,ia+ha|0,c[z>>2]|0);do{if((F|0)==(c[G>>2]|0)){if((c[(c[H>>2]|0)+124>>2]|0)!=1080){ja=11;break}if((c[I>>2]|0)==0){me[c[J>>2]&511](K);me[c[J>>2]&511](L);me[c[J>>2]&511](M);me[c[J>>2]&511](N);ka=0;break}else{Xe[c[O>>2]&4095](K,ca+((c[P>>2]|0)+fa)|0,c[y>>2]|0);Xe[c[O>>2]&4095](L,ca+((c[P>>2]|0)+ea)|0,c[y>>2]|0);Xe[c[O>>2]&4095](M,ga+((c[Q>>2]|0)+ha)|0,c[z>>2]|0);Xe[c[O>>2]&4095](N,ia+((c[Q>>2]|0)+ha)|0,c[z>>2]|0);ka=0;break}}else{ja=11}}while(0);if((ja|0)==11){ja=0;Xe[c[A>>2]&4095](K,ca+((c[P>>2]|0)+fa)|0,c[y>>2]|0);Xe[c[A>>2]&4095](L,ca+((c[P>>2]|0)+ea)|0,c[y>>2]|0);Xe[c[A>>2]&4095](M,ga+((c[Q>>2]|0)+ha)|0,c[z>>2]|0);Xe[c[A>>2]&4095](N,ia+((c[Q>>2]|0)+ha)|0,c[z>>2]|0);ka=0}do{Z=m+14864+(ka<<7)|0;da=d[1349896+ka|0]|0;la=Pe[c[R>>2]&255](j,Z,ka<<1&4,_,l)|0;ma=b[Z>>1]|0;na=m+9868+(da<<2)|0;da=(ma<<16>>16)-(c[na>>2]|0)|0;if((da|0)<0){oa=da*-2|0;pa=(oa&65280|0)==0;qa=(d[1191992+(pa?oa:oa>>>8)|0]|0)+(pa?0:8)|0;ra=da-1|0}else{pa=da<<1;oa=(pa&65280|0)==0;qa=(d[1191992+(oa?pa:da>>>7&16777215)|0]|0)+(oa?0:8)|0;ra=da}da=c[q>>2]|0;oa=(d[(c[da+48>>2]|0)+qa|0]|0)+qa|0;pa=((d[(c[da+44>>2]|0)+qa|0]|0)<<qa)+((1<<qa)-1&ra)|0;da=c[p>>2]|0;sa=c[n>>2]|0;if((sa|0)>(oa|0)){ta=sa-oa|0;ua=pa|da<<oa;va=ma}else{ma=fe(pa>>>((oa-sa|0)>>>0)|da<<sa|0)|0;da=c[g>>2]|0;x=ma;a[da]=x;x=x>>8;a[da+1|0]=x;x=x>>8;a[da+2|0]=x;x=x>>8;a[da+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;ta=32-oa+sa|0;ua=pa;va=b[Z>>1]|0}c[p>>2]=ua;c[n>>2]=ta;c[na>>2]=va<<16>>16;if((la|0)>=1){na=1;Z=0;while(1){pa=b[m+14864+(ka<<7)+((d[m+376+na|0]|0)<<1)>>1]|0;do{if(pa<<16>>16==0){wa=Z}else{sa=na-Z-1|0;oa=(sa|0)!=0;da=pa<<16>>16<<1|oa&1;ma=d[(c[S>>2]|0)+da|0]|0;xa=c[(c[T>>2]|0)+(da<<2)>>2]|0;da=c[p>>2]|0;ya=c[n>>2]|0;if((ya|0)>(ma|0)){za=ya-ma|0;Aa=da<<ma|xa}else{Ba=fe(xa>>>((ma-ya|0)>>>0)|da<<ya|0)|0;da=c[g>>2]|0;x=Ba;a[da]=x;x=x>>8;a[da+1|0]=x;x=x>>8;a[da+2|0]=x;x=x>>8;a[da+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;za=32-ma+ya|0;Aa=xa}c[p>>2]=Aa;c[n>>2]=za;if(!oa){wa=na;break}oa=d[(c[U>>2]|0)+sa|0]|0;xa=e[(c[V>>2]|0)+(sa<<1)>>1]|0;if((za|0)>(oa|0)){Ca=za;Da=xa|Aa<<oa}else{sa=fe(xa>>>((oa-za|0)>>>0)|Aa<<za|0)|0;ya=c[g>>2]|0;x=sa;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;Ca=za+32|0;Da=xa}c[p>>2]=Da;c[n>>2]=Ca-oa;wa=na}}while(0);pa=na+1|0;if((pa|0)>(la|0)){break}else{na=pa;Z=wa}}}Z=d[c[S>>2]|0]|0;na=c[c[T>>2]>>2]|0;la=c[p>>2]|0;pa=c[n>>2]|0;if((pa|0)>(Z|0)){Ea=pa-Z|0;Fa=la<<Z|na}else{oa=fe(na>>>((Z-pa|0)>>>0)|la<<pa|0)|0;la=c[g>>2]|0;x=oa;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;Ea=32-Z+pa|0;Fa=na}c[p>>2]=Fa;c[n>>2]=Ea;ka=ka+1|0;}while((ka|0)<8);_=W+1|0;ha=c[r>>2]|0;if((_|0)<(ha|0)){W=_;X=ha;s=Fa;Y=Ea}else{break}}Ga=Ea;Ha=c[f>>2]|0;Ia=c[g>>2]|0;Ja=Fa}else{Ga=32;Ha=o;Ia=o;Ja=0}o=32-Ga+(Ia-Ha<<3)&31;if((o|0)==0){Ka=Ga;La=Ja;Ma=Ia}else{Ha=32-o|0;if((Ga|0)>(Ha|0)){Na=Ga-Ha|0;Oa=Ja<<Ha;Pa=Ia}else{Ha=Ia;x=fe(Ja<<Ga|0)|0;a[Ha]=x;x=x>>8;a[Ha+1|0]=x;x=x>>8;a[Ha+2|0]=x;x=x>>8;a[Ha+3|0]=x;Ha=(c[g>>2]|0)+4|0;c[g>>2]=Ha;Na=Ga+o|0;Oa=0;Pa=Ha}c[p>>2]=Oa;c[n>>2]=Na;Ka=Na;La=Oa;Ma=Pa}if((Ka|0)>=32){c[n>>2]=32;c[p>>2]=0;i=k;return 0}Pa=La<<Ka;c[p>>2]=Pa;Ka=Pa>>>24&255;Pa=Ma;while(1){c[g>>2]=Pa+1;a[Pa]=Ka;Ma=c[p>>2]|0;c[p>>2]=Ma<<8;La=(c[n>>2]|0)+8|0;c[n>>2]=La;if((La|0)>=32){break}Ka=Ma>>>16&255;Pa=c[g>>2]|0}c[n>>2]=32;c[p>>2]=0;i=k;return 0}function h2(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=c[a+60>>2]|0;if(((c[f+128>>2]|0)-1|0)==(g|0)){i=(c[a+124>>2]>>c[f+14840>>2]&15|0)!=0}else{i=0}j=c[f+14700+(h<<2)>>2]|0;h=j+156|0;if((c[(c[j+14684>>2]|0)+28>>2]|0)!=8){f=c[h>>2]>>1;k=j+124|0;l=c[k>>2]|0;if((l|0)<=0){return 0}m=c[(c[j+14700>>2]|0)+15908>>2]|0;n=ba(f,g)|0;o=c[j+15956>>2]|0;p=0;q=l;do{l=ba(q,g)|0;r=m+(p+n<<4<<1)|0;s=0;t=0;u=0;while(1){v=s;w=t;x=0;do{y=(e[r+(x<<1)>>1]|0)>>>6;v=y+v|0;w=(ba(y,y)|0)+w|0;x=x+1|0;}while((x|0)<16);x=u+1|0;if((x|0)<16){r=r+(f<<1)|0;s=v;t=w;u=x}else{break}}u=l+p|0;t=v>>8;c[o+(u<<3)+4>>2]=(w>>8)-(ba(t,t)|0);b[o+(u<<3)>>1]=u;p=p+1|0;q=c[k>>2]|0;}while((p|0)<(q|0));return 0}q=j+124|0;p=c[q>>2]|0;if((p|0)<=0){return 0}k=g<<4;o=ba(k,c[h>>2]|0)|0;w=a+120|0;v=a+124|0;a=j+14840|0;f=j+15956|0;n=j+10108|0;m=j+10112|0;u=(c[(c[j+14700>>2]|0)+15908>>2]|0)+o|0;o=0;j=p;while(1){p=(ba(j,g)|0)+o|0;do{if(i){z=c[w>>2]|0;A=o<<4;B=10}else{t=o<<4;s=c[w>>2]|0;if((t|0)>(s-16|0)){z=s;A=t;B=10;break}t=Oe[c[n>>2]&1023](u,c[h>>2]|0)|0;C=t;D=Oe[c[m>>2]&1023](u,c[h>>2]|0)|0}}while(0);do{if((B|0)==10){B=0;l=z-A|0;t=(l|0)>16?16:l;l=(c[v>>2]>>c[a>>2])-k|0;s=(l|0)>16?16:l;if((s|0)<=0){C=0;D=0;break}l=(t|0)>0;r=0;x=0;y=0;while(1){if(l){E=ba(c[h>>2]|0,y)|0;F=r;G=x;H=0;while(1){I=d[u+(E+H)|0]|0;J=I+G|0;K=(ba(I,I)|0)+F|0;I=H+1|0;if((I|0)<(t|0)){F=K;G=J;H=I}else{L=K;M=J;break}}}else{L=r;M=x}H=y+1|0;if((H|0)<(s|0)){r=L;x=M;y=H}else{C=M;D=L;break}}}}while(0);y=(D+128-((ba(C,C)|0)>>>8)|0)>>>8;x=c[f>>2]|0;c[x+(p<<3)+4>>2]=y;b[x+(p<<3)>>1]=p;x=o+1|0;y=c[q>>2]|0;if((x|0)<(y|0)){u=u+16|0;o=x;j=y}else{break}}return 0}function i2(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;f=i;i=i+136|0;j=f|0;k=f+128|0;l=c[e+60>>2]|0;m=c[l+15940>>2]|0;n=j|0;o=c[l+14700+(h<<2)>>2]|0;h=o+14684|0;l=1<<(c[(c[h>>2]|0)+28>>2]|0)+2;p=o+8|0;c[o+9876>>2]=l;c[o+9872>>2]=l;c[o+9868>>2]=l;l=o+124|0;q=c[l>>2]|0;if((q|0)<=0){i=f;return 0}r=o+14836|0;s=o+14700|0;t=g<<4;u=o+156|0;v=o+160|0;w=o+10064|0;x=o+14864|0;y=o+14992|0;z=o+15120|0;A=o+15248|0;B=g+1|0;C=o+128|0;D=o+12|0;E=o+14840|0;F=o+10100|0;G=o+15376|0;H=o+15504|0;I=o+15632|0;J=o+15760|0;K=o+15964|0;L=o+14828|0;M=o+14832|0;N=j;O=o+14400|0;P=e+296|0;e=o+11180|0;Q=o+15924|0;R=o+15932|0;S=o+15960|0;T=0;U=q;do{q=(ba(U,g)|0)+T|0;V=c[r>>2]|0;W=c[s>>2]|0;X=c[W+15908>>2]|0;Y=c[u>>2]|0;Z=(ba(Y,t)|0)+(T<<V+1)|0;_=c[W+15912>>2]|0;$=(ba(c[v>>2]|0,t)|0)+(T<<V)|0;aa=c[W+15916>>2]|0;Xe[c[w>>2]&4095](x,X+Z|0,Y);Y=Z+(1<<V)|0;Xe[c[w>>2]&4095](y,X+Y|0,c[u>>2]|0);Xe[c[w>>2]&4095](z,_+$|0,c[v>>2]|0);Xe[c[w>>2]&4095](A,aa+$|0,c[v>>2]|0);do{if((B|0)==(c[C>>2]|0)){if((c[(c[D>>2]|0)+124>>2]|0)!=1080){ca=8;break}if((c[E>>2]|0)==0){me[c[F>>2]&511](G);me[c[F>>2]&511](H);me[c[F>>2]&511](I);me[c[F>>2]&511](J);da=0;ea=0;fa=0;ga=0;break}else{Xe[c[K>>2]&4095](G,X+((c[L>>2]|0)+Z)|0,c[u>>2]|0);Xe[c[K>>2]&4095](H,X+((c[L>>2]|0)+Y)|0,c[u>>2]|0);Xe[c[K>>2]&4095](I,_+((c[M>>2]|0)+$)|0,c[v>>2]|0);Xe[c[K>>2]&4095](J,aa+((c[M>>2]|0)+$)|0,c[v>>2]|0);da=0;ea=0;fa=0;ga=0;break}}else{ca=8}}while(0);if((ca|0)==8){ca=0;Xe[c[w>>2]&4095](G,X+((c[L>>2]|0)+Z)|0,c[u>>2]|0);Xe[c[w>>2]&4095](H,X+((c[L>>2]|0)+Y)|0,c[u>>2]|0);Xe[c[w>>2]&4095](I,_+((c[M>>2]|0)+$)|0,c[v>>2]|0);Xe[c[w>>2]&4095](J,aa+((c[M>>2]|0)+$)|0,c[v>>2]|0);da=0;ea=0;fa=0;ga=0}while(1){V=d[1349896+ea|0]|0;UGb(N|0,o+14864+(ea<<7)|0,128)|0;W=Pe[c[O>>2]&255](p,n,ea<<1&4,m,k)|0;ha=(W|0)<1;if(ha){ia=0}else{ja=1;ka=0;la=0;while(1){ma=b[j+(d[o+376+ja|0]<<1)>>1]|0;if(ma<<16>>16==0){na=la;oa=ka}else{pa=ja-la-1|0;na=ja;oa=(d[(c[Q>>2]|0)+(ma<<16>>16<<1|(pa|0)!=0)|0]|0)+ka+(d[(c[R>>2]|0)+pa|0]|0)|0}pa=ja+1|0;if((pa|0)>(W|0)){ia=oa;break}else{ja=pa;ka=oa;la=na}}}qa=ia+fa|0;la=b[n>>1]|0;ka=o+9868+(V<<2)|0;ja=la-(c[ka>>2]|0)|0;if((ja|0)<0){ra=ja*-2|0}else{ra=ja<<1}ja=(ra&65280|0)==0;pa=(ja?0:8)+(d[1191992+(ja?ra:ra>>>8)|0]|0)|0;sa=pa+da+(d[(c[(c[h>>2]|0)+48>>2]|0)+pa|0]|0)|0;c[ka>>2]=la;if((c[P>>2]|0)==2){la=c[h>>2]|0;ka=c[((ea&2|0)==0?la+36|0:la+40|0)>>2]|0;if(!ha){pa=la+28|0;la=1;do{ja=j+(d[o+376+la|0]<<1)|0;ma=b[ja>>1]|0;if(!(ma<<16>>16==0)){ta=ma<<16>>16<<1;do{if(ma<<16>>16<0){ua=ba(1-ta|0,m)|0;va=a[ka+la|0]|0;wa=ba(ua,va&255)|0;if((c[pa>>2]|0)==10){xa=(va<<24>>24==8?wa:wa+8|0)>>4}else{xa=(va<<24>>24==32?wa:wa+32|0)>>6}ya=-xa&65535}else{wa=ba(ta|1,m)|0;va=a[ka+la|0]|0;ua=ba(wa,va&255)|0;if((c[pa>>2]|0)==10){if(va<<24>>24==8){ya=ua>>>4&65535;break}ya=(ua+8|0)>>>4&65535;break}else{if(va<<24>>24==32){ya=ua>>>6&65535;break}ya=(ua+32|0)>>>6&65535;break}}}while(0);b[ja>>1]=ya}la=la+1|0;}while((la|0)<=(W|0))}me[c[e>>2]&511](n);W=0;la=0;do{pa=(b[o+14864+(ea<<7)+(la<<1)>>1]|0)-(b[j+(la<<1)>>1]|0)|0;W=(ba(pa,pa)|0)+W|0;la=la+1|0;}while((la|0)<64);za=W+ga|0}else{za=ga}la=ea+1|0;if((la|0)<8){da=sa;ea=la;fa=qa;ga=za}else{break}}$=c[S>>2]|0;c[$+(m*65280|0)+(q<<3)>>2]=za;c[$+(m*65280|0)+(q<<3)+4>>2]=sa+12+qa+(d[c[Q>>2]|0]<<3);T=T+1|0;U=c[l>>2]|0;}while((T|0)<(U|0));i=f;return 0}function j2(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;h=c[a+364>>2]|0;i=c[((f|0)<4?a+13160|0:a+13164|0)>>2]|0;me[c[a+11164>>2]&511](e);b[e>>1]=((b[e>>1]|0)+2|0)>>>2;a=1;f=0;do{j=d[h+a|0]|0;k=e+(j<<1)|0;l=b[k>>1]|0;m=l>>31;n=(ba((m^l)-m|0,c[i+(g<<8)+(j<<2)>>2]|0)|0)>>18;b[k>>1]=(n^m)-m;f=(n|0)==0?f:a;a=a+1|0;}while((a|0)<64);return f|0}function k2(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=c;f=d>>1;b[a>>1]=b[e>>1]|0;b[a+2>>1]=b[c+2>>1]|0;b[a+4>>1]=b[c+4>>1]|0;b[a+6>>1]=b[c+6>>1]|0;b[a+8>>1]=b[c+8>>1]|0;b[a+10>>1]=b[c+10>>1]|0;b[a+12>>1]=b[c+12>>1]|0;b[a+14>>1]=b[c+14>>1]|0;b[a+16>>1]=b[e+(f<<1)>>1]|0;b[a+18>>1]=b[e+(f+1<<1)>>1]|0;b[a+20>>1]=b[e+(f+2<<1)>>1]|0;b[a+22>>1]=b[e+(f+3<<1)>>1]|0;b[a+24>>1]=b[e+(f+4<<1)>>1]|0;b[a+26>>1]=b[e+(f+5<<1)>>1]|0;b[a+28>>1]=b[e+(f+6<<1)>>1]|0;b[a+30>>1]=b[e+(f+7<<1)>>1]|0;c=f<<1;b[a+32>>1]=b[e+(c<<1)>>1]|0;b[a+34>>1]=b[e+((c|1)<<1)>>1]|0;b[a+36>>1]=b[e+(c+2<<1)>>1]|0;b[a+38>>1]=b[e+(c+3<<1)>>1]|0;b[a+40>>1]=b[e+(c+4<<1)>>1]|0;b[a+42>>1]=b[e+(c+5<<1)>>1]|0;b[a+44>>1]=b[e+(c+6<<1)>>1]|0;b[a+46>>1]=b[e+(c+7<<1)>>1]|0;d=c+f|0;b[a+48>>1]=b[e+(d<<1)>>1]|0;b[a+50>>1]=b[e+(d+1<<1)>>1]|0;b[a+52>>1]=b[e+(d+2<<1)>>1]|0;b[a+54>>1]=b[e+(d+3<<1)>>1]|0;b[a+56>>1]=b[e+(d+4<<1)>>1]|0;b[a+58>>1]=b[e+(d+5<<1)>>1]|0;b[a+60>>1]=b[e+(d+6<<1)>>1]|0;b[a+62>>1]=b[e+(d+7<<1)>>1]|0;UGb(a+64|0,a+48|0,16)|0;UGb(a+80|0,a+32|0,16)|0;UGb(a+96|0,a+16|0,16)|0;UGb(a+112|0,a|0,16)|0;return}function l2(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0;b[a>>1]=d[c]|0;b[a+2>>1]=d[c+1|0]|0;b[a+4>>1]=d[c+2|0]|0;b[a+6>>1]=d[c+3|0]|0;b[a+8>>1]=d[c+4|0]|0;b[a+10>>1]=d[c+5|0]|0;b[a+12>>1]=d[c+6|0]|0;b[a+14>>1]=d[c+7|0]|0;b[a+16>>1]=d[c+e|0]|0;b[a+18>>1]=d[c+(e+1)|0]|0;b[a+20>>1]=d[c+(e+2)|0]|0;b[a+22>>1]=d[c+(e+3)|0]|0;b[a+24>>1]=d[c+(e+4)|0]|0;b[a+26>>1]=d[c+(e+5)|0]|0;b[a+28>>1]=d[c+(e+6)|0]|0;b[a+30>>1]=d[c+(e+7)|0]|0;f=e<<1;b[a+32>>1]=d[c+f|0]|0;b[a+34>>1]=d[c+(f|1)|0]|0;b[a+36>>1]=d[c+(f+2)|0]|0;b[a+38>>1]=d[c+(f+3)|0]|0;b[a+40>>1]=d[c+(f+4)|0]|0;b[a+42>>1]=d[c+(f+5)|0]|0;b[a+44>>1]=d[c+(f+6)|0]|0;b[a+46>>1]=d[c+(f+7)|0]|0;g=f+e|0;b[a+48>>1]=d[c+g|0]|0;b[a+50>>1]=d[c+(g+1)|0]|0;b[a+52>>1]=d[c+(g+2)|0]|0;b[a+54>>1]=d[c+(g+3)|0]|0;b[a+56>>1]=d[c+(g+4)|0]|0;b[a+58>>1]=d[c+(g+5)|0]|0;b[a+60>>1]=d[c+(g+6)|0]|0;b[a+62>>1]=d[c+(g+7)|0]|0;UGb(a+64|0,a+48|0,16)|0;UGb(a+80|0,a+32|0,16)|0;UGb(a+96|0,a+16|0,16)|0;UGb(a+112|0,a|0,16)|0;return}function m2(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=c[a+60>>2]|0;if(((c[a+416>>2]|0)-1|0)>>>0>1>>>0){yDb(a,16,2290392,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=d;return g|0}h=e+516|0;c[h>>2]=0;j=e+512|0;c[j>>2]=0;k=a+12|0;l=c[(c[k>>2]|0)+12>>2]|0;do{if((l|0)==81920){m=e;n=0;do{o=(ba(n,n)|0)&65535;b[m+(n<<1)>>1]=o;b[m+(n+128<<1)>>1]=-o;n=n+1|0;}while((n|0)<128)}else if((l|0)==81923){n=c[a+52>>2]|0;if((n|0)==2){c[e+520>>2]=435096;c[h>>2]=128;c[j>>2]=128;break}else if((n|0)==3){break}else if((n|0)==1){c[e+520>>2]=435080;c[h>>2]=128;c[j>>2]=128;break}else{yDb(a,16,2274488,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1;i=d;return g|0}}}while(0);do{if((c[(c[k>>2]|0)+12>>2]|0)==81923){if((c[a+52>>2]|0)==3){break}c[a+420>>2]=0;g=0;i=d;return g|0}}while(0);c[a+420>>2]=1;g=0;i=d;return g|0}function n2(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=l;n=h+28|0;o=c[n>>2]|0;p=c[e+60>>2]|0;q=f;r=e+416|0;s=c[r>>2]|0;t=s-1|0;u=(t|0)!=0;if(u){v=(o<<31>>31)+o|0}else{v=o}o=c[h+24>>2]|0;if(!((v|0)>-1)){yDb(0,0,2353768,(w=i,i=i+24|0,c[w>>2]=2333776,c[w+8>>2]=2309112,c[w+16>>2]=135,w)|0);i=w;Cd();return 0}h=e+12|0;x=c[(c[h>>2]|0)+12>>2]|0;if((x|0)==81923){y=v<<((c[e+52>>2]|0)!=3);z=10}else if((x|0)==81920){y=v-8|0;z=10}else if((x|0)==81922){y=v-(s<<1)|0;z=10}else if((x|0)==81921){y=v-6-s|0;z=10}do{if((z|0)==10){if((y|0)<1){break}if(((y|0)%(s|0)|0|0)==0){A=s}else{yDb(e,24,1896592,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;A=c[r>>2]|0}c[f+76>>2]=(y-1+A|0)/(A|0)|0;v=_$a(e,q,0)|0;if((v|0)<0){B=v;i=j;return B|0}v=c[f>>2]|0;x=v;C=x+(y<<1)|0;D=c[(c[h>>2]|0)+12>>2]|0;a:do{if((D|0)==81921){E=o+6|0;F=c[r>>2]|0;if((F|0)>0){G=E;H=x;I=0;while(1){J=G+2|0;K=G;L=(d[K]|d[K+1|0]<<8)<<16>>16;c[k+(I<<2)>>2]=L<<16>>16;K=H+2|0;b[H>>1]=L;L=I+1|0;if((L|0)<(F|0)){G=J;H=K;I=L}else{M=J;N=K;break}}}else{M=E;N=x}if(N>>>0<C>>>0){O=M;P=N;Q=0}else{break}while(1){I=k+(Q<<2)|0;H=(c[I>>2]|0)+(b[908296+(d[O]<<1)>>1]|0)|0;if((H+32768|0)>>>0>65535>>>0){R=(H>>31^32767)&65535}else{R=H&65535}c[I>>2]=R<<16>>16;I=P+2|0;b[P>>1]=R;if(!(I>>>0<C>>>0)){break a}O=O+1|0;P=I;Q=Q^t}}else if((D|0)==81920){E=o+6|0;if(u){c[k+4>>2]=d[E]<<24>>16;I=d[o+7|0]<<24>>16;c[k>>2]=I;S=I}else{I=E;E=(d[I]|d[I+1|0]<<8)<<16>>16<<16>>16;c[k>>2]=E;S=E}if(!(x>>>0<C>>>0)){break}E=p;I=o+8|0;H=x;G=0;F=S;while(1){K=F+(b[E+(d[I]<<1)>>1]|0)|0;if((K+32768|0)>>>0>65535>>>0){T=(K>>31^32767)&65535}else{T=K&65535}c[k+(G<<2)>>2]=T<<16>>16;K=H+2|0;b[H>>1]=T;J=G^t;if(!(K>>>0<C>>>0)){break a}I=I+1|0;H=K;G=J;F=c[k+(J<<2)>>2]|0}}else if((D|0)==81922){c[l>>2]=4;c[l+4>>2]=4;F=c[r>>2]|0;if((F|0)>0){G=o;H=0;while(1){I=G+2|0;E=G;c[k+(H<<2)>>2]=(d[E]|d[E+1|0]<<8)<<16>>16<<16>>16;E=H+1|0;if((E|0)<(F|0)){G=I;H=E}else{U=I;break}}}else{U=o}if(x>>>0<C>>>0){V=U;W=x;X=0}else{break}while(1){H=d[V]|0;G=H&3;if((G|0)==3){F=m+(X<<2)|0;I=(c[F>>2]|0)+1|0;c[F>>2]=I;Y=I}else{I=m+(X<<2)|0;F=(c[I>>2]|0)-(G<<1)|0;c[I>>2]=F;Y=F}if((Y|0)<0){c[m+(X<<2)>>2]=0;Z=0}else{Z=Y}F=k+(X<<2)|0;I=(c[F>>2]|0)+((H<<24>>16&-1024)>>Z)|0;if((I+32768|0)>>>0>65535>>>0){_=(I>>31^32767)&65535}else{_=I&65535}c[F>>2]=_<<16>>16;F=W+2|0;b[W>>1]=_;if(F>>>0<C>>>0){V=V+1|0;W=F;X=X^t}else{break}}}else if((D|0)==81923){if((c[e+52>>2]|0)==3){if(!(x>>>0<C>>>0)){break}F=p+512|0;I=o;H=x;G=0;while(1){E=d[I]|0;J=b[435112+((E&127)<<1)>>1]|0;K=F+(G<<2)|0;L=((E&128|0)==0?J:-J|0)+(c[K>>2]|0)|0;if((L+32768|0)>>>0>65535>>>0){$=(L>>31^32767)&65535}else{$=L&65535}c[K>>2]=$<<16>>16;K=H+2|0;b[H>>1]=$;if(K>>>0<C>>>0){I=I+1|0;H=K;G=G^t}else{break a}}}G=v+y|0;if((y|0)<=0){break}H=p+520|0;I=p+512|0;F=I;K=I+(t<<2)|0;I=o;L=v;while(1){J=d[I]|0;E=(c[F>>2]|0)+(a[(c[H>>2]|0)+(J>>>4)|0]|0)|0;if(E>>>0>255>>>0){aa=-E>>31&255}else{aa=E&255}c[F>>2]=aa&255;a[L]=aa;E=(c[K>>2]|0)+(a[(c[H>>2]|0)+(J&15)|0]|0)|0;if(E>>>0>255>>>0){ba=-E>>31&255}else{ba=E&255}c[K>>2]=ba&255;E=L+2|0;a[L+1|0]=ba;if(E>>>0<G>>>0){I=I+1|0;L=E}else{break}}}}while(0);c[g>>2]=1;B=c[n>>2]|0;i=j;return B|0}}while(0);yDb(e,16,1917448,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;B=-22;i=j;return B|0}function o2(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;h=i;i=i+32|0;j=h|0;k=j;l=g+24|0;m=c[l>>2]|0;n=g+28|0;g=c[n>>2]|0;o=e;if((g|0)<1635){yDb(a,16,2189960,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}r=m;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=m+4|0;if((s|0)==1481655379){t=r;u=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;v=1;w=0}else if((s|0)==1396985944){s=r;u=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;v=0;w=1}else{yDb(a,16,2054056,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}if(!(g>>>0>u>>>0)){yDb(a,16,2008392,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}s=m+772|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;if(w){s=m+776|0;t=s;x=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;y=r;z=s}else{s=fe(r|0)|0;r=m+776|0;m=r;x=fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;y=s;z=r}r=V$a(a,y,x)|0;if((r|0)<0){q=r;i=h;return q|0}r=d[z+24|0]|0;x=d[z+27|0]|0;c[a+796>>2]=x;y=z+28|0;s=(d[y]|d[y+1|0]<<8)<<16>>16;if(w){y=z+30|0;m=y;A=(d[m]|d[m+1|0]<<8)<<16>>16;B=s;C=y}else{y=de(s|0)|0;s=z+30|0;z=s;A=de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0;B=y;C=s}if((B&65535)>>>0>1>>>0){EDb(a,1970200,(p=i,i=i+8|0,c[p>>2]=B&65535,p)|0);i=p;q=-1163346256;i=h;return q|0}if(!(A<<16>>16==0)){EDb(a,1941560,(p=i,i=i+8|0,c[p>>2]=A&65535,p)|0);i=p;q=-1163346256;i=h;return q|0}A=C+822|0;s=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;if(w){A=a+224|0;c[A>>2]=s;y=C+826|0;D=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;E=A}else{A=a+224|0;c[A>>2]=fe(s|0)|0;s=C+826|0;D=fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;E=A}A=a+228|0;c[A>>2]=D;s=c[E>>2]|0;if((s|0)>0&(D|0)>0){iFb(E,A,s,(s|0)<0|0?-1:0,D,(D|0)<0|0?-1:0,65536,0)|0}else{c[E>>2]=0;c[A>>2]=1}if((r|0)==50){G=3}else if((r|0)==6){G=1}else if((r|0)==52|(r|0)==51){G=4}else{EDb(a,1917432,(p=i,i=i+8|0,c[p>>2]=r,p)|0);i=p;q=-1163346256;i=h;return q|0}a:do{switch(x|0){case 12:{if(!(B<<16>>16==0)){H=ba(ba(G<<1,c[a+120>>2]|0)|0,c[a+124>>2]|0)|0;break a}yDb(a,16,2353736,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0};case 8:{H=ba(ba(c[a+120>>2]|0,G)|0,c[a+124>>2]|0)|0;break};case 16:{H=ba(ba(G<<1,c[a+120>>2]|0)|0,c[a+124>>2]|0)|0;break};case 10:{if(!(B<<16>>16==0)){A=(((ba(c[a+120>>2]|0,G)|0)+2|0)/3|0)<<2;H=ba(A,c[a+124>>2]|0)|0;break a}yDb(a,16,1896560,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0};case 1:case 32:case 64:{EDb(a,2333760,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=-1163346256;i=h;return q|0};default:{q=-1094995529;i=h;return q|0}}}while(0);B=(x*10|0)+(r*1e3|0)|v;if((B|0)==51160){c[a+140>>2]=292}else if((B|0)==50081|(B|0)==50080){c[a+140>>2]=2}else if((B|0)==6161){c[a+140>>2]=31}else if((B|0)==50160){c[a+140>>2]=42}else if((B|0)==6160){c[a+140>>2]=32}else if((B|0)==50100|(B|0)==51100|(B|0)==50101|(B|0)==51101){c[a+140>>2]=86}else if((B|0)==51081|(B|0)==51080){c[a+140>>2]=28}else if((B|0)==50161){c[a+140>>2]=41}else if((B|0)==50120|(B|0)==51120|(B|0)==50121|(B|0)==51121){c[a+140>>2]=314}else if((B|0)==6081|(B|0)==6080){c[a+140>>2]=8}else if((B|0)==51161){c[a+140>>2]=291}else if((B|0)==52081|(B|0)==52080){c[a+140>>2]=29}else{yDb(a,16,2309088,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1163346256;i=h;return q|0}B=_$a(a,o,0)|0;if((B|0)<0){q=B;i=h;return q|0}B=c[l>>2]|0;UGb(k|0,e|0,32)|0;k=B+u|0;B=YGb(H,(H|0)<0|0?-1:0,u,0)|0;u=F;H=c[n>>2]|0;n=(H|0)<0|0?-1:0;if((u|0)>(n|0)|(u|0)==(n|0)&B>>>0>H>>>0){yDb(a,16,2290352,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}do{if((x|0)==16){I=G<<1;J=97}else if((x|0)==8){I=G;J=97}else if((x|0)==10){p=c[a+124>>2]|0;if((p|0)<=0){break}H=j|0;B=j+4|0;n=j+8|0;u=(G|0)==4;l=e+32|0;o=c[a+120>>2]|0;v=k;r=0;A=0;E=c[H>>2]|0;D=c[B>>2]|0;s=c[n>>2]|0;while(1){C=E;y=D;z=s;if((o|0)>0){if(w){m=v;t=r;K=0;L=0;M=z;N=y;O=C;while(1){do{if((K|0)==0){P=m;Q=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;P=Q>>>22;b[M>>1]=P;R=m+4|0;S=Q;T=2;U=P;V=M+2|0;J=68}else{P=K-1|0;Q=t>>>22;W=M+2|0;b[M>>1]=Q;if((P|0)!=0){R=m;S=t;T=P;U=Q;V=W;J=68;break}Q=m;P=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=P>>>22;b[O>>1]=Q;X=W;Y=m+4|0;Z=P;_=2;$=Q;aa=O+2|0;J=69}}while(0);do{if((J|0)==68){J=0;Q=T-1|0;P=S>>>12&1023;W=O+2|0;b[O>>1]=P;if((Q|0)!=0){X=V;Y=R;Z=S<<10|U;_=Q;$=P;aa=W;J=69;break}P=R;ca=2;da=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;ea=R+4|0;fa=V;ga=W}}while(0);if((J|0)==69){J=0;ca=_-1|0;da=Z<<10|$;ea=Y;fa=X;ga=aa}W=da>>>22;P=da<<10|W;Q=N+2|0;b[N>>1]=W;if(u){if((ca|0)==0){W=ea;ha=2;ia=d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0;ja=ea+4|0}else{ha=ca-1|0;ia=P;ja=ea}ka=ha;la=ia<<10|ia>>>22;ma=ja}else{ka=ca;la=P;ma=ea}P=L+1|0;if((P|0)<(o|0)){m=ma;t=la;K=ka;L=P;M=fa;N=Q;O=ga}else{na=ma;oa=la;break}}}else{O=v;N=r;M=0;L=0;K=z;t=y;m=C;while(1){do{if((M|0)==0){Q=O;P=fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Q=P>>>22;b[K>>1]=Q;pa=O+4|0;qa=P;ra=2;sa=Q;ta=K+2|0;J=81}else{Q=M-1|0;P=N>>>22;W=K+2|0;b[K>>1]=P;if((Q|0)!=0){pa=O;qa=N;ra=Q;sa=P;ta=W;J=81;break}P=O;Q=fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=Q>>>22;b[m>>1]=P;ua=W;va=O+4|0;wa=Q;xa=2;ya=P;za=m+2|0;J=82}}while(0);do{if((J|0)==81){J=0;P=ra-1|0;Q=qa>>>12&1023;W=m+2|0;b[m>>1]=Q;if((P|0)!=0){ua=ta;va=pa;wa=qa<<10|sa;xa=P;ya=Q;za=W;J=82;break}Q=pa;Aa=2;Ba=fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Ca=pa+4|0;Da=ta;Ea=W}}while(0);if((J|0)==82){J=0;Aa=xa-1|0;Ba=wa<<10|ya;Ca=va;Da=ua;Ea=za}W=Ba>>>22;Q=Ba<<10|W;P=t+2|0;b[t>>1]=W;if(u){if((Aa|0)==0){W=Ca;Fa=2;Ga=fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0;Ha=Ca+4|0}else{Fa=Aa-1|0;Ga=Q;Ha=Ca}Ia=Fa;Ja=Ga<<10|Ga>>>22;Ka=Ha}else{Ia=Aa;Ja=Q;Ka=Ca}Q=L+1|0;if((Q|0)<(o|0)){O=Ka;N=Ja;M=Ia;L=Q;K=Da;t=P;m=Ea}else{na=Ka;oa=Ja;break}}}}else{na=v;oa=r}m=E+(c[l>>2]|0)|0;c[H>>2]=m;t=D+(c[e+36>>2]|0)|0;c[B>>2]=t;K=s+(c[e+40>>2]|0)|0;c[n>>2]=K;L=A+1|0;if((L|0)<(p|0)){v=na;r=oa;A=L;E=m;D=t;s=K}else{break}}}else if((x|0)==12){s=c[a+124>>2]|0;if((s|0)<=0){break}D=j|0;E=j+4|0;A=j+8|0;r=(G|0)==4;v=e+32|0;p=c[a+120>>2]|0;n=k;B=0;H=c[D>>2]|0;l=c[E>>2]|0;o=c[A>>2]|0;while(1){u=H;K=l;t=o;if((p|0)>0){if(w){m=n;L=0;M=t;N=K;O=u;while(1){C=m;b[M>>1]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>4;C=m+2|0;b[O>>1]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>4;C=m+4|0;b[N>>1]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>4;C=r?m+8|0:m+6|0;y=L+1|0;if((y|0)<(p|0)){m=C;L=y;M=M+2|0;N=N+2|0;O=O+2|0}else{La=C;break}}}else{O=n;N=0;M=t;L=K;m=u;while(1){C=O;b[M>>1]=((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;C=O+2|0;b[m>>1]=((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;C=O+4|0;b[L>>1]=((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;C=r?O+8|0:O+6|0;y=N+1|0;if((y|0)<(p|0)){O=C;N=y;M=M+2|0;L=L+2|0;m=m+2|0}else{La=C;break}}}}else{La=n}m=H+(c[v>>2]|0)|0;c[D>>2]=m;L=l+(c[e+36>>2]|0)|0;c[E>>2]=L;M=o+(c[e+40>>2]|0)|0;c[A>>2]=M;N=B+1|0;if((N|0)<(s|0)){n=La;B=N;H=m;l=L;o=M}else{break}}}}while(0);if((J|0)==97){J=ba(c[a+120>>2]|0,I)|0;iDb(c[j>>2]|0,c[e+32>>2]|0,k,J,J,c[a+124>>2]|0)}c[f>>2]=1;q=g;i=h;return q|0}function p2(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=c[b+60>>2]|0;h=b+140|0;j=bFb(c[h>>2]|0)|0;k=j+7|0;c[g>>2]=a[k]&1;l=g+4|0;c[l>>2]=((e[j+8>>1]|0)>>>11&15)+1;j=g+8|0;c[j>>2]=(a[k]|0)<0?51:50;c[g+12>>2]=(d[k]|0)>>>4&1;switch(c[h>>2]|0){case 85:case 86:case 313:case 314:case 2:case 291:case 292:case 28:{m=0;i=f;return m|0};case 31:case 32:case 8:{c[j>>2]=6;m=0;i=f;return m|0};case 42:case 41:{h=c[b+796>>2]|0;if((h|0)==0){m=0;i=f;return m|0}c[l>>2]=h;m=0;i=f;return m|0};case 29:{c[j>>2]=52;m=0;i=f;return m|0};default:{yDb(b,32,2008312,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;m=-1;i=f;return m|0}}return 0}function q2(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0;h=i;j=b+60|0;k=c[j>>2]|0;l=k+4|0;if((c[l>>2]|0)==10){m=ba(c[b+124>>2]<<2,c[b+120>>2]|0)|0}else{m=QZ(c[b+140>>2]|0,c[b+120>>2]|0,c[b+124>>2]|0)|0}n=m+1664|0;o=r0a(b,e,n,(n|0)<0|0?-1:0)|0;if((o|0)<0){p=o;i=h;return p|0}o=c[e+24>>2]|0;TGb(o|0,0,1664)|0;n=k;q=o;x=(c[n>>2]|0)==0?1396985944:1481655379;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=o+4|0;x=(c[n>>2]|0)==0?1664:-2147090432;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=o+8|0;x=808333654;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=o+20|0;x=(c[n>>2]|0)==0?1:16777216;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=o+24|0;x=(c[n>>2]|0)==0?1664:-2147090432;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;if((c[b+88>>2]&8388608|0)==0){UGb(o+160|0,2112744,14)|0}q=o+660|0;x=-1;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=o+768|0;x=0;a[q]=x;x=x>>8;a[q+1|0]=x;q=o+770|0;x=(c[n>>2]|0)==0?1:256;a[q]=x;x=x>>8;a[q+1|0]=x;q=b+120|0;r=c[q>>2]|0;if((c[n>>2]|0)==0){s=o+772|0;x=r;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x}else{s=o+772|0;x=fe(r|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x}s=b+124|0;r=c[s>>2]|0;if((c[n>>2]|0)==0){t=o+776|0;x=r;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x}else{t=o+776|0;x=fe(r|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x}a[o+800|0]=c[k+8>>2];a[o+801|0]=2;a[o+802|0]=2;a[o+803|0]=c[l>>2];t=c[l>>2]|0;r=(t|0)==10;if((c[n>>2]|0)==0){if(r){u=1}else{u=(t|0)==12|0}v=o+804|0;x=u;a[v]=x;x=x>>8;a[v+1|0]=x}else{if(r){w=1}else{w=(t|0)==12|0}t=o+804|0;x=de(w|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x}t=o+808|0;x=(c[n>>2]|0)==0?1664:-2147090432;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=c[b+224>>2]|0;if((c[n>>2]|0)==0){w=o+1628|0;x=t;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x}else{w=o+1628|0;x=fe(t|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x}w=c[b+228>>2]|0;if((c[n>>2]|0)==0){t=o+1632|0;x=w;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x}else{t=o+1632|0;x=fe(w|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x}t=c[l>>2]|0;do{if((t|0)==10){l=o+1664|0;w=c[s>>2]|0;r=(w|0)>0;if((c[k+12>>2]|0)==0){if(!r){y=m;break}v=f+32|0;u=c[j>>2]|0;z=l;A=c[f>>2]|0;B=0;C=c[q>>2]|0;D=w;while(1){if((C|0)>0){E=z;F=0;do{G=F*6|0;H=A+G|0;I=A+(G+4)|0;J=(d[I]|d[I+1|0]<<8)<<16>>16;if((c[u>>2]|0)==0){I=A+(G+2)|0;K=H;L=E;x=((d[I]|d[I+1|0]<<8)<<16>>16&65535)<<6&4190208|(J&65535)>>>4&4092|((d[K]|d[K+1|0]<<8)<<16>>16&65535)<<16&-4194304;a[L]=x;x=x>>8;a[L+1|0]=x;x=x>>8;a[L+2|0]=x;x=x>>8;a[L+3|0]=x}else{L=((de(J|0)|0)&65535)>>>4&4092;J=A+(G+2)|0;G=((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)<<6&4190208|L;L=H;H=E;x=fe(G|((de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<16&-4194304|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x}E=E+4|0;F=F+1|0;M=c[q>>2]|0;}while((F|0)<(M|0));N=E;O=M;P=c[s>>2]|0}else{N=z;O=C;P=D}F=B+1|0;if((F|0)<(P|0)){z=N;A=A+(c[v>>2]|0)|0;B=F;C=O;D=P}else{y=m;break}}}else{if(!r){y=m;break}D=c[j>>2]|0;C=f+32|0;B=f+36|0;v=f+40|0;A=l;z=0;u=c[q>>2]|0;F=c[f>>2]|0;H=c[f+4>>2]|0;L=c[f+8>>2]|0;G=w;while(1){if((u|0)>0){J=A;K=0;do{I=K<<1;Q=F+I|0;R=(d[Q]|d[Q+1|0]<<8)<<16>>16;if((c[D>>2]|0)==0){Q=H+I|0;S=L+I|0;T=J;x=((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)<<2|(R&65535)<<12|((d[S]|d[S+1|0]<<8)<<16>>16&65535)<<22;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x}else{T=((de(R|0)|0)&65535)<<12;R=H+I|0;S=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<2|T;T=L+I|0;I=J;x=fe(S|((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<22|0)|0;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x}J=J+4|0;K=K+1|0;U=c[q>>2]|0;}while((K|0)<(U|0));V=J;W=U;X=c[s>>2]|0}else{V=A;W=u;X=G}K=z+1|0;if((K|0)<(X|0)){A=V;z=K;u=W;F=F+(c[C>>2]|0)|0;H=H+(c[B>>2]|0)|0;L=L+(c[v>>2]|0)|0;G=X}else{y=m;break}}}}else if((t|0)==8|(t|0)==16){G=PZ(f,c[b+140>>2]|0,c[q>>2]|0,c[s>>2]|0,o+1664|0,(c[e+28>>2]|0)-1664|0)|0;if((G|0)<0){p=G}else{y=G;break}i=h;return p|0}else if((t|0)==12){G=c[s>>2]|0;if((G|0)<=0){y=m;break}v=c[j>>2]|0;L=f+32|0;B=f+36|0;H=f+40|0;C=o+1664|0;F=0;u=c[q>>2]|0;z=c[f>>2]|0;A=c[f+4>>2]|0;D=c[f+8>>2]|0;w=G;while(1){if((u|0)>0){G=C;l=0;do{r=z+(l<<1)|0;K=(d[r]|d[r+1|0]<<8)<<16>>16;if((c[v>>2]|0)==0){r=A+(l<<1)|0;E=D+(l<<1)|0;Y=(d[E]|d[E+1|0]<<8)<<16>>16<<4;Z=K;_=(d[r]|d[r+1|0]<<8)<<16>>16}else{r=de(K|0)|0;K=A+(l<<1)|0;E=de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0;K=D+(l<<1)|0;Y=de((de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)<<4|0)|0;Z=r;_=E}E=Z<<4;r=_<<4;x=Y;a[G]=x;x=x>>8;a[G+1|0]=x;K=G+2|0;if((c[v>>2]|0)==0){$=E}else{$=de(E|0)|0}x=$;a[K]=x;x=x>>8;a[K+1|0]=x;K=G+4|0;if((c[v>>2]|0)==0){aa=r}else{aa=de(r|0)|0}x=aa;a[K]=x;x=x>>8;a[K+1|0]=x;G=G+6|0;l=l+1|0;ca=c[q>>2]|0;}while((l|0)<(ca|0));da=G;ea=ca;fa=c[s>>2]|0}else{da=C;ea=u;fa=w}l=F+1|0;if((l|0)<(fa|0)){C=da;F=l;u=ea;z=z+(((c[L>>2]|0)/2|0)<<1)|0;A=A+(((c[B>>2]|0)/2|0)<<1)|0;D=D+(((c[H>>2]|0)/2|0)<<1)|0;w=fa}else{y=m;break}}}else{yDb(b,16,2054024,(w=i,i=i+8|0,c[w>>2]=t,w)|0);i=w;p=-1;i=h;return p|0}}while(0);t=y+1664|0;if((c[n>>2]|0)==0){n=o+16|0;x=t;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x}else{n=o+16|0;x=fe(t|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x}n=e+36|0;c[n>>2]=c[n>>2]|1;c[g>>2]=1;p=0;i=h;return p|0}function r2(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+60>>2]|0;e=d;c[e>>2]=a;c[a+140>>2]=11;f=ICb()|0;c[d+4>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}f=d;h=d+8|0;c[h>>2]=ba(c[a+124>>2]|0,c[a+120>>2]|0)|0;a=0;while(1){if((a|0)>=3){g=0;j=6;break}k=cEb(c[h>>2]|0)|0;c[f+1036+(a<<2)>>2]=k;if((k|0)==0){break}else{a=a+1|0}}if((j|0)==6){i=b;return g|0}yDb(c[e>>2]|0,16,2008280,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;$Db(d+1036|0);$Db(d+1040|0);$Db(d+1044|0);g=-12;i=b;return g|0}function s2(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;h=i;i=i+16|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=a[k]|0;n=k+1|0;o=(d[n]|d[n+1|0]<<8)<<16>>16;n=o&65535;p=d[k+3|0]|0;q=k+4|0;r=l-4|0;if((r|0)<(ba(n,m<<24>>24!=0?4:3)|0)){s=-1094995529;i=h;return s|0}do{if(m<<24>>24==0){if((o&65535)>>>0>256>>>0){s=-1094995529;i=h;return s|0}if(o<<16>>16==0){t=r;u=q;break}v=g+12|0;w=(o&65535)>>>0>1>>>0?n*3|0:3;x=w+4|0;y=q;z=0;while(1){c[v+(z<<2)>>2]=(d[y+2|0]|0)<<16|(d[y+1|0]|0)<<8|(d[y]|0)|-16777216;A=z+1|0;if((A|0)<(n|0)){y=y+3|0;z=A}else{break}}t=r-w|0;u=k+x|0}else{if(o<<16>>16==0){t=r;u=q;break}z=g+12|0;y=(o&65535)>>>0>1>>>0?n<<2:4;v=y+4|0;A=q;B=0;while(1){c[z+((d[A]|0)<<2)>>2]=(d[A+3|0]|0)<<16|(d[A+2|0]|0)<<8|(d[A+1|0]|0)|-16777216;C=B+1|0;if((C|0)<(n|0)){A=A+4|0;B=C}else{break}}t=r-y|0;u=k+v|0}}while(0);a:do{switch(p|0){case 9:{k=c[g+1036>>2]|0;r=c[g+8>>2]|0;n=k+r|0;q=u+t|0;if(!((t|0)>1&(r|0)>0)){break a}r=q;o=n;m=k;k=u;B=u+1|0;while(1){A=d[k]|0;if((A&128|0)==0){z=A+1|0;x=r-B|0;if((z|0)>(x|0)){break}w=o-m|0;C=(z|0)>(w|0)?w:z;UGb(m|0,B|0,(C|0)>(x|0)?x:C)|0;D=k+(A+2)|0;E=z}else{z=A-127|0;A=o-m|0;TGb(m|0,a[B]|0,((z|0)>(A|0)?A:z)|0)|0;D=k+2|0;E=z}z=m+E|0;A=D+1|0;if(A>>>0<q>>>0&z>>>0<n>>>0){m=z;k=D;B=A}else{break a}}yDb(0,16,2053984,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;break};case 37:{B=c[g+1036>>2]|0;k=B+(c[g+8>>2]|0)|0;m=u+t|0;UGb(j|0,u|0,15)|0;n=u+15|0;q=B;while(1){if(!(n>>>0<m>>>0)){break a}B=n+1|0;o=a[n]|0;r=o&255;v=r>>>4;if((v|0)==15){y=a[B]|0;G=n+2|0;H=y&255;I=(y&255)>>>4|o<<4}else{G=B;H=r;I=a[j+v|0]|0}v=q+1|0;a[q]=I;if(!(v>>>0<k>>>0)){break a}r=H&15;if((r|0)==15){J=G+1|0;K=G}else{J=G;K=j+r|0}r=q+2|0;a[v]=a[K]|0;if(r>>>0<k>>>0){n=J;q=r}else{break}}break};case 34:{q=g+1036|0;n=c[q>>2]|0;k=g+8|0;m=c[k>>2]|0;r=n+m|0;v=u+t|0;b:do{if((t|0)>1&(m|0)>0){B=v;o=r;y=n;A=u;z=u+1|0;while(1){C=d[A]|0;if((C&128|0)==0){x=C+1|0;w=B-z|0;if((x|0)>(w|0)){break}L=o-y|0;M=(x|0)>(L|0)?L:x;UGb(y|0,z|0,(M|0)>(w|0)?w:M)|0;N=A+(C+2)|0;O=x}else{x=C-127|0;C=o-y|0;TGb(y|0,a[z]|0,((x|0)>(C|0)?C:x)|0)|0;N=A+2|0;O=x}x=y+O|0;C=N+1|0;if(C>>>0<v>>>0&x>>>0<r>>>0){y=x;A=N;z=C}else{break b}}yDb(0,16,2053984,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F}}while(0);r=c[k>>2]|0;if((r|0)==0){break a}v=c[g+1040>>2]|0;n=c[q>>2]|0;m=r;while(1){r=m-1|0;a[n]=(a[n]|0)+(a[v]|0);if((r|0)==0){break}else{v=v+1|0;n=n+1|0;m=r}}break};case 35:{m=g+1036|0;n=g+1044|0;v=c[n>>2]|0;q=g+8|0;k=v+(c[q>>2]|0)|0;r=u+t|0;UGb(j|0,u|0,15)|0;z=u+15|0;A=v;while(1){if(!(z>>>0<r>>>0)){P=A;break}y=z+1|0;o=a[z]|0;B=o&255;C=B>>>4;if((C|0)==15){x=a[y]|0;Q=z+2|0;R=x&255;S=(x&255)>>>4|o<<4}else{Q=y;R=B;S=a[j+C|0]|0}C=A+1|0;a[A]=S;if(!(C>>>0<k>>>0)){P=C;break}B=R&15;if((B|0)==15){T=Q+1|0;U=Q}else{T=Q;U=j+B|0}B=A+2|0;a[C]=a[U]|0;if(B>>>0<k>>>0){z=T;A=B}else{P=B;break}}A=P-v|0;z=c[n>>2]|0;k=c[m>>2]|0;r=c[q>>2]|0;B=k+r|0;C=z+A|0;if(!((A|0)>1&(r|0)>0)){break a}r=C;A=B;y=k;k=z;o=z+1|0;while(1){z=d[k]|0;if((z&128|0)==0){x=z+1|0;M=r-o|0;if((x|0)>(M|0)){break}w=A-y|0;L=(x|0)>(w|0)?w:x;UGb(y|0,o|0,(L|0)>(M|0)?M:L)|0;V=k+(z+2)|0;W=x}else{x=z-127|0;z=A-y|0;TGb(y|0,a[o]|0,((x|0)>(z|0)?z:x)|0)|0;V=k+2|0;W=x}x=y+W|0;z=V+1|0;if(z>>>0<C>>>0&x>>>0<B>>>0){y=x;k=V;o=z}else{break a}}yDb(0,16,2053984,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;break};case 36:{o=g+1036|0;k=g+1044|0;y=c[k>>2]|0;B=g+8|0;C=y+(c[B>>2]|0)|0;A=u+t|0;UGb(j|0,u|0,15)|0;r=u+15|0;q=y;while(1){if(!(r>>>0<A>>>0)){X=q;break}m=r+1|0;n=a[r]|0;v=n&255;z=v>>>4;if((z|0)==15){x=a[m]|0;Y=r+2|0;Z=x&255;_=(x&255)>>>4|n<<4}else{Y=m;Z=v;_=a[j+z|0]|0}z=q+1|0;a[q]=_;if(!(z>>>0<C>>>0)){X=z;break}v=Z&15;if((v|0)==15){$=Y+1|0;aa=Y}else{$=Y;aa=j+v|0}v=q+2|0;a[z]=a[aa]|0;if(v>>>0<C>>>0){r=$;q=v}else{X=v;break}}q=X-y|0;r=c[k>>2]|0;C=o;A=c[C>>2]|0;v=c[B>>2]|0;z=A+v|0;m=r+q|0;c:do{if((q|0)>1&(v|0)>0){n=m;x=z;L=A;M=r;w=r+1|0;while(1){ca=d[M]|0;if((ca&128|0)==0){da=ca+1|0;ea=n-w|0;if((da|0)>(ea|0)){break}fa=x-L|0;ga=(da|0)>(fa|0)?fa:da;UGb(L|0,w|0,(ga|0)>(ea|0)?ea:ga)|0;ha=M+(ca+2)|0;ia=da}else{da=ca-127|0;ca=x-L|0;TGb(L|0,a[w]|0,((da|0)>(ca|0)?ca:da)|0)|0;ha=M+2|0;ia=da}da=L+ia|0;ca=ha+1|0;if(ca>>>0<m>>>0&da>>>0<z>>>0){L=da;M=ha;w=ca}else{break c}}yDb(0,16,2053984,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F}}while(0);z=c[B>>2]|0;if((z|0)==0){break a}m=c[g+1040>>2]|0;r=c[C>>2]|0;A=z;while(1){z=A-1|0;a[r]=(a[r]|0)+(a[m]|0);if((z|0)==0){break}else{m=m+1|0;r=r+1|0;A=z}}break};case 38:{A=w2(u,t,c[g+1036>>2]|0,c[g+8>>2]|0)|0;if((A|0)<0){s=A}else{break a}i=h;return s|0};case 39:{A=g+1036|0;r=g+8|0;m=w2(u,t,c[A>>2]|0,c[r>>2]|0)|0;if((m|0)<0){s=m;i=h;return s|0}m=c[r>>2]|0;if((m|0)==0){break a}r=c[g+1040>>2]|0;C=c[A>>2]|0;A=m;while(1){m=A-1|0;a[C]=(a[C]|0)+(a[r]|0);if((m|0)==0){break}else{r=r+1|0;C=C+1|0;A=m}}break};default:{}}}while(0);t=g+4|0;u=$$a(b,c[t>>2]|0)|0;if((u|0)<0){s=u;i=h;return s|0}UGb(c[(c[t>>2]|0)+4>>2]|0,g+12|0,1024)|0;u=c[t>>2]|0;c[u+304>>2]=1;b=g;F=c[b>>2]|0;ha=c[F+124>>2]|0;ia=g+1036|0;if((ha|0)>0){X=0;$=F;F=ha;ha=u;while(1){aa=(c[ha>>2]|0)+(ba(c[ha+32>>2]|0,F+~X|0)|0)|0;j=c[$+120>>2]|0;UGb(aa|0,(c[ia>>2]|0)+(ba(j,X)|0)|0,j)|0;j=X+1|0;aa=c[b>>2]|0;Y=c[aa+124>>2]|0;Z=c[t>>2]|0;if((j|0)<(Y|0)){X=j;$=aa;F=Y;ha=Z}else{ja=Z;break}}}else{ja=u}u=g+1040|0;g=c[u>>2]|0;c[u>>2]=c[ia>>2];c[ia>>2]=g;g=MCb(e,ja)|0;if((g|0)<0){s=g;i=h;return s|0}c[f>>2]=1;s=l;i=h;return s|0}function t2(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);$Db(b+1036|0);$Db(b+1040|0);$Db(b+1044|0);return 0}function u2(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=1;c[b+4>>2]=0;c[a+420>>2]=1;c[a+416>>2]=1;b=a+448|0;c[b>>2]=4;c[b+4>>2]=0;return 0}function v2(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=c[g+24>>2]|0;i=c[a+60>>2]|0;j=g+28|0;g=c[j>>2]|0;k=h+g|0;l=i;c[e+76>>2]=g-(c[l>>2]|0);g=_$a(a,e,0)|0;if((g|0)<0){m=g;return m|0}g=c[e>>2]|0;e=g;a=i+4|0;if((c[l>>2]|0)==0){n=c[a>>2]|0;o=e;p=h}else{c[l>>2]=0;l=h;i=(d[l]|d[l+1|0]<<8)<<16>>16;b[e>>1]=i;n=i<<16>>16;o=g+2|0;p=h+2|0}if(p>>>0<k>>>0){h=p;p=o;o=n;while(1){g=h+1|0;i=(b[1485248+(d[h]<<1)>>1]|0)+o|0;if((i+32768|0)>>>0>65535>>>0){q=(i>>31^32767)&65535}else{q=i&65535}i=q<<16>>16;b[p>>1]=q;if(g>>>0<k>>>0){h=g;p=p+2|0;o=i}else{r=i;break}}}else{r=n}c[a>>2]=r;c[f>>2]=1;m=c[j>>2]|0;return m|0}function w2(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=e+f|0;h=b+c|0;if(!((c|0)>0&(f|0)>0)){i=0;return i|0}f=e;c=g;j=~c;k=e;e=b;a:while(1){b=e+1|0;l=d[e]|0;if(b>>>0<h>>>0&k>>>0<g>>>0){m=0;n=k;o=b;while(1){do{if((1<<m&l|0)==0){p=o;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=o+2|0;r=q&65535;s=r>>>4;t=n;if((t-f|0)<(s+1|0)){i=-1094995529;u=13;break a}v=(r&15)+2|0;r=c-t|0;w=(v|0)>(r|0)?r:v;if((w|0)==0){x=p;y=n;break}v=~s;s=t+j|0;t=-3-(q&15)|0;q=(s|0)>(t|0)?s:t;t=w;w=n;while(1){s=t-1|0;a[w]=a[w+v|0]|0;if((s|0)==0){break}else{t=s;w=w+1|0}}x=p;y=n+~q|0}else{a[n]=a[o]|0;x=o+1|0;y=n+1|0}}while(0);w=m+1|0;if((w|0)<8&x>>>0<h>>>0&y>>>0<g>>>0){m=w;n=y;o=x}else{z=y;A=x;break}}}else{z=k;A=b}if(A>>>0<h>>>0&z>>>0<g>>>0){k=z;e=A}else{i=0;u=13;break}}if((u|0)==13){return i|0}return 0}function x2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;c[e>>2]=f;g=0;while(1){a[e+4+g|0]=a[b+(d[f+g|0]|0)|0]|0;h=g+1|0;if((h|0)<64){g=h}else{i=-1;j=0;break}}do{g=d[e+4+j|0]|0;i=(g|0)>(i|0)?g:i;a[e+68+j|0]=i;j=j+1|0;}while((j|0)<64);return}function y2(b,e){b=b|0;e=e|0;var f=0;f=i;switch(e|0){case 3:{e=0;do{a[b+e|0]=a[436952+e|0]|0;e=e+1|0;}while((e|0)<64);i=f;return};case 2:{e=0;do{a[b+e|0]=e>>>1&3|e&56|e<<2&4;e=e+1|0;}while((e|0)<64);i=f;return};case 6:{e=0;do{a[b+e|0]=d[918176+(e&7)|0]|0|e&56;e=e+1|0;}while((e|0)<64);i=f;return};case 1:{e=0;do{a[b+e|0]=e;e=e+1|0;}while((e|0)<64);i=f;return};case 4:{e=0;do{a[b+e|0]=e<<3&56|e>>>3;e=e+1|0;}while((e|0)<64);i=f;return};case 5:{e=0;do{a[b+e|0]=e<<3&24|e&36|e>>>3&3;e=e+1|0;}while((e|0)<64);i=f;return};default:{yDb(0,16,2302504,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=f;return}}}function z2(b,c,e,f,g,h,i,j,k,l,m,n,o,p){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;q=1<<m;r=o-1|0;o=p-1|0;if((f|0)<=0){return}p=q-1|0;s=m<<1;t=0;u=h;h=g;while(1){g=ba(t,e)|0;v=h;w=u;x=0;while(1){y=v>>16;z=w>>16;A=y&p;B=z&p;C=y>>m;y=z>>m;z=y>>>0<o>>>0;do{if(C>>>0<r>>>0){if(z){D=(ba(y,e)|0)+C|0;E=q-A|0;F=ba(d[c+D|0]|0,E)|0;G=ba((ba(d[c+(D+1)|0]|0,A)|0)+F|0,q-B|0)|0;F=D+e|0;D=ba(d[c+F|0]|0,E)|0;a[b+(x+g)|0]=G+n+(ba((ba(d[c+(F+1)|0]|0,A)|0)+D|0,B)|0)>>s;break}if((y|0)<0){H=0}else{H=(y|0)>(o|0)?o:y}D=(ba(H,e)|0)+C|0;F=ba(d[c+D|0]|0,q-A|0)|0;a[b+(x+g)|0]=((ba(d[c+(D+1)|0]|0,A)|0)+F<<m)+n>>s}else{if((C|0)<0){I=0}else{I=(C|0)>(r|0)?r:C}if(z){F=I+(ba(y,e)|0)|0;D=ba(d[c+F|0]|0,q-B|0)|0;a[b+(x+g)|0]=((ba(d[c+(F+e)|0]|0,B)|0)+D<<m)+n>>s;break}if((y|0)<0){J=0}else{J=(y|0)>(o|0)?o:y}a[b+(x+g)|0]=a[c+((ba(J,e)|0)+I)|0]|0}}while(0);y=x+1|0;if((y|0)<8){v=v+i|0;w=w+k|0;x=y}else{break}}x=t+1|0;if((x|0)<(f|0)){t=x;u=u+l|0;h=h+j|0}else{break}}return}function A2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;B2(o,n,8,16,9);k=l|0;C2(k,n,8,16);l=m|0;C2(l,o,8,8);D2(b,n,o,k,l,f,16,8,8,8,8);i=g;return}function B2(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=d[h]|0;c=h+1|0;k=d[c]|0;l=h+2|0;m=d[l]|0;n=h+3|0;o=h+4|0;a[i]=a[(16-m+((k+b|0)*20|0)+((m+b|0)*-6|0)-(d[o]|0)+(((d[n]|0)+k|0)*3|0)>>5)+1236056|0]|0;k=d[c]|0;b=d[h]|0;m=h+5|0;a[i+1|0]=a[(16-k+(((d[l]|0)+k|0)*20|0)+(((d[n]|0)+b|0)*-6|0)-(d[m]|0)+(((d[o]|0)+b|0)*3|0)>>5)+1236056|0]|0;b=d[h]|0;k=h+6|0;a[i+2|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+16-b+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+b|0)*3|0)>>5)+1236056|0]|0;b=h+7|0;a[i+3|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+16+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1236056|0]|0;p=h+8|0;a[i+4|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+16+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1236056|0]|0;c=d[p]|0;a[i+5|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+16+(((d[b]|0)+(d[o]|0)|0)*-6|0)-c-(d[l]|0)+((c+(d[n]|0)|0)*3|0)>>5)+1236056|0]|0;c=d[b]|0;l=d[p]|0;a[i+6|0]=a[(16-c+((c+(d[k]|0)|0)*20|0)+((l+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[o]|0)+l|0)*3|0)>>5)+1236056|0]|0;l=d[b]|0;b=d[p]|0;p=d[k]|0;a[i+7|0]=a[(16-p+((b+l|0)*20|0)+((p+b|0)*-6|0)-(d[o]|0)+(((d[m]|0)+l|0)*3|0)>>5)+1236056|0]|0;l=j+1|0;if((l|0)<(g|0)){h=h+f|0;i=i+e|0;j=l}else{break}}return}function C2(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=e<<1;o=e*3|0;p=e<<2;q=e*5|0;r=e*6|0;s=e*7|0;t=0;u=c;c=b;while(1){b=d[u]|0;v=d[u+f|0]|0;w=d[u+g|0]|0;x=d[u+h|0]|0;y=d[u+i|0]|0;z=d[u+j|0]|0;A=d[u+k|0]|0;B=d[u+l|0]|0;C=d[u+m|0]|0;D=16-w|0;a[c]=a[(D+((v+b|0)*20|0)+((w+b|0)*-6|0)-y+((x+v|0)*3|0)>>5)+1236056|0]|0;E=16-v|0;a[c+e|0]=a[(E+((w+v|0)*20|0)+((x+b|0)*-6|0)-z+((y+b|0)*3|0)>>5)+1236056|0]|0;F=16-b|0;a[c+n|0]=a[(F+((x+w|0)*20|0)+((y+v|0)*-6|0)-A+((z+b|0)*3|0)>>5)+1236056|0]|0;a[c+o|0]=a[(F+((y+x|0)*20|0)+((z+w|0)*-6|0)-B+((A+v|0)*3|0)>>5)+1236056|0]|0;a[c+p|0]=a[(E+((z+y|0)*20|0)+((A+x|0)*-6|0)-C+((B+w|0)*3|0)>>5)+1236056|0]|0;a[c+q|0]=a[(D+((A+z|0)*20|0)-C+((B+y|0)*-6|0)+((C+x|0)*3|0)>>5)+1236056|0]|0;a[c+r|0]=a[(16-x-B+((B+A|0)*20|0)+((C+z|0)*-6|0)+((C+y|0)*3|0)>>5)+1236056|0]|0;a[c+s|0]=a[(16-y-A+((B+z|0)*3|0)+((C+A|0)*-6|0)+((C+B|0)*20|0)>>5)+1236056|0]|0;B=t+1|0;if((B|0)<8){t=B;u=u+1|0;c=c+1|0}else{break}}return}function D2(a,b,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((m|0)>0){n=0}else{return}do{o=ba(n,i)|0;p=b+o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(n,j)|0;r=e+p|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ba(n,k)|0;t=f+r|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=ba(n,l)|0;v=g+t|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=ba(n,h)|0;c[a+v>>2]=(s>>>2&1061109567)+(q>>>2&1061109567)+(u>>>2&1061109567)+(w>>>2&1061109567)+(((q&50529027)+33686018+(s&50529027)+(u&50529027)+(w&50529027)|0)>>>2&252645135);w=b+(o+4)|0;o=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=e+(p+4)|0;p=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=f+(r+4)|0;r=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=g+(t+4)|0;t=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[a+(v+4)>>2]=(p>>>2&1061109567)+(o>>>2&1061109567)+(r>>>2&1061109567)+(t>>>2&1061109567)+(((o&50529027)+33686018+(p&50529027)+(r&50529027)+(t&50529027)|0)>>>2&252645135);n=n+1|0;}while((n|0)<(m|0));return}function E2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;B2(n,h,8,16,9);k=l|0;l=h+1|0;C2(k,l,8,16);h=m|0;C2(h,n,8,8);D2(b,l,n,k,h,f,16,8,8,8,8);i=g;return}function F2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;p=f<<1;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+40|0]=a[e+(p+8)|0]|0;q=h+48|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+56|0]=a[e+(j+8)|0]|0;p=h+64|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+72|0]=a[e+(q+8)|0]|0;j=h+80|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+88|0]=a[e+(p+8)|0]|0;q=h+96|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+104|0]=a[e+(j+8)|0]|0;p=h+112|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+120|0]=a[e+(q+8)|0]|0;j=h+128|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+136|0]=a[e+(p+8)|0]|0;p=k|0;B2(p,n,8,16,9);e=l|0;C2(e,n,8,16);n=m|0;C2(n,p,8,8);D2(b,o,k+8|0,e,n,f,16,8,8,8,8);i=g;return}function G2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=i;i=i+64|0;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=l|0;B2(o,h,8,16,9);h=m|0;C2(h,k+1|0,8,16);m=n|0;C2(m,o,8,8);D2(b,k+17|0,l+8|0,h,m,f,16,8,8,8,8);i=g;return}function H2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;B2(o,n,8,16,9);C2(l|0,n,8,16);C2(m|0,o,8,8);o=0;do{n=o<<3;k=l+n|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+n|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(o,f)|0;c[b+k>>2]=(h|e)-((h^e)>>>1&2139062143);e=n|4;n=l+e|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+e|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(k+4)>>2]=(e|h)-((e^h)>>>1&2139062143);o=o+1|0;}while((o|0)<8);i=g;return}function I2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;B2(n,h,8,16,9);C2(l|0,h+1|0,8,16);C2(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(n,f)|0;c[b+k>>2]=(o|e)-((o^e)>>>1&2139062143);e=h|4;h=l+e|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=(e|o)-((e^o)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function J2(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);c=j|0;L2(c,l,16,24);m=k|0;L2(m,n,16,16);D2(b,l,n,c,m,e,24,16,16,16,16);D2(b+8|0,g+8|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function K2(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=d[h]|0;c=h+1|0;k=d[c]|0;l=h+2|0;m=d[l]|0;n=h+3|0;o=h+4|0;a[i]=a[(16-m+((k+b|0)*20|0)+((m+b|0)*-6|0)-(d[o]|0)+(((d[n]|0)+k|0)*3|0)>>5)+1236056|0]|0;k=d[c]|0;b=d[h]|0;m=h+5|0;a[i+1|0]=a[(16-k+(((d[l]|0)+k|0)*20|0)+(((d[n]|0)+b|0)*-6|0)-(d[m]|0)+(((d[o]|0)+b|0)*3|0)>>5)+1236056|0]|0;b=d[h]|0;k=h+6|0;a[i+2|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+16-b+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+b|0)*3|0)>>5)+1236056|0]|0;b=h+7|0;a[i+3|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+16+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1236056|0]|0;p=h+8|0;a[i+4|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+16+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1236056|0]|0;c=h+9|0;a[i+5|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+16+(((d[b]|0)+(d[o]|0)|0)*-6|0)-(d[l]|0)+(((d[p]|0)+(d[n]|0)|0)*3|0)-(d[c]|0)>>5)+1236056|0]|0;l=h+10|0;a[i+6|0]=a[((((d[b]|0)+(d[k]|0)|0)*20|0)+16+(((d[p]|0)+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[c]|0)+(d[o]|0)|0)*3|0)-(d[l]|0)>>5)+1236056|0]|0;n=h+11|0;a[i+7|0]=a[((((d[p]|0)+(d[b]|0)|0)*20|0)+16+(((d[c]|0)+(d[k]|0)|0)*-6|0)-(d[o]|0)+(((d[l]|0)+(d[m]|0)|0)*3|0)-(d[n]|0)>>5)+1236056|0]|0;o=h+12|0;a[i+8|0]=a[((((d[c]|0)+(d[p]|0)|0)*20|0)+16+(((d[l]|0)+(d[b]|0)|0)*-6|0)-(d[m]|0)+(((d[n]|0)+(d[k]|0)|0)*3|0)-(d[o]|0)>>5)+1236056|0]|0;m=h+13|0;a[i+9|0]=a[((((d[l]|0)+(d[c]|0)|0)*20|0)+16+(((d[n]|0)+(d[p]|0)|0)*-6|0)-(d[k]|0)+(((d[o]|0)+(d[b]|0)|0)*3|0)-(d[m]|0)>>5)+1236056|0]|0;k=h+14|0;a[i+10|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+16+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[b]|0)+(((d[m]|0)+(d[p]|0)|0)*3|0)-(d[k]|0)>>5)+1236056|0]|0;b=h+15|0;a[i+11|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+16+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[p]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1236056|0]|0;p=h+16|0;a[i+12|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+16+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1236056|0]|0;c=d[p]|0;a[i+13|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+16+(((d[b]|0)+(d[o]|0)|0)*-6|0)-c-(d[l]|0)+((c+(d[n]|0)|0)*3|0)>>5)+1236056|0]|0;c=d[b]|0;l=d[p]|0;a[i+14|0]=a[(16-c+((c+(d[k]|0)|0)*20|0)+((l+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[o]|0)+l|0)*3|0)>>5)+1236056|0]|0;l=d[b]|0;b=d[p]|0;p=d[k]|0;a[i+15|0]=a[(16-p+((b+l|0)*20|0)+((p+b|0)*-6|0)-(d[o]|0)+(((d[m]|0)+l|0)*3|0)>>5)+1236056|0]|0;l=j+1|0;if((l|0)<(g|0)){h=h+f|0;i=i+e|0;j=l}else{break}}return}function L2(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=f*9|0;o=f*10|0;p=f*11|0;q=f*12|0;r=f*13|0;s=f*14|0;t=f*15|0;u=f<<4;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=e<<3;C=e*9|0;D=e*10|0;E=e*11|0;F=e*12|0;G=e*13|0;H=e*14|0;I=e*15|0;J=0;K=c;c=b;while(1){b=d[K]|0;L=d[K+f|0]|0;M=d[K+g|0]|0;N=d[K+h|0]|0;O=d[K+i|0]|0;P=d[K+j|0]|0;Q=d[K+k|0]|0;R=d[K+l|0]|0;S=d[K+m|0]|0;T=d[K+n|0]|0;U=d[K+o|0]|0;V=d[K+p|0]|0;W=d[K+q|0]|0;X=d[K+r|0]|0;Y=d[K+s|0]|0;Z=d[K+t|0]|0;_=d[K+u|0]|0;$=16-M|0;a[c]=a[($+((L+b|0)*20|0)+((M+b|0)*-6|0)-O+((N+L|0)*3|0)>>5)+1236056|0]|0;aa=16-L|0;a[c+e|0]=a[(aa+((M+L|0)*20|0)+((N+b|0)*-6|0)-P+((O+b|0)*3|0)>>5)+1236056|0]|0;ba=16-b|0;a[c+v|0]=a[(ba+((N+M|0)*20|0)+((O+L|0)*-6|0)-Q+((P+b|0)*3|0)>>5)+1236056|0]|0;a[c+w|0]=a[(ba+((O+N|0)*20|0)+((P+M|0)*-6|0)-R+((Q+L|0)*3|0)>>5)+1236056|0]|0;a[c+x|0]=a[(aa+((P+O|0)*20|0)+((Q+N|0)*-6|0)-S+((R+M|0)*3|0)>>5)+1236056|0]|0;a[c+y|0]=a[($+((Q+P|0)*20|0)+((R+O|0)*-6|0)-T+((S+N|0)*3|0)>>5)+1236056|0]|0;a[c+z|0]=a[(16-N+((R+Q|0)*20|0)+((S+P|0)*-6|0)-U+((T+O|0)*3|0)>>5)+1236056|0]|0;a[c+A|0]=a[(16-O+((S+R|0)*20|0)+((T+Q|0)*-6|0)-V+((U+P|0)*3|0)>>5)+1236056|0]|0;a[c+B|0]=a[(16-P+((T+S|0)*20|0)+((U+R|0)*-6|0)-W+((V+Q|0)*3|0)>>5)+1236056|0]|0;a[c+C|0]=a[(16-Q+((U+T|0)*20|0)+((V+S|0)*-6|0)-X+((W+R|0)*3|0)>>5)+1236056|0]|0;a[c+D|0]=a[(16-R+((V+U|0)*20|0)+((W+T|0)*-6|0)-Y+((X+S|0)*3|0)>>5)+1236056|0]|0;a[c+E|0]=a[(16-S+((W+V|0)*20|0)+((X+U|0)*-6|0)-Z+((Y+T|0)*3|0)>>5)+1236056|0]|0;a[c+F|0]=a[(16-T+((X+W|0)*20|0)+((Y+V|0)*-6|0)-_+((Z+U|0)*3|0)>>5)+1236056|0]|0;a[c+G|0]=a[(16-U+((Y+X|0)*20|0)-_+((Z+W|0)*-6|0)+((_+V|0)*3|0)>>5)+1236056|0]|0;a[c+H|0]=a[(16-V-Z+((Z+Y|0)*20|0)+((_+X|0)*-6|0)+((_+W|0)*3|0)>>5)+1236056|0]|0;a[c+I|0]=a[(16-W-Y+((Z+X|0)*3|0)+((_+Y|0)*-6|0)+((_+Z|0)*20|0)>>5)+1236056|0]|0;Z=J+1|0;if((Z|0)<16){J=Z;K=K+1|0;c=c+1|0}else{break}}return}function M2(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);l=j|0;c=g+1|0;L2(l,c,16,24);m=k|0;L2(m,n,16,16);D2(b,c,n,l,m,e,24,16,16,16,16);D2(b+8|0,g+9|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function N2(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);c=j|0;L2(c,l,16,24);l=k|0;L2(l,n,16,16);D2(b,g+24|0,h+16|0,c,l,e,24,16,16,16,16);D2(b+8|0,g+32|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function O2(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);l=j|0;L2(l,g+1|0,16,24);c=k|0;L2(c,n,16,16);D2(b,g+25|0,h+16|0,l,c,e,24,16,16,16,16);D2(b+8|0,g+33|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function P2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1192|0;h=g+408|0;j=g+680|0;k=g+936|0;l=g|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);L2(j|0,l,16,24);L2(k|0,n,16,16);n=0;while(1){l=n<<4;h=j+l|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=(m|e)-((m^e)>>>1&2139062143);e=l|4;l=j+e|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+e|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(h+4)>>2]=(e|m)-((e^m)>>>1&2139062143);m=n+1|0;if((m|0)<16){n=m}else{s=0;break}}do{n=s<<4;m=n|8;e=j+m|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(s,f)|0;c[b+(e+8)>>2]=(m|h)-((m^h)>>>1&2139062143);h=n|12;n=j+h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(e+12)>>2]=(h|m)-((h^m)>>>1&2139062143);s=s+1|0;}while((s|0)<16);i=g;return}function Q2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+1192|0;h=g|0;j=g+408|0;k=g+680|0;l=g+936|0;m=h|0;n=e;e=m;o=0;while(1){p=n;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=n+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;a[e+16|0]=a[n+16|0]|0;q=o+1|0;if((q|0)<17){n=n+f|0;e=e+24|0;o=q}else{break}}o=j|0;K2(o,m,16,24,17);L2(k|0,h+1|0,16,24);L2(l|0,o,16,16);o=0;while(1){h=o<<4;m=k+h|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(o,f)|0;c[b+m>>2]=(e|j)-((e^j)>>>1&2139062143);j=h|4;h=k+j|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(m+4)>>2]=(j|e)-((j^e)>>>1&2139062143);e=o+1|0;if((e|0)<16){o=e}else{t=0;break}}do{o=t<<4;e=o|8;j=k+e|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+e|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ba(t,f)|0;c[b+(j+8)>>2]=(e|m)-((e^m)>>>1&2139062143);m=o|12;o=k+m|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+m|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[b+(j+12)>>2]=(m|e)-((m^e)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function R2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;S2(o,n,8,16,9);k=l|0;T2(k,n,8,16);l=m|0;T2(l,o,8,8);U2(b,n,o,k,l,f,16,8,8,8,8);i=g;return}function S2(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=d[h]|0;c=h+1|0;k=d[c]|0;l=h+2|0;m=d[l]|0;n=h+3|0;o=h+4|0;a[i]=a[(15-m+((k+b|0)*20|0)+((m+b|0)*-6|0)-(d[o]|0)+(((d[n]|0)+k|0)*3|0)>>5)+1236056|0]|0;k=d[c]|0;b=d[h]|0;m=h+5|0;a[i+1|0]=a[(15-k+(((d[l]|0)+k|0)*20|0)+(((d[n]|0)+b|0)*-6|0)-(d[m]|0)+(((d[o]|0)+b|0)*3|0)>>5)+1236056|0]|0;b=d[h]|0;k=h+6|0;a[i+2|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+15-b+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+b|0)*3|0)>>5)+1236056|0]|0;b=h+7|0;a[i+3|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+15+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1236056|0]|0;p=h+8|0;a[i+4|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+15+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1236056|0]|0;c=d[p]|0;a[i+5|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+15+(((d[b]|0)+(d[o]|0)|0)*-6|0)-c-(d[l]|0)+((c+(d[n]|0)|0)*3|0)>>5)+1236056|0]|0;c=d[b]|0;l=d[p]|0;a[i+6|0]=a[(15-c+((c+(d[k]|0)|0)*20|0)+((l+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[o]|0)+l|0)*3|0)>>5)+1236056|0]|0;l=d[b]|0;b=d[p]|0;p=d[k]|0;a[i+7|0]=a[(15-p+((b+l|0)*20|0)+((p+b|0)*-6|0)-(d[o]|0)+(((d[m]|0)+l|0)*3|0)>>5)+1236056|0]|0;l=j+1|0;if((l|0)<(g|0)){h=h+f|0;i=i+e|0;j=l}else{break}}return}function T2(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=e<<1;o=e*3|0;p=e<<2;q=e*5|0;r=e*6|0;s=e*7|0;t=0;u=c;c=b;while(1){b=d[u]|0;v=d[u+f|0]|0;w=d[u+g|0]|0;x=d[u+h|0]|0;y=d[u+i|0]|0;z=d[u+j|0]|0;A=d[u+k|0]|0;B=d[u+l|0]|0;C=d[u+m|0]|0;D=15-w|0;a[c]=a[(D+((v+b|0)*20|0)+((w+b|0)*-6|0)-y+((x+v|0)*3|0)>>5)+1236056|0]|0;E=15-v|0;a[c+e|0]=a[(E+((w+v|0)*20|0)+((x+b|0)*-6|0)-z+((y+b|0)*3|0)>>5)+1236056|0]|0;F=15-b|0;a[c+n|0]=a[(F+((x+w|0)*20|0)+((y+v|0)*-6|0)-A+((z+b|0)*3|0)>>5)+1236056|0]|0;a[c+o|0]=a[(F+((y+x|0)*20|0)+((z+w|0)*-6|0)-B+((A+v|0)*3|0)>>5)+1236056|0]|0;a[c+p|0]=a[(E+((z+y|0)*20|0)+((A+x|0)*-6|0)-C+((B+w|0)*3|0)>>5)+1236056|0]|0;a[c+q|0]=a[(D+((A+z|0)*20|0)-C+((B+y|0)*-6|0)+((C+x|0)*3|0)>>5)+1236056|0]|0;a[c+r|0]=a[(15-x-B+((B+A|0)*20|0)+((C+z|0)*-6|0)+((C+y|0)*3|0)>>5)+1236056|0]|0;a[c+s|0]=a[(15-y-A+((B+z|0)*3|0)+((C+A|0)*-6|0)+((C+B|0)*20|0)>>5)+1236056|0]|0;B=t+1|0;if((B|0)<8){t=B;u=u+1|0;c=c+1|0}else{break}}return}function U2(a,b,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((m|0)>0){n=0}else{return}do{o=ba(n,i)|0;p=b+o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(n,j)|0;r=e+p|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ba(n,k)|0;t=f+r|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=ba(n,l)|0;v=g+t|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=ba(n,h)|0;c[a+v>>2]=(s>>>2&1061109567)+(q>>>2&1061109567)+(u>>>2&1061109567)+(w>>>2&1061109567)+(((q&50529027)+16843009+(s&50529027)+(u&50529027)+(w&50529027)|0)>>>2&252645135);w=b+(o+4)|0;o=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=e+(p+4)|0;p=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=f+(r+4)|0;r=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=g+(t+4)|0;t=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[a+(v+4)>>2]=(p>>>2&1061109567)+(o>>>2&1061109567)+(r>>>2&1061109567)+(t>>>2&1061109567)+(((o&50529027)+16843009+(p&50529027)+(r&50529027)+(t&50529027)|0)>>>2&252645135);n=n+1|0;}while((n|0)<(m|0));return}function V2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;S2(n,h,8,16,9);k=l|0;l=h+1|0;T2(k,l,8,16);h=m|0;T2(h,n,8,8);U2(b,l,n,k,h,f,16,8,8,8,8);i=g;return}function W2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;p=f<<1;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+40|0]=a[e+(p+8)|0]|0;q=h+48|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+56|0]=a[e+(j+8)|0]|0;p=h+64|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+72|0]=a[e+(q+8)|0]|0;j=h+80|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+88|0]=a[e+(p+8)|0]|0;q=h+96|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+104|0]=a[e+(j+8)|0]|0;p=h+112|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+120|0]=a[e+(q+8)|0]|0;j=h+128|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+136|0]=a[e+(p+8)|0]|0;p=k|0;S2(p,n,8,16,9);e=l|0;T2(e,n,8,16);n=m|0;T2(n,p,8,8);U2(b,o,k+8|0,e,n,f,16,8,8,8,8);i=g;return}function X2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=i;i=i+64|0;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=l|0;S2(o,h,8,16,9);h=m|0;T2(h,k+1|0,8,16);m=n|0;T2(m,o,8,8);U2(b,k+17|0,l+8|0,h,m,f,16,8,8,8,8);i=g;return}function Y2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;S2(o,n,8,16,9);T2(l|0,n,8,16);T2(m|0,o,8,8);o=0;do{n=o<<3;k=l+n|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+n|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(o,f)|0;c[b+k>>2]=((h^e)>>>1&2139062143)+(h&e);e=n|4;n=l+e|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+e|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(k+4)>>2]=((e^h)>>>1&2139062143)+(e&h);o=o+1|0;}while((o|0)<8);i=g;return}function Z2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;S2(n,h,8,16,9);T2(l|0,h+1|0,8,16);T2(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(n,f)|0;c[b+k>>2]=((o^e)>>>1&2139062143)+(o&e);e=h|4;h=l+e|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=((e^o)>>>1&2139062143)+(e&o);n=n+1|0;}while((n|0)<8);i=g;return}function _2(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;$2(n,l,16,24,17);c=j|0;a3(c,l,16,24);m=k|0;a3(m,n,16,16);U2(b,l,n,c,m,e,24,16,16,16,16);U2(b+8|0,g+8|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function $2(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=d[h]|0;c=h+1|0;k=d[c]|0;l=h+2|0;m=d[l]|0;n=h+3|0;o=h+4|0;a[i]=a[(15-m+((k+b|0)*20|0)+((m+b|0)*-6|0)-(d[o]|0)+(((d[n]|0)+k|0)*3|0)>>5)+1236056|0]|0;k=d[c]|0;b=d[h]|0;m=h+5|0;a[i+1|0]=a[(15-k+(((d[l]|0)+k|0)*20|0)+(((d[n]|0)+b|0)*-6|0)-(d[m]|0)+(((d[o]|0)+b|0)*3|0)>>5)+1236056|0]|0;b=d[h]|0;k=h+6|0;a[i+2|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+15-b+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+b|0)*3|0)>>5)+1236056|0]|0;b=h+7|0;a[i+3|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+15+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1236056|0]|0;p=h+8|0;a[i+4|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+15+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1236056|0]|0;c=h+9|0;a[i+5|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+15+(((d[b]|0)+(d[o]|0)|0)*-6|0)-(d[l]|0)+(((d[p]|0)+(d[n]|0)|0)*3|0)-(d[c]|0)>>5)+1236056|0]|0;l=h+10|0;a[i+6|0]=a[((((d[b]|0)+(d[k]|0)|0)*20|0)+15+(((d[p]|0)+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[c]|0)+(d[o]|0)|0)*3|0)-(d[l]|0)>>5)+1236056|0]|0;n=h+11|0;a[i+7|0]=a[((((d[p]|0)+(d[b]|0)|0)*20|0)+15+(((d[c]|0)+(d[k]|0)|0)*-6|0)-(d[o]|0)+(((d[l]|0)+(d[m]|0)|0)*3|0)-(d[n]|0)>>5)+1236056|0]|0;o=h+12|0;a[i+8|0]=a[((((d[c]|0)+(d[p]|0)|0)*20|0)+15+(((d[l]|0)+(d[b]|0)|0)*-6|0)-(d[m]|0)+(((d[n]|0)+(d[k]|0)|0)*3|0)-(d[o]|0)>>5)+1236056|0]|0;m=h+13|0;a[i+9|0]=a[((((d[l]|0)+(d[c]|0)|0)*20|0)+15+(((d[n]|0)+(d[p]|0)|0)*-6|0)-(d[k]|0)+(((d[o]|0)+(d[b]|0)|0)*3|0)-(d[m]|0)>>5)+1236056|0]|0;k=h+14|0;a[i+10|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+15+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[b]|0)+(((d[m]|0)+(d[p]|0)|0)*3|0)-(d[k]|0)>>5)+1236056|0]|0;b=h+15|0;a[i+11|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+15+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[p]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1236056|0]|0;p=h+16|0;a[i+12|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+15+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1236056|0]|0;c=d[p]|0;a[i+13|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+15+(((d[b]|0)+(d[o]|0)|0)*-6|0)-c-(d[l]|0)+((c+(d[n]|0)|0)*3|0)>>5)+1236056|0]|0;c=d[b]|0;l=d[p]|0;a[i+14|0]=a[(15-c+((c+(d[k]|0)|0)*20|0)+((l+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[o]|0)+l|0)*3|0)>>5)+1236056|0]|0;l=d[b]|0;b=d[p]|0;p=d[k]|0;a[i+15|0]=a[(15-p+((b+l|0)*20|0)+((p+b|0)*-6|0)-(d[o]|0)+(((d[m]|0)+l|0)*3|0)>>5)+1236056|0]|0;l=j+1|0;if((l|0)<(g|0)){h=h+f|0;i=i+e|0;j=l}else{break}}return}function a3(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=f*9|0;o=f*10|0;p=f*11|0;q=f*12|0;r=f*13|0;s=f*14|0;t=f*15|0;u=f<<4;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=e<<3;C=e*9|0;D=e*10|0;E=e*11|0;F=e*12|0;G=e*13|0;H=e*14|0;I=e*15|0;J=0;K=c;c=b;while(1){b=d[K]|0;L=d[K+f|0]|0;M=d[K+g|0]|0;N=d[K+h|0]|0;O=d[K+i|0]|0;P=d[K+j|0]|0;Q=d[K+k|0]|0;R=d[K+l|0]|0;S=d[K+m|0]|0;T=d[K+n|0]|0;U=d[K+o|0]|0;V=d[K+p|0]|0;W=d[K+q|0]|0;X=d[K+r|0]|0;Y=d[K+s|0]|0;Z=d[K+t|0]|0;_=d[K+u|0]|0;$=15-M|0;a[c]=a[($+((L+b|0)*20|0)+((M+b|0)*-6|0)-O+((N+L|0)*3|0)>>5)+1236056|0]|0;aa=15-L|0;a[c+e|0]=a[(aa+((M+L|0)*20|0)+((N+b|0)*-6|0)-P+((O+b|0)*3|0)>>5)+1236056|0]|0;ba=15-b|0;a[c+v|0]=a[(ba+((N+M|0)*20|0)+((O+L|0)*-6|0)-Q+((P+b|0)*3|0)>>5)+1236056|0]|0;a[c+w|0]=a[(ba+((O+N|0)*20|0)+((P+M|0)*-6|0)-R+((Q+L|0)*3|0)>>5)+1236056|0]|0;a[c+x|0]=a[(aa+((P+O|0)*20|0)+((Q+N|0)*-6|0)-S+((R+M|0)*3|0)>>5)+1236056|0]|0;a[c+y|0]=a[($+((Q+P|0)*20|0)+((R+O|0)*-6|0)-T+((S+N|0)*3|0)>>5)+1236056|0]|0;a[c+z|0]=a[(15-N+((R+Q|0)*20|0)+((S+P|0)*-6|0)-U+((T+O|0)*3|0)>>5)+1236056|0]|0;a[c+A|0]=a[(15-O+((S+R|0)*20|0)+((T+Q|0)*-6|0)-V+((U+P|0)*3|0)>>5)+1236056|0]|0;a[c+B|0]=a[(15-P+((T+S|0)*20|0)+((U+R|0)*-6|0)-W+((V+Q|0)*3|0)>>5)+1236056|0]|0;a[c+C|0]=a[(15-Q+((U+T|0)*20|0)+((V+S|0)*-6|0)-X+((W+R|0)*3|0)>>5)+1236056|0]|0;a[c+D|0]=a[(15-R+((V+U|0)*20|0)+((W+T|0)*-6|0)-Y+((X+S|0)*3|0)>>5)+1236056|0]|0;a[c+E|0]=a[(15-S+((W+V|0)*20|0)+((X+U|0)*-6|0)-Z+((Y+T|0)*3|0)>>5)+1236056|0]|0;a[c+F|0]=a[(15-T+((X+W|0)*20|0)+((Y+V|0)*-6|0)-_+((Z+U|0)*3|0)>>5)+1236056|0]|0;a[c+G|0]=a[(15-U+((Y+X|0)*20|0)-_+((Z+W|0)*-6|0)+((_+V|0)*3|0)>>5)+1236056|0]|0;a[c+H|0]=a[(15-V-Z+((Z+Y|0)*20|0)+((_+X|0)*-6|0)+((_+W|0)*3|0)>>5)+1236056|0]|0;a[c+I|0]=a[(15-W-Y+((Z+X|0)*3|0)+((_+Y|0)*-6|0)+((_+Z|0)*20|0)>>5)+1236056|0]|0;Z=J+1|0;if((Z|0)<16){J=Z;K=K+1|0;c=c+1|0}else{break}}return}function b3(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;$2(n,l,16,24,17);l=j|0;c=g+1|0;a3(l,c,16,24);m=k|0;a3(m,n,16,16);U2(b,c,n,l,m,e,24,16,16,16,16);U2(b+8|0,g+9|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function c3(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;$2(n,l,16,24,17);c=j|0;a3(c,l,16,24);l=k|0;a3(l,n,16,16);U2(b,g+24|0,h+16|0,c,l,e,24,16,16,16,16);U2(b+8|0,g+32|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function d3(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;$2(n,l,16,24,17);l=j|0;a3(l,g+1|0,16,24);c=k|0;a3(c,n,16,16);U2(b,g+25|0,h+16|0,l,c,e,24,16,16,16,16);U2(b+8|0,g+33|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function e3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1192|0;h=g+408|0;j=g+680|0;k=g+936|0;l=g|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=h|0;$2(n,l,16,24,17);a3(j|0,l,16,24);a3(k|0,n,16,16);n=0;while(1){l=n<<4;h=j+l|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=((m^e)>>>1&2139062143)+(m&e);e=l|4;l=j+e|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+e|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(h+4)>>2]=((e^m)>>>1&2139062143)+(e&m);m=n+1|0;if((m|0)<16){n=m}else{s=0;break}}do{n=s<<4;m=n|8;e=j+m|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(s,f)|0;c[b+(e+8)>>2]=((m^h)>>>1&2139062143)+(m&h);h=n|12;n=j+h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(e+12)>>2]=((h^m)>>>1&2139062143)+(h&m);s=s+1|0;}while((s|0)<16);i=g;return}function f3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+1192|0;h=g|0;j=g+408|0;k=g+680|0;l=g+936|0;m=h|0;n=e;e=m;o=0;while(1){p=n;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=n+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;a[e+16|0]=a[n+16|0]|0;q=o+1|0;if((q|0)<17){n=n+f|0;e=e+24|0;o=q}else{break}}o=j|0;$2(o,m,16,24,17);a3(k|0,h+1|0,16,24);a3(l|0,o,16,16);o=0;while(1){h=o<<4;m=k+h|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(o,f)|0;c[b+m>>2]=((e^j)>>>1&2139062143)+(e&j);j=h|4;h=k+j|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(m+4)>>2]=((j^e)>>>1&2139062143)+(j&e);e=o+1|0;if((e|0)<16){o=e}else{t=0;break}}do{o=t<<4;e=o|8;j=k+e|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+e|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ba(t,f)|0;c[b+(j+8)>>2]=((e^m)>>>1&2139062143)+(e&m);m=o|12;o=k+m|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+m|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[b+(j+12)>>2]=((m^e)>>>1&2139062143)+(m&e);t=t+1|0;}while((t|0)<16);i=g;return}function g3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;B2(o,n,8,16,9);k=l|0;C2(k,n,8,16);l=m|0;C2(l,o,8,8);h3(b,n,o,k,l,f,16,8,8,8,8);i=g;return}function h3(a,b,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((m|0)>0){n=0}else{return}do{o=ba(n,i)|0;p=b+o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(n,j)|0;r=e+p|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ba(n,k)|0;t=f+r|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=ba(n,l)|0;v=g+t|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=ba(n,h)|0;x=a+v|0;y=c[x>>2]|0;z=(s>>>2&1061109567)+(q>>>2&1061109567)+(u>>>2&1061109567)+(w>>>2&1061109567)+(((q&50529027)+33686018+(s&50529027)+(u&50529027)+(w&50529027)|0)>>>2&252645135)|0;c[x>>2]=(z|y)-((z^y)>>>1&2139062143);y=b+(o+4)|0;o=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=e+(p+4)|0;p=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=f+(r+4)|0;r=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=g+(t+4)|0;t=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=a+(v+4)|0;v=c[y>>2]|0;z=(p>>>2&1061109567)+(o>>>2&1061109567)+(r>>>2&1061109567)+(t>>>2&1061109567)+(((o&50529027)+33686018+(p&50529027)+(r&50529027)+(t&50529027)|0)>>>2&252645135)|0;c[y>>2]=(z|v)-((z^v)>>>1&2139062143);n=n+1|0;}while((n|0)<(m|0));return}function i3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;B2(n,h,8,16,9);k=l|0;l=h+1|0;C2(k,l,8,16);h=m|0;C2(h,n,8,8);h3(b,l,n,k,h,f,16,8,8,8,8);i=g;return}function j3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;p=f<<1;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+40|0]=a[e+(p+8)|0]|0;q=h+48|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+56|0]=a[e+(j+8)|0]|0;p=h+64|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+72|0]=a[e+(q+8)|0]|0;j=h+80|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+88|0]=a[e+(p+8)|0]|0;q=h+96|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+104|0]=a[e+(j+8)|0]|0;p=h+112|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+120|0]=a[e+(q+8)|0]|0;j=h+128|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+136|0]=a[e+(p+8)|0]|0;p=k|0;B2(p,n,8,16,9);e=l|0;C2(e,n,8,16);n=m|0;C2(n,p,8,8);h3(b,o,k+8|0,e,n,f,16,8,8,8,8);i=g;return}function k3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=i;i=i+64|0;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=l|0;B2(o,h,8,16,9);h=m|0;C2(h,k+1|0,8,16);m=n|0;C2(m,o,8,8);h3(b,k+17|0,l+8|0,h,m,f,16,8,8,8,8);i=g;return}function l3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;B2(o,n,8,16,9);C2(l|0,n,8,16);C2(m|0,o,8,8);o=0;do{n=o<<3;k=l+n|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+n|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(o,f)|0;p=b+k|0;j=c[p>>2]|0;q=(h|e)-((h^e)>>>1&2139062143)|0;c[p>>2]=(q|j)-((q^j)>>>1&2139062143);j=n|4;n=l+j|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+j|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(k+4)|0;k=c[n>>2]|0;p=(j|q)-((j^q)>>>1&2139062143)|0;c[n>>2]=(p|k)-((p^k)>>>1&2139062143);o=o+1|0;}while((o|0)<8);i=g;return}function m3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;B2(n,h,8,16,9);C2(l|0,h+1|0,8,16);C2(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(n,f)|0;j=b+k|0;p=c[j>>2]|0;q=(o|e)-((o^e)>>>1&2139062143)|0;c[j>>2]=(q|p)-((q^p)>>>1&2139062143);p=h|4;h=l+p|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(k+4)|0;k=c[h>>2]|0;j=(p|q)-((p^q)>>>1&2139062143)|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function n3(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);c=j|0;L2(c,l,16,24);m=k|0;L2(m,n,16,16);h3(b,l,n,c,m,e,24,16,16,16,16);h3(b+8|0,g+8|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function o3(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);l=j|0;c=g+1|0;L2(l,c,16,24);m=k|0;L2(m,n,16,16);h3(b,c,n,l,m,e,24,16,16,16,16);h3(b+8|0,g+9|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function p3(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);c=j|0;L2(c,l,16,24);l=k|0;L2(l,n,16,16);h3(b,g+24|0,h+16|0,c,l,e,24,16,16,16,16);h3(b+8|0,g+32|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function q3(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);l=j|0;L2(l,g+1|0,16,24);c=k|0;L2(c,n,16,16);h3(b,g+25|0,h+16|0,l,c,e,24,16,16,16,16);h3(b+8|0,g+33|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function r3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1192|0;h=g+408|0;j=g+680|0;k=g+936|0;l=g|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=h|0;K2(n,l,16,24,17);L2(j|0,l,16,24);L2(k|0,n,16,16);n=0;while(1){l=n<<4;h=j+l|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;p=b+h|0;r=c[p>>2]|0;q=(m|e)-((m^e)>>>1&2139062143)|0;c[p>>2]=(q|r)-((q^r)>>>1&2139062143);r=l|4;l=j+r|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+r|0;r=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(h+4)|0;h=c[l>>2]|0;p=(r|q)-((r^q)>>>1&2139062143)|0;c[l>>2]=(p|h)-((p^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{s=0;break}}do{n=s<<4;h=n|8;p=j+h|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(s,f)|0;q=b+(p+8)|0;r=c[q>>2]|0;e=(h|l)-((h^l)>>>1&2139062143)|0;c[q>>2]=(e|r)-((e^r)>>>1&2139062143);r=n|12;n=j+r|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+r|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(p+12)|0;p=c[n>>2]|0;q=(r|e)-((r^e)>>>1&2139062143)|0;c[n>>2]=(q|p)-((q^p)>>>1&2139062143);s=s+1|0;}while((s|0)<16);i=g;return}function s3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+1192|0;h=g|0;j=g+408|0;k=g+680|0;l=g+936|0;m=h|0;n=e;e=m;o=0;while(1){p=n;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=n+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;a[e+16|0]=a[n+16|0]|0;q=o+1|0;if((q|0)<17){n=n+f|0;e=e+24|0;o=q}else{break}}o=j|0;K2(o,m,16,24,17);L2(k|0,h+1|0,16,24);L2(l|0,o,16,16);o=0;while(1){h=o<<4;m=k+h|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(o,f)|0;n=b+m|0;q=c[n>>2]|0;s=(e|j)-((e^j)>>>1&2139062143)|0;c[n>>2]=(s|q)-((s^q)>>>1&2139062143);q=h|4;h=k+q|0;s=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+q|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(m+4)|0;m=c[h>>2]|0;n=(q|s)-((q^s)>>>1&2139062143)|0;c[h>>2]=(n|m)-((n^m)>>>1&2139062143);m=o+1|0;if((m|0)<16){o=m}else{t=0;break}}do{o=t<<4;m=o|8;n=k+m|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+m|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(t,f)|0;s=b+(n+8)|0;q=c[s>>2]|0;j=(m|h)-((m^h)>>>1&2139062143)|0;c[s>>2]=(j|q)-((j^q)>>>1&2139062143);q=o|12;o=k+q|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+q|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+12)|0;n=c[o>>2]|0;s=(q|j)-((q^j)>>>1&2139062143)|0;c[o>>2]=(s|n)-((s^n)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function t3(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(e+4)|0;c[a+(e+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=e<<1;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;e=b+g|0;c[a+h>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=b+(g+4)|0;c[a+(h+4)>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function u3(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=f;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[g>>2]=(j|h)-((j^h)>>>1&2139062143);h=b+4|0;j=c[h>>2]|0;g=f+4|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[h>>2]=(i|j)-((i^j)>>>1&2139062143);j=a+1|0;if((j|0)<8){f=f+e|0;b=b+e|0;a=j}else{break}}return}function v3(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(e+4)|0;c[a+(e+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=e<<1;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+8|0;c[a+8>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+12|0;c[a+12>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=e+8|0;f=e+8|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(e+12)|0;c[a+(e+12)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;g=b+f|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(f+4)|0;c[a+(h+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=h+e|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(g+4)|0;c[a+(f+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;g=b+f|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(f+4)|0;c[a+(h+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=h+e|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(g+4)|0;c[a+(f+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;g=b+f|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(f+4)|0;c[a+(h+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=h+e|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(g+4)|0;c[a+(f+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;g=b+f|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(f+4)|0;c[a+(h+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=h+e|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(g+4)|0;c[a+(f+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;e=b+f|0;c[a+h>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=b+(f+4)|0;c[a+(h+4)>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function w3(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=f;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[i>>2]=(l|j)-((l^j)>>>1&2139062143);j=g+4|0;l=c[j>>2]|0;i=f+4|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[j>>2]=(k|l)-((k^l)>>>1&2139062143);l=h+1|0;if((l|0)<16){f=f+e|0;g=g+e|0;h=l}else{break}}h=b+8|0;b=a+8|0;a=0;while(1){g=b;f=c[g>>2]|0;l=h;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[g>>2]=(k|f)-((k^f)>>>1&2139062143);f=b+4|0;k=c[f>>2]|0;g=h+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[f>>2]=(l|k)-((l^k)>>>1&2139062143);k=a+1|0;if((k|0)<16){h=h+e|0;b=b+e|0;a=k}else{break}}return}function x3(a,b,c){a=a|0;b=b|0;c=c|0;A3(a,b,c,16);A3(a+8|0,b+8|0,c,16);return}function y3(a,b,c){a=a|0;b=b|0;c=c|0;C3(a,b,c,16);C3(a+8|0,b+8|0,c,16);return}function z3(a,b,c){a=a|0;b=b|0;c=c|0;A3(a,b,c,8);return}function A3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=e+4-(ba(f+1|0,e)|0)|0;h=4-(ba(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+33686018+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;c[b>>2]=r+o+((a+l|0)>>>2&252645135);p=n+j|0;q=p;s=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+k|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=(s&50529027)+33686018+(t&50529027)|0;u=(t>>>2&1061109567)+(s>>>2&1061109567)|0;c[b+e>>2]=u+r+((q+a|0)>>>2&252645135);a=m+2|0;if((a|0)<(f|0)){l=q;o=u;m=a;n=p;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+33686018+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(p&50529027)+(b&50529027)|0;a=(p>>>2&1061109567)+(b>>>2&1061109567)|0;c[m>>2]=a+n+((h+o|0)>>>2&252645135);b=g+j|0;p=b;u=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+k|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=(u&50529027)+33686018+(q&50529027)|0;r=(q>>>2&1061109567)+(u>>>2&1061109567)|0;c[m+e>>2]=r+a+((p+h|0)>>>2&252645135);h=l+2|0;if((h|0)<(f|0)){o=p;n=r;l=h;g=b;m=m+j|0}else{break}}return}function B3(a,b,c){a=a|0;b=b|0;c=c|0;C3(a,b,c,8);return}function C3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=e+4-(ba(f+1|0,e)|0)|0;h=4-(ba(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+33686018+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;p=b;q=c[p>>2]|0;s=r+o+((a+l|0)>>>2&252645135)|0;c[p>>2]=(s|q)-((s^q)>>>1&2139062143);q=n+j|0;s=q;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+k|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=(p&50529027)+33686018+(t&50529027)|0;u=(t>>>2&1061109567)+(p>>>2&1061109567)|0;p=b+e|0;t=c[p>>2]|0;v=u+r+((s+a|0)>>>2&252645135)|0;c[p>>2]=(v|t)-((v^t)>>>1&2139062143);t=m+2|0;if((t|0)<(f|0)){l=s;o=u;m=t;n=q;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+33686018+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(q&50529027)+(b&50529027)|0;t=(q>>>2&1061109567)+(b>>>2&1061109567)|0;b=m;q=c[b>>2]|0;u=t+n+((h+o|0)>>>2&252645135)|0;c[b>>2]=(u|q)-((u^q)>>>1&2139062143);q=g+j|0;u=q;b=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=g+k|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=(b&50529027)+33686018+(s&50529027)|0;v=(s>>>2&1061109567)+(b>>>2&1061109567)|0;b=m+e|0;s=c[b>>2]|0;p=v+t+((u+h|0)>>>2&252645135)|0;c[b>>2]=(p|s)-((p^s)>>>1&2139062143);s=l+2|0;if((s|0)<(f|0)){o=u;n=v;l=s;g=q;m=m+j|0}else{break}}return}function D3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;if((f|0)<=0){return}g=c[b>>2]|0;b=a;a=0;while(1){h=g;c[b>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+4|0;c[b+4>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=a+1|0;if((h|0)<(f|0)){g=g+e|0;b=b+e|0;a=h}else{break}}return}function E3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[b>>2]|0;if((f|0)>0){h=g;i=a;j=0}else{return}while(1){b=h;c[i>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=h+4|0;c[i+4>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=j+1|0;if((b|0)<(f|0)){h=h+e|0;i=i+e|0;j=b}else{break}}j=g+8|0;g=a+8|0;a=0;while(1){i=j;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=j+4|0;c[g+4>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=a+1|0;if((i|0)<(f|0)){j=j+e|0;g=g+e|0;a=i}else{break}}return}function F3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[b>>2]|0;if((f|0)>0){h=g;i=a;j=0}else{return}while(1){b=h;c[i>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=h+4|0;c[i+4>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=j+1|0;if((b|0)<(f|0)){h=h+e|0;i=i+e|0;j=b}else{break}}j=g+8|0;i=a+8|0;h=0;while(1){b=j;c[i>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=j+4|0;c[i+4>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=h+1|0;if((b|0)<(f|0)){j=j+e|0;i=i+e|0;h=b}else{break}}h=g+16|0;i=a+16|0;j=0;while(1){b=h;c[i>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=h+4|0;c[i+4>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=j+1|0;if((b|0)<(f|0)){h=h+e|0;i=i+e|0;j=b}else{break}}j=g+24|0;g=a+24|0;a=0;while(1){i=j;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=j+4|0;c[g+4>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=a+1|0;if((i|0)<(f|0)){j=j+e|0;g=g+e|0;a=i}else{break}}return}function G3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}do{b=ba(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+b>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+4|0;b=g+k|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+k|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+k>>2]=(j|l)-((j^l)>>>1&2139062143);i=i+1|0;}while((i|0)<(f|0));return}function H3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}while(1){b=ba(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+b>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+4|0;b=g+k|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+k|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+k>>2]=(j|l)-((j^l)>>>1&2139062143);l=i+1|0;if((l|0)<(f|0)){i=l}else{m=0;break}}do{i=ba(m,e)|0;l=i+8|0;j=g+l|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+l|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(b|k)-((b^k)>>>1&2139062143);k=i+12|0;i=g+k|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=h+k|0;l=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+k>>2]=(l|b)-((l^b)>>>1&2139062143);m=m+1|0;}while((m|0)<(f|0));return}function I3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}while(1){b=ba(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+b>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+4|0;b=g+k|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+k|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+k>>2]=(j|l)-((j^l)>>>1&2139062143);l=i+1|0;if((l|0)<(f|0)){i=l}else{m=0;break}}while(1){i=ba(m,e)|0;l=i+8|0;j=g+l|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+l|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(b|k)-((b^k)>>>1&2139062143);k=i+12|0;i=g+k|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=h+k|0;l=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+k>>2]=(l|b)-((l^b)>>>1&2139062143);b=m+1|0;if((b|0)<(f|0)){m=b}else{n=0;break}}while(1){m=ba(n,e)|0;b=m+16|0;l=g+b|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+b|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+b>>2]=(i|k)-((i^k)>>>1&2139062143);k=m+20|0;m=g+k|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+k|0;b=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+k>>2]=(b|i)-((b^i)>>>1&2139062143);i=n+1|0;if((i|0)<(f|0)){n=i}else{o=0;break}}do{n=ba(o,e)|0;i=n+24|0;b=g+i|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+i|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+i>>2]=(m|k)-((m^k)>>>1&2139062143);k=n+28|0;n=g+k|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+k|0;i=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[a+k>>2]=(i|m)-((i^m)>>>1&2139062143);o=o+1|0;}while((o|0)<(f|0));return}function J3(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;D2(a,c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,c[b+12>>2]|0,d,d,d,d,d,e);return}function K3(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[b>>2]|0;g=c[b+4>>2]|0;h=c[b+8>>2]|0;i=c[b+12>>2]|0;D2(a,f,g,h,i,d,d,d,d,d,e);D2(a+8|0,f+8|0,g+8|0,h+8|0,i+8|0,d,d,d,d,d,e);return}function L3(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[b>>2]|0;g=b+4|0;h=c[g>>2]|0;i=b+8|0;j=c[i>>2]|0;k=b+12|0;l=c[k>>2]|0;D2(a,f,h,j,l,d,d,d,d,d,e);D2(a+8|0,f+8|0,h+8|0,j+8|0,l+8|0,d,d,d,d,d,e);l=c[b>>2]|0;b=c[g>>2]|0;g=c[i>>2]|0;i=c[k>>2]|0;D2(a+16|0,l+16|0,b+16|0,g+16|0,i+16|0,d,d,d,d,d,e);D2(a+24|0,l+24|0,b+24|0,g+24|0,i+24|0,d,d,d,d,d,e);return}function M3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)<=0){return}g=c[b>>2]|0;b=a;a=0;while(1){h=b;i=c[h>>2]|0;j=g;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[h>>2]=(k|i)-((k^i)>>>1&2139062143);i=b+4|0;k=c[i>>2]|0;h=g+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[i>>2]=(j|k)-((j^k)>>>1&2139062143);k=a+1|0;if((k|0)<(f|0)){g=g+e|0;b=b+e|0;a=k}else{break}}return}function N3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c[b>>2]|0;if((f|0)>0){h=g;i=a;j=0}else{return}while(1){b=i;k=c[b>>2]|0;l=h;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b>>2]=(m|k)-((m^k)>>>1&2139062143);k=i+4|0;m=c[k>>2]|0;b=h+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<(f|0)){h=h+e|0;i=i+e|0;j=m}else{break}}j=g+8|0;g=a+8|0;a=0;while(1){i=g;h=c[i>>2]|0;m=j;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[i>>2]=(l|h)-((l^h)>>>1&2139062143);h=g+4|0;l=c[h>>2]|0;i=j+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);l=a+1|0;if((l|0)<(f|0)){j=j+e|0;g=g+e|0;a=l}else{break}}return}function O3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c[b>>2]|0;if((f|0)>0){h=g;i=a;j=0}else{return}while(1){b=i;k=c[b>>2]|0;l=h;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b>>2]=(m|k)-((m^k)>>>1&2139062143);k=i+4|0;m=c[k>>2]|0;b=h+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<(f|0)){h=h+e|0;i=i+e|0;j=m}else{break}}j=g+8|0;i=a+8|0;h=0;while(1){m=i;l=c[m>>2]|0;k=j;b=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[m>>2]=(b|l)-((b^l)>>>1&2139062143);l=i+4|0;b=c[l>>2]|0;m=j+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[l>>2]=(k|b)-((k^b)>>>1&2139062143);b=h+1|0;if((b|0)<(f|0)){j=j+e|0;i=i+e|0;h=b}else{break}}h=g+16|0;i=a+16|0;j=0;while(1){b=i;k=c[b>>2]|0;l=h;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b>>2]=(m|k)-((m^k)>>>1&2139062143);k=i+4|0;m=c[k>>2]|0;b=h+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<(f|0)){h=h+e|0;i=i+e|0;j=m}else{break}}j=g+24|0;g=a+24|0;a=0;while(1){i=g;h=c[i>>2]|0;m=j;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[i>>2]=(l|h)-((l^h)>>>1&2139062143);h=g+4|0;l=c[h>>2]|0;i=j+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);l=a+1|0;if((l|0)<(f|0)){j=j+e|0;g=g+e|0;a=l}else{break}}return}function P3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}do{b=ba(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+b|0;m=c[j>>2]|0;n=(l|k)-((l^k)>>>1&2139062143)|0;c[j>>2]=(n|m)-((n^m)>>>1&2139062143);m=b+4|0;b=g+m|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+m|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+m|0;m=c[b>>2]|0;k=(j|n)-((j^n)>>>1&2139062143)|0;c[b>>2]=(k|m)-((k^m)>>>1&2139062143);i=i+1|0;}while((i|0)<(f|0));return}function Q3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}while(1){b=ba(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+b|0;m=c[j>>2]|0;n=(l|k)-((l^k)>>>1&2139062143)|0;c[j>>2]=(n|m)-((n^m)>>>1&2139062143);m=b+4|0;b=g+m|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+m|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+m|0;m=c[b>>2]|0;k=(j|n)-((j^n)>>>1&2139062143)|0;c[b>>2]=(k|m)-((k^m)>>>1&2139062143);m=i+1|0;if((m|0)<(f|0)){i=m}else{o=0;break}}do{i=ba(o,e)|0;m=i+8|0;k=g+m|0;b=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+m|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+m|0;m=c[k>>2]|0;j=(n|b)-((n^b)>>>1&2139062143)|0;c[k>>2]=(j|m)-((j^m)>>>1&2139062143);m=i+12|0;i=g+m|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=h+m|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+m|0;m=c[i>>2]|0;b=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(b|m)-((b^m)>>>1&2139062143);o=o+1|0;}while((o|0)<(f|0));return}function R3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=(f|0)>0;if(b){i=0}else{return}while(1){j=ba(i,e)|0;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+j|0;n=c[k>>2]|0;o=(m|l)-((m^l)>>>1&2139062143)|0;c[k>>2]=(o|n)-((o^n)>>>1&2139062143);n=j+4|0;j=g+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+n|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+n|0;n=c[j>>2]|0;l=(k|o)-((k^o)>>>1&2139062143)|0;c[j>>2]=(l|n)-((l^n)>>>1&2139062143);n=i+1|0;if((n|0)<(f|0)){i=n}else{p=0;break}}while(1){i=ba(p,e)|0;n=i+8|0;l=g+n|0;j=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+n|0;n=c[l>>2]|0;k=(o|j)-((o^j)>>>1&2139062143)|0;c[l>>2]=(k|n)-((k^n)>>>1&2139062143);n=i+12|0;i=g+n|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=h+n|0;l=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+n|0;n=c[i>>2]|0;j=(l|k)-((l^k)>>>1&2139062143)|0;c[i>>2]=(j|n)-((j^n)>>>1&2139062143);n=p+1|0;if((n|0)<(f|0)){p=n}else{q=0;break}}do{p=ba(q,e)|0;n=p+16|0;j=g+n|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+n|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+n|0;n=c[j>>2]|0;l=(k|i)-((k^i)>>>1&2139062143)|0;c[j>>2]=(l|n)-((l^n)>>>1&2139062143);n=p+20|0;p=g+n|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+n|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+n|0;n=c[p>>2]|0;i=(j|l)-((j^l)>>>1&2139062143)|0;c[p>>2]=(i|n)-((i^n)>>>1&2139062143);q=q+1|0;}while((q|0)<(f|0));if(b){r=0}else{return}do{b=ba(r,e)|0;q=b+24|0;n=g+q|0;i=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+q|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+q|0;q=c[n>>2]|0;l=(p|i)-((p^i)>>>1&2139062143)|0;c[n>>2]=(l|q)-((l^q)>>>1&2139062143);q=b+28|0;b=g+q|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+q|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+q|0;q=c[b>>2]|0;i=(n|l)-((n^l)>>>1&2139062143)|0;c[b>>2]=(i|q)-((i^q)>>>1&2139062143);r=r+1|0;}while((r|0)<(f|0));return}function S3(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;h3(a,c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,c[b+12>>2]|0,d,d,d,d,d,e);return}function T3(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[b>>2]|0;g=c[b+4>>2]|0;h=c[b+8>>2]|0;i=c[b+12>>2]|0;h3(a,f,g,h,i,d,d,d,d,d,e);h3(a+8|0,f+8|0,g+8|0,h+8|0,i+8|0,d,d,d,d,d,e);return}function U3(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[b>>2]|0;g=b+4|0;h=c[g>>2]|0;i=b+8|0;j=c[i>>2]|0;k=b+12|0;l=c[k>>2]|0;h3(a,f,h,j,l,d,d,d,d,d,e);h3(a+8|0,f+8|0,h+8|0,j+8|0,l+8|0,d,d,d,d,d,e);l=c[b>>2]|0;b=c[g>>2]|0;g=c[i>>2]|0;i=c[k>>2]|0;h3(a+16|0,l+16|0,b+16|0,g+16|0,i+16|0,d,d,d,d,d,e);h3(a+24|0,l+24|0,b+24|0,g+24|0,i+24|0,d,d,d,d,d,e);return}function V3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;TGb(b|0,0,24)|0;f=d&255;d=0;do{switch(f|0){case 3:{c[b+(d<<2)>>2]=c[a+124+(d<<2)>>2];break};case 5:{c[b+(d<<2)>>2]=c[a+172+(d<<2)>>2];break};case 1:{c[b+(d<<2)>>2]=c[a+76+(d<<2)>>2];break};case 13:{c[b+(d<<2)>>2]=c[a+340+(d<<2)>>2];break};case 11:{c[b+(d<<2)>>2]=c[a+292+(d<<2)>>2];break};case 2:{c[b+(d<<2)>>2]=c[a+100+(d<<2)>>2];break};case 10:{c[b+(d<<2)>>2]=c[a+268+(d<<2)>>2];break};case 0:{c[b+(d<<2)>>2]=c[a+52+(d<<2)>>2];break};case 14:{c[b+(d<<2)>>2]=c[a+364+(d<<2)>>2];break};case 7:{c[b+(d<<2)>>2]=86;break};case 6:{c[b+(d<<2)>>2]=c[a+196+(d<<2)>>2];break};case 9:{c[b+(d<<2)>>2]=c[a+244+(d<<2)>>2];break};case 8:{c[b+(d<<2)>>2]=c[a+220+(d<<2)>>2];break};case 12:{c[b+(d<<2)>>2]=c[a+316+(d<<2)>>2];break};case 4:{c[b+(d<<2)>>2]=c[a+148+(d<<2)>>2];break};default:{yDb(0,16,2327168,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}}d=d+1|0;}while((d|0)<6);i=e;return}function W3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function X3(){var a=0,b=0;a=0;do{b=a-256|0;c[5398952+(a<<2)>>2]=ba(b,b)|0;a=a+1|0;}while((a|0)<512);return}function Y3(){return 0}function Z3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b+796|0;e=c[d>>2]|0;do{if((e|0)==10){c[a+1108>>2]=70;c[a+1112>>2]=60}else{f=c[b+784>>2]|0;if((f|0)==1){c[a+1108>>2]=8;c[a+1112>>2]=240;break}g=a+1108|0;if((f|0)==6){c[g>>2]=226;c[a+1112>>2]=322;break}else{c[g>>2]=80;c[a+1112>>2]=368;break}}}while(0);g=c[b+800>>2]|0;do{if((g|0)==1){c[a+1120>>2]=714;c[a+1124>>2]=118;c[a+1116>>2]=116;c[a+1192>>2]=1}else if((g|0)==3){c[a+1120>>2]=274;c[a+1124>>2]=388;c[a+1116>>2]=118;c[a+1192>>2]=1}else if((g|0)==2){c[a+1120>>2]=2334;c[a+1124>>2]=1598;c[a+1116>>2]=120;c[a+1192>>2]=1}else{if((e|0)==12){c[a+1120>>2]=224;c[a+1124>>2]=1998;c[a+1116>>2]=34;c[a+1192>>2]=1;break}else if((e|0)==10){c[a+1120>>2]=226;c[a+1124>>2]=108;c[a+1116>>2]=32;c[a+1192>>2]=1;break}else{f=c[b+788>>2]|0;if((f|0)==1){c[a+1120>>2]=1002;c[a+1124>>2]=1978;c[a+1116>>2]=342;c[a+1192>>2]=2;break}h=a+1120|0;if((f|0)==20){c[h>>2]=1070;c[a+1124>>2]=800;c[a+1116>>2]=172;c[a+1192>>2]=1;break}else{c[h>>2]=2148;c[a+1124>>2]=246;c[a+1116>>2]=258;c[a+1192>>2]=1;break}}}}while(0);c[a+4>>2]=612;c[a+8>>2]=1894;c[a+12>>2]=1128;c[a+16>>2]=1796;c[a+24>>2]=1242;c[a+28>>2]=442;c[a+32>>2]=2;c[a+44>>2]=442;c[a+48>>2]=844;c[a+1236>>2]=120;c[a+1240>>2]=752;c[a+1040>>2]=100;c[a+1044>>2]=140;c[a+1048>>2]=184;c[a+1052>>2]=56;c[a+1056>>2]=164;c[a+1060>>2]=122;c[a+1064>>2]=170;c[a+1068>>2]=58;c[a+536>>2]=460;c[a+540>>2]=24;c[a+544>>2]=394;c[a+552>>2]=220;c[a+556>>2]=498;c[a+560>>2]=412;c[a+568>>2]=46;c[a+572>>2]=390;c[a+576>>2]=480;c[a+580>>2]=158;c[a+584>>2]=74;c[a+588>>2]=484;c[a+596>>2]=380;c[a+600>>2]=126;c[a+604>>2]=204;c[a+612>>2]=306;c[a+616>>2]=466;c[a+620>>2]=344;c[a+624>>2]=932;c[a+628>>2]=524;c[a+632>>2]=94;c[a+636>>2]=1838;c[a+640>>2]=1416;c[a+644>>2]=194;c[a+648>>2]=396;c[a+652>>2]=2340;c[a+656>>2]=1738;c[a+660>>2]=1078;c[a+664>>2]=674;c[a+668>>2]=1222;c[a+672>>2]=828;c[a+676>>2]=758;c[a+680>>2]=996;c[a+684>>2]=910;c[a+880>>2]=932;c[a+884>>2]=718;c[a+888>>2]=214;c[a+892>>2]=2346;c[a+896>>2]=2124;c[a+900>>2]=1410;c[a+904>>2]=1396;c[a+908>>2]=318;c[a+912>>2]=1812;c[a+916>>2]=144;c[a+920>>2]=1976;c[a+924>>2]=560;c[a+928>>2]=346;c[a+932>>2]=414;c[a+936>>2]=482;c[a+940>>2]=892;c[a+752>>2]=514;c[a+756>>2]=522;c[a+760>>2]=18;c[a+764>>2]=972;c[a+768>>2]=1044;c[a+772>>2]=2312;c[a+776>>2]=928;c[a+780>>2]=1304;c[a+784>>2]=1970;c[a+788>>2]=280;c[a+792>>2]=1824;c[a+796>>2]=1560;c[a+800>>2]=242;c[a+804>>2]=1708;c[a+808>>2]=362;c[a+812>>2]=1892;c[a+688>>2]=1788;c[a+692>>2]=1784;c[a+696>>2]=228;c[a+700>>2]=1890;c[a+704>>2]=1990;c[a+708>>2]=874;c[a+712>>2]=942;c[a+716>>2]=2206;c[a+720>>2]=780;c[a+724>>2]=6;c[a+728>>2]=622;c[a+732>>2]=1302;c[a+736>>2]=1694;c[a+740>>2]=1440;c[a+744>>2]=1544;c[a+748>>2]=1630;c[a+944>>2]=1788;c[a+948>>2]=568;c[a+952>>2]=1400;c[a+956>>2]=1942;c[a+960>>2]=1502;c[a+964>>2]=276;c[a+968>>2]=456;c[a+972>>2]=1586;c[a+976>>2]=1842;c[a+980>>2]=1168;c[a+984>>2]=1670;c[a+988>>2]=1332;c[a+992>>2]=914;c[a+996>>2]=838;c[a+1e3>>2]=1082;c[a+1004>>2]=1004;c[a+816>>2]=1870;c[a+820>>2]=1292;c[a+824>>2]=72;c[a+828>>2]=288;c[a+832>>2]=1102;c[a+836>>2]=2216;c[a+840>>2]=380;c[a+844>>2]=1480;c[a+848>>2]=236;c[a+852>>2]=1908;c[a+856>>2]=654;c[a+860>>2]=2040;c[a+864>>2]=508;c[a+868>>2]=416;c[a+872>>2]=976;c[a+876>>2]=1192;c[a+1008>>2]=1788;c[a+1012>>2]=1946;c[a+1016>>2]=1530;c[a+1020>>2]=900;c[a+1024>>2]=806;c[a+1028>>2]=184;c[a+1032>>2]=2128;c[a+1036>>2]=1872;c[a+100>>2]=174;c[a+104>>2]=38;c[a+116>>2]=54;c[a+120>>2]=142;c[a+124>>2]=146;c[a+128>>2]=60;c[a+340>>2]=186;c[a+344>>2]=12;c[a+52>>2]=100;c[a+56>>2]=164;c[a+76>>2]=98;c[a+80>>2]=96;c[a+84>>2]=88;c[a+148>>2]=114;c[a+152>>2]=8;c[a+196>>2]=104;c[a+200>>2]=90;c[a+172>>2]=166;c[a+176>>2]=32;c[a+220>>2]=26;c[a+236>>2]=134;c[a+240>>2]=108;c[a+244>>2]=82;c[a+260>>2]=188;c[a+264>>2]=80;c[a+268>>2]=102;c[a+272>>2]=4;BYa(a);c[a+532>>2]=182;c[a+1072>>2]=752;c[a+1076>>2]=102;c[a+1084>>2]=148;c[a+1080>>2]=206;c[a+1088>>2]=392;c[a+1092>>2]=538;c[a+1096>>2]=778;c[a+1100>>2]=496;c[a+1196>>2]=288;c[a+1200>>2]=174;c[a+1104>>2]=2;c[a+1224>>2]=74;c[a+1228>>2]=22;c[a+1232>>2]=108;c[a+1208>>2]=72;c[a+1212>>2]=160;c[a+1216>>2]=228;c[a+1220>>2]=210;c[a+20>>2]=1068;c[a+1204>>2]=514;c[a+36>>2]=336;c[a+40>>2]=276;e=c[d>>2]|0;if((e|0)==9|(e|0)==10|(e|0)==12|(e|0)==14){c[a>>2]=1700;i=a+1128|0;j=a+1192|0;k=c[j>>2]|0;y2(i,k);return}do{if((e|0)>=9){if((c[b+8>>2]|0)!=0){break}i=a+1128|0;j=a+1192|0;k=c[j>>2]|0;y2(i,k);return}}while(0);c[a>>2]=884;i=a+1128|0;j=a+1192|0;k=c[j>>2]|0;y2(i,k);return}function _3(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;UJa(e);f=c;c=e;e=0;while(1){g=b[c>>1]|0;if((g&65535)>>>0>255>>>0){h=-(g<<16>>16)>>31&255}else{h=g&255}a[f]=h;g=b[c+2>>1]|0;if((g&65535)>>>0>255>>>0){i=-(g<<16>>16)>>31&255}else{i=g&255}a[f+1|0]=i;g=b[c+4>>1]|0;if((g&65535)>>>0>255>>>0){j=-(g<<16>>16)>>31&255}else{j=g&255}a[f+2|0]=j;g=b[c+6>>1]|0;if((g&65535)>>>0>255>>>0){k=-(g<<16>>16)>>31&255}else{k=g&255}a[f+3|0]=k;g=e+1|0;if((g|0)<4){f=f+d|0;c=c+16|0;e=g}else{break}}return}function $3(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;UJa(f);g=c;c=f;f=0;while(1){h=(b[c>>1]|0)+(d[g]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[g]=i;h=g+1|0;j=(b[c+2>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=g+2|0;j=(b[c+4>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=g+3|0;j=(b[c+6>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=f+1|0;if((h|0)<4){g=g+e|0;c=c+16|0;f=h}else{break}}return}function a4(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;VJa(e);f=b[e>>1]|0;if((f&65535)>>>0>255>>>0){g=-(f<<16>>16)>>31&255}else{g=f&255}a[c]=g;g=b[e+2>>1]|0;if((g&65535)>>>0>255>>>0){h=-(g<<16>>16)>>31&255}else{h=g&255}a[c+1|0]=h;h=b[e+16>>1]|0;if((h&65535)>>>0>255>>>0){i=-(h<<16>>16)>>31&255}else{i=h&255}a[c+d|0]=i;i=b[e+18>>1]|0;if(!((i&65535)>>>0>255>>>0)){j=i&255;k=d+1|0;l=c+k|0;a[l]=j;return}j=-(i<<16>>16)>>31&255;k=d+1|0;l=c+k|0;a[l]=j;return}function b4(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;VJa(f);g=(b[f>>1]|0)+(d[c]|0)|0;if(g>>>0>255>>>0){h=-g>>31&255}else{h=g&255}a[c]=h;h=c+1|0;g=(b[f+2>>1]|0)+(d[h]|0)|0;if(g>>>0>255>>>0){i=-g>>31&255}else{i=g&255}a[h]=i;i=c+e|0;h=(b[f+16>>1]|0)+(d[i]|0)|0;if(h>>>0>255>>>0){j=-h>>31&255}else{j=h&255}a[i]=j;j=c+(e+1)|0;e=(b[f+18>>1]|0)+(d[j]|0)|0;if(!(e>>>0>255>>>0)){k=e&255;a[j]=k;return}k=-e>>31&255;a[j]=k;return}function c4(c,d,e){c=c|0;d=d|0;e=e|0;var f=0;d=(b[e>>1]|0)+4>>3;if(!(d>>>0>255>>>0)){f=d&255;a[c]=f;return}f=-d>>31&255;a[c]=f;return}function d4(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;e=((b[f>>1]|0)+4>>3)+(d[c]|0)|0;if(!(e>>>0>255>>>0)){g=e&255;a[c]=g;return}g=-e>>31&255;a[c]=g;return}function e4(a,b,c){a=a|0;b=b|0;c=c|0;TJa(c);h4(c,a,b);return}function f4(a,b,c){a=a|0;b=b|0;c=c|0;TJa(c);j4(c,a,b);return}function g4(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0;g=c;c=e;e=a;a=0;while(1){b[e>>1]=(d[g]|0)-(d[c]|0);b[e+2>>1]=(d[g+1|0]|0)-(d[c+1|0]|0);b[e+4>>1]=(d[g+2|0]|0)-(d[c+2|0]|0);b[e+6>>1]=(d[g+3|0]|0)-(d[c+3|0]|0);b[e+8>>1]=(d[g+4|0]|0)-(d[c+4|0]|0);b[e+10>>1]=(d[g+5|0]|0)-(d[c+5|0]|0);b[e+12>>1]=(d[g+6|0]|0)-(d[c+6|0]|0);b[e+14>>1]=(d[g+7|0]|0)-(d[c+7|0]|0);h=a+1|0;if((h|0)<8){g=g+f|0;c=c+f|0;e=e+16|0;a=h}else{break}}return}function h4(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=d;d=c;c=0;while(1){g=b[d>>1]|0;if((g&65535)>>>0>255>>>0){h=-(g<<16>>16)>>31&255}else{h=g&255}a[f]=h;g=b[d+2>>1]|0;if((g&65535)>>>0>255>>>0){i=-(g<<16>>16)>>31&255}else{i=g&255}a[f+1|0]=i;g=b[d+4>>1]|0;if((g&65535)>>>0>255>>>0){j=-(g<<16>>16)>>31&255}else{j=g&255}a[f+2|0]=j;g=b[d+6>>1]|0;if((g&65535)>>>0>255>>>0){k=-(g<<16>>16)>>31&255}else{k=g&255}a[f+3|0]=k;g=b[d+8>>1]|0;if((g&65535)>>>0>255>>>0){l=-(g<<16>>16)>>31&255}else{l=g&255}a[f+4|0]=l;g=b[d+10>>1]|0;if((g&65535)>>>0>255>>>0){m=-(g<<16>>16)>>31&255}else{m=g&255}a[f+5|0]=m;g=b[d+12>>1]|0;if((g&65535)>>>0>255>>>0){n=-(g<<16>>16)>>31&255}else{n=g&255}a[f+6|0]=n;g=b[d+14>>1]|0;if((g&65535)>>>0>255>>>0){o=-(g<<16>>16)>>31&255}else{o=g&255}a[f+7|0]=o;g=c+1|0;if((g|0)<8){f=f+e|0;d=d+16|0;c=g}else{break}}return}function i4(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d;d=c;c=0;while(1){g=d+16|0;h=b[d>>1]|0;i=h&255;do{if(h<<16>>16<-128){a[f]=0}else{if(h<<16>>16>127){a[f]=-1;break}else{a[f]=i^-128;break}}}while(0);i=f+1|0;h=b[d+2>>1]|0;j=h&255;do{if(h<<16>>16<-128){a[i]=0}else{if(h<<16>>16>127){a[i]=-1;break}else{a[i]=j^-128;break}}}while(0);j=f+2|0;i=b[d+4>>1]|0;h=i&255;do{if(i<<16>>16<-128){a[j]=0}else{if(i<<16>>16>127){a[j]=-1;break}else{a[j]=h^-128;break}}}while(0);h=f+3|0;j=b[d+6>>1]|0;i=j&255;do{if(j<<16>>16<-128){a[h]=0}else{if(j<<16>>16>127){a[h]=-1;break}else{a[h]=i^-128;break}}}while(0);i=f+4|0;h=b[d+8>>1]|0;j=h&255;do{if(h<<16>>16<-128){a[i]=0}else{if(h<<16>>16>127){a[i]=-1;break}else{a[i]=j^-128;break}}}while(0);j=f+5|0;i=b[d+10>>1]|0;h=i&255;do{if(i<<16>>16<-128){a[j]=0}else{if(i<<16>>16>127){a[j]=-1;break}else{a[j]=h^-128;break}}}while(0);h=f+6|0;j=b[d+12>>1]|0;i=j&255;do{if(j<<16>>16<-128){a[h]=0}else{if(j<<16>>16>127){a[h]=-1;break}else{a[h]=i^-128;break}}}while(0);i=f+7|0;h=b[d+14>>1]|0;j=h&255;do{if(h<<16>>16<-128){a[i]=0}else{if(h<<16>>16>127){a[i]=-1;break}else{a[i]=j^-128;break}}}while(0);j=c+1|0;if((j|0)<8){f=f+e|0;d=g;c=j}else{break}}return}function j4(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=e;e=c;c=0;while(1){h=(b[e>>1]|0)+(d[g]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[g]=i;h=g+1|0;j=(b[e+2>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=g+2|0;j=(b[e+4>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=g+3|0;j=(b[e+6>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=g+4|0;j=(b[e+8>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[h]=n;h=g+5|0;j=(b[e+10>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[h]=o;h=g+6|0;j=(b[e+12>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[h]=p;h=g+7|0;j=(b[e+14>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[h]=q;h=c+1|0;if((h|0)<8){g=g+f|0;e=e+16|0;c=h}else{break}}return}function k4(a){a=a|0;var c=0,d=0,e=0,f=0;c=0;d=0;do{e=b[a+(d<<1)>>1]|0;f=e<<16>>16;c=(e<<16>>16>-1?f:-f|0)+c|0;d=d+1|0;}while((d|0)<64);return c|0}function l4(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=16-g|0;k=16-h|0;l=ba(k,j)|0;m=ba(k,g)|0;k=ba(j,h)|0;j=ba(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;n=e+3|0;o=e+4|0;p=e+5|0;q=e+6|0;r=e+7|0;s=e+8|0;t=c;c=b;b=0;while(1){u=ba(d[t]|0,l)|0;v=t+1|0;w=ba(d[v]|0,m)|0;x=t+e|0;y=ba(d[x]|0,k)|0;z=t+g|0;a[c]=(u+i+w+y+(ba(d[z]|0,j)|0)|0)>>>8;y=ba(d[v]|0,l)|0;v=t+2|0;w=ba(d[v]|0,m)|0;u=ba(d[z]|0,k)|0;z=t+h|0;a[c+1|0]=(y+i+w+u+(ba(d[z]|0,j)|0)|0)>>>8;u=ba(d[v]|0,l)|0;v=t+3|0;w=ba(d[v]|0,m)|0;y=ba(d[z]|0,k)|0;z=t+n|0;a[c+2|0]=(u+i+w+y+(ba(d[z]|0,j)|0)|0)>>>8;y=ba(d[v]|0,l)|0;v=t+4|0;w=ba(d[v]|0,m)|0;u=ba(d[z]|0,k)|0;z=t+o|0;a[c+3|0]=(y+i+w+u+(ba(d[z]|0,j)|0)|0)>>>8;u=ba(d[v]|0,l)|0;v=t+5|0;w=ba(d[v]|0,m)|0;y=ba(d[z]|0,k)|0;z=t+p|0;a[c+4|0]=(u+i+w+y+(ba(d[z]|0,j)|0)|0)>>>8;y=ba(d[v]|0,l)|0;v=t+6|0;w=ba(d[v]|0,m)|0;u=ba(d[z]|0,k)|0;z=t+q|0;a[c+5|0]=(y+i+w+u+(ba(d[z]|0,j)|0)|0)>>>8;u=ba(d[v]|0,l)|0;v=t+7|0;w=ba(d[v]|0,m)|0;y=ba(d[z]|0,k)|0;z=t+r|0;a[c+6|0]=(u+i+w+y+(ba(d[z]|0,j)|0)|0)>>>8;y=ba(d[v]|0,l)|0;v=ba(d[t+8|0]|0,m)|0;w=ba(d[z]|0,k)|0;a[c+7|0]=(y+i+v+w+(ba(d[t+s|0]|0,j)|0)|0)>>>8;w=b+1|0;if((w|0)<(f|0)){t=x;c=c+e|0;b=w}else{break}}return}function m4(a,b){a=a|0;b=b|0;var c=0,e=0,f=0,g=0;c=a;a=0;e=0;while(1){f=(d[c+8|0]|0)+((d[c]|0)+a+(d[c+1|0]|0)+(d[c+2|0]|0)+(d[c+3|0]|0)+(d[c+4|0]|0)+(d[c+5|0]|0)+(d[c+6|0]|0)+(d[c+7|0]|0))+(d[c+9|0]|0)+(d[c+10|0]|0)+(d[c+11|0]|0)+(d[c+12|0]|0)+(d[c+13|0]|0)+(d[c+14|0]|0)+(d[c+15|0]|0)|0;g=e+1|0;if((g|0)<16){c=c+b|0;a=f;e=g}else{break}}return f|0}function n4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=0;e=0;f=a;while(1){a=c[f>>2]|0;g=c[f+4>>2]|0;h=c[f+8>>2]|0;i=c[f+12>>2]|0;j=(c[5398952+((h&255|256)<<2)>>2]|0)+((c[5398952+((a&255|256)<<2)>>2]|0)+e+(c[5398952+((a>>>8&255|256)<<2)>>2]|0)+(c[5398952+((a>>>16&255|256)<<2)>>2]|0)+(c[5398952+((a>>>24|256)<<2)>>2]|0)+(c[5398952+((g&255|256)<<2)>>2]|0)+(c[5398952+((g>>>8&255|256)<<2)>>2]|0)+(c[5398952+((g>>>16&255|256)<<2)>>2]|0)+(c[5398952+((g>>>24|256)<<2)>>2]|0))+(c[5398952+((h>>>8&255|256)<<2)>>2]|0)+(c[5398952+((h>>>16&255|256)<<2)>>2]|0)+(c[5398952+((h>>>24|256)<<2)>>2]|0)+(c[5398952+((i&255|256)<<2)>>2]|0)+(c[5398952+((i>>>8&255|256)<<2)>>2]|0)+(c[5398952+((i>>>16&255|256)<<2)>>2]|0)+(c[5398952+((i>>>24|256)<<2)>>2]|0)|0;i=d+1|0;if((i|0)<16){d=i;e=j;f=f+b|0}else{break}}return j|0}function o4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if((d|0)>0){e=a;f=0}else{return}while(1){TGb(e|0,b|0,16)|0;a=f+1|0;if((a|0)<(d|0)){e=e+c|0;f=a}else{break}}return}function p4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if((d|0)>0){e=a;f=0}else{return}while(1){TGb(e|0,b|0,8)|0;a=f+1|0;if((a|0)<(d|0)){e=e+c|0;f=a}else{break}}return}function q4(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((f|0)>0){g=c;h=b;i=0;j=0}else{k=0;return k|0}while(1){b=(d[h]|0)-(d[g]|0)|0;c=(d[h+1|0]|0)-(d[g+1|0]|0)|0;a=(d[h+2|0]|0)-(d[g+2|0]|0)|0;l=(d[h+3|0]|0)-(d[g+3|0]|0)|0;m=(d[h+4|0]|0)-(d[g+4|0]|0)|0;n=(d[h+5|0]|0)-(d[g+5|0]|0)|0;o=(d[h+6|0]|0)-(d[g+6|0]|0)|0;p=(d[h+7|0]|0)-(d[g+7|0]|0)|0;q=(d[h+8|0]|0)-(d[g+8|0]|0)|0;r=(d[h+9|0]|0)-(d[g+9|0]|0)|0;s=(d[h+10|0]|0)-(d[g+10|0]|0)|0;t=(d[h+11|0]|0)-(d[g+11|0]|0)|0;u=(d[h+12|0]|0)-(d[g+12|0]|0)|0;v=(d[h+13|0]|0)-(d[g+13|0]|0)|0;w=(d[h+14|0]|0)-(d[g+14|0]|0)|0;x=(d[h+15|0]|0)-(d[g+15|0]|0)|0;y=((b|0)>-1?b:-b|0)+i+((c|0)>-1?c:-c|0)+((a|0)>-1?a:-a|0)+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)+((q|0)>-1?q:-q|0)+((r|0)>-1?r:-r|0)+((s|0)>-1?s:-s|0)+((t|0)>-1?t:-t|0)+((u|0)>-1?u:-u|0)+((v|0)>-1?v:-v|0)+((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)|0;x=j+1|0;if((x|0)<(f|0)){g=g+e|0;h=h+e|0;i=y;j=x}else{k=y;break}}return k|0}function r4(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((f|0)>0){g=c;h=b;i=0;j=0}else{k=0;return k|0}while(1){b=d[g+1|0]|0;c=(d[h]|0)-(((d[g]|0)+1+b|0)>>>1)|0;a=d[g+2|0]|0;l=(d[h+1|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+3|0]|0;m=(d[h+2|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+4|0]|0;n=(d[h+3|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+5|0]|0;o=(d[h+4|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+6|0]|0;p=(d[h+5|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+7|0]|0;q=(d[h+6|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+8|0]|0;r=(d[h+7|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+9|0]|0;s=(d[h+8|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+10|0]|0;t=(d[h+9|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+11|0]|0;u=(d[h+10|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+12|0]|0;v=(d[h+11|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+13|0]|0;w=(d[h+12|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+14|0]|0;x=(d[h+13|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+15|0]|0;y=(d[h+14|0]|0)-((a+1+b|0)>>>1)|0;a=(d[h+15|0]|0)-((b+1+(d[g+16|0]|0)|0)>>>1)|0;b=((c|0)>-1?c:-c|0)+i+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)+((q|0)>-1?q:-q|0)+((r|0)>-1?r:-r|0)+((s|0)>-1?s:-s|0)+((t|0)>-1?t:-t|0)+((u|0)>-1?u:-u|0)+((v|0)>-1?v:-v|0)+((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)+((y|0)>-1?y:-y|0)+((a|0)>-1?a:-a|0)|0;a=j+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=b;j=a}else{k=b;break}}return k|0}function s4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;if((g|0)<=0){h=0;return h|0}b=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=f+9|0;q=f+10|0;r=f+11|0;s=f+12|0;t=f+13|0;u=f+14|0;v=f+15|0;w=c;c=0;x=0;y=e;z=a[e]|0;while(1){e=y+f|0;A=a[e]|0;B=(d[w]|0)-(((z&255)+1+(A&255)|0)>>>1)|0;C=(d[w+1|0]|0)-(((d[y+1|0]|0)+1+(d[y+b|0]|0)|0)>>>1)|0;D=(d[w+2|0]|0)-(((d[y+2|0]|0)+1+(d[y+i|0]|0)|0)>>>1)|0;E=(d[w+3|0]|0)-(((d[y+3|0]|0)+1+(d[y+j|0]|0)|0)>>>1)|0;F=(d[w+4|0]|0)-(((d[y+4|0]|0)+1+(d[y+k|0]|0)|0)>>>1)|0;G=(d[w+5|0]|0)-(((d[y+5|0]|0)+1+(d[y+l|0]|0)|0)>>>1)|0;H=(d[w+6|0]|0)-(((d[y+6|0]|0)+1+(d[y+m|0]|0)|0)>>>1)|0;I=(d[w+7|0]|0)-(((d[y+7|0]|0)+1+(d[y+n|0]|0)|0)>>>1)|0;J=(d[w+8|0]|0)-(((d[y+8|0]|0)+1+(d[y+o|0]|0)|0)>>>1)|0;K=(d[w+9|0]|0)-(((d[y+9|0]|0)+1+(d[y+p|0]|0)|0)>>>1)|0;L=(d[w+10|0]|0)-(((d[y+10|0]|0)+1+(d[y+q|0]|0)|0)>>>1)|0;M=(d[w+11|0]|0)-(((d[y+11|0]|0)+1+(d[y+r|0]|0)|0)>>>1)|0;N=(d[w+12|0]|0)-(((d[y+12|0]|0)+1+(d[y+s|0]|0)|0)>>>1)|0;O=(d[w+13|0]|0)-(((d[y+13|0]|0)+1+(d[y+t|0]|0)|0)>>>1)|0;P=(d[w+14|0]|0)-(((d[y+14|0]|0)+1+(d[y+u|0]|0)|0)>>>1)|0;Q=(d[w+15|0]|0)-(((d[y+15|0]|0)+1+(d[y+v|0]|0)|0)>>>1)|0;R=((B|0)>-1?B:-B|0)+c+((C|0)>-1?C:-C|0)+((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)+((F|0)>-1?F:-F|0)+((G|0)>-1?G:-G|0)+((H|0)>-1?H:-H|0)+((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)+((K|0)>-1?K:-K|0)+((L|0)>-1?L:-L|0)+((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)+((O|0)>-1?O:-O|0)+((P|0)>-1?P:-P|0)+((Q|0)>-1?Q:-Q|0)|0;Q=x+1|0;if((Q|0)<(g|0)){w=w+f|0;c=R;x=Q;y=e;z=A}else{h=R;break}}return h|0}function t4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;if((g|0)<=0){h=0;return h|0}b=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=f+9|0;q=f+10|0;r=f+11|0;s=f+12|0;t=f+13|0;u=f+14|0;v=f+15|0;w=f+16|0;x=c;c=0;y=0;z=e;A=a[e]|0;while(1){e=z+f|0;B=d[z+1|0]|0;C=a[e]|0;D=d[z+b|0]|0;E=(d[x]|0)-(((A&255)+2+B+(C&255)+D|0)>>>2)|0;F=d[z+2|0]|0;G=d[z+i|0]|0;H=(d[x+1|0]|0)-((B+2+F+D+G|0)>>>2)|0;D=d[z+3|0]|0;B=d[z+j|0]|0;I=(d[x+2|0]|0)-((F+2+D+G+B|0)>>>2)|0;G=d[z+4|0]|0;F=d[z+k|0]|0;J=(d[x+3|0]|0)-((D+2+G+B+F|0)>>>2)|0;B=d[z+5|0]|0;D=d[z+l|0]|0;K=(d[x+4|0]|0)-((G+2+B+F+D|0)>>>2)|0;F=d[z+6|0]|0;G=d[z+m|0]|0;L=(d[x+5|0]|0)-((B+2+F+D+G|0)>>>2)|0;D=d[z+7|0]|0;B=d[z+n|0]|0;M=(d[x+6|0]|0)-((F+2+D+G+B|0)>>>2)|0;G=d[z+8|0]|0;F=d[z+o|0]|0;N=(d[x+7|0]|0)-((D+2+G+B+F|0)>>>2)|0;B=d[z+9|0]|0;D=d[z+p|0]|0;O=(d[x+8|0]|0)-((G+2+B+F+D|0)>>>2)|0;F=d[z+10|0]|0;G=d[z+q|0]|0;P=(d[x+9|0]|0)-((B+2+F+D+G|0)>>>2)|0;D=d[z+11|0]|0;B=d[z+r|0]|0;Q=(d[x+10|0]|0)-((F+2+D+G+B|0)>>>2)|0;G=d[z+12|0]|0;F=d[z+s|0]|0;R=(d[x+11|0]|0)-((D+2+G+B+F|0)>>>2)|0;B=d[z+13|0]|0;D=d[z+t|0]|0;S=(d[x+12|0]|0)-((G+2+B+F+D|0)>>>2)|0;F=d[z+14|0]|0;G=d[z+u|0]|0;T=(d[x+13|0]|0)-((B+2+F+D+G|0)>>>2)|0;D=d[z+15|0]|0;B=d[z+v|0]|0;U=(d[x+14|0]|0)-((F+2+D+G+B|0)>>>2)|0;G=(d[x+15|0]|0)-((D+2+(d[z+16|0]|0)+B+(d[z+w|0]|0)|0)>>>2)|0;B=((E|0)>-1?E:-E|0)+c+((H|0)>-1?H:-H|0)+((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)+((K|0)>-1?K:-K|0)+((L|0)>-1?L:-L|0)+((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)+((O|0)>-1?O:-O|0)+((P|0)>-1?P:-P|0)+((Q|0)>-1?Q:-Q|0)+((R|0)>-1?R:-R|0)+((S|0)>-1?S:-S|0)+((T|0)>-1?T:-T|0)+((U|0)>-1?U:-U|0)+((G|0)>-1?G:-G|0)|0;G=y+1|0;if((G|0)<(g|0)){x=x+f|0;c=B;y=G;z=e;A=C}else{h=B;break}}return h|0}function u4(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f|0)>0){g=c;h=b;i=0;j=0}else{k=0;return k|0}while(1){b=(d[h]|0)-(d[g]|0)|0;c=(d[h+1|0]|0)-(d[g+1|0]|0)|0;a=(d[h+2|0]|0)-(d[g+2|0]|0)|0;l=(d[h+3|0]|0)-(d[g+3|0]|0)|0;m=(d[h+4|0]|0)-(d[g+4|0]|0)|0;n=(d[h+5|0]|0)-(d[g+5|0]|0)|0;o=(d[h+6|0]|0)-(d[g+6|0]|0)|0;p=(d[h+7|0]|0)-(d[g+7|0]|0)|0;q=((b|0)>-1?b:-b|0)+i+((c|0)>-1?c:-c|0)+((a|0)>-1?a:-a|0)+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)|0;p=j+1|0;if((p|0)<(f|0)){g=g+e|0;h=h+e|0;i=q;j=p}else{k=q;break}}return k|0}function v4(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f|0)>0){g=c;h=b;i=0;j=0}else{k=0;return k|0}while(1){b=d[g+1|0]|0;c=(d[h]|0)-(((d[g]|0)+1+b|0)>>>1)|0;a=d[g+2|0]|0;l=(d[h+1|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+3|0]|0;m=(d[h+2|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+4|0]|0;n=(d[h+3|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+5|0]|0;o=(d[h+4|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+6|0]|0;p=(d[h+5|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+7|0]|0;q=(d[h+6|0]|0)-((a+1+b|0)>>>1)|0;a=(d[h+7|0]|0)-((b+1+(d[g+8|0]|0)|0)>>>1)|0;b=((c|0)>-1?c:-c|0)+i+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)+((q|0)>-1?q:-q|0)+((a|0)>-1?a:-a|0)|0;a=j+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=b;j=a}else{k=b;break}}return k|0}function w4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((g|0)<=0){h=0;return h|0}b=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=c;c=0;p=0;q=e;r=a[e]|0;while(1){e=q+f|0;s=a[e]|0;t=(d[o]|0)-(((r&255)+1+(s&255)|0)>>>1)|0;u=(d[o+1|0]|0)-(((d[q+1|0]|0)+1+(d[q+b|0]|0)|0)>>>1)|0;v=(d[o+2|0]|0)-(((d[q+2|0]|0)+1+(d[q+i|0]|0)|0)>>>1)|0;w=(d[o+3|0]|0)-(((d[q+3|0]|0)+1+(d[q+j|0]|0)|0)>>>1)|0;x=(d[o+4|0]|0)-(((d[q+4|0]|0)+1+(d[q+k|0]|0)|0)>>>1)|0;y=(d[o+5|0]|0)-(((d[q+5|0]|0)+1+(d[q+l|0]|0)|0)>>>1)|0;z=(d[o+6|0]|0)-(((d[q+6|0]|0)+1+(d[q+m|0]|0)|0)>>>1)|0;A=(d[o+7|0]|0)-(((d[q+7|0]|0)+1+(d[q+n|0]|0)|0)>>>1)|0;B=((t|0)>-1?t:-t|0)+c+((u|0)>-1?u:-u|0)+((v|0)>-1?v:-v|0)+((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)+((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)+((A|0)>-1?A:-A|0)|0;A=p+1|0;if((A|0)<(g|0)){o=o+f|0;c=B;p=A;q=e;r=s}else{h=B;break}}return h|0}function x4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((g|0)<=0){h=0;return h|0}b=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=c;c=0;q=0;r=e;s=a[e]|0;while(1){e=r+f|0;t=d[r+1|0]|0;u=a[e]|0;v=d[r+b|0]|0;w=(d[p]|0)-(((s&255)+2+t+(u&255)+v|0)>>>2)|0;x=d[r+2|0]|0;y=d[r+i|0]|0;z=(d[p+1|0]|0)-((t+2+x+v+y|0)>>>2)|0;v=d[r+3|0]|0;t=d[r+j|0]|0;A=(d[p+2|0]|0)-((x+2+v+y+t|0)>>>2)|0;y=d[r+4|0]|0;x=d[r+k|0]|0;B=(d[p+3|0]|0)-((v+2+y+t+x|0)>>>2)|0;t=d[r+5|0]|0;v=d[r+l|0]|0;C=(d[p+4|0]|0)-((y+2+t+x+v|0)>>>2)|0;x=d[r+6|0]|0;y=d[r+m|0]|0;D=(d[p+5|0]|0)-((t+2+x+v+y|0)>>>2)|0;v=d[r+7|0]|0;t=d[r+n|0]|0;E=(d[p+6|0]|0)-((x+2+v+y+t|0)>>>2)|0;y=(d[p+7|0]|0)-((v+2+(d[r+8|0]|0)+t+(d[r+o|0]|0)|0)>>>2)|0;t=((w|0)>-1?w:-w|0)+c+((z|0)>-1?z:-z|0)+((A|0)>-1?A:-A|0)+((B|0)>-1?B:-B|0)+((C|0)>-1?C:-C|0)+((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)+((y|0)>-1?y:-y|0)|0;y=q+1|0;if((y|0)<(g|0)){p=p+f|0;c=t;q=y;r=e;s=u}else{h=t;break}}return h|0}function y4(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((g|0)==4){if((h|0)>0){i=e;j=a;k=0}else{return}while(1){l=i;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=k+1|0;if((l|0)<(h|0)){i=i+f|0;j=j+f|0;k=l}else{break}}return}else if((g|0)==2){if((h|0)>0){m=e;n=a;o=0}else{return}while(1){k=m;b[n>>1]=(d[k]|d[k+1|0]<<8)<<16>>16;k=o+1|0;if((k|0)<(h|0)){m=m+f|0;n=n+f|0;o=k}else{break}}return}else if((g|0)==16){if((h|0)>0){p=e;q=a;r=0}else{return}while(1){o=p;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+4|0;c[q+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=r+1|0;if((o|0)<(h|0)){p=p+f|0;q=q+f|0;r=o}else{break}}r=e+8|0;q=a+8|0;p=0;while(1){o=r;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=r+4|0;c[q+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+1|0;if((o|0)<(h|0)){r=r+f|0;q=q+f|0;p=o}else{break}}return}else if((g|0)==8){if((h|0)>0){s=e;t=a;u=0}else{return}while(1){a=s;c[t>>2]=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24;a=s+4|0;c[t+4>>2]=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24;a=u+1|0;if((a|0)<(h|0)){s=s+f|0;t=t+f|0;u=a}else{break}}return}else{return}}function z4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)>0&(f|0)>0){h=c;i=b;j=0}else{return}while(1){b=0;while(1){c=b+1|0;a[i+b|0]=(((((d[h+b|0]|0)<<1)+(d[h+c|0]|0)|0)*683|0)+683|0)>>>11;if((c|0)<(f|0)){b=c}else{break}}b=j+1|0;if((b|0)<(g|0)){h=h+e|0;i=i+e|0;j=b}else{break}}return}function A4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)>0&(f|0)>0){h=c;i=b;j=0}else{return}while(1){b=0;while(1){c=b+1|0;a[i+b|0]=(((((d[h+c|0]|0)<<1)+(d[h+b|0]|0)|0)*683|0)+683|0)>>>11;if((c|0)<(f|0)){b=c}else{break}}b=j+1|0;if((b|0)<(g|0)){h=h+e|0;i=i+e|0;j=b}else{break}}return}function B4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;do{a[c+j|0]=(((((d[i+j|0]|0)<<1)+(d[i+(j+e)|0]|0)|0)*683|0)+683|0)>>>11;j=j+1|0;}while((j|0)<(f|0))}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function C4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=j+1|0;l=j+e|0;a[c+j|0]=(((((d[i+(l+1)|0]|0)<<1)+((d[i+j|0]|0)<<2)+(((d[i+l|0]|0)+(d[i+k|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15;if((k|0)<(f|0)){j=k}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function D4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=j+1|0;l=j+e|0;a[c+j|0]=(((((d[i+l|0]|0)<<1)+((d[i+k|0]|0)<<2)+(((d[i+(l+1)|0]|0)+(d[i+j|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15;if((k|0)<(f|0)){j=k}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function E4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;do{a[c+j|0]=(((((d[i+(j+e)|0]|0)<<1)+(d[i+j|0]|0)|0)*683|0)+683|0)>>>11;j=j+1|0;}while((j|0)<(f|0))}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function F4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=j+1|0;l=j+e|0;a[c+j|0]=(((((d[i+l|0]|0)<<2)+((d[i+k|0]|0)<<1)+(((d[i+(l+1)|0]|0)+(d[i+j|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15;if((k|0)<(f|0)){j=k}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function G4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=j+1|0;l=j+e|0;a[c+j|0]=(((((d[i+(l+1)|0]|0)<<2)+((d[i+j|0]|0)<<1)+(((d[i+l|0]|0)+(d[i+k|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15;if((k|0)<(f|0)){j=k}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function H4(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((g|0)==16){if((h|0)>0){i=e;j=a;k=0}else{return}while(1){l=j;m=c[l>>2]|0;n=i;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=(o|m)-((o^m)>>>1&2139062143);m=j+4|0;o=c[m>>2]|0;l=i+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[m>>2]=(n|o)-((n^o)>>>1&2139062143);o=k+1|0;if((o|0)<(h|0)){i=i+f|0;j=j+f|0;k=o}else{break}}k=e+8|0;j=a+8|0;i=0;while(1){o=j;n=c[o>>2]|0;m=k;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[o>>2]=(l|n)-((l^n)>>>1&2139062143);n=j+4|0;l=c[n>>2]|0;o=k+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=(m|l)-((m^l)>>>1&2139062143);l=i+1|0;if((l|0)<(h|0)){k=k+f|0;j=j+f|0;i=l}else{break}}return}else if((g|0)==2){if((h|0)>0){p=e;q=a;r=0}else{return}while(1){i=q;j=b[i>>1]|0;k=p;l=(d[k]|d[k+1|0]<<8)<<16>>16;b[i>>1]=(l|j)-(((l^j)&65535)>>>1&32639);j=r+1|0;if((j|0)<(h|0)){p=p+f|0;q=q+f|0;r=j}else{break}}return}else if((g|0)==4){if((h|0)>0){s=e;t=a;u=0}else{return}while(1){r=t;q=c[r>>2]|0;p=s;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[r>>2]=(j|q)-((j^q)>>>1&2139062143);q=u+1|0;if((q|0)<(h|0)){s=s+f|0;t=t+f|0;u=q}else{break}}return}else if((g|0)==8){if((h|0)>0){v=e;w=a;x=0}else{return}while(1){a=w;e=c[a>>2]|0;g=v;u=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[a>>2]=(u|e)-((u^e)>>>1&2139062143);e=w+4|0;u=c[e>>2]|0;a=v+4|0;g=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;c[e>>2]=(g|u)-((g^u)>>>1&2139062143);u=x+1|0;if((u|0)<(h|0)){v=v+f|0;w=w+f|0;x=u}else{break}}return}else{return}}function I4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;a[k]=((d[k]|0)+1+((((((d[i+j|0]|0)<<1)+(d[i+l|0]|0)|0)*683|0)+683|0)>>>11)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function J4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;a[k]=((d[k]|0)+1+((((((d[i+l|0]|0)<<1)+(d[i+j|0]|0)|0)*683|0)+683|0)>>>11)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function K4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;do{k=c+j|0;a[k]=((d[k]|0)+1+((((((d[i+j|0]|0)<<1)+(d[i+(j+e)|0]|0)|0)*683|0)+683|0)>>>11)|0)>>>1;j=j+1|0;}while((j|0)<(f|0))}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function L4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;m=j+e|0;a[k]=((d[k]|0)+1+((((((d[i+(m+1)|0]|0)<<1)+((d[i+j|0]|0)<<2)+(((d[i+m|0]|0)+(d[i+l|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function M4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;m=j+e|0;a[k]=((d[k]|0)+1+((((((d[i+m|0]|0)<<1)+((d[i+l|0]|0)<<2)+(((d[i+(m+1)|0]|0)+(d[i+j|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function N4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;do{k=c+j|0;a[k]=((d[k]|0)+1+((((((d[i+(j+e)|0]|0)<<1)+(d[i+j|0]|0)|0)*683|0)+683|0)>>>11)|0)>>>1;j=j+1|0;}while((j|0)<(f|0))}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function O4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;m=j+e|0;a[k]=((d[k]|0)+1+((((((d[i+m|0]|0)<<2)+((d[i+l|0]|0)<<1)+(((d[i+(m+1)|0]|0)+(d[i+j|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function P4(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;m=j+e|0;a[k]=((d[k]|0)+1+((((((d[i+(m+1)|0]|0)<<2)+((d[i+j|0]|0)<<1)+(((d[i+m|0]|0)+(d[i+l|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function Q4(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;K2(g|0,b,16,e,16);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ba(o,e)|0;n=h+8|0;k=b+n|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=o<<4;j=g+(k|8)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+n>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+12|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(k|12)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+l>>2]=(k|m)-((k^m)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function R4(a,b,c){a=a|0;b=b|0;c=c|0;K2(a,b,c,c,16);return}function S4(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;K2(g|0,b,16,e,16);h=0;while(1){j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ba(o,e)|0;n=b+(h+9)|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o<<4;j=g+(n|8)|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(h+8)>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(n|12)|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+(h+12)>>2]=(n|l)-((n^l)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function T4(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}L2(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(k,f)|0;c[b+o>>2]=(q|l)-((q^l)>>>1&2139062143);l=h+(m|4)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+(e|4)|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(o+4)>>2]=(e|m)-((e^m)>>>1&2139062143);m=k+1|0;if((m|0)<16){k=m}else{r=0;break}}do{k=r*24|0;m=h+(k+8)|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r<<4;o=j+(m|8)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(r,f)|0;c[b+(o+8)>>2]=(l|e)-((l^e)>>>1&2139062143);e=h+(k+12)|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+(m|12)|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+12)>>2]=(m|k)-((m^k)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function U4(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;K2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);L2(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=(p|l)-((p^l)>>>1&2139062143);l=s|4;s=j+l|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=(l|p)-((l^p)>>>1&2139062143);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+p|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(t,f)|0;c[b+(l+8)>>2]=(p|h)-((p^h)>>>1&2139062143);h=n|12;n=j+h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=(h|p)-((h^p)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function V4(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;K2(j,b,16,e,17);L2(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=g+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<16){j=m}else{n=0;break}}do{j=n<<4;m=j|8;l=g+m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(n,e)|0;c[a+(l+8)>>2]=(m|k)-((m^k)>>>1&2139062143);k=j|12;j=g+k|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+k|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(l+12)>>2]=(k|m)-((k^m)>>>1&2139062143);n=n+1|0;}while((n|0)<16);i=f;return}function W4(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;K2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);L2(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=(p|l)-((p^l)>>>1&2139062143);l=s|4;s=j+l|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=(l|p)-((l^p)>>>1&2139062143);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+p|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(t,f)|0;c[b+(l+8)>>2]=(p|h)-((p^h)>>>1&2139062143);h=n|12;n=j+h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=(h|p)-((h^p)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function X4(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+408|0;g=f|0;h=c;c=g;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;a[c+16|0]=a[h+16|0]|0;l=j+1|0;if((l|0)<17){h=h+e|0;c=c+24|0;j=l}else{break}}L2(b,g,e,24);i=f;return}function Y4(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;K2(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+q|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=(n|o)-((n^o)>>>1&2139062143);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|4)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=(q|e)-((q^e)>>>1&2139062143);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+8)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=(l|q)-((l^q)>>>1&2139062143);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+12)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=(o|k)-((o^k)>>>1&2139062143);r=r+1|0;}while((r|0)<17);L2(b,m,f,16);i=g;return}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+272|0;e=d|0;K2(e,b,16,c,17);L2(a,e,c,16);i=d;return}function _4(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;K2(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+(q|1)|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=(n|o)-((n^o)>>>1&2139062143);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|5)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=(q|e)-((q^e)>>>1&2139062143);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+9)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=(l|q)-((l^q)>>>1&2139062143);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+13)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=(o|k)-((o^k)>>>1&2139062143);r=r+1|0;}while((r|0)<17);L2(b,m,f,16);i=g;return}function $4(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}L2(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+(m+24)|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(k,f)|0;c[b+o>>2]=(q|l)-((q^l)>>>1&2139062143);l=h+((m|4)+24)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+(e|4)|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(o+4)>>2]=(e|m)-((e^m)>>>1&2139062143);m=k+1|0;if((m|0)<16){k=m}else{r=0;break}}do{k=r*24|0;m=h+(k+32)|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r<<4;o=j+(m|8)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(r,f)|0;c[b+(o+8)>>2]=(l|e)-((l^e)>>>1&2139062143);e=h+(k+36)|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+(m|12)|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+12)>>2]=(m|k)-((m^k)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function a5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;K2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);L2(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=(p|l)-((p^l)>>>1&2139062143);l=s|4;s=j+(l+16)|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=(l|p)-((l^p)>>>1&2139062143);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+(p+16)|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(t,f)|0;c[b+(l+8)>>2]=(p|h)-((p^h)>>>1&2139062143);h=n|12;n=j+(h+16)|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=(h|p)-((h^p)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function b5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;K2(j,b,16,e,17);L2(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+(b+16)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=g+(l+16)|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<16){j=m}else{n=0;break}}do{j=n<<4;m=j|8;l=g+(m+16)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(n,e)|0;c[a+(l+8)>>2]=(m|k)-((m^k)>>>1&2139062143);k=j|12;j=g+(k+16)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+k|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(l+12)>>2]=(k|m)-((k^m)>>>1&2139062143);n=n+1|0;}while((n|0)<16);i=f;return}function c5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;K2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);L2(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=(p|l)-((p^l)>>>1&2139062143);l=s|4;s=j+(l+16)|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=(l|p)-((l^p)>>>1&2139062143);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+(p+16)|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(t,f)|0;c[b+(l+8)>>2]=(p|h)-((p^h)>>>1&2139062143);h=n|12;n=j+(h+16)|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=(h|p)-((h^p)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function d5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;$2(g|0,b,16,e,16);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=((n^l)>>>1&2139062143)+(n&l);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=((k^n)>>>1&2139062143)+(k&n);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ba(o,e)|0;n=h+8|0;k=b+n|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=o<<4;j=g+(k|8)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+n>>2]=((m^l)>>>1&2139062143)+(m&l);l=h+12|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(k|12)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+l>>2]=((k^m)>>>1&2139062143)+(k&m);o=o+1|0;}while((o|0)<16);i=f;return}function e5(a,b,c){a=a|0;b=b|0;c=c|0;$2(a,b,c,c,16);return}function f5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;$2(g|0,b,16,e,16);h=0;while(1){j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=((n^l)>>>1&2139062143)+(n&l);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=((k^n)>>>1&2139062143)+(k&n);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ba(o,e)|0;n=b+(h+9)|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o<<4;j=g+(n|8)|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(h+8)>>2]=((l^k)>>>1&2139062143)+(l&k);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(n|12)|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+(h+12)>>2]=((n^l)>>>1&2139062143)+(n&l);o=o+1|0;}while((o|0)<16);i=f;return}function g5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}a3(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(k,f)|0;c[b+o>>2]=((q^l)>>>1&2139062143)+(q&l);l=h+(m|4)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+(e|4)|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(o+4)>>2]=((e^m)>>>1&2139062143)+(e&m);m=k+1|0;if((m|0)<16){k=m}else{r=0;break}}do{k=r*24|0;m=h+(k+8)|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r<<4;o=j+(m|8)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(r,f)|0;c[b+(o+8)>>2]=((l^e)>>>1&2139062143)+(l&e);e=h+(k+12)|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+(m|12)|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+12)>>2]=((m^k)>>>1&2139062143)+(m&k);r=r+1|0;}while((r|0)<16);i=g;return}function h5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;$2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=((o^p)>>>1&2139062143)+(o&p);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=((r^e)>>>1&2139062143)+(r&e);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=((m^r)>>>1&2139062143)+(m&r);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=((p^l)>>>1&2139062143)+(p&l);s=s+1|0;}while((s|0)<17);a3(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=((p^l)>>>1&2139062143)+(p&l);l=s|4;s=j+l|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=((l^p)>>>1&2139062143)+(l&p);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+p|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(t,f)|0;c[b+(l+8)>>2]=((p^h)>>>1&2139062143)+(p&h);h=n|12;n=j+h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=((h^p)>>>1&2139062143)+(h&p);t=t+1|0;}while((t|0)<16);i=g;return}function i5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;$2(j,b,16,e,17);a3(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;c[a+k>>2]=((m^l)>>>1&2139062143)+(m&l);l=b|4;b=g+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=((l^m)>>>1&2139062143)+(l&m);m=j+1|0;if((m|0)<16){j=m}else{n=0;break}}do{j=n<<4;m=j|8;l=g+m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(n,e)|0;c[a+(l+8)>>2]=((m^k)>>>1&2139062143)+(m&k);k=j|12;j=g+k|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+k|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(l+12)>>2]=((k^m)>>>1&2139062143)+(k&m);n=n+1|0;}while((n|0)<16);i=f;return}function j5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;$2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=((o^p)>>>1&2139062143)+(o&p);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=((r^e)>>>1&2139062143)+(r&e);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=((m^r)>>>1&2139062143)+(m&r);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=((p^l)>>>1&2139062143)+(p&l);s=s+1|0;}while((s|0)<17);a3(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=((p^l)>>>1&2139062143)+(p&l);l=s|4;s=j+l|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=((l^p)>>>1&2139062143)+(l&p);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+p|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(t,f)|0;c[b+(l+8)>>2]=((p^h)>>>1&2139062143)+(p&h);h=n|12;n=j+h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=((h^p)>>>1&2139062143)+(h&p);t=t+1|0;}while((t|0)<16);i=g;return}function k5(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+408|0;g=f|0;h=c;c=g;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;a[c+16|0]=a[h+16|0]|0;l=j+1|0;if((l|0)<17){h=h+e|0;c=c+24|0;j=l}else{break}}a3(b,g,e,24);i=f;return}function l5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;$2(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+q|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=((n^o)>>>1&2139062143)+(n&o);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|4)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=((q^e)>>>1&2139062143)+(q&e);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+8)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=((l^q)>>>1&2139062143)+(l&q);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+12)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=((o^k)>>>1&2139062143)+(o&k);r=r+1|0;}while((r|0)<17);a3(b,m,f,16);i=g;return}function m5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+272|0;e=d|0;$2(e,b,16,c,17);a3(a,e,c,16);i=d;return}function n5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;$2(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+(q|1)|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=((n^o)>>>1&2139062143)+(n&o);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|5)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=((q^e)>>>1&2139062143)+(q&e);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+9)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=((l^q)>>>1&2139062143)+(l&q);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+13)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=((o^k)>>>1&2139062143)+(o&k);r=r+1|0;}while((r|0)<17);a3(b,m,f,16);i=g;return}function o5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}a3(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+(m+24)|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(k,f)|0;c[b+o>>2]=((q^l)>>>1&2139062143)+(q&l);l=h+((m|4)+24)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+(e|4)|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(o+4)>>2]=((e^m)>>>1&2139062143)+(e&m);m=k+1|0;if((m|0)<16){k=m}else{r=0;break}}do{k=r*24|0;m=h+(k+32)|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r<<4;o=j+(m|8)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(r,f)|0;c[b+(o+8)>>2]=((l^e)>>>1&2139062143)+(l&e);e=h+(k+36)|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+(m|12)|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+12)>>2]=((m^k)>>>1&2139062143)+(m&k);r=r+1|0;}while((r|0)<16);i=g;return}function p5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;$2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=((o^p)>>>1&2139062143)+(o&p);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=((r^e)>>>1&2139062143)+(r&e);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=((m^r)>>>1&2139062143)+(m&r);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=((p^l)>>>1&2139062143)+(p&l);s=s+1|0;}while((s|0)<17);a3(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=((p^l)>>>1&2139062143)+(p&l);l=s|4;s=j+(l+16)|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=((l^p)>>>1&2139062143)+(l&p);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+(p+16)|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(t,f)|0;c[b+(l+8)>>2]=((p^h)>>>1&2139062143)+(p&h);h=n|12;n=j+(h+16)|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=((h^p)>>>1&2139062143)+(h&p);t=t+1|0;}while((t|0)<16);i=g;return}function q5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;$2(j,b,16,e,17);a3(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+(b+16)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;c[a+k>>2]=((m^l)>>>1&2139062143)+(m&l);l=b|4;b=g+(l+16)|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=((l^m)>>>1&2139062143)+(l&m);m=j+1|0;if((m|0)<16){j=m}else{n=0;break}}do{j=n<<4;m=j|8;l=g+(m+16)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(n,e)|0;c[a+(l+8)>>2]=((m^k)>>>1&2139062143)+(m&k);k=j|12;j=g+(k+16)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+k|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(l+12)>>2]=((k^m)>>>1&2139062143)+(k&m);n=n+1|0;}while((n|0)<16);i=f;return}function r5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;$2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=((o^p)>>>1&2139062143)+(o&p);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=((r^e)>>>1&2139062143)+(r&e);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=((m^r)>>>1&2139062143)+(m&r);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=((p^l)>>>1&2139062143)+(p&l);s=s+1|0;}while((s|0)<17);a3(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;c[b+h>>2]=((p^l)>>>1&2139062143)+(p&l);l=s|4;s=j+(l+16)|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=((l^p)>>>1&2139062143)+(l&p);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+(p+16)|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(t,f)|0;c[b+(l+8)>>2]=((p^h)>>>1&2139062143)+(p&h);h=n|12;n=j+(h+16)|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=((h^p)>>>1&2139062143)+(h&p);t=t+1|0;}while((t|0)<16);i=g;return}function s5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f|0;K2(g|0,b,16,e,16);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=j+4|0;j=b+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+o|0;o=c[j>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[j>>2]=(m|o)-((m^o)>>>1&2139062143);o=h+1|0;if((o|0)<16){h=o}else{q=0;break}}do{h=ba(q,e)|0;o=h+8|0;m=b+o|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q<<4;p=g+(m|8)|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+o|0;o=c[p>>2]|0;l=(k|j)-((k^j)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=h+12|0;h=b+o|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(m|12)|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+o|0;o=c[h>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[h>>2]=(p|o)-((p^o)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function t5(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c;c=b;b=0;while(1){g=d[f]|0;h=f+1|0;i=d[h]|0;j=f+2|0;k=d[j]|0;l=f+3|0;m=f+4|0;a[c]=((d[c]|0)+1+(d[(16-k+((i+g|0)*20|0)+((k+g|0)*-6|0)-(d[m]|0)+(((d[l]|0)+i|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;i=c+1|0;g=d[h]|0;k=d[f]|0;n=f+5|0;a[i]=((d[i]|0)+1+(d[(16-g+(((d[j]|0)+g|0)*20|0)+(((d[l]|0)+k|0)*-6|0)-(d[n]|0)+(((d[m]|0)+k|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;k=c+2|0;g=d[f]|0;i=f+6|0;a[k]=((d[k]|0)+1+(d[((((d[l]|0)+(d[j]|0)|0)*20|0)+16-g+(((d[m]|0)+(d[h]|0)|0)*-6|0)-(d[i]|0)+(((d[n]|0)+g|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;g=c+3|0;k=f+7|0;a[g]=((d[g]|0)+1+(d[((((d[m]|0)+(d[l]|0)|0)*20|0)+16+(((d[n]|0)+(d[j]|0)|0)*-6|0)-(d[f]|0)+(((d[i]|0)+(d[h]|0)|0)*3|0)-(d[k]|0)>>5)+1236056|0]|0)|0)>>>1;g=c+4|0;o=f+8|0;a[g]=((d[g]|0)+1+(d[((((d[n]|0)+(d[m]|0)|0)*20|0)+16+(((d[i]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[j]|0)|0)*3|0)-(d[o]|0)>>5)+1236056|0]|0)|0)>>>1;h=c+5|0;g=f+9|0;a[h]=((d[h]|0)+1+(d[((((d[i]|0)+(d[n]|0)|0)*20|0)+16+(((d[k]|0)+(d[m]|0)|0)*-6|0)-(d[j]|0)+(((d[o]|0)+(d[l]|0)|0)*3|0)-(d[g]|0)>>5)+1236056|0]|0)|0)>>>1;j=c+6|0;h=f+10|0;a[j]=((d[j]|0)+1+(d[((((d[k]|0)+(d[i]|0)|0)*20|0)+16+(((d[o]|0)+(d[n]|0)|0)*-6|0)-(d[l]|0)+(((d[g]|0)+(d[m]|0)|0)*3|0)-(d[h]|0)>>5)+1236056|0]|0)|0)>>>1;l=c+7|0;j=f+11|0;a[l]=((d[l]|0)+1+(d[((((d[o]|0)+(d[k]|0)|0)*20|0)+16+(((d[g]|0)+(d[i]|0)|0)*-6|0)-(d[m]|0)+(((d[h]|0)+(d[n]|0)|0)*3|0)-(d[j]|0)>>5)+1236056|0]|0)|0)>>>1;m=c+8|0;l=f+12|0;a[m]=((d[m]|0)+1+(d[((((d[g]|0)+(d[o]|0)|0)*20|0)+16+(((d[h]|0)+(d[k]|0)|0)*-6|0)-(d[n]|0)+(((d[j]|0)+(d[i]|0)|0)*3|0)-(d[l]|0)>>5)+1236056|0]|0)|0)>>>1;n=c+9|0;m=f+13|0;a[n]=((d[n]|0)+1+(d[((((d[h]|0)+(d[g]|0)|0)*20|0)+16+(((d[j]|0)+(d[o]|0)|0)*-6|0)-(d[i]|0)+(((d[l]|0)+(d[k]|0)|0)*3|0)-(d[m]|0)>>5)+1236056|0]|0)|0)>>>1;i=c+10|0;n=f+14|0;a[i]=((d[i]|0)+1+(d[((((d[j]|0)+(d[h]|0)|0)*20|0)+16+(((d[l]|0)+(d[g]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+(d[o]|0)|0)*3|0)-(d[n]|0)>>5)+1236056|0]|0)|0)>>>1;k=c+11|0;i=f+15|0;a[k]=((d[k]|0)+1+(d[((((d[l]|0)+(d[j]|0)|0)*20|0)+16+(((d[m]|0)+(d[h]|0)|0)*-6|0)-(d[o]|0)+(((d[n]|0)+(d[g]|0)|0)*3|0)-(d[i]|0)>>5)+1236056|0]|0)|0)>>>1;o=c+12|0;k=f+16|0;a[o]=((d[o]|0)+1+(d[((((d[m]|0)+(d[l]|0)|0)*20|0)+16+(((d[n]|0)+(d[j]|0)|0)*-6|0)-(d[g]|0)+(((d[i]|0)+(d[h]|0)|0)*3|0)-(d[k]|0)>>5)+1236056|0]|0)|0)>>>1;g=c+13|0;o=d[k]|0;a[g]=((d[g]|0)+1+(d[((((d[n]|0)+(d[m]|0)|0)*20|0)+16+(((d[i]|0)+(d[l]|0)|0)*-6|0)-o-(d[h]|0)+((o+(d[j]|0)|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;o=c+14|0;h=d[i]|0;g=d[k]|0;a[o]=((d[o]|0)+1+(d[(16-h+((h+(d[n]|0)|0)*20|0)+((g+(d[m]|0)|0)*-6|0)-(d[j]|0)+(((d[l]|0)+g|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;g=c+15|0;j=d[i]|0;i=d[k]|0;k=d[n]|0;a[g]=((d[g]|0)+1+(d[(16-k+((i+j|0)*20|0)+((k+i|0)*-6|0)-(d[l]|0)+(((d[m]|0)+j|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;j=b+1|0;if((j|0)<16){f=f+e|0;c=c+e|0;b=j}else{break}}return}function u5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f|0;K2(g|0,b,16,e,16);h=0;while(1){j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=b+(j+5)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+(k|4)|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(j+4)|0;j=c[o>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[o>>2]=(m|j)-((m^j)>>>1&2139062143);j=h+1|0;if((j|0)<16){h=j}else{q=0;break}}do{h=ba(q,e)|0;j=b+(h+9)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=q<<4;o=g+(j|8)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(h+8)|0;k=c[o>>2]|0;l=(p|m)-((p^m)>>>1&2139062143)|0;c[o>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(j|12)|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+(h+12)|0;h=c[k>>2]|0;o=(j|l)-((j^l)>>>1&2139062143)|0;c[k>>2]=(o|h)-((o^h)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function v5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}L2(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(k,f)|0;p=b+o|0;n=c[p>>2]|0;r=(q|l)-((q^l)>>>1&2139062143)|0;c[p>>2]=(r|n)-((r^n)>>>1&2139062143);n=h+(m|4)|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+(e|4)|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(o+4)|0;o=c[n>>2]|0;r=(e|m)-((e^m)>>>1&2139062143)|0;c[n>>2]=(r|o)-((r^o)>>>1&2139062143);o=k+1|0;if((o|0)<16){k=o}else{s=0;break}}do{k=s*24|0;o=h+(k+8)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=s<<4;n=j+(o|8)|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(s,f)|0;e=b+(n+8)|0;p=c[e>>2]|0;l=(m|r)-((m^r)>>>1&2139062143)|0;c[e>>2]=(l|p)-((l^p)>>>1&2139062143);p=h+((k|4)+8)|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+(o|12)|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(n+12)|0;n=c[p>>2]|0;l=(o|k)-((o^k)>>>1&2139062143)|0;c[p>>2]=(l|n)-((l^n)>>>1&2139062143);s=s+1|0;}while((s|0)<16);i=g;return}function w5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;K2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);L2(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;r=b+h|0;m=c[r>>2]|0;e=(p|l)-((p^l)>>>1&2139062143)|0;c[r>>2]=(e|m)-((e^m)>>>1&2139062143);m=s|4;s=j+m|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+m|0;m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=b+(h+4)|0;h=c[s>>2]|0;r=(m|e)-((m^e)>>>1&2139062143)|0;c[s>>2]=(r|h)-((r^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{t=0;break}}do{n=t<<4;h=n|8;r=j+h|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=k+h|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ba(t,f)|0;e=b+(r+8)|0;m=c[e>>2]|0;l=(h|s)-((h^s)>>>1&2139062143)|0;c[e>>2]=(l|m)-((l^m)>>>1&2139062143);m=n|12;n=j+m|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+m|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(r+12)|0;r=c[n>>2]|0;e=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(e|r)-((e^r)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function x5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;K2(j,b,16,e,17);L2(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=g+o|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(k+4)|0;k=c[b>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(n|k)-((n^k)>>>1&2139062143);k=j+1|0;if((k|0)<16){j=k}else{q=0;break}}do{j=q<<4;k=j|8;n=g+k|0;b=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+k|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(q,e)|0;p=a+(n+8)|0;o=c[p>>2]|0;l=(k|b)-((k^b)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=j|12;j=g+o|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+(n+12)|0;n=c[j>>2]|0;p=(o|l)-((o^l)>>>1&2139062143)|0;c[j>>2]=(p|n)-((p^n)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function y5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;K2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);L2(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;r=b+h|0;m=c[r>>2]|0;e=(p|l)-((p^l)>>>1&2139062143)|0;c[r>>2]=(e|m)-((e^m)>>>1&2139062143);m=s|4;s=j+m|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+m|0;m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=b+(h+4)|0;h=c[s>>2]|0;r=(m|e)-((m^e)>>>1&2139062143)|0;c[s>>2]=(r|h)-((r^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{t=0;break}}do{n=t<<4;h=n|8;r=j+h|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=k+h|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ba(t,f)|0;e=b+(r+8)|0;m=c[e>>2]|0;l=(h|s)-((h^s)>>>1&2139062143)|0;c[e>>2]=(l|m)-((l^m)>>>1&2139062143);m=n|12;n=j+m|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+m|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(r+12)|0;r=c[n>>2]|0;e=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(e|r)-((e^r)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function z5(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+408|0;g=f|0;h=c;c=g;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;a[c+16|0]=a[h+16|0]|0;l=j+1|0;if((l|0)<17){h=h+e|0;c=c+24|0;j=l}else{break}}B7(b,g,e,24);i=f;return}function A5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;K2(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+q|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=(n|o)-((n^o)>>>1&2139062143);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|4)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=(q|e)-((q^e)>>>1&2139062143);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+8)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=(l|q)-((l^q)>>>1&2139062143);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+12)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=(o|k)-((o^k)>>>1&2139062143);r=r+1|0;}while((r|0)<17);B7(b,m,f,16);i=g;return}function B5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+272|0;e=d|0;K2(e,b,16,c,17);B7(a,e,c,16);i=d;return}function C5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;K2(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+(q|1)|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=(n|o)-((n^o)>>>1&2139062143);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|5)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=(q|e)-((q^e)>>>1&2139062143);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+9)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=(l|q)-((l^q)>>>1&2139062143);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+13)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=(o|k)-((o^k)>>>1&2139062143);r=r+1|0;}while((r|0)<17);B7(b,m,f,16);i=g;return}function D5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}L2(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+(m+24)|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(k,f)|0;p=b+o|0;n=c[p>>2]|0;r=(q|l)-((q^l)>>>1&2139062143)|0;c[p>>2]=(r|n)-((r^n)>>>1&2139062143);n=h+((m|4)+24)|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+(e|4)|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(o+4)|0;o=c[n>>2]|0;r=(e|m)-((e^m)>>>1&2139062143)|0;c[n>>2]=(r|o)-((r^o)>>>1&2139062143);o=k+1|0;if((o|0)<16){k=o}else{s=0;break}}do{k=s*24|0;o=h+(k+32)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=s<<4;n=j+(o|8)|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(s,f)|0;e=b+(n+8)|0;p=c[e>>2]|0;l=(m|r)-((m^r)>>>1&2139062143)|0;c[e>>2]=(l|p)-((l^p)>>>1&2139062143);p=h+((k|4)+32)|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+(o|12)|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(n+12)|0;n=c[p>>2]|0;l=(o|k)-((o^k)>>>1&2139062143)|0;c[p>>2]=(l|n)-((l^n)>>>1&2139062143);s=s+1|0;}while((s|0)<16);i=g;return}function E5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;K2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);L2(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;r=b+h|0;m=c[r>>2]|0;e=(p|l)-((p^l)>>>1&2139062143)|0;c[r>>2]=(e|m)-((e^m)>>>1&2139062143);m=s|4;s=j+(m+16)|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+m|0;m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=b+(h+4)|0;h=c[s>>2]|0;r=(m|e)-((m^e)>>>1&2139062143)|0;c[s>>2]=(r|h)-((r^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{t=0;break}}do{n=t<<4;h=j+(n+24)|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+(n|8)|0;s=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(t,f)|0;e=b+(h+8)|0;m=c[e>>2]|0;l=(s|r)-((s^r)>>>1&2139062143)|0;c[e>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+((n|4)+24)|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+(n|12)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+12)|0;h=c[m>>2]|0;e=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(e|h)-((e^h)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function F5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;K2(j,b,16,e,17);L2(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+(b+16)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=g+(o+16)|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(k+4)|0;k=c[b>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(n|k)-((n^k)>>>1&2139062143);k=j+1|0;if((k|0)<16){j=k}else{q=0;break}}do{j=q<<4;k=g+(j+24)|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+(j|8)|0;b=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(q,e)|0;p=a+(k+8)|0;o=c[p>>2]|0;l=(b|n)-((b^n)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=g+((j|4)+24)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+(j|12)|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(k+12)|0;k=c[o>>2]|0;p=(j|l)-((j^l)>>>1&2139062143)|0;c[o>>2]=(p|k)-((p^k)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function G5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=o;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=q+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;K2(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);L2(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(n,f)|0;r=b+h|0;m=c[r>>2]|0;e=(p|l)-((p^l)>>>1&2139062143)|0;c[r>>2]=(e|m)-((e^m)>>>1&2139062143);m=s|4;s=j+(m+16)|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+m|0;m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=b+(h+4)|0;h=c[s>>2]|0;r=(m|e)-((m^e)>>>1&2139062143)|0;c[s>>2]=(r|h)-((r^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{t=0;break}}do{n=t<<4;h=j+(n+24)|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+(n|8)|0;s=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(t,f)|0;e=b+(h+8)|0;m=c[e>>2]|0;l=(s|r)-((s^r)>>>1&2139062143)|0;c[e>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+((n|4)+24)|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+(n|12)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+12)|0;h=c[m>>2]|0;e=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(e|h)-((e^h)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function H5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;B2(g|0,b,8,e,8);h=0;do{j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function I5(a,b,c){a=a|0;b=b|0;c=c|0;B2(a,b,c,c,8);return}function J5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;B2(g|0,b,8,e,8);h=0;do{j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function K5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;C2(k|0,l,8,16);m=0;do{e=m<<4;h=c[l+e>>2]|0;n=m<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ba(m,f)|0;c[b+j>>2]=(o|h)-((o^h)>>>1&2139062143);h=c[l+(e|4)>>2]|0;e=k+(n|4)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(j+4)>>2]=(n|h)-((n^h)>>>1&2139062143);m=m+1|0;}while((m|0)<8);i=g;return}function L5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;B2(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=(q|j)-((q^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=(q|h)-((q^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);C2(l|0,n,8,8);n=0;do{e=n<<3;m=k+e|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(n,f)|0;c[b+m>>2]=(q|h)-((q^h)>>>1&2139062143);h=e|4;e=k+h|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(m+4)>>2]=(h|q)-((h^q)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function M5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;B2(j,b,8,e,9);C2(h|0,j,8,8);j=0;do{b=j<<3;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=g+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function N5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;B2(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=(r|j)-((r^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=(p|e)-((p^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);C2(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(n,f)|0;c[b+k>>2]=(p|e)-((p^e)>>>1&2139062143);e=h|4;h=l+e|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=(e|p)-((e^p)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function O5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+144|0;h=g|0;j=h|0;k=e;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=k;a[h+8|0]=a[e+8|0]|0;k=h+16|0;j=e+f|0;l=j|0;m=j+4|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[k>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[k+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;k=f<<1;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+40|0]=a[e+(k+8)|0]|0;l=h+48|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+56|0]=a[e+(j+8)|0]|0;k=h+64|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+72|0]=a[e+(l+8)|0]|0;j=h+80|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+88|0]=a[e+(k+8)|0]|0;l=h+96|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+104|0]=a[e+(j+8)|0]|0;k=h+112|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+120|0]=a[e+(l+8)|0]|0;j=h+128|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+136|0]=a[e+(k+8)|0]|0;C2(b,h,f,16);i=g;return}function P5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=k|0;B2(m,l,8,16,9);e=0;do{h=e<<3;n=k+h|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=e<<4;p=c[l+o>>2]|0;c[n>>2]=(p|j)-((p^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;p=c[l+(o|4)>>2]|0;c[j>>2]=(p|h)-((p^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);C2(b,m,f,8);i=g;return}function Q5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+72|0;e=d|0;B2(e,b,8,c,9);C2(a,e,c,8);i=d;return}function R5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=l|0;B2(m,h,8,16,9);h=0;do{e=h<<3;n=l+e|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=h<<4;p=k+(o|1)|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=(q|j)-((q^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=k+(o|5)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=(o|e)-((o^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);C2(b,m,f,8);i=g;return}function S5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=e;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+8|0]=a[e+8|0]|0;l=h+16|0;j=e+f|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;C2(k|0,h,8,16);h=l;l=0;do{m=l<<4;e=c[h+m>>2]|0;n=l<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ba(l,f)|0;c[b+j>>2]=(o|e)-((o^e)>>>1&2139062143);e=c[h+(m|4)>>2]|0;m=k+(n|4)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[b+(j+4)>>2]=(n|e)-((n^e)>>>1&2139062143);l=l+1|0;}while((l|0)<8);i=g;return}function T5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;B2(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=(q|j)-((q^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=(q|h)-((q^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);C2(l|0,n,8,8);n=0;do{e=n<<3;m=k+(e+8)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(n,f)|0;c[b+m>>2]=(q|h)-((q^h)>>>1&2139062143);h=e|4;e=k+(h+8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(m+4)>>2]=(h|q)-((h^q)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function U5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;B2(j,b,8,e,9);C2(h|0,j,8,8);j=0;do{b=j<<3;k=g+(b+8)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=g+(l+8)|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function V5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;B2(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=(r|j)-((r^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=(p|e)-((p^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);C2(m|0,n,8,8);n=0;do{h=n<<3;k=l+(h+8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(n,f)|0;c[b+k>>2]=(p|e)-((p^e)>>>1&2139062143);e=h|4;h=l+(e+8)|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=(e|p)-((e^p)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function W5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;S2(g|0,b,8,e,8);h=0;do{j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=((n^l)>>>1&2139062143)+(n&l);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=((k^n)>>>1&2139062143)+(k&n);h=h+1|0;}while((h|0)<8);i=f;return}function X5(a,b,c){a=a|0;b=b|0;c=c|0;S2(a,b,c,c,8);return}function Y5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;S2(g|0,b,8,e,8);h=0;do{j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=((n^l)>>>1&2139062143)+(n&l);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=((k^n)>>>1&2139062143)+(k&n);h=h+1|0;}while((h|0)<8);i=f;return}function Z5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;T2(k|0,l,8,16);m=0;do{e=m<<4;h=c[l+e>>2]|0;n=m<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ba(m,f)|0;c[b+j>>2]=((o^h)>>>1&2139062143)+(o&h);h=c[l+(e|4)>>2]|0;e=k+(n|4)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(j+4)>>2]=((n^h)>>>1&2139062143)+(n&h);m=m+1|0;}while((m|0)<8);i=g;return}function _5(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;S2(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=((q^j)>>>1&2139062143)+(q&j);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=((q^h)>>>1&2139062143)+(q&h);e=e+1|0;}while((e|0)<9);T2(l|0,n,8,8);n=0;do{e=n<<3;m=k+e|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(n,f)|0;c[b+m>>2]=((q^h)>>>1&2139062143)+(q&h);h=e|4;e=k+h|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(m+4)>>2]=((h^q)>>>1&2139062143)+(h&q);n=n+1|0;}while((n|0)<8);i=g;return}function $5(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;S2(j,b,8,e,9);T2(h|0,j,8,8);j=0;do{b=j<<3;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;c[a+k>>2]=((m^l)>>>1&2139062143)+(m&l);l=b|4;b=g+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=((l^m)>>>1&2139062143)+(l&m);j=j+1|0;}while((j|0)<8);i=f;return}function a6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;S2(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=((r^j)>>>1&2139062143)+(r&j);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=((p^e)>>>1&2139062143)+(p&e);h=h+1|0;}while((h|0)<9);T2(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(n,f)|0;c[b+k>>2]=((p^e)>>>1&2139062143)+(p&e);e=h|4;h=l+e|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=((e^p)>>>1&2139062143)+(e&p);n=n+1|0;}while((n|0)<8);i=g;return}function b6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+144|0;h=g|0;j=h|0;k=e;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=k;a[h+8|0]=a[e+8|0]|0;k=h+16|0;j=e+f|0;l=j|0;m=j+4|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[k>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[k+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;k=f<<1;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+40|0]=a[e+(k+8)|0]|0;l=h+48|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+56|0]=a[e+(j+8)|0]|0;k=h+64|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+72|0]=a[e+(l+8)|0]|0;j=h+80|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+88|0]=a[e+(k+8)|0]|0;l=h+96|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+104|0]=a[e+(j+8)|0]|0;k=h+112|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+120|0]=a[e+(l+8)|0]|0;j=h+128|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+136|0]=a[e+(k+8)|0]|0;T2(b,h,f,16);i=g;return}function c6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=k|0;S2(m,l,8,16,9);e=0;do{h=e<<3;n=k+h|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=e<<4;p=c[l+o>>2]|0;c[n>>2]=((p^j)>>>1&2139062143)+(p&j);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;p=c[l+(o|4)>>2]|0;c[j>>2]=((p^h)>>>1&2139062143)+(p&h);e=e+1|0;}while((e|0)<9);T2(b,m,f,8);i=g;return}function d6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+72|0;e=d|0;S2(e,b,8,c,9);T2(a,e,c,8);i=d;return}function e6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=l|0;S2(m,h,8,16,9);h=0;do{e=h<<3;n=l+e|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=h<<4;p=k+(o|1)|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=((q^j)>>>1&2139062143)+(q&j);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=k+(o|5)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=((o^e)>>>1&2139062143)+(o&e);h=h+1|0;}while((h|0)<9);T2(b,m,f,8);i=g;return}function f6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=e;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+8|0]=a[e+8|0]|0;l=h+16|0;j=e+f|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;T2(k|0,h,8,16);h=l;l=0;do{m=l<<4;e=c[h+m>>2]|0;n=l<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ba(l,f)|0;c[b+j>>2]=((o^e)>>>1&2139062143)+(o&e);e=c[h+(m|4)>>2]|0;m=k+(n|4)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[b+(j+4)>>2]=((n^e)>>>1&2139062143)+(n&e);l=l+1|0;}while((l|0)<8);i=g;return}function g6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;S2(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=((q^j)>>>1&2139062143)+(q&j);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=((q^h)>>>1&2139062143)+(q&h);e=e+1|0;}while((e|0)<9);T2(l|0,n,8,8);n=0;do{e=n<<3;m=k+(e+8)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(n,f)|0;c[b+m>>2]=((q^h)>>>1&2139062143)+(q&h);h=e|4;e=k+(h+8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(m+4)>>2]=((h^q)>>>1&2139062143)+(h&q);n=n+1|0;}while((n|0)<8);i=g;return}function h6(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;S2(j,b,8,e,9);T2(h|0,j,8,8);j=0;do{b=j<<3;k=g+(b+8)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;c[a+k>>2]=((m^l)>>>1&2139062143)+(m&l);l=b|4;b=g+(l+8)|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=((l^m)>>>1&2139062143)+(l&m);j=j+1|0;}while((j|0)<8);i=f;return}function i6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;S2(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=((r^j)>>>1&2139062143)+(r&j);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=((p^e)>>>1&2139062143)+(p&e);h=h+1|0;}while((h|0)<9);T2(m|0,n,8,8);n=0;do{h=n<<3;k=l+(h+8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(n,f)|0;c[b+k>>2]=((p^e)>>>1&2139062143)+(p&e);e=h|4;h=l+(e+8)|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=((e^p)>>>1&2139062143)+(e&p);n=n+1|0;}while((n|0)<8);i=g;return}function j6(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;B2(g|0,b,8,e,8);h=0;do{j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=j+4|0;j=b+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+o|0;o=c[j>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[j>>2]=(m|o)-((m^o)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function k6(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c;c=b;b=0;while(1){g=d[f]|0;h=f+1|0;i=d[h]|0;j=f+2|0;k=d[j]|0;l=f+3|0;m=f+4|0;a[c]=((d[c]|0)+1+(d[(16-k+((i+g|0)*20|0)+((k+g|0)*-6|0)-(d[m]|0)+(((d[l]|0)+i|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;i=c+1|0;g=d[h]|0;k=d[f]|0;n=f+5|0;a[i]=((d[i]|0)+1+(d[(16-g+(((d[j]|0)+g|0)*20|0)+(((d[l]|0)+k|0)*-6|0)-(d[n]|0)+(((d[m]|0)+k|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;k=c+2|0;g=d[f]|0;i=f+6|0;a[k]=((d[k]|0)+1+(d[((((d[l]|0)+(d[j]|0)|0)*20|0)+16-g+(((d[m]|0)+(d[h]|0)|0)*-6|0)-(d[i]|0)+(((d[n]|0)+g|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;g=c+3|0;k=f+7|0;a[g]=((d[g]|0)+1+(d[((((d[m]|0)+(d[l]|0)|0)*20|0)+16+(((d[n]|0)+(d[j]|0)|0)*-6|0)-(d[f]|0)+(((d[i]|0)+(d[h]|0)|0)*3|0)-(d[k]|0)>>5)+1236056|0]|0)|0)>>>1;g=c+4|0;o=f+8|0;a[g]=((d[g]|0)+1+(d[((((d[n]|0)+(d[m]|0)|0)*20|0)+16+(((d[i]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[j]|0)|0)*3|0)-(d[o]|0)>>5)+1236056|0]|0)|0)>>>1;h=c+5|0;g=d[o]|0;a[h]=((d[h]|0)+1+(d[((((d[i]|0)+(d[n]|0)|0)*20|0)+16+(((d[k]|0)+(d[m]|0)|0)*-6|0)-g-(d[j]|0)+((g+(d[l]|0)|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;g=c+6|0;j=d[k]|0;h=d[o]|0;a[g]=((d[g]|0)+1+(d[(16-j+((j+(d[i]|0)|0)*20|0)+((h+(d[n]|0)|0)*-6|0)-(d[l]|0)+(((d[m]|0)+h|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;h=c+7|0;l=d[k]|0;k=d[o]|0;o=d[i]|0;a[h]=((d[h]|0)+1+(d[(16-o+((k+l|0)*20|0)+((o+k|0)*-6|0)-(d[m]|0)+(((d[n]|0)+l|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;l=b+1|0;if((l|0)<8){f=f+e|0;c=c+e|0;b=l}else{break}}return}function l6(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;B2(g|0,b,8,e,8);h=0;do{j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=b+(j+5)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+(k|4)|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(j+4)|0;j=c[o>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[o>>2]=(m|j)-((m^j)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function m6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;C2(k|0,l,8,16);m=0;do{e=m<<4;h=c[l+e>>2]|0;n=m<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ba(m,f)|0;p=b+j|0;q=c[p>>2]|0;r=(o|h)-((o^h)>>>1&2139062143)|0;c[p>>2]=(r|q)-((r^q)>>>1&2139062143);q=c[l+(e|4)>>2]|0;e=k+(n|4)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(j+4)|0;j=c[e>>2]|0;r=(n|q)-((n^q)>>>1&2139062143)|0;c[e>>2]=(r|j)-((r^j)>>>1&2139062143);m=m+1|0;}while((m|0)<8);i=g;return}function n6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;B2(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=(q|j)-((q^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=(q|h)-((q^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);C2(l|0,n,8,8);n=0;do{e=n<<3;m=k+e|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(n,f)|0;j=b+m|0;p=c[j>>2]|0;o=(q|h)-((q^h)>>>1&2139062143)|0;c[j>>2]=(o|p)-((o^p)>>>1&2139062143);p=e|4;e=k+p|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(m+4)|0;m=c[e>>2]|0;j=(p|o)-((p^o)>>>1&2139062143)|0;c[e>>2]=(j|m)-((j^m)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function o6(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;B2(j,b,8,e,9);C2(h|0,j,8,8);j=0;do{b=j<<3;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=g+o|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(k+4)|0;k=c[b>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(n|k)-((n^k)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function p6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;B2(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=(r|j)-((r^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=(p|e)-((p^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);C2(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(n,f)|0;j=b+k|0;r=c[j>>2]|0;o=(p|e)-((p^e)>>>1&2139062143)|0;c[j>>2]=(o|r)-((o^r)>>>1&2139062143);r=h|4;h=l+r|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+r|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(k+4)|0;k=c[h>>2]|0;j=(r|o)-((r^o)>>>1&2139062143)|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function q6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+144|0;h=g|0;j=h|0;k=e;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=k;a[h+8|0]=a[e+8|0]|0;k=h+16|0;j=e+f|0;l=j|0;m=j+4|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[k>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[k+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;k=f<<1;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+40|0]=a[e+(k+8)|0]|0;l=h+48|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+56|0]=a[e+(j+8)|0]|0;k=h+64|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+72|0]=a[e+(l+8)|0]|0;j=h+80|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+88|0]=a[e+(k+8)|0]|0;l=h+96|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+104|0]=a[e+(j+8)|0]|0;k=h+112|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+120|0]=a[e+(l+8)|0]|0;j=h+128|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+136|0]=a[e+(k+8)|0]|0;A7(b,h,f,16);i=g;return}function r6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=k|0;B2(m,l,8,16,9);e=0;do{h=e<<3;n=k+h|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=e<<4;p=c[l+o>>2]|0;c[n>>2]=(p|j)-((p^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;p=c[l+(o|4)>>2]|0;c[j>>2]=(p|h)-((p^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);A7(b,m,f,8);i=g;return}function s6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+72|0;e=d|0;B2(e,b,8,c,9);A7(a,e,c,8);i=d;return}function t6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=l|0;B2(m,h,8,16,9);h=0;do{e=h<<3;n=l+e|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=h<<4;p=k+(o|1)|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=(q|j)-((q^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=k+(o|5)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=(o|e)-((o^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);A7(b,m,f,8);i=g;return}function u6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=e;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+8|0]=a[e+8|0]|0;l=h+16|0;j=e+f|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;C2(k|0,h,8,16);h=l;l=0;do{m=l<<4;e=c[h+m>>2]|0;n=l<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ba(l,f)|0;p=b+j|0;q=c[p>>2]|0;r=(o|e)-((o^e)>>>1&2139062143)|0;c[p>>2]=(r|q)-((r^q)>>>1&2139062143);q=c[h+(m|4)>>2]|0;m=k+(n|4)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(j+4)|0;j=c[m>>2]|0;r=(n|q)-((n^q)>>>1&2139062143)|0;c[m>>2]=(r|j)-((r^j)>>>1&2139062143);l=l+1|0;}while((l|0)<8);i=g;return}function v6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;B2(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=(q|j)-((q^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=(q|h)-((q^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);C2(l|0,n,8,8);n=0;do{e=n<<3;m=k+(e+8)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(n,f)|0;j=b+m|0;p=c[j>>2]|0;o=(q|h)-((q^h)>>>1&2139062143)|0;c[j>>2]=(o|p)-((o^p)>>>1&2139062143);p=e|4;e=k+(p+8)|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(m+4)|0;m=c[e>>2]|0;j=(p|o)-((p^o)>>>1&2139062143)|0;c[e>>2]=(j|m)-((j^m)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function w6(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;B2(j,b,8,e,9);C2(h|0,j,8,8);j=0;do{b=j<<3;k=g+(b+8)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(j,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=g+(o+8)|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(k+4)|0;k=c[b>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(n|k)-((n^k)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function x6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;B2(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=(r|j)-((r^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=(p|e)-((p^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);C2(m|0,n,8,8);n=0;do{h=n<<3;k=l+(h+8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(n,f)|0;j=b+k|0;r=c[j>>2]|0;o=(p|e)-((p^e)>>>1&2139062143)|0;c[j>>2]=(o|r)-((o^r)>>>1&2139062143);r=h|4;h=l+(r+8)|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+r|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(k+4)|0;k=c[h>>2]|0;j=(r|o)-((r^o)>>>1&2139062143)|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function y6(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;y7(g|0,b,8,e,8);h=0;do{j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function z6(a,b,c){a=a|0;b=b|0;c=c|0;y7(a,b,c,c,8);return}function A6(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;y7(g|0,b,8,e,8);h=0;do{j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function B6(a,b,c){a=a|0;b=b|0;c=c|0;z7(a,b,c,c);return}function C6(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+216|0;g=f|0;h=f+88|0;j=f+152|0;y7(g|0,b+(-e|0)|0,8,e,11);z7(h|0,b,8,e);z7(j|0,g+8|0,8,8);g=0;do{b=g<<3;k=h+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(g,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=h+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);g=g+1|0;}while((g|0)<8);i=f;return}function D6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+88|0;e=d|0;y7(e|0,b+(-c|0)|0,8,c,11);z7(a,e+8|0,c,8);i=d;return}function E6(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+216|0;g=f|0;h=f+88|0;j=f+152|0;y7(g|0,b+(-e|0)|0,8,e,11);z7(h|0,b+1|0,8,e);z7(j|0,g+8|0,8,8);g=0;do{b=g<<3;k=h+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(g,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=h+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);g=g+1|0;}while((g|0)<8);i=f;return}function F6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=G6(a,b,c,d,8)|0;g=(G6(a,b+8|0,c+8|0,d,8)|0)+f|0;if((e|0)!=16){h=g;return h|0}e=d<<3;f=(G6(a,b+e|0,c+e|0,d,8)|0)+g|0;g=e+8|0;h=f+(G6(a,b+g|0,c+g|0,d,8)|0)|0;return h|0}function G6(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+256|0;a=g|0;h=0;while(1){j=ba(h,f)|0;k=j+1|0;l=d[e+k|0]|0;m=d[b+k|0]|0;k=(d[e+j|0]|0)-(d[b+j|0]|0)|0;n=k+l-m|0;o=h<<3;p=k-l+m|0;m=j+2|0;l=j+3|0;k=d[e+l|0]|0;q=d[b+l|0]|0;l=(d[e+m|0]|0)-(d[b+m|0]|0)|0;m=l+k-q|0;r=l-k+q|0;q=j+4|0;k=j+5|0;l=d[e+k|0]|0;s=d[b+k|0]|0;k=(d[e+q|0]|0)-(d[b+q|0]|0)|0;q=k+l-s|0;t=k-l+s|0;s=j+6|0;l=j+7|0;j=d[e+l|0]|0;k=d[b+l|0]|0;l=(d[e+s|0]|0)-(d[b+s|0]|0)|0;s=l+j-k|0;u=l-j+k|0;k=m+n|0;j=n-m|0;m=r+p|0;n=p-r|0;r=s+q|0;p=q-s|0;s=u+t|0;q=t-u|0;c[a+(o<<2)>>2]=r+k;c[a+((o|4)<<2)>>2]=k-r;c[a+((o|1)<<2)>>2]=s+m;c[a+((o|5)<<2)>>2]=m-s;c[a+((o|2)<<2)>>2]=p+j;c[a+((o|6)<<2)>>2]=j-p;c[a+((o|3)<<2)>>2]=q+n;c[a+((o|7)<<2)>>2]=n-q;q=h+1|0;if((q|0)<8){h=q}else{v=0;w=0;break}}do{h=a+(w<<2)|0;b=c[h>>2]|0;e=a+(w+8<<2)|0;f=c[e>>2]|0;q=f+b|0;n=b-f|0;f=a+(w+16<<2)|0;b=c[f>>2]|0;o=a+(w+24<<2)|0;p=c[o>>2]|0;j=p+b|0;s=b-p|0;p=a+(w+32<<2)|0;b=c[p>>2]|0;m=a+(w+40<<2)|0;r=c[m>>2]|0;k=r+b|0;u=b-r|0;r=a+(w+48<<2)|0;b=c[r>>2]|0;t=a+(w+56<<2)|0;l=c[t>>2]|0;x=l+b|0;y=b-l|0;l=j+q|0;c[h>>2]=l;h=q-j|0;c[f>>2]=h;f=s+n|0;c[e>>2]=f;e=n-s|0;c[o>>2]=e;o=x+k|0;c[p>>2]=o;p=k-x|0;c[r>>2]=p;r=y+u|0;c[m>>2]=r;m=u-y|0;c[t>>2]=m;t=o+l|0;y=l-o|0;o=r+f|0;l=f-r|0;r=p+h|0;f=h-p|0;p=e+m|0;h=e-m|0;v=((y|0)>-1?y:-y|0)+v+((t|0)>-1?t:-t|0)+((l|0)>-1?l:-l|0)+((o|0)>-1?o:-o|0)+((f|0)>-1?f:-f|0)+((r|0)>-1?r:-r|0)+((h|0)>-1?h:-h|0)+((p|0)>-1?p:-p|0)|0;w=w+1|0;}while((w|0)<8);i=g;return v|0}function H6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=I6(a,b,c,d,8)|0;g=(I6(a,b+8|0,c+8|0,d,8)|0)+f|0;if((e|0)!=16){h=g;return h|0}e=d<<3;f=(I6(a,b+e|0,c+e|0,d,8)|0)+g|0;g=e+8|0;h=f+(I6(a,b+g|0,c+g|0,d,8)|0)|0;return h|0}function I6(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+256|0;e=g|0;a=0;while(1){h=ba(a,f)|0;j=d[b+h|0]|0;k=d[b+(h+1)|0]|0;l=k+j|0;m=a<<3;n=j-k|0;k=d[b+(h+2)|0]|0;j=d[b+(h+3)|0]|0;o=j+k|0;p=k-j|0;j=d[b+(h+4)|0]|0;k=d[b+(h+5)|0]|0;q=k+j|0;r=j-k|0;k=d[b+(h+6)|0]|0;j=d[b+(h+7)|0]|0;h=j+k|0;s=k-j|0;j=o+l|0;k=l-o|0;o=p+n|0;l=n-p|0;p=h+q|0;n=q-h|0;h=s+r|0;q=r-s|0;c[e+(m<<2)>>2]=p+j;c[e+((m|4)<<2)>>2]=j-p;c[e+((m|1)<<2)>>2]=h+o;c[e+((m|5)<<2)>>2]=o-h;c[e+((m|2)<<2)>>2]=n+k;c[e+((m|6)<<2)>>2]=k-n;c[e+((m|3)<<2)>>2]=q+l;c[e+((m|7)<<2)>>2]=l-q;q=a+1|0;if((q|0)<8){a=q}else{t=0;u=0;break}}do{a=e+(u<<2)|0;b=c[a>>2]|0;f=e+(u+8<<2)|0;q=c[f>>2]|0;l=q+b|0;m=b-q|0;q=e+(u+16<<2)|0;b=c[q>>2]|0;n=e+(u+24<<2)|0;k=c[n>>2]|0;h=k+b|0;o=b-k|0;k=e+(u+32<<2)|0;b=c[k>>2]|0;p=e+(u+40<<2)|0;j=c[p>>2]|0;s=j+b|0;r=b-j|0;j=e+(u+48<<2)|0;b=c[j>>2]|0;v=e+(u+56<<2)|0;w=c[v>>2]|0;x=w+b|0;y=b-w|0;w=h+l|0;c[a>>2]=w;a=l-h|0;c[q>>2]=a;q=o+m|0;c[f>>2]=q;f=m-o|0;c[n>>2]=f;n=x+s|0;c[k>>2]=n;k=s-x|0;c[j>>2]=k;j=y+r|0;c[p>>2]=j;p=r-y|0;c[v>>2]=p;v=n+w|0;y=w-n|0;n=j+q|0;w=q-j|0;j=k+a|0;q=a-k|0;k=f+p|0;a=f-p|0;t=((y|0)>-1?y:-y|0)+t+((v|0)>-1?v:-v|0)+((w|0)>-1?w:-w|0)+((n|0)>-1?n:-n|0)+((q|0)>-1?q:-q|0)+((j|0)>-1?j:-j|0)+((a|0)>-1?a:-a|0)+((k|0)>-1?k:-k|0)|0;u=u+1|0;}while((u|0)<8);u=(c[e+128>>2]|0)+(c[e>>2]|0)|0;i=g;return t-((u|0)>-1?u:-u|0)|0}function J6(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+128|0;h=g|0;j=a+10060|0;cf[c[j>>2]&1023](h,b,d,e);k=a+11164|0;me[c[k>>2]&511](h);l=a+10080|0;a=re[c[l>>2]&4095](h)|0;cf[c[j>>2]&1023](h,b+8|0,d+8|0,e);me[c[k>>2]&511](h);m=(re[c[l>>2]&4095](h)|0)+a|0;if((f|0)!=16){n=m;i=g;return n|0}f=e<<3;cf[c[j>>2]&1023](h,b+f|0,d+f|0,e);me[c[k>>2]&511](h);a=(re[c[l>>2]&4095](h)|0)+m|0;m=f+8|0;cf[c[j>>2]&1023](h,b+m|0,d+m|0,e);me[c[k>>2]&511](h);n=a+(re[c[l>>2]&4095](h)|0)|0;i=g;return n|0}function K6(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;f=i;i=i+128|0;g=f|0;cf[c[a+10060>>2]&1023](g,b,d,e);me[c[a+11164>>2]&511](g);e=re[c[a+10080>>2]&4095](g)|0;i=f;return e|0}function L6(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+128|0;j=h|0;k=j|0;l=a+10060|0;cf[c[l>>2]&1023](k,d,e,f);m=a+11164|0;me[c[m>>2]&511](k);a=0;n=0;do{o=b[j+(n<<1)>>1]|0;p=o<<16>>16;q=o<<16>>16>-1?p:-p|0;a=(a|0)>(q|0)?a:q;n=n+1|0;}while((n|0)<64);cf[c[l>>2]&1023](k,d+8|0,e+8|0,f);me[c[m>>2]&511](k);n=0;q=0;do{p=b[j+(q<<1)>>1]|0;o=p<<16>>16;r=p<<16>>16>-1?o:-o|0;n=(n|0)>(r|0)?n:r;q=q+1|0;}while((q|0)<64);q=n+a|0;if((g|0)!=16){s=q;i=h;return s|0}g=f<<3;cf[c[l>>2]&1023](k,d+g|0,e+g|0,f);me[c[m>>2]&511](k);a=0;n=0;do{r=b[j+(n<<1)>>1]|0;o=r<<16>>16;p=r<<16>>16>-1?o:-o|0;a=(a|0)>(p|0)?a:p;n=n+1|0;}while((n|0)<64);n=g+8|0;cf[c[l>>2]&1023](k,d+n|0,e+n|0,f);me[c[m>>2]&511](k);k=0;m=0;do{f=b[j+(m<<1)>>1]|0;n=f<<16>>16;e=f<<16>>16>-1?n:-n|0;k=(k|0)>(e|0)?k:e;m=m+1|0;}while((m|0)<64);s=a+q+k|0;i=h;return s|0}function M6(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;g=i;i=i+128|0;h=g|0;j=h|0;cf[c[a+10060>>2]&1023](j,d,e,f);me[c[a+11164>>2]&511](j);j=0;a=0;do{f=b[h+(a<<1)>>1]|0;e=f<<16>>16;d=f<<16>>16>-1?e:-e|0;j=(j|0)>(d|0)?j:d;a=a+1|0;}while((a|0)<64);i=g;return j|0}function N6(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=e;i=0;j=0;k=b}else{l=0;return l|0}while(1){b=(c[5398952+((d[k]|0|256)-(d[h]|0)<<2)>>2]|0)+i+(c[5398952+((d[k+1|0]|0|256)-(d[h+1|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+2|0]|0|256)-(d[h+2|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+3|0]|0|256)-(d[h+3|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+4|0]|0|256)-(d[h+4|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+5|0]|0|256)-(d[h+5|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+6|0]|0|256)-(d[h+6|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+7|0]|0|256)-(d[h+7|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+8|0]|0|256)-(d[h+8|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+9|0]|0|256)-(d[h+9|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+10|0]|0|256)-(d[h+10|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+11|0]|0|256)-(d[h+11|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+12|0]|0|256)-(d[h+12|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+13|0]|0|256)-(d[h+13|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+14|0]|0|256)-(d[h+14|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+15|0]|0|256)-(d[h+15|0]|0)<<2)>>2]|0)|0;e=j+1|0;if((e|0)<(g|0)){h=h+f|0;i=b;j=e;k=k+f|0}else{l=b;break}}return l|0}function O6(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=e;i=0;j=0;k=b}else{l=0;return l|0}while(1){b=(c[5398952+((d[k]|0|256)-(d[h]|0)<<2)>>2]|0)+i+(c[5398952+((d[k+1|0]|0|256)-(d[h+1|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+2|0]|0|256)-(d[h+2|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+3|0]|0|256)-(d[h+3|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+4|0]|0|256)-(d[h+4|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+5|0]|0|256)-(d[h+5|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+6|0]|0|256)-(d[h+6|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+7|0]|0|256)-(d[h+7|0]|0)<<2)>>2]|0)|0;e=j+1|0;if((e|0)<(g|0)){h=h+f|0;i=b;j=e;k=k+f|0}else{l=b;break}}return l|0}function P6(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=e;i=0;j=0;k=b}else{l=0;return l|0}while(1){b=(c[5398952+((d[k]|0|256)-(d[h]|0)<<2)>>2]|0)+i+(c[5398952+((d[k+1|0]|0|256)-(d[h+1|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+2|0]|0|256)-(d[h+2|0]|0)<<2)>>2]|0)+(c[5398952+((d[k+3|0]|0|256)-(d[h+3|0]|0)<<2)>>2]|0)|0;e=j+1|0;if((e|0)<(g|0)){h=h+f|0;i=b;j=e;k=k+f|0}else{l=b;break}}return l|0}function Q6(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+288|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+280|0;o=m;p=a;q=m|0;r=a+12488|0;c[r>>2]=0;s=a+10060|0;cf[c[s>>2]&1023](q,d,e,f);t=m+128|0;UGb(t|0,o|0,128)|0;u=a+14396|0;v=a+9960|0;w=a+180|0;c[w>>2]=Pe[c[u>>2]&255](p,q,0,c[v>>2]|0,n)|0;x=a+14388|0;cf[c[x>>2]&1023](p,q,0,c[v>>2]|0);EXa(q);c[n>>2]=0;n=0;a=0;do{y=(b[m+(n<<1)>>1]|0)-(b[m+(n+64<<1)>>1]|0)|0;a=(ba(y,y)|0)+a|0;n=n+1|0;}while((n|0)<64);c[r>>2]=0;cf[c[s>>2]&1023](q,d+8|0,e+8|0,f);UGb(t|0,o|0,128)|0;c[w>>2]=Pe[c[u>>2]&255](p,q,0,c[v>>2]|0,l)|0;cf[c[x>>2]&1023](p,q,0,c[v>>2]|0);EXa(q);c[l>>2]=0;l=0;n=0;do{y=(b[m+(l<<1)>>1]|0)-(b[m+(l+64<<1)>>1]|0)|0;n=(ba(y,y)|0)+n|0;l=l+1|0;}while((l|0)<64);l=n+a|0;if((g|0)!=16){z=l;i=h;return z|0}g=f<<3;c[r>>2]=0;cf[c[s>>2]&1023](q,d+g|0,e+g|0,f);UGb(t|0,o|0,128)|0;c[w>>2]=Pe[c[u>>2]&255](p,q,0,c[v>>2]|0,k)|0;cf[c[x>>2]&1023](p,q,0,c[v>>2]|0);EXa(q);c[k>>2]=0;k=0;a=0;do{n=(b[m+(k<<1)>>1]|0)-(b[m+(k+64<<1)>>1]|0)|0;a=(ba(n,n)|0)+a|0;k=k+1|0;}while((k|0)<64);k=g+8|0;c[r>>2]=0;cf[c[s>>2]&1023](q,d+k|0,e+k|0,f);UGb(t|0,o|0,128)|0;c[w>>2]=Pe[c[u>>2]&255](p,q,0,c[v>>2]|0,j)|0;cf[c[x>>2]&1023](p,q,0,c[v>>2]|0);EXa(q);c[j>>2]=0;j=0;q=0;do{v=(b[m+(j<<1)>>1]|0)-(b[m+(j+64<<1)>>1]|0)|0;q=(ba(v,v)|0)+q|0;j=j+1|0;}while((j|0)<64);z=a+l+q|0;i=h;return z|0}function R6(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+264|0;h=g|0;j=g+256|0;k=a;l=h|0;c[a+12488>>2]=0;cf[c[a+10060>>2]&1023](l,d,e,f);UGb(h+128|0,h|0,128)|0;f=a+9960|0;c[a+180>>2]=Pe[c[a+14396>>2]&255](k,l,0,c[f>>2]|0,j)|0;cf[c[a+14388>>2]&1023](k,l,0,c[f>>2]|0);EXa(l);c[j>>2]=0;j=0;l=0;do{f=(b[h+(j<<1)>>1]|0)-(b[h+(j+64<<1)>>1]|0)|0;l=(ba(f,f)|0)+l|0;j=j+1|0;}while((j|0)<64);i=g;return l|0}function S6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=T6(a,b,c,d,8)|0;g=(T6(a,b+8|0,c+8|0,d,8)|0)+f|0;if((e|0)!=16){h=g;return h|0}e=d<<3;f=(T6(a,b+e|0,c+e|0,d,8)|0)+g|0;g=e+8|0;h=f+(T6(a,b+g|0,c+g|0,d,8)|0)|0;return h|0}function T6(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;i=i+192|0;j=h|0;k=h+128|0;l=k|0;m=i;i=i+64|0;n=m|0;o=i;i=i+4|0;i=i+7&-8;p=a;q=j|0;r=k;s=m;t=c[a+13088>>2]|0;u=e;v=u|0;w=u+4|0;u=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[l>>2]=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24;c[l+4>>2]=u;u=k+8|0;l=e+g|0;v=l|0;w=l+4|0;l=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[u>>2]=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24;c[u+4>>2]=l;l=k+16|0;u=g<<1;v=e+u|0;w=v|0;x=v+4|0;v=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;c[l>>2]=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24;c[l+4>>2]=v;v=k+24|0;l=u+g|0;w=e+l|0;x=w|0;y=w+4|0;w=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;c[v>>2]=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24;c[v+4>>2]=w;w=k+32|0;v=l+g|0;x=e+v|0;y=x|0;z=x+4|0;x=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;c[w>>2]=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24;c[w+4>>2]=x;x=k+40|0;w=v+g|0;y=e+w|0;z=y|0;A=y+4|0;y=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;c[x>>2]=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24;c[x+4>>2]=y;y=k+48|0;x=w+g|0;z=e+x|0;A=z|0;B=z+4|0;z=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;c[y>>2]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;c[y+4>>2]=z;z=k+56|0;k=x+g|0;y=e+k|0;e=y|0;A=y+4|0;y=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;c[z>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;c[z+4>>2]=y;y=f;z=y|0;e=y+4|0;y=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[n>>2]=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24;c[n+4>>2]=y;y=m+8|0;n=f+g|0;g=n|0;z=n+4|0;n=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;c[y>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[y+4>>2]=n;n=m+16|0;y=f+u|0;u=y|0;g=y+4|0;y=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[n>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[n+4>>2]=y;y=m+24|0;n=f+l|0;l=n|0;u=n+4|0;n=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[y>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[y+4>>2]=n;n=m+32|0;y=f+v|0;v=y|0;l=y+4|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[n>>2]=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24;c[n+4>>2]=y;y=m+40|0;n=f+w|0;w=n|0;v=n+4|0;n=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[y>>2]=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24;c[y+4>>2]=n;n=m+48|0;y=f+x|0;x=y|0;w=y+4|0;y=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[n>>2]=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24;c[n+4>>2]=y;y=m+56|0;m=f+k|0;k=m|0;f=m+4|0;m=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[y>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[y+4>>2]=m;cf[c[a+10060>>2]&1023](q,r,s,8);m=a+9960|0;y=Pe[c[a+14396>>2]&255](p,q,0,c[m>>2]|0,o)|0;c[a+180>>2]=y;k=(c[a+12488>>2]|0)==0;if(k){C=a+13104|0;D=a+13100|0;E=0;F=0}else{C=a+13096|0;D=a+13092|0;E=d[(c[a+13108>>2]|0)+((b[q>>1]|0)+256)|0]|0;F=1}f=c[C>>2]|0;C=c[D>>2]|0;do{if((y|0)<(F|0)){G=E}else{c[o>>2]=F;if((F|0)<(y|0)){D=F;n=E;x=0;while(1){w=b[j+(d[a+(D+368)|0]<<1)>>1]|0;if(w<<16>>16==0){H=x+1|0;I=n}else{v=(w<<16>>16)+64|0;if(v>>>0<128>>>0){J=d[C+(v+(x<<7))|0]|0}else{J=t}H=0;I=J+n|0}v=D+1|0;c[o>>2]=v;if((v|0)<(y|0)){D=v;n=I;x=H}else{K=I;L=H;break}}}else{K=E;L=0}x=d[a+(y+368)|0]|0;c[o>>2]=x;n=(b[j+(x<<1)>>1]|0)+64|0;if(n>>>0<128>>>0){G=(d[f+(n+(L<<7))|0]|0)+K|0;break}else{G=K+t|0;break}}}while(0);if(!((y|0)>-1)){M=a+11180|0;N=M;O=c[N>>2]|0;Xe[O&4095](s,8,q);P=a+10136|0;Q=P;R=c[Q>>2]|0;S=Pe[R&255](0,s,r,8,8)|0;T=c[m>>2]|0;U=G*109|0;V=ba(U,T)|0;W=ba(V,T)|0;X=W+64|0;Y=X>>7;Z=Y+S|0;i=h;return Z|0}if(k){cf[c[a+14388>>2]&1023](p,q,0,c[m>>2]|0);M=a+11180|0;N=M;O=c[N>>2]|0;Xe[O&4095](s,8,q);P=a+10136|0;Q=P;R=c[Q>>2]|0;S=Pe[R&255](0,s,r,8,8)|0;T=c[m>>2]|0;U=G*109|0;V=ba(U,T)|0;W=ba(V,T)|0;X=W+64|0;Y=X>>7;Z=Y+S|0;i=h;return Z|0}else{cf[c[a+14384>>2]&1023](p,q,0,c[m>>2]|0);M=a+11180|0;N=M;O=c[N>>2]|0;Xe[O&4095](s,8,q);P=a+10136|0;Q=P;R=c[Q>>2]|0;S=Pe[R&255](0,s,r,8,8)|0;T=c[m>>2]|0;U=G*109|0;V=ba(U,T)|0;W=ba(V,T)|0;X=W+64|0;Y=X>>7;Z=Y+S|0;i=h;return Z|0}return 0}function U6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=V6(a,b,c,d,8)|0;g=(V6(a,b+8|0,c+8|0,d,8)|0)+f|0;if((e|0)!=16){h=g;return h|0}e=d<<3;f=(V6(a,b+e|0,c+e|0,d,8)|0)+g|0;g=e+8|0;h=f+(V6(a,b+g|0,c+g|0,d,8)|0)|0;return h|0}function V6(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+136|0;j=h|0;k=h+128|0;l=j|0;m=c[a+13088>>2]|0;cf[c[a+10060>>2]&1023](l,e,f,g);g=Pe[c[a+14396>>2]&255](a,l,0,c[a+9960>>2]|0,k)|0;c[a+180>>2]=g;if((c[a+12488>>2]|0)==0){n=a+13104|0;o=a+13100|0;p=0;q=0}else{n=a+13096|0;o=a+13092|0;p=d[(c[a+13108>>2]|0)+((b[l>>1]|0)+256)|0]|0;q=1}l=c[n>>2]|0;n=c[o>>2]|0;if((g|0)<(q|0)){r=p;i=h;return r|0}c[k>>2]=q;if((q|0)<(g|0)){o=q;q=p;f=0;while(1){e=b[j+(d[a+(o+368)|0]<<1)>>1]|0;if(e<<16>>16==0){s=f+1|0;t=q}else{u=(e<<16>>16)+64|0;if(u>>>0<128>>>0){v=d[n+(u+(f<<7))|0]|0}else{v=m}s=0;t=v+q|0}u=o+1|0;c[k>>2]=u;if((u|0)<(g|0)){o=u;q=t;f=s}else{w=t;x=s;break}}}else{w=p;x=0}p=d[a+(g+368)|0]|0;c[k>>2]=p;k=(b[j+(p<<1)>>1]|0)+64|0;if(k>>>0<128>>>0){r=(d[l+(k+(x<<7))|0]|0)+w|0;i=h;return r|0}else{r=w+m|0;i=h;return r|0}return 0}function W6(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>1){g=c;h=b;i=0;j=1}else{k=0;return k|0}while(1){b=i;c=0;do{a=c+e|0;l=(d[h+c|0]|0)-(d[g+c|0]|0)-(d[h+a|0]|0)+(d[g+a|0]|0)|0;b=((l|0)>-1?l:-l|0)+b|0;c=c+1|0;}while((c|0)<16);c=j+1|0;if((c|0)<(f|0)){g=g+e|0;h=h+e|0;i=b;j=c}else{k=b;break}}return k|0}function X6(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>1){g=b;h=0;i=1}else{j=0;return j|0}while(1){b=h;c=0;do{a=(d[g+c|0]|0)-(d[g+(c+e)|0]|0)|0;k=c|1;l=(d[g+k|0]|0)-(d[g+(k+e)|0]|0)|0;k=c|2;m=(d[g+k|0]|0)-(d[g+(k+e)|0]|0)|0;k=c|3;n=(d[g+k|0]|0)-(d[g+(k+e)|0]|0)|0;b=((a|0)>-1?a:-a|0)+b+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)|0;c=c+4|0;}while((c|0)<16);c=i+1|0;if((c|0)<(f|0)){g=g+e|0;h=b;i=c}else{j=b;break}}return j|0}function Y6(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((g|0)<=1){h=0;return h|0}e=c;b=0;i=1;j=a[c]|0;while(1){c=e+f|0;k=a[c]|0;l=(j&255)-(k&255)|0;m=(d[e+1|0]|0)-(d[e+(f+1)|0]|0)|0;n=(d[e+2|0]|0)-(d[e+(f+2)|0]|0)|0;o=(d[e+3|0]|0)-(d[e+(f+3)|0]|0)|0;p=(d[e+4|0]|0)-(d[e+(f+4)|0]|0)|0;q=(d[e+5|0]|0)-(d[e+(f+5)|0]|0)|0;r=(d[e+6|0]|0)-(d[e+(f+6)|0]|0)|0;s=(d[e+7|0]|0)-(d[e+(f+7)|0]|0)|0;t=((p|0)>-1?p:-p|0)+(((l|0)>-1?l:-l|0)+b+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0))+((q|0)>-1?q:-q|0)+((r|0)>-1?r:-r|0)+((s|0)>-1?s:-s|0)|0;s=i+1|0;if((s|0)<(g|0)){e=c;b=t;i=s;j=k}else{h=t;break}}return h|0}function Z6(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>1){g=c;h=b;i=0;j=1}else{k=0;return k|0}while(1){b=i;c=0;do{a=c+e|0;l=(d[h+c|0]|0)-(d[g+c|0]|0)-(d[h+a|0]|0)+(d[g+a|0]|0)|0;b=(ba(l,l)|0)+b|0;c=c+1|0;}while((c|0)<16);c=j+1|0;if((c|0)<(f|0)){g=g+e|0;h=h+e|0;i=b;j=c}else{k=b;break}}return k|0}function _6(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>1){g=b;h=0;i=1}else{j=0;return j|0}while(1){b=h;c=0;do{a=(d[g+c|0]|0)-(d[g+(c+e)|0]|0)|0;k=ba(a,a)|0;a=c|1;l=(d[g+a|0]|0)-(d[g+(a+e)|0]|0)|0;a=ba(l,l)|0;l=c|2;m=(d[g+l|0]|0)-(d[g+(l+e)|0]|0)|0;l=ba(m,m)|0;m=c|3;n=(d[g+m|0]|0)-(d[g+(m+e)|0]|0)|0;b=k+b+a+l+(ba(n,n)|0)|0;c=c+4|0;}while((c|0)<16);c=i+1|0;if((c|0)<(f|0)){g=g+e|0;h=b;i=c}else{j=b;break}}return j|0}function $6(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=1){h=0;return h|0}e=c;b=0;i=1;j=a[c]|0;while(1){c=e+f|0;k=a[c]|0;l=(j&255)-(k&255)|0;m=ba(l,l)|0;l=(d[e+1|0]|0)-(d[e+(f+1)|0]|0)|0;n=ba(l,l)|0;l=(d[e+2|0]|0)-(d[e+(f+2)|0]|0)|0;o=ba(l,l)|0;l=(d[e+3|0]|0)-(d[e+(f+3)|0]|0)|0;p=m+b+n+o+(ba(l,l)|0)|0;l=(d[e+4|0]|0)-(d[e+(f+4)|0]|0)|0;o=ba(l,l)|0;l=(d[e+5|0]|0)-(d[e+(f+5)|0]|0)|0;n=ba(l,l)|0;l=(d[e+6|0]|0)-(d[e+(f+6)|0]|0)|0;m=ba(l,l)|0;l=(d[e+7|0]|0)-(d[e+(f+7)|0]|0)|0;q=o+p+n+m+(ba(l,l)|0)|0;l=i+1|0;if((l|0)<(g|0)){e=c;b=q;i=l;j=k}else{h=q;break}}return h|0}function a7(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a:do{if((h|0)>0){i=f;j=e;k=0;l=0;m=0;while(1){n=k;o=0;do{p=(d[j+o|0]|0)-(d[i+o|0]|0)|0;n=(ba(p,p)|0)+n|0;o=o+1|0;}while((o|0)<16);o=m+1|0;p=(o|0)<(h|0);if(!p){q=n;r=l;break a}s=l;t=0;u=a[j]|0;v=a[i]|0;while(1){w=t+g|0;x=t+1|0;y=a[j+x|0]|0;z=x+g|0;A=(u&255)-(d[j+w|0]|0)-(y&255)+(d[j+z|0]|0)|0;B=a[i+x|0]|0;C=(v&255)-(d[i+w|0]|0)-(B&255)+(d[i+z|0]|0)|0;D=((A|0)>-1?A:-A|0)+s-((C|0)>-1?C:-C|0)|0;if((x|0)<15){s=D;t=x;u=y;v=B}else{break}}if(p){i=i+g|0;j=j+g|0;k=n;l=D;m=o}else{q=n;r=D;break}}}else{q=0;r=0}}while(0);D=(r|0)>-1?r:-r|0;if((b|0)==0){E=D<<3;F=E+q|0;return F|0}else{E=ba(c[(c[b+4>>2]|0)+836>>2]|0,D)|0;F=E+q|0;return F|0}return 0}function b7(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a:do{if((h|0)>0){i=f;j=e;k=0;l=0;m=0;while(1){n=a[j]|0;o=a[i]|0;p=(n&255)-(o&255)|0;q=(ba(p,p)|0)+k|0;p=(d[j+1|0]|0)-(d[i+1|0]|0)|0;r=(ba(p,p)|0)+q|0;q=(d[j+2|0]|0)-(d[i+2|0]|0)|0;p=(ba(q,q)|0)+r|0;r=(d[j+3|0]|0)-(d[i+3|0]|0)|0;q=(ba(r,r)|0)+p|0;p=(d[j+4|0]|0)-(d[i+4|0]|0)|0;r=(ba(p,p)|0)+q|0;q=(d[j+5|0]|0)-(d[i+5|0]|0)|0;p=(ba(q,q)|0)+r|0;r=(d[j+6|0]|0)-(d[i+6|0]|0)|0;q=(ba(r,r)|0)+p|0;p=(d[j+7|0]|0)-(d[i+7|0]|0)|0;r=(ba(p,p)|0)+q|0;q=m+1|0;p=(q|0)<(h|0);if(p){s=l;t=0;u=n;v=o}else{w=r;x=l;break a}while(1){o=t+g|0;n=t+1|0;y=a[j+n|0]|0;z=n+g|0;A=(u&255)-(d[j+o|0]|0)-(y&255)+(d[j+z|0]|0)|0;B=a[i+n|0]|0;C=(v&255)-(d[i+o|0]|0)-(B&255)+(d[i+z|0]|0)|0;D=((A|0)>-1?A:-A|0)+s-((C|0)>-1?C:-C|0)|0;if((n|0)<7){s=D;t=n;u=y;v=B}else{break}}if(p){i=i+g|0;j=j+g|0;k=r;l=D;m=q}else{w=r;x=D;break}}}else{w=0;x=0}}while(0);D=(x|0)>-1?x:-x|0;if((b|0)==0){E=D<<3;F=E+w|0;return F|0}else{E=ba(c[(c[b+4>>2]|0)+836>>2]|0,D)|0;F=E+w|0;return F|0}return 0}function c7(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((e|0)>0){f=0;g=0}else{h=0;return h|0}while(1){i=(a[c+g|0]|0)-(b[d+(g<<1)>>1]|0)|0;j=(ba(i,i)|0)+f|0;i=g+1|0;if((i|0)<(e|0)){f=j;g=i}else{h=j;break}}return h|0}function d7(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=e-4|0;if((f|0)<0){g=0}else{h=0;while(1){i=c[d+h>>2]|0;j=b+h|0;k=c[j>>2]|0;c[j>>2]=(k&2139062143)+(i&2139062143)^(k^i)&-2139062144;i=h+4|0;if((i|0)>(f|0)){g=i;break}else{h=i}}}if((g|0)<(e|0)){l=g}else{return}do{g=b+l|0;a[g]=(a[g]|0)+(a[d+l|0]|0);l=l+1|0;}while((l|0)<(e|0));return}function e7(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;do{if((e&3|0)==0){g=f-4|0;if((g|0)<0){h=0;break}else{i=0}while(1){j=c[d+i>>2]|0;k=c[e+i>>2]|0;c[b+i>>2]=(k^j)&-2139062144^-2139062144^(j|-2139062144)-(k&2139062143);k=i+4|0;if((k|0)>(g|0)){h=k;break}else{i=k}}}else{if((f|0)>7){l=0;m=7}else{h=0;break}while(1){a[b+l|0]=(a[d+l|0]|0)-(a[e+l|0]|0);g=l|1;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|2;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|3;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|4;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|5;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|6;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);a[b+m|0]=(a[d+m|0]|0)-(a[e+m|0]|0);g=l+8|0;k=g|7;if((k|0)<(f|0)){l=g;m=k}else{h=g;break}}}}while(0);if((h|0)<(f|0)){n=h}else{return}do{a[b+n|0]=(a[d+n|0]|0)-(a[e+n|0]|0);n=n+1|0;}while((n|0)<(f|0));return}function f7(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=c[h>>2]|0;k=c[i>>2]&255;l=j&255;if((g|0)<=0){m=k;n=l;c[h>>2]=n;o=m&255;c[i>>2]=o;return}p=0;q=j&255;j=k;k=l;while(1){l=a[e+p|0]|0;r=l&255;s=k-(j&255)+r&255;do{if((q&255)>>>0>(l&255)>>>0){if(!(s>>>0>r>>>0)){t=r;break}t=s>>>0>k>>>0?k:s}else{if(!(r>>>0>s>>>0)){t=r;break}t=s>>>0>k>>>0?s:k}}while(0);s=(d[f+p|0]|0)+t|0;r=s&255;a[b+p|0]=r;u=p+1|0;v=s&255;if((u|0)<(g|0)){p=u;q=r;j=l;k=v}else{m=l;n=v;break}}c[h>>2]=n;o=m&255;c[i>>2]=o;return}function g7(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c[g>>2]|0;j=c[h>>2]&255;k=i&255;if((f|0)<=0){l=j;m=k;c[g>>2]=m;n=l&255;c[h>>2]=n;return}o=i&255;i=j;j=0;p=k;while(1){k=a[d+j|0]|0;q=k&255;r=p-(i&255)+q&255;do{if((o&255)>>>0>(k&255)>>>0){if(!(r>>>0>q>>>0)){s=q;break}s=r>>>0>p>>>0?p:r}else{if(!(q>>>0>r>>>0)){s=q;break}s=r>>>0>p>>>0?r:p}}while(0);r=a[e+j|0]|0;q=r&255;a[b+j|0]=q-s;t=j+1|0;if((t|0)<(f|0)){o=r;i=k;j=t;p=q}else{l=k;m=q;break}}c[g>>2]=m;n=l&255;c[h>>2]=n;return}function h7(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=e-1|0;if((g|0)>0){h=f;i=0;while(1){j=(d[c+i|0]|0)+h|0;a[b+i|0]=j;k=i|1;l=j+(d[c+k|0]|0)|0;a[b+k|0]=l;k=i+2|0;if((k|0)<(g|0)){h=l;i=k}else{m=l;n=k;break}}}else{m=f;n=0}if((n|0)<(e|0)){o=m;p=n}else{q=m;return q|0}while(1){m=(d[c+p|0]|0)+o|0;a[b+p|0]=m;n=p+1|0;if((n|0)<(e|0)){o=m;p=n}else{q=m;break}}return q|0}function i7(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=c[g>>2]|0;l=c[h>>2]|0;m=c[i>>2]|0;n=c[j>>2]|0;if((f|0)>0){o=0;p=k;q=l;r=m;s=n}else{t=k;u=l;v=m;w=n;c[g>>2]=t;c[h>>2]=u;c[i>>2]=v;c[j>>2]=w;return}while(1){n=o<<2;m=(d[e+n|0]|0)+r|0;l=n|1;k=(d[e+l|0]|0)+q|0;x=n|2;y=(d[e+x|0]|0)+p|0;z=n|3;A=(d[e+z|0]|0)+s|0;a[b+n|0]=m;a[b+l|0]=k;a[b+x|0]=y;a[b+z|0]=A;z=o+1|0;if((z|0)<(f|0)){o=z;p=y;q=k;r=m;s=A}else{t=y;u=k;v=m;w=A;break}}c[g>>2]=t;c[h>>2]=u;c[i>>2]=v;c[j>>2]=w;return}function j7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)<8){e=0}else{f=0;g=8;while(1){c[a+(f<<2)>>2]=fe(c[b+(f<<2)>>2]|0)|0;h=f|1;c[a+(h<<2)>>2]=fe(c[b+(h<<2)>>2]|0)|0;h=f|2;c[a+(h<<2)>>2]=fe(c[b+(h<<2)>>2]|0)|0;h=f|3;c[a+(h<<2)>>2]=fe(c[b+(h<<2)>>2]|0)|0;h=f|4;c[a+(h<<2)>>2]=fe(c[b+(h<<2)>>2]|0)|0;h=f|5;c[a+(h<<2)>>2]=fe(c[b+(h<<2)>>2]|0)|0;h=f|6;c[a+(h<<2)>>2]=fe(c[b+(h<<2)>>2]|0)|0;h=f|7;c[a+(h<<2)>>2]=fe(c[b+(h<<2)>>2]|0)|0;h=g+8|0;if((h|0)>(d|0)){e=g;break}else{f=g;g=h}}}if((e|0)<(d|0)){i=e}else{return}do{c[a+(i<<2)>>2]=fe(c[b+(i<<2)>>2]|0)|0;i=i+1|0;}while((i|0)<(d|0));return}function k7(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;if((d|0)==0){return}else{e=a;f=c;g=d}while(1){d=g-1|0;b[e>>1]=de(b[f>>1]|0)|0;if((d|0)==0){break}else{e=e+2|0;f=f+2|0;g=d}}return}function l7(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=0;g=0;do{h=((ba(b[d+(g<<1)>>1]|0,e)|0)+512>>10)+(b[a+(g<<1)>>1]|0)|0;i=ba(h>>6,b[c+(g<<1)>>1]|0)|0;f=((ba(i,i)|0)>>>4)+f|0;g=g+1|0;}while((g|0)<64);return f>>>2|0}function m7(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=0;do{g=((ba(b[c+(f<<1)>>1]|0,d)|0)+512|0)>>>10;h=a+(f<<1)|0;b[h>>1]=g+(e[h>>1]|0);f=f+1|0;}while((f|0)<64);return}function n7(a,b,d,e,f){a=a|0;b=b|0;d=+d;e=+e;f=f|0;var h=0,i=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0;h=(g[k>>2]=d,c[k>>2]|0);i=(g[k>>2]=e,c[k>>2]|0);if(d<0.0&e>0.0){j=i^-2147483648;if((f|0)>0){l=0}else{return}do{m=c[b+(l<<2)>>2]|0;if(m>>>0>h>>>0){n=h}else{n=(m^-2147483648)>>>0>j>>>0?i:m}c[a+(l<<2)>>2]=n;m=l|1;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){p=h}else{p=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=p;m=l|2;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){q=h}else{q=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=q;m=l|3;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){r=h}else{r=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=r;m=l|4;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){s=h}else{s=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=s;m=l|5;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){t=h}else{t=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=t;m=l|6;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){u=h}else{u=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=u;m=l|7;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){v=h}else{v=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=v;l=l+8|0;}while((l|0)<(f|0));return}else{if((f|0)>0){w=0}else{return}do{x=+g[b+(w<<2)>>2];if(x<d){y=d}else{y=x>e?e:x}g[a+(w<<2)>>2]=y;l=w|1;x=+g[b+(l<<2)>>2];if(x<d){z=d}else{z=x>e?e:x}g[a+(l<<2)>>2]=z;l=w|2;x=+g[b+(l<<2)>>2];if(x<d){A=d}else{A=x>e?e:x}g[a+(l<<2)>>2]=A;l=w|3;x=+g[b+(l<<2)>>2];if(x<d){B=d}else{B=x>e?e:x}g[a+(l<<2)>>2]=B;l=w|4;x=+g[b+(l<<2)>>2];if(x<d){C=d}else{C=x>e?e:x}g[a+(l<<2)>>2]=C;l=w|5;x=+g[b+(l<<2)>>2];if(x<d){D=d}else{D=x>e?e:x}g[a+(l<<2)>>2]=D;l=w|6;x=+g[b+(l<<2)>>2];if(x<d){E=d}else{E=x>e?e:x}g[a+(l<<2)>>2]=E;l=w|7;x=+g[b+(l<<2)>>2];if(x<d){F=d}else{F=x>e?e:x}g[a+(l<<2)>>2]=F;w=w+8|0;}while((w|0)<(f|0));return}}function o7(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)==0){e=0;return e|0}else{f=a;g=c;h=d;i=0}while(1){d=h-1|0;c=(ba(b[g>>1]|0,b[f>>1]|0)|0)+i|0;if((d|0)==0){e=c;break}else{f=f+2|0;g=g+2|0;h=d;i=c}}return e|0}function p7(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((e|0)==0){g=0;return g|0}else{h=c;i=d;j=e;k=a;l=0}while(1){a=j-1|0;e=b[k>>1]|0;d=(ba(b[h>>1]|0,e)|0)+l|0;b[k>>1]=(ba(b[i>>1]|0,f)|0)+e;if((a|0)==0){g=d;break}else{h=h+2|0;i=i+2|0;j=a;k=k+2|0;l=d}}return g|0}function q7(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f;f=a;a=b;while(1){b=c[a>>2]|0;if((b|0)<(d|0)){h=d}else{h=(b|0)>(e|0)?e:b}c[f>>2]=h;b=c[a+4>>2]|0;if((b|0)<(d|0)){i=d}else{i=(b|0)>(e|0)?e:b}c[f+4>>2]=i;b=c[a+8>>2]|0;if((b|0)<(d|0)){j=d}else{j=(b|0)>(e|0)?e:b}c[f+8>>2]=j;b=c[a+12>>2]|0;if((b|0)<(d|0)){k=d}else{k=(b|0)>(e|0)?e:b}c[f+12>>2]=k;b=c[a+16>>2]|0;if((b|0)<(d|0)){l=d}else{l=(b|0)>(e|0)?e:b}c[f+16>>2]=l;b=c[a+20>>2]|0;if((b|0)<(d|0)){m=d}else{m=(b|0)>(e|0)?e:b}c[f+20>>2]=m;b=c[a+24>>2]|0;if((b|0)<(d|0)){n=d}else{n=(b|0)>(e|0)?e:b}c[f+24>>2]=n;b=c[a+28>>2]|0;if((b|0)<(d|0)){o=d}else{o=(b|0)>(e|0)?e:b}c[f+28>>2]=o;b=g-8|0;if((b|0)==0){break}else{g=b;f=f+32|0;a=a+32|0}}return}function r7(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0;f=d;d=c;c=0;while(1){a[d]=(a[d]|0)+(b[f>>1]&255);g=d+1|0;a[g]=(a[g]|0)+(b[f+2>>1]&255);g=d+2|0;a[g]=(a[g]|0)+(b[f+4>>1]&255);g=d+3|0;a[g]=(a[g]|0)+(b[f+6>>1]&255);g=d+4|0;a[g]=(a[g]|0)+(b[f+8>>1]&255);g=d+5|0;a[g]=(a[g]|0)+(b[f+10>>1]&255);g=d+6|0;a[g]=(a[g]|0)+(b[f+12>>1]&255);g=d+7|0;a[g]=(a[g]|0)+(b[f+14>>1]&255);g=c+1|0;if((g|0)<8){f=f+16|0;d=d+e|0;c=g}else{break}}return}function s7(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=-f|0;if((e|0)>0){j=d-1|0;k=b;l=0;while(1){TGb(k+i|0,a[k]|0,f|0)|0;TGb(k+d|0,a[k+j|0]|0,f|0)|0;m=l+1|0;if((m|0)<(e|0)){k=k+c|0;l=m}else{break}}}l=b+i|0;i=(ba(e-1|0,c)|0)-f|0;e=b+i|0;if((h&1|0)!=0&(g|0)>0){k=(f<<1)+d|0;j=0;do{j=j+1|0;UGb(b+(-((ba(j,c)|0)+f|0)|0)|0,l|0,k)|0;}while((j|0)<(g|0))}if(!((h&2|0)!=0&(g|0)>0)){return}h=(f<<1)+d|0;d=0;do{d=d+1|0;UGb(b+((ba(d,c)|0)+i)|0,e|0,h)|0;}while((d|0)<(g|0));return}function t7(a){a=a|0;TGb(a|0,0,128)|0;return}function u7(a){a=a|0;TGb(a|0,0,768)|0;return}function v7(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=d>>>1;d=a;a=c;c=0;while(1){b[d>>1]=b[a>>1]|0;b[d+2>>1]=b[a+2>>1]|0;b[d+4>>1]=b[a+4>>1]|0;b[d+6>>1]=b[a+6>>1]|0;b[d+8>>1]=b[a+8>>1]|0;b[d+10>>1]=b[a+10>>1]|0;b[d+12>>1]=b[a+12>>1]|0;b[d+14>>1]=b[a+14>>1]|0;f=c+1|0;if((f|0)<8){d=d+16|0;a=a+(e<<1)|0;c=f}else{break}}return}function w7(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0;f=a;a=c;c=0;while(1){b[f>>1]=d[a]|0;b[f+2>>1]=d[a+1|0]|0;b[f+4>>1]=d[a+2|0]|0;b[f+6>>1]=d[a+3|0]|0;b[f+8>>1]=d[a+4|0]|0;b[f+10>>1]=d[a+5|0]|0;b[f+12>>1]=d[a+6|0]|0;b[f+14>>1]=d[a+7|0]|0;g=c+1|0;if((g|0)<8){f=f+16|0;a=a+e|0;c=g}else{break}}return}function x7(a,b){a=a|0;b=b|0;Z3(a,b);return}function y7(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=h+1|0;c=h+2|0;a[i]=a[(8-(d[h-1|0]|0)-(d[c]|0)+(((d[b]|0)+(d[h]|0)|0)*9|0)>>4)+1236056|0]|0;k=h+3|0;a[i+1|0]=a[(8-(d[h]|0)-(d[k]|0)+(((d[c]|0)+(d[b]|0)|0)*9|0)>>4)+1236056|0]|0;l=h+4|0;a[i+2|0]=a[(8-(d[b]|0)-(d[l]|0)+(((d[k]|0)+(d[c]|0)|0)*9|0)>>4)+1236056|0]|0;b=h+5|0;a[i+3|0]=a[(8-(d[c]|0)-(d[b]|0)+(((d[l]|0)+(d[k]|0)|0)*9|0)>>4)+1236056|0]|0;c=h+6|0;a[i+4|0]=a[(8-(d[k]|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*9|0)>>4)+1236056|0]|0;k=h+7|0;a[i+5|0]=a[(8-(d[l]|0)-(d[k]|0)+(((d[c]|0)+(d[b]|0)|0)*9|0)>>4)+1236056|0]|0;l=h+8|0;a[i+6|0]=a[(8-(d[b]|0)-(d[l]|0)+(((d[k]|0)+(d[c]|0)|0)*9|0)>>4)+1236056|0]|0;a[i+7|0]=a[(8-(d[c]|0)-(d[h+9|0]|0)+(((d[l]|0)+(d[k]|0)|0)*9|0)>>4)+1236056|0]|0;k=j+1|0;if((k|0)<(g|0)){h=h+f|0;i=i+e|0;j=k}else{break}}return}function z7(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=e<<1;q=e*3|0;r=e<<2;s=e*5|0;t=e*6|0;u=e*7|0;v=0;w=c;c=b;while(1){b=d[w]|0;x=d[w+f|0]|0;y=d[w+h|0]|0;z=d[w+i|0]|0;A=d[w+j|0]|0;B=d[w+k|0]|0;C=d[w+l|0]|0;D=d[w+m|0]|0;E=d[w+n|0]|0;F=d[w+o|0]|0;a[c]=a[(8-(d[w+g|0]|0)-y+((x+b|0)*9|0)>>4)+1236056|0]|0;a[c+e|0]=a[(8-b-z+((y+x|0)*9|0)>>4)+1236056|0]|0;a[c+p|0]=a[(8-x-A+((z+y|0)*9|0)>>4)+1236056|0]|0;a[c+q|0]=a[(8-y-B+((A+z|0)*9|0)>>4)+1236056|0]|0;a[c+r|0]=a[(8-z-C+((B+A|0)*9|0)>>4)+1236056|0]|0;a[c+s|0]=a[(8-A-D+((C+B|0)*9|0)>>4)+1236056|0]|0;a[c+t|0]=a[(8-B-E+((D+C|0)*9|0)>>4)+1236056|0]|0;a[c+u|0]=a[(8-C-F+((E+D|0)*9|0)>>4)+1236056|0]|0;D=v+1|0;if((D|0)<8){v=D;w=w+1|0;c=c+1|0}else{break}}return}function A7(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=e<<1;o=e*3|0;p=e<<2;q=e*5|0;r=e*6|0;s=e*7|0;t=0;u=c;c=b;while(1){b=d[u]|0;v=d[u+f|0]|0;w=d[u+g|0]|0;x=d[u+h|0]|0;y=d[u+i|0]|0;z=d[u+j|0]|0;A=d[u+k|0]|0;B=d[u+l|0]|0;C=d[u+m|0]|0;D=16-w|0;a[c]=((d[c]|0)+1+(d[(D+((v+b|0)*20|0)+((w+b|0)*-6|0)-y+((x+v|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;E=c+e|0;F=16-v|0;a[E]=((d[E]|0)+1+(d[(F+((w+v|0)*20|0)+((x+b|0)*-6|0)-z+((y+b|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;E=c+n|0;G=16-b|0;a[E]=((d[E]|0)+1+(d[(G+((x+w|0)*20|0)+((y+v|0)*-6|0)-A+((z+b|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;b=c+o|0;a[b]=((d[b]|0)+1+(d[(G+((y+x|0)*20|0)+((z+w|0)*-6|0)-B+((A+v|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;v=c+p|0;a[v]=((d[v]|0)+1+(d[(F+((z+y|0)*20|0)+((A+x|0)*-6|0)-C+((B+w|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;w=c+q|0;a[w]=((d[w]|0)+1+(d[(D+((A+z|0)*20|0)-C+((B+y|0)*-6|0)+((C+x|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;D=c+r|0;a[D]=((d[D]|0)+1+(d[(16-x-B+((B+A|0)*20|0)+((C+z|0)*-6|0)+((C+y|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;x=c+s|0;a[x]=((d[x]|0)+1+(d[(16-y-A+((B+z|0)*3|0)+((C+A|0)*-6|0)+((C+B|0)*20|0)>>5)+1236056|0]|0)|0)>>>1;B=t+1|0;if((B|0)<8){t=B;u=u+1|0;c=c+1|0}else{break}}return}function B7(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=f*9|0;o=f*10|0;p=f*11|0;q=f*12|0;r=f*13|0;s=f*14|0;t=f*15|0;u=f<<4;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=e<<3;C=e*9|0;D=e*10|0;E=e*11|0;F=e*12|0;G=e*13|0;H=e*14|0;I=e*15|0;J=0;K=c;c=b;while(1){b=d[K]|0;L=d[K+f|0]|0;M=d[K+g|0]|0;N=d[K+h|0]|0;O=d[K+i|0]|0;P=d[K+j|0]|0;Q=d[K+k|0]|0;R=d[K+l|0]|0;S=d[K+m|0]|0;T=d[K+n|0]|0;U=d[K+o|0]|0;V=d[K+p|0]|0;W=d[K+q|0]|0;X=d[K+r|0]|0;Y=d[K+s|0]|0;Z=d[K+t|0]|0;_=d[K+u|0]|0;$=16-M|0;a[c]=((d[c]|0)+1+(d[($+((L+b|0)*20|0)+((M+b|0)*-6|0)-O+((N+L|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;aa=c+e|0;ba=16-L|0;a[aa]=((d[aa]|0)+1+(d[(ba+((M+L|0)*20|0)+((N+b|0)*-6|0)-P+((O+b|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;aa=c+v|0;ca=16-b|0;a[aa]=((d[aa]|0)+1+(d[(ca+((N+M|0)*20|0)+((O+L|0)*-6|0)-Q+((P+b|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;b=c+w|0;a[b]=((d[b]|0)+1+(d[(ca+((O+N|0)*20|0)+((P+M|0)*-6|0)-R+((Q+L|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;L=c+x|0;a[L]=((d[L]|0)+1+(d[(ba+((P+O|0)*20|0)+((Q+N|0)*-6|0)-S+((R+M|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;M=c+y|0;a[M]=((d[M]|0)+1+(d[($+((Q+P|0)*20|0)+((R+O|0)*-6|0)-T+((S+N|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;$=c+z|0;a[$]=((d[$]|0)+1+(d[(16-N+((R+Q|0)*20|0)+((S+P|0)*-6|0)-U+((T+O|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;N=c+A|0;a[N]=((d[N]|0)+1+(d[(16-O+((S+R|0)*20|0)+((T+Q|0)*-6|0)-V+((U+P|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;O=c+B|0;a[O]=((d[O]|0)+1+(d[(16-P+((T+S|0)*20|0)+((U+R|0)*-6|0)-W+((V+Q|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;P=c+C|0;a[P]=((d[P]|0)+1+(d[(16-Q+((U+T|0)*20|0)+((V+S|0)*-6|0)-X+((W+R|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;Q=c+D|0;a[Q]=((d[Q]|0)+1+(d[(16-R+((V+U|0)*20|0)+((W+T|0)*-6|0)-Y+((X+S|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;R=c+E|0;a[R]=((d[R]|0)+1+(d[(16-S+((W+V|0)*20|0)+((X+U|0)*-6|0)-Z+((Y+T|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;S=c+F|0;a[S]=((d[S]|0)+1+(d[(16-T+((X+W|0)*20|0)+((Y+V|0)*-6|0)-_+((Z+U|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;T=c+G|0;a[T]=((d[T]|0)+1+(d[(16-U+((Y+X|0)*20|0)-_+((Z+W|0)*-6|0)+((_+V|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;U=c+H|0;a[U]=((d[U]|0)+1+(d[(16-V-Z+((Z+Y|0)*20|0)+((_+X|0)*-6|0)+((_+W|0)*3|0)>>5)+1236056|0]|0)|0)>>>1;V=c+I|0;a[V]=((d[V]|0)+1+(d[(16-W-Y+((Z+X|0)*3|0)+((_+Y|0)*-6|0)+((_+Z|0)*20|0)>>5)+1236056|0]|0)|0)>>>1;Z=J+1|0;if((Z|0)<16){J=Z;K=K+1|0;c=c+1|0}else{break}}return}function C7(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:do{if(f>>>0<480>>>0){g=0}else{h=a[e+3|0]|0;i=(h&255)>>>7;j=a[e+451|0]|0;k=j&31;l=(i|0)==1;m=(k|0)==0;if(l&m){if(!((a[e+4|0]&7)==0)){g=1346176;break}}n=(b|0)==0;do{if(!((k|0)!=31|n)){if((c[b+52>>2]|0)!=892488787){break}if((c[b+128>>2]|0)!=720){break}if((c[b+132>>2]|0)==576){g=1346176;break a}}}while(0);do{if(!((k|0)!=0|n)){o=c[b+52>>2]|0;if(!((o|0)==1685288548|(o|0)==1129727043)){break}if((c[b+128>>2]|0)!=720){break}if((c[b+132>>2]|0)==576){g=1346060;break a}}}while(0);n=(i|0)==0;if((i|k|0)==0){g=1345944;break}if(l&m){g=1346060;break}if(n&(k|0)==4){g=1346292;break}if(l&(k|0)==4){g=1346408;break}if(n&(k|0)==20){g=1346524;break}if(l&(k|0)==20){g=1346640;break}if(n&(k|0)==24){g=1346756;break}if(l){if((k|0)==24){g=1346872;break}if((k|0)==1){g=1346988;break}}if((d|0)!=0){if((c[d+8>>2]|0)==(f|0)){g=d;break}}if(!((h&127)==63&j<<24>>24==-1)){g=0;break}g=1345944+(i*116|0)|0}}while(0);return g|0}function D7(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;do{if(e>>>0<480>>>0){f=0}else{g=a[d+3|0]|0;h=(g&255)>>>7;i=a[d+451|0]|0;j=i&31;k=(h|0)==1;l=k&(j|0)==0;if(l){if(!((a[d+4|0]&7)==0)){f=1346176;break}f=(j|h|0)==0?1345944:1346060;break}m=(h|0)==0;n=(j|h|0)==0;if(n|l){f=n?1345944:1346060;break}n=(j|0)==4;if(m&n){f=1346292;break}if(k&n){f=1346408;break}n=(j|0)==20;if(m&n){f=1346524;break}if(k&n){f=1346640;break}n=(j|0)==24;if(m&n){f=1346756;break}if(k){if(n){f=1346872;break}if((j|0)==1){f=1346988;break}}if((b|0)!=0){if((c[b+8>>2]|0)==(e|0)){f=b;break}}if(!((g&127)==63&i<<24>>24==-1)){f=0;break}f=1345944+(h*116|0)|0}}while(0);return f|0}function E7(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+128|0;d=a+132|0;do{if((c[b>>2]|0)==0){if((c[d>>2]|0)!=0){e=d;f=b;break}e=a+124|0;f=a+120|0}else{e=d;f=b}}while(0);b=c[e>>2]|0;e=c[f>>2]|0;f=a+140|0;a=0;a:while(1){d=1345944+(a*116|0)|0;do{if((b|0)==(c[1345976+(a*116|0)>>2]|0)){if((c[f>>2]|0)!=(c[1346008+(a*116|0)>>2]|0)){break}if((e|0)==(c[1345980+(a*116|0)>>2]|0)){g=d;h=9;break a}}}while(0);d=a+1|0;if(d>>>0<10>>>0){a=d}else{g=0;h=9;break}}if((h|0)==9){return g|0}return 0}function F7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=0;do{f=c[1345980+(e*116|0)>>2]|0;g=c[1345976+(e*116|0)>>2]|0;h=ZEb(c[1346008+(e*116|0)>>2]|0)|0;j=c[1345968+(e*116|0)>>2]|0;k=c[1345964+(e*116|0)>>2]|0;yDb(a,b,2112584,(l=i,i=i+40|0,c[l>>2]=f,c[l+8>>2]=g,c[l+16>>2]=h,c[l+24>>2]=j,c[l+32>>2]=k,l)|0);i=l;e=e+1|0;}while(e>>>0<10>>>0);i=d;return}function G7(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+8|0;g=e|0;h=c[b+60>>2]|0;c[g>>2]=d;b=f+12|0;do{if((c[b>>2]|0)!=0){if((c[f+16>>2]|0)==0){j=-1}else{break}i=e;return j|0}}while(0);a[d]=15;a[d+1|0]=16;k=d+2|0;x=256;a[k]=x;x=x>>8;a[k+1|0]=x;k=d+4|0;a[d+6|0]=30;l=h;h=(c[l>>2]<<4|11)&255;m=d+8|0;c[g>>2]=m;a[d+7|0]=h;if((c[b>>2]|0)==0){n=m}else{h=f+16|0;o=0;p=m;while(1){c[g>>2]=p+1;a[p]=o;m=c[g>>2]|0;c[g>>2]=m+1;a[m]=-1;m=de(c[c[(c[h>>2]|0)+(o<<2)>>2]>>2]&65535|0)|0;q=c[g>>2]|0;x=m;a[q]=x;x=x>>8;a[q+1|0]=x;q=(c[g>>2]|0)+2|0;c[g>>2]=q;m=q;x=de(c[(c[(c[h>>2]|0)+(o<<2)>>2]|0)+4>>2]&65535|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[g>>2]|0)+2|0;c[g>>2]=m;q=o+1|0;if(q>>>0<(c[b>>2]|0)>>>0){o=q;p=m}else{n=m;break}}}p=k;x=de(65534-k+n&65535|0)|0;a[p]=x;x=x>>8;a[p+1|0]=x;a:do{if((c[b>>2]|0)!=0){p=f+16|0;n=0;b:do{k=c[(c[(c[p>>2]|0)+(n<<2)>>2]|0)+16>>2]|0;do{if((k|0)<5){r=7}else{if((k|0)<17){r=6;break}if((k|0)<257){r=5}else{j=-1;s=25;break b}}}while(0);k=c[g>>2]|0;c[g>>2]=k+1;a[k]=15;k=c[g>>2]|0;c[g>>2]=k+1;a[k]=18;k=c[g>>2]|0;x=256;a[k]=x;x=x>>8;a[k+1|0]=x;k=c[g>>2]|0;o=k+2|0;c[g>>2]=k+5;a[k+4|0]=n;k=c[g>>2]|0;c[g>>2]=k+1;a[k]=15;if((c[(c[(c[p>>2]|0)+(n<<2)>>2]|0)+16>>2]|0)>0){k=(1<<r|31)&255;h=0;do{m=c[g>>2]|0;c[g>>2]=m+1;a[m]=h;m=c[g>>2]|0;c[g>>2]=m+1;a[m]=k;m=c[(c[(c[(c[p>>2]|0)+(n<<2)>>2]|0)+24>>2]|0)+(h<<2)>>2]|0;q=m>>>16&255;t=m>>>8&255;u=m&255;v=c[g>>2]|0;c[g>>2]=v+1;a[v]=((u*100|0)+16896+(t*516|0)+(q*263|0)|0)>>>10;v=c[g>>2]|0;c[g>>2]=v+1;a[v]=(((u*-73|0)+511+(t*-377|0)+(q*450|0)|0)>>>10)+128;v=c[g>>2]|0;c[g>>2]=v+1;a[v]=(((u*450|0)+511+(t*-298|0)+(q*-152|0)|0)>>>10)+128;q=c[g>>2]|0;c[g>>2]=q+1;a[q]=m>>>24^255;h=h+1|0;}while((h|0)<(c[(c[(c[p>>2]|0)+(n<<2)>>2]|0)+16>>2]|0))}h=o;x=de(65534-o+(c[g>>2]|0)&65535|0)|0;a[h]=x;x=x>>8;a[h+1|0]=x;n=n+1|0;w=c[b>>2]|0;}while(n>>>0<w>>>0);if((s|0)==25){i=e;return j|0}if((w|0)==0){break}else{y=0}do{n=c[(c[(c[p>>2]|0)+(y<<2)>>2]|0)+16>>2]|0;if((n|0)<5){z=1}else{if((n|0)<17){z=2}else{j=-1;s=25;break}}n=c[g>>2]|0;c[g>>2]=n+1;a[n]=15;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=17;n=c[g>>2]|0;x=256;a[n]=x;x=x>>8;a[n+1|0]=x;n=c[g>>2]|0;h=n+2|0;k=y&255;c[g>>2]=n+5;a[n+4|0]=k;n=(c[l>>2]<<4|7)&255;m=c[g>>2]|0;c[g>>2]=m+1;a[m]=n;n=de(c[(c[(c[p>>2]|0)+(y<<2)>>2]|0)+8>>2]&65535|0)|0;m=c[g>>2]|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[g>>2]|0)+2|0;c[g>>2]=m;n=m;x=de(c[(c[(c[p>>2]|0)+(y<<2)>>2]|0)+12>>2]&65535|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;n=c[g>>2]|0;c[g>>2]=n+3;a[n+2|0]=z<<5|z<<2|3;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=k;k=c[g>>2]|0;c[g>>2]=k+1;a[k]=0;k=c[g>>2]|0;c[g>>2]=k+1;a[k]=3;k=de(y&65535|0)|0;n=c[g>>2]|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;n=c[g>>2]|0;c[g>>2]=n+3;a[n+2|0]=0;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=0;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=-16;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=0;n=h;x=de(65534-h+(c[g>>2]|0)&65535|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;y=y+1|0;A=c[b>>2]|0;}while(y>>>0<A>>>0);if((s|0)==25){i=e;return j|0}if((A|0)==0){break}else{B=0}c:while(1){n=c[(c[(c[p>>2]|0)+(B<<2)>>2]|0)+16>>2]|0;do{if((n|0)<5){C=192}else{if((n|0)<17){C=190;break}if((n|0)<257){C=188}else{j=-1;break c}}}while(0);n=c[g>>2]|0;c[g>>2]=n+1;a[n]=15;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=19;n=c[g>>2]|0;x=256;a[n]=x;x=x>>8;a[n+1|0]=x;n=c[g>>2]|0;o=n+2|0;h=n+4|0;c[g>>2]=h;n=h;x=de(B&65535|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;n=c[g>>2]|0;h=(c[l>>2]<<4|1)&255;c[g>>2]=n+3;a[n+2|0]=h;h=c[g>>2]|0;n=h+4|0;c[g>>2]=n;k=c[(c[p>>2]|0)+(B<<2)>>2]|0;m=c[k+8>>2]|0;le[C&1023](g,c[k+20>>2]|0,m<<1,m,c[k+12>>2]>>1);k=c[g>>2]|0;m=c[(c[p>>2]|0)+(B<<2)>>2]|0;q=c[m+8>>2]|0;le[C&1023](g,(c[m+20>>2]|0)+q|0,q<<1,q,c[m+12>>2]>>1);m=k;k=h;x=de(m-n&65535|0)|0;a[k]=x;x=x>>8;a[k+1|0]=x;k=h+2|0;x=de((c[g>>2]|0)-m&65535|0)|0;a[k]=x;x=x>>8;a[k+1|0]=x;k=o;x=de(65534-o+(c[g>>2]|0)&65535|0)|0;a[k]=x;x=x>>8;a[k+1|0]=x;B=B+1|0;if(!(B>>>0<(c[b>>2]|0)>>>0)){break a}}i=e;return j|0}}while(0);b=c[g>>2]|0;c[g>>2]=b+1;a[b]=15;b=c[g>>2]|0;c[g>>2]=b+1;a[b]=-128;b=c[g>>2]|0;x=256;a[b]=x;x=x>>8;a[b+1|0]=x;b=c[g>>2]|0;c[g>>2]=b+4;B=b+2|0;x=0;a[B]=x;x=x>>8;a[B+1|0]=x;c[l>>2]=(c[l>>2]|0)+1&15;j=(c[g>>2]|0)-d|0;i=e;return j|0}function H7(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;h=c[b>>2]|0;if((g|0)<=0){i=h;c[b>>2]=i;return}j=(f|0)>0;k=h;h=0;l=d;while(1){d=k+1|0;a[k]=16;do{if(j){m=d;n=0;o=6;p=0;while(1){q=a[l+p|0]|0;r=q&255;s=p;do{s=s+1|0;if((s|0)>=(f|0)){break}}while((a[l+s|0]|0)==q<<24>>24);t=s-p|0;u=q<<24>>24==0;a:do{if(u&(t|0)==2){do{if((o-2|0)<0){v=4}else{w=o-4|0;if((w|0)<0){v=6;break}x=1<<w|n;w=o-6|0;if((w|0)>=0){y=2;z=w;A=x;B=m;break a}a[m]=x;y=2;z=6;A=0;B=m+1|0;break a}}while(0);a[m]=n;y=2;z=v-2|0;A=1<<v;B=m+1|0}else{x=t-3|0;if(x>>>0<8>>>0){w=o-2|0;do{if((w|0)<0){a[m]=n;C=4;D=x>>>2<<6|128;E=18}else{F=(x>>2|2)<<w|n;G=o-4|0;if((G|0)<0){a[m]=F;C=6;D=0;E=18;break}H=F|(x&3)<<G;G=o-6|0;if((G|0)>=0){I=G;J=H;K=m;break}a[m]=H;y=t;z=4;A=r<<6;B=m+1|0;break a}}while(0);if((E|0)==18){E=0;I=C-2|0;J=(x&3)<<C|D;K=m+1|0}w=r<<I|J;H=I-2|0;if((H|0)>=0){y=t;z=H;A=w;B=K;break}a[K]=w;y=t;z=6;A=0;B=K+1|0;break}w=t-12|0;if(w>>>0<16>>>0){do{if((o-2|0)<0){L=4;E=26}else{H=o-4|0;if((H|0)<0){L=6;E=26;break}G=2<<H|n;H=o-6|0;if((H|0)>=0){M=H;N=G;O=m;E=29;break}a[m]=G;P=4;Q=w>>>2<<6;R=m;E=31}}while(0);if((E|0)==26){E=0;a[m]=n;M=L-2|0;N=2<<L;O=m+1|0;E=29}do{if((E|0)==29){E=0;x=w>>2<<M|N;G=M-2|0;if((G|0)<0){a[O]=x;P=6;Q=0;R=O;E=31;break}H=x|(w&3)<<G;G=M-4|0;if((G|0)>=0){S=G;T=H;U=O;break}a[O]=H;y=t;z=4;A=r<<6;B=O+1|0;break a}}while(0);if((E|0)==31){E=0;S=P-2|0;T=(w&3)<<P|Q;U=R+1|0}H=r<<S|T;G=S-2|0;if((G|0)>=0){y=t;z=G;A=H;B=U;break}a[U]=H;y=t;z=6;A=0;B=U+1|0;break}if((t|0)<=28){H=r<<o|n;G=o-2|0;if((G|0)<0){a[m]=H;V=6;W=0;X=m+1|0}else{V=G;W=H;X=m}if(!u){y=1;z=V;A=W;B=X;break}H=1<<V|W;G=V-2|0;if((G|0)>=0){y=1;z=G;A=H;B=X;break}a[X]=H;y=1;z=6;A=0;B=X+1|0;break}H=(t|0)>284?284:t;G=H-29|0;do{if((o-2|0)<0){Y=4;E=39}else{x=o-4|0;if((x|0)<0){Y=6;E=39;break}F=3<<x|n;x=o-6|0;if((x|0)>=0){Z=x;_=F;$=m;E=42;break}a[m]=F;aa=4;ba=G&-64;ca=m;E=44}}while(0);if((E|0)==39){E=0;a[m]=n;Z=Y-2|0;_=3<<Y;$=m+1|0;E=42}do{if((E|0)==42){E=0;w=G>>6<<Z|_;F=Z-2|0;if((F|0)<0){a[$]=w;aa=6;ba=0;ca=$;E=44;break}x=w|(G>>>4&3)<<F;F=Z-4|0;if((F|0)>=0){da=F;ea=x;fa=$;E=47;break}a[$]=x;ga=4;ha=G>>>2<<6&192;ia=$;E=49}}while(0);if((E|0)==44){E=0;da=aa-2|0;ea=(G>>>4&3)<<aa|ba;fa=ca+1|0;E=47}do{if((E|0)==47){E=0;x=(G>>>2&3)<<da|ea;F=da-2|0;if((F|0)<0){a[fa]=x;ga=6;ha=0;ia=fa;E=49;break}w=x|(G&3)<<F;F=da-4|0;if((F|0)>=0){ja=F;ka=w;la=fa;break}a[fa]=w;y=H;z=4;A=r<<6;B=fa+1|0;break a}}while(0);if((E|0)==49){E=0;ja=ga-2|0;ka=(G&3)<<ga|ha;la=ia+1|0}w=r<<ja|ka;F=ja-2|0;if((F|0)>=0){y=H;z=F;A=w;B=la;break}a[la]=w;y=H;z=6;A=0;B=la+1|0}}while(0);r=y+p|0;if((r|0)<(f|0)){m=B;n=A;o=z;p=r}else{break}}p=A&255;if((z-2|z-4|0)<0){a[B]=p;ma=B+1|0;na=0;E=65;break}o=z-6|0;if((o|0)<0){a[B]=p;oa=B+1|0;break}else{if((o|0)==6){oa=B;break}else{ma=B;na=p;E=65;break}}}else{ma=d;na=0;E=65}}while(0);if((E|0)==65){E=0;a[ma]=na;oa=ma+1|0}d=oa+1|0;a[oa]=-16;p=h+1|0;if((p|0)<(g|0)){k=d;h=p;l=l+e|0}else{i=d;break}}c[b>>2]=i;return}function I7(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;h=c[b>>2]|0;if((g|0)<=0){i=h;c[b>>2]=i;return}j=(f|0)>0;k=0;l=h;h=d;while(1){d=l+1|0;a[l]=17;do{if(j){m=0;n=4;o=0;p=d;while(1){q=a[h+o|0]|0;r=q&255;s=o;do{s=s+1|0;if((s|0)>=(f|0)){break}}while((a[h+s|0]|0)==q<<24>>24);t=s-o|0;u=q<<24>>24==0;a:do{if(u&(t|0)==2){v=n-4|0;if((v|0)<0){a[p]=m;w=p+1|0;x=2;y=0;z=208;break}A=13<<v|m;v=n-8|0;if((v|0)>=0){w=p;x=2;y=v;z=A;break}a[p]=A;w=p+1|0;x=2;y=4;z=0}else{do{if(u){if(!((t-3|0)>>>0<7>>>0)){break}A=n-4|0;if((A|0)<0){a[p]=m;w=p+1|0;x=t;y=0;z=(t<<4)-32|0;break a}v=t-2<<A|m;A=n-8|0;if((A|0)>=0){w=p;x=t;y=A;z=v;break a}a[p]=v;w=p+1|0;x=t;y=4;z=0;break a}}while(0);if((t-4|0)>>>0<4>>>0){v=n-4|0;do{if((v|0)<0){a[p]=m;B=p+1|0;C=((t<<4)+64|r)&255}else{A=t+4<<v|m;D=n-8|0;if((D|0)<0){a[p]=A;w=p+1|0;x=t;y=0;z=r<<4;break a}else{E=A|r<<D;D=n-12|0;if((D|0)<0){B=p;C=E&255;break}else{w=p;x=t;y=D;z=E;break a}}}}while(0);a[B]=C;w=B+1|0;x=t;y=4;z=0;break}v=t-9|0;if(v>>>0<16>>>0){E=n-4|0;do{if((E|0)<0){a[p]=m;F=p+1|0;G=(t+23|224)&255}else{D=14<<E|m;A=n-8|0;if((A|0)<0){a[p]=D;H=p+1|0;I=((t<<4)+112|r)&255}else{J=v<<A|D;D=n-12|0;if((D|0)<0){F=p;G=J&255;break}A=J|r<<D;D=n-16|0;if((D|0)<0){H=p;I=A&255}else{w=p;x=t;y=D;z=A;break a}}a[H]=I;w=H+1|0;x=t;y=4;z=0;break a}}while(0);a[F]=G;w=F+1|0;x=t;y=0;z=r<<4;break}if((t|0)<=24){v=r<<n|m;E=n-4|0;if((E|0)<0){a[p]=v;K=p+1|0;L=4;M=0}else{K=p;L=E;M=v}if(!u){w=K;x=1;y=L;z=M;break}v=12<<L|M;E=L-4|0;if((E|0)>=0){w=K;x=1;y=E;z=v;break}a[K]=v;w=K+1|0;x=1;y=4;z=0;break}v=(t|0)>280?280:t;E=v-25|0;A=n-4|0;b:do{if((A|0)<0){a[p]=m;N=p+1|0;O=(E>>>4|240)&255;P=40}else{D=15<<A|m;J=n-8|0;do{if((J|0)<0){a[p]=D;Q=p+1|0;R=E&255}else{S=E>>4<<J|D;T=n-12|0;if((T|0)<0){N=p;O=S&255;P=40;break b}U=S|(E&15)<<T;T=n-16|0;if((T|0)<0){Q=p;R=U&255;break}S=U|r<<T;T=n-20|0;if((T|0)<0){V=p;W=S&255;break b}else{w=p;x=v;y=T;z=S;break a}}}while(0);a[Q]=R;w=Q+1|0;x=v;y=0;z=r<<4;break a}}while(0);if((P|0)==40){P=0;a[N]=O;V=N+1|0;W=(E<<4|r)&255}a[V]=W;w=V+1|0;x=v;y=4;z=0}}while(0);r=x+o|0;if((r|0)<(f|0)){m=z;n=y;o=r;p=w}else{break}}p=z&255;if((y-4|0)<0){a[w]=p;X=0;Y=w+1|0}else{o=y-8|0;if((o|0)<0){Z=p;_=w;P=54;break}if((o|0)==4){$=w;break}else{X=p;Y=w}}a[Y]=X;$=Y+1|0}else{Z=0;_=d;P=54}}while(0);if((P|0)==54){P=0;a[_]=Z;$=_+1|0}d=$+1|0;a[$]=-16;p=k+1|0;if((p|0)<(g|0)){k=p;l=d;h=h+e|0}else{i=d;break}}c[b>>2]=i;return}function J7(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=c[b>>2]|0;if((g|0)<=0){i=h;c[b>>2]=i;return}if((f|0)>0){j=h;k=0;l=d}else{d=g*3|0;m=h;n=0;while(1){a[m]=18;a[m+1|0]=0;a[m+2|0]=0;o=n+1|0;if((o|0)<(g|0)){m=m+3|0;n=o}else{break}}i=h+d|0;c[b>>2]=i;return}while(1){a[j]=18;d=j+1|0;h=0;while(1){n=a[l+h|0]|0;m=h;do{m=m+1|0;if((m|0)>=(f|0)){break}}while((a[l+m|0]|0)==n<<24>>24);o=m-h|0;p=n<<24>>24==0;do{if((o|0)!=1|p){if(p){q=(o|0)>127?127:o;a[d]=0;a[d+1|0]=q;r=q;s=d+2|0;break}if((o|0)>2){q=(o|0)>127?127:o;a[d]=0;a[d+1|0]=q+128;a[d+2|0]=n;r=q;s=d+3|0;break}q=d+1|0;a[d]=n;if((o|0)!=2){r=1;s=q;break}a[q]=n;r=2;s=d+2|0}else{a[d]=n;r=1;s=d+1|0}}while(0);n=r+h|0;if((n|0)<(f|0)){d=s;h=n}else{break}}a[s]=0;h=s+2|0;a[s+1|0]=0;d=k+1|0;if((d|0)<(g|0)){j=h;k=d;l=l+e|0}else{i=h;break}}c[b>>2]=i;return}function K7(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;e=c[a+60>>2]|0;f=a+96|0;g=c[f>>2]|0;do{if((g|0)==0){h=4}else{j=c[a+100>>2]|0;if((j|0)<4){h=4;break}if(!(((j|0)%5|0|0)==0|(j|0)==4)){h=4;break}if((j|0)>5){yDb(a,24,2309016,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=c[f>>2]|0}else{l=g}j=l;c[e>>2]=(de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535;j=l+2|0;c[e+4>>2]=(de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535}}while(0);if((h|0)==4){yDb(a,24,2333568,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;c[e>>2]=-1;c[e+4>>2]=-1}c[e+8>>2]=-1;c[2149460]=-1;c[2149738]=0;c[2149462]=0;c[2149463]=-1;c[2149464]=-16777216;c[2149465]=-8421505;c[2149466]=0;e=1;do{k=(e&1|0)!=0;if((e|0)<8){m=(e&4|0)!=0?255:0;n=(e&2|0)!=0?255:0;o=k?255:0}else{m=(e&4|0)!=0?127:0;n=(e&2|0)!=0?127:0;o=k?127:0}c[8597864+(e<<2)>>2]=o<<16|n<<8|m|-16777216;e=e+1|0;}while((e|0)<16);c[2149482]=0;e=o;o=n;n=m;m=0;k=1;while(1){do{if((k|0)<8){p=63;q=(k&4|0)!=0?255:0;r=(k&2|0)!=0?255:0;s=(k&1|0)!=0?255:0}else{a=k&136;if((a|0)==136){p=255;q=((k&4|0)!=0?43:0)+((k&64|0)!=0?85:0)|0;r=((k&2|0)!=0?43:0)+((k&32|0)!=0?85:0)|0;s=((k&1|0)!=0?43:0)+((k&16|0)!=0?85:0)|0;break}else if((a|0)==8){p=127;q=((k&4|0)!=0?85:0)|((k&64|0)!=0?170:0);r=((k&2|0)!=0?85:0)|((k&32|0)!=0?170:0);s=((k&1|0)!=0?85:0)|((k&16|0)!=0?170:0);break}else if((a|0)==0){p=255;q=((k&4|0)!=0?85:0)|((k&64|0)!=0?170:0);r=((k&2|0)!=0?85:0)|((k&32|0)!=0?170:0);s=((k&1|0)!=0?85:0)|((k&16|0)!=0?170:0);break}else if((a|0)==128){p=255;q=((k&4|0)!=0?170:127)+((k&64|0)!=0?85:0)|0;r=((k&2|0)!=0?170:127)+((k&32|0)!=0?85:0)|0;s=((k&1|0)!=0?170:127)+((k&16|0)!=0?85:0)|0;break}else{p=m;q=n;r=o;s=e;break}}}while(0);c[8597928+(k<<2)>>2]=r<<8|s<<16|q|p<<24;a=k+1|0;if((a|0)<256){e=s;o=r;n=q;m=p;k=a}else{break}}i=b;return 0}function L7(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;h=i;i=i+8|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=b+60|0;m=c[g>>2]|0;n=e;if((l|0)<7){o=-1;i=h;return o|0}if((a[k]|0)!=15){o=-1;i=h;return o|0}p=k+l|0;l=k;q=m;r=b;s=b+680|0;t=b+120|0;u=b+124|0;v=m+4|0;m=k;k=0;w=l;x=1;a:while(1){if(!x){y=k;z=w;A=126;break}B=d[m+1|0]|0;C=m+2|0;D=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=m+4|0;E=(d[C]|d[C+1|0]<<8)<<16>>16;C=de(E|0)|0;F=C&65535;G=m+6|0;if((p-G|0)<(F|0)){o=-1;A=129;break}H=c[q>>2]|0;if((D|0)==(H|0)){A=8}else{I=c[v>>2]|0;if((D|0)==(I|0)|(H|0)==-1|(I|0)==-1){A=8}else{J=k}}b:do{if((A|0)==8){A=0;switch(B|0){case 128:{N7(c[g>>2]|0,n);c[f>>2]=1;J=k|16;break b;break};case 18:{I=m+(F+6)|0;H=d[G]|0;D=(d[m+7|0]|0)>>>4;K=m+8|0;L=(c[g>>2]|0)+20|0;M=L;while(1){N=c[M>>2]|0;if((N|0)==0){A=83;break}if((c[N>>2]|0)==(H|0)){O=N;break}else{M=N+1112|0}}if((A|0)==83){A=0;M=WDb(1116)|0;N=M;UGb(M|0,8597840,1116)|0;c[M>>2]=H;c[M+4>>2]=-1;c[M+1112>>2]=c[L>>2];c[L>>2]=N;O=N}N=O+4|0;c:do{if((c[N>>2]|0)!=(D|0)){c[N>>2]=D;if(!((C&65535)>>>0>6>>>0)){break}M=K;P=m+12|0;while(1){Q=d[M]|0;R=d[M+1|0]|0;if((R&224|0)==0){break}S=M+2|0;if((R&1|0)==0){T=d[S]|0;U=d[M+3|0]|0;V=P;W=T&252;X=(T<<2&12|U>>>6)<<4;Y=U<<6&192;Z=U<<2&240}else{V=M+6|0;W=d[S]|0;X=d[M+3|0]|0;Y=d[M+5|0]|0;Z=d[P]|0}S=(W|0)==0?255:Y;U=Z-128|0;T=X-128|0;_=(W*1192|0)-19072|0;$=d[((T*1634|0)+512+_>>10)+1236056|0]|0;aa=d[((U*-401|0)+512+(T*-832|0)+_>>10)+1236056|0]|0;T=d[((U*2066|0)+512+_>>10)+1236056|0]|0;_=(R&128|0)==0;U=R&64;ca=(U|0)==0;da=R&32;ea=(da|0)==0;if(((U>>>6)+(R>>>7)+(da>>>5)|0)>1){if((c[s>>2]|0)>0){o=-1094995529;A=129;break a}}do{if(_){if(!ca){c[O+24+(Q<<2)>>2]=($<<16|S<<24|aa<<8|T)^-16777216;break}if(ea){break}c[O+88+(Q<<2)>>2]=($<<16|S<<24|aa<<8|T)^-16777216}else{c[O+8+(Q<<2)>>2]=($<<16|S<<24|aa<<8|T)^-16777216}}while(0);T=V+4|0;if(T>>>0<I>>>0){M=V;P=T}else{break c}}yDb(r,16,1896440,(fa=i,i=i+8|0,c[fa>>2]=R,fa)|0);i=fa}}while(0);J=k|4;break b;break};case 20:{I=(c[g>>2]|0)+32|0;K=c[I>>2]|0;if((C&65535)>>>0<5>>>0){J=k;break b}D=m+7|0;N=d[G]|0;L=N>>>4;if((K|0)==0){H=cEb(20)|0;P=H;c[I>>2]=P;if((H|0)==0){J=k;break b}else{ga=P}}else{if((c[K>>2]|0)==(L|0)){J=k;break b}else{ga=K}}c[ga>>2]=L;L=ga+4|0;c[L>>2]=0;K=ga+8|0;c[K>>2]=0;P=D;D=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+1|0;P=ga+12|0;c[P>>2]=D;H=m+11|0;I=m+9|0;M=ga+16|0;c[M>>2]=((de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)+1;if((c[t>>2]|0)==0){A=119}else{if((c[u>>2]|0)==0){A=119}}if((A|0)==119){A=0;c[t>>2]=D;c[u>>2]=c[M>>2]}if((C&65535)>>>0<13>>>0){J=k;break b}if((N&8|0)==0){J=k;break b}N=H;H=(de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535;c[L>>2]=H;L=m+13|0;c[P>>2]=1-H+((de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535);L=m+15|0;H=(de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535;c[K>>2]=H;K=m+17|0;c[M>>2]=1-H+((de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535);J=k;break b;break};case 16:{K=c[g>>2]|0;H=m+(F+6)|0;do{if(!(E<<16>>16==0)){M=d[m+7|0]|0;L=M>>>4;P=K+8|0;if((c[P>>2]|0)==(L|0)){break}c[K+12>>2]=d[G]|0;c[P>>2]=L;do{if(((M>>>2&3)-1|0)>>>0<2>>>0){L=K+16|0;P=c[L>>2]|0;N=K+24|0;if((P|0)!=0){D=P;do{c[L>>2]=c[D+44>>2];P=D+40|0;I=c[P>>2]|0;if((I|0)!=0){T=I;do{I=c[T>>2]|0;aa=N;while(1){ha=c[aa>>2]|0;if((ha|0)==0){break}if((c[ha>>2]|0)==(I|0)){A=17;break}else{aa=ha+16|0}}do{if((A|0)==17){A=0;aa=ha+12|0;I=aa;while(1){S=c[I>>2]|0;ia=(S|0)!=0;ja=S+28|0;if(ia&(S|0)!=(T|0)){I=ja}else{break}}if(!ia){break}c[I>>2]=c[ja>>2];if((c[aa>>2]|0)==0){ka=N}else{break}while(1){S=c[ka>>2]|0;la=S+16|0;if((S|0)==(ha|0)){break}else{ka=la}}c[ka>>2]=c[la>>2];ZDb(ha)}}while(0);c[P>>2]=c[T+24>>2];ZDb(T);T=c[P>>2]|0;}while((T|0)!=0)}ZDb(c[D+28>>2]|0);ZDb(D);D=c[L>>2]|0;}while((D|0)!=0)}D=c[N>>2]|0;if((D|0)!=0){L=D;do{c[N>>2]=c[L+16>>2];ZDb(L);L=c[N>>2]|0;}while((L|0)!=0)}L=K+20|0;N=c[L>>2]|0;if((N|0)==0){break}else{ma=N}do{c[L>>2]=c[ma+1112>>2];ZDb(ma);ma=c[L>>2]|0;}while((ma|0)!=0)}}while(0);M=K+28|0;L=c[M>>2]|0;c[j>>2]=L;c[M>>2]=0;if((C&65535)>>>0>7>>>0){N=G;while(1){D=d[N+2|0]|0;T=N+4|0;P=j;while(1){aa=c[P>>2]|0;if((aa|0)==0){A=36;break}if((c[aa>>2]|0)==(D|0)){na=aa;break}P=aa+12|0}if((A|0)==36){A=0;na=cEb(16)|0}c[na>>2]=D;aa=T;c[na+4>>2]=(de((d[aa]|d[aa+1|0]<<8)<<16>>16|0)|0)&65535;aa=N+6|0;I=aa;c[na+8>>2]=(de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535;I=na+12|0;c[P>>2]=c[I>>2];c[I>>2]=c[M>>2];c[M>>2]=na;if((N+13|0)>>>0<H>>>0){N=aa}else{break}}oa=c[j>>2]|0}else{oa=L}if((oa|0)==0){break}else{pa=oa}while(1){N=c[pa+12>>2]|0;ZDb(pa);if((N|0)==0){break}else{pa=N}}c[j>>2]=0}}while(0);J=k|1;break b;break};case 19:{H=c[g>>2]|0;K=G;L=(de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535;K=H+24|0;while(1){qa=c[K>>2]|0;if((qa|0)==0){break}if((c[qa>>2]|0)==(L|0)){A=105;break}else{K=qa+16|0}}do{if((A|0)==105){A=0;K=d[m+8|0]|0;L=K>>>2&3;H=K>>>1&1;if((L|0)!=0){yDb(r,16,2112544,(fa=i,i=i+8|0,c[fa>>2]=L,fa)|0);i=fa;break}L=m+9|0;K=(de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535;L=m+11|0;N=(d[L]|d[L+1|0]<<8)<<16>>16;L=(de(N|0)|0)&65535;M=m+13|0;if((K+7+L|0)>(F|0)){yDb(r,16,2189816,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;break}aa=c[qa+12>>2]|0;if((aa|0)==0){break}I=N<<16>>16==0;N=I?M:m+(K+13)|0;S=I?K:L;L=aa;do{O7(b,L,M,K,0,H);O7(b,L,N,S,1,H);L=c[L+28>>2]|0;}while((L|0)!=0)}}while(0);J=k|8;break b;break};case 17:{L=c[g>>2]|0;H=m+(F+6)|0;do{if(!((C&65535)>>>0<10>>>0)){S=m+7|0;N=d[G]|0;K=L+16|0;M=K;while(1){aa=c[M>>2]|0;if((aa|0)==0){A=45;break}if((c[aa>>2]|0)==(N|0)){ra=aa;break}else{M=aa+44|0}}if((A|0)==45){A=0;M=cEb(48)|0;aa=M;c[M>>2]=N;c[M+4>>2]=-1;c[M+44>>2]=c[K>>2];c[K>>2]=aa;ra=aa}aa=(d[S]|0)>>>3&1;M=m+8|0;I=(de((d[M]|d[M+1|0]<<8)<<16>>16|0)|0)&65535;M=ra+8|0;c[M>>2]=I;$=m+10|0;Q=(de((d[$]|d[$+1|0]<<8)<<16>>16|0)|0)&65535;$=ra+12|0;c[$>>2]=Q;ea=ba(Q,I)|0;I=ra+32|0;if((ea|0)==(c[I>>2]|0)){sa=aa}else{aa=ra+28|0;ZDb(c[aa>>2]|0);ea=ba(c[$>>2]|0,c[M>>2]|0)|0;c[I>>2]=ea;c[aa>>2]=WDb(ea)|0;c[ra+36>>2]=0;sa=1}ea=m+13|0;aa=1<<((d[m+12|0]|0)>>>2&7);M=ra+16|0;c[M>>2]=aa;do{if((aa-2|0)>>>0>6>>>0){yDb(r,16,2353640,(fa=i,i=i+8|0,c[fa>>2]=aa,fa)|0);i=fa;c[M>>2]=4;c[ra+20>>2]=d[ea]|0;ta=m+16|0;ua=d[m+15|0]|0;A=53}else{c[ra+20>>2]=d[ea]|0;if((aa|0)==8){$=a[m+14|0]|0;c[ra+24>>2]=$&255;va=m+16|0;wa=$;break}$=m+16|0;Q=d[m+15|0]|0;if((aa|0)==4){ta=$;ua=Q;A=53;break}ca=Q>>>2&3;c[ra+24>>2]=ca;va=$;wa=ca&255}}while(0);if((A|0)==53){A=0;aa=ua>>>4;c[ra+24>>2]=aa;va=ta;wa=aa&255}if((sa|0)!=0){TGb(c[ra+28>>2]|0,wa|0,c[I>>2]|0)|0}aa=ra+40|0;ea=c[aa>>2]|0;if((ea|0)!=0){M=L+24|0;S=ea;do{ea=c[S>>2]|0;K=M;while(1){xa=c[K>>2]|0;if((xa|0)==0){break}if((c[xa>>2]|0)==(ea|0)){A=62;break}else{K=xa+16|0}}do{if((A|0)==62){A=0;K=xa+12|0;ea=K;while(1){P=c[ea>>2]|0;ya=(P|0)!=0;za=P+28|0;if(ya&(P|0)!=(S|0)){ea=za}else{break}}if(!ya){break}c[ea>>2]=c[za>>2];if((c[K>>2]|0)==0){Aa=M}else{break}while(1){P=c[Aa>>2]|0;Ba=P+16|0;if((P|0)==(xa|0)){break}else{Aa=Ba}}c[Aa>>2]=c[Ba>>2];ZDb(xa)}}while(0);c[aa>>2]=c[S+24>>2];ZDb(S);S=c[aa>>2]|0;}while((S|0)!=0)}if(!((va+5|0)>>>0<H>>>0)){break}S=L+24|0;M=va;while(1){I=M;K=(de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535;I=M+2|0;ea=S;while(1){P=c[ea>>2]|0;if((P|0)==0){A=74;break}if((c[P>>2]|0)==(K|0)){Ca=P;break}else{ea=P+16|0}}if((A|0)==74){A=0;ea=cEb(20)|0;P=ea;c[ea>>2]=K;c[ea+16>>2]=c[S>>2];c[S>>2]=P;Ca=P}P=Ca+8|0;c[P>>2]=(d[I]|0)>>>6;ea=cEb(32)|0;T=ea;c[ea>>2]=K;c[ea+4>>2]=N;D=I;c[ea+8>>2]=(de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&4095;D=M+4|0;c[ea+12>>2]=(de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&4095;D=M+6|0;do{if(((c[P>>2]|0)-1|0)>>>0<2>>>0){ca=M+7|0;if(!(ca>>>0<H>>>0)){Da=D;break}c[ea+16>>2]=d[D]|0;c[ea+20>>2]=d[ca]|0;Da=M+8|0}else{Da=D}}while(0);c[ea+24>>2]=c[aa>>2];c[aa>>2]=T;D=Ca+12|0;c[ea+28>>2]=c[D>>2];c[D>>2]=T;if((Da+5|0)>>>0<H>>>0){M=Da}else{break}}}}while(0);J=k|2;break b;break};default:{J=k;break b}}}}while(0);G=m+(F+6)|0;C=G;if((p-C|0)<=5){y=J;z=C;A=126;break}m=G;k=J;w=C;x=(a[G]|0)==15}if((A|0)==126){if(!((y|0)!=15|(e|0)==0)){N7(c[g>>2]|0,n);c[f>>2]=1}o=z-l|0;i=h;return o|0}else if((A|0)==129){i=h;return o|0}return 0}function M7(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[a+60>>2]|0;a=b+16|0;d=c[a>>2]|0;e=b+24|0;if((d|0)!=0){f=d;do{c[a>>2]=c[f+44>>2];d=f+40|0;g=c[d>>2]|0;if((g|0)!=0){h=g;do{g=c[h>>2]|0;i=e;while(1){j=c[i>>2]|0;if((j|0)==0){break}if((c[j>>2]|0)==(g|0)){k=6;break}else{i=j+16|0}}do{if((k|0)==6){k=0;i=j+12|0;g=i;while(1){l=c[g>>2]|0;m=(l|0)!=0;n=l+28|0;if(m&(l|0)!=(h|0)){g=n}else{break}}if(!m){break}c[g>>2]=c[n>>2];if((c[i>>2]|0)==0){o=e}else{break}while(1){l=c[o>>2]|0;p=l+16|0;if((l|0)==(j|0)){break}else{o=p}}c[o>>2]=c[p>>2];ZDb(j)}}while(0);c[d>>2]=c[h+24>>2];ZDb(h);h=c[d>>2]|0;}while((h|0)!=0)}ZDb(c[f+28>>2]|0);ZDb(f);f=c[a>>2]|0;}while((f|0)!=0)}f=c[e>>2]|0;if((f|0)!=0){a=f;do{c[e>>2]=c[a+16>>2];ZDb(a);a=c[e>>2]|0;}while((a|0)!=0)}a=b+20|0;e=c[a>>2]|0;if((e|0)!=0){f=e;do{c[a>>2]=c[f+1112>>2];ZDb(f);f=c[a>>2]|0;}while((f|0)!=0)}$Db(b+32|0);f=b+28|0;b=c[f>>2]|0;if((b|0)==0){return 0}else{q=b}do{c[f>>2]=c[q+12>>2];ZDb(q);q=c[f>>2]|0;}while((q|0)!=0);return 0}function N7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[a+32>>2]|0;c[b+8>>2]=(c[a+12>>2]|0)*1e3|0;if((d|0)==0){e=0;f=0}else{e=c[d+8>>2]|0;f=c[d+4>>2]|0}d=b+12|0;c[d>>2]=0;g=a+28|0;h=c[g>>2]|0;if((h|0)==0){return}i=a+16|0;j=h;h=0;while(1){k=c[j>>2]|0;l=i;while(1){m=c[l>>2]|0;if((m|0)==0){n=h;break}if((c[m>>2]|0)==(k|0)){o=8;break}else{l=m+44|0}}do{if((o|0)==8){o=0;if((c[m+36>>2]|0)==0){n=h;break}l=h+1|0;c[d>>2]=l;n=l}}while(0);l=c[j+12>>2]|0;if((l|0)==0){break}else{j=l;h=n}}if((n|0)==0){return}h=b+16|0;c[h>>2]=cEb(n<<2)|0;if((c[d>>2]|0)!=0){n=0;do{b=cEb(100)|0;c[(c[h>>2]|0)+(n<<2)>>2]=b;n=n+1|0;}while(n>>>0<(c[d>>2]|0)>>>0)}d=c[g>>2]|0;if((d|0)==0){return}g=a+16|0;n=a+20|0;a=0;b=d;while(1){d=c[b>>2]|0;j=g;while(1){p=c[j>>2]|0;if((p|0)==0){q=a;break}if((c[p>>2]|0)==(d|0)){o=19;break}else{j=p+44|0}}do{if((o|0)==19){o=0;if((c[p+36>>2]|0)==0){q=a;break}j=c[(c[h>>2]|0)+(a<<2)>>2]|0;c[j>>2]=(c[b+4>>2]|0)+f;c[j+4>>2]=(c[b+8>>2]|0)+e;d=p+8|0;c[j+8>>2]=c[d>>2];c[j+12>>2]=c[p+12>>2];m=p+16|0;c[j+16>>2]=1<<c[m>>2];c[j+84>>2]=1;c[j+52>>2]=c[d>>2];d=c[p+20>>2]|0;i=n;while(1){l=c[i>>2]|0;if((l|0)==0){r=0;break}if((c[l>>2]|0)==(d|0)){r=l;break}else{i=l+1112|0}}i=(r|0)==0?8597840:r;d=c[m>>2]|0;if((d|0)==2){s=i+8|0}else if((d|0)==8){s=i+88|0}else{s=i+24|0}i=cEb(1024)|0;c[j+24>>2]=i;UGb(i|0,s|0,4<<c[m>>2])|0;i=p+32|0;d=WDb(c[i>>2]|0)|0;c[j+20>>2]=d;UGb(d|0,c[p+28>>2]|0,c[i>>2]|0)|0;q=a+1|0}}while(0);i=c[b+12>>2]|0;if((i|0)==0){break}else{a=q;b=i}}return}function O7(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;k=i;i=i+8|0;l=k|0;m=l;n=i;i=i+4|0;i=i+7&-8;o=n;p=n;q=i;i=i+16|0;r=c[e+4>>2]|0;s=(c[b+60>>2]|0)+16|0;while(1){t=c[s>>2]|0;if((t|0)==0){u=0;break}if((c[t>>2]|0)==(r|0)){u=t;break}else{s=t+44|0}}s=f+g|0;c[l>>2]=252184320;c[n>>2]=-7833856;r=q|0;UGb(r|0,1345416,16)|0;if((u|0)==0){i=k;return}t=c[u+28>>2]|0;c[u+36>>2]=1;v=e+8|0;if((g|0)<=0){i=k;return}g=u+12|0;w=b;b=u+16|0;x=u+8|0;u=s;y=(j|0)==1;j=l;l=m+1|0;z=m+2|0;A=m+3|0;m=f;f=c[v>>2]|0;B=(c[e+12>>2]|0)+h|0;a:while(1){C=a[m]|0;if(!(C<<24>>24==-16)){D=c[x>>2]|0;if((f|0)>=(D|0)){E=9;break}}F=c[g>>2]|0;if((B|0)>=(F|0)){E=11;break}h=m+1|0;e=C&255;b:do{switch(e|0){case 18:{G=c[b>>2]|0;if((G|0)<8){E=109;break a}H=c[x>>2]|0;I=u-h|0;J=m+(I+1)|0;K=t+((ba(H,B)|0)+f)|0;L=m+2|0;M=a[h]|0;N=M<<24>>24==0;c:do{if((I|0)>0&(f|0)<(H|0)){if(y){O=K;P=f;Q=h;R=L;S=M;T=N}else{U=K;V=f;W=h;X=L;Y=M;Z=N;while(1){do{if(Z){_=W+2|0;$=a[X]|0;aa=$&255;ca=aa&127;if((aa&128|0)!=0){aa=W+3|0;if(!((ca|0)!=0&(V|0)<(H|0))){da=V;ea=U;fa=aa;break}ga=V-H|0;ha=$&127;ia=-ha|0;ja=~(((ia|0)>-1?ia:-1)+ha);ha=ga>>>0>ja>>>0?ga:ja;ja=-ha|0;TGb(U|0,a[_]|0,ja|0)|0;da=V-ha|0;ea=U+ja|0;fa=aa;break}if((ca|0)==0){ka=B;la=V;ma=_;break b}if((V|0)>=(H|0)){da=V;ea=U;fa=_;break}ca=V-H|0;aa=$&127;$=-aa|0;ja=~((($|0)>-1?$:-1)+aa);aa=ca>>>0>ja>>>0?ca:ja;ja=-aa|0;TGb(U|0,0,ja|0)|0;da=V-aa|0;ea=U+ja|0;fa=_}else{a[U]=Y;da=V+1|0;ea=U+1|0;fa=X}}while(0);_=fa+1|0;ja=a[fa]|0;aa=ja<<24>>24==0;if(fa>>>0<J>>>0&(da|0)<(H|0)){U=ea;V=da;W=fa;X=_;Y=ja;Z=aa}else{na=da;oa=aa;pa=_;break c}}}while(1){do{if(T){Z=Q+2|0;Y=a[R]|0;X=Y&255;W=X&127;if((X&128|0)!=0){X=Q+3|0;V=a[Z]|0;U=V<<24>>24==1?W:0;_=U+P|0;if(!((W|0)!=0&(_|0)<(H|0))){qa=_;ra=O;sa=X;break}aa=U-H+P|0;U=Y&127;ja=-U|0;ca=~(((ja|0)>-1?ja:-1)+U);U=aa>>>0>ca>>>0?aa:ca;ca=-U|0;TGb(O|0,V|0,ca|0)|0;qa=_-U|0;ra=O+ca|0;sa=X;break}if((W|0)==0){ka=B;la=P;ma=Z;break b}if((P|0)>=(H|0)){qa=P;ra=O;sa=Z;break}W=P-H|0;X=Y&127;Y=-X|0;ca=~(((Y|0)>-1?Y:-1)+X);X=W>>>0>ca>>>0?W:ca;ca=-X|0;TGb(O|0,0,ca|0)|0;qa=P-X|0;ra=O+ca|0;sa=Z}else{if(S<<24>>24==1){ta=O}else{a[O]=S;ta=O+1|0}qa=P+1|0;ra=ta;sa=R}}while(0);Z=sa+1|0;ca=a[sa]|0;X=ca<<24>>24==0;if(sa>>>0<J>>>0&(qa|0)<(H|0)){O=ra;P=qa;Q=sa;R=Z;S=ca;T=X}else{na=qa;oa=X;pa=Z;break}}}else{na=f;oa=N;pa=L}}while(0);if(oa){ka=B;la=na;ma=pa;break b}yDb(0,16,1917136,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;ka=B;la=na;ma=pa;break};case 16:{L=c[b>>2]|0;if((L|0)==4){va=j}else if((L|0)==8){va=o}else{va=0}L=c[x>>2]|0;N=u-h<<3;H=N>>>0>2147483639>>>0|(h|0)==0;J=H?0:h;M=H?8:N+8|0;H=J;K=fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0;d:do{if((N|0)>0&(f|0)<(L|0)){H=(va|0)==0;I=0;Z=t+((ba(L,B)|0)+f)|0;X=f;ca=K;e:while(1){W=ca>>>30;Y=I+2|0;U=M>>>0>Y>>>0?Y:M;do{if((W|0)==0){Y=((U|0)<(M|0))+U|0;_=J+(Y>>>3)|0;if(((d[J+(U>>>3)|0]|0)&128>>>((U&7)>>>0)|0)!=0){V=_;aa=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Y&7)>>>29;V=Y+3|0;ja=M>>>0>V>>>0?V:M;V=J+(ja>>>3)|0;$=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(ja&7)>>>30;V=ja+2|0;ja=M>>>0>V>>>0?V:M;if(y&($|0)==1){wa=X+3+aa|0;xa=Z;ya=ja;break}if(H){za=$&255}else{za=a[va+$|0]|0}if((X|0)>=(L|0)){wa=X;xa=Z;ya=ja;break}$=X-L|0;V=-3-aa|0;ha=((V|0)>-1?-4-V|0:-3)-aa|0;aa=$>>>0>ha>>>0?$:ha;ha=-aa|0;TGb(Z|0,za|0,ha|0)|0;wa=X-aa|0;xa=Z+ha|0;ya=ja;break}ja=((Y|0)<(M|0))+Y|0;if(((d[_]|0)&128>>>((Y&7)>>>0)|0)!=0){if(H){Aa=0}else{Aa=a[va]|0}a[Z]=Aa;wa=X+1|0;xa=Z+1|0;ya=ja;break}Y=J+(ja>>>3)|0;_=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(ja&7)>>>30;Y=ja+2|0;Ba=M>>>0>Y>>>0?Y:M;if((_|0)==3){Y=J+(Ba>>>3)|0;ja=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(Ba&7)>>>24;Y=Ba+8|0;ha=M>>>0>Y>>>0?Y:M;Y=J+(ha>>>3)|0;aa=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(ha&7)>>>30;Y=ha+2|0;ha=M>>>0>Y>>>0?Y:M;if(y&(aa|0)==1){wa=X+29+ja|0;xa=Z;ya=ha;break}if(H){Ca=aa&255}else{Ca=a[va+aa|0]|0}if((X|0)>=(L|0)){wa=X;xa=Z;ya=ha;break}aa=X-L|0;Y=-29-ja|0;$=((Y|0)>-1?-30-Y|0:-29)-ja|0;ja=aa>>>0>$>>>0?aa:$;$=-ja|0;TGb(Z|0,Ca|0,$|0)|0;wa=X-ja|0;xa=Z+$|0;ya=ha;break}else if((_|0)==1){if(H){Da=0}else{Da=a[va]|0}if((X|0)>=(L|0)){wa=X;xa=Z;ya=Ba;break}ha=(X-L|0)==-1?-1:-2;$=-ha|0;TGb(Z|0,Da|0,$|0)|0;wa=X-ha|0;xa=Z+$|0;ya=Ba;break}else if((_|0)==2){_=J+(Ba>>>3)|0;$=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Ba&7)>>>28;_=Ba+4|0;ha=M>>>0>_>>>0?_:M;_=J+(ha>>>3)|0;ja=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(ha&7)>>>30;_=ha+2|0;ha=M>>>0>_>>>0?_:M;if(y&(ja|0)==1){wa=X+12+$|0;xa=Z;ya=ha;break}if(H){Ea=ja&255}else{Ea=a[va+ja|0]|0}if((X|0)>=(L|0)){wa=X;xa=Z;ya=ha;break}ja=X-L|0;_=-12-$|0;aa=((_|0)>-1?-13-_|0:-12)-$|0;$=ja>>>0>aa>>>0?ja:aa;aa=-$|0;TGb(Z|0,Ea|0,aa|0)|0;wa=X-$|0;xa=Z+aa|0;ya=ha;break}else{break e}}else{do{if(y&(W|0)==1){Fa=Z}else{if(H){a[Z]=W;Fa=Z+1|0;break}else{a[Z]=a[va+W|0]|0;Fa=Z+1|0;break}}}while(0);wa=X+1|0;xa=Fa;ya=U}}while(0);U=J+(ya>>>3)|0;W=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(ya&7);if((ya|0)<(N|0)&(wa|0)<(L|0)){I=ya;Z=xa;X=wa;ca=W}else{Ga=ya;Ha=wa;Ia=W;break d}}ka=B;la=X;ma=m+((Ba+7>>3)+1)|0;break b}else{Ga=0;Ha=f;Ia=K}}while(0);K=Ga+6|0;if(!(Ia>>>0<67108864>>>0)){yDb(0,16,1917136,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua}ka=B;la=Ha;ma=m+(((M>>>0>K>>>0?K:M)+7>>3)+1)|0;break};case 33:{a[n]=a[h]|0;a[p+1|0]=a[m+2|0]|0;a[p+2|0]=a[m+3|0]|0;a[p+3|0]=a[m+4|0]|0;ka=B;la=f;ma=m+5|0;break};case 32:{a[j]=(d[h]|0)>>>4;K=m+2|0;a[l]=a[h]&15;a[z]=(d[K]|0)>>>4;a[A]=a[K]&15;ka=B;la=f;ma=m+3|0;break};case 240:{ka=B+2|0;la=c[v>>2]|0;ma=h;break};case 34:{a[r]=a[h]|0;a[q+1|0]=a[m+2|0]|0;a[q+2|0]=a[m+3|0]|0;a[q+3|0]=a[m+4|0]|0;a[q+4|0]=a[m+5|0]|0;a[q+5|0]=a[m+6|0]|0;a[q+6|0]=a[m+7|0]|0;a[q+7|0]=a[m+8|0]|0;a[q+8|0]=a[m+9|0]|0;a[q+9|0]=a[m+10|0]|0;a[q+10|0]=a[m+11|0]|0;a[q+11|0]=a[m+12|0]|0;a[q+12|0]=a[m+13|0]|0;a[q+13|0]=a[m+14|0]|0;a[q+14|0]=a[m+15|0]|0;a[q+15|0]=a[m+16|0]|0;ka=B;la=f;ma=m+17|0;break};case 17:{Ja=c[b>>2]|0;if((Ja|0)<4){E=61;break a}K=(Ja|0)==8;L=K?r:0;N=c[x>>2]|0;J=u-h<<3;ca=J>>>0>2147483639>>>0|(h|0)==0;Z=ca?0:h;I=ca?8:J+8|0;ca=Z;H=fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0;f:do{if((J|0)>0&(f|0)<(N|0)){ca=(L|0)==0;W=0;U=t+((ba(N,B)|0)+f)|0;ha=f;aa=H;g:while(1){$=aa>>>28;ja=W+4|0;_=I>>>0>ja>>>0?ja:I;do{if(($|0)==0){ja=((_|0)<(I|0))+_|0;Y=Z+(ja>>>3)|0;if(((d[Z+(_>>>3)|0]|0)&128>>>((_&7)>>>0)|0)==0){V=Y;ga=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(ja&7)>>>29;V=ja+3|0;Ka=I>>>0>V>>>0?V:I;if((ga|0)==0){break g}if(ca){La=0}else{La=a[L]|0}if((ha|0)>=(N|0)){Ma=ha;Na=U;Oa=Ka;break}V=ha-N|0;ia=-2-ga|0;Pa=((ia|0)>-1?-3-ia|0:-2)-ga|0;ga=V>>>0>Pa>>>0?V:Pa;Pa=-ga|0;TGb(U|0,La|0,Pa|0)|0;Ma=ha-ga|0;Na=U+Pa|0;Oa=Ka;break}Pa=((ja|0)<(I|0))+ja|0;ga=((d[Y]|0)&128>>>((ja&7)>>>0)|0)==0;ja=Z+(Pa>>>3)|0;Y=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(Pa&7)>>>30;ja=Pa+2|0;Pa=I>>>0>ja>>>0?ja:I;if(ga){ga=Y|4;ja=Z+(Pa>>>3)|0;V=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(Pa&7)>>>28;ja=Pa+4|0;ia=I>>>0>ja>>>0?ja:I;if(y&(V|0)==1){Ma=ga+ha|0;Na=U;Oa=ia;break}if(ca){Qa=V&255}else{Qa=a[L+V|0]|0}if((ha|0)>=(N|0)){Ma=ha;Na=U;Oa=ia;break}V=ha-N|0;ja=-ga|0;Ra=~(((ja|0)>-1?ja:-1)+ga);ga=V>>>0>Ra>>>0?V:Ra;Ra=-ga|0;TGb(U|0,Qa|0,Ra|0)|0;Ma=ha-ga|0;Na=U+Ra|0;Oa=ia;break}if((Y|0)==2){ia=Z+(Pa>>>3)|0;Ra=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(Pa&7)>>>28;ia=Pa+4|0;ga=I>>>0>ia>>>0?ia:I;ia=Z+(ga>>>3)|0;V=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(ga&7)>>>28;ia=ga+4|0;ga=I>>>0>ia>>>0?ia:I;if(y&(V|0)==1){Ma=ha+9+Ra|0;Na=U;Oa=ga;break}if(ca){Sa=V&255}else{Sa=a[L+V|0]|0}if((ha|0)>=(N|0)){Ma=ha;Na=U;Oa=ga;break}V=ha-N|0;ia=-9-Ra|0;ja=((ia|0)>-1?-10-ia|0:-9)-Ra|0;Ra=V>>>0>ja>>>0?V:ja;ja=-Ra|0;TGb(U|0,Sa|0,ja|0)|0;Ma=ha-Ra|0;Na=U+ja|0;Oa=ga;break}else if((Y|0)==3){ga=Z+(Pa>>>3)|0;ja=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(Pa&7)>>>24;ga=Pa+8|0;Ra=I>>>0>ga>>>0?ga:I;ga=Z+(Ra>>>3)|0;V=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(Ra&7)>>>28;ga=Ra+4|0;Ra=I>>>0>ga>>>0?ga:I;if(y&(V|0)==1){Ma=ha+25+ja|0;Na=U;Oa=Ra;break}if(ca){Ta=V&255}else{Ta=a[L+V|0]|0}if((ha|0)>=(N|0)){Ma=ha;Na=U;Oa=Ra;break}V=ha-N|0;ga=-25-ja|0;ia=((ga|0)>-1?-26-ga|0:-25)-ja|0;ja=V>>>0>ia>>>0?V:ia;ia=-ja|0;TGb(U|0,Ta|0,ia|0)|0;Ma=ha-ja|0;Na=U+ia|0;Oa=Ra;break}else if((Y|0)==1){if(K){Ua=a[L]|0}else{Ua=0}if((ha|0)>=(N|0)){Ma=ha;Na=U;Oa=Pa;break}Y=(ha-N|0)==-1?-1:-2;Ra=-Y|0;TGb(U|0,Ua|0,Ra|0)|0;Ma=ha-Y|0;Na=U+Ra|0;Oa=Pa;break}else{if(K){Va=a[L]|0}else{Va=0}a[U]=Va;Ma=ha+1|0;Na=U+1|0;Oa=Pa;break}}else{do{if(y&($|0)==1){Wa=U}else{if(ca){a[U]=$;Wa=U+1|0;break}else{a[U]=a[L+$|0]|0;Wa=U+1|0;break}}}while(0);Ma=ha+1|0;Na=Wa;Oa=_}}while(0);_=Z+(Oa>>>3)|0;$=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Oa&7);if((Oa|0)<(J|0)&(Ma|0)<(N|0)){W=Oa;U=Na;ha=Ma;aa=$}else{Xa=Oa;Ya=Ma;Za=$;break f}}ka=B;la=ha;ma=m+((Ka+7>>3)+1)|0;break b}else{Xa=0;Ya=f;Za=H}}while(0);H=Xa+8|0;if(!(Za>>>0<16777216>>>0)){yDb(0,16,1917136,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua}ka=B;la=Ya;ma=m+(((I>>>0>H>>>0?H:I)+7>>3)+1)|0;break};default:{yDb(w,32,1941416,(ua=i,i=i+8|0,c[ua>>2]=e,ua)|0);i=ua;ka=B;la=f;ma=h}}}while(0);if(ma>>>0<s>>>0){m=ma;f=la;B=ka}else{E=138;break}}if((E|0)==9){_a=D;$a=c[g>>2]|0}else if((E|0)==11){_a=c[x>>2]|0;$a=F}else if((E|0)==61){yDb(w,16,2008144,(ua=i,i=i+8|0,c[ua>>2]=Ja,ua)|0);i=ua;i=k;return}else if((E|0)==109){yDb(w,16,1970080,(ua=i,i=i+8|0,c[ua>>2]=G,ua)|0);i=ua;i=k;return}else if((E|0)==138){i=k;return}yDb(w,16,2053880,(ua=i,i=i+40|0,c[ua>>2]=f,c[ua+8>>2]=_a,c[ua+16>>2]=B,c[ua+24>>2]=$a,c[ua+32>>2]=C&255,ua)|0);i=ua;i=k;return}function P7(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=g;m=C7(b,c[l>>2]|0,j,k)|0;c[l>>2]=m;do{if((m|0)!=0){if((k|0)<(c[m+8>>2]|0)){break}if((Ekb(m)|0)!=0){break}n=g+4|0;c[n>>2]=e;c[e+84>>2]=1;c[e+88>>2]=1;o=c[l>>2]|0;c[b+140>>2]=c[o+64>>2];p=o+20|0;o=b+104|0;q=c[p+4>>2]|0;c[o>>2]=c[p>>2];c[o+4>>2]=q;q=c[l>>2]|0;o=V$a(b,c[q+36>>2]|0,c[q+32>>2]|0)|0;if((o|0)<0){r=o;i=h;return r|0}o=_$a(b,c[n>>2]|0,0)|0;if((o|0)<0){r=o;i=h;return r|0}o=c[n>>2]|0;c[o+296>>2]=1;c[o+300>>2]=0;if((a[j+453|0]|0)==97){o=a[j+455|0]&7;do{if((o|0)==2){s=1}else{if(!((a[j+4|0]&7)==0)){s=0;break}s=(o|0)==7|0}}while(0);o=(c[l>>2]|0)+40+(s<<3)|0;q=b+224|0;p=c[o+4>>2]|0;c[q>>2]=c[o>>2];c[q+4>>2]=p;c[(c[n>>2]|0)+300>>2]=((d[j+456|0]|0)>>>6&1^1)&255}c[g+12>>2]=j;p=c[b+824>>2]|0;q=c[l>>2]|0;o=c[q+56>>2]|0;t=ba((c[q+16>>2]|0)*27|0,c[q+12>>2]|0)|0;u=c[q+4>>2]|0;if((u|0)==20){v=(c[q>>2]|0)==1?t-81|0:t}else if((u|0)==24){v=(c[q>>2]|0)==1?t-108|0:t}else{v=t}oe[p&63](b,508,o,0,v,12)|0;c[f>>2]=1;r=c[(c[l>>2]|0)+8>>2]|0;i=h;return r|0}}while(0);yDb(b,16,2189736,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;r=-1;i=h;return r|0}function Q7(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0;h=i;i=i+6912|0;j=h|0;k=h+24|0;l=h+48|0;m=h+1192|0;n=h+6312|0;o=h+6408|0;p=h+6824|0;q=h+6848|0;r=c[f+60>>2]|0;s=n|0;t=o|0;u=c[(c[r+8>>2]|0)+800>>2]|0;TGb(m|0,0,5120)|0;v=r+12|0;w=(c[v>>2]|0)+((e[g>>1]|0)*80|0)|0;y=m|0;m=h+72|0;c[k+20>>2]=3200;z=k+8|0;c[z>>2]=t;c[k+16>>2]=o+400;o=k+12|0;c[o>>2]=t;A=k+4|0;c[A>>2]=32;B=k|0;c[B>>2]=0;C=j+20|0;D=j+8|0;E=n+80|0;n=j+16|0;F=j+12|0;G=j+4|0;H=j|0;I=r;J=l|0;K=l+12|0;L=l+16|0;M=l+4|0;N=l+8|0;O=r+156|0;P=O;Q=r+16|0;R=Q;S=(u|0)==0|0;T=O;O=c[I>>2]|0;U=y;V=w;w=m;W=0;X=O;Y=c[O+68>>2]|0;while(1){O=a[V+3|0]&15;Z=V+4|0;c[C>>2]=640;c[D>>2]=s;c[n>>2]=E;c[F>>2]=s;c[G>>2]=32;c[H>>2]=0;_=p+(W<<2)|0;c[_>>2]=0;if((Y|0)>0){$=O<<6;aa=Z;ca=w;da=U;ea=0;fa=X;while(1){ga=d[(c[fa+72>>2]|0)+ea|0]|0;ha=(aa|0)==0?0:ga;c[J>>2]=aa;c[K>>2]=ha;ia=ha+8|0;c[L>>2]=ia;c[M>>2]=aa+((ha+7|0)>>>3);c[N>>2]=0;ha=aa;ja=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)>>23;ha=ia>>>0>9>>>0;ka=ha?9:ia;c[N>>2]=ka;la=(d[aa+(ka>>>3)|0]|0)<<(ka&7)>>>7;ma=(ha&1)+ka|0;c[N>>2]=ma;ka=la&1;la=aa+(ma>>>3)|0;ha=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>30;la=ma+2|0;c[N>>2]=ia>>>0>la>>>0?la:ia;if((c[fa+4>>2]&16|0)==0){c[ca+12>>2]=c[P+(((ka|0)==0?0:S)<<2)>>2];c[ca+4>>2]=R+(ka<<6);c[ca>>2]=(c[(c[I>>2]|0)+60>>2]|0)+((-((ha|0)==3|0)<<6&2816)+(-ka&1408)+((d[1228304+ha|0]|0)+O<<6)<<2)}else{c[ca+12>>2]=c[T>>2];c[ca+4>>2]=Q;c[ca>>2]=(c[(c[I>>2]|0)+60>>2]|0)+((((ea|0)>3)<<12|$|ha<<10)<<2);c[_>>2]=c[_>>2]|((ea|0)==0?ka:0)}b[da>>1]=(ja<<2)+1024;na=aa+(ga>>>3)|0;ga=ca+8|0;a[ga]=0;a[ca+16|0]=0;S7(l,ca,da);if((d[ga]|0)>>>0>63>>>0){T7(j,l)}ga=ea+1|0;ja=c[I>>2]|0;if((ga|0)<(c[ja+68>>2]|0)){aa=na;ca=ca+28|0;da=da+128|0;ea=ga;fa=ja}else{break}}oa=na;pa=c[G>>2]|0;qa=c[D>>2]|0;ra=c[F>>2]|0;sa=c[H>>2]|0}else{oa=Z;pa=32;qa=s;ra=s;sa=0}fa=(ra-qa<<3)+(32-pa)|0;ea=fa>>>0>2147483639>>>0;da=ea?0:s;ca=ea?0:fa;c[J>>2]=da;c[K>>2]=ca;c[L>>2]=ca+8;c[M>>2]=da+(ca+7>>3);c[N>>2]=0;if((pa|0)>16){ta=pa-16|0;ua=sa<<16;va=ra}else{ca=ra;x=fe(sa<<pa|0)|0;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;ca=ra+4|0;c[F>>2]=ca;ta=pa+16|0;ua=0;va=ca}c[H>>2]=ua;c[G>>2]=ta;if((ta|0)>16){wa=ta-16|0;xa=va}else{ca=va;x=fe(ua<<ta|0)|0;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;ca=(c[F>>2]|0)+4|0;c[F>>2]=ca;wa=ta+16|0;xa=ca}c[H>>2]=0;c[G>>2]=wa;if((wa|0)<32){c[H>>2]=0;ca=wa+8|0;da=(((ca|0)>32?wa+7|0:31)-wa|0)>>>3;fa=da<<3;ea=xa;aa=wa;while(1){a[ea]=0;_=aa+8|0;if((_|0)<32){ea=ea+1|0;aa=_}else{break}}c[F>>2]=xa+(da+1);c[H>>2]=0;c[G>>2]=ca+fa}c[G>>2]=32;c[H>>2]=0;aa=c[I>>2]|0;ea=c[aa+68>>2]|0;a:do{if((ea|0)>0){Z=w;_=U;$=0;O=aa;b:while(1){ja=Z+8|0;do{if((d[ja]|0)>>>0<64>>>0){if(((c[K>>2]|0)-(c[N>>2]|0)|0)<=0){ya=O;break}S7(l,Z,_);za=c[I>>2]|0;if((d[ja]|0)>>>0<64>>>0){break b}else{ya=za}}else{ya=O}}while(0);ja=$+1|0;ga=c[ya+68>>2]|0;if((ja|0)<(ga|0)){Z=Z+28|0;_=_+128|0;$=ja;O=ya}else{Aa=ja;Ba=ya;Ca=ga;break a}}Aa=$;Ba=za;Ca=c[za+68>>2]|0}else{Aa=0;Ba=aa;Ca=ea}}while(0);if((Aa|0)<(Ca|0)){Da=Ba;Ea=Ca}else{T7(k,l);ea=c[I>>2]|0;Da=ea;Ea=c[ea+68>>2]|0}ea=W+1|0;if((ea|0)<5){U=U+(Ea<<6<<1)|0;V=oa;w=w+(Ea*28|0)|0;W=ea;X=Da;Y=Ea}else{break}}Ea=g;g=3-u|0;u=c[A>>2]|0;Y=c[o>>2]|0;Da=(Y-(c[z>>2]|0)<<3)+(32-u)|0;z=Da>>>0>2147483639>>>0;X=z?0:t;t=z?0:Da;c[J>>2]=X;c[K>>2]=t;c[L>>2]=t+8;c[M>>2]=X+(t+7>>3);c[N>>2]=0;t=c[B>>2]|0;if((u|0)>16){Fa=u-16|0;Ga=t<<16;Ha=Y}else{X=Y;x=fe(t<<u|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=Y+4|0;c[o>>2]=X;Fa=u+16|0;Ga=0;Ha=X}c[B>>2]=Ga;c[A>>2]=Fa;if((Fa|0)>16){Ia=Fa-16|0;Ja=Ha}else{X=Ha;x=fe(Ga<<Fa|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=Ha+4|0;c[o>>2]=X;Ia=Fa+16|0;Ja=X}c[B>>2]=0;c[A>>2]=Ia;if((Ia|0)<32){c[B>>2]=0;X=(((Ia+8|0)>32?Ia+7|0:31)-Ia|0)>>>3;Fa=Ia+(X<<3)|0;Ha=X+1|0;X=Ja;Ga=Ia;while(1){a[X]=0;Ia=Ga+8|0;if((Ia|0)<32){X=X+1|0;Ga=Ia}else{break}}c[o>>2]=Ja+Ha;c[B>>2]=0;c[A>>2]=Fa+8}c[A>>2]=32;c[B>>2]=0;B=f;f=m;A=y;Fa=0;Ha=c[I>>2]|0;while(1){if((c[Ha+68>>2]|0)>0){Ja=f;o=A;Ga=0;while(1){X=Ja+8|0;Ia=a[X]|0;do{if((Ia&255)>>>0<64>>>0){if(((c[K>>2]|0)-(c[N>>2]|0)|0)<=0){Ka=Ia;break}S7(l,Ja,o);Ka=a[X]|0}else{Ka=Ia}}while(0);if((Ka-64&255)>>>0<63>>>0){yDb(B,16,2112488,(Ia=i,i=i+8|0,c[Ia>>2]=Ka&255,Ia)|0);i=Ia}Ia=o+128|0;X=Ja+28|0;$=Ga+1|0;u=c[I>>2]|0;if(($|0)<(c[u+68>>2]|0)){Ja=X;o=Ia;Ga=$}else{La=X;Ma=Ia;Na=u;break}}}else{La=f;Ma=A;Na=Ha}Ga=Fa+1|0;if((Ga|0)<5){f=La;A=Ma;Fa=Ga;Ha=Na}else{break}}Ha=2<<g;Fa=r+4|0;r=1<<g;Ma=q;q=r>>1;A=g-1|0;La=(A|0)>0?1<<A:1;A=m;m=y;y=0;f=Na;while(1){Na=b[Ea+2+(y<<1)>>1]|0;Ka=Na&65535;B=Ka&255;l=Ka>>>8;Ka=c[f+32>>2]|0;do{if((Ka|0)==720){if(!((a[(c[v>>2]|0)+1|0]&12)==0)){Oa=l;break}Oa=l-((Na&65535)>>>0>4607>>>0?18:-72)|0}else{Oa=l}}while(0);l=c[f+64>>2]|0;if((l|0)==7){if(B>>>0>87>>>0){Pa=56}else{Pa=55}}else if((l|0)==0){Pa=56}else{Pa=55}do{if((Pa|0)==55){Pa=0;if(!((Ka|0)<720|(Oa|0)==134)){Pa=56;break}l=c[Fa>>2]|0;Qa=Ha;Ra=l;Sa=c[l+32>>2]|0;Ta=c[p+(y<<2)>>2]|0}}while(0);if((Pa|0)==56){Pa=0;Ka=c[Fa>>2]|0;l=c[Ka+32>>2]|0;Na=c[p+(y<<2)>>2]|0;Qa=l<<(g&-((Na|0)==0|0));Ra=Ka;Sa=l;Ta=Na}Na=c[Ra>>2]|0;l=(ba(Sa,Oa)|0)+B<<g;Ka=p+(y<<2)|0;N=Sa<<Ta;Xe[c[A+12>>2]&4095](Na+l|0,N,m);if((c[(c[I>>2]|0)+4>>2]|0)==4){Xe[c[A+68>>2]&4095](Na+(l+r)|0,N,m+256|0)}else{K=l+r|0;Xe[c[A+40>>2]&4095](Na+K|0,N,m+128|0);Xe[c[A+68>>2]&4095](Na+(l+Qa)|0,N,m+256|0);Xe[c[A+96>>2]&4095](Na+(K+Qa)|0,N,m+384|0)}N=c[(c[I>>2]|0)+64>>2]|0;K=c[Fa>>2]|0;Na=ba(Oa>>((N|0)==0),c[K+36>>2]|0)|0;l=Na+(B>>>(((N|0)==7?2:1)>>>0))<<g;Na=B>>>0>87>>>0;Ga=(Oa|0)==134;o=A+112|0;Ja=m+512|0;u=2;Ia=K;K=N;while(1){N=c[Ia+(u<<2)>>2]|0;X=N+l|0;do{if((K|0)==7&Na){Xe[c[o+12>>2]&4095](Ma,8,Ja);if(!((r|0)<1|(La|0)<1)){$=X;Y=Ma;t=0;M=c[(c[Fa>>2]|0)+32+(u<<2)>>2]|0;while(1){L=M<<g;J=0;do{a[$+J|0]=a[Y+J|0]|0;a[$+(J+L)|0]=a[Y+(J+q)|0]|0;J=J+1|0;}while((J|0)<(La|0));J=c[(c[Fa>>2]|0)+32+(u<<2)>>2]|0;L=t+1|0;if((L|0)<(r|0)){$=$+J|0;Y=Y+8|0;t=L;M=J}else{break}}}Ua=Ja+128|0;Va=o+28|0}else{M=c[Ia+32+(u<<2)>>2]|0;t=c[Ka>>2]|0;if(Ga){Wa=r}else{Wa=M<<(g&-((t|0)==0|0))}Y=M<<t;Xe[c[o+12>>2]&4095](X,Y,Ja);t=Ja+128|0;if((c[(c[I>>2]|0)+68>>2]|0)!=8){Ua=t;Va=o+28|0;break}Xe[c[o+40>>2]&4095](N+(Wa+l)|0,Y,t);Ua=Ja+256|0;Va=o+56|0}}while(0);N=u-1|0;if((N|0)==0){break}o=Va;Ja=Ua;u=N;Ia=c[Fa>>2]|0;K=c[(c[I>>2]|0)+64>>2]|0}K=y+1|0;if((K|0)>=5){break}A=Va;m=Ua;y=K;f=c[I>>2]|0}i=h;return 0}function R7(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(f>>>3)|0;a=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(f&7)>>>((32-b|0)>>>0);h=f+b|0;c[e>>2]=g>>>0>h>>>0?h:g;return a|0}function S7(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=c[e+12>>2]|0;i=c[f+4>>2]|0;j=c[f>>2]|0;k=f+8|0;l=d[k]|0;m=f+16|0;n=a[m]|0;o=n&255;p=e+8|0;q=c[p>>2]|0;r=e|0;e=(c[r>>2]|0)+(q>>>3)|0;s=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(q&7);if(n<<24>>24==0){t=l;u=s;v=q}else{n=c[f+20>>2]|s>>>(o>>>0);a[m]=0;t=l;u=n;v=q-o|0}while(1){o=u>>>23;q=a[7553490+(o<<2)|0]|0;n=q<<24>>24;if(q<<24>>24<0){w=(b[7553488+(o<<2)>>1]|0)+(u<<9>>>((n+32|0)>>>0))|0;x=9-n|0}else{w=o;x=n}n=x+v|0;if(n>>>0>h>>>0){break}o=(d[7553491+(w<<2)|0]|0)+t|0;if((o|0)>63){y=n;z=o&255;A=9;break}q=((ba(c[j+(o<<2)>>2]|0,b[7553488+(w<<2)>>1]|0)|0)+8192|0)>>>14&65535;b[g+(d[i+o|0]<<1)>>1]=q;q=(c[r>>2]|0)+(n>>>3)|0;t=o;u=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(n&7);v=n}if((A|0)==9){c[p>>2]=y;a[k]=z;return}A=h-v|0;a[m]=A;c[f+20>>2]=u&~(-1>>>((A&255)>>>0));y=h;z=t&255;c[p>>2]=y;a[k]=z;return}function T7(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e+8|0;g=c[f>>2]|0;h=c[e+12>>2]|0;i=h-g|0;if((i|0)>24){j=((h-25-g|0)>>>0)%25|0;g=i;while(1){U7(b,25,R7(e,25)|0);h=g-25|0;if((h|0)>24){g=h}else{k=j;break}}}else{k=i}if((k|0)<=0){return}i=c[f>>2]|0;j=c[e+16>>2]|0;g=(c[e>>2]|0)+(i>>>3)|0;e=32-k|0;h=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(i&7)>>>(e>>>0);g=i+k|0;c[f>>2]=j>>>0>g>>>0?g:j;j=b|0;g=c[j>>2]|0;f=b+4|0;i=c[f>>2]|0;if((i|0)>(k|0)){l=i-k|0;m=g<<k|h}else{n=fe(h>>>((k-i|0)>>>0)|g<<i|0)|0;g=b+12|0;b=c[g>>2]|0;x=n;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;l=e+i|0;m=h}c[j>>2]=m;c[f>>2]=l;return}function U7(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b|0;g=c[f>>2]|0;h=b+4|0;i=c[h>>2]|0;if((i|0)>(d|0)){j=i-d|0;k=g<<d|e;c[f>>2]=k;c[h>>2]=j;return}else{l=fe(e>>>((d-i|0)>>>0)|g<<i|0)|0;g=b+12|0;b=c[g>>2]|0;x=l;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;j=32-d+i|0;k=e;c[f>>2]=k;c[h>>2]=j;return}}function V7(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=c[b+60>>2]|0;k=j;l=b+96|0;do{if((c[l>>2]|0)!=0){m=b+100|0;n=c[m>>2]|0;if((n|0)==0){break}o=WDb(n+1|0)|0;if((o|0)==0){p=-12;i=d;return p|0}n=c[m>>2]|0;UGb(o|0,c[l>>2]|0,n)|0;a[o+n|0]=0;n=j+72|0;m=o;a:while(1){q=hc(m|0,1941408)|0;if((q|0)==0){if((a[m]|0)==0){r=19;break}}do{if((RGb(2053856,m,8)|0)==0){s=m+8|0;c[f>>2]=s;c[n>>2]=1;t=0;u=s;while(1){c[k+4+(t<<2)>>2]=hb(u|0,f|0,16)|0;s=c[f>>2]|0;while(1){v=a[s]|0;if(!(v<<24>>24==44)){if((EAb(v<<24>>24)|0)==0){break}}v=s+1|0;c[f>>2]=v;s=v}v=t+1|0;if((v|0)<16){t=v;u=s}else{break}}}else{if((RGb(1917128,m,5)|0)!=0){break}u=xd(m+5|0,1896432,(w=i,i=i+16|0,c[w>>2]=g,c[w+8>>2]=h,w)|0)|0;i=w;if((u|0)!=2){break}x=V$a(b,c[g>>2]|0,c[h>>2]|0)|0;if((x|0)<0){break a}}}while(0);m=m+((qd(m+q|0,1941408)|0)+q)|0}if((r|0)==19){ZDb(o);break}ZDb(o);p=x;i=d;return p|0}}while(0);x=c[j+68>>2]|0;if((x|0)==0){y=j+72|0}else{c[e>>2]=x;r=j+72|0;c[r>>2]=1;h=0;g=x;while(1){c[k+4+(h<<2)>>2]=hb(g|0,e|0,16)|0;x=c[e>>2]|0;while(1){f=a[x]|0;if(!(f<<24>>24==44)){if((EAb(f<<24>>24)|0)==0){break}}f=x+1|0;c[e>>2]=f;x=f}o=h+1|0;if((o|0)<16){h=o;g=x}else{y=r;break}}}if((c[y>>2]|0)==0){p=1;i=d;return p|0}y=b;yDb(y,48,2053856,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;b=j+4|0;j=0;do{yDb(y,48,2008128,(w=i,i=i+8|0,c[w>>2]=c[b+(j<<2)>>2],w)|0);i=w;j=j+1|0;}while((j|0)<16);yDb(y,48,1970072,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;p=1;i=d;return p|0}function W7(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0;h=i;i=i+272|0;j=h|0;k=h+256|0;l=b+60|0;m=c[l>>2]|0;n=m;o=c[g+24>>2]|0;p=c[g+28>>2]|0;g=m+336|0;q=g;r=c[q>>2]|0;a:do{if((r|0)==0){s=o;t=p}else{u=m+340|0;v=c[u>>2]|0;do{if((v|0)>(65535-p|0)){yDb(b,24,2112424,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;$Db(g);x=-1094995529}else{y=XDb(r,v+p|0)|0;c[q>>2]=y;if((y|0)==0){x=-12;break}UGb(y+(c[u>>2]|0)|0,o|0,p)|0;y=(c[u>>2]|0)+p|0;c[u>>2]=y;s=c[q>>2]|0;t=y;break a}}while(0);c[f>>2]=0;z=x;i=h;return z|0}}while(0);x=m+76|0;q=m+80|0;b:do{if((t|0)>=10){p=s;o=(d[p]|d[p+1|0]<<8)<<16>>16<<16>>16==0;p=o?4:2;r=s+(o?6:2)|0;if(o){u=r;v=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;if((v|0)>=0){A=v;B=11}}else{v=r;A=(de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535;B=11}c:do{if((B|0)==11){v=t-2-p|0;if((A|0)>(v|0)){break}r=p+2|0;u=e+16|0;y=u;C=e+12|0;D=k|0;E=m+72|0;F=m+81|0;G=m+82|0;H=m+83|0;I=m+79|0;J=m+78|0;K=m+77|0;L=e+4|0;M=e+8|0;N=0;O=A;P=0;Q=0;d:while(1){if(!((O|0)>0&(O|0)<(v|0))){R=N;B=75;break}S=s+O|0;T=(de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=s+(O+2)|0;if(o){U=S;V=fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0}else{U=S;V=(de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535}U=r+O|0;do{if((U|0)<(t|0)){S=(T<<10>>>0)/90|0;W=0;X=0;Y=-1;Z=-1;_=0;$=Q;aa=P;ca=0;da=U;ea=N;e:while(1){fa=da+1|0;ga=d[s+da|0]|0;switch(ga|0){case 6:{if((t-fa|0)<4){break d}ha=s+fa|0;ia=(de((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535;ha=s+(da+3)|0;ja=ea;ka=da+5|0;la=ca;ma=aa;na=$;oa=_;pa=(de((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535;qa=ia;ra=X;sa=W;break};case 4:{if((t-fa|0)<2){break d}ia=s+fa|0;a[H]=(d[ia]|0)>>>4;a[G]=a[ia]&15;ia=s+(da+2)|0;a[F]=(d[ia]|0)>>>4;a[q]=a[ia]&15;ja=ea;ka=da+3|0;la=ca;ma=aa;na=$;oa=_;pa=Z;qa=Y;ra=X;sa=W;break};case 132:{if((t-fa|0)<256){break d}else{ta=0}do{a[n+80+ta|0]=~a[s+(ta+fa)|0];ta=ta+1|0;}while((ta|0)<256);ja=ea;ka=da+257|0;la=ca;ma=aa;na=$;oa=_;pa=Z;qa=Y;ra=X;sa=W;break};case 5:case 133:{if((t-fa|0)<6){break d}ia=d[s+(da+2)|0]|0;ha=d[s+(da+5)|0]|0;ja=ea;ka=da+7|0;la=ia>>>4|d[s+fa|0]<<4;ma=aa;na=(ga&128|0)==0?$:1;oa=ha>>>4|d[s+(da+4)|0]<<4;pa=Z;qa=Y;ra=ha<<8&3840|d[s+(da+6)|0];sa=ia<<8&3840|d[s+(da+3)|0];break};case 1:{c[L>>2]=S;ja=ea;ka=fa;la=ca;ma=aa;na=$;oa=_;pa=Z;qa=Y;ra=X;sa=W;break};case 134:{if((t-fa|0)<8){break d}ia=s+fa|0;ha=fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0;ia=s+(da+5)|0;ja=ea;ka=da+9|0;la=ca;ma=aa;na=$;oa=_;pa=fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0;qa=ha;ra=X;sa=W;break};case 0:{ja=1;ka=fa;la=ca;ma=aa;na=$;oa=_;pa=Z;qa=Y;ra=X;sa=W;break};case 2:{c[M>>2]=S;ja=ea;ka=fa;la=ca;ma=aa;na=$;oa=_;pa=Z;qa=Y;ra=X;sa=W;break};case 3:{if((t-fa|0)<2){break d}ha=s+fa|0;a[I]=(d[ha]|0)>>>4;a[J]=a[ha]&15;ha=s+(da+2)|0;a[K]=(d[ha]|0)>>>4;a[x]=a[ha]&15;ja=ea;ka=da+3|0;la=ca;ma=aa;na=$;oa=_;pa=Z;qa=Y;ra=X;sa=W;break};case 131:{if((t-fa|0)<768){break d}ja=ea;ka=da+769|0;la=ca;ma=s+fa|0;na=$;oa=_;pa=Z;qa=Y;ra=X;sa=W;break};default:{ua=W;va=X;wa=Y;xa=Z;ya=_;za=$;Aa=aa;Ba=ca;Ca=ea;break e}}if((ka|0)<(t|0)){W=sa;X=ra;Y=qa;Z=pa;_=oa;$=na;aa=ma;ca=la;da=ka;ea=ja}else{ua=sa;va=ra;wa=qa;xa=pa;ya=oa;za=na;Aa=ma;Ba=la;Ca=ja;break}}if(!((wa|0)>-1)){Da=Ca;Ea=Aa;Fa=za;break}ea=ua-Ba+1|0;da=(ea|0)<0?0:ea;ea=va-ya|0;ca=(ea|0)<0?0:ea;if(!((da|0)>0&(ca|0)>0)){Da=Ca;Ea=Aa;Fa=za;break}ea=c[y>>2]|0;if((ea|0)!=0){f:do{if((c[C>>2]|0)!=0){aa=0;$=ea;while(1){$Db((c[$+(aa<<2)>>2]|0)+20|0);$Db((c[(c[y>>2]|0)+(aa<<2)>>2]|0)+24|0);$Db((c[y>>2]|0)+(aa<<2)|0);_=aa+1|0;if(!(_>>>0<(c[C>>2]|0)>>>0)){break f}aa=_;$=c[y>>2]|0}}}while(0);$Db(u);c[C>>2]=0}ea=WDb(ba(da,ca)|0)|0;c[y>>2]=cEb(4)|0;$=cEb(100)|0;c[c[y>>2]>>2]=$;c[C>>2]=1;c[(c[c[y>>2]>>2]|0)+20>>2]=ea;$=da<<1;Y7(ea,$,da,(ca+1|0)/2|0,s,wa,t,za);Y7(ea+da|0,$,da,(ca|0)/2|0,s,xa,t,za);$=cEb(1024)|0;c[(c[c[y>>2]>>2]|0)+24>>2]=$;g:do{if((za|0)==0){$=c[c[y>>2]>>2]|0;c[$+16>>2]=4;ea=c[$+24>>2]|0;$=ea;TGb(D|0,0,16)|0;if((c[E>>2]|0)!=0){c[$>>2]=ba(d[q]|0,285212672)|0|c[n+4+(d[x]<<2)>>2]&16777215;c[ea+4>>2]=ba(d[F]|0,285212672)|0|c[n+4+(d[K]<<2)>>2]&16777215;c[ea+8>>2]=ba(d[G]|0,285212672)|0|c[n+4+(d[J]<<2)>>2]&16777215;c[ea+12>>2]=ba(d[H]|0,285212672)|0|c[n+4+(d[I]<<2)>>2]&16777215;break}TGb(ea|0,0,16)|0;ea=a[q]|0;do{if(ea<<24>>24==0){Ga=0}else{aa=k+(d[x]|0)|0;if((a[aa]|0)!=0){Ga=0;break}a[aa]=1;Ga=1}}while(0);do{if((a[F]|0)==0){Ha=Ga}else{aa=k+(d[K]|0)|0;if((a[aa]|0)!=0){Ha=Ga;break}a[aa]=1;Ha=Ga+1|0}}while(0);do{if((a[G]|0)==0){Ia=Ha}else{aa=k+(d[J]|0)|0;if((a[aa]|0)!=0){Ia=Ha;break}a[aa]=1;Ia=Ha+1|0}}while(0);do{if((a[H]|0)==0){Ja=Ia}else{aa=k+(d[I]|0)|0;if((a[aa]|0)!=0){Ja=Ia;break}a[aa]=1;Ja=Ia+1|0}}while(0);if((Ja|0)==0){break}TGb(D|0,0,16)|0;aa=0;fa=0;ga=ea;while(1){_=ga&255;do{if(ga<<24>>24==0){Ka=aa}else{Z=n+76+fa|0;Y=a[k+(d[Z]|0)|0]|0;if(Y<<24>>24==0){X=(d[986040+(Ja<<2)+aa|0]|0)*255|0;c[$+(fa<<2)>>2]=X&65280|(ba(_,285212672)|0)|X>>>8<<16;a[k+(d[Z]|0)|0]=fa+1;Ka=aa+1|0;break}else{c[$+(fa<<2)>>2]=c[$+((Y&255)-1<<2)>>2]&16777215|(ba(_,285212672)|0);Ka=aa;break}}}while(0);_=fa+1|0;if((_|0)>=4){break g}aa=Ka;fa=_;ga=a[n+80+_|0]|0}}else{if((Aa|0)==0){break d}ga=c[c[y>>2]>>2]|0;c[ga+16>>2]=256;fa=256;aa=c[ga+24>>2]|0;ga=q;$=Aa;while(1){ea=(d[$+2|0]|0)-128|0;_=(d[$+1|0]|0)-128|0;Y=((d[$]|0)*1192|0)-18560|0;c[aa>>2]=d[((_*-832|0)+Y+(ea*-401|0)>>10)+1236056|0]<<8|d[((_*1634|0)+Y>>10)+1236056|0]<<16|d[((ea*2066|0)+Y>>10)+1236056|0]|d[ga]<<24;Y=fa-1|0;if((Y|0)>0){fa=Y;aa=aa+4|0;ga=ga+1|0;$=$+3|0}else{break}}}}while(0);$=c[c[y>>2]>>2]|0;c[$>>2]=Ba;c[$+4>>2]=ya;c[$+8>>2]=da;c[$+12>>2]=ca;c[$+84>>2]=1;c[$+52>>2]=da;c[$+96>>2]=(Ca|0)!=0;Da=Ca;Ea=Aa;Fa=za}else{Da=N;Ea=P;Fa=Q}}while(0);if((V|0)<(O|0)){B=73;break}if((V|0)==(O|0)){R=Da;B=75;break}else{N=Da;O=V;P=Ea;Q=Fa}}if((B|0)==73){yDb(0,16,2189704,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;R=Da;B=75}do{if((B|0)==75){if((c[C>>2]|0)==0){break}if((R|0)==-11){break c}if((R|0)<0){break b}do{if((R|0)==0){TGb(j|0,0,256)|0;Q=c[y>>2]|0;if((Q|0)==0){break b}P=c[Q>>2]|0;Q=c[P+8>>2]|0;if((Q|0)<1){break b}O=c[P+12>>2]|0;if((O|0)<1){break b}N=c[P+16>>2]|0;if((N|0)>0){D=c[P+24>>2]|0;I=0;do{if((c[D+(I<<2)>>2]|0)>>>0<16777216>>>0){a[j+I|0]=1}I=I+1|0;}while((I|0)<(N|0));if((O|0)>0){B=95}else{La=0;Ma=0}}else{B=95}h:do{if((B|0)==95){N=(Q|0)>0;I=P+52|0;D=P+20|0;da=0;while(1){if(N){ca=ba(c[I>>2]|0,da)|0;H=(c[D>>2]|0)+ca|0;ca=0;while(1){if((a[j+(d[H]|0)|0]|0)==0){La=da;Ma=1;break h}J=ca+1|0;if((J|0)<(Q|0)){H=H+1|0;ca=J}else{break}}}ca=da+1|0;if((ca|0)<(O|0)){da=ca}else{La=ca;Ma=1;break}}}}while(0);if((La|0)==(O|0)){$Db(P+20|0);da=c[c[y>>2]>>2]|0;c[da+12>>2]=0;c[da+8>>2]=0;break b}da=O-1|0;i:do{if((da|0)>0){D=c[P+20>>2]|0;I=c[P+52>>2]|0;if((Q|0)>0){Na=da}else{Oa=0;break}while(1){N=D+(ba(Na,I)|0)|0;ca=0;while(1){if((a[j+(d[N]|0)|0]|0)==0){Oa=Na;break i}H=ca+1|0;if((H|0)<(Q|0)){N=N+1|0;ca=H}else{break}}ca=Na-1|0;if((ca|0)>0){Na=ca}else{Oa=ca;break}}}else{Oa=da}}while(0);da=Q-1|0;j:do{if((da|0)>0){I=c[P+52>>2]|0;D=P+20|0;ca=0;k:while(1){if(Ma){N=(c[D>>2]|0)+ca|0;H=0;while(1){if((a[j+(d[N]|0)|0]|0)==0){Pa=ca;break k}J=H+1|0;if((J|0)<(O|0)){N=N+I|0;H=J}else{break}}}H=ca+1|0;if((H|0)<(da|0)){ca=H}else{Pa=H;break}}ca=c[D>>2]|0;if(Ma){Qa=da}else{Ra=0;Sa=Pa;break}while(1){H=ca+Qa|0;N=0;while(1){if((a[j+(d[H]|0)|0]|0)==0){Ra=Qa;Sa=Pa;break j}J=N+1|0;if((J|0)<(O|0)){H=H+I|0;N=J}else{break}}N=Qa-1|0;if((N|0)>0){Qa=N}else{Ra=N;Sa=Pa;break}}}else{Ra=da;Sa=0}}while(0);da=Ra-Sa+1|0;O=Oa-La+1|0;P=WDb(ba(da,O)|0)|0;if((P|0)==0){break}Q=c[y>>2]|0;if((O|0)>0){I=0;do{ca=P+(ba(I,da)|0)|0;D=c[Q>>2]|0;UGb(ca|0,(c[D+20>>2]|0)+((ba(c[D+52>>2]|0,I+La|0)|0)+Sa)|0,da)|0;I=I+1|0;}while((I|0)<(O|0))}$Db((c[Q>>2]|0)+20|0);c[(c[c[y>>2]>>2]|0)+20>>2]=P;I=c[c[y>>2]>>2]|0;c[I+52>>2]=da;c[I+8>>2]=da;c[I+12>>2]=O;D=I|0;c[D>>2]=(c[D>>2]|0)+Sa;D=I+4|0;c[D>>2]=(c[D>>2]|0)+La}}while(0);$Db(g);c[m+340>>2]=0;c[f>>2]=1;z=t;i=h;return z|0}}while(0);D=c[y>>2]|0;if((D|0)==0){break b}l:do{if((c[C>>2]|0)!=0){I=0;ca=D;while(1){$Db((c[ca+(I<<2)>>2]|0)+20|0);$Db((c[(c[y>>2]|0)+(I<<2)>>2]|0)+24|0);$Db((c[y>>2]|0)+(I<<2)|0);N=I+1|0;if(!(N>>>0<(c[C>>2]|0)>>>0)){break l}I=N;ca=c[y>>2]|0}}}while(0);$Db(u);c[C>>2]=0;break b}}while(0);c[f>>2]=0;o=c[l>>2]|0;p=o+340|0;y=c[p>>2]|0;if((y|0)>(65535-t|0)){yDb(b,24,2112424,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;$Db(o+336|0);z=-1094995529;i=h;return z|0}D=o+336|0;o=XDb(c[D>>2]|0,y+t|0)|0;c[D>>2]=o;if((o|0)==0){z=-12;i=h;return z|0}UGb(o+(c[p>>2]|0)|0,s|0,t)|0;c[p>>2]=(c[p>>2]|0)+t;z=0;i=h;return z|0}}while(0);c[f>>2]=0;z=t;i=h;return z|0}function X7(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+336|0);c[b+340>>2]=0;return 0}function Y7(a,b,c,e,f,g,h,i){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=h-g<<3;h=f+g|0;g=j>>>0>2147483639>>>0|(h|0)==0;f=g?0:h;h=g?8:j+8|0;g=(i|0)==0;i=a;a=1;k=0;a:while(1){if(g){l=0;m=k;while(1){if((m|0)>(j|0)){n=19;break a}else{o=0;p=1;q=m}do{r=f+(q>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)>>>28;r=q+4|0;q=h>>>0>r>>>0?r:h;o=s|o<<4;p=p<<2;}while(o>>>0<p>>>0&p>>>0<65>>>0);r=o>>>0<4>>>0?2147483647:o>>>2;t=c-l|0;u=(r|0)>(t|0)?t:r;TGb(i+l|0,s&3|0,u|0)|0;r=u+l|0;if((r|0)<(c|0)){l=r;m=q}else{v=q;break}}}else{m=0;l=k;while(1){if((l|0)>(j|0)){n=19;break a}r=d[f+(l>>>3)|0]|0;u=((l|0)<(h|0))+l|0;t=((u|0)<(h|0))+u|0;w=((d[f+(u>>>3)|0]|0)&128>>>((u&7)>>>0)|0)==0;u=f+(t>>>3)|0;x=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7);if(w){w=t+2|0;y=h>>>0>w>>>0?w:h;z=x>>>30&255}else{w=t+8|0;y=h>>>0>w>>>0?w:h;z=x>>>24&255}do{if((r&128>>>((l&7)>>>0)|0)==0){A=1;B=y}else{x=((y|0)<(h|0))+y|0;w=((d[f+(y>>>3)|0]|0)&128>>>((y&7)>>>0)|0)==0;t=f+(x>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(x&7);if(w){w=x+3|0;A=(u>>>29)+2|0;B=h>>>0>w>>>0?w:h;break}else{w=u>>>25;u=x+7|0;A=(w|0)==0?2147483647:w+9|0;B=h>>>0>u>>>0?u:h;break}}}while(0);r=c-m|0;u=(A|0)>(r|0)?r:A;TGb(i+m|0,z|0,u|0)|0;r=u+m|0;if((r|0)<(c|0)){m=r;l=B}else{v=B;break}}}if((a|0)>=(e|0)){n=19;break}l=-v&7;if((l|0)==0){C=v}else{m=l+v|0;C=h>>>0>m>>>0?m:h}i=i+b|0;a=a+1|0;k=C}if((n|0)==19){return}}function Z7(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+1024|0;d=b|0;e=c[a+60>>2]|0;f=e;UGb(e|0,1345256,64)|0;IAb(d,0,1);e=c[a+120>>2]|0;do{if((e|0)!=0){g=c[a+124>>2]|0;if((g|0)==0){break}KAb(d,2333544,(h=i,i=i+16|0,c[h>>2]=e,c[h+8>>2]=g,h)|0);i=h}}while(0);KAb(d,2308976,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;e=0;do{KAb(d,2290312,(h=i,i=i+16|0,c[h>>2]=c[f+(e<<2)>>2]&16777215,c[h+8>>2]=(e|0)<15?44:10,h)|0);i=h;e=e+1|0;}while((e|0)<16);e=e1a(a,d)|0;i=b;return((e|0)<0?e:0)|0}function _7(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;h=i;i=i+2376|0;j=h|0;k=h+16|0;l=h+152|0;m=h+1176|0;n=h+1184|0;o=h+1320|0;p=h+2344|0;q=h+2360|0;r=b+60|0;s=c[r>>2]|0;t=c[g+12>>2]|0;TGb(n|0,0,132)|0;if((t|0)==0){u=-22;i=h;return u|0}v=g+16|0;w=c[v>>2]|0;if((w|0)==0){u=-22;i=h;return u|0}else{y=0}while(1){if((y|0)>=(t|0)){break}if((c[(c[w+(y<<2)>>2]|0)+84>>2]|0)==1){y=y+1|0}else{z=5;break}}if((z|0)==5){yDb(b,16,2189616,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;u=-22;i=h;return u|0}y=c[w>>2]|0;B=c[y>>2]|0;C=c[y+4>>2]|0;D=c[y+8>>2]|0;E=c[y+12>>2]|0;F=c[y+20>>2]|0;y=(t|0)>1;do{if(y){G=1;H=B;I=D+B|0;J=C;K=E+C|0;do{L=c[w+(G<<2)>>2]|0;M=c[L>>2]|0;H=(H|0)>(M|0)?M:H;N=c[L+4>>2]|0;J=(J|0)>(N|0)?N:J;O=(c[L+8>>2]|0)+M|0;I=(I|0)>(O|0)?I:O;O=(c[L+12>>2]|0)+N|0;K=(K|0)>(O|0)?K:O;G=G+1|0;}while((G|0)<(t|0));G=I-H|0;O=K-J|0;N=hDb(G,O,0,b)|0;if((N|0)<0){u=N;i=h;return u|0}N=ba(O,G)|0;L=n|0;c[L>>2]=N;if((t|0)<=0){P=N;Q=O;R=G;S=J;T=H;U=L;z=10;break}M=c[v>>2]|0;V=0;W=N;do{N=c[M+(V<<2)>>2]|0;W=W-(ba(c[N+12>>2]|0,c[N+8>>2]|0)|0)|0;V=V+1|0;}while((V|0)<(t|0));c[L>>2]=W;X=H;Y=J;Z=G;_=O;$=W;aa=M;z=8}else{X=B;Y=C;Z=D;_=E;$=0;aa=w;z=8}}while(0);do{if((z|0)==8){if((t|0)<=0){P=$;Q=_;R=Z;S=Y;T=X;U=n|0;z=10;break}w=l;E=c[r>>2]|0;D=E;C=0;do{B=c[aa+(C<<2)>>2]|0;TGb(w|0,0,1024)|0;V=c[B+24>>2]|0;K=c[B+12>>2]|0;do{if((K|0)>0){I=B+52|0;N=c[B+8>>2]|0;if((N|0)<=0){ca=0;da=0;break}ea=0;fa=c[B+20>>2]|0;while(1){ga=0;ha=fa;while(1){ia=l+((d[ha]|0)<<2)|0;c[ia>>2]=(c[ia>>2]|0)+1;ia=ga+1|0;if((ia|0)<(N|0)){ga=ia;ha=ha+1|0}else{break}}ha=ea+1|0;if((ha|0)<(K|0)){ea=ha;fa=fa+(c[I>>2]|0)|0}else{ca=0;da=0;break}}}else{ca=0;da=0}}while(0);while(1){K=c[l+(ca<<2)>>2]|0;if((K|0)==0){ja=da}else{B=c[V+(ca<<2)>>2]|0;if(B>>>0<855638016>>>0){ka=da;la=0}else{I=B>>>16&255;fa=B>>>8&255;ea=B&255;N=0;ha=2147483647;ga=da;while(1){ia=c[D+(N<<2)>>2]|0;ma=(I-(ia>>>16&255)|0)*15|0;na=(fa-(ia>>>8&255)|0)*15|0;oa=(ea-(ia&255)|0)*15|0;ia=(ba(ma,ma)|0)+(ba(oa,oa)|0)+(ba(na,na)|0)|0;na=(ia|0)<(ha|0);pa=na?N:ga;oa=N+1|0;if((oa|0)<16){N=oa;ha=na?ia:ha;ga=pa}else{break}}ka=pa;la=pa+(B>>>0<3422552064>>>0?1:17)|0}ga=n+(la<<2)|0;c[ga>>2]=(c[ga>>2]|0)+K;ja=ka}ga=ca+1|0;if((ga|0)<256){ca=ga;da=ja}else{break}}C=C+1|0;}while((C|0)<(t|0));C=n|0;qa=c[C>>2]|0;ra=E;sa=C;ta=_;ua=Z;va=Y;wa=X;xa=1}}while(0);if((z|0)==10){qa=P;ra=c[r>>2]|0;sa=U;ta=Q;ua=R;va=S;wa=T;xa=0}TGb(j|0,0,16)|0;TGb(k|0,0,132)|0;c[sa>>2]=qa<<4;qa=ra;sa=0;while(1){T=sa+1|0;S=n+(T<<2)|0;R=c[S>>2]|0;Q=n+(sa+17<<2)|0;U=c[Q>>2]|0;if((R|0)!=(-U|0)){P=c[qa+(sa<<2)>>2]|0;z=P&255;if(z>>>0<64>>>0){ya=1}else{ya=z>>>0>191>>>0|0}z=P>>>8&255;if(z>>>0<64>>>0){za=1}else{za=z>>>0>191>>>0|0}z=P>>>16&255;if(z>>>0<64>>>0){Aa=1}else{Aa=z>>>0>191>>>0|0}z=za+ya+Aa|0;P=(z|0)>2?4:z+2|0;c[S>>2]=ba(P,R)|0;c[Q>>2]=ba(P,U)|0}if((T|0)<16){sa=T}else{break}}sa=p|0;Aa=j|0;ya=0;za=0;while(1){if((c[n+(ya<<2)>>2]|0)>>>0>(c[n+(za<<2)>>2]|0)>>>0){c[Aa>>2]=ya;Ba=ya}else{Ba=za}T=ya+1|0;if((T|0)<33){ya=T;za=Ba}else{break}}za=q|0;c[n+(Ba<<2)>>2]=0;ya=j+4|0;T=0;U=0;while(1){if((c[n+(T<<2)>>2]|0)>>>0>(c[n+(U<<2)>>2]|0)>>>0){c[ya>>2]=T;Ca=T}else{Ca=U}P=T+1|0;if((P|0)<33){T=P;U=Ca}else{break}}c[n+(Ca<<2)>>2]=0;Ca=j+8|0;U=0;T=0;while(1){if((c[n+(U<<2)>>2]|0)>>>0>(c[n+(T<<2)>>2]|0)>>>0){c[Ca>>2]=U;Da=U}else{Da=T}P=U+1|0;if((P|0)<33){U=P;T=Da}else{break}}c[n+(Da<<2)>>2]=0;Da=j+12|0;T=0;U=0;while(1){if((c[n+(T<<2)>>2]|0)>>>0>(c[n+(U<<2)>>2]|0)>>>0){c[Da>>2]=T;Ea=T}else{Ea=U}P=T+1|0;if((P|0)<33){T=P;U=Ea}else{break}}c[n+(Ea<<2)>>2]=0;Ea=0;while(1){n=c[qa+(Ea<<2)>>2]|0;U=Ea+1|0;c[k+(U<<2)>>2]=n|-2147483648;c[k+(Ea+17<<2)>>2]=n|-16777216;if((U|0)<16){Ea=U}else{Fa=0;Ga=Ba;break}}while(1){Ba=c[472696+(Fa<<2)>>2]|0;Ea=j+(Fa<<2)|0;qa=c[k+(Ga<<2)>>2]|0;U=Ba>>>28;n=qa>>>28;T=Ba>>>24<<3;P=T-(qa>>>24<<3)|0;Q=ba(Ba>>>16&255,U)|0;R=Q-(ba(qa>>>16&255,n)|0)|0;S=ba(Ba>>>8&255,U)|0;z=S-(ba(qa>>>8&255,n)|0)|0;X=ba(Ba&255,U)|0;U=X-(ba(n,qa&255)|0)|0;qa=Fa+1|0;n=(ba(U,U)|0)+(ba(P,P)|0)+(ba(R,R)|0)+(ba(z,z)|0)|0;z=qa;R=Ga;while(1){P=j+(z<<2)|0;U=c[P>>2]|0;Ba=c[k+(U<<2)>>2]|0;Y=Ba>>>28;Z=T-(Ba>>>24<<3)|0;_=Q-(ba(Ba>>>16&255,Y)|0)|0;ja=S-(ba(Ba>>>8&255,Y)|0)|0;da=X-(ba(Y,Ba&255)|0)|0;Ba=(ba(da,da)|0)+(ba(Z,Z)|0)+(ba(_,_)|0)+(ba(ja,ja)|0)|0;if((Ba|0)<(n|0)){c[P>>2]=R;c[Ea>>2]=U;Ha=Ba;Ia=U}else{Ha=n;Ia=R}U=z+1|0;if((U|0)<4){n=Ha;z=U;R=Ia}else{break}}if((qa|0)>=3){break}Fa=qa;Ga=c[j+(qa<<2)>>2]|0}j=c[Aa>>2]|0;if((j|0)==0){c[sa>>2]=0;Ja=0}else{c[sa>>2]=j+15&15;Ja=(j|0)<17?128:255}c[za>>2]=Ja;Ja=c[ya>>2]|0;if((Ja|0)==0){c[p+4>>2]=0;Ka=0}else{c[p+4>>2]=Ja+15&15;Ka=(Ja|0)<17?128:255}Ja=q+4|0;c[Ja>>2]=Ka;Ka=c[Ca>>2]|0;if((Ka|0)==0){c[p+8>>2]=0;La=0}else{c[p+8>>2]=Ka+15&15;La=(Ka|0)<17?128:255}Ka=q+8|0;c[Ka>>2]=La;La=c[Da>>2]|0;if((La|0)==0){c[p+12>>2]=0;Ma=0}else{c[p+12>>2]=La+15&15;Ma=(La|0)<17?128:255}La=q+12|0;c[La>>2]=Ma;if(y){y=dEb(ua,ta)|0;if((y|0)==0){u=-12;i=h;return u|0}Ma=o|0;if(xa){xa=0;do{$7(c[r>>2]|0,Ma,c[(c[(c[v>>2]|0)+(xa<<2)>>2]|0)+24>>2]|0,sa,za);q=c[(c[v>>2]|0)+(xa<<2)>>2]|0;Da=q+12|0;Ca=c[Da>>2]|0;if((Ca|0)>0){ya=y+((c[q>>2]|0)-wa+(ba((c[q+4>>2]|0)-va|0,ua)|0))|0;j=q+8|0;Aa=q+52|0;Ga=0;Fa=c[q+20>>2]|0;q=ya;ya=c[j>>2]|0;Ia=ua;Ha=Ca;while(1){if((ya|0)>0){Ca=0;k=Fa;R=q;while(1){Na=k+1|0;Oa=R+1|0;a[R]=c[o+((d[k]|0)<<2)>>2];z=Ca+1|0;Pa=c[j>>2]|0;if((z|0)<(Pa|0)){Ca=z;k=Na;R=Oa}else{break}}Qa=Na;Ra=Oa;Sa=Pa;Ta=ua;Ua=c[Da>>2]|0}else{Qa=Fa;Ra=q;Sa=ya;Ta=Ia;Ua=Ha}R=Ga+1|0;if((R|0)<(Ua|0)){Ga=R;Fa=Qa+((c[Aa>>2]|0)-Sa)|0;q=Ra+(Ta-Sa)|0;ya=Sa;Ia=Ta;Ha=Ua}else{break}}}xa=xa+1|0;}while((xa|0)<(t|0))}c[Ma>>2]=0;c[o+4>>2]=1;c[o+8>>2]=2;c[o+12>>2]=3;Va=y;Wa=y}else{$7(ra,o|0,c[(c[c[v>>2]>>2]|0)+24>>2]|0,sa,za);Va=0;Wa=F}F=b;yDb(F,48,2112400,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;b=s;s=c[sa>>2]|0;v=c[za>>2]|0;yDb(F,48,2053824,(A=i,i=i+32|0,c[A>>2]=c[b+(s<<2)>>2],c[A+8>>2]=v,c[A+16>>2]=s,c[A+24>>2]=v>>4,A)|0);i=A;v=p+4|0;s=c[v>>2]|0;ra=c[Ja>>2]|0;yDb(F,48,2053824,(A=i,i=i+32|0,c[A>>2]=c[b+(s<<2)>>2],c[A+8>>2]=ra,c[A+16>>2]=s,c[A+24>>2]=ra>>4,A)|0);i=A;ra=p+8|0;s=c[ra>>2]|0;y=c[Ka>>2]|0;yDb(F,48,2053824,(A=i,i=i+32|0,c[A>>2]=c[b+(s<<2)>>2],c[A+8>>2]=y,c[A+16>>2]=s,c[A+24>>2]=y>>4,A)|0);i=A;y=p+12|0;p=c[y>>2]|0;s=c[La>>2]|0;yDb(F,48,2053824,(A=i,i=i+32|0,c[A>>2]=c[b+(p<<2)>>2],c[A+8>>2]=s,c[A+16>>2]=p,c[A+24>>2]=s>>4,A)|0);i=A;yDb(F,48,2008120,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;c[m>>2]=e+4;F=e;if((((ba(ta,ua)|0)/2|0)+42|0)>(f|0)){yDb(0,16,1970048,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;Xa=-1397118274}else{f=ua<<1;s=o|0;a8(m,Wa,f,ua,ta+1>>1,s);o=(c[m>>2]|0)-F|0;a8(m,Wa+ua|0,f,ua,ta>>1,s);s=c[m>>2]|0;f=e+2|0;x=de(s-F&65535|0)|0;a[f]=x;x=x>>8;a[f+1|0]=x;f=s;x=de(((c[g+4>>2]|0)*90|0)>>>10&65535|0)|0;a[f]=x;x=x>>8;a[f+1|0]=x;f=(c[m>>2]|0)+2|0;c[m>>2]=f;s=f;x=de(22-F+f&65535|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;s=c[m>>2]|0;c[m>>2]=s+3;a[s+2|0]=3;s=(c[y>>2]<<4|c[ra>>2])&255;ra=c[m>>2]|0;c[m>>2]=ra+1;a[ra]=s;s=(c[v>>2]<<4|c[sa>>2])&255;sa=c[m>>2]|0;c[m>>2]=sa+1;a[sa]=s;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=4;s=((c[Ka>>2]|0)>>>4|c[La>>2]&240)&255;La=c[m>>2]|0;c[m>>2]=La+1;a[La]=s;s=((c[za>>2]|0)>>>4|c[Ja>>2]&240)&255;Ja=c[m>>2]|0;c[m>>2]=Ja+1;a[Ja]=s;s=wa-1+ua|0;ua=va-1+ta|0;ta=c[m>>2]|0;c[m>>2]=ta+1;a[ta]=5;ta=c[m>>2]|0;c[m>>2]=ta+1;a[ta]=wa>>>4;ta=c[m>>2]|0;c[m>>2]=ta+1;a[ta]=s>>>8&15|wa<<4;wa=c[m>>2]|0;c[m>>2]=wa+1;a[wa]=s;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=va>>>4;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=ua>>>8&15|va<<4;va=c[m>>2]|0;c[m>>2]=va+1;a[va]=ua;ua=c[m>>2]|0;c[m>>2]=ua+1;a[ua]=6;ua=c[m>>2]|0;x=1024;a[ua]=x;x=x>>8;a[ua+1|0]=x;ua=(c[m>>2]|0)+2|0;c[m>>2]=ua;va=ua;x=de(o&65535|0)|0;a[va]=x;x=x>>8;a[va+1|0]=x;va=c[m>>2]|0;c[m>>2]=va+3;a[va+2|0]=1;va=c[m>>2]|0;c[m>>2]=va+1;a[va]=-1;va=de(((c[g+8>>2]|0)*90|0)>>>10&65535|0)|0;g=c[m>>2]|0;x=va;a[g]=x;x=x>>8;a[g+1|0]=x;g=(c[m>>2]|0)+2|0;c[m>>2]=g;va=g;x=de(65534-F+g&65535|0)|0;a[va]=x;x=x>>8;a[va+1|0]=x;va=c[m>>2]|0;c[m>>2]=va+3;a[va+2|0]=2;va=c[m>>2]|0;c[m>>2]=va+1;a[va]=-1;va=(c[m>>2]|0)-F|0;g=e;x=de(va&65535|0)|0;a[g]=x;x=x>>8;a[g+1|0]=x;yDb(0,48,1941376,(A=i,i=i+8|0,c[A>>2]=va,A)|0);i=A;Xa=(c[m>>2]|0)-F|0}ZDb(Va);u=Xa;i=h;return u|0}function $7(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g|0;j=a;c[h>>2]=c[j+(c[e>>2]<<2)>>2]|c[f>>2]<<24;c[h+4>>2]=c[j+(c[e+4>>2]<<2)>>2]|c[f+4>>2]<<24;c[h+8>>2]=c[j+(c[e+8>>2]<<2)>>2]|c[f+8>>2]<<24;c[h+12>>2]=c[j+(c[e+12>>2]<<2)>>2]|c[f+12>>2]<<24;f=0;do{e=d+(f<<2)|0;j=b+(f<<2)|0;a=0;k=2147483647;while(1){l=c[h+(a<<2)>>2]|0;m=c[e>>2]|0;n=l>>>28;o=m>>>28;p=(l>>>24<<3)-(m>>>24<<3)|0;q=(ba(l>>>16&255,n)|0)-(ba(m>>>16&255,o)|0)|0;r=(ba(l>>>8&255,n)|0)-(ba(m>>>8&255,o)|0)|0;s=(ba(l&255,n)|0)-(ba(o,m&255)|0)|0;m=(ba(s,s)|0)+(ba(p,p)|0)+(ba(q,q)|0)+(ba(r,r)|0)|0;if((m|0)<(k|0)){c[j>>2]=a;t=m}else{t=k}m=a+1|0;if((m|0)<4){a=m;k=t}else{break}}f=f+1|0;}while((f|0)<256);i=g;return}function a8(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;j=i;k=c[b>>2]|0;if((g|0)<=0){l=k;c[b>>2]=l;i=j;return}m=(f|0)>0;n=d;d=k;k=0;o=0;a:while(1){do{if(m){p=d;q=k;r=0;s=0;while(1){t=a[n+s|0]|0;u=t&255;v=1;while(1){w=v+s|0;if((w|0)>=(f|0)){break}if((a[n+w|0]|0)==t<<24>>24){v=v+1|0}else{break}}t=c[h+(u<<2)>>2]|0;if((t|0)>=4){x=8;break a}do{if((v|0)<4){y=r+1|0;z=t|v<<2;if((r&1|0)==0){A=v;B=y;C=z<<4;D=p;break}else{a[p]=z&15|q;A=v;B=y;C=q;D=p+1|0;break}}else{if((v|0)<16){y=v>>>2;if((r&1|0)==0){z=y<<4;a[p]=(t|v<<2)&15|z;A=v;B=r+2|0;C=z;D=p+1|0;break}else{a[p]=y&15|q;A=v;B=r+2|0;C=(t|v<<2)<<4;D=p+1|0;break}}if((v|0)<64){if((r&1|0)==0){a[p]=v>>>2&15;A=v;B=r+3|0;C=(t|v<<2)<<4;D=p+1|0;break}else{a[p]=q;y=v>>>2<<4;a[p+1|0]=(t|v<<2)&15|y;A=v;B=r+3|0;C=y;D=p+2|0;break}}if((w|0)==(f|0)){if((r&1|0)==0){a[p]=0;a[p+1|0]=t&15;A=v;B=r+4|0;C=0;D=p+2|0;break}else{a[p]=q;a[p+1|0]=0;A=v;B=r+4|0;C=t<<4;D=p+2|0;break}}else{y=(v|0)>255?255:v;if((r&1|0)==0){a[p]=y>>>6&15;z=y>>>2<<4;a[p+1|0]=(t|y<<2)&15|z;A=y;B=r+4|0;C=z;D=p+2|0;break}else{a[p]=q;a[p+1|0]=y>>6<<4|y>>>2&15;A=y;B=r+4|0;C=(t|y<<2)<<4;D=p+2|0;break}}}}while(0);t=A+s|0;if((t|0)<(f|0)){p=D;q=C;r=B;s=t}else{break}}if((B&1|0)==0){E=D;F=C;break}a[D]=C;E=D+1|0;F=C}else{E=d;F=k}}while(0);s=o+1|0;if((s|0)<(g|0)){n=n+e|0;d=E;k=F;o=s}else{l=E;x=32;break}}if((x|0)==8){yDb(0,0,1917096,(E=i,i=i+24|0,c[E>>2]=1896416,c[E+8>>2]=2353600,c[E+16>>2]=61,E)|0);i=E;Cd()}else if((x|0)==32){c[b>>2]=l;i=j;return}}function b8(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;if((E7(b)|0)==0){g=b;h=c[b+120>>2]|0;j=c[b+124>>2]|0;k=ZEb(c[b+140>>2]|0)|0;yDb(g,16,2053752,(l=i,i=i+24|0,c[l>>2]=h,c[l+8>>2]=j,c[l+16>>2]=k,l)|0);i=l;F7(g,16);m=-22;i=f;return m|0}if((c[b+124>>2]|0)>576){yDb(b,16,2008064,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1163346256;i=f;return m|0}l=ICb()|0;c[b+804>>2]=l;if((l|0)==0){m=-12;i=f;return m|0}else{n=0}while(1){l=a[1226144+n|0]|0;do{if(!((l&255)>>>0>63>>>0)){g=l&255;k=a[1226560+n|0]|0;j=k&255;h=8164296+(g<<12)+(j<<3)+4|0;if((c[h>>2]|0)!=0){break}o=k<<24>>24!=0|0;c[8164296+(g<<12)+(j<<3)>>2]=(e[1227392+(n<<1)>>1]|0)<<o;c[h>>2]=(d[1226976+n|0]|0)+o}}while(0);l=n+1|0;if((l|0)<408){n=l}else{p=0;break}}do{n=p-1|0;l=8164296+(n<<12)|0;o=8164300+(n<<12)|0;n=1;do{h=8164296+(p<<12)+(n<<3)|0;j=8164296+(p<<12)+(n<<3)+4|0;g=c[j>>2]|0;if((g|0)==0){k=c[8164300+(n<<3)>>2]|0;q=c[l>>2]<<k|c[8164296+(n<<3)>>2];c[h>>2]=q;r=(c[o>>2]|0)+k|0;c[j>>2]=r;s=r;t=q}else{s=g;t=c[h>>2]|0}h=-n&511;c[8164296+(p<<12)+(h<<3)>>2]=t|1;c[8164296+(p<<12)+(h<<3)+4>>2]=s;n=n+1|0;}while((n|0)<256);p=p+1|0;}while((p|0)<64);m=Fkb(b)|0;i=f;return m|0}function c8(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c[b+60>>2]|0;h=E7(b)|0;i=g;c[i>>2]=h;if((h|0)==0){j=-1;return j|0}if((Ekb(h)|0)!=0){j=-1;return j|0}h=c[(c[i>>2]|0)+8>>2]|0;k=r0a(b,d,h,(h|0)<0|0?-1:0)|0;if((k|0)<0){j=k;return j|0}k=c[i>>2]|0;c[b+140>>2]=c[k+64>>2];h=g+4|0;c[h>>2]=e;e=c[b+804>>2]|0;c[e+84>>2]=1;c[e+88>>2]=1;e=d+24|0;c[g+12>>2]=c[e>>2];l=c[b+824>>2]|0;m=c[k+56>>2]|0;n=ba((c[k+16>>2]|0)*27|0,c[k+12>>2]|0)|0;o=c[k+4>>2]|0;if((o|0)==20){p=(c[k>>2]|0)==1?n-81|0:n}else if((o|0)==24){p=(c[k>>2]|0)==1?n-108|0:n}else{p=n}oe[l&63](b,650,m,0,p,12)|0;p=c[i>>2]|0;if((c[p+16>>2]|0)>0){m=g+8|0;g=c[e>>2]|0;e=0;b=p;while(1){if((c[b+12>>2]|0)>0){p=(e&255)<<3;l=g;n=0;while(1){TGb(l|0,-1|0,480)|0;a[l]=31;k=p|(n&255)<<4|7;a[l+1|0]=k;a[l+2|0]=0;o=c[i>>2]|0;q=(c[o+64>>2]|0)!=0|0;a[l+3|0]=(c[o>>2]|0)!=0?-65:63;a[l+4|0]=q|248;o=(q|120)&255;a[l+5|0]=o;a[l+6|0]=o;a[l+7|0]=o;a[l+80|0]=63;a[l+81|0]=k;a[l+82|0]=0;o=l+83|0;q=0;while(1){r=q&255;s=(n|0)<((c[(c[i>>2]|0)+12>>2]|0)/2|0|0);do{if((r<<24>>24|0)==0|(r<<24>>24|0)==6){a[o]=(s&1)<<7|15}else{t=(s&1)<<7;if(r<<24>>24==11){a[o]=t|127;break}else{a[o]=t|15;break}}}while(0);a[o+1|0]=r|-16;a[o+2|0]=-1;s=q+1|0;if((s|0)<6){o=o+8|0;q=s}else{break}}a[l+160|0]=63;a[l+161|0]=k;a[l+162|0]=1;q=l+163|0;o=0;while(1){s=o&255;t=(n|0)<((c[(c[i>>2]|0)+12>>2]|0)/2|0|0);do{if((s<<24>>24|0)==0|(s<<24>>24|0)==6){a[q]=(t&1)<<7|15}else{u=(t&1)<<7;if(s<<24>>24==11){a[q]=u|127;break}else{a[q]=u|15;break}}}while(0);a[q+1|0]=s|-16;a[q+2|0]=-1;t=o+1|0;if((t|0)<6){q=q+8|0;o=t}else{break}}o=l+240|0;q=0;while(1){a[o]=86;a[o+1|0]=k;a[o+2|0]=q;a[o+3|0]=96;a[o+4|0]=-1;a[o+5|0]=-1;t=c[i>>2]|0;a[o+6|0]=c[t+4>>2]|c[t>>2]<<5|192;a[o+7|0]=-1;t=c[(c[h>>2]|0)+300>>2]|0;r=c[m>>2]|0;u=c[r+224>>2]|0;v=c[r+228>>2]|0;w=c[r+120>>2]|0;x=c[r+124>>2]|0;a[o+8|0]=97;a[o+9|0]=63;a[o+10|0]=(~~(+(w|0)*(+(u|0)/+(v|0))/+(x|0)*10.0)|0)>16?-54:-56;a[o+11|0]=(t|0)!=0?-68:-4;a[o+12|0]=-1;a[o+48|0]=96;a[o+49|0]=-1;a[o+50|0]=-1;t=c[i>>2]|0;a[o+51|0]=c[t+4>>2]|c[t>>2]<<5|192;a[o+52|0]=-1;t=c[(c[h>>2]|0)+300>>2]|0;x=c[m>>2]|0;v=c[x+224>>2]|0;u=c[x+228>>2]|0;w=c[x+120>>2]|0;r=c[x+124>>2]|0;a[o+53|0]=97;a[o+54|0]=63;a[o+55|0]=(~~(+(w|0)*(+(v|0)/+(u|0))/+(r|0)*10.0)|0)>16?-54:-56;a[o+56|0]=(t|0)!=0?-68:-4;a[o+57|0]=-1;t=q+1|0;if((t|0)<3){o=o+80|0;q=t}else{break}}q=l+480|0;o=0;do{if(((o|0)%15|0|0)==0){TGb(q|0,-1|0,80)|0;a[q]=118;a[q+1|0]=k;a[q+2|0]=(o|0)/15|0;y=q+80|0}else{y=q}a[y]=-106;a[y+1|0]=k;a[y+2|0]=o;q=y+80|0;o=o+1|0;}while((o|0)<135);o=n+1|0;k=c[i>>2]|0;if((o|0)<(c[k+12>>2]|0)){l=q;n=o}else{z=q;A=k;break}}}else{z=g;A=b}n=e+1|0;if((n|0)<(c[A+16>>2]|0)){g=z;e=n;b=A}else{break}}}A=d+36|0;c[A>>2]=c[A>>2]|1;c[f>>2]=1;j=0;return j|0}function d8(a){a=a|0;JCb(a+804|0);return 0}function e8(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0;h=i;i=i+14384|0;j=h|0;k=h+128|0;l=h+280|0;m=h+13400|0;n=h+14360|0;o=c[f+60>>2]|0;p=o;q=g;r=h+152|0;s=n;c[s>>2]=c[336780];c[s+4>>2]=c[336781];c[s+8>>2]=c[336782];c[s+12>>2]=c[336783];c[s+16>>2]=c[336784];s=e[g>>1]|0;g=o+12|0;t=c[g>>2]|0;u=l|0;v=o;w=o+4|0;y=j;z=j|0;A=o+8|0;B=o+144|0;C=o+164|0;o=u;D=0;E=0;while(1){F=b[q+2+(E<<1)>>1]|0;G=F&65535;H=G&255;I=G>>>8;G=c[v>>2]|0;J=c[G+32>>2]|0;do{if((J|0)==720){if(!((a[(c[g>>2]|0)+1|0]&12)==0)){K=I;break}K=I-((F&65535)>>>0>4607>>>0?18:-72)|0}else{K=I}}while(0);I=c[G+64>>2]|0;if((I|0)==0){L=9}else if((I|0)==7){if(H>>>0>87>>>0){L=9}else{L=7}}else{L=7}do{if((L|0)==7){L=0;if((J|0)<=719){M=16;N=K;break}if((K|0)==134){M=16;N=134}else{L=9}}}while(0);if((L|0)==9){L=0;M=c[(c[w>>2]|0)+32>>2]<<3;N=K}J=c[w>>2]|0;I=c[J>>2]|0;F=c[J+32>>2]|0;J=(ba(F,N)|0)+H<<3;O=I+J|0;P=(c[G+4>>2]|0)==4;a[o+320|0]=0;c[o+324>>2]=0;c[o+52>>2]=0;TGb(o|0,0,16)|0;if((O|0)==0){TGb(y|0,0,128)|0;c[o+60>>2]=0;Q=0;R=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){S=0}else{T=(Pe[c[C>>2]&255](0,O,0,F,8)|0)-400|0;if((T|0)<=0){S=0;break}U=F<<1;V=Pe[c[C>>2]&255](0,O,0,U,4)|0;S=(T|0)>((Pe[c[C>>2]&255](0,I+(J+F)|0,0,U,4)|0)+V|0)|0}}while(0);G=o+60|0;c[G>>2]=S;Xe[c[B>>2]&4095](z,O,F);me[c[p+148+(c[G>>2]<<2)>>2]&511](z);Q=b[z>>1]|0;R=(c[G>>2]|0)!=0}b[o+64>>1]=Q;G=R?1076040:1075976;V=R?1345688:1345432;U=0;T=-1;W=0;X=1;while(1){c[o+32+(U<<2)>>2]=W;Y=o+16+(U<<2)|0;c[Y>>2]=1;Z=U+1|0;_=c[679592+(Z<<2)>>2]|0;$=X&255;if((X|0)<(_|0)){aa=X+1|0;ca=X;da=T;ea=W;while(1){fa=b[j+(d[G+ca|0]<<1)>>1]|0;ga=fa<<16>>16;if((ga+15|0)>>>0>30>>>0){a[o+256+ca|0]=ga>>>31;ha=(ba(c[V+(ca<<2)>>2]|0,fa<<16>>16>-1?ga:-ga|0)|0)+2097152>>22;b[o+64+(ca<<1)>>1]=ha;c[Y>>2]=(c[Y>>2]|0)+(c[8164296+(ca+~ea<<12)+(ha<<3)+4>>2]|0);a[o+192+ea|0]=ca;ia=ca;ja=(ha|0)>(da|0)?ha:da}else{ia=ea;ja=da}ha=ca+1|0;if((ha|0)<(_|0)){ca=ha;da=ja;ea=ia}else{break}}ka=((_|0)>(aa|0)?_:aa)&255;la=ja;ma=ia}else{ka=$;la=T;ma=W}if((Z|0)<4){U=Z;T=la;W=ma;X=_}else{break}}a[o+192+ma|0]=ka;X=o+56|0;W=0;while(1){c[X>>2]=W;if((la|0)>(c[1347104+(W<<2)>>2]|0)){W=W+1|0}else{break}}c[X>>2]=W;if((W|0)>2){c[X>>2]=3;T=d[o+192|0]|0;U=0;V=0;while(1){c[o+32+(U<<2)>>2]=V;G=o+16+(U<<2)|0;c[G>>2]=1;O=U+1|0;ea=c[679592+(O<<2)>>2]|0;if((T|0)<(ea|0)){da=T;ca=V;while(1){Y=o+64+(da<<1)|0;ha=(b[Y>>1]|0)>>>1&65535;b[Y>>1]=ha;if(ha<<16>>16==0){na=ca}else{c[G>>2]=(c[G>>2]|0)+(c[8164296+(da+~ca<<12)+(ha<<16>>16<<3)+4>>2]|0);a[o+192+ca|0]=da;na=da}ha=d[o+192+da|0]|0;if((ha|0)<(ea|0)){da=ha;ca=na}else{oa=ha;pa=na;break}}}else{oa=T;pa=V}if((O|0)<4){T=oa;U=O;V=pa}else{break}}a[o+192+pa|0]=oa}V=(c[o+20>>2]|0)+(c[o+16>>2]|0)+(c[o+24>>2]|0)+(c[o+28>>2]|0)|0;U=o+328|0;if(P){a[o+648|0]=0;c[o+652>>2]=0;c[o+380>>2]=0;TGb(U|0,0,16)|0;TGb(y|0,0,128)|0;c[o+388>>2]=0;b[o+392>>1]=0;T=0;X=-1;W=0;ca=1;while(1){c[o+360+(T<<2)>>2]=W;da=o+344+(T<<2)|0;c[da>>2]=1;ea=T+1|0;G=c[679592+(ea<<2)>>2]|0;_=ca&255;if((ca|0)<(G|0)){Z=ca+1|0;$=ca;aa=X;ha=W;while(1){Y=b[j+(d[1075976+$|0]<<1)>>1]|0;ga=Y<<16>>16;if((ga+15|0)>>>0>30>>>0){a[o+584+$|0]=ga>>>31;fa=(ba(c[1345432+($<<2)>>2]|0,Y<<16>>16>-1?ga:-ga|0)|0)+2097152>>22;b[o+392+($<<1)>>1]=fa;c[da>>2]=(c[da>>2]|0)+(c[8164296+($+~ha<<12)+(fa<<3)+4>>2]|0);a[o+520+ha|0]=$;qa=$;ra=(fa|0)>(aa|0)?fa:aa}else{qa=ha;ra=aa}fa=$+1|0;if((fa|0)<(G|0)){$=fa;aa=ra;ha=qa}else{break}}sa=((G|0)>(Z|0)?G:Z)&255;ta=ra;ua=qa}else{sa=_;ta=X;ua=W}if((ea|0)<4){T=ea;X=ta;W=ua;ca=G}else{break}}a[o+520+ua|0]=sa;ca=o+384|0;W=0;while(1){c[ca>>2]=W;if((ta|0)>(c[1347104+(W<<2)>>2]|0)){W=W+1|0}else{break}}c[ca>>2]=W;if((W|0)>2){c[ca>>2]=3;X=d[o+520|0]|0;T=0;P=0;while(1){c[o+360+(T<<2)>>2]=P;ha=o+344+(T<<2)|0;c[ha>>2]=1;aa=T+1|0;$=c[679592+(aa<<2)>>2]|0;if((X|0)<($|0)){da=X;O=P;while(1){fa=o+392+(da<<1)|0;ga=(b[fa>>1]|0)>>>1&65535;b[fa>>1]=ga;if(ga<<16>>16==0){va=O}else{c[ha>>2]=(c[ha>>2]|0)+(c[8164296+(da+~O<<12)+(ga<<16>>16<<3)+4>>2]|0);a[o+520+O|0]=da;va=da}ga=d[o+520+da|0]|0;if((ga|0)<($|0)){da=ga;O=va}else{wa=ga;xa=va;break}}}else{wa=X;xa=P}if((aa|0)<4){X=wa;T=aa;P=xa}else{break}}a[o+520+xa|0]=wa}P=c[o+344>>2]|0;T=c[o+348>>2]|0;X=c[o+352>>2]|0;ca=c[o+356>>2]|0;W=J+8|0;O=I+W|0;a[o+976|0]=0;c[o+980>>2]=0;c[o+708>>2]=0;TGb(o+656|0,0,16)|0;if((O|0)==0){TGb(y|0,0,128)|0;c[o+716>>2]=0;ya=0;za=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){Aa=0}else{da=(Pe[c[C>>2]&255](0,O,0,F,8)|0)-400|0;if((da|0)<=0){Aa=0;break}$=F<<1;ha=Pe[c[C>>2]&255](0,O,0,$,4)|0;Aa=(da|0)>((Pe[c[C>>2]&255](0,I+(W+F)|0,0,$,4)|0)+ha|0)|0}}while(0);W=o+716|0;c[W>>2]=Aa;Xe[c[B>>2]&4095](z,O,F);me[c[p+148+(c[W>>2]<<2)>>2]&511](z);ya=b[z>>1]|0;za=(c[W>>2]|0)!=0}b[o+720>>1]=ya;W=za?1076040:1075976;ha=za?1345688:1345432;$=0;da=-1;G=0;ea=1;while(1){c[o+688+($<<2)>>2]=G;_=o+672+($<<2)|0;c[_>>2]=1;Z=$+1|0;ga=c[679592+(Z<<2)>>2]|0;fa=ea&255;if((ea|0)<(ga|0)){Y=ea+1|0;Ba=ea;Ca=da;Da=G;while(1){Ea=b[j+(d[W+Ba|0]<<1)>>1]|0;Fa=Ea<<16>>16;if((Fa+15|0)>>>0>30>>>0){a[o+912+Ba|0]=Fa>>>31;Ga=(ba(c[ha+(Ba<<2)>>2]|0,Ea<<16>>16>-1?Fa:-Fa|0)|0)+2097152>>22;b[o+720+(Ba<<1)>>1]=Ga;c[_>>2]=(c[_>>2]|0)+(c[8164296+(Ba+~Da<<12)+(Ga<<3)+4>>2]|0);a[o+848+Da|0]=Ba;Ha=Ba;Ia=(Ga|0)>(Ca|0)?Ga:Ca}else{Ha=Da;Ia=Ca}Ga=Ba+1|0;if((Ga|0)<(ga|0)){Ba=Ga;Ca=Ia;Da=Ha}else{break}}Ja=((ga|0)>(Y|0)?ga:Y)&255;Ka=Ia;La=Ha}else{Ja=fa;Ka=da;La=G}if((Z|0)<4){$=Z;da=Ka;G=La;ea=ga}else{break}}a[o+848+La|0]=Ja;ea=o+712|0;G=0;while(1){c[ea>>2]=G;if((Ka|0)>(c[1347104+(G<<2)>>2]|0)){G=G+1|0}else{break}}c[ea>>2]=G;if((G|0)>2){c[ea>>2]=3;da=d[o+848|0]|0;$=0;ha=0;while(1){c[o+688+($<<2)>>2]=ha;W=o+672+($<<2)|0;c[W>>2]=1;O=$+1|0;Da=c[679592+(O<<2)>>2]|0;if((da|0)<(Da|0)){Ca=da;Ba=ha;while(1){_=o+720+(Ca<<1)|0;aa=(b[_>>1]|0)>>>1&65535;b[_>>1]=aa;if(aa<<16>>16==0){Ma=Ba}else{c[W>>2]=(c[W>>2]|0)+(c[8164296+(Ca+~Ba<<12)+(aa<<16>>16<<3)+4>>2]|0);a[o+848+Ba|0]=Ca;Ma=Ca}aa=d[o+848+Ca|0]|0;if((aa|0)<(Da|0)){Ca=aa;Ba=Ma}else{Na=aa;Oa=Ma;break}}}else{Na=da;Oa=ha}if((O|0)<4){da=Na;$=O;ha=Oa}else{break}}a[o+848+Oa|0]=Na}ha=c[o+672>>2]|0;$=c[o+676>>2]|0;da=c[o+680>>2]|0;ea=c[o+684>>2]|0;a[o+1304|0]=0;c[o+1308>>2]=0;c[o+1036>>2]=0;TGb(o+984|0,0,16)|0;TGb(y|0,0,128)|0;c[o+1044>>2]=0;b[o+1048>>1]=0;G=0;Ba=-1;Ca=0;Da=1;while(1){c[o+1016+(G<<2)>>2]=Ca;W=o+1e3+(G<<2)|0;c[W>>2]=1;ga=G+1|0;Z=c[679592+(ga<<2)>>2]|0;fa=Da&255;if((Da|0)<(Z|0)){Y=Da+1|0;aa=Da;_=Ba;Ga=Ca;while(1){Fa=b[j+(d[1075976+aa|0]<<1)>>1]|0;Ea=Fa<<16>>16;if((Ea+15|0)>>>0>30>>>0){a[o+1240+aa|0]=Ea>>>31;Pa=(ba(c[1345432+(aa<<2)>>2]|0,Fa<<16>>16>-1?Ea:-Ea|0)|0)+2097152>>22;b[o+1048+(aa<<1)>>1]=Pa;c[W>>2]=(c[W>>2]|0)+(c[8164296+(aa+~Ga<<12)+(Pa<<3)+4>>2]|0);a[o+1176+Ga|0]=aa;Qa=aa;Ra=(Pa|0)>(_|0)?Pa:_}else{Qa=Ga;Ra=_}Pa=aa+1|0;if((Pa|0)<(Z|0)){aa=Pa;_=Ra;Ga=Qa}else{break}}Sa=((Z|0)>(Y|0)?Z:Y)&255;Ta=Ra;Ua=Qa}else{Sa=fa;Ta=Ba;Ua=Ca}if((ga|0)<4){G=ga;Ba=Ta;Ca=Ua;Da=Z}else{break}}a[o+1176+Ua|0]=Sa;Da=o+1040|0;Ca=0;while(1){c[Da>>2]=Ca;if((Ta|0)>(c[1347104+(Ca<<2)>>2]|0)){Ca=Ca+1|0}else{break}}c[Da>>2]=Ca;if((Ca|0)>2){c[Da>>2]=3;Ba=d[o+1176|0]|0;G=0;Ga=0;while(1){c[o+1016+(G<<2)>>2]=Ga;_=o+1e3+(G<<2)|0;c[_>>2]=1;aa=G+1|0;W=c[679592+(aa<<2)>>2]|0;if((Ba|0)<(W|0)){O=Ba;Pa=Ga;while(1){Ea=o+1048+(O<<1)|0;Fa=(b[Ea>>1]|0)>>>1&65535;b[Ea>>1]=Fa;if(Fa<<16>>16==0){Va=Pa}else{c[_>>2]=(c[_>>2]|0)+(c[8164296+(O+~Pa<<12)+(Fa<<16>>16<<3)+4>>2]|0);a[o+1176+Pa|0]=O;Va=O}Fa=d[o+1176+O|0]|0;if((Fa|0)<(W|0)){O=Fa;Pa=Va}else{Wa=Fa;Xa=Va;break}}}else{Wa=Ba;Xa=Ga}if((aa|0)<4){Ba=Wa;G=aa;Ga=Xa}else{break}}a[o+1176+Xa|0]=Wa}Ya=P+V+T+X+ca+ha+$+da+ea+(c[o+1e3>>2]|0)+(c[o+1004>>2]|0)+(c[o+1008>>2]|0)+(c[o+1012>>2]|0)|0}else{Ga=J+8|0;G=I+Ga|0;a[o+648|0]=0;c[o+652>>2]=0;c[o+380>>2]=0;TGb(U|0,0,16)|0;if((G|0)==0){TGb(y|0,0,128)|0;c[o+388>>2]=0;Za=0;_a=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){$a=0}else{Ba=(Pe[c[C>>2]&255](0,G,0,F,8)|0)-400|0;if((Ba|0)<=0){$a=0;break}Da=F<<1;Ca=Pe[c[C>>2]&255](0,G,0,Da,4)|0;$a=(Ba|0)>((Pe[c[C>>2]&255](0,I+(Ga+F)|0,0,Da,4)|0)+Ca|0)|0}}while(0);U=o+388|0;c[U>>2]=$a;Xe[c[B>>2]&4095](z,G,F);me[c[p+148+(c[U>>2]<<2)>>2]&511](z);Za=b[z>>1]|0;_a=(c[U>>2]|0)!=0}b[o+392>>1]=Za;U=_a?1076040:1075976;ea=_a?1345688:1345432;da=0;$=-1;ha=0;ca=1;while(1){c[o+360+(da<<2)>>2]=ha;X=o+344+(da<<2)|0;c[X>>2]=1;T=da+1|0;P=c[679592+(T<<2)>>2]|0;Ca=ca&255;if((ca|0)<(P|0)){Da=ca+1|0;Ba=ca;Pa=$;O=ha;while(1){W=b[j+(d[U+Ba|0]<<1)>>1]|0;_=W<<16>>16;if((_+15|0)>>>0>30>>>0){a[o+584+Ba|0]=_>>>31;Z=(ba(c[ea+(Ba<<2)>>2]|0,W<<16>>16>-1?_:-_|0)|0)+2097152>>22;b[o+392+(Ba<<1)>>1]=Z;c[X>>2]=(c[X>>2]|0)+(c[8164296+(Ba+~O<<12)+(Z<<3)+4>>2]|0);a[o+520+O|0]=Ba;ab=Ba;bb=(Z|0)>(Pa|0)?Z:Pa}else{ab=O;bb=Pa}Z=Ba+1|0;if((Z|0)<(P|0)){Ba=Z;Pa=bb;O=ab}else{break}}cb=((P|0)>(Da|0)?P:Da)&255;db=bb;eb=ab}else{cb=Ca;db=$;eb=ha}if((T|0)<4){da=T;$=db;ha=eb;ca=P}else{break}}a[o+520+eb|0]=cb;ca=o+384|0;ha=0;while(1){c[ca>>2]=ha;if((db|0)>(c[1347104+(ha<<2)>>2]|0)){ha=ha+1|0}else{break}}c[ca>>2]=ha;if((ha|0)>2){c[ca>>2]=3;$=d[o+520|0]|0;da=0;ea=0;while(1){c[o+360+(da<<2)>>2]=ea;U=o+344+(da<<2)|0;c[U>>2]=1;G=da+1|0;O=c[679592+(G<<2)>>2]|0;if(($|0)<(O|0)){Pa=$;Ba=ea;while(1){X=o+392+(Pa<<1)|0;aa=(b[X>>1]|0)>>>1&65535;b[X>>1]=aa;if(aa<<16>>16==0){fb=Ba}else{c[U>>2]=(c[U>>2]|0)+(c[8164296+(Pa+~Ba<<12)+(aa<<16>>16<<3)+4>>2]|0);a[o+520+Ba|0]=Pa;fb=Pa}aa=d[o+520+Pa|0]|0;if((aa|0)<(O|0)){Pa=aa;Ba=fb}else{gb=aa;hb=fb;break}}}else{gb=$;hb=ea}if((G|0)<4){$=gb;da=G;ea=hb}else{break}}a[o+520+hb|0]=gb}ea=c[o+344>>2]|0;da=c[o+348>>2]|0;$=c[o+352>>2]|0;ca=c[o+356>>2]|0;ha=J+M|0;Ba=I+ha|0;a[o+976|0]=0;c[o+980>>2]=0;c[o+708>>2]=0;TGb(o+656|0,0,16)|0;if((Ba|0)==0){TGb(y|0,0,128)|0;c[o+716>>2]=0;ib=0;jb=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){kb=0}else{Pa=(Pe[c[C>>2]&255](0,Ba,0,F,8)|0)-400|0;if((Pa|0)<=0){kb=0;break}O=F<<1;U=Pe[c[C>>2]&255](0,Ba,0,O,4)|0;kb=(Pa|0)>((Pe[c[C>>2]&255](0,I+(ha+F)|0,0,O,4)|0)+U|0)|0}}while(0);ha=o+716|0;c[ha>>2]=kb;Xe[c[B>>2]&4095](z,Ba,F);me[c[p+148+(c[ha>>2]<<2)>>2]&511](z);ib=b[z>>1]|0;jb=(c[ha>>2]|0)!=0}b[o+720>>1]=ib;ha=jb?1076040:1075976;J=jb?1345688:1345432;U=0;O=-1;Pa=0;P=1;while(1){c[o+688+(U<<2)>>2]=Pa;T=o+672+(U<<2)|0;c[T>>2]=1;Ca=U+1|0;Da=c[679592+(Ca<<2)>>2]|0;aa=P&255;if((P|0)<(Da|0)){X=P+1|0;Z=P;_=O;W=Pa;while(1){ga=b[j+(d[ha+Z|0]<<1)>>1]|0;fa=ga<<16>>16;if((fa+15|0)>>>0>30>>>0){a[o+912+Z|0]=fa>>>31;Y=(ba(c[J+(Z<<2)>>2]|0,ga<<16>>16>-1?fa:-fa|0)|0)+2097152>>22;b[o+720+(Z<<1)>>1]=Y;c[T>>2]=(c[T>>2]|0)+(c[8164296+(Z+~W<<12)+(Y<<3)+4>>2]|0);a[o+848+W|0]=Z;lb=Z;mb=(Y|0)>(_|0)?Y:_}else{lb=W;mb=_}Y=Z+1|0;if((Y|0)<(Da|0)){Z=Y;_=mb;W=lb}else{break}}nb=((Da|0)>(X|0)?Da:X)&255;ob=mb;pb=lb}else{nb=aa;ob=O;pb=Pa}if((Ca|0)<4){U=Ca;O=ob;Pa=pb;P=Da}else{break}}a[o+848+pb|0]=nb;P=o+712|0;Pa=0;while(1){c[P>>2]=Pa;if((ob|0)>(c[1347104+(Pa<<2)>>2]|0)){Pa=Pa+1|0}else{break}}c[P>>2]=Pa;if((Pa|0)>2){c[P>>2]=3;O=d[o+848|0]|0;U=0;J=0;while(1){c[o+688+(U<<2)>>2]=J;ha=o+672+(U<<2)|0;c[ha>>2]=1;Ba=U+1|0;W=c[679592+(Ba<<2)>>2]|0;if((O|0)<(W|0)){_=O;Z=J;while(1){T=o+720+(_<<1)|0;G=(b[T>>1]|0)>>>1&65535;b[T>>1]=G;if(G<<16>>16==0){qb=Z}else{c[ha>>2]=(c[ha>>2]|0)+(c[8164296+(_+~Z<<12)+(G<<16>>16<<3)+4>>2]|0);a[o+848+Z|0]=_;qb=_}G=d[o+848+_|0]|0;if((G|0)<(W|0)){_=G;Z=qb}else{rb=G;sb=qb;break}}}else{rb=O;sb=J}if((Ba|0)<4){O=rb;U=Ba;J=sb}else{break}}a[o+848+sb|0]=rb}J=c[o+672>>2]|0;U=c[o+676>>2]|0;O=c[o+680>>2]|0;P=c[o+684>>2]|0;Pa=Ga+M|0;Z=I+Pa|0;a[o+1304|0]=0;c[o+1308>>2]=0;c[o+1036>>2]=0;TGb(o+984|0,0,16)|0;if((Z|0)==0){TGb(y|0,0,128)|0;c[o+1044>>2]=0;tb=0;ub=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){vb=0}else{_=(Pe[c[C>>2]&255](0,Z,0,F,8)|0)-400|0;if((_|0)<=0){vb=0;break}W=F<<1;ha=Pe[c[C>>2]&255](0,Z,0,W,4)|0;vb=(_|0)>((Pe[c[C>>2]&255](0,I+(Pa+F)|0,0,W,4)|0)+ha|0)|0}}while(0);Pa=o+1044|0;c[Pa>>2]=vb;Xe[c[B>>2]&4095](z,Z,F);me[c[p+148+(c[Pa>>2]<<2)>>2]&511](z);tb=b[z>>1]|0;ub=(c[Pa>>2]|0)!=0}b[o+1048>>1]=tb;Pa=ub?1076040:1075976;I=ub?1345688:1345432;Ga=0;ha=-1;W=0;_=1;while(1){c[o+1016+(Ga<<2)>>2]=W;Da=o+1e3+(Ga<<2)|0;c[Da>>2]=1;Ca=Ga+1|0;aa=c[679592+(Ca<<2)>>2]|0;X=_&255;if((_|0)<(aa|0)){G=_+1|0;T=_;Y=ha;fa=W;while(1){ga=b[j+(d[Pa+T|0]<<1)>>1]|0;Fa=ga<<16>>16;if((Fa+15|0)>>>0>30>>>0){a[o+1240+T|0]=Fa>>>31;Ea=(ba(c[I+(T<<2)>>2]|0,ga<<16>>16>-1?Fa:-Fa|0)|0)+2097152>>22;b[o+1048+(T<<1)>>1]=Ea;c[Da>>2]=(c[Da>>2]|0)+(c[8164296+(T+~fa<<12)+(Ea<<3)+4>>2]|0);a[o+1176+fa|0]=T;wb=T;xb=(Ea|0)>(Y|0)?Ea:Y}else{wb=fa;xb=Y}Ea=T+1|0;if((Ea|0)<(aa|0)){T=Ea;Y=xb;fa=wb}else{break}}yb=((aa|0)>(G|0)?aa:G)&255;zb=xb;Ab=wb}else{yb=X;zb=ha;Ab=W}if((Ca|0)<4){Ga=Ca;ha=zb;W=Ab;_=aa}else{break}}a[o+1176+Ab|0]=yb;_=o+1040|0;W=0;while(1){c[_>>2]=W;if((zb|0)>(c[1347104+(W<<2)>>2]|0)){W=W+1|0}else{break}}c[_>>2]=W;if((W|0)>2){c[_>>2]=3;ha=d[o+1176|0]|0;Ga=0;I=0;while(1){c[o+1016+(Ga<<2)>>2]=I;Pa=o+1e3+(Ga<<2)|0;c[Pa>>2]=1;F=Ga+1|0;Z=c[679592+(F<<2)>>2]|0;if((ha|0)<(Z|0)){fa=ha;Y=I;while(1){T=o+1048+(fa<<1)|0;Da=(b[T>>1]|0)>>>1&65535;b[T>>1]=Da;if(Da<<16>>16==0){Bb=Y}else{c[Pa>>2]=(c[Pa>>2]|0)+(c[8164296+(fa+~Y<<12)+(Da<<16>>16<<3)+4>>2]|0);a[o+1176+Y|0]=fa;Bb=fa}Da=d[o+1176+fa|0]|0;if((Da|0)<(Z|0)){fa=Da;Y=Bb}else{Cb=Da;Db=Bb;break}}}else{Cb=ha;Db=I}if((F|0)<4){ha=Cb;Ga=F;I=Db}else{break}}a[o+1176+Db|0]=Cb}Ya=ea+V+da+$+ca+J+U+O+P+(c[o+1e3>>2]|0)+(c[o+1004>>2]|0)+(c[o+1008>>2]|0)+(c[o+1012>>2]|0)|0}I=c[(c[v>>2]|0)+64>>2]|0;Ga=c[w>>2]|0;ha=ba(N>>((I|0)==0),c[Ga+36>>2]|0)|0;_=ha+(H>>>(((I|0)==7?2:1)>>>0))<<3;ha=(N|0)==134;W=H>>>0>87>>>0;Y=o+1312|0;fa=Ya+D|0;Z=2;Pa=Ga;Ga=I;while(1){I=(c[Pa+(Z<<2)>>2]|0)+_|0;aa=c[Pa+32+(Z<<2)>>2]|0;Ca=aa<<3;X=ha?8:Ca;if((Ga|0)==7&W){G=Ca|1;Da=Ca|2;T=Ca|3;Ba=I;Ea=r;Fa=0;while(1){a[Ea]=a[Ba]|0;a[Ea+1|0]=a[Ba+1|0]|0;a[Ea+2|0]=a[Ba+2|0]|0;a[Ea+3|0]=a[Ba+3|0]|0;a[Ea+4|0]=a[Ba+Ca|0]|0;a[Ea+5|0]=a[Ba+G|0]|0;a[Ea+6|0]=a[Ba+Da|0]|0;a[Ea+7|0]=a[Ba+T|0]|0;ga=Fa+1|0;if((ga|0)<8){Ba=Ba+aa|0;Ea=Ea+16|0;Fa=ga}else{Eb=16;Fb=r;break}}}else{Eb=aa;Fb=I}Fa=Y+328|0;a[Y+320|0]=0;c[Y+324>>2]=0;c[Y+52>>2]=0;TGb(Y|0,0,16)|0;if((Fb|0)==0){TGb(y|0,0,128)|0;c[Y+60>>2]=0;Gb=0;Hb=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){Ib=0}else{Ea=(Pe[c[C>>2]&255](0,Fb,0,Eb,8)|0)-400|0;if((Ea|0)<=0){Ib=0;break}Ba=Eb<<1;T=Pe[c[C>>2]&255](0,Fb,0,Ba,4)|0;Ib=(Ea|0)>((Pe[c[C>>2]&255](0,Fb+Eb|0,0,Ba,4)|0)+T|0)|0}}while(0);I=Y+60|0;c[I>>2]=Ib;Xe[c[B>>2]&4095](z,Fb,Eb);me[c[p+148+(c[I>>2]<<2)>>2]&511](z);Gb=b[z>>1]|0;Hb=(c[I>>2]|0)!=0}b[Y+64>>1]=Gb;I=Hb?1076040:1075976;aa=Hb?1345688:1345432;T=0;Ba=-1;Ea=0;Da=1;while(1){c[Y+32+(T<<2)>>2]=Ea;G=Y+16+(T<<2)|0;c[G>>2]=1;Ca=T+1|0;F=c[679592+(Ca<<2)>>2]|0;ga=Da&255;if((Da|0)<(F|0)){Jb=Da+1|0;Kb=Da;Lb=Ba;Mb=Ea;while(1){Nb=b[j+(d[I+Kb|0]<<1)>>1]|0;Ob=Nb<<16>>16;if((Ob+15|0)>>>0>30>>>0){a[Y+256+Kb|0]=Ob>>>31;Pb=(ba(c[aa+(Kb<<2)>>2]|0,Nb<<16>>16>-1?Ob:-Ob|0)|0)+2097152>>22;b[Y+64+(Kb<<1)>>1]=Pb;c[G>>2]=(c[G>>2]|0)+(c[8164296+(Kb+~Mb<<12)+(Pb<<3)+4>>2]|0);a[Y+192+Mb|0]=Kb;Qb=Kb;Rb=(Pb|0)>(Lb|0)?Pb:Lb}else{Qb=Mb;Rb=Lb}Pb=Kb+1|0;if((Pb|0)<(F|0)){Kb=Pb;Lb=Rb;Mb=Qb}else{break}}Sb=((F|0)>(Jb|0)?F:Jb)&255;Tb=Rb;Ub=Qb}else{Sb=ga;Tb=Ba;Ub=Ea}if((Ca|0)<4){T=Ca;Ba=Tb;Ea=Ub;Da=F}else{break}}a[Y+192+Ub|0]=Sb;Da=Y+56|0;Ea=0;while(1){c[Da>>2]=Ea;Vb=Ea+1|0;if((Tb|0)>(c[1347104+(Ea<<2)>>2]|0)){Ea=Vb}else{break}}c[Da>>2]=Vb;if((Vb|0)>2){c[Da>>2]=3;Ea=d[Y+192|0]|0;Ba=0;T=0;while(1){c[Y+32+(Ba<<2)>>2]=T;aa=Y+16+(Ba<<2)|0;c[aa>>2]=1;I=Ba+1|0;Mb=c[679592+(I<<2)>>2]|0;if((Ea|0)<(Mb|0)){Lb=Ea;Kb=T;while(1){G=Y+64+(Lb<<1)|0;Pb=(b[G>>1]|0)>>>1&65535;b[G>>1]=Pb;if(Pb<<16>>16==0){Wb=Kb}else{c[aa>>2]=(c[aa>>2]|0)+(c[8164296+(Lb+~Kb<<12)+(Pb<<16>>16<<3)+4>>2]|0);a[Y+192+Kb|0]=Lb;Wb=Lb}Pb=d[Y+192+Lb|0]|0;if((Pb|0)<(Mb|0)){Lb=Pb;Kb=Wb}else{Xb=Pb;Yb=Wb;break}}}else{Xb=Ea;Yb=T}if((I|0)<4){Ea=Xb;Ba=I;T=Yb}else{break}}a[Y+192+Yb|0]=Xb}T=(c[Y+16>>2]|0)+fa+(c[Y+20>>2]|0)+(c[Y+24>>2]|0)+(c[Y+28>>2]|0)|0;if((c[(c[v>>2]|0)+68>>2]|0)==8){Ba=Y+656|0;Ea=Fb+X|0;a[Y+648|0]=0;c[Y+652>>2]=0;c[Y+380>>2]=0;TGb(Fa|0,0,16)|0;if((Ea|0)==0){TGb(y|0,0,128)|0;c[Y+388>>2]=0;Zb=0;_b=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){$b=0}else{Da=(Pe[c[C>>2]&255](0,Ea,0,Eb,8)|0)-400|0;if((Da|0)<=0){$b=0;break}Kb=Eb<<1;Lb=Pe[c[C>>2]&255](0,Ea,0,Kb,4)|0;$b=(Da|0)>((Pe[c[C>>2]&255](0,Fb+(Eb+X)|0,0,Kb,4)|0)+Lb|0)|0}}while(0);X=Y+388|0;c[X>>2]=$b;Xe[c[B>>2]&4095](z,Ea,Eb);me[c[p+148+(c[X>>2]<<2)>>2]&511](z);Zb=b[z>>1]|0;_b=(c[X>>2]|0)!=0}b[Y+392>>1]=Zb;X=_b?1076040:1075976;Lb=_b?1345688:1345432;Kb=0;Da=-1;Mb=0;aa=1;while(1){c[Y+360+(Kb<<2)>>2]=Mb;F=Y+344+(Kb<<2)|0;c[F>>2]=1;Ca=Kb+1|0;ga=c[679592+(Ca<<2)>>2]|0;Jb=aa&255;if((aa|0)<(ga|0)){Pb=aa+1|0;G=aa;Ob=Da;Nb=Mb;while(1){ac=b[j+(d[X+G|0]<<1)>>1]|0;bc=ac<<16>>16;if((bc+15|0)>>>0>30>>>0){a[Y+584+G|0]=bc>>>31;cc=(ba(c[Lb+(G<<2)>>2]|0,ac<<16>>16>-1?bc:-bc|0)|0)+2097152>>22;b[Y+392+(G<<1)>>1]=cc;c[F>>2]=(c[F>>2]|0)+(c[8164296+(G+~Nb<<12)+(cc<<3)+4>>2]|0);a[Y+520+Nb|0]=G;dc=G;ec=(cc|0)>(Ob|0)?cc:Ob}else{dc=Nb;ec=Ob}cc=G+1|0;if((cc|0)<(ga|0)){G=cc;Ob=ec;Nb=dc}else{break}}fc=((ga|0)>(Pb|0)?ga:Pb)&255;gc=ec;hc=dc}else{fc=Jb;gc=Da;hc=Mb}if((Ca|0)<4){Kb=Ca;Da=gc;Mb=hc;aa=ga}else{break}}a[Y+520+hc|0]=fc;aa=Y+384|0;Mb=0;while(1){c[aa>>2]=Mb;ic=Mb+1|0;if((gc|0)>(c[1347104+(Mb<<2)>>2]|0)){Mb=ic}else{break}}c[aa>>2]=ic;if((ic|0)>2){c[aa>>2]=3;Mb=d[Y+520|0]|0;Da=0;Kb=0;while(1){c[Y+360+(Da<<2)>>2]=Kb;Lb=Y+344+(Da<<2)|0;c[Lb>>2]=1;X=Da+1|0;Ea=c[679592+(X<<2)>>2]|0;if((Mb|0)<(Ea|0)){Nb=Mb;Ob=Kb;while(1){G=Y+392+(Nb<<1)|0;F=(b[G>>1]|0)>>>1&65535;b[G>>1]=F;if(F<<16>>16==0){jc=Ob}else{c[Lb>>2]=(c[Lb>>2]|0)+(c[8164296+(Nb+~Ob<<12)+(F<<16>>16<<3)+4>>2]|0);a[Y+520+Ob|0]=Nb;jc=Nb}F=d[Y+520+Nb|0]|0;if((F|0)<(Ea|0)){Nb=F;Ob=jc}else{kc=F;lc=jc;break}}}else{kc=Mb;lc=Kb}if((X|0)<4){Mb=kc;Da=X;Kb=lc}else{break}}a[Y+520+lc|0]=kc}mc=(c[Y+344>>2]|0)+T+(c[Y+348>>2]|0)+(c[Y+352>>2]|0)+(c[Y+356>>2]|0)|0;nc=Ba}else{mc=T;nc=Fa}Kb=Z-1|0;if((Kb|0)==0){break}Y=nc;fa=mc;Z=Kb;Pa=c[w>>2]|0;Ga=c[(c[v>>2]|0)+64>>2]|0}Ga=E+1|0;if((Ga|0)<5){o=nc;D=mc;E=Ga}else{break}}E=n|0;D=t+(s*80|0)|0;a:do{if((mc|0)>2680){s=k+16|0;c[s>>2]=16777216;t=k+12|0;c[t>>2]=16777216;nc=k+8|0;c[nc>>2]=16777216;o=k+4|0;c[o>>2]=16777216;w=k|0;c[w>>2]=16777216;kc=n+4|0;lc=n+8|0;jc=n+12|0;ic=n+16|0;gc=u;fc=0;while(1){if((fc|0)>=5){if((c[kc>>2]|c[E>>2]|c[lc>>2]|c[jc>>2]|c[ic>>2]|0)==0){oc=2;break}else{gc=u;fc=0;continue}}hc=n+(fc<<2)|0;dc=c[hc>>2]|0;if((dc|0)==0){pc=gc}else{c[hc>>2]=dc-1;dc=k+(fc<<2)|0;c[dc>>2]=0;ec=0;j=gc;_b=0;while(1){Zb=j+56|0;z=0;p=_b;while(1){Eb=j+(z<<2)|0;B=c[Eb>>2]|0;$b=j+16+(z<<2)|0;if((B|0)==(d[1228216+((d[1228304+(c[Zb>>2]|0)|0]|0)+(c[hc>>2]|0)<<2)+z|0]|0)){qc=p;rc=z+1|0}else{c[$b>>2]=1;c[Eb>>2]=B+1;B=c[j+32+(z<<2)>>2]|0;Eb=d[j+192+B|0]|0;Fb=z+1|0;C=c[679592+(Fb<<2)>>2]|0;b:do{if((Eb|0)<(C|0)){A=z+2|0;y=679592+(A<<2)|0;Xb=B;Yb=Eb;while(1){Wb=j+192+Xb|0;Vb=~Xb;Tb=Yb;while(1){Sb=j+64+(Tb<<1)|0;sc=(b[Sb>>1]|0)>>>1&65535;b[Sb>>1]=sc;if(!(sc<<16>>16==0)){break}Sb=j+192+Tb|0;Ub=a[Sb]|0;Qb=Ub&255;if((Qb|0)>=(C|0)&(Ub&255)>>>0<64>>>0){if((Qb|0)<(c[y>>2]|0)){tc=Fb;uc=Qb}else{Qb=Fb;Rb=A;while(1){c[j+32+(Qb<<2)>>2]=Xb;Hb=d[Sb]|0;Gb=Rb+1|0;if((Hb|0)<(c[679592+(Gb<<2)>>2]|0)){tc=Rb;uc=Hb;break}else{Qb=Rb;Rb=Gb}}}Rb=b[j+64+(uc<<1)>>1]|0;Qb=j+16+(tc<<2)|0;c[Qb>>2]=(c[8164296+(uc+Vb<<12)+(Rb<<3)+4>>2]|0)-(c[8164296+(uc+~Tb<<12)+(Rb<<3)+4>>2]|0)+(c[Qb>>2]|0);c[j+32+(tc<<2)>>2]=Xb;vc=a[Sb]|0}else{vc=Ub}a[Wb]=vc;Qb=d[Sb]|0;if((Qb|0)<(C|0)){Tb=Qb}else{wc=Xb;break b}}c[$b>>2]=(c[$b>>2]|0)+(c[8164296+(Tb+Vb<<12)+(sc<<16>>16<<3)+4>>2]|0);Wb=d[j+192+Tb|0]|0;if((Wb|0)<(C|0)){Xb=Tb;Yb=Wb}else{wc=Tb;break}}}else{wc=B}}while(0);c[j+32+(Fb<<2)>>2]=wc;qc=c[dc>>2]|0;rc=Fb}xc=(c[$b>>2]|0)+qc|0;c[dc>>2]=xc;if((rc|0)<4){z=rc;p=xc}else{break}}p=ec+1|0;if((p|0)<6){ec=p;j=j+328|0;_b=xc}else{break}}if(((c[o>>2]|0)+(c[w>>2]|0)+(c[nc>>2]|0)+(c[t>>2]|0)+(c[s>>2]|0)|0)<2681){break a}else{pc=gc+1968|0}}gc=pc;fc=fc+1|0}while(1){if((oc|0)!=2){if((c[w>>2]|0)<=2680){break a}}c[w>>2]=120;fc=-oc|0;gc=0;s=u;while(1){t=c[s+32>>2]|0;nc=a[s+192+t|0]|0;c:do{if((nc&255)>>>0<64>>>0){o=t;ic=nc;while(1){jc=s+192+o|0;lc=ic;while(1){yc=lc&255;zc=b[s+64+(yc<<1)>>1]|0;if(!((zc|0)<(oc|0)&(zc|0)>(fc|0))){break}kc=s+192+yc|0;a[jc]=a[kc]|0;lc=a[kc]|0;if(!((lc&255)>>>0<64>>>0)){break c}}c[w>>2]=(c[w>>2]|0)+(c[8164296+(yc+~o<<12)+(zc<<3)+4>>2]|0);lc=a[s+192+yc|0]|0;if((lc&255)>>>0<64>>>0){o=yc;ic=lc}else{break}}}}while(0);nc=gc+1|0;if((nc|0)<30){gc=nc;s=s+328|0}else{break}}oc=oc<<1}}}while(0);oc=c[(c[v>>2]|0)+68>>2]|0;if((oc*5|0|0)>0){yc=D;D=E;E=0;while(1){zc=D+4|0;a[yc+3|0]=c[D>>2];u=yc+4|0;pc=c[v>>2]|0;xc=c[pc+68>>2]|0;do{if((xc|0)>0){rc=u;qc=E;wc=0;sc=pc;while(1){vc=(d[(c[sc+72>>2]|0)+wc|0]|0)>>>3;tc=m+(qc*24|0)|0;c[m+(qc*24|0)+20>>2]=vc<<3;c[m+(qc*24|0)+8>>2]=rc;Ac=rc+vc|0;c[m+(qc*24|0)+16>>2]=Ac;c[m+(qc*24|0)+12>>2]=rc;c[tc>>2]=((((e[l+(qc*328|0)+64>>1]|0)>>>3)+1026|0)>>>2<<1&1022|c[l+(qc*328|0)+60>>2])<<2|c[l+(qc*328|0)+56>>2];c[m+(qc*24|0)+4>>2]=20;Bc=qc+1|0;vc=m+(Bc*24|0)|0;uc=l+(qc*328|0)+320|0;k=d[uc]|0;n=l+(qc*328|0)+324|0;mc=c[n>>2]|0;c[n>>2]=0;a[uc]=0;w=l+(qc*328|0)+52|0;s=k;k=tc;tc=mc;d:while(1){mc=k+4|0;gc=c[mc>>2]|0;fc=k+12|0;nc=c[fc>>2]|0;t=k+16|0;ic=gc-32+((c[t>>2]|0)-nc<<3)|0;if((s|0)>(ic|0)){Cc=tc;Dc=s;Ec=ic;Fc=gc;Gc=nc}else{ic=k|0;o=tc;$b=s;Fb=gc;gc=nc;while(1){nc=c[ic>>2]|0;if((Fb|0)>($b|0)){Hc=Fb;Ic=nc<<$b|o;Jc=gc}else{lc=gc;x=fe(nc<<Fb|o>>>(($b-Fb|0)>>>0)|0)|0;a[lc]=x;x=x>>8;a[lc+1|0]=x;x=x>>8;a[lc+2|0]=x;x=x>>8;a[lc+3|0]=x;lc=(c[fc>>2]|0)+4|0;c[fc>>2]=lc;Hc=Fb+32|0;Ic=o;Jc=lc}c[ic>>2]=Ic;c[mc>>2]=Hc-$b;lc=c[w>>2]|0;if((lc|0)>63){break d}nc=a[l+(qc*328|0)+192+lc|0]|0;jc=nc&255;c[w>>2]=jc;if((nc&255)>>>0<64>>>0){nc=jc-lc-1|0;lc=b[l+(qc*328|0)+64+(jc<<1)>>1]|0;Kc=c[8164296+(nc<<12)+(lc<<3)+4>>2]|0;Lc=c[8164296+(nc<<12)+(lc<<3)>>2]|d[l+(qc*328|0)+256+jc|0]}else{Kc=4;Lc=6}jc=c[mc>>2]|0;lc=jc-32+((c[t>>2]|0)-Jc<<3)|0;if((Kc|0)>(lc|0)){Cc=Lc;Dc=Kc;Ec=lc;Fc=jc;Gc=Jc;break}else{o=Lc;$b=Kc;Fb=jc;gc=Jc}}}if((Ec|0)==0){Mc=Dc;Nc=Cc}else{gc=Dc-Ec|0;Fb=Cc>>>(gc>>>0);$b=k|0;o=c[$b>>2]|0;if((Fc|0)>(Ec|0)){Oc=Fc;Pc=o<<Ec|Fb}else{t=Gc;x=fe(o<<Fc|Fb>>>((Ec-Fc|0)>>>0)|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[fc>>2]=(c[fc>>2]|0)+4;Oc=Fc+32|0;Pc=Fb}c[$b>>2]=Pc;c[mc>>2]=Oc-Ec;Mc=gc;Nc=(1<<gc)-1&Cc}gc=k+24|0;if(gc>>>0<vc>>>0){s=Mc;k=gc;tc=Nc}else{L=272;break}}if((L|0)==272){L=0;a[uc]=Mc;c[n>>2]=Nc}tc=wc+1|0;k=c[v>>2]|0;Qc=c[k+68>>2]|0;if((tc|0)<(Qc|0)){rc=Ac;qc=Bc;wc=tc;sc=k}else{break}}if((Qc|0)<=0){Rc=Qc;Sc=Bc;Tc=Ac;break}sc=m+(E*24|0)|0;wc=0;qc=Qc;while(1){rc=wc+E|0;k=l+(rc*328|0)+320|0;tc=a[k]|0;e:do{if(tc<<24>>24==0){Uc=sc}else{s=m+((qc+E|0)*24|0)|0;vc=l+(rc*328|0)+324|0;w=c[vc>>2]|0;c[vc>>2]=0;a[k]=0;gc=l+(rc*328|0)+52|0;$b=tc&255;Fb=sc;t=w;while(1){w=Fb+4|0;o=c[w>>2]|0;ic=Fb+12|0;jc=c[ic>>2]|0;lc=Fb+16|0;nc=o-32+((c[lc>>2]|0)-jc<<3)|0;if(($b|0)>(nc|0)){Vc=t;Wc=$b;Xc=nc;Yc=o;Zc=jc}else{nc=Fb|0;kc=t;_b=$b;j=o;o=jc;while(1){jc=c[nc>>2]|0;if((j|0)>(_b|0)){_c=j;$c=jc<<_b|kc;ad=o}else{ec=o;x=fe(jc<<j|kc>>>((_b-j|0)>>>0)|0)|0;a[ec]=x;x=x>>8;a[ec+1|0]=x;x=x>>8;a[ec+2|0]=x;x=x>>8;a[ec+3|0]=x;ec=(c[ic>>2]|0)+4|0;c[ic>>2]=ec;_c=j+32|0;$c=kc;ad=ec}c[nc>>2]=$c;c[w>>2]=_c-_b;ec=c[gc>>2]|0;if((ec|0)>63){Uc=Fb;break e}jc=a[l+(rc*328|0)+192+ec|0]|0;dc=jc&255;c[gc>>2]=dc;if((jc&255)>>>0<64>>>0){jc=dc-ec-1|0;ec=b[l+(rc*328|0)+64+(dc<<1)>>1]|0;bd=c[8164296+(jc<<12)+(ec<<3)+4>>2]|0;cd=c[8164296+(jc<<12)+(ec<<3)>>2]|d[l+(rc*328|0)+256+dc|0]}else{bd=4;cd=6}dc=c[w>>2]|0;ec=dc-32+((c[lc>>2]|0)-ad<<3)|0;if((bd|0)>(ec|0)){Vc=cd;Wc=bd;Xc=ec;Yc=dc;Zc=ad;break}else{kc=cd;_b=bd;j=dc;o=ad}}}if((Xc|0)==0){dd=Wc;ed=Vc}else{o=Wc-Xc|0;j=Vc>>>(o>>>0);_b=Fb|0;kc=c[_b>>2]|0;if((Yc|0)>(Xc|0)){fd=Yc;gd=kc<<Xc|j}else{lc=Zc;x=fe(kc<<Yc|j>>>((Xc-Yc|0)>>>0)|0)|0;a[lc]=x;x=x>>8;a[lc+1|0]=x;x=x>>8;a[lc+2|0]=x;x=x>>8;a[lc+3|0]=x;c[ic>>2]=(c[ic>>2]|0)+4;fd=Yc+32|0;gd=j}c[_b>>2]=gd;c[w>>2]=fd-Xc;dd=o;ed=(1<<o)-1&Vc}o=Fb+24|0;if(o>>>0<s>>>0){$b=dd;Fb=o;t=ed}else{break}}a[k]=dd;c[vc>>2]=ed;Uc=Fb}}while(0);k=wc+1|0;rc=c[(c[v>>2]|0)+68>>2]|0;if((k|0)<(rc|0)){sc=Uc;wc=k;qc=rc}else{Rc=rc;Sc=Bc;Tc=Ac;break}}}else{Rc=xc;Sc=E;Tc=u}}while(0);if((Sc|0)<(Rc*5|0|0)){yc=Tc;D=zc;E=Sc}else{hd=Rc;break}}}else{hd=oc}oc=hd*5|0;if((oc|0)>0){Rc=f;Sc=m|0;E=0;D=oc;while(1){oc=l+(E*328|0)+320|0;Tc=a[oc]|0;do{if(Tc<<24>>24==0){id=Sc}else{yc=m+(D*24|0)|0;Ac=l+(E*328|0)+324|0;Bc=c[Ac>>2]|0;c[Ac>>2]=0;a[oc]=0;Uc=l+(E*328|0)+52|0;ed=Tc&255;dd=Sc;Vc=Bc;f:while(1){Bc=dd+4|0;Xc=c[Bc>>2]|0;fd=dd+12|0;gd=c[fd>>2]|0;Yc=dd+16|0;Zc=Xc-32+((c[Yc>>2]|0)-gd<<3)|0;if((ed|0)>(Zc|0)){jd=Vc;kd=ed;ld=Zc;md=Xc;nd=gd}else{Zc=dd|0;Wc=Vc;ad=ed;bd=Xc;Xc=gd;while(1){gd=c[Zc>>2]|0;if((bd|0)>(ad|0)){od=bd;pd=gd<<ad|Wc;qd=Xc}else{cd=Xc;x=fe(gd<<bd|Wc>>>((ad-bd|0)>>>0)|0)|0;a[cd]=x;x=x>>8;a[cd+1|0]=x;x=x>>8;a[cd+2|0]=x;x=x>>8;a[cd+3|0]=x;cd=(c[fd>>2]|0)+4|0;c[fd>>2]=cd;od=bd+32|0;pd=Wc;qd=cd}c[Zc>>2]=pd;c[Bc>>2]=od-ad;cd=c[Uc>>2]|0;if((cd|0)>63){L=323;break f}gd=a[l+(E*328|0)+192+cd|0]|0;_c=gd&255;c[Uc>>2]=_c;if((gd&255)>>>0<64>>>0){gd=_c-cd-1|0;cd=b[l+(E*328|0)+64+(_c<<1)>>1]|0;rd=c[8164296+(gd<<12)+(cd<<3)+4>>2]|0;sd=c[8164296+(gd<<12)+(cd<<3)>>2]|d[l+(E*328|0)+256+_c|0]}else{rd=4;sd=6}_c=c[Bc>>2]|0;cd=_c-32+((c[Yc>>2]|0)-qd<<3)|0;if((rd|0)>(cd|0)){jd=sd;kd=rd;ld=cd;md=_c;nd=qd;break}else{Wc=sd;ad=rd;bd=_c;Xc=qd}}}if((ld|0)==0){td=kd;ud=jd}else{Xc=kd-ld|0;bd=jd>>>(Xc>>>0);ad=dd|0;Wc=c[ad>>2]|0;if((md|0)>(ld|0)){vd=md;wd=Wc<<ld|bd}else{Yc=nd;x=fe(Wc<<md|bd>>>((ld-md|0)>>>0)|0)|0;a[Yc]=x;x=x>>8;a[Yc+1|0]=x;x=x>>8;a[Yc+2|0]=x;x=x>>8;a[Yc+3|0]=x;c[fd>>2]=(c[fd>>2]|0)+4;vd=md+32|0;wd=bd}c[ad>>2]=wd;c[Bc>>2]=vd-ld;td=Xc;ud=(1<<Xc)-1&jd}Xc=dd+24|0;if(Xc>>>0<yc>>>0){ed=td;dd=Xc;Vc=ud}else{L=315;break}}if((L|0)==315){L=0;Vc=td&255;a[oc]=Vc;c[Ac>>2]=ud;xd=Vc}else if((L|0)==323){L=0;xd=a[oc]|0}if(xd<<24>>24==0){id=dd;break}yDb(Rc,16,2189584,(yd=i,i=i+1|0,i=i+7&-8,c[yd>>2]=0,yd)|0);i=yd;id=dd}}while(0);oc=E+1|0;Tc=c[(c[v>>2]|0)+68>>2]|0;zc=Tc*5|0;if((oc|0)<(zc|0)){Sc=id;E=oc;D=zc}else{zd=Tc;break}}}else{zd=hd}if((zd*5|0|0)>0){Ad=0}else{Bd=0;i=h;return Bd|0}while(1){zd=c[m+(Ad*24|0)+20>>2]>>3;hd=m+(Ad*24|0)+4|0;D=c[hd>>2]|0;E=m+(Ad*24|0)|0;if((D|0)<32){id=c[E>>2]<<D;c[E>>2]=id;D=m+(Ad*24|0)+12|0;Sc=id>>>24&255;while(1){id=c[D>>2]|0;c[D>>2]=id+1;a[id]=Sc;id=c[E>>2]|0;c[E>>2]=id<<8;Rc=(c[hd>>2]|0)+8|0;c[hd>>2]=Rc;if((Rc|0)<32){Sc=id>>>16&255}else{Cd=D;break}}}else{Cd=m+(Ad*24|0)+12|0}c[hd>>2]=32;c[E>>2]=0;D=c[m+(Ad*24|0)+8>>2]|0;Sc=(c[Cd>>2]|0)-D<<3>>3;if((Sc|0)>(zd|0)){break}TGb(D+Sc|0,-1|0,zd-Sc|0)|0;Sc=Ad+1|0;if((Sc|0)<((c[(c[v>>2]|0)+68>>2]|0)*5|0|0)){Ad=Sc}else{Bd=0;L=334;break}}if((L|0)==334){i=h;return Bd|0}yDb(f,16,2112320,(yd=i,i=i+1|0,i=i+7&-8,c[yd>>2]=0,yd)|0);i=yd;Bd=-1;i=h;return Bd|0}function f8(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;e=ICb()|0;f=d;c[f>>2]=e;if((e|0)==0){g=-12;i=b;return g|0}c[a+140>>2]=11;e=ba(c[a+120>>2]<<1,c[a+124>>2]|0)|0;c[d+4>>2]=e;h=WDb(e+16|0)|0;c[d+8>>2]=h;if((h|0)!=0){g=0;i=b;return g|0}JCb(f);yDb(a,16,2308936,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-12;i=b;return g|0}function g8(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0;h=i;i=i+8|0;j=h|0;k=e;l=c[b+60>>2]|0;m=g+24|0;n=c[m>>2]|0;o=g+28|0;g=c[o>>2]|0;if(!((g|0)>-1)){yDb(0,0,1896376,(p=i,i=i+24|0,c[p>>2]=2353584,c[p+8>>2]=2333520,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}q=n+g|0;r=n;do{if((g|0)<4){s=0;t=n}else{u=n;if((d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)!=1346456899){s=0;t=n;break}u=l+12|0;v=n+(g>>>0>4>>>0?4:g)|0;w=0;while(1){if((q-v|0)<3){y=-16777216;z=v}else{y=(d[v]|0)<<16|(d[v+1|0]|0)<<8|(d[v+2|0]|0)|-16777216;z=v+3|0}c[u+(w<<2)>>2]=y;A=w+1|0;if((A|0)<256){v=z;w=A}else{s=1;t=z;break}}}}while(0);z=_$a(b,k,1)|0;if((z|0)<0){B=z;i=h;return B|0}UGb(c[e+4>>2]|0,l+12|0,1024)|0;c[e+304>>2]=s;s=e;z=c[s>>2]|0;y=l+8|0;g=c[y>>2]|0;n=l;w=c[c[n>>2]>>2]|0;v=e+32|0;u=c[v>>2]|0;do{if((q-t|0)<4){C=t;D=13}else{A=t;if((d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)!=1280070990){C=t+4|0;D=13;break}A=c[l+4>>2]|0;c[j>>2]=A;E=-1;G=A}}while(0);do{if((D|0)==13){if((q-C|0)<1){c[j>>2]=c[l+4>>2];H=C;I=0}else{t=a[C]|0;A=t&255;J=c[l+4>>2]|0;c[j>>2]=J;if(t<<24>>24==4){E=A;G=J;break}else{H=C+1|0;I=A}}A=q-H|0;J=H+(A>>>0>4>>>0?4:A)|0;if((Zb(g|0,j|0,(c[m>>2]|0)+(J-r)|0,q-J|0)|0)==0){J=c[j>>2]|0;TGb((c[y>>2]|0)+J|0,0,16)|0;E=I;G=J;break}yDb(b,16,2189560,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;B=-1313558101;i=h;return B|0}}while(0);if((c[b+688>>2]&1|0)!=0){yDb(b,48,2112296,(p=i,i=i+16|0,c[p>>2]=E,c[p+8>>2]=G,p)|0);i=p}a:do{switch(E|0){case-1:{G=e+84|0;c[G>>2]=0;I=e+88|0;c[I>>2]=2;y=c[c[n>>2]>>2]|0;q=c[s>>2]|0;r=ba(c[b+124>>2]|0,c[v>>2]|0)|0;if((y|0)==0){TGb(q|0,0,r|0)|0;c[G>>2]=1;c[I>>2]=1;break a}else{UGb(q|0,y|0,r)|0;break a}break};case 2:case 4:{c[e+84>>2]=1;c[e+88>>2]=1;r=b+124|0;if((c[r>>2]|0)<=0){break a}y=b+120|0;q=z;I=g;G=0;m=c[y>>2]|0;while(1){UGb(q|0,I|0,m)|0;H=c[y>>2]|0;C=G+1|0;if((C|0)<(c[r>>2]|0)){q=q+u|0;I=I+H|0;G=C;m=H}else{break}}break};case 3:case 5:{do{if((w|0)==0){yDb(b,16,2053720,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;if((c[b+92>>2]&4194304|0)==0){B=-1094995529}else{break}i=h;return B|0}}while(0);c[e+84>>2]=0;c[e+88>>2]=2;m=b+124|0;if((c[m>>2]|0)<=0){break a}G=b+120|0;I=z;q=g;r=w;y=0;while(1){H=c[G>>2]|0;if((r|0)==0){UGb(I|0,q|0,H)|0;K=0;L=c[G>>2]|0}else{if((H|0)>0){C=0;while(1){a[I+C|0]=a[r+C|0]^a[q+C|0];l=C+1|0;J=c[G>>2]|0;if((l|0)<(J|0)){C=l}else{M=J;break}}}else{M=H}K=r+u|0;L=M}C=y+1|0;if((C|0)<(c[m>>2]|0)){I=I+u|0;q=q+L|0;r=K;y=C}else{break}}break};case 12:case 13:{c[e+84>>2]=0;c[e+88>>2]=2;y=c[c[n>>2]>>2]|0;if((y|0)==0){yDb(b,16,2008032,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;B=-1094995529;i=h;return B|0}r=c[s>>2]|0;q=c[v>>2]|0;I=c[j>>2]|0;m=g+I|0;G=b+120|0;C=c[G>>2]|0;J=b+124|0;l=c[J>>2]|0;A=((ba(l,C)|0)>>4)+12|0;t=g;N=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=YGb(A,(A|0)<0|0?-1:0,N,0)|0;O=F;P=g+4|0;Q=fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=YGb(t,O,Q,0)|0;O=F;t=(I|0)<0|0?-1:0;if(O>>>0>t>>>0|O>>>0==t>>>0&P>>>0>I>>>0){break a}I=A+N|0;if((l|0)<=0){break a}N=q<<2;P=q+1|0;t=q<<1;O=t+q|0;R=g+12|0;S=g+A|0;A=g+I|0;T=g+(I+Q)|0;Q=y;y=0;I=r;r=0;U=C;C=l;b:while(1){if((U|0)>0){l=r-4|0;V=r-2|0;W=R;X=S;Y=A;Z=T;_=0;$=0;aa=U;while(1){if(X>>>0>m>>>0|Y>>>0>m>>>0|Z>>>0>m>>>0){break a}ca=I+_|0;da=Q+_|0;ea=W+1|0;fa=a[W]|0;ga=fa&255;switch(ga|0){case 2:{TGb(ca|0,a[X]|0,4)|0;ha=_+q|0;TGb(I+ha|0,a[X]|0,4)|0;ia=ha+q|0;TGb(I+ia|0,a[X]|0,4)|0;TGb(I+(ia+q)|0,a[X]|0,4)|0;ja=Z;ka=Y;la=X+1|0;break};case 3:{ia=X;ha=ca;x=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;ha=_+q|0;ia=X+4|0;ma=I+ha|0;x=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;a[ma]=x;x=x>>8;a[ma+1|0]=x;x=x>>8;a[ma+2|0]=x;x=x>>8;a[ma+3|0]=x;ma=ha+q|0;ha=X+8|0;ia=I+ma|0;x=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=X+12|0;ha=I+(ma+q)|0;x=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;ja=Z;ka=Y;la=X+16|0;break};case 4:{ha=d[Y]|0;ia=ha>>>4;na=(ia&8|0)==0?ia:8-ia|0;ia=ha&15;oa=(ha&8|0)==0?ia:8-ia|0;if((_|0)<(-na|0)){D=53;break b}if((aa-4+$|0)<(na|0)){D=53;break b}if((y|0)<(-oa|0)){D=53;break b}if((l+(c[J>>2]|0)|0)<(oa|0)){D=53;break b}pa=Q+((ba(oa,q)|0)+_+na)|0;qa=Y+1|0;D=55;break};case 0:case 5:{pa=da;qa=Y;D=55;break};case 1:case 10:case 11:case 12:case 13:case 14:case 15:{if(fa<<24>>24==1){fa=Z;ra=(de((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535;sa=Z+2|0}else{fa=ga-10|0;ia=d[Z]|0;ra=(ia&240)<<c[444112+(fa<<2)>>2]|(ia&15)<<c[444088+(fa<<2)>>2];sa=Z+1|0}fa=(ra&32768|0)==0;ia=fa?X:X+1|0;a[ca]=a[fa?da:X]|0;da=(ra&16384|0)==0;fa=da?ia:ia+1|0;a[I+(_|1)|0]=a[da?Q+(_|1)|0:ia]|0;ia=(ra&8192|0)==0;da=ia?fa:fa+1|0;a[I+(_|2)|0]=a[ia?Q+(_|2)|0:fa]|0;fa=(ra&4096|0)==0;ia=fa?da:da+1|0;a[I+(_|3)|0]=a[fa?Q+(_|3)|0:da]|0;da=ra<<4;fa=_+q|0;ha=_+q|0;ma=(da&32768|0)==0;ta=ma?ia:ia+1|0;a[I+fa|0]=a[ma?Q+ha|0:ia]|0;ia=(da&16384|0)==0;ma=ia?ta:ta+1|0;a[I+(fa+1)|0]=a[ia?Q+(ha+1)|0:ta]|0;ta=(da&8192|0)==0;ia=ta?ma:ma+1|0;a[I+(fa+2)|0]=a[ta?Q+(ha+2)|0:ma]|0;ma=(da&4096|0)==0;da=ma?ia:ia+1|0;a[I+(fa+3)|0]=a[ma?Q+(ha+3)|0:ia]|0;ia=ra<<8;ma=fa+q|0;fa=ha+q|0;ha=(ia&32768|0)==0;ta=ha?da:da+1|0;a[I+ma|0]=a[ha?Q+fa|0:da]|0;da=(ia&16384|0)==0;ha=da?ta:ta+1|0;a[I+(ma+1)|0]=a[da?Q+(fa+1)|0:ta]|0;ta=(ia&8192|0)==0;da=ta?ha:ha+1|0;a[I+(ma+2)|0]=a[ta?Q+(fa+2)|0:ha]|0;ha=(ia&4096|0)==0;ia=ha?da:da+1|0;a[I+(ma+3)|0]=a[ha?Q+(fa+3)|0:da]|0;da=ra<<12;ha=ma+q|0;ma=fa+q|0;fa=(da&32768|0)==0;ta=fa?ia:ia+1|0;a[I+ha|0]=a[fa?Q+ma|0:ia]|0;ia=(da&16384|0)==0;fa=ia?ta:ta+1|0;a[I+(ha+1)|0]=a[ia?Q+(ma+1)|0:ta]|0;ta=(da&8192|0)==0;ia=ta?fa:fa+1|0;a[I+(ha+2)|0]=a[ta?Q+(ma+2)|0:fa]|0;fa=(da&4096|0)==0;a[I+(ha+3)|0]=a[fa?Q+(ma+3)|0:ia]|0;ja=sa;ka=Y;la=fa?ia:ia+1|0;break};case 8:{ia=Z+1|0;fa=$-2|0;ma=_+q|0;ha=X;da=Y;ta=0;ua=d[Z]|0;while(1){va=ta<<1&2;wa=ta&2;xa=va+(ba(wa,q)|0)|0;ya=xa+_|0;za=ua&192;if((za|0)==128){Aa=d[da]|0;Ba=Aa>>>4;Ca=(Ba&8|0)==0?Ba:8-Ba|0;Ba=Aa&15;Da=(Aa&8|0)==0?Ba:8-Ba|0;if((va|_|0)<(-Ca|0)){D=66;break b}if((fa-va+(c[G>>2]|0)|0)<(Ca|0)){D=66;break b}if((wa|y|0)<(-Da|0)){D=66;break b}if((V-wa+(c[J>>2]|0)|0)<(Da|0)){D=66;break b}Ea=(ba(Da,q)|0)+ya+Ca|0;Fa=da+1|0;D=68}else if((za|0)==0){Ea=ya;Fa=da;D=68}else if((za|0)==64){a[I+ya|0]=a[ha]|0;wa=xa|1;a[I+(wa+_)|0]=a[ha]|0;a[I+(xa+ma)|0]=a[ha]|0;a[I+(wa+ma)|0]=a[ha]|0;Ga=da;Ha=ha+1|0}else if((za|0)==192){a[I+ya|0]=a[ha]|0;za=xa|1;a[I+(za+_)|0]=a[ha+1|0]|0;a[I+(xa+ma)|0]=a[ha+2|0]|0;a[I+(za+ma)|0]=a[ha+3|0]|0;Ga=da;Ha=ha+4|0}else{Ga=da;Ha=ha}if((D|0)==68){D=0;a[I+ya|0]=a[Q+Ea|0]|0;ya=xa|1;a[I+(ya+_)|0]=a[Q+(Ea+1)|0]|0;a[I+(xa+ma)|0]=a[Q+(Ea+q)|0]|0;a[I+(ya+ma)|0]=a[Q+(P+Ea)|0]|0;Ga=Fa;Ha=ha}ya=ta+1|0;if((ya|0)<4){ha=Ha;da=Ga;ta=ya;ua=ua<<2}else{ja=ia;ka=Ga;la=Ha;break}}break};case 32:{ia=Z;ua=(de((d[ia]|d[ia+1|0]<<8)<<16>>16|0)|0)&65535;a[ca]=a[X+(ua&1)|0]|0;a[I+(_|1)|0]=a[X+(ua>>>1&1)|0]|0;a[I+(_|2)|0]=a[X+(ua>>>2&1)|0]|0;a[I+(_|3)|0]=a[X+(ua>>>3&1)|0]|0;ia=_+q|0;a[I+ia|0]=a[X+(ua>>>4&1)|0]|0;a[I+(ia+1)|0]=a[X+(ua>>>5&1)|0]|0;a[I+(ia+2)|0]=a[X+(ua>>>6&1)|0]|0;a[I+(ia+3)|0]=a[X+(ua>>>7&1)|0]|0;ta=ia+q|0;a[I+ta|0]=a[X+(ua>>>8&1)|0]|0;a[I+(ta+1)|0]=a[X+(ua>>>9&1)|0]|0;a[I+(ta+2)|0]=a[X+(ua>>>10&1)|0]|0;a[I+(ta+3)|0]=a[X+(ua>>>11&1)|0]|0;ia=ta+q|0;a[I+ia|0]=a[X+(ua>>>12&1)|0]|0;a[I+(ia+1)|0]=a[X+(ua>>>13&1)|0]|0;a[I+(ia+2)|0]=a[X+(ua>>>14&1)|0]|0;a[I+(ia+3)|0]=a[X+(ua>>>15)|0]|0;ja=Z+2|0;ka=Y;la=X+2|0;break};case 33:case 34:{ua=Z;ia=fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0;a[ca]=a[X+(ia&3)|0]|0;a[I+(_|1)|0]=a[X+(ia>>>2&3)|0]|0;a[I+(_|2)|0]=a[X+(ia>>>4&3)|0]|0;a[I+(_|3)|0]=a[X+(ia>>>6&3)|0]|0;ua=_+q|0;a[I+ua|0]=a[X+(ia>>>8&3)|0]|0;a[I+(ua+1)|0]=a[X+(ia>>>10&3)|0]|0;a[I+(ua+2)|0]=a[X+(ia>>>12&3)|0]|0;a[I+(ua+3)|0]=a[X+(ia>>>14&3)|0]|0;ta=ua+q|0;a[I+ta|0]=a[X+(ia>>>16&3)|0]|0;a[I+(ta+1)|0]=a[X+(ia>>>18&3)|0]|0;a[I+(ta+2)|0]=a[X+(ia>>>20&3)|0]|0;a[I+(ta+3)|0]=a[X+(ia>>>22&3)|0]|0;ua=ta+q|0;a[I+ua|0]=a[X+(ia>>>24&3)|0]|0;a[I+(ua+1)|0]=a[X+(ia>>>26&3)|0]|0;a[I+(ua+2)|0]=a[X+(ia>>>28&3)|0]|0;a[I+(ua+3)|0]=a[X+(ia>>>30)|0]|0;ja=Z+4|0;ka=Y;la=X+(ga-30)|0;break};default:{D=74;break b}}if((D|0)==55){D=0;ia=pa;ua=ca;x=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;a[ua]=x;x=x>>8;a[ua+1|0]=x;x=x>>8;a[ua+2|0]=x;x=x>>8;a[ua+3|0]=x;ua=_+q|0;ia=pa+q|0;ta=I+ua|0;x=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;ta=ua+q|0;ua=pa+t|0;ia=I+ta|0;x=d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=pa+O|0;ua=I+(ta+q)|0;x=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;a[ua]=x;x=x>>8;a[ua+1|0]=x;x=x>>8;a[ua+2|0]=x;x=x>>8;a[ua+3|0]=x;ja=Z;ka=qa;la=X}ua=_+4|0;ia=-4-_|0;Ia=c[G>>2]|0;if((ua|0)<(Ia|0)){W=ea;X=la;Y=ka;Z=ja;_=ua;$=ia;aa=Ia}else{break}}Ja=ea;Ka=la;La=ka;Ma=ja;Na=Ia;Oa=c[J>>2]|0}else{Ja=R;Ka=S;La=A;Ma=T;Na=U;Oa=C}aa=y+4|0;$=-4-y|0;if((aa|0)<(Oa|0)){R=Ja;S=Ka;A=La;T=Ma;Q=Q+N|0;y=aa;I=I+N|0;r=$;U=Na;C=Oa}else{break a}}if((D|0)==53){yDb(b,16,1941344,(p=i,i=i+16|0,c[p>>2]=na,c[p+8>>2]=oa,p)|0);i=p;break a}else if((D|0)==66){yDb(b,16,1941344,(p=i,i=i+16|0,c[p>>2]=Ca,c[p+8>>2]=Da,p)|0);i=p;break a}else if((D|0)==74){yDb(b,16,1917008,(p=i,i=i+8|0,c[p>>2]=ga,p)|0);i=p;break a}break};default:{yDb(b,16,1969984,(p=i,i=i+8|0,c[p>>2]=E,p)|0);i=p;B=-1094995529;i=h;return B|0}}}while(0);KCb(c[n>>2]|0);p=MCb(c[n>>2]|0,k)|0;if((p|0)<0){B=p;i=h;return B|0}c[f>>2]=1;B=c[o>>2]|0;i=h;return B|0}function h8(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+8|0);JCb(b);return 0}function i8(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0;j=i;i=i+24|0;k=j|0;l=f;m=c[h+24>>2]|0;n=h+28|0;h=c[n>>2]|0;if((h|0)<16){yDb(e,16,2189528,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}q=m;r=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;a:do{if((r|0)==67108865){q=e+120|0;s=e+124|0;if((ba((c[q>>2]|0)*3|0,c[s>>2]|0)|0)>(h-16|0)){yDb(e,16,2189528,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=5;t=_$a(e,l,0)|0;if((t|0)<0){p=t;i=j;return p|0}t=c[s>>2]|0;if((t|0)<=0){break}u=f+32|0;v=f+36|0;w=f+40|0;x=m+16|0;y=0;z=c[f>>2]|0;A=c[f+4>>2]|0;B=c[f+8>>2]|0;C=c[q>>2]|0;D=t;while(1){if((C|0)>0){t=x;E=0;while(1){a[z+E|0]=a[t]|0;a[A+E|0]=a[t+1|0]^-128;G=t+3|0;a[B+E|0]=a[t+2|0]^-128;H=E+1|0;I=c[q>>2]|0;if((H|0)<(I|0)){t=G;E=H}else{break}}J=G;K=I;L=c[s>>2]|0}else{J=x;K=C;L=D}E=y+1|0;if((E|0)<(L|0)){x=J;y=E;z=z+(c[u>>2]|0)|0;A=A+(c[v>>2]|0)|0;B=B+(c[w>>2]|0)|0;C=K;D=L}else{break}}}else if((r|0)==16777225){D=m+16|0;C=h-16|0;if(!((C|0)>-1)){yDb(0,0,1896336,(o=i,i=i+24|0,c[o>>2]=2353544,c[o+8>>2]=2333488,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}w=m+h|0;if((C|0)<2){M=0;N=D}else{B=D;M=(d[B]|d[B+1|0]<<8)<<16>>16&65535;N=m+18|0}B=(M<<2|2)+15&524272;if(B>>>0>C>>>0){yDb(e,16,2053688,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}D=c[e+124>>2]|0;do{if((M|0)!=0){if(((D|0)%(M|0)|0|0)!=0){break}v=(D|0)/(M|0)|0;c[e+140>>2]=3;A=_$a(e,l,0)|0;if((A|0)<0){p=A;i=j;return p|0}A=e+120|0;u=f+32|0;z=k;y=k|0;x=k;s=k+8|0;q=s;E=k+16|0;t=E;H=(v|0)>0;O=x+1|0;P=x+9|0;Q=x+17|0;R=e;S=N;T=B;U=0;V=c[f>>2]|0;while(1){if((w-S|0)<4){W=0;X=25;break}Y=S+4|0;Z=S;_=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;$=C-T|0;if(_>>>0>$>>>0){X=23;break}if(_>>>0<17>>>0){W=_;X=25;break}Z=m+(T+16)|0;aa=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;Z=_-16|0;if((aa|0)!=(Z|0)){yDb(R,16,1916936,(o=i,i=i+16|0,c[o>>2]=aa,c[o+8>>2]=Z,o)|0);i=o}aa=m+(T+32)|0;ca=Z<<3;Z=ca>>>0>2147483639>>>0|(aa|0)==0;da=Z?0:aa;aa=Z?8:ca+8|0;ca=c[A>>2]|0;Z=c[u>>2]|0;c[y>>2]=1614815232;c[y+4>>2]=-4153216;c[s>>2]=1614815232;c[s+4>>2]=-4153216;c[E>>2]=1614815232;c[E+4>>2]=-4153216;if(H){ea=(ca|0)>0;fa=V;ga=0;ha=0;while(1){if(ea){ia=0;ja=ha;while(1){ka=0;la=ja;while(1){if((ka|0)>=8){ma=la;break}na=((la|0)<(aa|0))+la|0;if(((d[da+(la>>>3)|0]|0)&1<<(la&7)|0)==0){ma=na;break}else{ka=ka+1|0;la=na}}if((ka&255)<<24>>24==0){la=da+(ma>>>3)|0;na=ma+8|0;oa=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ma&7)>>>0)&255;VGb(O|0,z|0,7)|0;pa=oa;qa=aa>>>0>na>>>0?na:aa}else{na=(ka&255)-1|0;oa=a[x+na|0]|0;VGb(O|0,z|0,na|0)|0;pa=oa;qa=ma}a[z]=pa;oa=ia*3|0;a[fa+oa|0]=pa;na=0;la=qa;while(1){if((na|0)>=8){ra=la;break}sa=((la|0)<(aa|0))+la|0;if(((d[da+(la>>>3)|0]|0)&1<<(la&7)|0)==0){ra=sa;break}else{na=na+1|0;la=sa}}if((na&255)<<24>>24==0){la=da+(ra>>>3)|0;ka=ra+8|0;sa=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ra&7)>>>0)&255;VGb(P|0,q|0,7)|0;ta=sa;ua=aa>>>0>ka>>>0?ka:aa}else{ka=(na&255)-1|0;sa=a[x+8+ka|0]|0;VGb(P|0,q|0,ka|0)|0;ta=sa;ua=ra}a[q]=ta;a[fa+(oa+1)|0]=ta;sa=0;ka=ua;while(1){if((sa|0)>=8){va=ka;break}la=((ka|0)<(aa|0))+ka|0;if(((d[da+(ka>>>3)|0]|0)&1<<(ka&7)|0)==0){va=la;break}else{sa=sa+1|0;ka=la}}if((sa&255)<<24>>24==0){ka=da+(va>>>3)|0;na=va+8|0;la=(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)>>>((va&7)>>>0)&255;VGb(Q|0,t|0,7)|0;wa=la;xa=aa>>>0>na>>>0?na:aa}else{na=(sa&255)-1|0;la=a[x+16+na|0]|0;VGb(Q|0,t|0,na|0)|0;wa=la;xa=va}a[t]=wa;a[fa+(oa+2)|0]=wa;la=ia+1|0;if((la|0)<(ca|0)){ia=la;ja=xa}else{ya=xa;break}}}else{ya=ha}ja=ga+1|0;if((ja|0)<(v|0)){fa=fa+Z|0;ga=ja;ha=ya}else{break}}za=c[u>>2]|0}else{za=Z}ha=V+(ba(za,v)|0)|0;ga=U+1|0;if((ga|0)<(M|0)){S=Y;T=_+T|0;U=ga;V=ha}else{break a}}if((X|0)==23){yDb(R,16,1969920,(o=i,i=i+16|0,c[o>>2]=_,c[o+8>>2]=$,o)|0);i=o;p=-1094995529;i=j;return p|0}else if((X|0)==25){yDb(R,16,1941312,(o=i,i=i+8|0,c[o>>2]=W,o)|0);i=o;p=-1094995529;i=j;return p|0}}}while(0);C=c[e+120>>2]|0;DDb(e,2007984,(o=i,i=i+24|0,c[o>>2]=M,c[o+8>>2]=C,c[o+16>>2]=D,o)|0);i=o;p=-1163346256;i=j;return p|0}else if((r|0)==33554441){C=m+16|0;w=h-16|0;if(!((w|0)>-1)){yDb(0,0,1896336,(o=i,i=i+24|0,c[o>>2]=2353544,c[o+8>>2]=2333488,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}B=m+h|0;if((w|0)<2){Aa=0;Ba=C}else{V=C;Aa=(d[V]|d[V+1|0]<<8)<<16>>16&65535;Ba=m+18|0}V=(Aa<<2|2)+15&524272;if(V>>>0>w>>>0){yDb(e,16,2053688,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}C=c[e+124>>2]|0;do{if((Aa|0)!=0){if(((C|0)%(Aa|0)|0|0)!=0){break}U=(C|0)/(Aa|0)|0;T=e+120|0;S=c[T>>2]|0;if((S&1|0)==0){if((C&1|0)!=0){X=73}}else{X=73}if((X|0)==73){DDb(e,2308896,(o=i,i=i+16|0,c[o>>2]=S,c[o+8>>2]=C,o)|0);i=o}c[e+140>>2]=0;S=_$a(e,l,0)|0;if((S|0)<0){p=S;i=j;return p|0}S=f+32|0;v=f+36|0;u=f+40|0;t=k;Q=k|0;x=k;q=k+8|0;P=q;z=k+16|0;O=z;H=x+1|0;E=x+9|0;s=x+17|0;y=e;A=Ba;ha=0;ga=U;fa=V;ca=0;aa=c[f>>2]|0;da=c[f+4>>2]|0;ea=c[f+8>>2]|0;while(1){if((B-A|0)<4){Ca=0;X=80;break}ja=A+4|0;ia=A;Da=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;ia=(ga&-2)-(ha&-2)|0;Ea=w-fa|0;if(Da>>>0>Ea>>>0){X=78;break}if(Da>>>0<17>>>0){Ca=Da;X=80;break}la=m+(fa+16)|0;na=d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0;la=Da-16|0;if((na|0)!=(la|0)){yDb(y,16,1916936,(o=i,i=i+16|0,c[o>>2]=na,c[o+8>>2]=la,o)|0);i=o}na=m+(fa+32)|0;ka=la<<3;la=ka>>>0>2147483639>>>0|(na|0)==0;Fa=la?0:na;na=la?8:ka+8|0;ka=c[T>>2]|0;la=c[S>>2]|0;Ga=c[v>>2]|0;Ha=c[u>>2]|0;c[Q>>2]=1614815232;c[Q+4>>2]=-4153216;c[q>>2]=1614815232;c[q+4>>2]=-4153216;c[z>>2]=1614815232;c[z+4>>2]=-4153216;if((ia|0)>0){Ia=(ka|0)>0;Ja=la<<1;Ka=ea;La=da;Ma=aa;Na=0;Oa=0;while(1){if(Ia){Pa=0;Qa=Oa;while(1){Ra=0;Sa=Qa;while(1){if((Ra|0)>=8){Ta=Sa;break}Ua=((Sa|0)<(na|0))+Sa|0;if(((d[Fa+(Sa>>>3)|0]|0)&1<<(Sa&7)|0)==0){Ta=Ua;break}else{Ra=Ra+1|0;Sa=Ua}}if((Ra&255)<<24>>24==0){Sa=Fa+(Ta>>>3)|0;oa=Ta+8|0;sa=(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)>>>((Ta&7)>>>0)&255;VGb(H|0,t|0,7)|0;Va=sa;Wa=na>>>0>oa>>>0?oa:na}else{oa=(Ra&255)-1|0;sa=a[x+oa|0]|0;VGb(H|0,t|0,oa|0)|0;Va=sa;Wa=Ta}a[t]=Va;a[Ma+Pa|0]=Va;sa=0;oa=Wa;while(1){if((sa|0)>=8){Xa=oa;break}Sa=((oa|0)<(na|0))+oa|0;if(((d[Fa+(oa>>>3)|0]|0)&1<<(oa&7)|0)==0){Xa=Sa;break}else{sa=sa+1|0;oa=Sa}}if((sa&255)<<24>>24==0){oa=Fa+(Xa>>>3)|0;Ra=Xa+8|0;Sa=(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)>>>((Xa&7)>>>0)&255;VGb(H|0,t|0,7)|0;Ya=Sa;Za=na>>>0>Ra>>>0?Ra:na}else{Ra=(sa&255)-1|0;Sa=a[x+Ra|0]|0;VGb(H|0,t|0,Ra|0)|0;Ya=Sa;Za=Xa}a[t]=Ya;Sa=Pa|1;a[Ma+Sa|0]=Ya;Ra=0;oa=Za;while(1){if((Ra|0)>=8){_a=oa;break}Ua=((oa|0)<(na|0))+oa|0;if(((d[Fa+(oa>>>3)|0]|0)&1<<(oa&7)|0)==0){_a=Ua;break}else{Ra=Ra+1|0;oa=Ua}}if((Ra&255)<<24>>24==0){oa=Fa+(_a>>>3)|0;sa=_a+8|0;Ua=(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)>>>((_a&7)>>>0)&255;VGb(H|0,t|0,7)|0;$a=Ua;ab=na>>>0>sa>>>0?sa:na}else{sa=(Ra&255)-1|0;Ua=a[x+sa|0]|0;VGb(H|0,t|0,sa|0)|0;$a=Ua;ab=_a}a[t]=$a;a[Ma+(Pa+la)|0]=$a;Ua=0;sa=ab;while(1){if((Ua|0)>=8){bb=sa;break}oa=((sa|0)<(na|0))+sa|0;if(((d[Fa+(sa>>>3)|0]|0)&1<<(sa&7)|0)==0){bb=oa;break}else{Ua=Ua+1|0;sa=oa}}if((Ua&255)<<24>>24==0){sa=Fa+(bb>>>3)|0;Ra=bb+8|0;oa=(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)>>>((bb&7)>>>0)&255;VGb(H|0,t|0,7)|0;cb=oa;db=na>>>0>Ra>>>0?Ra:na}else{Ra=(Ua&255)-1|0;oa=a[x+Ra|0]|0;VGb(H|0,t|0,Ra|0)|0;cb=oa;db=bb}a[t]=cb;a[Ma+(Sa+la)|0]=cb;oa=0;Ra=db;while(1){if((oa|0)>=8){eb=Ra;break}sa=((Ra|0)<(na|0))+Ra|0;if(((d[Fa+(Ra>>>3)|0]|0)&1<<(Ra&7)|0)==0){eb=sa;break}else{oa=oa+1|0;Ra=sa}}if((oa&255)<<24>>24==0){Ra=Fa+(eb>>>3)|0;Sa=eb+8|0;Ua=(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)>>>((eb&7)>>>0)&255;VGb(E|0,P|0,7)|0;fb=Ua;gb=na>>>0>Sa>>>0?Sa:na}else{Sa=(oa&255)-1|0;Ua=a[x+8+Sa|0]|0;VGb(E|0,P|0,Sa|0)|0;fb=Ua;gb=eb}a[P]=fb;Ua=Pa>>1;a[La+Ua|0]=fb^-128;Sa=0;Ra=gb;while(1){if((Sa|0)>=8){hb=Ra;break}sa=((Ra|0)<(na|0))+Ra|0;if(((d[Fa+(Ra>>>3)|0]|0)&1<<(Ra&7)|0)==0){hb=sa;break}else{Sa=Sa+1|0;Ra=sa}}if((Sa&255)<<24>>24==0){Ra=Fa+(hb>>>3)|0;oa=hb+8|0;sa=(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)>>>((hb&7)>>>0)&255;VGb(s|0,O|0,7)|0;ib=sa;jb=na>>>0>oa>>>0?oa:na}else{oa=(Sa&255)-1|0;sa=a[x+16+oa|0]|0;VGb(s|0,O|0,oa|0)|0;ib=sa;jb=hb}a[O]=ib;a[Ka+Ua|0]=ib^-128;sa=Pa+2|0;if((sa|0)<(ka|0)){Pa=sa;Qa=jb}else{kb=jb;break}}}else{kb=Oa}Qa=Na+2|0;if((Qa|0)<(ia|0)){Ka=Ka+Ha|0;La=La+Ga|0;Ma=Ma+Ja|0;Na=Qa;Oa=kb}else{break}}lb=c[S>>2]|0;mb=c[v>>2]|0;nb=c[u>>2]|0}else{lb=la;mb=Ga;nb=Ha}Oa=aa+(ba(lb,ia)|0)|0;Na=ia>>1;Ja=da+(ba(mb,Na)|0)|0;Ma=ea+(ba(nb,Na)|0)|0;Na=ca+1|0;if((Na|0)<(Aa|0)){A=ja;ha=ga;ga=ga+U|0;fa=Da+fa|0;ca=Na;aa=Oa;da=Ja;ea=Ma}else{break a}}if((X|0)==78){yDb(y,16,1969920,(o=i,i=i+16|0,c[o>>2]=Da,c[o+8>>2]=Ea,o)|0);i=o;p=-1094995529;i=j;return p|0}else if((X|0)==80){yDb(y,16,1941312,(o=i,i=i+8|0,c[o>>2]=Ca,o)|0);i=o;p=-1094995529;i=j;return p|0}}}while(0);w=c[e+120>>2]|0;DDb(e,2007984,(o=i,i=i+24|0,c[o>>2]=Aa,c[o+8>>2]=w,c[o+16>>2]=C,o)|0);i=o;p=-1163346256;i=j;return p|0}else if((r|0)==50331657){w=m+16|0;B=h-16|0;if(!((B|0)>-1)){yDb(0,0,1896336,(o=i,i=i+24|0,c[o>>2]=2353544,c[o+8>>2]=2333488,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}V=m+h|0;if((B|0)<2){ob=0;pb=w}else{D=w;ob=(d[D]|d[D+1|0]<<8)<<16>>16&65535;pb=m+18|0}D=(ob<<2|2)+15&524272;if(D>>>0>B>>>0){yDb(e,16,2053688,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}w=c[e+124>>2]|0;do{if((ob|0)!=0){if(((w|0)%(ob|0)|0|0)!=0){break}ea=(w|0)/(ob|0)|0;da=e+120|0;aa=c[da>>2]|0;if((aa&3|0)==0){if((w&3|0)!=0){X=146}}else{X=146}if((X|0)==146){DDb(e,2308896,(o=i,i=i+16|0,c[o>>2]=aa,c[o+8>>2]=w,o)|0);i=o}c[e+140>>2]=6;aa=_$a(e,l,0)|0;if((aa|0)<0){p=aa;i=j;return p|0}aa=f+32|0;ca=f+36|0;fa=f+40|0;U=k;ga=k|0;ha=k;A=k+8|0;u=A;v=k+16|0;S=v;O=ha+1|0;s=ha+9|0;x=ha+17|0;P=e;E=pb;t=0;H=ea;z=D;q=0;Q=c[f>>2]|0;T=c[f+4>>2]|0;R=c[f+8>>2]|0;while(1){if((V-E|0)<4){qb=0;X=153;break}Ma=E+4|0;Ja=E;rb=d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0;Ja=(H&-4)-(t&-4)|0;sb=B-z|0;if(rb>>>0>sb>>>0){X=151;break}if(rb>>>0<17>>>0){qb=rb;X=153;break}Oa=m+(z+16)|0;Na=d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0;Oa=rb-16|0;if((Na|0)!=(Oa|0)){yDb(P,16,1916936,(o=i,i=i+16|0,c[o>>2]=Na,c[o+8>>2]=Oa,o)|0);i=o}Na=m+(z+32)|0;La=Oa<<3;Oa=La>>>0>2147483639>>>0|(Na|0)==0;Ka=Oa?0:Na;Na=Oa?8:La+8|0;La=c[da>>2]|0;Oa=c[aa>>2]|0;ka=c[ca>>2]|0;na=c[fa>>2]|0;c[ga>>2]=1614815232;c[ga+4>>2]=-4153216;c[A>>2]=1614815232;c[A+4>>2]=-4153216;c[v>>2]=1614815232;c[v+4>>2]=-4153216;if((Ja|0)>0){Fa=(La|0)>0;Ia=Oa<<2;Y=R;Z=T;Qa=Q;Pa=0;sa=0;while(1){if(Fa){oa=0;Ra=sa;while(1){tb=0;ub=Ra;while(1){vb=(ba(tb,Oa)|0)+oa|0;wb=0;xb=ub;while(1){yb=0;zb=xb;while(1){if((yb|0)>=8){Ab=zb;break}Bb=((zb|0)<(Na|0))+zb|0;if(((d[Ka+(zb>>>3)|0]|0)&1<<(zb&7)|0)==0){Ab=Bb;break}else{yb=yb+1|0;zb=Bb}}if((yb&255)<<24>>24==0){zb=Ka+(Ab>>>3)|0;Bb=Ab+8|0;Cb=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((Ab&7)>>>0)&255;VGb(O|0,U|0,7)|0;Db=Cb;Eb=Na>>>0>Bb>>>0?Bb:Na}else{Bb=(yb&255)-1|0;Cb=a[ha+Bb|0]|0;VGb(O|0,U|0,Bb|0)|0;Db=Cb;Eb=Ab}a[U]=Db;a[Qa+(vb+wb)|0]=Db;Cb=wb+1|0;if((Cb|0)<4){wb=Cb;xb=Eb}else{break}}xb=tb+1|0;if((xb|0)<4){tb=xb;ub=Eb}else{Fb=0;Gb=Eb;break}}while(1){if((Fb|0)>=8){Hb=Gb;break}ub=((Gb|0)<(Na|0))+Gb|0;if(((d[Ka+(Gb>>>3)|0]|0)&1<<(Gb&7)|0)==0){Hb=ub;break}else{Fb=Fb+1|0;Gb=ub}}if((Fb&255)<<24>>24==0){ub=Ka+(Hb>>>3)|0;tb=Hb+8|0;Ua=(d[ub]|d[ub+1|0]<<8|d[ub+2|0]<<16|d[ub+3|0]<<24|0)>>>((Hb&7)>>>0)&255;VGb(s|0,u|0,7)|0;Ib=Ua;Jb=Na>>>0>tb>>>0?tb:Na}else{tb=(Fb&255)-1|0;Ua=a[ha+8+tb|0]|0;VGb(s|0,u|0,tb|0)|0;Ib=Ua;Jb=Hb}a[u]=Ib;Ua=oa>>2;a[Z+Ua|0]=Ib^-128;tb=0;ub=Jb;while(1){if((tb|0)>=8){Kb=ub;break}Sa=((ub|0)<(Na|0))+ub|0;if(((d[Ka+(ub>>>3)|0]|0)&1<<(ub&7)|0)==0){Kb=Sa;break}else{tb=tb+1|0;ub=Sa}}if((tb&255)<<24>>24==0){ub=Ka+(Kb>>>3)|0;Sa=Kb+8|0;xb=(d[ub]|d[ub+1|0]<<8|d[ub+2|0]<<16|d[ub+3|0]<<24|0)>>>((Kb&7)>>>0)&255;VGb(x|0,S|0,7)|0;Lb=xb;Mb=Na>>>0>Sa>>>0?Sa:Na}else{Sa=(tb&255)-1|0;xb=a[ha+16+Sa|0]|0;VGb(x|0,S|0,Sa|0)|0;Lb=xb;Mb=Kb}a[S]=Lb;a[Y+Ua|0]=Lb^-128;xb=oa+4|0;if((xb|0)<(La|0)){oa=xb;Ra=Mb}else{Nb=Mb;break}}}else{Nb=sa}Ra=Pa+4|0;if((Ra|0)<(Ja|0)){Y=Y+na|0;Z=Z+ka|0;Qa=Qa+Ia|0;Pa=Ra;sa=Nb}else{break}}Ob=c[aa>>2]|0;Pb=c[ca>>2]|0;Qb=c[fa>>2]|0}else{Ob=Oa;Pb=ka;Qb=na}sa=Q+(ba(Ob,Ja)|0)|0;Pa=Ja>>2;Ia=T+(ba(Pb,Pa)|0)|0;Qa=R+(ba(Qb,Pa)|0)|0;Pa=q+1|0;if((Pa|0)<(ob|0)){E=Ma;t=H;H=H+ea|0;z=rb+z|0;q=Pa;Q=sa;T=Ia;R=Qa}else{break a}}if((X|0)==151){yDb(P,16,1969920,(o=i,i=i+16|0,c[o>>2]=rb,c[o+8>>2]=sb,o)|0);i=o;p=-1094995529;i=j;return p|0}else if((X|0)==153){yDb(P,16,1941312,(o=i,i=i+8|0,c[o>>2]=qb,o)|0);i=o;p=-1094995529;i=j;return p|0}}}while(0);B=c[e+120>>2]|0;DDb(e,2007984,(o=i,i=i+24|0,c[o>>2]=ob,c[o+8>>2]=B,c[o+16>>2]=w,o)|0);i=o;p=-1163346256;i=j;return p|0}else if((r|0)==385875969){B=h-16|0;V=(B|0)<0|0?-1:0;D=e+120|0;C=e+124|0;R=ba(c[C>>2]|0,c[D>>2]|0)|0;T=R;Q=((R|0)<0|0?-1:0)<<1|T>>>31;if((V|0)<(Q|0)|(V|0)==(Q|0)&B>>>0<(T<<1|0>>>31)>>>0){yDb(e,16,2189528,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=44;T=_$a(e,l,0)|0;if((T|0)<0){p=T;i=j;return p|0}if((c[C>>2]|0)<=0){break}T=f+32|0;B=m+16|0;Q=0;V=c[f>>2]|0;R=c[D>>2]|0;while(1){UGb(V|0,B|0,R<<1)|0;q=c[D>>2]|0;z=Q+1|0;if((z|0)<(c[C>>2]|0)){B=B+(q<<1)|0;Q=z;V=V+(c[T>>2]|0)|0;R=q}else{break}}}else if((r|0)==33554433){R=e+120|0;T=e+124|0;if(((ba((c[R>>2]|0)*3|0,c[T>>2]|0)|0)/2|0|0)>(h-16|0)){yDb(e,16,2189528,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=0;V=_$a(e,l,0)|0;if((V|0)<0){p=V;i=j;return p|0}V=c[f>>2]|0;Q=f+32|0;B=c[T>>2]|0;if((B|0)<=0){break}C=c[Q>>2]|0;D=f+36|0;w=f+40|0;q=m+16|0;z=0;ea=V;H=V+C|0;V=c[f+4>>2]|0;t=c[f+8>>2]|0;E=c[R>>2]|0;fa=C;C=B;while(1){if((E|0)>0){B=q;ca=0;do{b[ea+ca>>1]=b[B>>1]|0;b[H+ca>>1]=b[B+2>>1]|0;aa=ca>>1;a[V+aa|0]=a[B+4|0]^-128;a[t+aa|0]=a[B+5|0]^-128;B=B+6|0;ca=ca+2|0;Rb=c[R>>2]|0;}while((ca|0)<(Rb|0));Sb=B;Tb=Rb;Ub=c[Q>>2]|0;Vb=c[T>>2]|0}else{Sb=q;Tb=E;Ub=fa;Vb=C}ca=Ub<<1;P=z+2|0;if((P|0)<(Vb|0)){q=Sb;z=P;ea=ea+ca|0;H=H+ca|0;V=V+(c[D>>2]|0)|0;t=t+(c[w>>2]|0)|0;E=Tb;fa=Ub;C=Vb}else{break}}}else if((r|0)==50331649){C=e+120|0;fa=e+124|0;if(((ba((c[C>>2]|0)*9|0,c[fa>>2]|0)|0)/8|0|0)>(h-16|0)){yDb(e,16,2189528,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=6;E=_$a(e,l,0)|0;if((E|0)<0){p=E;i=j;return p|0}E=c[f>>2]|0;w=f+32|0;t=c[w>>2]|0;D=c[fa>>2]|0;if((D|0)<=0){break}V=f+36|0;H=f+40|0;ea=m+16|0;z=0;q=E;T=E+t|0;Q=E+(t<<1)|0;R=E+(t*3|0)|0;E=c[f+4>>2]|0;ca=c[f+8>>2]|0;P=c[C>>2]|0;aa=t;t=D;while(1){if((P|0)>0){D=ea;S=0;do{c[q+S>>2]=c[D>>2];c[T+S>>2]=c[D+4>>2];c[Q+S>>2]=c[D+8>>2];c[R+S>>2]=c[D+12>>2];x=S>>2;a[E+x|0]=a[D+16|0]^-128;a[ca+x|0]=a[D+17|0]^-128;D=D+18|0;S=S+4|0;Wb=c[C>>2]|0;}while((S|0)<(Wb|0));Xb=D;Yb=Wb;Zb=c[w>>2]|0;_b=c[fa>>2]|0}else{Xb=ea;Yb=P;Zb=aa;_b=t}S=Zb<<2;B=z+4|0;if((B|0)<(_b|0)){ea=Xb;z=B;q=q+S|0;T=T+S|0;Q=Q+S|0;R=R+S|0;E=E+(c[V>>2]|0)|0;ca=ca+(c[H>>2]|0)|0;P=Yb;aa=Zb;t=_b}else{break}}}else if((r|0)==67108873){t=m+16|0;aa=h-16|0;if(!((aa|0)>-1)){yDb(0,0,1896336,(o=i,i=i+24|0,c[o>>2]=2353544,c[o+8>>2]=2333488,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}P=m+h|0;if((aa|0)<2){$b=0;ac=t}else{H=t;$b=(d[H]|d[H+1|0]<<8)<<16>>16&65535;ac=m+18|0}H=($b<<2|2)+15&524272;if(H>>>0>aa>>>0){yDb(e,16,2053688,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}t=c[e+124>>2]|0;do{if(($b|0)!=0){if(((t|0)%($b|0)|0|0)!=0){break}ca=(t|0)/($b|0)|0;c[e+140>>2]=5;V=_$a(e,l,0)|0;if((V|0)<0){p=V;i=j;return p|0}V=e+120|0;E=f+32|0;R=f+36|0;Q=f+40|0;T=k;q=k|0;z=k;ea=k+8|0;fa=ea;w=k+16|0;C=w;S=(ca|0)>0;B=z+1|0;x=z+9|0;ha=z+17|0;u=e;s=ac;U=H;O=0;v=c[f>>2]|0;A=c[f+4>>2]|0;ga=c[f+8>>2]|0;while(1){if((P-s|0)<4){bc=0;X=208;break}da=s+4|0;y=s;cc=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;dc=aa-U|0;if(cc>>>0>dc>>>0){X=206;break}if(cc>>>0<17>>>0){bc=cc;X=208;break}y=m+(U+16)|0;Qa=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=cc-16|0;if((Qa|0)!=(y|0)){yDb(u,16,1916936,(o=i,i=i+16|0,c[o>>2]=Qa,c[o+8>>2]=y,o)|0);i=o}Qa=m+(U+32)|0;Ia=y<<3;y=Ia>>>0>2147483639>>>0|(Qa|0)==0;sa=y?0:Qa;Qa=y?8:Ia+8|0;Ia=c[V>>2]|0;y=c[E>>2]|0;Pa=c[R>>2]|0;Z=c[Q>>2]|0;c[q>>2]=1614815232;c[q+4>>2]=-4153216;c[ea>>2]=1614815232;c[ea+4>>2]=-4153216;c[w>>2]=1614815232;c[w+4>>2]=-4153216;if(S){Y=(Ia|0)>0;La=ga;Na=A;Ka=v;Fa=0;ja=0;while(1){if(Y){ia=0;Ha=ja;while(1){Ga=0;la=Ha;while(1){if((Ga|0)>=8){ec=la;break}Ra=((la|0)<(Qa|0))+la|0;if(((d[sa+(la>>>3)|0]|0)&1<<(la&7)|0)==0){ec=Ra;break}else{Ga=Ga+1|0;la=Ra}}if((Ga&255)<<24>>24==0){la=sa+(ec>>>3)|0;Ua=ec+8|0;tb=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ec&7)>>>0)&255;VGb(B|0,T|0,7)|0;fc=tb;gc=Qa>>>0>Ua>>>0?Ua:Qa}else{Ua=(Ga&255)-1|0;tb=a[z+Ua|0]|0;VGb(B|0,T|0,Ua|0)|0;fc=tb;gc=ec}a[T]=fc;a[Ka+ia|0]=fc;tb=0;Ua=gc;while(1){if((tb|0)>=8){hc=Ua;break}la=((Ua|0)<(Qa|0))+Ua|0;if(((d[sa+(Ua>>>3)|0]|0)&1<<(Ua&7)|0)==0){hc=la;break}else{tb=tb+1|0;Ua=la}}if((tb&255)<<24>>24==0){Ua=sa+(hc>>>3)|0;Ga=hc+8|0;la=(d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0)>>>((hc&7)>>>0)&255;VGb(x|0,fa|0,7)|0;ic=la;jc=Qa>>>0>Ga>>>0?Ga:Qa}else{Ga=(tb&255)-1|0;la=a[z+8+Ga|0]|0;VGb(x|0,fa|0,Ga|0)|0;ic=la;jc=hc}a[fa]=ic;a[Na+ia|0]=ic^-128;la=0;Ga=jc;while(1){if((la|0)>=8){kc=Ga;break}Ua=((Ga|0)<(Qa|0))+Ga|0;if(((d[sa+(Ga>>>3)|0]|0)&1<<(Ga&7)|0)==0){kc=Ua;break}else{la=la+1|0;Ga=Ua}}if((la&255)<<24>>24==0){Ga=sa+(kc>>>3)|0;tb=kc+8|0;Ua=(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)>>>((kc&7)>>>0)&255;VGb(ha|0,C|0,7)|0;lc=Ua;mc=Qa>>>0>tb>>>0?tb:Qa}else{tb=(la&255)-1|0;Ua=a[z+16+tb|0]|0;VGb(ha|0,C|0,tb|0)|0;lc=Ua;mc=kc}a[C]=lc;a[La+ia|0]=lc^-128;Ua=ia+1|0;if((Ua|0)<(Ia|0)){ia=Ua;Ha=mc}else{nc=mc;break}}}else{nc=ja}Ha=Fa+1|0;if((Ha|0)<(ca|0)){La=La+Z|0;Na=Na+Pa|0;Ka=Ka+y|0;Fa=Ha;ja=nc}else{break}}oc=c[E>>2]|0;pc=c[R>>2]|0;qc=c[Q>>2]|0}else{oc=y;pc=Pa;qc=Z}ja=v+(ba(oc,ca)|0)|0;Fa=A+(ba(pc,ca)|0)|0;Ka=ga+(ba(qc,ca)|0)|0;Na=O+1|0;if((Na|0)<($b|0)){s=da;U=cc+U|0;O=Na;v=ja;A=Fa;ga=Ka}else{break a}}if((X|0)==206){yDb(u,16,1969920,(o=i,i=i+16|0,c[o>>2]=cc,c[o+8>>2]=dc,o)|0);i=o;p=-1094995529;i=j;return p|0}else if((X|0)==208){yDb(u,16,1941312,(o=i,i=i+8|0,c[o>>2]=bc,o)|0);i=o;p=-1094995529;i=j;return p|0}}}while(0);aa=c[e+120>>2]|0;DDb(e,2007984,(o=i,i=i+24|0,c[o>>2]=$b,c[o+8>>2]=aa,c[o+16>>2]=t,o)|0);i=o;p=-1163346256;i=j;return p|0}else if((r|0)==16777217){aa=h-16|0;P=(aa|0)<0|0?-1:0;H=e+120|0;ga=e+124|0;A=ba(c[ga>>2]|0,c[H>>2]|0)|0;v=gHb(A,(A|0)<0|0?-1:0,3,0)|0;A=F;if((P|0)<(A|0)|(P|0)==(A|0)&aa>>>0<v>>>0){yDb(e,16,2189528,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=3;v=_$a(e,l,0)|0;if((v|0)<0){p=v;i=j;return p|0}if((c[ga>>2]|0)<=0){break}v=f+32|0;aa=m+16|0;A=0;P=c[f>>2]|0;O=c[H>>2]|0;while(1){UGb(P|0,aa|0,O*3|0)|0;U=c[H>>2]|0;s=A+1|0;if((s|0)<(c[ga>>2]|0)){aa=aa+(U*3|0)|0;A=s;P=P+(c[v>>2]|0)|0;O=U}else{break}}}else if((r|0)==385875977){rc=j8(e,l,m+16|0,h-16|0,1)|0;X=251}else if((r|0)==402653185|(r|0)==419430401){O=h-16|0;v=(O|0)<0|0?-1:0;P=e+120|0;A=e+124|0;aa=ba(c[A>>2]|0,c[P>>2]|0)|0;ga=aa;H=((aa|0)<0|0?-1:0)<<1|ga>>>31;if((v|0)<(H|0)|(v|0)==(H|0)&O>>>0<(ga<<1|0>>>31)>>>0){yDb(e,16,2189528,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=46;ga=_$a(e,l,0)|0;if((ga|0)<0){p=ga;i=j;return p|0}if((c[A>>2]|0)<=0){break}ga=f+32|0;O=m+16|0;H=0;v=c[f>>2]|0;aa=c[P>>2]|0;while(1){UGb(v|0,O|0,aa<<1)|0;t=c[P>>2]|0;U=H+1|0;if((U|0)<(c[A>>2]|0)){O=O+(t<<1)|0;H=U;v=v+(c[ga>>2]|0)|0;aa=t}else{break}}}else if((r|0)==402653193|(r|0)==419430409){rc=j8(e,l,m+16|0,h-16|0,0)|0;X=251}else{DDb(e,2112272,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;p=-1163346256;i=j;return p|0}}while(0);do{if((X|0)==251){if((rc|0)==0){break}else{p=rc}i=j;return p|0}}while(0);c[f+88>>2]=1;c[f+84>>2]=1;c[g>>2]=1;p=c[n>>2]|0;i=j;return p|0}function j8(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;j=i;i=i+24|0;k=j|0;if(!((g|0)>-1)){yDb(0,0,1896336,(l=i,i=i+24|0,c[l>>2]=2353544,c[l+8>>2]=2333488,c[l+16>>2]=135,l)|0);i=l;Cd();return 0}m=f+g|0;if((g|0)<2){n=0;o=f}else{p=f;n=(d[p]|d[p+1|0]<<8)<<16>>16&65535;o=f+2|0}p=(n<<2|2)+15&524272;if(p>>>0>g>>>0){yDb(b,16,2053688,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;q=-1094995529;i=j;return q|0}r=c[b+124>>2]|0;do{if((n|0)!=0){if(((r|0)%(n|0)|0|0)!=0){break}s=(r|0)/(n|0)|0;c[b+140>>2]=2;t=_$a(b,e,0)|0;if((t|0)<0){q=t;i=j;return q|0}t=b+120|0;u=e+32|0;v=k;w=k|0;x=k+8|0;y=(h|0)!=0;z=y?537921536:403703808;A=y?16176:31;B=k+16|0;C=(s|0)>0;D=v+1|0;E=x;F=y?6:5;G=32-F|0;H=E+1|0;I=B;J=I+1|0;K=b;L=o;M=p;N=0;O=c[e>>2]|0;while(1){if((m-L|0)<4){P=0;Q=16;break}R=L+4|0;S=L;T=d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0;U=g-M|0;if(T>>>0>U>>>0){Q=14;break}if(T>>>0<17>>>0){P=T;Q=16;break}S=f+M|0;V=d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0;S=T-16|0;if((V|0)!=(S|0)){yDb(K,16,1916936,(l=i,i=i+16|0,c[l>>2]=V,c[l+8>>2]=S,l)|0);i=l}V=f+(M+16)|0;W=S<<3;S=W>>>0>2147483639>>>0|(V|0)==0;X=S?0:V;V=S?8:W+8|0;W=c[t>>2]|0;S=c[u>>2]|0;c[w>>2]=403703808;c[w+4>>2]=31;c[x>>2]=z;c[x+4>>2]=A;c[B>>2]=403703808;c[B+4>>2]=31;if(C){Y=(W|0)>0;Z=0;_=O;$=0;while(1){if(Y){aa=0;ca=$;while(1){da=0;ea=ca;while(1){if((da|0)>=5){fa=ea;break}ga=((ea|0)<(V|0))+ea|0;if(((d[X+(ea>>>3)|0]|0)&1<<(ea&7)|0)==0){fa=ga;break}else{da=da+1|0;ea=ga}}if((da&255)<<24>>24==0){ea=X+(fa>>>3)|0;ga=fa+5|0;ha=(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)>>>((fa&7)>>>0)&31;VGb(D|0,v|0,5)|0;ia=ha;ja=V>>>0>ga>>>0?ga:V}else{ga=(da&255)-1|0;ha=a[v+ga|0]|0;VGb(D|0,v|0,ga|0)|0;ia=ha;ja=fa}a[v]=ia;ha=0;ga=ja;while(1){if((ha|0)>=(F|0)){ka=ga;break}ea=((ga|0)<(V|0))+ga|0;if(((d[X+(ga>>>3)|0]|0)&1<<(ga&7)|0)==0){ka=ea;break}else{ha=ha+1|0;ga=ea}}if((ha&255)<<24>>24==0){ga=X+(ka>>>3)|0;da=ka+F|0;ea=(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((ka&7)>>>0)<<G>>>(G>>>0)&255;VGb(H|0,E|0,5)|0;la=ea;ma=V>>>0>da>>>0?da:V}else{da=(ha&255)-1|0;ea=a[E+da|0]|0;VGb(H|0,E|0,da|0)|0;la=ea;ma=ka}a[E]=la;ea=0;da=ma;while(1){if((ea|0)>=5){na=da;break}ga=((da|0)<(V|0))+da|0;if(((d[X+(da>>>3)|0]|0)&1<<(da&7)|0)==0){na=ga;break}else{ea=ea+1|0;da=ga}}if((ea&255)<<24>>24==0){da=X+(na>>>3)|0;ha=na+5|0;ga=(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((na&7)>>>0)&31;VGb(J|0,I|0,5)|0;oa=ga;pa=V>>>0>ha>>>0?ha:V}else{ha=(ea&255)-1|0;ga=a[I+ha|0]|0;VGb(J|0,I|0,ha|0)|0;oa=ga;pa=na}a[I]=oa;ga=aa*3|0;a[_+ga|0]=oa<<3|(oa&255)>>>2;if(y){qa=la<<2|(la&255)>>>4}else{qa=la<<3|(la&255)>>>2}a[_+(ga+1)|0]=qa;a[_+(ga+2)|0]=ia<<3|(ia&255)>>>2;ga=aa+1|0;if((ga|0)<(W|0)){aa=ga;ca=pa}else{ra=pa;break}}}else{ra=$}ca=Z+1|0;if((ca|0)<(s|0)){Z=ca;_=_+S|0;$=ra}else{break}}sa=c[u>>2]|0}else{sa=S}$=O+(ba(sa,s)|0)|0;_=N+1|0;if((_|0)<(n|0)){L=R;M=T+M|0;N=_;O=$}else{q=0;Q=47;break}}if((Q|0)==14){yDb(K,16,1969920,(l=i,i=i+16|0,c[l>>2]=T,c[l+8>>2]=U,l)|0);i=l;q=-1094995529;i=j;return q|0}else if((Q|0)==16){yDb(K,16,1941312,(l=i,i=i+8|0,c[l>>2]=P,l)|0);i=l;q=-1094995529;i=j;return q|0}else if((Q|0)==47){i=j;return q|0}}}while(0);Q=c[b+120>>2]|0;DDb(b,2007984,(l=i,i=i+24|0,c[l>>2]=n,c[l+8>>2]=Q,c[l+16>>2]=r,l)|0);i=l;q=-1163346256;i=j;return q|0}function k8(){var b=0;TGb(8160200,-1|0,3072)|0;b=0;do{a[(d[1224493+(b*6|0)|0]|0)+(8160200+((d[1224488+(b*6|0)|0]|0)-1<<10)+((d[1224489+(b*6|0)|0]|0)<<8)+((d[1224490+(b*6|0)|0]|0)<<6)+((d[1224491+(b*6|0)|0]|0)<<4)+((d[1224492+(b*6|0)|0]|0)<<2))|0]=b;b=b+1|0;}while((b|0)<32);return}function l8(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b+2740|0;if((c[b+2332>>2]|0)<6){c[e>>2]=0;return}c[e>>2]=1;f=(c[b+2464>>2]|0)==0|0;g=b+2368|0;if((f|0)>(c[g>>2]|0)){return}else{h=f}while(1){f=a[(d[b+2688+(h*6|0)+5|0]|0)+(8160200+((d[b+2688+(h*6|0)|0]|0)-1<<10)+((d[b+2688+(h*6|0)+1|0]|0)<<8)+((d[b+2688+(h*6|0)+2|0]|0)<<6)+((d[b+2688+(h*6|0)+3|0]|0)<<4)+((d[b+2688+(h*6|0)+4|0]|0)<<2))|0]|0;if(f<<24>>24<0){break}a[b+2730+h|0]=f;f=h+1|0;if((f|0)>(c[g>>2]|0)){i=7;break}else{h=f}}if((i|0)==7){return}c[e>>2]=0;return}function m8(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+32|0;e=d|0;f=b+2368|0;g=c[f>>2]|0;if((g|0)>=1){h=1;do{c[e+(h<<2)>>2]=1;h=h+1|0;}while((h|0)<=(g|0))}h=b+2332|0;j=c[h>>2]|0;if((j|0)>0){k=0;l=g;g=j;while(1){if((l|0)<1){m=l;n=g}else{o=1;p=l;while(1){q=e+(o<<2)|0;do{if((a[b+1536+(k<<7)+64+o|0]|0)==0){c[q>>2]=1;r=p}else{if((c[q>>2]|0)==0){r=p;break}a[b+1536+(k<<7)+76+o|0]=2;c[q>>2]=0;r=c[f>>2]|0}}while(0);q=o+1|0;if((q|0)>(r|0)){break}else{o=q;p=r}}m=r;n=c[h>>2]|0}p=k+1|0;if((p|0)<(n|0)){k=p;l=m;g=n}else{s=n;break}}}else{s=j}j=0;while(1){if((j|0)>=(s|0)){t=16;break}if((c[b+1536+(j<<7)+60>>2]|0)==0){j=j+1|0}else{break}}if((t|0)==16){i=d;return}c[b+1536+(j<<7)+96>>2]=2;i=d;return}function n8(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0;e=b+112|0;f=c[e>>2]|0;g=b+116|0;h=c[g>>2]|0;if((h|0)>16){i=h-16|0;j=f<<16|2935}else{k=fe(2935>>>((16-h|0)>>>0)|f<<h|0)|0;f=b+124|0;l=c[f>>2]|0;x=k;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;i=h+16|0;j=2935}c[e>>2]=j;c[g>>2]=i;if((i|0)>2){m=i-2|0;n=j<<2}else{h=fe(j<<i|0)|0;j=b+124|0;f=c[j>>2]|0;x=h;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;m=i+30|0;n=0}c[e>>2]=n;c[g>>2]=m;if((m|0)>3){o=m-3|0;p=n<<3}else{i=fe(n<<m|0)|0;n=b+124|0;j=c[n>>2]|0;x=i;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;o=m+29|0;p=0}c[e>>2]=p;c[g>>2]=o;m=((c[b+2340>>2]|0)/2|0)-1|0;if((o|0)>11){q=o-11|0;r=p<<11|m}else{n=fe(m>>>((11-o|0)>>>0)|p<<o|0)|0;p=b+124|0;j=c[p>>2]|0;x=n;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;q=o+21|0;r=m}c[e>>2]=r;c[g>>2]=q;m=b+2524|0;do{if((c[b+2528>>2]|0)==0){o=c[m>>2]|0;if((q|0)>2){s=q-2|0;t=r<<2|o}else{p=fe(r<<q|o>>>((2-q|0)>>>0)|0)|0;j=b+124|0;n=c[j>>2]|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;s=q+30|0;t=o}c[e>>2]=t;c[g>>2]=s;o=c[b+2328>>2]|0;if((s|0)>2){u=s-2|0;v=t<<2|o;break}else{j=fe(t<<s|o>>>((2-s|0)>>>0)|0)|0;n=b+124|0;p=c[n>>2]|0;x=j;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;u=s+30|0;v=o;break}}else{if((q|0)>2){w=q-2|0;y=r<<2|3}else{o=fe(r<<q|3>>>((2-q|0)>>>0)|0)|0;n=b+124|0;p=c[n>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;w=q+30|0;y=3}c[e>>2]=y;c[g>>2]=w;n=c[m>>2]|0;if((w|0)>2){u=w-2|0;v=y<<2|n;break}else{p=fe(y<<w|n>>>((2-w|0)>>>0)|0)|0;o=b+124|0;j=c[o>>2]|0;x=p;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;u=w+30|0;v=n;break}}}while(0);c[e>>2]=v;c[g>>2]=u;w=b+2392|0;y=c[w>>2]|0;if((u|0)>3){z=u-3|0;A=v<<3|y}else{m=fe(v<<u|y>>>((3-u|0)>>>0)|0)|0;v=b+124|0;q=c[v>>2]|0;x=m;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;z=u+29|0;A=y}c[e>>2]=A;c[g>>2]=z;y=b+2376|0;u=c[y>>2]|0;if((z|0)>1){B=z-1|0;C=A<<1|u}else{v=fe(A<<z|u>>>((1-z|0)>>>0)|0)|0;A=b+124|0;q=c[A>>2]|0;x=v;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;B=z+31|0;C=u}c[e>>2]=C;c[g>>2]=B;u=c[b+2312>>2]|0;if((B|0)>5){D=B-5|0;E=C<<5|u}else{z=fe(C<<B|u>>>((5-B|0)>>>0)|0)|0;C=b+124|0;A=c[C>>2]|0;x=z;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;D=B+27|0;E=u}c[e>>2]=E;c[g>>2]=D;u=-(c[b+4>>2]|0)|0;if((D|0)>5){F=D-5|0;G=E<<5|u}else{B=fe(E<<D|u>>>((5-D|0)>>>0)|0)|0;E=b+124|0;C=c[E>>2]|0;x=B;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;F=D+27|0;G=u}c[e>>2]=G;c[g>>2]=F;if((F|0)>1){H=F-1|0;I=G<<1}else{u=fe(G<<F|0)|0;G=b+124|0;D=c[G>>2]|0;x=u;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;H=F+31|0;I=0}c[e>>2]=I;c[g>>2]=H;F=b+84|0;G=c[F>>2]|0;if((H|0)>1){J=H-1|0;K=I<<1|G;L=G}else{D=fe(I<<H|G>>>((1-H|0)>>>0)|0)|0;I=b+124|0;u=c[I>>2]|0;x=D;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;J=H+31|0;K=G;L=c[F>>2]|0}c[e>>2]=K;c[g>>2]=J;if((L|0)==0){M=J;N=K}else{if((c[w>>2]|0)>2){L=c[b+48>>2]|0;if((J|0)>2){O=J-2|0;P=K<<2|L}else{F=fe(K<<J|L>>>((2-J|0)>>>0)|0)|0;G=b+124|0;H=c[G>>2]|0;x=F;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;O=J+30|0;P=L}c[e>>2]=P;c[g>>2]=O;Q=O;R=P}else{Q=J;R=K}if((c[b+2384>>2]|0)==0){S=Q;T=R}else{K=c[b+2408>>2]|0;if((Q|0)>3){U=Q-3|0;V=R<<3|K}else{J=fe(K>>>((3-Q|0)>>>0)|R<<Q|0)|0;R=b+124|0;P=c[R>>2]|0;x=J;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[R>>2]=(c[R>>2]|0)+4;U=Q+29|0;V=K}c[e>>2]=V;c[g>>2]=U;K=c[b+2416>>2]|0;if((U|0)>3){W=U-3|0;X=V<<3|K}else{Q=fe(V<<U|K>>>((3-U|0)>>>0)|0)|0;V=b+124|0;R=c[V>>2]|0;x=Q;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[V>>2]=(c[V>>2]|0)+4;W=U+29|0;X=K}c[e>>2]=X;c[g>>2]=W;S=W;T=X}if((c[b+2388>>2]|0)==0){Y=S;Z=T}else{X=c[b+2412>>2]|0;if((S|0)>3){_=S-3|0;$=T<<3|X}else{W=fe(X>>>((3-S|0)>>>0)|T<<S|0)|0;T=b+124|0;K=c[T>>2]|0;x=W;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[T>>2]=(c[T>>2]|0)+4;_=S+29|0;$=X}c[e>>2]=$;c[g>>2]=_;X=c[b+2420>>2]|0;if((_|0)>3){aa=_-3|0;ba=$<<3|X}else{S=fe($<<_|X>>>((3-_|0)>>>0)|0)|0;$=b+124|0;T=c[$>>2]|0;x=S;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[$>>2]=(c[$>>2]|0)+4;aa=_+29|0;ba=X}c[e>>2]=ba;c[g>>2]=aa;Y=aa;Z=ba}if((c[y>>2]|0)==0){ca=Y;da=Z}else{if((Y|0)>1){ea=Y-1|0;fa=Z<<1}else{ba=fe(Z<<Y|0)|0;Z=b+124|0;aa=c[Z>>2]|0;x=ba;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;c[Z>>2]=(c[Z>>2]|0)+4;ea=Y+31|0;fa=0}c[e>>2]=fa;c[g>>2]=ea;ca=ea;da=fa}if((ca|0)>1){ga=ca-1|0;ha=da<<1}else{fa=fe(da<<ca|0)|0;da=b+124|0;ea=c[da>>2]|0;x=fa;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;c[da>>2]=(c[da>>2]|0)+4;ga=ca+31|0;ha=0}c[e>>2]=ha;c[g>>2]=ga;if((ga|0)>1){ia=ga-1|0;ja=ha<<1}else{ca=fe(ha<<ga|0)|0;ha=b+124|0;da=c[ha>>2]|0;x=ca;a[da]=x;x=x>>8;a[da+1|0]=x;x=x>>8;a[da+2|0]=x;x=x>>8;a[da+3|0]=x;c[ha>>2]=(c[ha>>2]|0)+4;ia=ga+31|0;ja=0}c[e>>2]=ja;c[g>>2]=ia;if((ia|0)>2){ka=ia-2|0;la=ja<<2}else{ga=fe(ja<<ia|0)|0;ja=b+124|0;ha=c[ja>>2]|0;x=ga;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;ka=ia+30|0;la=0}c[e>>2]=la;c[g>>2]=ka;if((c[w>>2]|0)<2){if((ka|0)>1){ma=ka-1|0;na=la<<1}else{ia=fe(la<<ka|0)|0;ja=b+124|0;ha=c[ja>>2]|0;x=ia;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;ma=ka+31|0;na=0}c[e>>2]=na;c[g>>2]=ma;oa=ma;pa=na}else{oa=ka;pa=la}if((oa|0)>1){qa=oa-1|0;ra=pa<<1}else{la=fe(pa<<oa|0)|0;pa=b+124|0;ka=c[pa>>2]|0;x=la;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;c[pa>>2]=(c[pa>>2]|0)+4;qa=oa+31|0;ra=0}c[e>>2]=ra;c[g>>2]=qa;M=qa;N=ra}ra=b+88|0;qa=c[ra>>2]|0;if((M|0)>1){sa=M-1|0;ta=N<<1|qa;ua=qa}else{oa=fe(N<<M|qa>>>((1-M|0)>>>0)|0)|0;N=b+124|0;pa=c[N>>2]|0;x=oa;a[pa]=x;x=x>>8;a[pa+1|0]=x;x=x>>8;a[pa+2|0]=x;x=x>>8;a[pa+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;sa=M+31|0;ta=qa;ua=c[ra>>2]|0}c[e>>2]=ta;c[g>>2]=sa;if((ua|0)==0){va=sa;wa=ta}else{ua=c[b+2316>>2]|0;if((sa|0)>3){xa=sa-3|0;ya=ta<<3|ua}else{ra=fe(ta<<sa|ua>>>((3-sa|0)>>>0)|0)|0;ta=b+124|0;qa=c[ta>>2]|0;x=ra;a[qa]=x;x=x>>8;a[qa+1|0]=x;x=x>>8;a[qa+2|0]=x;x=x>>8;a[qa+3|0]=x;c[ta>>2]=(c[ta>>2]|0)+4;xa=sa+29|0;ya=ua}c[e>>2]=ya;c[g>>2]=xa;ua=c[b+36>>2]|0;if((xa|0)>1){za=xa-1|0;Aa=ya<<1|ua}else{sa=fe(ya<<xa|ua>>>((1-xa|0)>>>0)|0)|0;ya=b+124|0;ta=c[ya>>2]|0;x=sa;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;c[ya>>2]=(c[ya>>2]|0)+4;za=xa+31|0;Aa=ua}c[e>>2]=Aa;c[g>>2]=za;ua=c[b+40>>2]|0;if((za|0)>1){Ba=za-1|0;Ca=Aa<<1|ua}else{xa=fe(Aa<<za|ua>>>((1-za|0)>>>0)|0)|0;Aa=b+124|0;ya=c[Aa>>2]|0;x=xa;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;Ba=za+31|0;Ca=ua}c[e>>2]=Ca;c[g>>2]=Ba;ua=c[w>>2]|0;if((ua|0)==2){za=c[b+20>>2]|0;if((Ba|0)>2){Da=Ba-2|0;Ea=Ca<<2|za}else{Aa=fe(Ca<<Ba|za>>>((2-Ba|0)>>>0)|0)|0;ya=b+124|0;xa=c[ya>>2]|0;x=Aa;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[ya>>2]=(c[ya>>2]|0)+4;Da=Ba+30|0;Ea=za}c[e>>2]=Ea;c[g>>2]=Da;za=c[b+76>>2]|0;if((Da|0)>2){Fa=Da-2|0;Ga=Ea<<2|za}else{ya=fe(Ea<<Da|za>>>((2-Da|0)>>>0)|0)|0;Ea=b+124|0;xa=c[Ea>>2]|0;x=ya;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[Ea>>2]=(c[Ea>>2]|0)+4;Fa=Da+30|0;Ga=za}c[e>>2]=Ga;c[g>>2]=Fa;Ha=c[w>>2]|0;Ia=Ga;Ja=Fa}else{Ha=ua;Ia=Ca;Ja=Ba}if((Ha|0)>5){Ha=c[b+72>>2]|0;if((Ja|0)>2){Ka=Ja-2|0;La=Ia<<2|Ha}else{Ba=fe(Ha>>>((2-Ja|0)>>>0)|Ia<<Ja|0)|0;Ca=b+124|0;ua=c[Ca>>2]|0;x=Ba;a[ua]=x;x=x>>8;a[ua+1|0]=x;x=x>>8;a[ua+2|0]=x;x=x>>8;a[ua+3|0]=x;c[Ca>>2]=(c[Ca>>2]|0)+4;Ka=Ja+30|0;La=Ha}c[e>>2]=La;c[g>>2]=Ka;Ma=Ka;Na=La}else{Ma=Ja;Na=Ia}Ia=b+24|0;Ja=c[Ia>>2]|0;if((Ma|0)>1){Oa=Ma-1|0;Pa=Na<<1|Ja;Qa=Ja}else{La=fe(Na<<Ma|Ja>>>((1-Ma|0)>>>0)|0)|0;Na=b+124|0;Ka=c[Na>>2]|0;x=La;a[Ka]=x;x=x>>8;a[Ka+1|0]=x;x=x>>8;a[Ka+2|0]=x;x=x>>8;a[Ka+3|0]=x;c[Na>>2]=(c[Na>>2]|0)+4;Oa=Ma+31|0;Pa=Ja;Qa=c[Ia>>2]|0}c[e>>2]=Pa;c[g>>2]=Oa;if((Qa|0)==0){Ra=Oa;Sa=Pa}else{Qa=(c[b+28>>2]|0)-80|0;if((Oa|0)>5){Ta=Oa-5|0;Ua=Pa<<5|Qa}else{Ia=fe(Qa>>>((5-Oa|0)>>>0)|Pa<<Oa|0)|0;Pa=b+124|0;Ja=c[Pa>>2]|0;x=Ia;a[Ja]=x;x=x>>8;a[Ja+1|0]=x;x=x>>8;a[Ja+2|0]=x;x=x>>8;a[Ja+3|0]=x;c[Pa>>2]=(c[Pa>>2]|0)+4;Ta=Oa+27|0;Ua=Qa}c[e>>2]=Ua;c[g>>2]=Ta;Qa=c[b+32>>2]|0;if((Ta|0)>2){Va=Ta-2|0;Wa=Ua<<2|Qa}else{Oa=fe(Ua<<Ta|Qa>>>((2-Ta|0)>>>0)|0)|0;Ua=b+124|0;Pa=c[Ua>>2]|0;x=Oa;a[Pa]=x;x=x>>8;a[Pa+1|0]=x;x=x>>8;a[Pa+2|0]=x;x=x>>8;a[Pa+3|0]=x;c[Ua>>2]=(c[Ua>>2]|0)+4;Va=Ta+30|0;Wa=Qa}c[e>>2]=Wa;c[g>>2]=Va;Qa=c[b+80>>2]|0;if((Va|0)>1){Xa=Va-1|0;Ya=Wa<<1|Qa}else{Ta=fe(Wa<<Va|Qa>>>((1-Va|0)>>>0)|0)|0;Wa=b+124|0;Ua=c[Wa>>2]|0;x=Ta;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;c[Wa>>2]=(c[Wa>>2]|0)+4;Xa=Va+31|0;Ya=Qa}c[e>>2]=Ya;c[g>>2]=Xa;Ra=Xa;Sa=Ya}if((Ra|0)>1){Za=Ra-1|0;_a=Sa<<1}else{Ya=fe(Sa<<Ra|0)|0;Sa=b+124|0;Xa=c[Sa>>2]|0;x=Ya;a[Xa]=x;x=x>>8;a[Xa+1|0]=x;x=x>>8;a[Xa+2|0]=x;x=x>>8;a[Xa+3|0]=x;c[Sa>>2]=(c[Sa>>2]|0)+4;Za=Ra+31|0;_a=0}c[e>>2]=_a;c[g>>2]=Za;va=Za;wa=_a}_a=b+2332|0;if((c[_a>>2]|0)==6){$a=va;ab=wa}else{Za=((c[(c[b+108>>2]|0)+428>>2]|0)%6|0|0)==0|0;if((va|0)>1){bb=va-1|0;cb=wa<<1|Za}else{Ra=fe(Za>>>((1-va|0)>>>0)|wa<<va|0)|0;wa=b+124|0;Sa=c[wa>>2]|0;x=Ra;a[Sa]=x;x=x>>8;a[Sa+1|0]=x;x=x>>8;a[Sa+2|0]=x;x=x>>8;a[Sa+3|0]=x;c[wa>>2]=(c[wa>>2]|0)+4;bb=va+31|0;cb=Za}c[e>>2]=cb;c[g>>2]=bb;$a=bb;ab=cb}if(($a|0)>1){db=$a-1|0;eb=ab<<1}else{cb=fe(ab<<$a|0)|0;ab=b+124|0;bb=c[ab>>2]|0;x=cb;a[bb]=x;x=x>>8;a[bb+1|0]=x;x=x>>8;a[bb+2|0]=x;x=x>>8;a[bb+3|0]=x;c[ab>>2]=(c[ab>>2]|0)+4;db=$a+31|0;eb=0}c[e>>2]=eb;c[g>>2]=db;if((c[_a>>2]|0)==6){$a=(c[b+2740>>2]|0)==0|0;if((db|0)>1){fb=db-1|0;gb=eb<<1|$a}else{ab=fe($a>>>((1-db|0)>>>0)|eb<<db|0)|0;bb=b+124|0;cb=c[bb>>2]|0;x=ab;a[cb]=x;x=x>>8;a[cb+1|0]=x;x=x>>8;a[cb+2|0]=x;x=x>>8;a[cb+3|0]=x;c[bb>>2]=(c[bb>>2]|0)+4;fb=db+31|0;gb=$a}c[e>>2]=gb;c[g>>2]=fb;if((fb|0)>1){hb=fb-1|0;ib=gb<<1}else{$a=fe(gb<<fb|0)|0;gb=b+124|0;bb=c[gb>>2]|0;x=$a;a[bb]=x;x=x>>8;a[bb+1|0]=x;x=x>>8;a[bb+2|0]=x;x=x>>8;a[bb+3|0]=x;c[gb>>2]=(c[gb>>2]|0)+4;hb=fb+31|0;ib=0}c[e>>2]=ib;c[g>>2]=hb;jb=hb;kb=ib}else{jb=db;kb=eb}if((jb|0)>2){lb=jb-2|0;mb=kb<<2}else{eb=fe(kb<<jb|0)|0;kb=b+124|0;db=c[kb>>2]|0;x=eb;a[db]=x;x=x>>8;a[db+1|0]=x;x=x>>8;a[db+2|0]=x;x=x>>8;a[db+3|0]=x;c[kb>>2]=(c[kb>>2]|0)+4;lb=jb+30|0;mb=0}c[e>>2]=mb;c[g>>2]=lb;if((lb|0)>1){nb=lb-1|0;ob=mb<<1}else{jb=fe(mb<<lb|0)|0;mb=b+124|0;kb=c[mb>>2]|0;x=jb;a[kb]=x;x=x>>8;a[kb+1|0]=x;x=x>>8;a[kb+2|0]=x;x=x>>8;a[kb+3|0]=x;c[mb>>2]=(c[mb>>2]|0)+4;nb=lb+31|0;ob=0}c[e>>2]=ob;c[g>>2]=nb;if((nb|0)>1){pb=nb-1|0;qb=ob<<1}else{lb=fe(ob<<nb|0)|0;ob=b+124|0;mb=c[ob>>2]|0;x=lb;a[mb]=x;x=x>>8;a[mb+1|0]=x;x=x>>8;a[mb+2|0]=x;x=x>>8;a[mb+3|0]=x;c[ob>>2]=(c[ob>>2]|0)+4;pb=nb+31|0;qb=0}c[e>>2]=qb;c[g>>2]=pb;if((pb|0)>1){rb=pb-1|0;sb=qb<<1}else{nb=fe(qb<<pb|0)|0;qb=b+124|0;ob=c[qb>>2]|0;x=nb;a[ob]=x;x=x>>8;a[ob+1|0]=x;x=x>>8;a[ob+2|0]=x;x=x>>8;a[ob+3|0]=x;c[qb>>2]=(c[qb>>2]|0)+4;rb=pb+31|0;sb=0}c[e>>2]=sb;c[g>>2]=rb;if((rb|0)>1){tb=rb-1|0;ub=sb<<1}else{pb=fe(sb<<rb|0)|0;sb=b+124|0;qb=c[sb>>2]|0;x=pb;a[qb]=x;x=x>>8;a[qb+1|0]=x;x=x>>8;a[qb+2|0]=x;x=x>>8;a[qb+3|0]=x;c[sb>>2]=(c[sb>>2]|0)+4;tb=rb+31|0;ub=0}c[e>>2]=ub;c[g>>2]=tb;if((tb|0)>1){vb=tb-1|0;wb=ub<<1}else{rb=fe(ub<<tb|0)|0;ub=b+124|0;sb=c[ub>>2]|0;x=rb;a[sb]=x;x=x>>8;a[sb+1|0]=x;x=x>>8;a[sb+2|0]=x;x=x>>8;a[sb+3|0]=x;c[ub>>2]=(c[ub>>2]|0)+4;vb=tb+31|0;wb=0}c[e>>2]=wb;c[g>>2]=vb;if((vb|0)>1){xb=vb-1|0;yb=wb<<1}else{tb=fe(wb<<vb|0)|0;wb=b+124|0;ub=c[wb>>2]|0;x=tb;a[ub]=x;x=x>>8;a[ub+1|0]=x;x=x>>8;a[ub+2|0]=x;x=x>>8;a[ub+3|0]=x;c[wb>>2]=(c[wb>>2]|0)+4;xb=vb+31|0;yb=0}c[e>>2]=yb;c[g>>2]=xb;if((xb|0)>1){zb=xb-1|0;Ab=yb<<1}else{vb=fe(yb<<xb|0)|0;yb=b+124|0;wb=c[yb>>2]|0;x=vb;a[wb]=x;x=x>>8;a[wb+1|0]=x;x=x>>8;a[wb+2|0]=x;x=x>>8;a[wb+3|0]=x;c[yb>>2]=(c[yb>>2]|0)+4;zb=xb+31|0;Ab=0}c[e>>2]=Ab;c[g>>2]=zb;if((zb|0)>1){Bb=zb-1|0;Cb=Ab<<1}else{xb=fe(Ab<<zb|0)|0;Ab=b+124|0;yb=c[Ab>>2]|0;x=xb;a[yb]=x;x=x>>8;a[yb+1|0]=x;x=x>>8;a[yb+2|0]=x;x=x>>8;a[yb+3|0]=x;c[Ab>>2]=(c[Ab>>2]|0)+4;Bb=zb+31|0;Cb=0}c[e>>2]=Cb;c[g>>2]=Bb;do{if((c[w>>2]|0)>1){zb=c[b+1596>>2]|0;if((Bb|0)>1){Db=Bb-1|0;Eb=Cb<<1|zb}else{Ab=fe(Cb<<Bb|zb>>>((1-Bb|0)>>>0)|0)|0;yb=b+124|0;xb=c[yb>>2]|0;x=Ab;a[xb]=x;x=x>>8;a[xb+1|0]=x;x=x>>8;a[xb+2|0]=x;x=x>>8;a[xb+3|0]=x;c[yb>>2]=(c[yb>>2]|0)+4;Db=Bb+31|0;Eb=zb}c[e>>2]=Eb;c[g>>2]=Db;if((c[_a>>2]|0)<=1){Fb=Eb;Gb=Db;break}zb=b+124|0;yb=1;xb=Eb;Ab=Db;while(1){wb=b+1536+(yb<<7)+56|0;vb=c[wb>>2]|0;if((Ab|0)>1){Hb=Ab-1|0;Ib=xb<<1|vb;Jb=vb}else{ub=fe(vb>>>((1-Ab|0)>>>0)|xb<<Ab|0)|0;tb=c[zb>>2]|0;x=ub;a[tb]=x;x=x>>8;a[tb+1|0]=x;x=x>>8;a[tb+2|0]=x;x=x>>8;a[tb+3|0]=x;c[zb>>2]=(c[zb>>2]|0)+4;Hb=Ab+31|0;Ib=vb;Jb=c[wb>>2]|0}c[e>>2]=Ib;c[g>>2]=Hb;if((Jb|0)==0){Kb=Ib;Lb=Hb}else{wb=c[b+1536+(yb<<7)+60>>2]|0;if((Hb|0)>1){Mb=Hb-1|0;Nb=Ib<<1|wb}else{vb=fe(Ib<<Hb|wb>>>((1-Hb|0)>>>0)|0)|0;tb=c[zb>>2]|0;x=vb;a[tb]=x;x=x>>8;a[tb+1|0]=x;x=x>>8;a[tb+2|0]=x;x=x>>8;a[tb+3|0]=x;c[zb>>2]=(c[zb>>2]|0)+4;Mb=Hb+31|0;Nb=wb}c[e>>2]=Nb;c[g>>2]=Mb;Kb=Nb;Lb=Mb}wb=yb+1|0;if((wb|0)<(c[_a>>2]|0)){yb=wb;xb=Kb;Ab=Lb}else{Fb=Kb;Gb=Lb;break}}}else{Fb=Cb;Gb=Bb}}while(0);Bb=b+2740|0;do{if((c[Bb>>2]|0)==0){Cb=c[_a>>2]|0;if((Cb|0)<=0){Ob=Fb;Pb=Gb;break}Lb=b+2368|0;Kb=b+124|0;Mb=0;Nb=Fb;Hb=Gb;Ib=c[Lb>>2]|0;Jb=Cb;while(1){Cb=(c[b+1536+(Mb<<7)+60>>2]|0)==0|0;if((Cb|0)>(Ib|0)){Qb=Nb;Rb=Hb;Sb=Ib;Tb=Jb}else{Db=Cb;Cb=Nb;Eb=Hb;w=Ib;while(1){Ab=d[b+2688+(Db*6|0)+Mb|0]|0;if((Eb|0)>2){Ub=Eb-2|0;Vb=Cb<<2|Ab;Wb=w}else{xb=fe(Ab>>>((2-Eb|0)>>>0)|Cb<<Eb|0)|0;yb=c[Kb>>2]|0;x=xb;a[yb]=x;x=x>>8;a[yb+1|0]=x;x=x>>8;a[yb+2|0]=x;x=x>>8;a[yb+3|0]=x;c[Kb>>2]=(c[Kb>>2]|0)+4;Ub=Eb+30|0;Vb=Ab;Wb=c[Lb>>2]|0}c[e>>2]=Vb;c[g>>2]=Ub;Ab=Db+1|0;if((Ab|0)>(Wb|0)){break}else{Db=Ab;Cb=Vb;Eb=Ub;w=Wb}}Qb=Vb;Rb=Ub;Sb=Wb;Tb=c[_a>>2]|0}w=Mb+1|0;if((w|0)<(Tb|0)){Mb=w;Nb=Qb;Hb=Rb;Ib=Sb;Jb=Tb}else{Ob=Qb;Pb=Rb;break}}}else{Jb=(c[b+2464>>2]|0)==0|0;Ib=b+2368|0;Hb=c[Ib>>2]|0;if((Jb|0)>(Hb|0)){Ob=Fb;Pb=Gb;break}Nb=b+124|0;Mb=Jb;Jb=Fb;Lb=Gb;Kb=Hb;while(1){Hb=d[b+2730+Mb|0]|0;if((Lb|0)>5){Xb=Lb-5|0;Yb=Jb<<5|Hb;Zb=Kb}else{w=fe(Hb>>>((5-Lb|0)>>>0)|Jb<<Lb|0)|0;Eb=c[Nb>>2]|0;x=w;a[Eb]=x;x=x>>8;a[Eb+1|0]=x;x=x>>8;a[Eb+2|0]=x;x=x>>8;a[Eb+3|0]=x;c[Nb>>2]=(c[Nb>>2]|0)+4;Xb=Lb+27|0;Yb=Hb;Zb=c[Ib>>2]|0}c[e>>2]=Yb;c[g>>2]=Xb;Hb=Mb+1|0;if((Hb|0)>(Zb|0)){Ob=Yb;Pb=Xb;break}else{Mb=Hb;Jb=Yb;Lb=Xb;Kb=Zb}}}}while(0);Zb=c[_a>>2]|0;do{if((c[y>>2]|0)==0){_b=Zb;$b=Ob;ac=Pb;bc=214}else{if((Zb|0)<=0){cc=Pb;dc=Ob;bc=217;break}Xb=b+2380|0;Yb=b+124|0;Gb=0;Fb=Ob;Rb=Pb;Qb=Zb;while(1){Tb=d[b+2688+((c[Xb>>2]|0)*6|0)+Gb|0]|0;if((Rb|0)>1){ec=Rb-1|0;fc=Fb<<1|Tb;gc=Qb}else{Sb=fe(Tb>>>((1-Rb|0)>>>0)|Fb<<Rb|0)|0;Wb=c[Yb>>2]|0;x=Sb;a[Wb]=x;x=x>>8;a[Wb+1|0]=x;x=x>>8;a[Wb+2|0]=x;x=x>>8;a[Wb+3|0]=x;c[Yb>>2]=(c[Yb>>2]|0)+4;ec=Rb+31|0;fc=Tb;gc=c[_a>>2]|0}c[e>>2]=fc;c[g>>2]=ec;Tb=Gb+1|0;if((Tb|0)<(gc|0)){Gb=Tb;Fb=fc;Rb=ec;Qb=gc}else{_b=gc;$b=fc;ac=ec;bc=214;break}}}}while(0);do{if((bc|0)==214){if((_b|0)!=6){cc=ac;dc=$b;bc=217;break}ec=b+2368|0;if((c[ec>>2]|0)<1){hc=ac;ic=$b;break}fc=b+124|0;gc=1;Zb=$b;Pb=ac;while(1){do{if((c[Bb>>2]|0)==0){if((Pb|0)>5){jc=Pb-5|0;kc=Zb<<5;break}else{Ob=fe(Zb<<Pb|0)|0;y=c[fc>>2]|0;x=Ob;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[fc>>2]=(c[fc>>2]|0)+4;jc=Pb+27|0;kc=0;break}}else{y=d[b+2730+gc|0]|0;if((Pb|0)>5){jc=Pb-5|0;kc=Zb<<5|y;break}else{Ob=fe(y>>>((5-Pb|0)>>>0)|Zb<<Pb|0)|0;Qb=c[fc>>2]|0;x=Ob;a[Qb]=x;x=x>>8;a[Qb+1|0]=x;x=x>>8;a[Qb+2|0]=x;x=x>>8;a[Qb+3|0]=x;c[fc>>2]=(c[fc>>2]|0)+4;jc=Pb+27|0;kc=y;break}}}while(0);c[e>>2]=kc;c[g>>2]=jc;y=gc+1|0;if((y|0)>(c[ec>>2]|0)){hc=jc;ic=kc;break}else{gc=y;Zb=kc;Pb=jc}}}}while(0);if((bc|0)==217){if((cc|0)>1){lc=cc-1|0;mc=dc<<1}else{bc=fe(dc<<cc|0)|0;dc=b+124|0;jc=c[dc>>2]|0;x=bc;a[jc]=x;x=x>>8;a[jc+1|0]=x;x=x>>8;a[jc+2|0]=x;x=x>>8;a[jc+3|0]=x;c[dc>>2]=(c[dc>>2]|0)+4;lc=cc+31|0;mc=0}c[e>>2]=mc;c[g>>2]=lc;hc=lc;ic=mc}mc=c[b+2560>>2]|0;if((hc|0)>6){nc=hc-6|0;oc=ic<<6|mc}else{lc=fe(ic<<hc|mc>>>((6-hc|0)>>>0)|0)|0;ic=b+124|0;cc=c[ic>>2]|0;x=lc;a[cc]=x;x=x>>8;a[cc+1|0]=x;x=x>>8;a[cc+2|0]=x;x=x>>8;a[cc+3|0]=x;c[ic>>2]=(c[ic>>2]|0)+4;nc=hc+26|0;oc=mc}c[e>>2]=oc;c[g>>2]=nc;mc=c[b+2596>>2]|0;if((nc|0)>4){pc=nc-4|0;qc=oc<<4|mc}else{hc=fe(oc<<nc|mc>>>((4-nc|0)>>>0)|0)|0;oc=b+124|0;ic=c[oc>>2]|0;x=hc;a[ic]=x;x=x>>8;a[ic+1|0]=x;x=x>>8;a[ic+2|0]=x;x=x>>8;a[ic+3|0]=x;c[oc>>2]=(c[oc>>2]|0)+4;pc=nc+28|0;qc=mc}c[e>>2]=qc;c[g>>2]=pc;if((c[_a>>2]|0)<=1){return}if((pc|0)>1){rc=pc-1|0;sc=qc<<1}else{_a=fe(qc<<pc|0)|0;qc=b+124|0;b=c[qc>>2]|0;x=_a;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[qc>>2]=(c[qc>>2]|0)+4;rc=pc+31|0;sc=0}c[e>>2]=sc;c[g>>2]=rc;return}function o8(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;a=b+4|0;c[a>>2]=ICb()|0;d=ICb()|0;e=b+8|0;c[e>>2]=d;if(!((c[a>>2]|0)==0|(d|0)==0)){f=0;return f|0}JCb(a);JCb(e);f=-12;return f|0}function p8(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=g;m=j+k|0;n=e;if((k|0)<8){o=-1094995529;i=h;return o|0}p=j;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;do{if((q|0)==1749636685|(q|0)==1297500520){p=j+4|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m;if((p-(j+8)|0)<16){yDb(c[g>>2]|0,24,2189472,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;o=-1094995529;i=h;return o|0}s=j+12|0;t=(d[s]|d[s+1|0]<<8)<<16>>16&65535;s=g+12|0;c[s>>2]=t;u=j+14|0;v=(d[u]|d[u+1|0]<<8)<<16>>16&65535;u=g+16|0;c[u>>2]=v;w=g;y=c[w>>2]|0;if((t|0)==(c[y+120>>2]|0)){if((v|0)==(c[y+124>>2]|0)){z=y;A=t;B=v}else{C=8}}else{C=8}if((C|0)==8){KCb(c[g+4>>2]|0);KCb(c[g+8>>2]|0);z=c[w>>2]|0;A=c[s>>2]|0;B=c[u>>2]|0}v=V$a(z,A,B)|0;if((v|0)<0){o=v;i=h;return o|0}v=j+18|0;t=(d[v]|d[v+1|0]<<8)<<16>>16;if(!(t<<16>>16==0)){v=c[w>>2]|0;c[v+104>>2]=1;c[v+108>>2]=t&65535}t=j+20|0;v=(d[t]|d[t+1|0]<<8)<<16>>16;t=v&65535;y=j+22|0;D=(d[y]|d[y+1|0]<<8)<<16>>16;y=(D&65535)+t|0;a:do{if(D<<16>>16!=0&(v&65535)>>>0<256>>>0){E=t;F=j+24|0;while(1){if((p-F|0)<=2){break a}c[l+20+(E<<2)>>2]=d[F]<<16|d[F+1|0]<<8|d[F+2|0]|-16777216;G=E+1|0;if((G|0)<(y|0)&(G|0)<256){E=G;F=F+3|0}else{break}}}}while(0);if(r>>>0>(k-8|0)>>>0){o=-1;i=h;return o|0}else{H=j+r|0;I=s;J=u;K=w;break}}else{H=j;I=g+12|0;J=g+16|0;K=g}}while(0);if((hDb(c[I>>2]|0,c[J>>2]|0,0,c[K>>2]|0)|0)!=0){o=-1;i=h;return o|0}J=_$a(b,n,1)|0;if((J|0)<0){o=J;i=h;return o|0}UGb(c[e+4>>2]|0,g+20|0,1024)|0;b:do{if((a[H+8|0]&1)==0){c[e+84>>2]=1;c[e+88>>2]=1;J=m;b=c[K>>2]|0;if((c[b+124>>2]|0)<=0){break}I=e+32|0;j=H+10|0;l=c[e>>2]|0;B=0;A=c[b+120>>2]|0;while(1){if((J-j|0)<(A|0)){break b}UGb(l|0,j|0,A)|0;b=c[K>>2]|0;z=c[b+120>>2]|0;C=B+1|0;if((C|0)<(c[b+124>>2]|0)){j=j+z|0;l=l+(c[I>>2]|0)|0;B=C;A=z}else{break}}}else{A=c[K>>2]|0;B=c[A+124>>2]|0;if((B|0)>3){I=c[A+120>>2]|0;l=m-(H+10)|0;j=e;J=e+32|0;w=g+8|0;u=g+4|0;s=0;r=0;z=H+(((ba(I,B)|0)/16|0)+10)|0;B=A;A=I;while(1){I=r<<2;if((A|0)>3&(l|0)>(s|0)){C=I+4|0;b=s;q=0;y=z;p=B;t=A;while(1){v=q<<2;D=v+4|0;F=v|1;E=((D|0)>(F|0)?D:F)+(q*-4|0)|0;F=a[H+(b+10)|0]|0;G=F&255;c:do{if(F<<24>>24==-1){L=c[j>>2]|0;M=c[J>>2]|0;N=(ba(M,I)|0)+v|0;O=L+N|0;do{if((y+16|0)>>>0<m>>>0){if(!((a[y]|0)==-1)){break}P=y+1|0;Q=O;x=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=y+5|0;P=L+((c[J>>2]|0)+N)|0;x=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;P=y+9|0;Q=L+((c[J>>2]<<1)+N)|0;x=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=y+13|0;P=L+(((c[J>>2]|0)*3|0)+N)|0;x=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;R=y+17|0;break c}}while(0);if(!(y>>>0<m>>>0)){R=y;break}N=d[y]|0;O=c[w>>2]|0;P=c[O>>2]|0;if((P|0)!=0){Q=(N>>>4)-7|0;S=(N&15)-7|0;N=c[O+32>>2]|0;O=c[p+124>>2]|0;T=I;U=0;while(1){V=Q+T|0;W=(ba(V,N)|0)+S|0;X=ba(T,M)|0;if((V|0)>-1&(V|0)<(O|0)){V=v;do{Y=V+S|0;if((Y|0)>-1&(Y|0)<(t|0)){a[L+(V+X)|0]=a[P+(W+V)|0]|0}else{a[L+(V+X)|0]=0}V=V+1|0;}while((V|0)<(D|0))}else{TGb(L+((ba(U+I|0,M)|0)+v)|0,0,E|0)|0}V=T+1|0;if((V|0)<(C|0)){T=V;U=U+1|0}else{break}}}R=y+1|0}else{U=c[u>>2]|0;T=c[U>>2]|0;if((T|0)==0){R=y;break}M=(G>>>4)-7|0;L=(G&15)-7|0;P=c[j>>2]|0;S=c[J>>2]|0;O=c[U+32>>2]|0;U=c[p+124>>2]|0;N=I;Q=0;while(1){V=M+N|0;X=(ba(V,O)|0)+L|0;W=ba(N,S)|0;if((V|0)>-1&(V|0)<(U|0)){V=v;do{Y=V+L|0;if((Y|0)>-1&(Y|0)<(t|0)){a[P+(V+W)|0]=a[T+(X+V)|0]|0}else{a[P+(V+W)|0]=0}V=V+1|0;}while((V|0)<(D|0))}else{TGb(P+((ba(Q+I|0,S)|0)+v)|0,0,E|0)|0}V=N+1|0;if((V|0)<(C|0)){N=V;Q=Q+1|0}else{R=y;break}}}}while(0);E=b+1|0;v=q+1|0;D=c[K>>2]|0;G=c[D+120>>2]|0;if((v|0)<((G|0)/4|0|0)&(l|0)>(E|0)){b=E;q=v;y=R;p=D;t=G}else{Z=E;_=R;$=D;aa=G;break}}}else{Z=s;_=z;$=B;aa=A}t=r+1|0;if((t|0)<((c[$+124>>2]|0)/4|0|0)){s=Z;r=t;z=_;B=$;A=aa}else{break}}}c[e+84>>2]=0;c[e+88>>2]=2}}while(0);e=g+8|0;KCb(c[e>>2]|0);aa=g+4|0;QCb(c[e>>2]|0,c[aa>>2]|0);e=MCb(c[aa>>2]|0,n)|0;if((e|0)<0){o=e;i=h;return o|0}c[f>>2]=1;o=k;i=h;return o|0}function q8(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);JCb(b+8|0);return 0}function r8(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=0;Z3(b+4|0,a);a=b+1132|0;y2(a,1);x2(a,b+1408|0,1075976);xMa();a=ICb()|0;c[b+1248>>2]=a;return((a|0)==0?-12:0)|0}function s8(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;k=i;l=c[j+24>>2]|0;m=c[j+28>>2]|0;j=l+m|0;n=c[f+60>>2]|0;o=n;p=g;if((m|0)<26){yDb(f,16,2189448,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[h>>2]=0;r=-1094995529;i=k;return r|0}s=l;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+14|0;iFb(f+104|0,f+108|0,(d[s]|d[s+1|0]<<8)<<16>>16&65535,0,1e3,0,1073741824,0)|0;s=l+16|0;u=(d[s]|d[s+1|0]<<8)<<16>>16;s=l+18|0;v=(d[s]|d[s+1|0]<<8)<<16>>16;s=d[l+21|0]|0;w=n+1540|0;b[w>>1]=(ba(e[589588]|0,e[600292]|0)|0)>>>11;x=1;do{b[o+1540+(x<<1)>>1]=((ba(ba(e[1200584+(x<<1)>>1]|0,s)|0,e[1179176+(x<<1)>>1]|0)|0)+32|0)>>>10;x=x+1|0;}while((x|0)<64);x=(t|0)==1698971981;s=u&65535;y=v&65535;z=l+24|0;if((u&65535)>>>0<16>>>0|(v&65535)>>>0<16>>>0){yDb(f,16,2112216,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=k;return r|0}v=f+120|0;if((c[v>>2]|0)==(s|0)){if((c[f+124>>2]|0)!=(y|0)){A=9}}else{A=9}do{if((A|0)==9){KCb(c[n+1248>>2]|0);if((((ba(y,s)|0)>>>11)*7|0|0)>(j-z|0)){r=-1094995529;i=k;return r|0}u=V$a(f,s,y)|0;if((u|0)<0){r=u}else{break}i=k;return r|0}}while(0);y=_$a(f,p,1)|0;if((y|0)<0){r=y;i=k;return r|0}do{if((t|0)==1833189709|(t|0)==1698971981){y=n+1248|0;if((c[c[y>>2]>>2]|0)!=0){break}yDb(f,24,2053624,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=_$a(f,c[y>>2]|0,1)|0;if((s|0)<0){r=s;i=k;return r|0}else{s=c[y>>2]|0;TGb(c[s>>2]|0,0,ba(c[s+32>>2]|0,c[s+72>>2]|0)|0)|0;s=c[y>>2]|0;TGb(c[s+4>>2]|0,-128|0,ba(c[s+36>>2]|0,(c[s+72>>2]|0)/2|0)|0)|0;s=c[y>>2]|0;TGb(c[s+8>>2]|0,-128|0,ba(c[s+40>>2]|0,(c[s+72>>2]|0)/2|0)|0)|0;break}}}while(0);s=n+1272|0;y=s;A=j-z|0;O$a(s,n+1276|0,A);s=c[y>>2]|0;if((s|0)==0){r=-12;i=k;return r|0}Xe[c[n+1104>>2]&4095](s,z,(A|0)/2|0);TGb((c[y>>2]|0)+A|0,0,16)|0;z=c[y>>2]|0;y=A<<3;A=y>>>0>2147483639>>>0|(z|0)==0;s=A?0:z;z=A?0:y;y=n+1252|0;c[y>>2]=s;c[n+1264>>2]=z;A=n+1268|0;c[A>>2]=z+8;c[n+1256>>2]=s+(z>>3);z=n+1260|0;c[z>>2]=0;s=n+1672|0;c[s>>2]=0;j=f+124|0;a:do{if((c[j>>2]|0)>0){f=n+1668|0;u=n+40|0;l=n+1280|0;B=g;C=g+32|0;D=n;E=n+1248|0;F=0;b:while(1){c[f>>2]=0;if((c[v>>2]|0)>0){do{do{if((t|0)==1833189709|(t|0)==1698971981){G=c[z>>2]|0;H=c[y>>2]|0;I=d[H+(G>>>3)|0]|0;J=c[A>>2]|0;K=((G|0)<(J|0))+G|0;c[z>>2]=K;if((I&128>>>((G&7)>>>0)|0)==0){G=d[H+(K>>>3)|0]<<(K&7)>>>7;I=((K|0)<(J|0))+K|0;c[z>>2]=I;if(!((2-(G&1)|0)>>>0<2>>>0)){L=0;M=0;N=0;break}G=H+(I>>>3)|0;O=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(I&7)>>>26;G=I+6|0;I=J>>>0>G>>>0?G:J;c[z>>2]=I;P=O;Q=I}else{P=63;Q=K}K=d[H+(Q>>>3)|0]|0;I=((Q|0)<(J|0))+Q|0;c[z>>2]=I;if((K&128>>>((Q&7)>>>0)|0)==0){R=0;S=I}else{K=d[H+(I>>>3)|0]|0;O=((I|0)<(J|0))+I|0;c[z>>2]=O;G=H+(O>>>3)|0;T=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(O&7)>>>28;G=O+4|0;O=J>>>0>G>>>0?G:J;c[z>>2]=O;R=((K&128>>>((I&7)>>>0)|0)==0?1:-16)+T|0;S=O}O=d[H+(S>>>3)|0]|0;T=((S|0)<(J|0))+S|0;c[z>>2]=T;if((O&128>>>((S&7)>>>0)|0)==0){L=P;M=0;N=R;break}O=d[H+(T>>>3)|0]|0;I=((T|0)<(J|0))+T|0;c[z>>2]=I;K=H+(I>>>3)|0;H=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(I&7)>>>28;K=I+4|0;c[z>>2]=J>>>0>K>>>0?K:J;L=P;M=((O&128>>>((T&7)>>>0)|0)==0?1:-16)+H|0;N=R}else{L=0;M=0;N=0}}while(0);H=(M|0)/2|0;T=(N|0)/2|0;O=0;do{do{if((1<<O&L|0)==0){me[c[u>>2]&511](l);J=c[z>>2]|0;K=c[A>>2]|0;I=c[y>>2]|0;G=I+(J>>>3)|0;U=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(J&7)>>24;G=J+8|0;J=K>>>0>G>>>0?G:K;c[z>>2]=J;b[l>>1]=ba(U+128|0,b[w>>1]|0)|0;U=c[287062]|0;G=J;J=0;c:while(1){V=I+(G>>>3)|0;W=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(G&7);V=W>>>23;X=b[U+(V<<2)>>1]|0;Y=a[U+(V<<2)+2|0]|0;Z=Y<<24>>24;if(Y<<24>>24<0){Y=W<<9;_=G+9|0;$=(Y>>>((Z+32|0)>>>0))+X|0;aa=$;ca=a[U+($<<2)+2|0]|0;da=b[U+($<<2)>>1]|0;ea=Y;fa=K>>>0>_>>>0?_:K}else{aa=V;ca=Z;da=X;ea=W;fa=G}W=ca+fa|0;ga=K>>>0>W>>>0?W:K;do{if((da|0)==0){W=I+(ga>>>3)|0;X=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(ga&7)>>22;W=ga+10|0;Z=K>>>0>W>>>0?W:K;W=I+(Z>>>3)|0;V=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Z&7)>>>26;W=Z+6|0;Z=K>>>0>W>>>0?W:K;W=J+1+V|0;V=d[o+1412+W|0]|0;if((X|0)<0){ha=-(((ba(b[o+1540+(V<<1)>>1]|0,-X|0)|0)>>>4)+65535|1)&65535;ia=Z;ja=W;ka=V;break}else{ha=(((ba(b[o+1540+(V<<1)>>1]|0,X)|0)>>>4)+65535|1)&65535;ia=Z;ja=W;ka=V;break}}else if((da|0)==127){break c}else{V=(d[U+(aa<<2)+3|0]|0)+J|0;W=d[o+1412+V|0]|0;Z=ea<<ca>>31;X=((((ba(b[o+1540+(W<<1)>>1]|0,da)|0)>>>4)+65535|1)^Z)-Z|0;Z=ga+1|0;ha=X&65535;ia=K>>>0>Z>>>0?Z:K;ja=V;ka=W}}while(0);if((ja|0)>63){break b}b[o+1280+(ka<<1)>>1]=ha;G=ia;J=ja}c[z>>2]=ga;J=c[f>>2]|0;G=c[s>>2]|0;if((O|0)<4){K=c[C>>2]|0;Jkb((c[B>>2]|0)+((ba(K,G<<4|O<<2&8)|0)+(J<<4|O<<3&8))|0,K,l);break}if((c[(c[D>>2]|0)+88>>2]&8192|0)!=0){break}K=O-3|0;U=c[p+32+(K<<2)>>2]|0;Jkb((c[p+(K<<2)>>2]|0)+((ba(U,G)|0)+J<<3)|0,U,l)}else{U=c[z>>2]|0;J=c[y>>2]|0;G=d[J+(U>>>3)|0]|0;K=c[A>>2]|0;I=((U|0)<(K|0))+U|0;c[z>>2]=I;if((G&128>>>((U&7)>>>0)|0)==0){la=0}else{U=d[J+(I>>>3)|0]|0;G=((I|0)<(K|0))+I|0;c[z>>2]=G;W=J+(G>>>3)|0;J=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(G&7)>>>28;W=G+4|0;c[z>>2]=K>>>0>W>>>0?W:K;la=((U&128>>>((I&7)>>>0)|0)==0?1:2147483632)+J<<1}J=c[E>>2]|0;I=c[J>>2]|0;if((I|0)==0){break}U=c[f>>2]|0;K=c[s>>2]|0;if((O|0)<4){W=K<<4|O<<2&8;G=c[J+32>>2]|0;V=U<<4;Z=O<<3&8;X=Z+N+V+(ba(G,W+M|0)|0)|0;if(!(X>>>0<((ba((c[(c[D>>2]|0)+124>>2]|0)-7|0,G)|0)-7|0)>>>0)){break}_=c[C>>2]|0;u8((c[B>>2]|0)+((ba(_,W)|0)+(V|Z))|0,_,I+X|0,G,la);break}G=c[D>>2]|0;if((c[G+88>>2]&8192|0)!=0){break}X=O-3|0;I=K<<3;K=c[J+32+(X<<2)>>2]|0;_=U<<3;U=_+T+(ba(K,I+H|0)|0)|0;if(!(U>>>0<((ba(((c[G+124>>2]|0)/2|0)-7|0,K)|0)-7|0)>>>0)){break}G=c[p+32+(X<<2)>>2]|0;Z=(c[p+(X<<2)>>2]|0)+((ba(G,I)|0)+_)|0;u8(Z,G,(c[J+(X<<2)>>2]|0)+U|0,K,la)}}while(0);O=O+1|0;}while((O|0)<6);O=(c[f>>2]|0)+1|0;c[f>>2]=O;}while((O|0)<(((c[v>>2]|0)+15|0)/16|0|0));ma=c[s>>2]|0}else{ma=F}F=ma+1|0;c[s>>2]=F;if((F|0)>=(((c[j>>2]|0)+15|0)/16|0|0)){break a}}F=c[s>>2]|0;yDb(c[D>>2]|0,16,2007840,(q=i,i=i+16|0,c[q>>2]=c[f>>2],c[q+8>>2]=F,q)|0);i=q;r=-1094995529;i=k;return r|0}}while(0);c[h>>2]=1;do{if(!x){h=n+1248|0;KCb(c[h>>2]|0);q=MCb(c[h>>2]|0,p)|0;if((q|0)<0){r=q}else{break}i=k;return r|0}}while(0);r=m;i=k;return r|0}function t8(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+1248|0);ZDb(c[b+1272>>2]|0);return 0}function u8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=0;do{i=ba(h,f)|0;j=ba(h,c)|0;k=(d[e+i|0]|0)+g|0;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[b+j|0]=l;k=(d[e+(i+1)|0]|0)+g|0;if(k>>>0>255>>>0){m=-k>>31&255}else{m=k&255}a[b+(j+1)|0]=m;k=(d[e+(i+2)|0]|0)+g|0;if(k>>>0>255>>>0){n=-k>>31&255}else{n=k&255}a[b+(j+2)|0]=n;k=(d[e+(i+3)|0]|0)+g|0;if(k>>>0>255>>>0){o=-k>>31&255}else{o=k&255}a[b+(j+3)|0]=o;k=(d[e+(i+4)|0]|0)+g|0;if(k>>>0>255>>>0){p=-k>>31&255}else{p=k&255}a[b+(j+4)|0]=p;k=(d[e+(i+5)|0]|0)+g|0;if(k>>>0>255>>>0){q=-k>>31&255}else{q=k&255}a[b+(j+5)|0]=q;k=(d[e+(i+6)|0]|0)+g|0;if(k>>>0>255>>>0){r=-k>>31&255}else{r=k&255}a[b+(j+6)|0]=r;k=(d[e+(i+7)|0]|0)+g|0;if(k>>>0>255>>>0){s=-k>>31&255}else{s=k&255}a[b+(j+7)|0]=s;h=h+1|0;}while((h|0)<8);return}function v8(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+64|0;d=c[a+60>>2]|0;c[d>>2]=a;e=b|0;y2(e,1);x2(e,d+12|0,1075976);c[a+104>>2]=1;c[a+108>>2]=15;c[a+140>>2]=0;i=b;return 0}function w8(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0;k=i;i=i+8|0;l=k|0;m=c[j+24>>2]|0;n=j+28|0;j=c[n>>2]|0;o=c[f+60>>2]|0;p=o;q=g;if((j|0)<16){yDb(f,24,2189424,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=k;return s|0}t=m+8|0;if(!((j-8|0)>-1)){yDb(0,0,2053592,(r=i,i=i+24|0,c[r>>2]=2007824,c[r+8>>2]=1969816,c[r+16>>2]=135,r)|0);i=r;Cd();return 0}u=m+4|0;v=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>0>1048575>>>0;u=o+1168|0;c[o+1176>>2]=t;w=o+1172|0;c[w>>2]=m+j;j=m+10|0;c[u>>2]=j;x=t;t=(d[x]|d[x+1|0]<<8)<<16>>16;if(v){v=(de(t|0)|0)&65535;c[o+4>>2]=v;c[u>>2]=m+12;x=j;y=(de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535;c[o+8>>2]=y;z=v;A=y}else{y=t&65535;c[o+4>>2]=y;c[u>>2]=m+12;m=j;j=(d[m]|d[m+1|0]<<8)<<16>>16&65535;c[o+8>>2]=j;z=y;A=j}j=o;y=V$a(c[j>>2]|0,z,A)|0;if((y|0)<0){s=y;i=k;return s|0}y=c[u>>2]|0;c[u>>2]=y+1;A=100-(d[y]|0)|0;y=((A*14|0|0)/100|0)+1|0;z=((A*11|0|0)/100|0)+4|0;A=0;while(1){m=A<<3;t=((ba(A,y)|0)/14|0)+z|0;c[p+144+(m<<2)>>2]=(ba(e[1200584+(m<<1)>>1]|0,t)|0)>>10;t=A+1|0;v=((ba(t,y)|0)/14|0)+z|0;x=m|1;c[p+144+(x<<2)>>2]=(ba(e[1200584+(x<<1)>>1]|0,v)|0)>>10;v=((ba(A+2|0,y)|0)/14|0)+z|0;x=m|2;c[p+144+(x<<2)>>2]=(ba(e[1200584+(x<<1)>>1]|0,v)|0)>>10;v=((ba(A+3|0,y)|0)/14|0)+z|0;x=m|3;c[p+144+(x<<2)>>2]=(ba(e[1200584+(x<<1)>>1]|0,v)|0)>>10;v=((ba(A+4|0,y)|0)/14|0)+z|0;x=m|4;c[p+144+(x<<2)>>2]=(ba(e[1200584+(x<<1)>>1]|0,v)|0)>>10;v=((ba(A+5|0,y)|0)/14|0)+z|0;x=m|5;c[p+144+(x<<2)>>2]=(ba(e[1200584+(x<<1)>>1]|0,v)|0)>>10;v=((ba(A+6|0,y)|0)/14|0)+z|0;x=m|6;c[p+144+(x<<2)>>2]=(ba(e[1200584+(x<<1)>>1]|0,v)|0)>>10;v=((ba(A+7|0,y)|0)/14|0)+z|0;x=m|7;c[p+144+(x<<2)>>2]=(ba(e[1200584+(x<<1)>>1]|0,v)|0)>>10;if((t|0)<8){A=t}else{break}}A=c[u>>2]|0;z=(c[w>>2]|0)-A|0;c[u>>2]=A+(z>>>0>3>>>0?3:z);z=_$a(f,q,0)|0;if((z|0)<0){s=z;i=k;return s|0}c[g+84>>2]=1;c[g+88>>2]=1;z=f+124|0;q=c[z>>2]|0;a:do{if((q+15>>4|0)>0){A=f+120|0;y=l|0;t=o+144|0;v=g+32|0;x=g;m=g+4|0;B=g+36|0;C=g+8|0;D=g+40|0;E=o+400|0;F=o+528|0;G=o+656|0;H=o+784|0;I=o+912|0;J=o+1040|0;K=l+4|0;L=l+5|0;M=l+1|0;N=l+2|0;O=l+3|0;P=0;Q=c[A>>2]|0;R=q;b:while(1){if((Q+15>>4|0)>0){S=P<<4;T=P<<3;U=0;do{V=c[u>>2]|0;W=c[w>>2]|0;if((W-V|0)<1){X=0;break b}Y=V+1|0;c[u>>2]=Y;Z=a[V]|0;_=Z&255;do{if((Z&255)>>>0>12>>>0){$=W-Y|0;aa=$>>>0>_>>>0?_:$;$=aa>>>0>268435455>>>0?-8:aa<<3;aa=$>>>0>2147483639>>>0|(Y|0)==0;ca=aa?0:Y;da=aa?8:$+8|0;$=0;aa=0;while(1){ea=p+400+(aa<<7)|0;fa=ca+($>>>3)|0;ga=$+8|0;b[ea>>1]=ba((d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)>>>(($&7)>>>0)<<24>>24,c[t>>2]|0)|0;fa=1;ha=da>>>0>ga>>>0?ga:da;while(1){ga=ca+(ha>>>3)|0;c:do{switch((d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((ha&7)>>>0)&7|0){case 2:{ia=ha+3|0;ja=d[p+16+fa|0]|0;b[p+400+(aa<<7)+(ja<<1)>>1]=c[p+144+(ja<<2)>>2];ka=fa+1|0;la=da>>>0>ia>>>0?ia:da;break};case 0:{ma=fa;na=23;break};case 5:case 1:{ia=ha+2|0;ja=da>>>0>ia>>>0?ia:da;ia=ca+(ja>>>3)|0;oa=(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)>>>((ja&7)>>>0)&63;ia=ja+6|0;ja=da>>>0>ia>>>0?ia:da;if((oa|0)==0){ka=fa;la=ja;break c}else{pa=0;qa=fa}while(1){b[p+400+(aa<<7)+(d[p+16+qa|0]<<1)>>1]=0;ia=pa+1|0;if((ia|0)<(oa|0)){pa=ia;qa=qa+1|0}else{break}}ka=(oa>>>0>1>>>0?oa:1)+fa|0;la=ja;break};case 4:{b[p+400+(aa<<7)+(d[p+16+fa|0]<<1)>>1]=0;ma=fa+1|0;na=23;break};case 7:case 3:{ia=ha+2|0;ra=da>>>0>ia>>>0?ia:da;ia=ca+(ra>>>3)|0;sa=(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)>>>((ra&7)>>>0);if((sa&63|0)==63){ia=ra+6|0;ta=da>>>0>ia>>>0?ia:da;ia=ca+(ta>>>3)|0;ua=ta+8|0;va=d[p+16+fa|0]|0;b[p+400+(aa<<7)+(va<<1)>>1]=ba((d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)>>>((ta&7)>>>0)<<24>>24,c[p+144+(va<<2)>>2]|0)|0;wa=da>>>0>ua>>>0?ua:da}else{ua=ra+6|0;ra=d[p+16+fa|0]|0;b[p+400+(aa<<7)+(ra<<1)>>1]=ba(c[p+144+(ra<<2)>>2]|0,sa<<26>>26)|0;wa=da>>>0>ua>>>0?ua:da}ka=fa+1|0;la=wa;break};case 6:{ua=ha+3|0;sa=d[p+16+fa|0]|0;b[p+400+(aa<<7)+(sa<<1)>>1]=-(c[p+144+(sa<<2)>>2]|0);ka=fa+1|0;la=da>>>0>ua>>>0?ua:da;break};default:{na=73;break b}}}while(0);if((na|0)==23){na=0;b[p+400+(aa<<7)+(d[p+16+ma|0]<<1)>>1]=0;ga=ha+3|0;ka=ma+1|0;la=da>>>0>ga>>>0?ga:da}if((ka|0)<64){fa=ka;ha=la}else{break}}b[ea>>1]=(b[ea>>1]|0)+2048;ha=aa+1|0;if((ha|0)<6){$=la;aa=ha}else{break}}aa=c[v>>2]|0;$=c[x>>2]|0;da=(ba(S,aa)|0)+(U<<4)|0;ca=c[m>>2]|0;ha=c[B>>2]|0;fa=U<<3;ga=c[C>>2]|0;ua=c[D>>2]|0;Jkb($+da|0,aa,E);Jkb($+(da|8)|0,aa,F);sa=da+(aa<<3)|0;Jkb($+sa|0,aa,G);Jkb($+(sa+8)|0,aa,H);if((c[(c[j>>2]|0)+88>>2]&8192|0)==0){aa=ga+((ba(ua,T)|0)+fa)|0;ua=ca+((ba(ha,T)|0)+fa)|0;Jkb(ua,c[B>>2]|0,I);Jkb(aa,c[D>>2]|0,J)}aa=c[u>>2]|0;ua=(c[w>>2]|0)-aa|0;c[u>>2]=aa+(ua>>>0>_>>>0?_:ua)}else{if((_|0)==12){if((W-Y|0)<1){xa=0;ya=Y}else{ua=V+2|0;c[u>>2]=ua;xa=a[Y]|0;ya=ua}a[y]=xa;ua=W-ya|0;aa=ua>>>0>1>>>0?1:ua;ua=ya+aa|0;c[u>>2]=ua;if((W-ua|0)<1){za=0;Aa=ua}else{fa=ya+(aa+1)|0;c[u>>2]=fa;za=a[ua]|0;Aa=fa}a[M]=za;fa=W-Aa|0;ua=fa>>>0>1>>>0?1:fa;fa=Aa+ua|0;c[u>>2]=fa;if((W-fa|0)<1){Ba=0;Ca=fa}else{aa=Aa+(ua+1)|0;c[u>>2]=aa;Ba=a[fa]|0;Ca=aa}a[N]=Ba;aa=W-Ca|0;fa=aa>>>0>1>>>0?1:aa;aa=Ca+fa|0;c[u>>2]=aa;if((W-aa|0)<1){Da=0;Ea=aa}else{ua=Ca+(fa+1)|0;c[u>>2]=ua;Da=a[aa]|0;Ea=ua}a[O]=Da;ua=W-Ea|0;aa=ua>>>0>1>>>0?1:ua;ua=Ea+aa|0;c[u>>2]=ua;if((W-ua|0)<1){Fa=0;Ga=ua}else{fa=Ea+(aa+1)|0;c[u>>2]=fa;Fa=a[ua]|0;Ga=fa}a[K]=Fa;fa=W-Ga|0;ua=fa>>>0>1>>>0?1:fa;fa=Ga+ua|0;c[u>>2]=fa;if((W-fa|0)<1){Ha=0;Ia=fa}else{aa=Ga+(ua+1)|0;c[u>>2]=aa;Ha=a[fa]|0;Ia=aa}a[L]=Ha;aa=W-Ia|0;c[u>>2]=Ia+(aa>>>0>1>>>0?1:aa);Ja=xa}else if((_|0)==6){aa=W-Y|0;fa=aa>>>0>6>>>0?6:aa;UGb(y|0,Y|0,fa)|0;c[u>>2]=V+(fa+1);Ja=a[y]|0}else if((_|0)==3){if((W-Y|0)<1){Ka=0;La=Y}else{fa=V+2|0;c[u>>2]=fa;Ka=a[Y]|0;La=fa}TGb(y|0,Ka|0,4)|0;if((W-La|0)<1){Ma=0;Na=La}else{fa=La+1|0;c[u>>2]=fa;Ma=a[La]|0;Na=fa}a[K]=Ma;if((W-Na|0)<1){Oa=0}else{c[u>>2]=Na+1;Oa=a[Na]|0}a[L]=Oa;Ja=Ka}else{X=_;break b}fa=c[v>>2]|0;aa=c[x>>2]|0;ua=(ba(S,fa)|0)+(U<<4)|0;ha=c[m>>2]|0;ca=c[B>>2]|0;ga=U<<3;sa=c[C>>2]|0;$=c[D>>2]|0;da=(ba(c[t>>2]|0,Ja<<24>>24)|0)+2056>>4;if(da>>>0>255>>>0){Pa=-da>>31&255}else{Pa=da&255}TGb(aa+ua|0,Pa|0,8)|0;TGb(aa+(ua+fa)|0,Pa|0,8)|0;da=fa<<1;TGb(aa+(ua+da)|0,Pa|0,8)|0;ra=fa*3|0;TGb(aa+(ua+ra)|0,Pa|0,8)|0;va=fa<<2;TGb(aa+(ua+va)|0,Pa|0,8)|0;ta=fa*5|0;TGb(aa+(ua+ta)|0,Pa|0,8)|0;ia=fa*6|0;TGb(aa+(ua+ia)|0,Pa|0,8)|0;Qa=fa*7|0;TGb(aa+(ua+Qa)|0,Pa|0,8)|0;Ra=ua|8;Sa=(ba(a[M]|0,c[t>>2]|0)|0)+2056>>4;if(Sa>>>0>255>>>0){Ta=-Sa>>31&255}else{Ta=Sa&255}TGb(aa+Ra|0,Ta|0,8)|0;TGb(aa+(Ra+fa)|0,Ta|0,8)|0;TGb(aa+(Ra+da)|0,Ta|0,8)|0;TGb(aa+(Ra+ra)|0,Ta|0,8)|0;TGb(aa+(Ra+va)|0,Ta|0,8)|0;TGb(aa+(Ra+ta)|0,Ta|0,8)|0;TGb(aa+(Ra+ia)|0,Ta|0,8)|0;TGb(aa+(Ra+Qa)|0,Ta|0,8)|0;Ra=ua+(fa<<3)|0;ua=(ba(a[N]|0,c[t>>2]|0)|0)+2056>>4;if(ua>>>0>255>>>0){Ua=-ua>>31&255}else{Ua=ua&255}TGb(aa+Ra|0,Ua|0,8)|0;TGb(aa+(Ra+fa)|0,Ua|0,8)|0;TGb(aa+(Ra+da)|0,Ua|0,8)|0;TGb(aa+(Ra+ra)|0,Ua|0,8)|0;TGb(aa+(Ra+va)|0,Ua|0,8)|0;TGb(aa+(Ra+ta)|0,Ua|0,8)|0;TGb(aa+(Ra+ia)|0,Ua|0,8)|0;TGb(aa+(Ra+Qa)|0,Ua|0,8)|0;ua=Ra+8|0;Ra=(ba(a[O]|0,c[t>>2]|0)|0)+2056>>4;if(Ra>>>0>255>>>0){Va=-Ra>>31&255}else{Va=Ra&255}TGb(aa+ua|0,Va|0,8)|0;TGb(aa+(ua+fa)|0,Va|0,8)|0;TGb(aa+(ua+da)|0,Va|0,8)|0;TGb(aa+(ua+ra)|0,Va|0,8)|0;TGb(aa+(ua+va)|0,Va|0,8)|0;TGb(aa+(ua+ta)|0,Va|0,8)|0;TGb(aa+(ua+ia)|0,Va|0,8)|0;TGb(aa+(ua+Qa)|0,Va|0,8)|0;if((c[(c[j>>2]|0)+88>>2]&8192|0)!=0){break}Qa=(ba($,T)|0)+ga|0;$=(ba(ca,T)|0)+ga|0;ga=c[B>>2]|0;ca=(ba(a[K]|0,c[t>>2]|0)|0)+2056>>4;if(ca>>>0>255>>>0){Wa=-ca>>31&255}else{Wa=ca&255}TGb(ha+$|0,Wa|0,8)|0;TGb(ha+(ga+$)|0,Wa|0,8)|0;TGb(ha+((ga<<1)+$)|0,Wa|0,8)|0;TGb(ha+((ga*3|0)+$)|0,Wa|0,8)|0;TGb(ha+((ga<<2)+$)|0,Wa|0,8)|0;TGb(ha+((ga*5|0)+$)|0,Wa|0,8)|0;TGb(ha+((ga*6|0)+$)|0,Wa|0,8)|0;TGb(ha+((ga*7|0)+$)|0,Wa|0,8)|0;$=c[D>>2]|0;ga=(ba(a[L]|0,c[t>>2]|0)|0)+2056>>4;if(ga>>>0>255>>>0){Xa=-ga>>31&255}else{Xa=ga&255}TGb(sa+Qa|0,Xa|0,8)|0;TGb(sa+($+Qa)|0,Xa|0,8)|0;TGb(sa+(($<<1)+Qa)|0,Xa|0,8)|0;TGb(sa+(($*3|0)+Qa)|0,Xa|0,8)|0;TGb(sa+(($<<2)+Qa)|0,Xa|0,8)|0;TGb(sa+(($*5|0)+Qa)|0,Xa|0,8)|0;TGb(sa+(($*6|0)+Qa)|0,Xa|0,8)|0;TGb(sa+(($*7|0)+Qa)|0,Xa|0,8)|0}}while(0);U=U+1|0;Ya=c[A>>2]|0;}while((U|0)<(Ya+15>>4|0));Za=Ya;_a=c[z>>2]|0}else{Za=Q;_a=R}U=P+1|0;if((U|0)<(_a+15>>4|0)){P=U;Q=Za;R=_a}else{break a}}if((na|0)==73){while(1){na=0;na=73}}yDb(c[j>>2]|0,16,2112192,(r=i,i=i+8|0,c[r>>2]=X,r)|0);i=r;s=-1094995529;i=k;return s|0}}while(0);c[h>>2]=1;s=c[n>>2]|0;i=k;return s|0}function x8(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+104>>2]=1;c[a+108>>2]=15;c[a+140>>2]=11;a=ICb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function y8(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;h=i;i=i+16|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=k+l|0;n=e;o=m;if((l|0)<8){p=-1094995529;i=h;return p|0}q=k;r=k+8|0;s=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)==1413961323;a:do{if(s){if((o-r|0)<12){yDb(b,24,2189400,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;p=-1094995529;i=h;return p|0}q=r;u=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=g+12|0;c[q>>2]=u;v=k+10|0;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;v=g+16|0;c[v>>2]=w;x=g;y=c[x>>2]|0;if((c[y+120>>2]|0)==(u|0)){if((c[y+124>>2]|0)!=(w|0)){z=7}}else{z=7}do{if((z|0)==7){$Db(g+8|0);KCb(c[g+4>>2]|0);w=V$a(c[x>>2]|0,c[q>>2]|0,c[v>>2]|0)|0;if((w|0)<0){p=w}else{break}i=h;return p|0}}while(0);v=k+14|0;q=(d[v]|d[v+1|0]<<8)<<16>>16;v=q&65535;x=k+20|0;if(q<<16>>16==0){A=x;break}q=g+20|0;w=x;x=0;while(1){if((o-w|0)<=2){A=w;break a}c[q+(x<<2)>>2]=(d[w]|0)<<16|(d[w+1|0]|0)<<8|(d[w+2|0]|0)|-16777216;y=w+3|0;u=x+1|0;if((u|0)<(v|0)&(u|0)<256){w=y;x=u}else{A=y;break}}}else{A=r}}while(0);r=_$a(b,n,1)|0;if((r|0)<0){p=r;i=h;return p|0}UGb(c[e+4>>2]|0,g+20|0,1024)|0;b:do{if(s){c[e+84>>2]=1;c[e+88>>2]=1;r=g+8|0;k=c[r>>2]|0;do{if((k|0)==0){x=cEb(ba(c[g+16>>2]|0,c[g+12>>2]|0)|0)|0;c[r>>2]=x;if((x|0)==0){p=-12}else{B=x;break}i=h;return p|0}else{B=k}}while(0);k=c[g>>2]|0;x=B+(ba(c[k+124>>2]|0,c[k+120>>2]|0)|0)|0;k=(a[A]&1)==0?A+2|0:A+5|0;if((o-k|0)<3){yDb(b,24,2112168,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;p=-1094995529;i=h;return p|0}w=(d[k+1|0]|0)<<8|(d[k]|0)<<16|(d[k+2|0]|0);v=k+3|0;c:do{if((w|0)!=0&v>>>0<m>>>0){k=x;q=B;y=B;u=v;C=w;D=0;while(1){E=a[u]|0;F=E&255;G=F&3;do{if((F&128|0)==0){H=(d[u+1|0]|0|F<<3&768)+1|0;I=(F>>>2&7)+3|0;J=G;K=u+2|0}else{if((F&64|0)==0){L=u+1|0;M=(d[L]|0)>>>6;N=L;H=((de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&16383)+1|0;I=(F&63)+4|0;J=M;K=u+3|0;break}if((F&32|0)==0){M=u+1|0;N=((de((d[M]|d[M+1|0]<<8)<<16>>16|0)|0)&65535|F<<12&65536)+1|0;H=N;I=(d[u+3|0]|0|F<<6&768)+5|0;J=G;K=u+4|0;break}if((E&255)>>>0<252>>>0){O=(F<<2&124)+4|0}else{O=G}H=D;I=0;J=O;K=u+1|0}}while(0);if((J|0)>(o-K|0)){break c}if((J|0)>0){G=k-y|0;F=(J|0)>(G|0)?G:J;UGb(y|0,K|0,F)|0;P=C-J|0;Q=K+F|0;R=y+F|0}else{P=C;Q=K;R=y}if((I|0)>0){F=R;if((F-q|0)<(H|0)){break c}G=k-F|0;F=(I|0)>(G|0)?G:I;iEb(R,H,F);S=P-I|0;T=R+F|0}else{S=P;T=R}if((S|0)>0&Q>>>0<m>>>0){y=T;u=Q;C=S;D=H}else{break}}}}while(0);w=g+16|0;if((c[w>>2]|0)>0){v=e;x=e+32|0;D=g+12|0;C=0;do{u=(c[v>>2]|0)+(ba(c[x>>2]|0,C)|0)|0;y=c[D>>2]|0;UGb(u|0,(c[r>>2]|0)+(ba(y,C)|0)|0,y)|0;C=C+1|0;}while((C|0)<(c[w>>2]|0))}U=g+4|0}else{w=g+4|0;if((c[c[w>>2]>>2]|0)==0){yDb(b,24,2053544,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;p=l;i=h;return p|0}c[e+84>>2]=0;c[e+88>>2]=2;d:do{if((o-A|0)>=12){C=A;r=(d[C]|d[C+1|0]<<8)<<16>>16;C=r&65535;D=A+2|0;x=(d[D]|d[D+1|0]<<8)<<16>>16&65535;D=A+4|0;v=(d[D]|d[D+1|0]<<8)<<16>>16;D=v&65535;y=A+6|0;u=(d[y]|d[y+1|0]<<8)<<16>>16;y=u&65535;k=A+12|0;if(!((u&65535)>>>0<26>>>0&u<<16>>16!=0)){yDb(c[g>>2]|0,16,1969768,(t=i,i=i+8|0,c[t>>2]=y,t)|0);i=t;break}u=g+1052|0;do{if((C|0)>(c[u>>2]|0)){if((bEb(g+1044|0,C,8)|0)==0){c[u>>2]=C;break}else{c[u>>2]=0;break d}}}while(0);u=g+1056|0;do{if((D|0)>(c[u>>2]|0)){if((_Db(g+1048|0,D<<4)|0)<0){c[u>>2]=0;break d}else{c[u>>2]=D;break}}}while(0);u=(C*20|0)+31&4194272;q=u>>>3;F=x<<4;if((o-k|0)<((D<<3)+F+q|0)){break}G=(k|0)==0?8:u|8;if(!(r<<16>>16==0)){u=c[g+1044>>2]|0;E=0;N=0;while(1){M=A+((E>>>3)+12)|0;L=E+10|0;V=G>>>0>L>>>0?L:G;c[u+(N<<3)>>2]=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((E&7)>>>0)<<22>>22;M=A+((V>>>3)+12)|0;L=V+10|0;c[u+(N<<3)+4>>2]=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((V&7)>>>0)<<22>>22;V=N+1|0;if((V|0)<(C|0)){E=G>>>0>L>>>0?L:G;N=V}else{break}}}N=q+12|0;G=A+(N+F)|0;E=o-G<<3;u=E>>>0>2147483639>>>0|(G|0)==0;r=u?0:G;G=u?0:E;E=G+8|0;if(v<<16>>16==0){W=0}else{u=g+1048|0;k=j|0;V=j+4|0;L=j+8|0;M=j+12|0;X=0;Y=0;while(1){Z=r+(X>>>3)|0;_=X+8|0;$=E>>>0>_>>>0?_:E;c[k>>2]=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>((X&7)>>>0)&255;Z=r+($>>>3)|0;_=$+8|0;aa=E>>>0>_>>>0?_:E;c[V>>2]=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>(($&7)>>>0)&255;$=r+(aa>>>3)|0;Z=aa+8|0;_=E>>>0>Z>>>0?Z:E;c[L>>2]=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((aa&7)>>>0)&255;aa=r+(_>>>3)|0;$=_+8|0;c[M>>2]=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((_&7)>>>0)&255;_=E>>>0>$>>>0?$:E;$=0;while(1){aa=r+(_>>>3)|0;Z=_+2|0;ca=E>>>0>Z>>>0?Z:E;a[15-$+((c[u>>2]|0)+(Y<<4))|0]=c[j+(((d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((_&7)>>>0)&3)<<2)>>2];aa=$+1|0;if((aa|0)<16){_=ca;$=aa}else{break}}$=Y+1|0;if(($|0)<(D|0)){X=ca;Y=$}else{W=ca;break}}}Y=g;X=c[Y>>2]|0;u=c[X+124>>2]|0;M=ba((u|0)/4|0,y)|0;L=c[X+120>>2]|0;if((G-W|0)<(ba(M,(L|0)/4|0)|0)){break}if((u|0)<=3){U=w;break b}u=32-y|0;M=g+1044|0;V=e+32|0;k=e;v=g+1048|0;F=W;q=0;$=X;X=L;while(1){if((X|0)>3){L=q<<2;_=F;aa=0;Z=$;da=X;while(1){ea=r+(_>>>3)|0;fa=(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)>>>((_&7)>>>0)<<u>>>(u>>>0);ea=_+y|0;ga=E>>>0>ea>>>0?ea:E;e:do{if(fa>>>0<C>>>0){ea=c[M>>2]|0;ha=(c[ea+(fa<<3)>>2]|0)+(aa<<2)|0;ia=(c[ea+(fa<<3)+4>>2]|0)+L|0;do{if((ha|0)>=0){if((ha+4|0)>(da|0)|(ia|0)<0){break}if((ia+4|0)>(c[Z+124>>2]|0)){break}ea=c[w>>2]|0;ja=c[ea+32>>2]|0;ka=ja;la=(c[ea>>2]|0)+((ba(ja,ia)|0)+ha)|0;z=76;break e}}while(0);yDb(Z,16,1941240,(t=i,i=i+16|0,c[t>>2]=ha,c[t+8>>2]=ia,t)|0);i=t}else{ja=fa-C|0;if((ja|0)<(x|0)){ka=4;la=A+((ja<<4)+N)|0;z=76;break}ea=ja-x|0;if((ea|0)>=(D|0)){break}ka=4;la=(c[v>>2]|0)+(ea<<4)|0;z=76}}while(0);if((z|0)==76){z=0;fa=aa<<2;ea=fa|1;ja=fa|2;ma=fa|3;na=0;do{oa=ba(na,ka)|0;pa=na+L|0;qa=(ba(c[V>>2]|0,pa)|0)+fa|0;a[(c[k>>2]|0)+qa|0]=a[la+oa|0]|0;qa=(ba(c[V>>2]|0,pa)|0)+ea|0;a[(c[k>>2]|0)+qa|0]=a[la+(oa+1)|0]|0;qa=(ba(c[V>>2]|0,pa)|0)+ja|0;a[(c[k>>2]|0)+qa|0]=a[la+(oa+2)|0]|0;qa=(ba(c[V>>2]|0,pa)|0)+ma|0;a[(c[k>>2]|0)+qa|0]=a[la+(oa+3)|0]|0;na=na+1|0;}while((na|0)<4)}na=aa+1|0;ma=c[Y>>2]|0;ja=c[ma+120>>2]|0;if((na|0)<((ja|0)/4|0|0)){_=ga;aa=na;Z=ma;da=ja}else{ra=ga;sa=ma;ta=ja;break}}}else{ra=F;sa=$;ta=X}da=q+1|0;if((da|0)<((c[sa+124>>2]|0)/4|0|0)){F=ra;q=da;$=sa;X=ta}else{U=w;break b}}}}while(0);yDb(b,24,2007800,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;p=-1094995529;i=h;return p|0}}while(0);KCb(c[U>>2]|0);t=MCb(c[U>>2]|0,n)|0;if((t|0)<0){p=t;i=h;return p|0}c[f>>2]=1;p=l;i=h;return p|0}function z8(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);$Db(b+8|0);ZDb(c[b+1044>>2]|0);ZDb(c[b+1048>>2]|0);return 0}function A8(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b+4>>2]=a;Z3(b+10056|0,a);d=b+11184|0;y2(d,1);x2(d,b+364|0,1075976);c[b+9960>>2]=1;c[a+104>>2]=1;c[a+108>>2]=15;c[a+140>>2]=0;xMa();return 0}function B8(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;i=c[h+24>>2]|0;j=c[h+28>>2]|0;h=c[a+60>>2]|0;k=h;l=i;m=h+8|0;c[m>>2]=(d[l]|d[l+1|0]<<8)<<16>>16&65535;l=i+2|0;n=h+12|0;c[n>>2]=(d[l]|d[l+1|0]<<8)<<16>>16&65535;l=(215-((d[i+4|0]|0)<<1)|0)*5|0;b[h+12560>>1]=(ba(e[589588]|0,e[600292]|0)|0)>>>11;o=1;do{b[k+12560+(o<<1)>>1]=((ba(ba(l,e[1200584+(o<<1)>>1]|0)|0,e[1179176+(o<<1)>>1]|0)|0)+32|0)>>>14;o=o+1|0;}while((o|0)<64);o=h+4|0;l=V$a(c[o>>2]|0,c[m>>2]|0,c[n>>2]|0)|0;if((l|0)<0){p=l;return p|0}l=_$a(a,f,0)|0;if((l|0)<0){p=l;return p|0}l=h+14672|0;n=l;m=j-8|0;O$a(l,h+14676|0,m);l=c[n>>2]|0;if((l|0)==0){p=-12;return p|0}Xe[c[h+11152>>2]&4095](l,i+8|0,(m|0)/4|0);i=c[n>>2]|0;n=m<<3;m=n>>>0>2147483639>>>0|(i|0)==0;l=m?0:i;i=m?0:n;c[h+14120>>2]=l;c[h+14132>>2]=i;c[h+14136>>2]=i+8;c[h+14124>>2]=l+(i>>3);c[h+14128>>2]=0;c[h+9868>>2]=0;c[h+9864>>2]=0;c[h+9860>>2]=0;i=h+12480|0;c[i>>2]=0;l=a+124|0;a:do{if((c[l>>2]|0)>0){n=h+12476|0;m=a+120|0;q=h+14688|0;r=q;s=h+10096|0;t=q;q=f+32|0;u=f;v=f+4|0;w=f+36|0;x=f+8|0;y=f+40|0;z=h+14816|0;A=h+14944|0;B=h+15072|0;C=h+15200|0;D=h+15328|0;E=0;do{c[n>>2]=0;if((c[m>>2]|0)>0){do{me[c[s>>2]&511](t);F=0;while(1){if((F|0)>=6){break}if((zMa(k,r+(F<<7)|0,F)|0)<0){break a}else{F=F+1|0}}F=c[q>>2]|0;G=c[u>>2]|0;H=c[i>>2]|0;I=ba(F<<4,H)|0;J=c[n>>2]|0;K=(J<<4)+I|0;I=c[v>>2]|0;L=H<<3;H=c[w>>2]|0;M=J<<3;J=c[x>>2]|0;N=c[y>>2]|0;Jkb(G+K|0,F,t);Jkb(G+(K|8)|0,F,z);O=K+(F<<3)|0;Jkb(G+O|0,F,A);Jkb(G+(O+8)|0,F,B);if((c[(c[o>>2]|0)+88>>2]&8192|0)==0){F=J+((ba(N,L)|0)+M)|0;N=I+((ba(H,L)|0)+M)|0;Jkb(N,c[w>>2]|0,C);Jkb(F,c[y>>2]|0,D)}F=(c[n>>2]|0)+1|0;c[n>>2]=F;}while((F|0)<(((c[m>>2]|0)+15|0)/16|0|0));P=c[i>>2]|0}else{P=E}E=P+1|0;c[i>>2]=E;}while((E|0)<(((c[l>>2]|0)+15|0)/16|0|0))}}while(0);c[g>>2]=1;p=j;return p|0}function C8(a){a=a|0;ZDb(c[(c[a+60>>2]|0)+14672>>2]|0);return 0}function D8(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((e*24|0|0)<(c|0)){i=(c|0)/8|0;j=b<<2;k=WDb(ba(j,i)|0)|0;l=k;if((c|0)<=7){m=f<<1;D8(l,b,i,d,e,m,g,h);E8(l,b,i,d,e,m,g,h);ZDb(k);return}n=c;o=(c|0)<0|0?-1:0;p=0;do{q=gHb(p,(p|0)<0|0?-1:0,433494437,0)|0;r=fHb(q,F,n,o)|0;UGb(l+((ba(p,b)|0)<<2)|0,a+((ba(r,b)|0)<<2)|0,j)|0;p=p+1|0;}while((p|0)<(i|0));m=f<<1;D8(l,b,i,d,e,m,g,h);E8(l,b,i,d,e,m,g,h);ZDb(k);return}else{if((e|0)<=0){return}k=c;h=(c|0)<0|0?-1:0;c=b;g=(b|0)<0|0?-1:0;m=b<<2;i=0;do{l=d+((ba(i,b)|0)<<2)|0;f=gHb(i,(i|0)<0|0?-1:0,433494437,0)|0;p=fHb(f,F,k,h)|0;f=gHb(p,F,c,g)|0;UGb(l|0,a+(f<<2)|0,m)|0;i=i+1|0;}while((i|0)<(e|0));return}}function E8(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0;k=i;i=i+56|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+40|0;q=WDb(d<<2)|0;r=q;s=f<<2;t=WDb(s)|0;u=t;v=WDb(d<<3)|0;w=v;x=WDb(s)|0;y=x;z=WDb(s)|0;A=z;B=WDb(s)|0;C=B;D=WDb(b*20|0)|0;E=D;F=(d|0)>0;G=(f|0)>0;H=e;I=b<<2;J=ba(I,f)|0;K=(b|0)>0;L=p|0;M=p+4|0;N=p+8|0;O=o+8|0;P=o|0;Q=l;R=m|0;S=m+4|0;T=o+4|0;U=Q+4|0;V=n|0;W=n+4|0;X=l;Y=C+(f-1<<2)|0;Z=j+256|0;_=b<<1;$=E+(_<<2)|0;aa=b*3|0;ca=E+(aa<<2)|0;da=E+(I<<2)|0;ea=ca;fa=b<<3;ga=(E|0)==(ca|0);ha=(I|0)==(b|0);ia=E+(b<<2)|0;ja=da;ka=(b|0)>1;la=0;ma=0;na=2147483647;while(1){oa=ma+1|0;TGb(z|0,0,s|0)|0;TGb(x|0,0,s|0)|0;if(F){pa=0;qa=0;ra=w;sa=la;while(1){ta=ba(qa,b)|0;ua=ba(sa,b)|0;if(K){va=0;wa=0;while(1){xa=(c[a+(va+ta<<2)>>2]|0)-(c[e+(va+ua<<2)>>2]|0)|0;ya=(ba(xa,xa)|0)+wa|0;xa=va+1|0;if((xa|0)<(b|0)){va=xa;wa=ya}else{za=ya;break}}}else{za=0}if(G){wa=0;va=za;ua=sa;while(1){ya=ba(wa,b)|0;xa=0;Aa=0;while(1){if((Aa|0)>=(b|0)){Ba=xa;break}Ca=(c[a+(Aa+ta<<2)>>2]|0)-(c[e+(Aa+ya<<2)>>2]|0)|0;Da=(ba(Ca,Ca)|0)+xa|0;if((Da|0)>(va|0)){Ba=2147483647;break}else{xa=Da;Aa=Aa+1|0}}Aa=(Ba|0)<(va|0);xa=Aa?Ba:va;ya=Aa?wa:ua;Aa=wa+1|0;if((Aa|0)<(f|0)){wa=Aa;va=xa;ua=ya}else{Ea=xa;Fa=ya;break}}}else{Ea=za;Fa=sa}ua=h+(qa<<2)|0;c[ua>>2]=Fa;c[r+(qa<<2)>>2]=Ea;va=Ea+pa|0;wa=A+(Fa<<2)|0;c[wa>>2]=(c[wa>>2]|0)+Ea;c[ra>>2]=qa;wa=y+(c[ua>>2]<<2)|0;c[ra+4>>2]=c[wa>>2];c[wa>>2]=ra;wa=qa+1|0;if((wa|0)<(d|0)){pa=va;qa=wa;ra=ra+8|0;sa=Fa}else{Ga=va;Ha=Fa;break}}}else{Ga=0;Ha=la}a:do{if(G){sa=0;ra=0;do{qa=c[A+(sa<<2)>>2]|0;pa=(ba(qa,f)|0)>(Ga|0);ra=(pa?qa:0)+ra|0;c[C+(sa<<2)>>2]=ra;sa=sa+1|0;}while((sa|0)<(f|0));c[L>>2]=0;sa=0;ra=Ga;while(1){qa=A+(sa<<2)|0;pa=c[qa>>2]|0;do{if((ba(pa,f)|0)<(ra|0)){va=c[Y>>2]|0;if((va|0)==0){Ia=ra;break a}wa=c[Z>>2]|0;c[j+((wa&63)<<2)>>2]=(c[j+((wa+9&63)<<2)>>2]|0)+(c[j+((wa+40&63)<<2)>>2]|0);wa=c[Z>>2]|0;c[Z>>2]=wa+1;ua=(((c[j+((wa&63)<<2)>>2]|0)>>>0)%(va>>>0)|0)+1|0;va=0;while(1){if((c[C+(va<<2)>>2]|0)<(ua|0)){va=va+1|0}else{break}}c[M>>2]=va;ua=ba(sa,b)|0;wa=0;ta=0;ya=2147483647;while(1){if((ta|0)==(sa|0)){Ja=ya;Ka=wa}else{xa=ba(ta,b)|0;Aa=0;Da=0;while(1){if((Da|0)>=(b|0)){La=Aa;break}Ca=(c[e+(Da+xa<<2)>>2]|0)-(c[e+(Da+ua<<2)>>2]|0)|0;Ma=(ba(Ca,Ca)|0)+Aa|0;if((Ma|0)>(ya|0)){La=2147483647;break}else{Aa=Ma;Da=Da+1|0}}Da=(La|0)<(ya|0);Ja=Da?La:ya;Ka=Da?ta:wa}Da=ta+1|0;if((Da|0)<(f|0)){wa=Ka;ta=Da;ya=Ja}else{break}}c[N>>2]=Ka;if((va|0)==(sa|0)|(va|0)==(Ka|0)){Na=ra;break}ya=A+(va<<2)|0;ta=A+(Ka<<2)|0;wa=(c[ya>>2]|0)+pa+(c[ta>>2]|0)|0;TGb($|0,0,I|0)|0;ua=y+(sa<<2)|0;Da=c[ua>>2]|0;Aa=(Da|0)==0;if(Aa){Oa=0}else{xa=0;Ma=Da;while(1){Ca=xa+1|0;if(K){Pa=Ma|0;Qa=0;do{Ra=c[a+((ba(c[Pa>>2]|0,b)|0)+Qa<<2)>>2]|0;Sa=E+(Qa+_<<2)|0;c[Sa>>2]=(c[Sa>>2]|0)+Ra;Qa=Qa+1|0;}while((Qa|0)<(b|0))}Qa=c[Ma+4>>2]|0;if((Qa|0)==0){Oa=Ca;break}else{xa=Ca;Ma=Qa}}}Ma=y+(Ka<<2)|0;xa=c[Ma>>2]|0;Qa=(xa|0)==0;if(Qa){Ta=Oa}else{Pa=Oa;Ra=xa;while(1){Sa=Pa+1|0;if(K){Ua=Ra|0;Va=0;do{Wa=c[a+((ba(c[Ua>>2]|0,b)|0)+Va<<2)>>2]|0;Xa=E+(Va+_<<2)|0;c[Xa>>2]=(c[Xa>>2]|0)+Wa;Va=Va+1|0;}while((Va|0)<(b|0))}Va=c[Ra+4>>2]|0;if((Va|0)==0){Ta=Sa;break}else{Pa=Sa;Ra=Va}}}do{if((Ta|0)>1){if(!K){break}Ra=Ta>>1;Pa=-Ra|0;Va=0;while(1){Ua=E+(Va+_<<2)|0;Ca=c[Ua>>2]|0;c[Ua>>2]=(((Ca|0)>0?Ra:Pa)+Ca|0)/(Ta|0)|0;Ca=Va+1|0;if((Ca|0)<(b|0)){Va=Ca}else{Ya=36;break}}}else{Ya=36}}while(0);do{if((Ya|0)==36){Ya=0;if(K){Za=0}else{break}do{c[E+(Za<<2)>>2]=2147483647;c[E+(Za+b<<2)>>2]=0;Za=Za+1|0;}while((Za|0)<(b|0))}}while(0);Va=y+(va<<2)|0;Pa=c[Va>>2]|0;Ra=(Pa|0)==0;if(!Ra){Sa=Pa;do{if(K){Ca=Sa|0;Ua=0;do{Wa=E+(Ua<<2)|0;Xa=c[Wa>>2]|0;_a=c[a+((ba(c[Ca>>2]|0,b)|0)+Ua<<2)>>2]|0;c[Wa>>2]=(Xa|0)>(_a|0)?_a:Xa;Xa=E+(Ua+b<<2)|0;_a=c[Xa>>2]|0;Wa=c[a+((ba(c[Ca>>2]|0,b)|0)+Ua<<2)>>2]|0;c[Xa>>2]=(_a|0)>(Wa|0)?_a:Wa;Ua=Ua+1|0;}while((Ua|0)<(b|0))}Sa=c[Sa+4>>2]|0;}while((Sa|0)!=0)}if(K){Sa=0;do{Ua=E+(Sa<<2)|0;Ca=c[Ua>>2]|0;Wa=E+(Sa+b<<2)|0;_a=(c[Wa>>2]|0)-Ca|0;c[Ua>>2]=((_a|0)/3|0)+Ca;c[Wa>>2]=((_a<<1|0)/3|0)+Ca;Sa=Sa+1|0;}while((Sa|0)<(b|0))}b:do{if(Aa){$a=0}else{if(K){ab=Da;bb=0}else{Sa=Da;while(1){Ca=c[Sa+4>>2]|0;if((Ca|0)==0){$a=0;break b}else{Sa=Ca}}}while(1){Sa=ba(c[ab>>2]|0,b)|0;Ca=0;_a=0;do{Wa=(c[E+(Ca+_<<2)>>2]|0)-(c[a+(Ca+Sa<<2)>>2]|0)|0;_a=(ba(Wa,Wa)|0)+_a|0;Ca=Ca+1|0;}while((Ca|0)<(b|0));Ca=_a+bb|0;Sa=c[ab+4>>2]|0;if((Sa|0)==0){$a=Ca;break}else{ab=Sa;bb=Ca}}}}while(0);c[O>>2]=$a;c:do{if(Qa){cb=0}else{if(K){db=xa;eb=0}else{Da=xa;while(1){Aa=c[Da+4>>2]|0;if((Aa|0)==0){cb=0;break c}else{Da=Aa}}}while(1){Da=ba(c[db>>2]|0,b)|0;Aa=0;Ca=0;do{Sa=(c[E+(Aa+_<<2)>>2]|0)-(c[a+(Aa+Da<<2)>>2]|0)|0;Ca=(ba(Sa,Sa)|0)+Ca|0;Aa=Aa+1|0;}while((Aa|0)<(b|0));Aa=Ca+eb|0;Da=c[db+4>>2]|0;if((Da|0)==0){cb=Aa;break}else{db=Da;eb=Aa}}}}while(0);xa=cb+$a|0;c[O>>2]=xa;c[l>>2]=0;c[l+4>>2]=0;c[R>>2]=ca;c[S>>2]=da;TGb(ea|0,0,fa|0)|0;c[T>>2]=0;c[P>>2]=0;do{if(Ra){Ya=69}else{Qa=Pa;do{Aa=Qa|0;Da=ba(c[Aa>>2]|0,b)|0;do{if(K){_a=0;Sa=0;while(1){Wa=(c[E+(_a<<2)>>2]|0)-(c[a+(_a+Da<<2)>>2]|0)|0;fb=(ba(Wa,Wa)|0)+Sa|0;Wa=_a+1|0;if((Wa|0)<(b|0)){_a=Wa;Sa=fb}else{gb=0;hb=0;break}}do{Sa=(c[E+(gb+b<<2)>>2]|0)-(c[a+(gb+Da<<2)>>2]|0)|0;hb=(ba(Sa,Sa)|0)+hb|0;gb=gb+1|0;}while((gb|0)<(b|0));Sa=(fb|0)>=(hb|0)|0;_a=Q+(Sa<<2)|0;c[_a>>2]=(c[_a>>2]|0)+1;_a=c[m+(Sa<<2)>>2]|0;c[_a>>2]=(c[_a>>2]|0)+(c[a+(Da<<2)>>2]|0);if(ka){ib=1}else{break}do{Sa=c[a+((ba(c[Aa>>2]|0,b)|0)+ib<<2)>>2]|0;Wa=_a+(ib<<2)|0;c[Wa>>2]=(c[Wa>>2]|0)+Sa;ib=ib+1|0;}while((ib|0)<(b|0))}else{c[U>>2]=(c[U>>2]|0)+1}}while(0);Qa=c[Qa+4>>2]|0;}while((Qa|0)!=0);Qa=c[X>>2]|0;if((Qa|0)<=1){Ya=69;break}if(!K){break}Aa=Qa>>1;Da=-Aa|0;Ca=0;do{_a=c[E+(Ca+aa<<2)>>2]|0;c[E+(Ca<<2)>>2]=(((_a|0)>0?Aa:Da)+_a|0)/(Qa|0)|0;Ca=Ca+1|0;}while((Ca|0)<(b|0))}}while(0);do{if((Ya|0)==69){Ya=0;if(ga){break}UGb(D|0,ea|0,I)|0}}while(0);Ca=c[U>>2]|0;do{if((Ca|0)>1){if(!K){break}Qa=Ca>>1;Da=-Qa|0;Aa=0;do{_a=c[E+(Aa+I<<2)>>2]|0;c[E+(Aa+b<<2)>>2]=(((_a|0)>0?Qa:Da)+_a|0)/(Ca|0)|0;Aa=Aa+1|0;}while((Aa|0)<(b|0))}else{if(ha){break}UGb(ia|0,ja|0,I)|0}}while(0);do{if(Ra){jb=0;kb=0}else{if(K){lb=Pa}else{Ca=Pa;do{Ca=c[Ca+4>>2]|0;}while((Ca|0)!=0);c[V>>2]=0;c[W>>2]=0;c[P>>2]=0;jb=0;kb=0;break}do{Ca=ba(c[lb>>2]|0,b)|0;Aa=0;Da=0;do{Qa=(c[E+(Aa<<2)>>2]|0)-(c[a+(Aa+Ca<<2)>>2]|0)|0;Da=(ba(Qa,Qa)|0)+Da|0;Aa=Aa+1|0;}while((Aa|0)<(b|0));c[V>>2]=Da;Aa=0;Qa=0;do{_a=(c[E+(Aa+b<<2)>>2]|0)-(c[a+(Aa+Ca<<2)>>2]|0)|0;Qa=(ba(_a,_a)|0)+Qa|0;Aa=Aa+1|0;}while((Aa|0)<(b|0));c[W>>2]=Qa;Aa=(Da|0)>(Qa|0)|0;Ca=o+(Aa<<2)|0;c[Ca>>2]=(c[Ca>>2]|0)+(c[n+(Aa<<2)>>2]|0);lb=c[lb+4>>2]|0;}while((lb|0)!=0);jb=c[P>>2]|0;kb=c[T>>2]|0}}while(0);Pa=kb+xa+jb|0;if((wa|0)>(Pa|0)){mb=Ma}else{Na=ra;break}while(1){Ra=c[mb>>2]|0;if((Ra|0)==0){break}mb=Ra+4|0}c[mb>>2]=c[ua>>2];c[ua>>2]=0;xa=c[Va>>2]|0;c[Va>>2]=0;d:do{if((xa|0)!=0){if(K){nb=xa}else{Ra=xa;Aa=c[ua>>2]|0;while(1){Ca=Ra+4|0;_a=c[Ca>>2]|0;c[Ca>>2]=Aa;c[ua>>2]=Ra;if((_a|0)==0){break d}else{Aa=Ra;Ra=_a}}}while(1){Ra=nb+4|0;Aa=c[Ra>>2]|0;_a=ba(c[nb>>2]|0,b)|0;Ca=0;Sa=0;while(1){Wa=(c[a+(Ca+_a<<2)>>2]|0)-(c[E+(Ca<<2)>>2]|0)|0;ob=(ba(Wa,Wa)|0)+Sa|0;Wa=Ca+1|0;if((Wa|0)<(b|0)){Ca=Wa;Sa=ob}else{pb=0;qb=0;break}}do{Sa=(c[a+(pb+_a<<2)>>2]|0)-(c[E+(pb+b<<2)>>2]|0)|0;qb=(ba(Sa,Sa)|0)+qb|0;pb=pb+1|0;}while((pb|0)<(b|0));_a=y+(c[p+(((ob|0)>(qb|0))<<2)>>2]<<2)|0;c[Ra>>2]=c[_a>>2];c[_a>>2]=nb;if((Aa|0)==0){break}else{nb=Aa}}}}while(0);xa=Pa-wa+ra|0;c[qa>>2]=jb;_a=c[ua>>2]|0;if((_a|0)!=0){Sa=_a;do{c[h+(c[Sa>>2]<<2)>>2]=sa;Sa=c[Sa+4>>2]|0;}while((Sa|0)!=0)}c[ya>>2]=kb;Sa=c[Va>>2]|0;if((Sa|0)!=0){ua=Sa;do{c[h+(c[ua>>2]<<2)>>2]=va;ua=c[ua+4>>2]|0;}while((ua|0)!=0)}c[ta>>2]=c[O>>2];ua=c[Ma>>2]|0;if((ua|0)==0){rb=0;sb=0}else{va=ua;while(1){c[h+(c[va>>2]<<2)>>2]=Ka;ua=c[va+4>>2]|0;if((ua|0)==0){rb=0;sb=0;break}else{va=ua}}}while(1){va=c[A+(rb<<2)>>2]|0;Ma=(ba(va,f)|0)>(xa|0);ta=(Ma?va:0)+sb|0;c[C+(rb<<2)>>2]=ta;va=rb+1|0;if((va|0)<(f|0)){rb=va;sb=ta}else{Na=xa;break}}}else{Na=ra}}while(0);qa=sa+1|0;c[L>>2]=qa;if((qa|0)<(f|0)){sa=qa;ra=Na}else{Ia=Na;break}}}else{c[L>>2]=0;Ia=Ga}}while(0);TGb(t|0,0,s|0)|0;TGb(H|0,0,J|0)|0;if(F){ra=0;do{sa=h+(ra<<2)|0;qa=c[sa>>2]|0;pa=u+(qa<<2)|0;c[pa>>2]=(c[pa>>2]|0)+1;e:do{if(K){pa=ba(ra,b)|0;xa=0;ta=qa;while(1){va=e+((ba(ta,b)|0)+xa<<2)|0;c[va>>2]=(c[va>>2]|0)+(c[a+(xa+pa<<2)>>2]|0);va=xa+1|0;if((va|0)>=(b|0)){break e}xa=va;ta=c[sa>>2]|0}}}while(0);ra=ra+1|0;}while((ra|0)<(d|0))}if(G){ra=0;do{sa=ba(ra,b)|0;qa=c[u+(ra<<2)>>2]|0;if((qa|0)>1&K){ta=qa>>1;xa=-ta|0;pa=0;do{va=e+(pa+sa<<2)|0;Ma=c[va>>2]|0;c[va>>2]=(((Ma|0)>0?ta:xa)+Ma|0)/(qa|0)|0;pa=pa+1|0;}while((pa|0)<(b|0))}ra=ra+1|0;}while((ra|0)<(f|0))}if(+(na-Ia|0)>+(Ia|0)*.1&(oa|0)<(g|0)){la=Ha;ma=oa;na=Ia}else{break}}ZDb(q);ZDb(t);ZDb(z);ZDb(v);ZDb(x);ZDb(B);ZDb(D);i=k;return}function F8(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[a+140>>2]=46;c[b+4>>2]=ba((c[a+124>>2]|0)>>>3,(c[a+120>>2]|0)>>>3)|0;a=ICb()|0;c[b>>2]=a;return((a|0)==0?-12:0)|0}function G8(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;k=i;i=i+128|0;l=k|0;m=c[j+28>>2]|0;n=c[f+60>>2]|0;o=n;p=g;q=(c[f+120>>2]|0)/8|0;r=c[j+24>>2]|0;j=m>>>0>268435455>>>0?-8:m<<3;s=j>>>0>2147483639>>>0|(r|0)==0;t=s?0:r;r=s?0:j;j=r+8|0;if(s){u=s?-1094995529:0;i=k;return u|0}if((r|0)<64){u=-1;i=k;return u|0}s=t;v=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j>>>0>16>>>0?16:j;w=t+(s>>>3)|0;x=s+16|0;s=j>>>0>x>>>0?x:j;x=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24)<<16;w=x|v&65535;y=t+(s>>>3)|0;z=s+16|0;A=j>>>0>z>>>0?z:j;z=t+(A>>>3)|0;B=A+16|0;C=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((A&7)>>>0)<<16|(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((s&7)>>>0)&65535;if((v&276|0)==0|(x&125829120|0)==0){v=n;if((c[c[v>>2]>>2]|0)==0){u=-1094995529;i=k;return u|0}yDb(f,48,2189384,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;c[h>>2]=1;s=MCb(p,c[v>>2]|0)|0;u=(s|0)<0?s:C;i=k;return u|0}s=n+8|0;v=n+4|0;y=j>>>0>B>>>0?B:j;B=0;a:while(1){do{if((1<<B+17&w|0)==0){E=y}else{A=t+(y>>>3)|0;z=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((y&7)>>>0);do{if((B|0)==2){A=z&1048575;F=y+20|0;G=A-1|0;H=G>>>0>65535>>>0;I=H?G>>>16:G;G=H?16:0;if((I&65280|0)==0){J=G;K=I}else{J=G|8;K=I>>>8}L=A;M=J+1+(d[1191992+K|0]|0)|0;N=j>>>0>F>>>0?F:j}else{F=z&15;A=y+4|0;I=j>>>0>A>>>0?A:j;if((B|0)==0){L=1<<F;M=F;N=I;break}else{L=c[v>>2]<<F;M=F;N=I;break}}}while(0);O=s+(B*12|0)+8|0;ZDb(c[O>>2]|0);if(L>>>0>63161282>>>0){P=20;break a}if((r-N|0)>>>0<(L*34|0)>>>0){P=20;break a}z=(L|0)==0;I=WDb(z?1:L<<3)|0;F=I;A=(I|0)==0;if(A|z){c[s+(B*12|0)>>2]=A?0:M;c[s+(B*12|0)+4>>2]=0;c[O>>2]=F;if((I|0)==0){u=-1;P=88;break a}else{E=N;break}}else{Q=0;R=N}do{I=t+(R>>>3)|0;A=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((R&7)>>>0);I=R+4|0;z=j>>>0>I>>>0?I:j;I=t+(z>>>3)|0;G=z+15|0;H=j>>>0>G>>>0?G:j;G=t+(H>>>3)|0;S=H+15|0;R=j>>>0>S>>>0?S:j;S=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((z&7)>>>0)&32767;z=F+(Q<<3)|0;I=z;T=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((H&7)>>>0)&32767;b[z>>1]=(A&1|0)==0?S:T;b[I+2>>1]=(A&2|0)==0?S:T;b[F+(Q<<3)+4>>1]=(A&4|0)==0?S:T;b[I+6>>1]=(A&8|0)==0?S:T;Q=Q+1|0;}while(Q>>>0<L>>>0);c[s+(B*12|0)>>2]=M;c[s+(B*12|0)+4>>2]=L;c[O>>2]=F;E=R}}while(0);T=B+1|0;if(T>>>0<3>>>0){y=E;B=T}else{P=23;break}}if((P|0)==20){c[s+(B*12|0)>>2]=0;c[s+(B*12|0)+4>>2]=0;c[O>>2]=0;u=-1;i=k;return u|0}else if((P|0)==23){O=_$a(f,p,1)|0;if((O|0)<0){u=O;i=k;return u|0}O=(c[g+32>>2]|0)/2|0;B=n;s=c[B>>2]|0;y=(c[s+32>>2]|0)/2|0;if((c[v>>2]|0)==0){U=E}else{R=O<<1;L=O*3|0;M=O<<2;Q=O*5|0;N=O*6|0;K=O*7|0;J=y<<1;w=y*3|0;T=y<<2;S=y*5|0;A=y*6|0;I=y*7|0;z=q<<3;H=8-z+(O<<3)|0;G=(y<<3)-z|0;z=l;V=l+16|0;W=l+32|0;X=l+48|0;Y=l+64|0;Z=l+80|0;_=l+96|0;$=l+112|0;aa=n+20|0;n=(x&65536|0)==0;x=E;E=1;ba=-1;ca=c[s>>2]|0;s=c[g>>2]|0;g=0;da=0;while(1){do{if((ba|0)==-1){if((r-x|0)<1){ea=x;fa=-1;P=33;break}ga=((x|0)<(j|0))+x|0;ha=(d[t+(x>>>3)|0]|0)>>>((x&7)>>>0)&1;if((ha|0)==0){ia=ga;P=36;break}ja=t+(ga>>>3)|0;ka=ga+3|0;la=j>>>0>ka>>>0?ka:j;ka=((d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)>>>((ga&7)>>>0)&7)+ha|0;if((ka|0)!=8){ma=ka;na=la;P=32;break}ka=t+(la>>>3)|0;ha=la+7|0;ga=j>>>0>ha>>>0?ha:j;ha=((d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)>>>((la&7)>>>0)&127)+8|0;if((ha|0)!=135){ea=ga;fa=ha;P=33;break}ha=t+(ga>>>3)|0;la=ga+12|0;ea=j>>>0>la>>>0?la:j;fa=((d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)>>>((ga&7)>>>0)&4095)+135|0;P=33}else{ma=ba;na=x;P=32}}while(0);if((P|0)==32){P=0;if((ma|0)==0){ia=na;P=36}else{ea=na;fa=ma;P=33}}do{if((P|0)==33){P=0;ga=s;if((ca|0)==0){TGb(ga|0,0,16)|0;TGb(s+(O<<1)|0,0,16)|0;TGb(s+(R<<1)|0,0,16)|0;TGb(s+(L<<1)|0,0,16)|0;TGb(s+(M<<1)|0,0,16)|0;TGb(s+(Q<<1)|0,0,16)|0;TGb(s+(N<<1)|0,0,16)|0;TGb(s+(K<<1)|0,0,16)|0;oa=E;pa=ea;qa=fa;break}else{UGb(ga|0,ca|0,16)|0;UGb(s+(O<<1)|0,ca+(y<<1)|0,16)|0;UGb(s+(R<<1)|0,ca+(J<<1)|0,16)|0;UGb(s+(L<<1)|0,ca+(w<<1)|0,16)|0;UGb(s+(M<<1)|0,ca+(T<<1)|0,16)|0;UGb(s+(Q<<1)|0,ca+(S<<1)|0,16)|0;UGb(s+(N<<1)|0,ca+(A<<1)|0,16)|0;UGb(s+(K<<1)|0,ca+(I<<1)|0,16)|0;oa=E;pa=ea;qa=fa;break}}else if((P|0)==36){P=0;if((ca|0)==0){TGb(l|0,0,128)|0}else{UGb(z|0,ca|0,16)|0;UGb(V|0,ca+(y<<1)|0,16)|0;UGb(W|0,ca+(J<<1)|0,16)|0;UGb(X|0,ca+(w<<1)|0,16)|0;UGb(Y|0,ca+(T<<1)|0,16)|0;UGb(Z|0,ca+(S<<1)|0,16)|0;UGb(_|0,ca+(A<<1)|0,16)|0;UGb($|0,ca+(I<<1)|0,16)|0}b:do{if((r-ia|0)>0){ga=ia;ha=E;la=0;while(1){ka=((ga|0)<(j|0))+ga|0;if((d[t+(ga>>>3)|0]&1<<(ga&7)|0)!=0){ra=ka;sa=ha;ta=la;break b}ja=((ka|0)<(j|0))+ka|0;if((d[t+(ka>>>3)|0]&1<<(ka&7)|0)==0){ua=ha;va=ja}else{ua=a[((d[t+(ja>>>3)|0]|0)>>>((ja&7)>>>0)&1)+(1403272+(ha<<1))|0]|0;va=((ja|0)<(j|0))+ja|0}ja=c[o+8+(ua*12|0)>>2]|0;if((ja|0)==0){wa=0;xa=va}else{ka=t+(va>>>3)|0;ya=32-ja|0;za=ja+va|0;wa=(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)>>>((va&7)>>>0)<<ya>>>(ya>>>0);xa=j>>>0>za>>>0?za:j}if((ua|0)==1){Aa=(da<<c[aa>>2])+wa|0}else{Aa=wa}if(Aa>>>0<(c[o+8+(ua*12|0)+4>>2]|0)>>>0){za=(c[o+8+(ua*12|0)+8>>2]|0)+(Aa<<3)|0;Ba=c[za+4>>2]|0;Ca=c[za>>2]|0}else{Ba=0;Ca=0}za=t+(xa>>>3)|0;ya=(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)>>>((xa&7)>>>0);za=xa+16|0;ka=j>>>0>za>>>0?za:j;za=0;do{if((e[684712+(za<<1)>>1]&ya|0)!=0){ja=(za&-4)+za|0;c[l+(ja<<2)>>2]=Ca;c[l+(ja+4<<2)>>2]=Ba}za=za+1|0;}while(za>>>0<16>>>0);za=ya&65535|la;if((r-ka|0)>0){ga=ka;ha=ua;la=za}else{ra=ka;sa=ua;ta=za;break}}}else{ra=ia;sa=E;ta=0}}while(0);F=((ra|0)<(j|0))+ra|0;c:do{if((d[t+(ra>>>3)|0]&1<<(ra&7)|0)==0){la=t+(F>>>3)|0;ha=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((F&7)>>>0);la=F+4|0;ga=j>>>0>la>>>0?la:j;if((ha&1|0)==0){la=t+(ga>>>3)|0;za=ga+4|0;Da=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ga&7)>>>0)&15;Ea=j>>>0>za>>>0?za:j}else{Da=15;Ea=ga}if((ha&2|0)==0){ga=t+(Ea>>>3)|0;za=Ea+4|0;Fa=(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((Ea&7)>>>0)<<4&240;Ga=j>>>0>za>>>0?za:j}else{Fa=240;Ga=Ea}if((ha&4|0)==0){za=t+(Ga>>>3)|0;ga=Ga+4|0;Ha=(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)>>>((Ga&7)>>>0)<<8&3840;Ia=j>>>0>ga>>>0?ga:j}else{Ha=3840;Ia=Ga}if((ha&8|0)==0){ha=t+(Ia>>>3)|0;ga=Ia+4|0;Ja=(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)>>>((Ia&7)>>>0)<<12&61440;Ka=j>>>0>ga>>>0?ga:j}else{Ja=61440;Ka=Ia}ga=Ja^(Ha^(Fa^(Da^ta)));ha=Ka;za=sa;la=0;while(1){if((e[684712+(la<<1)>>1]&ga|0)==0){La=za;Ma=ha}else{ja=((ha|0)<(j|0))+ha|0;if((d[t+(ha>>>3)|0]&1<<(ha&7)|0)==0){Na=za;Oa=ja}else{Na=a[((d[t+(ja>>>3)|0]|0)>>>((ja&7)>>>0)&1)+(1403272+(za<<1))|0]|0;Oa=((ja|0)<(j|0))+ja|0}ja=c[o+8+(Na*12|0)>>2]|0;if((ja|0)==0){Pa=0;Qa=Oa}else{Ra=t+(Oa>>>3)|0;Sa=32-ja|0;Ta=ja+Oa|0;Pa=(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)>>>((Oa&7)>>>0)<<Sa>>>(Sa>>>0);Qa=j>>>0>Ta>>>0?Ta:j}if((Na|0)==1){Ua=(da<<c[aa>>2])+Pa|0}else{Ua=Pa}if(Ua>>>0<(c[o+8+(Na*12|0)+4>>2]|0)>>>0){Ta=(c[o+8+(Na*12|0)+8>>2]|0)+(Ua<<3)|0;Va=c[Ta+4>>2]|0;Wa=c[Ta>>2]|0}else{Va=0;Wa=0}Ta=(la&-4)+la|0;c[l+(Ta<<2)>>2]=Wa;c[l+(Ta+4<<2)>>2]=Va;La=Na;Ma=Qa}Ta=la+1|0;if(Ta>>>0<16>>>0){ha=Ma;za=La;la=Ta}else{Xa=La;Ya=Ma;break}}}else{if(n){Xa=sa;Ya=F;break}if((r-F|0)>0){Za=F;_a=sa}else{Xa=sa;Ya=F;break}while(1){la=((Za|0)<(j|0))+Za|0;if((d[t+(Za>>>3)|0]&1<<(Za&7)|0)!=0){Xa=_a;Ya=la;break c}za=((la|0)<(j|0))+la|0;if((d[t+(la>>>3)|0]&1<<(la&7)|0)==0){$a=_a;ab=za}else{$a=a[((d[t+(za>>>3)|0]|0)>>>((za&7)>>>0)&1)+(1403272+(_a<<1))|0]|0;ab=((za|0)<(j|0))+za|0}za=c[o+8+($a*12|0)>>2]|0;if((za|0)==0){bb=0;cb=ab}else{la=t+(ab>>>3)|0;ha=32-za|0;ga=za+ab|0;bb=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ab&7)>>>0)<<ha>>>(ha>>>0);cb=j>>>0>ga>>>0?ga:j}if(($a|0)==1){db=(da<<c[aa>>2])+bb|0}else{db=bb}if(db>>>0<(c[o+8+($a*12|0)+4>>2]|0)>>>0){ga=(c[o+8+($a*12|0)+8>>2]|0)+(db<<3)|0;eb=c[ga+4>>2]|0;fb=c[ga>>2]|0}else{eb=0;fb=0}ga=t+(cb>>>3)|0;ha=(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((cb&7)>>>0);ga=cb+4|0;la=j>>>0>ga>>>0?ga:j;ga=(ha&12)+(ha&15)|0;c[l+(ga<<2)>>2]=fb;c[l+(ga+4<<2)>>2]=eb;if((r-la|0)>0){Za=la;_a=$a}else{Xa=$a;Ya=la;break}}}}while(0);UGb(s|0,z|0,16)|0;UGb(s+(O<<1)|0,V|0,16)|0;UGb(s+(R<<1)|0,W|0,16)|0;UGb(s+(L<<1)|0,X|0,16)|0;UGb(s+(M<<1)|0,Y|0,16)|0;UGb(s+(Q<<1)|0,Z|0,16)|0;UGb(s+(N<<1)|0,_|0,16)|0;UGb(s+(K<<1)|0,$|0,16)|0;oa=Xa;pa=Ya;qa=0}}while(0);F=g+1|0;la=s+16|0;ga=(ca|0)==0?0:ca+16|0;do{if((F|0)==(q|0)){ha=s+(H<<1)|0;if((ga|0)==0){gb=0;hb=ha;ib=0;break}gb=0;hb=ha;ib=ga+(G<<1)|0}else{gb=F;hb=la;ib=ga}}while(0);ga=da+1|0;if(ga>>>0<(c[v>>2]|0)>>>0){x=pa;E=oa;ba=qa-1|0;ca=ib;s=hb;g=gb;da=ga}else{U=pa;break}}}yDb(f,48,2112136,(D=i,i=i+24|0,c[D>>2]=C,c[D+8>>2]=m,c[D+16>>2]=(U|0)/8|0,D)|0);i=D;KCb(c[B>>2]|0);D=MCb(c[B>>2]|0,p)|0;if((D|0)<0){u=D;i=k;return u|0}c[h>>2]=1;u=C;i=k;return u|0}else if((P|0)==88){i=k;return u|0}return 0}function H8(a){a=a|0;var b=0;b=c[a+60>>2]|0;ZDb(c[b+16>>2]|0);ZDb(c[b+28>>2]|0);ZDb(c[b+40>>2]|0);JCb(b);return 0}function I8(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+60>>2]|0;c[a+140>>2]=0;e=a+120|0;f=c[e>>2]|0;do{if((f&1|0)==0){g=a+124|0;h=c[g>>2]|0;if((h&1|0)!=0){break}j=d;c[j>>2]=WDb((ba(h,f)|0)/4|0)|0;h=d+28|0;k=h;c[k>>2]=WDb((ba((c[e>>2]|0)*3|0,c[g>>2]|0)|0)/2|0)|0;l=WDb((ba((c[e>>2]|0)*3|0,c[g>>2]|0)|0)/2|0)|0;m=d+32|0;c[m>>2]=l;do{if((c[j>>2]|0)!=0){n=c[k>>2]|0;if((n|0)==0|(l|0)==0){break}c[d+36>>2]=c[e>>2];o=(c[e>>2]|0)/2|0;c[d+44>>2]=o;c[d+40>>2]=o;c[d+4>>2]=n;o=ba(c[g>>2]|0,c[e>>2]|0)|0;c[d+12>>2]=n+o;p=(o|0)/4|0;q=p+o|0;c[d+20>>2]=n+q;c[d+8>>2]=l;n=d+16|0;c[n>>2]=l+o;r=d+24|0;c[r>>2]=l+q;TGb(l|0,0,o|0)|0;TGb(c[n>>2]|0,16,p|0)|0;TGb(c[r>>2]|0,16,(ba(c[g>>2]|0,c[e>>2]|0)|0)/4|0|0)|0;s=0;i=b;return s|0}}while(0);$Db(d);$Db(h);$Db(m);yDb(a,16,2007768,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-12;i=b;return s|0}}while(0);yDb(a,16,2053496,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=b;return s|0}function J8(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;h=i;i=i+16|0;j=h|0;k=g+28|0;l=c[k>>2]|0;m=c[b+60>>2]|0;n=b+120|0;o=b+124|0;p=ba(c[o>>2]|0,c[n>>2]|0)|0;q=(p|0)/4|0;TGb(j|0,0,16)|0;r=c[m>>2]|0;if((l|0)<17){yDb(b,16,2189312,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}u=_$a(b,e,0)|0;if((u|0)<0){t=u;i=h;return t|0}u=c[g+24>>2]|0;g=c[k>>2]|0;k=g>>>0>268435455>>>0?-8:g<<3;g=k>>>0>2147483639>>>0|(u|0)==0;v=g?0:u;u=g?0:k;k=u+8|0;if(g){t=g?-1094995529:0;i=h;return t|0}g=m+4|0;w=m+12|0;x=m+20|0;y=c[m+36>>2]|0;z=c[m+40>>2]|0;A=c[m+44>>2]|0;B=m+8|0;C=m+16|0;D=m+24|0;a:do{if((p+3|0)>>>0>6>>>0){m=j|0;E=j+4|0;F=j+8|0;G=y+1|0;H=j+12|0;I=y<<1;J=(k|0)<128?k:128;K=c[x>>2]|0;L=0;M=0;N=16;O=16;P=-1;Q=0;R=r;S=c[w>>2]|0;T=c[g>>2]|0;U=c[D>>2]|0;V=c[C>>2]|0;W=c[B>>2]|0;b:while(1){do{if((P|0)==-1){if((u-J|0)<4){break b}X=((J|0)<(k|0))+J|0;if((d[v+(J>>>3)|0]&1<<(J&7)|0)!=0){Y=X;Z=17;break}_=v+(X>>>3)|0;$=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((X&7)>>>0)&7;_=X+3|0;X=k>>>0>_>>>0?_:k;if(($|0)!=0){aa=$;ca=X;Z=14;break}$=v+(X>>>3)|0;_=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((X&7)>>>0)&255;$=X+8|0;X=k>>>0>$>>>0?$:k;if((_|0)==0){$=v+(X>>>3)|0;da=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((X&7)>>>0)&32767;$=X+15|0;aa=(da|0)==0?-1:da+262|0;ca=k>>>0>$>>>0?$:k;Z=14;break}else{aa=_+7|0;ca=X;Z=14;break}}else{aa=P;ca=J;Z=14}}while(0);do{if((Z|0)==14){Z=0;if((aa|0)==(-1|0)){break b}else if((aa|0)==0){Y=ca;Z=17;break}c[m>>2]=d[W]|0;c[E>>2]=d[W+1|0]|0;c[F>>2]=d[W+y|0]|0;c[H>>2]=d[W+G|0]|0;ea=d[R]|0;fa=d[U]|0;ga=d[V]|0;ha=ca;ia=aa}}while(0);do{if((Z|0)==17){Z=0;X=((Y|0)<(k|0))+Y|0;_=v+(X>>>3)|0;do{if((d[v+(Y>>>3)|0]&1<<(Y&7)|0)==0){$=((X|0)<(k|0))+X|0;if((d[_]&1<<(X&7)|0)==0){ja=Q;ka=$;break}da=(($|0)<(k|0))+$|0;la=v+(da>>>3)|0;ma=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((da&7)>>>0);if((d[v+($>>>3)|0]&1<<($&7)|0)==0){$=da+3|0;na=(d[688344+(ma&7)|0]|0)+Q|0;oa=k>>>0>$>>>0?$:k}else{$=da+6|0;na=ma;oa=k>>>0>$>>>0?$:k}$=na&63;c[m>>2]=$;c[E>>2]=$;c[F>>2]=$;c[H>>2]=$;ja=$;ka=oa}else{$=_;ma=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((X&7)>>>0)&63;$=X+6|0;da=k>>>0>$>>>0?$:k;$=v+(da>>>3)|0;la=da+2|0;pa=k>>>0>la>>>0?la:k;la=v+(pa>>>3)|0;qa=pa+5|0;ra=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((pa&7)>>>0)<<1&62;pa=d[628584+((d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((da&7)>>>0)&3)|0]|0;da=(ba(a[437584+(ma<<2)|0]|0,pa)|0)+ra|0;if((da|0)<0){sa=0}else{sa=(da|0)>63?63:da}c[m>>2]=sa;da=(ba(a[437585+(ma<<2)|0]|0,pa)|0)+ra|0;if((da|0)<0){ta=0}else{ta=(da|0)>63?63:da}c[E>>2]=ta;da=(ba(a[437586+(ma<<2)|0]|0,pa)|0)+ra|0;if((da|0)<0){ua=0}else{ua=(da|0)>63?63:da}c[F>>2]=ua;da=(ba(a[437587+(ma<<2)|0]|0,pa)|0)+ra|0;if((da|0)<0){va=0}else{va=(da|0)>63?63:da}c[H>>2]=va;ja=ra;ka=k>>>0>qa>>>0?qa:k}}while(0);X=((ka|0)<(k|0))+ka|0;if((d[v+(ka>>>3)|0]&1<<(ka&7)|0)==0){ea=ja;fa=O;ga=N;ha=X;ia=0;break}_=((X|0)<(k|0))+X|0;qa=v+(_>>>3)|0;ra=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((_&7)>>>0);if((d[v+(X>>>3)|0]&1<<(X&7)|0)==0){X=ra&7;qa=_+3|0;ea=ja;fa=(d[1487280+X|0]|0)+O&31;ga=(d[1487272+X|0]|0)+N&31;ha=k>>>0>qa>>>0?qa:k;ia=0;break}else{qa=_+5|0;_=k>>>0>qa>>>0?qa:k;qa=v+(_>>>3)|0;X=_+5|0;ea=ja;fa=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((_&7)>>>0)&31;ga=ra&31;ha=k>>>0>X>>>0?X:k;ia=0;break}}}while(0);a[R]=ea;a[T]=c[m>>2];a[T+1|0]=c[E>>2];a[T+y|0]=c[F>>2];a[T+G|0]=c[H>>2];a[S]=ga;a[K]=fa;X=M+1|0;ra=X<<1;if((ra|0)==(c[n>>2]|0)){_=I-ra+2|0;qa=(ra|0)/2|0;ra=z-qa+1|0;da=A-qa+1|0;wa=W+_|0;xa=V+ra|0;ya=U+da|0;za=T+_|0;Aa=S+ra|0;Ba=0;Ca=K+da|0}else{wa=W+2|0;xa=V+1|0;ya=U+1|0;za=T+2|0;Aa=S+1|0;Ba=X;Ca=K+1|0}X=L+1|0;if(X>>>0<q>>>0){J=ha;K=Ca;L=X;M=Ba;N=ga;O=fa;P=ia-1|0;Q=ea;R=R+1|0;S=Aa;T=za;U=ya;V=xa;W=wa}else{break a}}yDb(b,16,2112104,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}}while(0);s=c[w>>2]|0;b=c[x>>2]|0;wa=c[e+4>>2]|0;xa=c[e+8>>2]|0;ya=c[o>>2]|0;do{if((ya|0)>0){za=e+32|0;Aa=c[e>>2]|0;ea=0;ia=c[g>>2]|0;fa=c[n>>2]|0;ga=ya;while(1){if((fa|0)>0){Ba=0;do{a[Aa+Ba|0]=a[ia+Ba|0]<<2;Ba=Ba+1|0;Da=c[n>>2]|0;}while((Ba|0)<(Da|0));Ea=Da;Fa=c[o>>2]|0}else{Ea=fa;Fa=ga}Ba=ea+1|0;if((Ba|0)<(Fa|0)){Aa=Aa+(c[za>>2]|0)|0;ea=Ba;ia=ia+y|0;fa=Ea;ga=Fa}else{break}}if((Fa|0)<=1){break}ga=e+36|0;fa=e+40|0;ia=xa;ea=wa;za=b;Aa=0;Ba=s;Ca=c[n>>2]|0;ha=Fa;while(1){if((Ca|0)>1){q=0;do{a[ea+q|0]=a[1485856+(d[Ba+q|0]|0)|0]|0;a[ia+q|0]=a[1485856+(d[za+q|0]|0)|0]|0;q=q+1|0;Ga=c[n>>2]|0;}while((q|0)<((Ga|0)/2|0|0));Ha=Ga;Ia=c[o>>2]|0}else{Ha=Ca;Ia=ha}q=Aa+1|0;if((q|0)<((Ia|0)/2|0|0)){ia=ia+(c[fa>>2]|0)|0;ea=ea+(c[ga>>2]|0)|0;za=za+A|0;Aa=q;Ba=Ba+z|0;Ca=Ha;ha=Ia}else{break}}}}while(0);Ia=c[g>>2]|0;c[g>>2]=c[B>>2];c[B>>2]=Ia;Ia=c[w>>2]|0;c[w>>2]=c[C>>2];c[C>>2]=Ia;Ia=c[x>>2]|0;c[x>>2]=c[D>>2];c[D>>2]=Ia;c[f>>2]=1;t=l;i=h;return t|0}function K8(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b);$Db(b+28|0);$Db(b+32|0);return 0}function L8(b){b=b|0;var d=0,e=0,f=0,h=0.0,i=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0;d=c[b+60>>2]|0;c[b+416>>2]=1;e=b+448|0;c[e>>2]=4;c[e+4>>2]=0;c[b+420>>2]=3;g[d+116>>2]=.04800000041723251;g[d+156>>2]=0.0;g[d+120>>2]=.09600000083446503;g[d+160>>2]=0.0;g[d+124>>2]=.14399999380111694;g[d+164>>2]=0.0;g[d+128>>2]=.19200000166893005;g[d+168>>2]=0.0;g[d+132>>2]=.23999999463558197;g[d+172>>2]=0.0;g[d+136>>2]=.2879999876022339;g[d+176>>2]=0.0;g[d+140>>2]=.335999995470047;g[d+180>>2]=0.0;g[d+144>>2]=.3840000033378601;g[d+184>>2]=0.0;g[d+148>>2]=.4320000112056732;g[d+188>>2]=0.0;g[d+152>>2]=.47999998927116394;g[d+192>>2]=0.0;b=d+1788|0;e=d+1020|0;f=0;do{g[b+(f<<2)>>2]=0.0;g[e+(f<<2)>>2]=0.0;f=f+1|0;}while((f|0)<128);c[d+24>>2]=1;g[d+1008>>2]=40.0;g[d+2856>>2]=1.0;a[d+2865|0]=0;g[d+1016>>2]=0.0;g[d+1012>>2]=0.0;f=d+2300|0;d=0;e=0;while(1){h=(+(e|0)+-4.0)*.125;b=d;i=-8;while(1){j=h- +(i|0);k=j*2.827433388230814;if(k!=0.0){l=k;m=+U(l)*(+T(j*3.141592653589793*.11764705926179886)*.46+.54)/l*.8999999761581421}else{m=.8999999761581421}g[f+(b<<2)>>2]=m;n=i+1|0;if((n|0)<9){b=b+1|0;i=n}else{break}}i=e+1|0;if((i|0)<8){d=d+17|0;e=i}else{break}}return 0}function M8(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0.0,Z=0.0,$=0.0,aa=0.0,ca=0.0,da=0.0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0.0,na=0.0,oa=0.0,pa=0,qa=0.0,ra=0.0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0.0,ya=0,za=0.0,Aa=0.0,Ba=0.0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0.0,Ua=0.0,Va=0.0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0.0,gb=0,hb=0.0,ib=0,jb=0,kb=0,lb=0,mb=0.0,nb=0.0,ob=0.0,pb=0.0,qb=0.0,rb=0,sb=0.0;l=i;i=i+640|0;m=l|0;n=l+40|0;o=l+80|0;p=l+320|0;q=l+360|0;r=l+400|0;s=c[k+24>>2]|0;t=f+60|0;u=c[t>>2]|0;v=u;w=k+28|0;k=c[w>>2]|0;c[h+76>>2]=160;x=_$a(f,h,0)|0;if((x|0)<0){y=x;i=l;return y|0}x=h;h=c[x>>2]|0;switch(k|0){case 10:{z=3;A=19;break};case 5:{z=2;A=19;break};case 2:{z=1;A=19;break};case 0:{z=0;A=19;break};case 22:{z=4;A=19;break};case 11:{B=3;A=8;break};case 6:{B=2;A=8;break};case 3:{B=1;A=8;break};case 1:{C=0;D=d[s]|0;A=12;break};case 23:{B=4;A=8;break};default:{E=f;A=20}}do{if((A|0)==8){F=a[s]|0;G=F&255;if(!(B>>>0>G>>>0)){C=B;D=G;A=12;break}G=(c[t>>2]|0)+2866|0;if((a[G]|0)==0){yDb(f,24,2007720,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;a[G]=1;I=a[s]|0}else{I=F}J=I&255;A=14}else if((A|0)==19){yDb(f,48,1941168,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=z;L=k;M=s;A=21}}while(0);do{if((A|0)==12){if((C|0)>=(D|0)){J=C;A=14;break}z=f;yDb(z,16,1969720,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;E=z;A=20}}while(0);if((A|0)==14){K=J;L=k-1|0;M=s+1|0;A=21}else if((A|0)==20){s=u+20|0;c[s>>2]=-1;yDb(E,24,2053480,(H=i,i=i+16|0,c[H>>2]=c[f+428>>2],c[H+8>>2]=2189280,H)|0);i=H;N=s;A=110}a:do{if((A|0)==21){s=u+20|0;c[s>>2]=K;if((K|0)<1|(K|0)==2){N=s;A=110;break}E=(K|0)==1;do{if(E){if((c[u+24>>2]|0)!=4){break}if((a[u+2865|0]|0)==0){N=s;A=110;break a}}}while(0);k=L<<3;J=k>>>0>2147483639>>>0|(M|0)==0;C=J?0:M;D=J?0:k;c[u>>2]=C;c[u+12>>2]=D;k=D+8|0;c[u+16>>2]=k;c[u+4>>2]=C+(D>>3);D=u+8|0;c[D>>2]=0;J=u+28|0;TGb(J|0,0,46)|0;if((K|0)==4){z=(d[C]|0)>>>7;I=(k|0)>0|0;c[D>>2]=I;a[J]=z;z=C;t=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<I>>>26;z=I|6;I=k>>>0>z>>>0?z:k;c[D>>2]=I;z=t&65535;b[u+30>>1]=z;t=C+(I>>>3)|0;B=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(I&7)>>>26;t=I+6|0;I=k>>>0>t>>>0?t:k;c[D>>2]=I;t=B&65535;b[u+32>>1]=t;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>23;B=I+9|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;b[u+34>>1]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>25;F=I+7|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;b[u+36>>1]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>25;B=I+7|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;a[u+38|0]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>27;F=I+5|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;a[u+39|0]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>29;B=I+3|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;a[u+40|0]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>24;F=I+8|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;b[u+44>>1]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>24;B=I+8|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;b[u+46>>1]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>24;F=I+8|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;b[u+48>>1]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>21;B=I+11|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;b[u+50>>1]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>27;F=I+5|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;a[u+68|0]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>29;B=I+3|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;a[u+41|0]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>24;F=I+8|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;b[u+52>>1]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>24;B=I+8|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;b[u+54>>1]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>24;F=I+8|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;b[u+56>>1]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>21;B=I+11|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;b[u+58>>1]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>27;F=I+5|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;a[u+69|0]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>29;B=I+3|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;a[u+42|0]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>24;F=I+8|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;b[u+60>>1]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>24;B=I+8|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;b[u+62>>1]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>24;F=I+8|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;b[u+64>>1]=B;B=C+(I>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>21;B=I+11|0;I=k>>>0>B>>>0?B:k;c[D>>2]=I;b[u+66>>1]=F;F=C+(I>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>27;F=I+5|0;I=k>>>0>F>>>0?F:k;c[D>>2]=I;a[u+70|0]=B;B=d[C+(I>>>3)|0]<<(I&7)>>>7;c[D>>2]=((I|0)<(k|0))+I;a[u+72|0]=B&1;O=z;P=t;R=0}else if((K|0)==3){t=C;z=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>1;t=k>>>0>7>>>0?7:k;c[D>>2]=t;B=z&127;b[u+30>>1]=B;z=C+(t>>>3)|0;I=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>25;z=t+7|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;z=I&65535;b[u+32>>1]=z;I=C+(t>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(t&7)>>>24;I=t+8|0;t=k>>>0>I>>>0?I:k;c[D>>2]=t;b[u+34>>1]=F;F=C+(t>>>3)|0;I=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(t&7)>>>25;F=t+7|0;t=k>>>0>F>>>0?F:k;c[D>>2]=t;a[u+38|0]=I;I=C+(t>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(t&7)>>>29;I=t+3|0;t=k>>>0>I>>>0?I:k;c[D>>2]=t;a[u+40|0]=F;F=C+(t>>>3)|0;I=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(t&7)>>>22;F=t+10|0;t=k>>>0>F>>>0?F:k;c[D>>2]=t;b[u+44>>1]=I;I=C+(t>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(t&7)>>>28;I=t+4|0;t=k>>>0>I>>>0?I:k;c[D>>2]=t;a[u+68|0]=F;F=C+(t>>>3)|0;I=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(t&7)>>>29;F=t+3|0;t=k>>>0>F>>>0?F:k;c[D>>2]=t;a[u+41|0]=I;I=C+(t>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(t&7)>>>22;I=t+10|0;t=k>>>0>I>>>0?I:k;c[D>>2]=t;b[u+52>>1]=F;F=C+(t>>>3)|0;I=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(t&7)>>>28;F=t+4|0;t=k>>>0>F>>>0?F:k;c[D>>2]=t;a[u+69|0]=I;I=C+(t>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(t&7)>>>29;I=t+3|0;t=k>>>0>I>>>0?I:k;c[D>>2]=t;a[u+42|0]=F;F=C+(t>>>3)|0;I=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(t&7)>>>22;F=t+10|0;t=k>>>0>F>>>0?F:k;c[D>>2]=t;b[u+60>>1]=I;I=C+(t>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(t&7)>>>28;I=t+4|0;c[D>>2]=k>>>0>I>>>0?I:k;a[u+70|0]=F;O=B;P=z;R=0}else if((K|0)==1){z=C;B=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>4;z=k>>>0>4>>>0?4:k;c[D>>2]=z;F=B&15;b[u+30>>1]=F;B=C+(z>>>3)|0;I=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&4)>>>28;B=z+4|0;z=k>>>0>B>>>0?B:k;c[D>>2]=z;B=I&65535;b[u+32>>1]=B;I=C+(z>>>3)|0;C=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(z&7)>>>24;I=z+8|0;c[D>>2]=k>>>0>I>>>0?I:k;k=C&255;a[u+71|0]=k;O=F;P=B;R=k}else{O=0;P=0;R=0}if(E){if(O<<16>>16==15&P<<16>>16==15&R<<24>>24==-1){N=s;A=110;break}A=36}else{k=0;while(1){if(!(k>>>0<46>>>0)){break}if((a[u+(k+28)|0]|0)==0){k=k+1|0}else{break}}if((k|0)==46){N=s;A=110;break}if((K|0)==2|(K|0)==0){T=K}else{A=36}}if((A|0)==36){E=c[1337656+(K<<2)>>2]|0;B=0;F=0;C=K;while(1){I=a[(c[1337632+(C<<2)>>2]|0)+F|0]|0;D=I&255;z=c[E+(F<<2)>>2]|0;if(I<<24>>24==0){U=B;V=C}else{I=v+30+(F<<1)|0;t=D>>>0>1>>>0;G=0;W=B;while(1){g[v+76+(W<<2)>>2]=+g[z+((ba(e[I>>1]|0,D)|0)+G<<2)>>2];X=G+1|0;if((X|0)<(D|0)){G=X;W=W+1|0}else{break}}U=(t?D:1)+B|0;V=c[s>>2]|0}W=F+1|0;if((W|0)<(d[1321704+V|0]|0)){B=U;F=W;C=V}else{T=V;break}}}C=1;while(1){if((C|0)>=10){break}if(+g[v+76+(C<<2)>>2]>+g[v+76+(C-1<<2)>>2]){C=C+1|0}else{N=s;A=110;break a}}C=(d[1321704+T|0]|0)-1|0;F=1337632+(T<<2)|0;B=0;E=0;while(1){if((B|0)>=(C|0)){break}k=(d[(c[F>>2]|0)+B|0]|0)+E|0;if(+g[v+76+(k<<2)>>2]- +g[v+76+(k-1<<2)>>2]>.007957747154594767){B=B+1|0;E=k}else{N=s;A=110;break a}}if((T-3|0)>>>0<2>>>0){E=a[u+38|0]|0;if((E&255)>>>0>100>>>0){N=s;A=110;break}Y=+((E&255)+20|0);E=u+1004|0;g[E>>2]=Y;B=a[u+39|0]|0;do{if(B<<24>>24==0){Z=0.0;$=0.0;aa=0.0;ca=Y}else{da=+(B&255|0);if((~~(Y-da+16.0)-20|0)>>>0>100>>>0){N=s;A=110;break a}if((T|0)!=4){Z=0.0;$=0.0;aa=0.0;ca=Y;break}if((a[u+2865|0]|0)==0){Z=0.0;$=0.0;aa=0.0;ca=Y;break}F=u+1020|0;UGb(F|0,u+1788|0,512)|0;C=u+1008|0;ea=+g[C>>2];fa=ea-da+16.0;g[C>>2]=fa;k=+Q(+(Y-ea))>15.0;da=k?Y:ea;k=F;W=u+1532|0;G=u+1012|0;I=0;ea=fa;fa=0.0;ga=.3312999904155731;while(1){z=d[429552+I|0]|0;ha=ea;ia=da*fa+ha*(1.0-fa);X=I+1|0;ja=da*ga+ha*(1.0-ga);ka=+g[908272+(I+2<<2)>>2];la=da*ka+ha*(1.0-ka);ha=+g[G>>2];ma=+(z|0);na=1.0/ma;oa=na*(ja-ia);if(ma>0.0){pa=0;qa=0.0;do{ra=ia+oa*qa;sa=W+(pa<<2)|0;ta=Gc(+ra)|0;ua=~~((+(ta|0)-ra+.5)*8.0+.5);va=ua<<16>>16==8;wa=va?0:(ua<<16>>16)*17|0;g[sa>>2]=0.0;ua=pa-8-ta-(va<<31>>31)|0;va=0;ra=0.0;do{ra=ra+ +g[v+2300+(va+wa<<2)>>2]*+g[W+(ua+va<<2)>>2];g[sa>>2]=ra;va=va+1|0;}while((va|0)<17);pa=pa+1|0;qa=+(pa|0);}while(qa<ma)}qa=na*(la-ja);pa=~~ma;oa=+(pa|0);ra=ma+10.0;if(oa<ra){va=pa;xa=oa;while(1){oa=ja+qa*(xa-ma);pa=W+(va<<2)|0;sa=Gc(+oa)|0;ua=~~((+(sa|0)-oa+.5)*8.0+.5);wa=ua<<16>>16==8;ta=wa?0:(ua<<16>>16)*17|0;g[pa>>2]=0.0;ua=va-8-sa-(wa<<31>>31)|0;wa=0;oa=0.0;do{oa=oa+ +g[v+2300+(wa+ta<<2)>>2]*+g[W+(ua+wa<<2)>>2];g[pa>>2]=oa;wa=wa+1|0;}while((wa|0)<17);wa=va+1|0;oa=+(wa|0);if(oa<ra){va=wa;xa=oa}else{ya=0;break}}}else{ya=0}do{va=W+(ya<<2)|0;g[va>>2]=ha*+g[va>>2];ya=ya+1|0;}while((ya|0)<(z|0));VGb(F|0,k+(z<<2)|0,512)|0;if((X|0)>=3){break}I=X;ea=+g[C>>2];fa=ga;ga=ka}Z=ia;$=ja;aa=la;ca=+g[E>>2]}}while(0);B=u+1008|0;if(+Q(+(ca- +g[B>>2]))>15.0){g[B>>2]=ca}C=u+1016|0;g[C>>2]=0.0;I=u+1012|0;g[I>>2]=0.0;za=Z;Aa=$;Ba=aa;Ca=I;Da=C;Ea=u+2844|0;Fa=E;Ga=B}else{B=a[u+71|0]|0;C=u+2844|0;I=B&255;g[C>>2]=+S(+10.0,+(+g[1337680+(I*12|0)>>2]));g[u+2848>>2]=+S(+10.0,+(+g[1337684+(I*12|0)>>2]));g[u+2852>>2]=+S(+10.0,+(+g[1337688+(I*12|0)>>2]));a[u+2864|0]=B;za=20.0;Aa=20.0;Ba=20.0;Ca=u+1012|0;Da=u+1016|0;Ea=C;Fa=u+1004|0;Ga=u+1008|0}C=Ea;B=r;I=p|0;k=u+76|0;F=u+116|0;W=q|0;G=u+1020|0;D=G;t=u+1532|0;va=u+156|0;wa=r|0;pa=G;ua=u+44|0;ta=u+2856|0;sa=u+2865|0;Ha=q+4|0;Ia=q+8|0;Ja=q+12|0;Ka=q+16|0;La=q+20|0;Ma=q+24|0;Na=q+28|0;Oa=q+32|0;Pa=q+36|0;Y=Ba;ga=Aa;fa=za;Qa=0;Ra=h;while(1){TGb(B|0,0,240)|0;Sa=d[429552+Qa|0]|0;ea=+g[908256+(Qa<<2)>>2];Mgb(I,F,k,1.0-ea,ea,10);if((c[s>>2]|0)==1){Ta=fa;Ua=ga;Va=Y}else{ea=+g[Fa>>2];da=+g[908272+(Qa<<2)>>2];ha=+g[Ga>>2];xa=+g[908272+(Qa+1<<2)>>2];ra=+g[908272+(Qa+2<<2)>>2];Ta=ea*da+ha*(1.0-da);Ua=ea*xa+ha*(1.0-xa);Va=ea*ra+ha*(1.0-ra)}Wa=Gc(+((Ua+Ta)*.5))|0;N8(I,W);do{if((a[J]|0)!=0){if((a[sa]|0)==0){break}g[W>>2]=+g[W>>2]*.75;g[Ha>>2]=+g[Ha>>2]*.5625;g[Ia>>2]=+g[Ia>>2]*.421875;g[Ja>>2]=+g[Ja>>2]*.31640625;g[Ka>>2]=+g[Ka>>2]*.2373046875;g[La>>2]=+g[La>>2]*.177978515625;g[Ma>>2]=+g[Ma>>2]*.13348388671875;g[Na>>2]=+g[Na>>2]*.1001129150390625;g[Oa>>2]=+g[Oa>>2]*.07508468627929688;g[Pa>>2]=+g[Pa>>2]*.056313514709472656}}while(0);Xa=c[s>>2]|0;if((Xa|0)==1){Ya=C+(Qa<<2)|0;Za=0;do{g[pa+(Za+128<<2)>>2]=+g[Ya>>2];Za=Za+1|0;}while((Za|0)<(Sa|0))}else{ra=+_(((Xa|0)==3?.5:.25)*+((d[u+(Qa+68)|0]|0)+1|0));Za=a[u+(Qa+40)|0]|0;Ya=Za&255;ha=+g[588656+(Ya<<2)>>2];g[Ca>>2]=ha/3.0+ +g[Ca>>2];g[Da>>2]=ra/3.0+ +g[Da>>2];ea=+(Sa|0);xa=1.0/ea;da=(Ua-Ta)*xa;if(ea>0.0){_a=0;ma=0.0;do{qa=Ta+da*ma;$a=t+(_a<<2)|0;ab=Gc(+qa)|0;bb=~~((+(ab|0)-qa+.5)*8.0+.5);cb=bb<<16>>16==8;db=cb?0:(bb<<16>>16)*17|0;g[$a>>2]=0.0;bb=_a-8-ab-(cb<<31>>31)|0;cb=0;qa=0.0;do{qa=qa+ +g[v+2300+(cb+db<<2)>>2]*+g[t+(bb+cb<<2)>>2];g[$a>>2]=qa;cb=cb+1|0;}while((cb|0)<17);_a=_a+1|0;ma=+(_a|0);}while(ma<ea)}ma=(Va-Ua)*xa;_a=~~ea;da=+(_a|0);qa=ea+10.0;if(da<qa){Xa=_a;ka=da;while(1){da=Ua+ma*(ka-ea);_a=t+(Xa<<2)|0;cb=Gc(+da)|0;$a=~~((+(cb|0)-da+.5)*8.0+.5);bb=$a<<16>>16==8;db=bb?0:($a<<16>>16)*17|0;g[_a>>2]=0.0;$a=Xa-8-cb-(bb<<31>>31)|0;bb=0;da=0.0;do{da=da+ +g[v+2300+(bb+db<<2)>>2]*+g[t+($a+bb<<2)>>2];g[_a>>2]=da;bb=bb+1|0;}while((bb|0)<17);bb=Xa+1|0;da=+(bb|0);if(da<qa){Xa=bb;ka=da}else{eb=0;break}}}else{eb=0}do{Xa=t+(eb<<2)|0;g[Xa>>2]=ha*+g[Xa>>2];eb=eb+1|0;}while((eb|0)<(Sa|0));Xa=ua+(Qa<<3)|0;if((c[s>>2]|0)==4){bb=b[ua+(Qa<<3)+6>>1]|0;_a=bb&65535;$a=_a>>>9&3;db=e[Xa>>1]|0;cb=db&127;X=($a>>>0)%5|0;z=(((cb>>>0)/11|0)*5|0)+X|0;ab=(((cb>>>0)%11|0)*5|0)+X|0;ka=(db&128|0)!=0?-1.0:1.0;g[r+(z<<2)>>2]=ka;if((ab|0)<(z|0)){g[r+(ab<<2)>>2]=-0.0-ka}else{z=r+(ab<<2)|0;g[z>>2]=ka+ +g[z>>2]}z=e[ua+(Qa<<3)+2>>1]|0;ab=z&127;db=(($a+1|0)>>>0)%5|0;X=(((ab>>>0)/11|0)*5|0)+db|0;cb=(((ab>>>0)%11|0)*5|0)+db|0;ka=(z&128|0)!=0?-1.0:1.0;g[r+(X<<2)>>2]=ka;if((cb|0)<(X|0)){g[r+(cb<<2)>>2]=-0.0-ka}else{X=r+(cb<<2)|0;g[X>>2]=ka+ +g[X>>2]}X=e[ua+(Qa<<3)+4>>1]|0;cb=X&127;z=(($a+2|0)>>>0)%5|0;db=(((cb>>>0)/11|0)*5|0)+z|0;ab=(((cb>>>0)%11|0)*5|0)+z|0;ka=(X&128|0)!=0?-1.0:1.0;g[r+(db<<2)>>2]=ka;if((ab|0)<(db|0)){g[r+(ab<<2)>>2]=-0.0-ka}else{db=r+(ab<<2)|0;g[db>>2]=ka+ +g[db>>2]}db=_a&127;g[r+((((db>>>0)/11|0)*5|0)+((($a+3|0)>>>0)%5|0)<<2)>>2]=(_a&256|0)!=0?-1.0:1.0;g[r+((((db>>>0)%11|0)*5|0)+((($a|4)>>>0)%5|0)<<2)>>2]=(bb&128)!=0?-1.0:1.0}else{bb=e[Xa>>1]|0;ka=(bb&512|0)!=0?-1.0:1.0;Xa=r+(((bb&7)*7|0)+4<<2)|0;g[Xa>>2]=+g[Xa>>2]+ka;Xa=r+(((bb>>>3&7)*7|0)+2<<2)|0;g[Xa>>2]=+g[Xa>>2]-ka;Xa=r+(((bb>>>6&7)*7|0)<<2)|0;g[Xa>>2]=+g[Xa>>2]+ka}if(Za<<24>>24==0){fb=.20000000298023224}else{fb=(Ya-6|0)>>>0<2>>>0?.8999999761581421:ha}if((Wa|0)<(Sa|0)){Xa=Wa;while(1){bb=r+(Xa<<2)|0;g[bb>>2]=+g[bb>>2]+fb*+g[r+(Xa-Wa<<2)>>2];bb=Xa+1|0;if((bb|0)<(Sa|0)){Xa=bb}else{gb=0;break}}}else{gb=0}do{Xa=pa+(gb+128<<2)|0;g[Xa>>2]=+g[Xa>>2]+ra*+g[r+(gb<<2)>>2];gb=gb+1|0;}while((gb|0)<(Sa|0));ra=+g[ta>>2]+.2;if(ra>1.0){hb=1.0}else{hb=ra}g[ta>>2]=hb}VGb(G|0,D+(Sa<<2)|0,512)|0;O8(t,W,va,Sa,wa);P8(v,wa,W,Ra,Wa,563504+(c[s>>2]<<4)|0,Sa);Xa=Qa+1|0;if((Xa|0)<3){Y=Va;ga=Ua;fa=Ta;Qa=Xa;Ra=Ra+(Sa<<2)|0}else{break}}ib=0;jb=s;kb=u+24|0}}while(0);if((A|0)==110){yDb(f,24,2112088,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;H=u+20|0;f=0;while(1){Ta=+g[v+116+(f<<2)>>2];if((c[H>>2]|0)==1){g[v+76+(f<<2)>>2]=Ta;lb=f+1|0}else{A=f+1|0;g[v+76+(f<<2)>>2]=+(A|0)*.125*.048+Ta*.875;lb=A}if((lb|0)<10){f=lb}else{break}}if((a[u+2865|0]|0)!=0){lb=u+1012|0;g[lb>>2]=+g[lb>>2]*.75}if((c[H>>2]|0)==4){UGb(u+1788|0,u+1020|0,512)|0}lb=u+24|0;f=(c[lb>>2]|0)==1;c[H>>2]=f?1:4;if(f){f=d[u+2864|0]|0;Ta=+S(+10.0,+((+g[1337680+(f*12|0)>>2]+0.0+ +g[1337684+(f*12|0)>>2]+ +g[1337688+(f*12|0)>>2])/3.0));g[u+2844>>2]=Ta;g[u+2848>>2]=Ta;g[u+2852>>2]=Ta;mb=+g[u+1004>>2];nb=+g[u+1008>>2]}else{Ta=+g[u+1008>>2];g[u+1004>>2]=Ta;mb=Ta;nb=Ta}f=u+1004|0;A=u+1008|0;if(+Q(+(mb-nb))>15.0){g[A>>2]=mb}gb=m|0;m=u+76|0;r=u+116|0;eb=n|0;n=u+1020|0;Da=u+1532|0;Ca=u+156|0;Ga=o|0;o=u+1012|0;Fa=u+1016|0;q=u+2856|0;mb=20.0;nb=20.0;Ta=20.0;p=0;Ea=h;while(1){h=d[429552+p|0]|0;Ua=+g[908256+(p<<2)>>2];Mgb(gb,r,m,1.0-Ua,Ua,10);do{if((c[H>>2]|0)==1){ob=Ta;pb=nb;qb=mb}else{if(+g[o>>2]<.3){ob=+g[1340800+(p<<2)>>2];pb=+g[1340800+(p+1<<2)>>2];qb=+g[1340800+(p+2<<2)>>2];break}else{Ua=+g[f>>2];Va=+g[908272+(p<<2)>>2];hb=+g[A>>2];fb=+g[908272+(p+1<<2)>>2];za=+g[908272+(p+2<<2)>>2];ob=Ua*Va+hb*(1.0-Va);pb=Ua*fb+hb*(1.0-fb);qb=Ua*za+hb*(1.0-za);break}}}while(0);s=Gc(+((pb+ob)*.5))|0;N8(gb,eb);if((c[H>>2]|0)==1){ya=v+2844+(p<<2)|0;T=0;do{g[v+1020+(T+128<<2)>>2]=+g[ya>>2];T=T+1|0;}while((T|0)<(h|0))}else{za=+g[o>>2];hb=+(h|0);Ua=1.0/hb;fb=(pb-ob)*Ua;if(hb>0.0){T=0;Va=0.0;do{Aa=ob+fb*Va;ya=T+128|0;V=v+1020+(ya<<2)|0;U=Gc(+Aa)|0;K=~~((+(U|0)-Aa+.5)*8.0+.5);R=K<<16>>16==8;P=R?0:(K<<16>>16)*17|0;g[V>>2]=0.0;K=-8-U+ya-(R<<31>>31)|0;R=0;Aa=0.0;do{Aa=Aa+ +g[v+2300+(R+P<<2)>>2]*+g[v+1020+(K+R<<2)>>2];g[V>>2]=Aa;R=R+1|0;}while((R|0)<17);T=T+1|0;Va=+(T|0);}while(Va<hb)}Va=(qb-pb)*Ua;T=~~hb;fb=+(T|0);Aa=hb+10.0;if(fb<Aa){R=T;Ba=fb;while(1){fb=pb+Va*(Ba-hb);T=R+128|0;V=v+1020+(T<<2)|0;K=Gc(+fb)|0;P=~~((+(K|0)-fb+.5)*8.0+.5);Sa=P<<16>>16==8;Wa=Sa?0:(P<<16>>16)*17|0;g[V>>2]=0.0;P=-8-K+T-(Sa<<31>>31)|0;Sa=0;fb=0.0;do{fb=fb+ +g[v+2300+(Sa+Wa<<2)>>2]*+g[v+1020+(P+Sa<<2)>>2];g[V>>2]=fb;Sa=Sa+1|0;}while((Sa|0)<17);Sa=R+1|0;fb=+(Sa|0);if(fb<Aa){R=Sa;Ba=fb}else{rb=0;break}}}else{rb=0}do{R=v+1020+(rb+128<<2)|0;g[R>>2]=za*+g[R>>2];rb=rb+1|0;}while((rb|0)<(h|0));R=0;za=+g[q>>2];do{Sa=v+1020+(R+128<<2)|0;g[Sa>>2]=za*+g[Sa>>2];R=R+1|0;za=+g[q>>2]}while((R|0)<(h|0));Ba=za+-.05;if(Ba>0.0){sb=Ba}else{sb=0.0}g[q>>2]=sb}VGb(n|0,v+1020+(h<<2)|0,512)|0;do{if((c[H>>2]|0)==1){R=v+2844+(p<<2)|0;Sa=0;do{g[v+1020+(Sa+128<<2)>>2]=+g[R>>2];Sa=Sa+1|0;}while((Sa|0)<(h|0))}else{if(!(+g[o>>2]<.4)){break}Ba=+g[Fa>>2]*.1;Sa=0;do{R=v+1020+(Sa+128<<2)|0;g[R>>2]=Ba+ +g[R>>2];Sa=Sa+1|0;}while((Sa|0)<(h|0))}}while(0);O8(Da,eb,Ca,h,Ga);P8(v,Ga,eb,Ea,s,563504+(c[H>>2]<<4)|0,h);Sa=p+1|0;if((Sa|0)<3){mb=qb;nb=pb;Ta=ob;p=Sa;Ea=Ea+(h<<2)|0}else{ib=1;jb=N;kb=lb;break}}}UGb(u+116|0,u+76|0,40)|0;a[u+2865|0]=ib;c[kb>>2]=c[jb>>2];if((c[jb>>2]|0)!=1){g[u+1008>>2]=+g[u+1004>>2]}u=c[x>>2]|0;x=0;do{jb=u+(x<<2)|0;g[jb>>2]=+g[jb>>2]*30517578125.0e-15;x=x+1|0;}while((x|0)<160);c[j>>2]=1;y=c[w>>2]|0;i=l;return y|0}function N8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0.0,y=0,z=0.0,A=0,B=0,C=0.0,D=0,E=0.0;c=i;i=i+152|0;d=c|0;e=c+80|0;f=c+104|0;j=c+128|0;k=i;i=i+20|0;i=i+7&-8;l=i;i=i+20|0;i=i+7&-8;m=i;i=i+20|0;i=i+7&-8;TGb(j|0,0,20)|0;TGb(k|0,0,20)|0;TGb(l|0,0,20)|0;TGb(m|0,0,20)|0;MKa(d|0,a,10);a=e|0;n=f|0;o=e+20|0;p=f+20|0;q=0;while(1){r=(q|0)<2;s=r?.25:0.0;g[a>>2]=s;if(r){t=(q|0)<1?.25:-.25}else{t=0.0}g[n>>2]=t;r=0;u=s;s=t;while(1){v=r<<1;w=j+(r<<2)|0;x=+g[w>>2];y=k+(r<<2)|0;z=+g[y>>2]+(u- +h[d+(v<<3)>>3]*2.0*x);A=r+1|0;g[e+(A<<2)>>2]=z;B=l+(r<<2)|0;C=+g[B>>2];D=m+(r<<2)|0;E=+g[D>>2]+(s- +h[d+((v|1)<<3)>>3]*2.0*C);g[f+(A<<2)>>2]=E;g[y>>2]=x;g[w>>2]=u;g[D>>2]=C;g[B>>2]=s;if((A|0)<5){r=A;u=z;s=E}else{break}}if((q|0)==0){q=q+1|0;continue}else{g[b+(q-1<<2)>>2]=(+g[o>>2]+ +g[p>>2])*2.0;r=q+1|0;if((r|0)<11){q=r;continue}else{break}}}i=c;return}function O8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0.0,j=0,k=0,l=0,m=0.0;if((d|0)<=0){return}f=b+36|0;h=0;do{i=+g[a+(h<<2)>>2];j=e+(h<<2)|0;g[j>>2]=i;k=c+36|0;g[j>>2]=i- +g[f>>2]*+g[k>>2];l=c+32|0;i=+g[l>>2];g[k>>2]=i;g[j>>2]=+g[j>>2]- +g[b+32>>2]*i;k=c+28|0;i=+g[k>>2];g[l>>2]=i;g[j>>2]=+g[j>>2]- +g[b+28>>2]*i;l=c+24|0;i=+g[l>>2];g[k>>2]=i;g[j>>2]=+g[j>>2]- +g[b+24>>2]*i;k=c+20|0;i=+g[k>>2];g[l>>2]=i;g[j>>2]=+g[j>>2]- +g[b+20>>2]*i;l=c+16|0;i=+g[l>>2];g[k>>2]=i;g[j>>2]=+g[j>>2]- +g[b+16>>2]*i;k=c+12|0;i=+g[k>>2];g[l>>2]=i;g[j>>2]=+g[j>>2]- +g[b+12>>2]*i;l=c+8|0;i=+g[l>>2];g[k>>2]=i;g[j>>2]=+g[j>>2]- +g[b+8>>2]*i;k=c+4|0;i=+g[k>>2];g[l>>2]=i;g[j>>2]=+g[j>>2]- +g[b+4>>2]*i;i=+g[c>>2];g[k>>2]=i;m=+g[j>>2]- +g[b>>2]*i;g[j>>2]=m;g[c>>2]=m;h=h+1|0;}while((h|0)<(d|0));return}function P8(a,b,d,e,f,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0.0,P=0.0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0.0,da=0.0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0,ja=0,ka=0.0,la=0,ma=0,na=0.0,oa=0,pa=0.0,qa=0.0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0.0,Aa=0.0,Ba=0,Ca=0.0,Da=0;k=i;i=i+472|0;l=k|0;m=k+40|0;n=k+256|0;o=+g[h>>2];p=+g[h+8>>2];q=p;r=+g[d>>2];s=p*r;p=q*q;t=+g[d+4>>2];u=p*t;v=q*p;p=+g[d+8>>2];w=v*p;x=q*v;v=+g[d+12>>2];y=x*v;z=q*x;x=+g[d+16>>2];A=z*x;B=q*z;z=+g[d+20>>2];C=B*z;D=q*B;B=+g[d+24>>2];E=D*B;F=q*D;D=+g[d+28>>2];G=F*D;H=q*F;F=+g[d+32>>2];I=H*F;J=+g[d+36>>2];K=q*H*J;d=l|0;H=+g[h+12>>2];q=H;L=r*H;g[d>>2]=L;H=q*q;r=H*t;g[l+4>>2]=r;t=q*H;H=t*p;g[l+8>>2]=H;p=q*t;t=p*v;g[l+12>>2]=t;v=q*p;p=v*x;g[l+16>>2]=p;x=q*v;v=x*z;g[l+20>>2]=v;z=q*x;x=z*B;g[l+24>>2]=x;B=q*z;z=B*D;g[l+28>>2]=z;D=q*B;B=D*F;g[l+32>>2]=B;F=q*D*J;g[l+36>>2]=F;l=j-1|0;if((l|0)>0){J=0.0;M=0;D=+g[b>>2];while(1){N=M+1|0;q=+g[b+(N<<2)>>2];O=J+D*q;if((N|0)<(l|0)){J=O;M=N;D=q}else{break}}P=O<0.0?0.0:o}else{P=o}M=(j|0)>0;do{if(M){l=a+2860|0;N=0;o=+g[l>>2];while(1){O=+g[b+(N<<2)>>2];g[m+(N<<2)>>2]=O-P*o;g[l>>2]=O;Q=N+1|0;if((Q|0)<(j|0)){N=Q;o=O}else{break}}N=a+276|0;l=a+788|0;Q=a+196|0;if(!M){S=N;T=l;break}U=a+232|0;V=a+228|0;W=a+224|0;X=a+220|0;Y=a+216|0;Z=a+212|0;_=a+208|0;$=a+204|0;aa=a+200|0;ba=0;while(1){o=+g[m+(ba<<2)>>2];O=o+K*+g[U>>2];D=+g[V>>2];g[U>>2]=D;J=+g[W>>2];g[V>>2]=J;q=+g[X>>2];g[W>>2]=q;ca=+g[Y>>2];g[X>>2]=ca;da=+g[Z>>2];g[Y>>2]=da;ea=+g[_>>2];g[Z>>2]=ea;fa=+g[$>>2];g[_>>2]=fa;ga=+g[aa>>2];g[$>>2]=ga;ha=+g[Q>>2];g[aa>>2]=ha;g[Q>>2]=o;g[a+276+(ba+128<<2)>>2]=O+I*D+G*J+E*q+C*ca+A*da+y*ea+w*fa+u*ga+s*ha;ia=ba+1|0;if((ia|0)<(j|0)){ba=ia}else{S=N;T=l;break}}}else{S=a+276|0;T=a+788|0}}while(0);l=f-3|0;N=(l|0)<20?l:20;l=f+3|0;ba=(l|0)<120?120:l;l=j+128|0;a:do{if((N|0)>(ba|0)){ja=f}else{if(M){ka=0.0;la=N;ma=f}else{Q=N;while(1){aa=Q+1|0;if((aa|0)>(ba|0)){ja=f;break a}else{Q=aa}}}while(1){s=0.0;Q=128;do{s=s+ +g[a+276+(Q<<2)>>2]*+g[a+276+(Q-la<<2)>>2];Q=Q+1|0;}while((Q|0)<(l|0));Q=s>ka;aa=Q?la:ma;$=la+1|0;if(($|0)>(ba|0)){ja=aa;break}else{ka=Q?s:ka;la=$;ma=aa}}}}while(0);do{if(M){ka=0.0;ma=128;do{u=+g[a+276+(ma-ja<<2)>>2];ka=ka+u*u;ma=ma+1|0;}while((ma|0)<(l|0));if(M){na=0.0;oa=128}else{pa=0.0;qa=ka;break}while(1){u=na+ +g[a+276+(oa<<2)>>2]*+g[a+276+(oa-ja<<2)>>2];ma=oa+1|0;if((ma|0)<(l|0)){na=u;oa=ma}else{pa=u;qa=ka;break}}}else{pa=0.0;qa=0.0}}while(0);do{if(qa*pa==0.0){ra=24}else{if((c[a+20>>2]|0)==1){ra=24;break}na=pa/qa;if(na<.5){oa=n;l=j<<2;UGb(oa|0,T|0,l)|0;sa=oa;ta=l;break}if(M){ka=(na>1.0?1.0:na)*+g[h+4>>2];l=0;do{oa=l+128|0;g[n+(l<<2)>>2]=+g[a+276+(oa<<2)>>2]+ka*+g[a+276+(oa-ja<<2)>>2];l=l+1|0;}while((l|0)<(j|0))}sa=n;ta=j<<2}}while(0);if((ra|0)==24){ra=n;ja=j<<2;UGb(ra|0,T|0,ja)|0;sa=ra;ta=ja}UGb(m|0,sa|0,ta)|0;if(!M){ua=n|0;va=a+236|0;O8(ua,d,va,j,e);wa=S;xa=a+276+(j<<2)|0;ya=xa;VGb(wa|0,ya|0,512)|0;i=k;return}ta=0;qa=+g[a+236>>2];pa=+g[a+240>>2];ka=+g[a+244>>2];na=+g[a+248>>2];u=+g[a+252>>2];w=+g[a+256>>2];y=+g[a+260>>2];A=+g[a+264>>2];C=+g[a+268>>2];E=+g[a+272>>2];while(1){sa=m+(ta<<2)|0;G=+g[sa>>2]-E*F-C*B-A*z-y*x-w*v-u*p-na*t-ka*H-pa*r-qa*L;g[sa>>2]=G;sa=ta+1|0;if((sa|0)<(j|0)){ta=sa;E=C;C=A;A=y;y=w;w=u;u=na;na=ka;ka=pa;pa=qa;qa=G}else{break}}if(M){za=0.0;Aa=0.0;Ba=0}else{ua=n|0;va=a+236|0;O8(ua,d,va,j,e);wa=S;xa=a+276+(j<<2)|0;ya=xa;VGb(wa|0,ya|0,512)|0;i=k;return}do{qa=+g[b+(Ba<<2)>>2];Aa=Aa+qa*qa;qa=+g[m+(Ba<<2)>>2];za=za+qa*qa;Ba=Ba+1|0;}while((Ba|0)<(j|0));if(za!=0.0){Ca=+R(Aa/za)}else{Ca=1.0}if(M){Da=0}else{ua=n|0;va=a+236|0;O8(ua,d,va,j,e);wa=S;xa=a+276+(j<<2)|0;ya=xa;VGb(wa|0,ya|0,512)|0;i=k;return}do{M=n+(Da<<2)|0;g[M>>2]=Ca*+g[M>>2];Da=Da+1|0;}while((Da|0)<(j|0));ua=n|0;va=a+236|0;O8(ua,d,va,j,e);wa=S;xa=a+276+(j<<2)|0;ya=xa;VGb(wa|0,ya|0,512)|0;i=k;return}function Q8(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;j=i;i=i+40|0;l=j|0;m=j+8|0;n=j+24|0;o=j+32|0;p=o;q=c[h+24>>2]|0;c[l>>2]=q;r=c[h+28>>2]|0;h=q+r|0;s=c[b+60>>2]|0;t=e;c[m>>2]=t;c[m+4>>2]=0;c[m+8>>2]=0;u=s+40|0;v=s+36|0;w=v;x=s+48|0;y=s+44|0;z=s+52|0;A=s+56|0;B=s+16|0;C=B;D=B;B=s+20|0;E=s+24|0;F=s+28|0;G=s+12|0;H=G;I=s+92|0;TGb(G|0,-1|0,20)|0;TGb(v|0,-1|0,24)|0;c[I>>2]=0;v=s+8|0;c[v>>2]=-1;c[s+76>>2]=q;c[s+84>>2]=r;if(r>>>0<10>>>0){yDb(b,16,2189248,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}q=c[l>>2]|0;G=q+4|0;c[l>>2]=G;L=q;M=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;if((M|0)!=20000630){yDb(b,16,2112064,(J=i,i=i+8|0,c[J>>2]=M,J)|0);i=J;K=-1094995529;i=j;return K|0}M=q+5|0;c[l>>2]=M;L=a[G]|0;if(!(L<<24>>24==2)){EDb(b,2053464,(J=i,i=i+8|0,c[J>>2]=L&255,J)|0);i=J;K=-1163346256;i=j;return K|0}L=q+8|0;c[l>>2]=L;if(!((a[M]&2)==0)){EDb(b,2007704,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1163346256;i=j;return K|0}a:do{if(L>>>0<h>>>0){M=s+104|0;q=b;G=s+88|0;N=b+224|0;O=h;P=0;Q=0;R=0;S=L;b:while(1){if((a[S]|0)==0){T=P;U=Q;V=R;W=S;break a}do{if((S8(b,l,h,1969704,1941160,38,n)|0)>-1){X=c[n>>2]|0;if((X|0)==0){K=-1094995529;Y=112;break b}Z=c[l>>2]|0;_=Z+X|0;$=_;if((X|0)>18){X=P;aa=Z;while(1){Z=c[M>>2]|0;do{if((a[Z]|0)==0){ca=aa}else{da=SGb(Z|0)|0;if((RGb(aa,Z,da)|0)!=0){ca=aa;break}ea=aa+da|0;if((a[ea]|0)==46){fa=aa+(da+1)|0}else{fa=ea}yDb(q,32,1896280,(J=i,i=i+16|0,c[J>>2]=Z,c[J+8>>2]=fa,J)|0);i=J;ca=fa}}while(0);do{if((QGb(ca,2353504)|0)==0){ga=0}else{if((QGb(ca,2333432)|0)==0){ga=0;break}if((QGb(ca,2308848)|0)==0){ga=0;break}if((QGb(ca,2290264)|0)==0){ga=1;break}if((QGb(ca,2274416)|0)==0){ga=1;break}if((QGb(ca,2258624)|0)==0){ga=1;break}if((QGb(ca,2244272)|0)==0){ga=2;break}if((QGb(ca,2231784)|0)==0){ga=2;break}if((QGb(ca,2219568)|0)==0){ga=2;break}if((QGb(ca,2210264)|0)==0){ga=3;break}yDb(q,24,2201472,(J=i,i=i+8|0,c[J>>2]=c[l>>2],J)|0);i=J;ga=-1}}while(0);Z=c[l>>2]|0;while(1){ha=Z+1|0;c[l>>2]=ha;if((a[Z]|0)!=0&ha>>>0<_>>>0){Z=ha}else{break}}if(($-ha|0)<4){Y=34;break b}c[l>>2]=Z+5;ea=ha;da=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0;if(da>>>0>2>>>0){Y=36;break b}ea=Z+13|0;c[l>>2]=ea;ia=Z+9|0;ja=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;c[l>>2]=Z+17;ia=ea;ka=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;if(!((ja|0)==1&(ka|0)==1)){Y=38;break b}if((ga|0)>-1){ia=c[H>>2]|0;if(!((ia|0)==-1|(ia|0)==(da|0))){Y=41;break b}c[H>>2]=da;c[C+(ga<<2)>>2]=X}ia=c[G>>2]|0;ea=(c[I>>2]|0)+1|0;c[I>>2]=ea;la=YDb(ia,ea,12)|0;ea=la;c[G>>2]=ea;if((la|0)==0){K=-12;Y=112;break b}la=(c[I>>2]|0)-1|0;c[ea+(la*12|0)+8>>2]=da;c[ea+(la*12|0)>>2]=1;c[ea+(la*12|0)+4>>2]=1;la=(1<<da)+X|0;da=c[l>>2]|0;if(($-da|0)>18){X=la;aa=da}else{ma=la;break}}}else{ma=P}na=c[D>>2]|0;oa=c[B>>2]|0;aa=(na|0)>(oa|0)?oa:na;X=c[E>>2]|0;if((((aa|0)>(X|0)?X:aa)|0)<0){Y=46;break b}c[l>>2]=_;pa=R;qa=Q;ra=ma;sa=_}else{if((S8(b,l,h,2133160,2126768,31,n)|0)>-1){aa=c[n>>2]|0;if((aa|0)==0){K=-1094995529;Y=112;break b}X=c[l>>2]|0;$=X;la=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;c[u>>2]=la;$=X+4|0;da=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;c[x>>2]=da;$=X+8|0;ea=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;c[w>>2]=ea;$=X+12|0;ia=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;c[y>>2]=ia;c[z>>2]=ea+1-la;c[A>>2]=ia+1-da;da=X+aa|0;c[l>>2]=da;pa=R;qa=Q;ra=P;sa=da;break}if((S8(b,l,h,2120928,2126768,34,n)|0)>-1){da=c[n>>2]|0;if((da|0)==0){K=-1094995529;Y=112;break b}aa=c[l>>2]|0;X=aa+8|0;ia=(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24)+1|0;X=aa+12|0;la=(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24)+1|0;X=aa+da|0;c[l>>2]=X;pa=ia;qa=la;ra=P;sa=X;break}if((S8(b,l,h,2114920,2114920,25,n)|0)>-1){X=c[n>>2]|0;if((X|0)==0){K=-1094995529;Y=112;break b}yDb(q,48,2100664,(J=i,i=i+8|0,c[J>>2]=d[c[l>>2]|0]|0,J)|0);i=J;la=c[l>>2]|0;if((d[la]|0)>>>0>2>>>0){Y=63;break b}ia=la+X|0;c[l>>2]=ia;pa=R;qa=Q;ra=P;sa=ia;break}if((S8(b,l,h,2088744,2083968,31,n)|0)>-1){ia=c[n>>2]|0;if((ia|0)==0){K=-1094995529;Y=112;break b}X=c[l>>2]|0;lFb(p,(c[k>>2]=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24,+g[k>>2]),255);X=c[o+4>>2]|0;c[N>>2]=c[o>>2];c[N+4>>2]=X;X=(c[l>>2]|0)+ia|0;c[l>>2]=X;pa=R;qa=Q;ra=P;sa=X;break}if((S8(b,l,h,2078464,2078464,29,n)|0)>-1){X=c[n>>2]|0;if((X|0)==0){K=-1094995529;Y=112;break b}if((c[v>>2]|0)==-1){ia=c[l>>2]|0;c[v>>2]=d[ia]|0;ta=ia}else{yDb(q,24,2073560,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;ta=c[l>>2]|0}ia=ta+X|0;c[l>>2]=ia;pa=R;qa=Q;ra=P;sa=ia;break}ia=c[l>>2]|0;if((O-ia|0)<10){Y=75;break b}else{ua=ia}while(1){ia=ua+1|0;c[l>>2]=ia;if(!(ia>>>0<h>>>0)){va=ia;break}if((a[ia]|0)==0){va=ia;break}else{ua=ia}}while(1){_=va+1|0;c[l>>2]=_;if(!(_>>>0<h>>>0)){break}if((a[_]|0)==0){break}else{va=_}}_=va+2|0;c[l>>2]=_;if((O-_|0)<=4){pa=R;qa=Q;ra=P;sa=_;break}ia=va+6|0;c[l>>2]=ia;X=_;_=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;X=_>>>0<(O-ia|0)>>>0?_:0;c[n>>2]=X;if((X|0)==0){Y=79;break b}_=va+(X+6)|0;c[l>>2]=_;pa=R;qa=Q;ra=P;sa=_}}while(0);if(sa>>>0<h>>>0){P=ra;Q=qa;R=pa;S=sa}else{T=ra;U=qa;V=pa;W=sa;break a}}if((Y|0)==34){yDb(q,16,2193144,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==36){yDb(q,16,2176688,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==38){EDb(q,2165976,(J=i,i=i+16|0,c[J>>2]=ja,c[J+8>>2]=ka,J)|0);i=J;K=-1163346256;i=j;return K|0}else if((Y|0)==41){yDb(q,16,2159312,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==46){if((na|0)<0){yDb(q,16,2152312,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;wa=c[B>>2]|0}else{wa=oa}if((wa|0)<0){yDb(q,16,2145464,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J}if((c[E>>2]|0)>=0){K=-1094995529;i=j;return K|0}yDb(q,16,2139480,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==63){yDb(q,16,2093872,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==75){yDb(q,16,2193144,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==79){yDb(q,16,2193144,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==112){i=j;return K|0}}else{T=0;U=0;V=0;W=L}}while(0);if((c[v>>2]|0)==-1){yDb(b,16,2069032,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}if(!(W>>>0<h>>>0)){yDb(b,16,2064432,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}c[l>>2]=W+1;W=c[H>>2]|0;if((W|0)==2|(W|0)==1){H=b+140|0;c[H>>2]=(c[F>>2]>>31&-250)+292;F=c[v>>2]|0;switch(F|0){case 0:case 1:case 2:{c[s+72>>2]=1;break};case 5:case 3:{c[s+72>>2]=16;break};case 4:{c[s+72>>2]=32;break};default:{EDb(b,2045e3,(J=i,i=i+8|0,c[J>>2]=F,J)|0);i=J;K=-1163346256;i=j;return K|0}}F=c[u>>2]|0;u=c[w>>2]|0;do{if(!(F>>>0>u>>>0)){w=c[y>>2]|0;if((c[x>>2]|0)>>>0>w>>>0){break}if(!((c[z>>2]|0)==(1-F+u|0)&u>>>0<V>>>0&w>>>0<U>>>0)){break}w=V$a(b,V,U)|0;if((w|0)<0){K=w;i=j;return K|0}w=bFb(c[H>>2]|0)|0;c[s+32>>2]=w;L=ba(d[w+4|0]|0,c[b+120>>2]<<1)|0;w=s+64|0;c[w>>2]=ba(c[z>>2]|0,T)|0;c[w+4>>2]=0;w=c[s+72>>2]|0;Y=(((c[A>>2]|0)-1+w|0)>>>0)/(w>>>0)|0;do{if((c[v>>2]|0)!=0){w=s+100|0;E=c[w>>2]|0;wa=c[b+808>>2]|0;oa=wa*24|0;do{if(wa>>>0>65535>>>0){if(((oa>>>0)/(wa>>>0)|0|0)==24){break}else{K=-22}i=j;return K|0}}while(0);wa=s+96|0;B=jEb(c[wa>>2]|0,w,oa)|0;na=B;if((B|0)==0){K=-12;i=j;return K|0}else{c[wa>>2]=na;TGb(na+(E*24|0)|0,0,(c[w>>2]|0)-E|0)|0;break}}}while(0);q=W0a(b,m,0)|0;if((q|0)<0){K=q;i=j;return K|0}q=c[l>>2]|0;if((h-q|0)<(Y<<3|0)){K=-1094995529;i=j;return K|0}c[s+80>>2]=q;q=c[e>>2]|0;if((c[x>>2]|0)==0){xa=q}else{na=e+32|0;wa=0;B=q;while(1){TGb(B|0,0,L|0)|0;q=B+(c[na>>2]|0)|0;ka=wa+1|0;if(ka>>>0<(c[x>>2]|0)>>>0){wa=ka;B=q}else{xa=q;break}}}c[s+4>>2]=t;Pe[c[b+828>>2]&255](b,14,c[s+96>>2]|0,0,Y)|0;B=(c[y>>2]|0)+1|0;wa=b+124|0;if((B|0)<(c[wa>>2]|0)){na=e+32|0;q=xa;ka=B;while(1){TGb(q|0,0,L|0)|0;B=ka+1|0;if((B|0)<(c[wa>>2]|0)){q=q+(c[na>>2]|0)|0;ka=B}else{break}}}c[e+88>>2]=1;c[f>>2]=1;K=r;i=j;return K|0}}while(0);yDb(b,16,2039984,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((W|0)==0){DDb(b,2060504,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1163346256;i=j;return K|0}else{yDb(b,16,2055800,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}return 0}function R8(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;a=b+100|0;d=b+96|0;if(!((c[a>>2]|0)>>>0>23>>>0)){$Db(d);c[a>>2]=0;e=b+88|0;$Db(e);return 0}f=d;g=0;do{h=c[f>>2]|0;$Db(h+(g*24|0)|0);$Db(h+(g*24|0)+8|0);$Db(h+(g*24|0)+16|0);$Db(h+(g*24|0)+20|0);g=g+1|0;}while(g>>>0<(((c[a>>2]|0)>>>0)/24|0)>>>0);$Db(d);c[a>>2]=0;e=b+88|0;$Db(e);return 0}function S8(a,b,e,f,g,h,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=c[b>>2]|0;m=e;if((m-l|0)>>>0<h>>>0){n=-1;i=k;return n|0}if((QGb(l,f)|0)!=0){n=-1;i=k;return n|0}h=SGb(f|0)|0;e=h+1|0;o=l+e|0;c[b>>2]=o;if((QGb(o,g)|0)!=0){c[b>>2]=l+(e+~(SGb(f|0)|0));yDb(a,24,2025168,(p=i,i=i+8|0,c[p>>2]=f,p)|0);i=p;n=-1;i=k;return n|0}f=h+2+(SGb(g|0)|0)|0;g=l+(f+4)|0;c[b>>2]=g;b=l+f|0;f=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=f>>>0<(m-g|0)>>>0?f:0;c[j>>2]=b;if((b|0)!=0){n=1;i=k;return n|0}yDb(a,16,2193144,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=1;i=k;return n|0}function T8(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0;g=i;i=i+488|0;k=g|0;l=g+8|0;m=g+480|0;n=c[f+60>>2]|0;o=c[n+4>>2]|0;p=c[n+96>>2]|0;q=p+(j*24|0)|0;r=n+52|0;s=c[r>>2]|0;t=n+32|0;u=d[(c[t>>2]|0)+4|0]|0;v=ba((c[f+120>>2]|0)+2147483647-(c[n+36>>2]|0)<<1,u)|0;f=n+40|0;w=ba(c[f>>2]<<1,u)|0;u=c[n+84>>2]|0;y=(c[n+80>>2]|0)+(h<<3)|0;h=y|0;z=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=y+4|0;y=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=u-8|0;A=(h|0)<0|0?-1:0;if(y>>>0>A>>>0|y>>>0==A>>>0&z>>>0>h>>>0){B=-1094995529;i=g;return B|0}h=c[n+76>>2]|0;A=z;C=A+8|0;D=h+C|0;E=h+A|0;G=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;if(G>>>0<(c[n+48>>2]|0)>>>0){B=-1094995529;i=g;return B|0}E=n+44|0;H=c[E>>2]|0;if(G>>>0>H>>>0){B=-1094995529;i=g;return B|0}I=h+(A+4)|0;J=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;if((J|0)<1|(J|0)>(u|0)){B=-1094995529;i=g;return B|0}I=n+72|0;K=c[I>>2]|0;L=H-G+1|0;H=K>>>0>L>>>0?L:K;K=n+60|0;c[K>>2]=H;L=n+64|0;M=gHb(H,(H|0)<0|0?-1:0,c[L>>2]|0,c[L+4>>2]|0)|0;H=F;N=n+8|0;O=J;P=(J|0)<0|0?-1:0;do{if((c[N>>2]|0)==0){if(!((O|0)==(M|0)&(P|0)==(H|0))){B=-1094995529;i=g;return B|0}Q=ZGb(u,(u|0)<0|0?-1:0,M,H)|0;R=F;if(y>>>0>R>>>0|y>>>0==R>>>0&z>>>0>Q>>>0){B=-1094995529}else{break}i=g;return B|0}else{if(P>>>0>H>>>0|P>>>0==H>>>0&O>>>0>M>>>0){B=-1094995529;i=g;return B|0}Q=u-J|0;R=(Q|0)<0|0?-1:0;if(y>>>0>R>>>0|y>>>0==R>>>0&z>>>0>Q>>>0){B=-1094995529}else{break}i=g;return B|0}}while(0);z=(J|0)<0|0?-1:0;if(z>>>0<H>>>0|z>>>0==H>>>0&J>>>0<M>>>0){H=q|0;z=M;O$a(q,p+(j*24|0)+4|0,z);q=p+(j*24|0)+8|0;O$a(q,p+(j*24|0)+12|0,z);if((c[H>>2]|0)==0){B=-12;i=g;return B|0}M=c[q>>2]|0;if((M|0)==0){B=-12;i=g;return B|0}a:do{switch(c[N>>2]|0){case 2:case 3:{c[m>>2]=z;if(!((Zb(M|0,m|0,D|0,J|0)|0)==0&(c[m>>2]|0)==(z|0))){break a}y=c[q>>2]|0;u=y+z|0;if((z|0)>1){O=y+1|0;P=a[y]|0;do{P=(a[O]|0)+P&255^-128;a[O]=P;O=O+1|0;}while(O>>>0<u>>>0);S=c[q>>2]|0}else{S=y}u=c[H>>2]|0;O=u+z|0;if((z|0)<=0){break a}P=S+((z+1|0)/2|0)|0;Q=u;u=S;while(1){R=Q+1|0;a[Q]=a[u]|0;if(!(R>>>0<O>>>0)){break a}T=Q+2|0;a[R]=a[P]|0;if(T>>>0<O>>>0){P=P+1|0;Q=T;u=u+1|0}else{break}}break};case 5:{c[k>>2]=z;u=(Zb(M|0,k|0,D|0,J|0)|0)==0;if(!(u&(c[k>>2]|0)==(z|0))){break a}u=c[K>>2]|0;if((u|0)<=0){break a}Q=n+92|0;P=n+88|0;O=c[H>>2]|0;y=0;T=M;R=c[Q>>2]|0;U=u;while(1){if((R|0)>0){u=O;V=0;W=T;while(1){X=c[(c[P>>2]|0)+(V*12|0)+8>>2]|0;do{if((X|0)==2){Y=c[r>>2]|0;Z=Y<<1;_=W+(Z+Y)|0;if((Y|0)==0){$=_;aa=u;break}ca=u;da=0;ea=W+Z|0;Z=W+Y|0;Y=W;fa=0;while(1){ga=(d[Z]<<16|d[Y]<<24|d[ea]<<8)+fa|0;ha=ca;x=ga;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;ha=ca+4|0;ia=da+1|0;if(ia>>>0<(c[r>>2]|0)>>>0){ca=ha;da=ia;ea=ea+1|0;Z=Z+1|0;Y=Y+1|0;fa=ga}else{$=_;aa=ha;break}}}else if((X|0)==1){_=c[r>>2]|0;fa=W+(_<<1)|0;if((_|0)==0){$=fa;aa=u;break}Y=u;Z=0;ea=W+_|0;_=W;da=0;while(1){ca=(d[_]<<8|d[ea])+da|0;ha=Y;x=ca&65535;a[ha]=x;x=x>>8;a[ha+1|0]=x;ha=Y+2|0;ga=Z+1|0;if(ga>>>0<(c[r>>2]|0)>>>0){Y=ha;Z=ga;ea=ea+1|0;_=_+1|0;da=ca}else{$=fa;aa=ha;break}}}else{$=W;aa=u}}while(0);X=V+1|0;ja=c[Q>>2]|0;if((X|0)<(ja|0)){u=aa;V=X;W=$}else{break}}ka=aa;la=$;ma=ja;na=c[K>>2]|0}else{ka=O;la=T;ma=R;na=U}W=y+1|0;if((W|0)<(na|0)){O=ka;y=W;T=la;R=ma;U=na}else{break}}break};case 1:{U=M+z|0;if((J|0)>0){R=M;T=D;y=J;O=z;while(1){Q=T+1|0;P=a[T]|0;W=P<<24>>24;do{if(P<<24>>24<0){V=W+O|0;if((V|0)<0){break a}u=-W|0;X=y-1+W|0;if((X|0)<0){break a}if(P<<24>>24==0){oa=V;pa=X;qa=Q;ra=R;break}else{sa=R;ta=Q;ua=u}while(1){fa=ua-1|0;a[sa]=a[ta]|0;if((fa|0)==0){break}else{sa=sa+1|0;ta=ta+1|0;ua=fa}}oa=V;pa=X;qa=T+(1-W)|0;ra=R+u|0}else{fa=W+1|0;da=O-fa|0;if((da|0)<0){break a}_=y-2|0;if((_|0)<0){break a}if((fa|0)==0){va=R}else{ea=R;Z=fa;while(1){Y=Z-1|0;a[ea]=a[Q]|0;if((Y|0)==0){break}else{ea=ea+1|0;Z=Y}}va=R+fa|0}oa=da;pa=_;qa=T+2|0;ra=va}}while(0);if((pa|0)>0){R=ra;T=qa;y=pa;O=oa}else{wa=ra;break}}}else{wa=M}if((U|0)!=(wa|0)){break a}O=c[q>>2]|0;y=O+z|0;if((z|0)>1){T=O+1|0;R=a[O]|0;do{R=(a[T]|0)+R&255^-128;a[T]=R;T=T+1|0;}while(T>>>0<y>>>0);xa=c[q>>2]|0}else{xa=O}y=c[H>>2]|0;T=y+z|0;if((z|0)<=0){break a}R=xa+((z+1|0)/2|0)|0;U=y;y=xa;while(1){Q=U+1|0;a[U]=a[y]|0;if(!(Q>>>0<T>>>0)){break a}W=U+2|0;a[Q]=a[R]|0;if(W>>>0<T>>>0){R=R+1|0;U=W;y=y+1|0}else{break}}break};case 4:{y=M;U=p+(j*24|0)+16|0;R=c[U>>2]|0;if((R|0)==0){T=WDb(8192)|0;c[U>>2]=T;ya=T}else{ya=R}R=p+(j*24|0)+20|0;T=c[R>>2]|0;if((T|0)==0){O=WDb(131072)|0;c[R>>2]=O;za=c[U>>2]|0;Aa=O}else{za=ya;Aa=T}if((za|0)==0|(Aa|0)==0){break a}if(!((J|0)>-1)){yDb(0,0,2036648,(T=i,i=i+24|0,c[T>>2]=2033032,c[T+8>>2]=2028840,c[T+16>>2]=135,T)|0);i=T;Cd();return 0}T=h+(J+C)|0;O=T;if((J|0)<2){Ba=0;Ca=D}else{W=D;Ba=(d[W]|d[W+1|0]<<8)<<16>>16&65535;Ca=h+(A+10)|0}if((O-Ca|0)<2){Da=Ca;Ea=0}else{W=Ca;Q=(d[W]|d[W+1|0]<<8)<<16>>16;if((Q&65535)>>>0>8191>>>0){break a}else{Da=Ca+2|0;Ea=Q&65535}}TGb(za|0,0,(Ba>>>0>8192>>>0?8192:Ba)|0)|0;if(Ba>>>0>Ea>>>0){Fa=Da}else{Q=Ea-Ba+1|0;W=O-Da|0;P=W>>>0>Q>>>0?Q:W;UGb((c[U>>2]|0)+Ba|0,Da|0,P)|0;Fa=Da+P|0}TGb((c[U>>2]|0)+Ea|0,0,8192-Ea|0)|0;P=c[U>>2]|0;U=c[R>>2]|0;W=0;Q=0;while(1){if((W|0)==0){Ga=39}else{if((d[P+(W>>3)|0]&1<<(W&7)|0)==0){Ha=Q}else{Ga=39}}if((Ga|0)==39){Ga=0;b[U+(Q<<1)>>1]=W;Ha=Q+1|0}Z=W+1|0;if((Z|0)<65536){W=Z;Q=Ha}else{break}}TGb(U+(Ha<<1)|0,0,65536-Ha<<1|0)|0;Q=Ha+65535&65535;W=z>>>1;if((O-Fa|0)<4){Ia=0;Ja=Fa}else{P=Fa;Ia=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;Ja=Fa+4|0}if((O-Ja|0)<4){Ka=0;La=Ja}else{P=Ja;Ka=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;La=Ja+4|0}if((O-La|0)<4){Ma=0;Na=La}else{P=La;Ma=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;Na=La+4|0}P=O-Na|0;Z=P>>>0>4>>>0?4:P;P=Na+Z|0;if((O-P|0)<4){Oa=0;Pa=P}else{ea=P;Oa=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0;Pa=Na+(Z+4)|0}if(Ka>>>0>65536>>>0|Ma>>>0>65536>>>0|(Ia|0)<0){break a}Z=O-Pa|0;ea=Z>>>0>4>>>0?4:Z;Z=Pa+ea|0;P=dEb(65537,8)|0;u=P;X=dEb(16384,12)|0;V=X;Y=(X|0)==0;b:do{if((P|0)==0|Y){Qa=-12}else{ha=O-Z|0;ca=ha>>>0>268435455>>>0?-8:ha<<3;ga=ca>>>0>2147483639>>>0|(Z|0)==0;ia=ga?0:Z;Ra=ga?8:ca+8|0;ca=(Ka|0)>(Ma|0);if(ca){Sa=0}else{ga=Ma+1|0;Ta=0;Ua=Ka;while(1){Va=ia+(Ta>>>3)|0;Wa=(fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7);Va=Wa>>>26;Xa=Ta+6|0;Ya=Ra>>>0>Xa>>>0?Xa:Ra;Xa=u+(Ua<<3)|0;c[Xa>>2]=Va;c[Xa+4>>2]=0;do{if((Va|0)==63){Za=ia+(Ya>>>3)|0;_a=(fe(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(Ya&7)>>>24;Za=Ya+8|0;if((Ua+6+_a|0)>(ga|0)){Qa=-1094995529;break b}TGb(Xa|0,0,(_a<<3)+48|0)|0;$a=Ua+5+_a|0;ab=Ra>>>0>Za>>>0?Za:Ra}else{if(!(Wa>>>0>3959422975>>>0)){$a=Ua;ab=Ya;break}Za=Va-57|0;if((Za+Ua|0)>(ga|0)){Qa=-1094995529;break b}if((Za|0)==0){bb=Ua}else{TGb(Xa|0,0,(Va<<3)-456|0)|0;bb=Ua-57+Va|0}$a=bb-1|0;ab=Ya}}while(0);Ya=$a+1|0;if((Ya|0)>(Ma|0)){Sa=ab;break}else{Ta=ab;Ua=Ya}}}Ua=(Sa+7|0)/8|0;Ta=ha>>>0>Ua>>>0?Ua:ha;TGb(l|0,0,472)|0;Ua=0;do{ga=l+(c[u+(Ua<<3)>>2]<<3)|0;Ra=YGb(c[ga>>2]|0,c[ga+4>>2]|0,1,0)|0;c[ga>>2]=Ra;c[ga+4>>2]=F;Ua=Ua+1|0;}while((Ua|0)<65537);Ua=Ta+ea|0;ha=58;ga=0;Ra=0;while(1){ia=l+(ha<<3)|0;Ya=YGb(c[ia>>2]|0,c[ia+4>>2]|0,Ra,ga)|0;Va=F;c[ia>>2]=Ra;c[ia+4>>2]=ga;ia=ha-1|0;if((ia|0)>0){ha=ia;ga=Va>>>1|0<<31;Ra=Ya>>>1|Va<<31}else{break}}Ra=Pa+Ua|0;ga=0;do{ha=u+(ga<<3)|0;Ta=c[ha>>2]|0;if((Ta|0)>0){Va=l+(Ta<<3)|0;Ya=c[Va>>2]|0;ia=c[Va+4>>2]|0;Xa=YGb(Ya,ia,1,0)|0;c[Va>>2]=Xa;c[Va+4>>2]=F;c[ha>>2]=Ya<<6|0>>>26|Ta;c[ha+4>>2]=ia<<6|Ya>>>26|((Ta|0)<0|0?-1:0)}ga=ga+1|0;}while((ga|0)<65537);if(Oa>>>0>O-Ra<<3>>>0){Qa=-1094995529;break}if(!ca){ga=Ka;do{Ta=u+(ga<<3)|0;Ya=c[Ta>>2]|0;ia=c[Ta+4>>2]|0;Ta=Ya>>>6|ia<<26;ha=ia>>>6|0<<26;ia=Ya&63;Ya=$Gb(Ta|0,ha|0,ia|0)|0;if(!((Ya|0)==0&(F|0)==0)){Qa=-1094995529;break b}do{if(ia>>>0>14>>>0){Ya=$Gb(Ta|0,ha|0,ia-14|0)|0;Va=Ya;if((c[V+(Va*12|0)>>2]|0)!=0){Qa=-1094995529;break b}Ya=V+(Va*12|0)+4|0;Xa=(c[Ya>>2]|0)+1|0;c[Ya>>2]=Xa;Wa=V+(Va*12|0)+8|0;Va=YDb(c[Wa>>2]|0,Xa,4)|0;Xa=Va;c[Wa>>2]=Xa;if((Va|0)==0){Qa=-12;break b}c[Xa+((c[Ya>>2]|0)-1<<2)>>2]=ga}else{if((ia|0)==0){break}Ya=14-ia|0;Xa=1<<Ya;if((Xa|0)<=0){break}Va=_Gb(Ta|0,ha|0,Ya|0)|0;Ya=Xa;Xa=V+(Va*12|0)|0;while(1){Va=Xa|0;if((c[Va>>2]|0)!=0){Qa=-1094995529;break b}if((c[Xa+8>>2]|0)!=0){Qa=-1094995529;break b}c[Va>>2]=ia;c[Xa+4>>2]=ga;Va=Ya-1|0;if((Va|0)>0){Ya=Va;Xa=Xa+12|0}else{break}}}}while(0);ga=ga+1|0;}while((ga|0)<=(Ma|0))}ga=y+(W<<1)|0;ca=Pa+(((Oa+7|0)/8|0)+Ua)|0;if((Oa|0)>0){ia=0;ha=0;Ta=0;Xa=y;Ya=Ra;Va=Ra;while(1){if((O-Ya|0)<1){cb=0;db=0;eb=Ya;fb=Va}else{Wa=Ya+1|0;cb=0;db=d[Ya]|0;eb=Wa;fb=Wa}Wa=db|(Ta<<8|0>>>24);_=cb|(ha<<8|Ta>>>24);da=ia+8|0;c:do{if((da|0)>13){fa=da;Za=_;_a=Wa;gb=Xa;hb=eb;ib=fb;while(1){jb=fa;kb=gb;while(1){lb=$Gb(_a|0,Za|0,jb-14|0)|0;mb=lb&16383;lb=c[V+(mb*12|0)>>2]|0;nb=c[V+(mb*12|0)+4>>2]|0;ob=c[V+(mb*12|0)+8>>2]|0;if((lb|0)==0){Ga=103;break}pb=jb-lb|0;if((nb|0)==(Ma|0)){Ga=93;break}if(!(kb>>>0<ga>>>0)){Qa=-1094995529;break b}lb=kb+2|0;b[kb>>1]=nb;if((pb|0)>13){jb=pb;kb=lb}else{qb=pb;rb=lb;sb=Za;tb=_a;ub=hb;vb=ib;break c}}do{if((Ga|0)==93){Ga=0;if((pb|0)<8){if((O-ib|0)<1){wb=0;xb=0;yb=ib}else{wb=0;xb=d[ib]|0;yb=ib+1|0}zb=wb|(Za<<8|_a>>>24);Ab=xb|(_a<<8|0>>>24);Bb=pb+8|0;Cb=yb;Db=yb}else{zb=Za;Ab=_a;Bb=pb;Cb=hb;Db=ib}lb=Bb-8|0;mb=$Gb(Ab|0,zb|0,lb|0)|0;if((kb+((mb&255)<<1)|0)>>>0>ga>>>0){Qa=-1094995529;break b}Eb=mb&255;if(Eb<<24>>24==0){Fb=kb;Gb=zb;Hb=Ab;Ib=lb;Jb=Cb;Kb=Db;break}mb=b[kb-2>>1]&255;Lb=Eb;Mb=kb;while(1){Nb=Lb-1&255;b[Mb>>1]=mb;if(Nb<<24>>24==0){break}else{Lb=Nb;Mb=Mb+2|0}}Fb=kb+((Eb-1&255)+1<<1)|0;Gb=zb;Hb=Ab;Ib=lb;Jb=Cb;Kb=Db}else if((Ga|0)==103){Ga=0;if((ob|0)==0){Qa=-1094995529;break b}d:do{if((nb|0)>0){Mb=jb;Lb=0;mb=Za;Nb=_a;Ob=hb;Pb=ib;while(1){Qb=c[ob+(Lb<<2)>>2]|0;Rb=u+(Qb<<3)|0;Sb=c[Rb>>2]|0;Tb=c[Rb+4>>2]|0;Rb=Sb&63;e:do{if((Mb|0)<(Rb|0)){Ub=Mb;Vb=mb;Wb=Nb;Xb=Ob;Yb=Pb;while(1){if((T|0)==(Xb|0)){_b=Ub;$b=Vb;ac=Wb;bc=T;cc=Yb;break e}if((O-Yb|0)<1){dc=0;ec=0;fc=Yb}else{dc=0;ec=d[Yb]|0;fc=Yb+1|0}gc=ec|(Wb<<8|0>>>24);hc=dc|(Vb<<8|Wb>>>24);ic=Ub+8|0;if((ic|0)<(Rb|0)){Ub=ic;Vb=hc;Wb=gc;Xb=fc;Yb=fc}else{jc=ic;kc=hc;lc=gc;mc=fc;nc=fc;Ga=110;break}}}else{jc=Mb;kc=mb;lc=Nb;mc=Ob;nc=Pb;Ga=110}}while(0);if((Ga|0)==110){Ga=0;oc=jc-Rb|0;Yb=$Gb(lc|0,kc|0,oc|0)|0;Xb=F;Wb=_Gb(1,0,Rb|0)|0;Vb=YGb(Wb,F,-1,-1)|0;if((Sb>>>6|Tb<<26|0)==(Yb&Vb|0)&(Tb>>>6|0<<26|0)==(Xb&F|0)){break}else{_b=jc;$b=kc;ac=lc;bc=mc;cc=nc}}Xb=Lb+1|0;if((Xb|0)<(nb|0)){Mb=_b;Lb=Xb;mb=$b;Nb=ac;Ob=bc;Pb=cc}else{pc=kb;qc=$b;rc=ac;sc=_b;tc=Xb;uc=bc;vc=cc;break d}}if((Qb|0)!=(Ma|0)){if(!(kb>>>0<ga>>>0)){Qa=-1094995529;break b}b[kb>>1]=Qb;pc=kb+2|0;qc=kc;rc=lc;sc=oc;tc=Lb;uc=mc;vc=nc;break}if((oc|0)<8){if((O-mc|0)<1){wc=0;xc=0;yc=mc;zc=nc}else{Pb=mc+1|0;wc=0;xc=d[mc]|0;yc=Pb;zc=Pb}Ac=wc|(kc<<8|lc>>>24);Bc=xc|(lc<<8|0>>>24);Cc=oc+8|0;Dc=yc;Ec=zc}else{Ac=kc;Bc=lc;Cc=oc;Dc=mc;Ec=nc}Pb=Cc-8|0;Ob=$Gb(Bc|0,Ac|0,Pb|0)|0;if((kb+((Ob&255)<<1)|0)>>>0>ga>>>0){Qa=-1094995529;break b}Nb=Ob&255;if(Nb<<24>>24==0){pc=kb;qc=Ac;rc=Bc;sc=Pb;tc=Lb;uc=Dc;vc=Ec;break}Ob=b[kb-2>>1]&255;mb=Nb;Mb=kb;while(1){Xb=mb-1&255;b[Mb>>1]=Ob;if(Xb<<24>>24==0){break}else{mb=Xb;Mb=Mb+2|0}}pc=kb+((Nb-1&255)+1<<1)|0;qc=Ac;rc=Bc;sc=Pb;tc=Lb;uc=Dc;vc=Ec}else{pc=kb;qc=Za;rc=_a;sc=jb;tc=0;uc=hb;vc=ib}}while(0);if((tc|0)==(nb|0)){Qa=-1094995529;break b}else{Fb=pc;Gb=qc;Hb=rc;Ib=sc;Jb=uc;Kb=vc}}}while(0);if((Ib|0)>13){fa=Ib;Za=Gb;_a=Hb;gb=Fb;hb=Jb;ib=Kb}else{qb=Ib;rb=Fb;sb=Gb;tb=Hb;ub=Jb;vb=Kb;break}}}else{qb=da;rb=Xa;sb=_;tb=Wa;ub=eb;vb=fb}}while(0);if(ub>>>0<ca>>>0){ia=qb;ha=sb;Ta=tb;Xa=rb;Ya=ub;Va=vb}else{Fc=qb;Gc=sb;Hc=tb;Ic=rb;Jc=ub;break}}}else{Fc=0;Gc=0;Hc=0;Ic=y;Jc=Ra}Va=-Oa&7;Ya=Fc-Va|0;f:do{if((Ya|0)>0){Xa=$Gb(Hc|0,Gc|0,Va|0)|0;Ta=Ya;ha=F;ia=Xa;Xa=Ic;ca=Jc;while(1){Ua=Ta;Wa=Xa;while(1){_=_Gb(ia|0,ha|0,14-Ua|0)|0;da=_&16383;_=c[V+(da*12|0)>>2]|0;ib=c[V+(da*12|0)+4>>2]|0;if((_|0)==0){Qa=-1094995529;break b}Kc=Ua-_|0;if((ib|0)==(Ma|0)){break}if(!(Wa>>>0<ga>>>0)){Qa=-1094995529;break b}_=Wa+2|0;b[Wa>>1]=ib;if((Kc|0)>0){Ua=Kc;Wa=_}else{Lc=_;break f}}if((Kc|0)<8){if((O-ca|0)<1){Mc=0;Nc=0;Oc=ca}else{Mc=0;Nc=d[ca]|0;Oc=ca+1|0}Pc=Mc|(ha<<8|ia>>>24);Qc=Nc|(ia<<8|0>>>24);Rc=Kc+8|0;Sc=Oc}else{Pc=ha;Qc=ia;Rc=Kc;Sc=ca}Ua=Rc-8|0;_=$Gb(Qc|0,Pc|0,Ua|0)|0;if((Wa+((_&255)<<1)|0)>>>0>ga>>>0){Qa=-1094995529;break b}ib=_&255;if(ib<<24>>24==0){Tc=Wa}else{_=b[Wa-2>>1]&255;da=ib;hb=Wa;while(1){gb=da-1&255;b[hb>>1]=_;if(gb<<24>>24==0){break}else{da=gb;hb=hb+2|0}}Tc=Wa+((ib-1&255)+1<<1)|0}if((Ua|0)>0){Ta=Ua;ha=Pc;ia=Qc;Xa=Tc;ca=Sc}else{Lc=Tc;break}}}else{Lc=Ic}}while(0);Qa=(Lc-M>>1|0)==(W|0)?0:-1094995529}}while(0);if(!Y){O=0;do{$Db(V+(O*12|0)+8|0);O=O+1|0;}while((O|0)<16384)}ZDb(P);ZDb(X);if((Qa|0)!=0){break a}O=n+92|0;V=c[O>>2]|0;if((V|0)>0){Y=c[n+88>>2]|0;T=c[r>>2]|0;u=c[K>>2]|0;ea=(Q&65535)>>>0<16384>>>0;Z=(T|0)>(u|0)?u:T;U=0;ga=y;do{Ya=c[Y+(U*12|0)+8>>2]|0;Va=ba(Ya,T)|0;if((Ya|0)>0){Ra=Va+Ya|0;ca=0;do{Xa=1;while(1){if((Xa|0)>(Z|0)){break}else{Xa=Xa<<1}}ia=ga+(ca<<1)|0;ha=Xa>>2;if((ha|0)>0){Ta=Xa>>1;hb=ha;while(1){ha=ba(u-Ta|0,Va)|0;da=ga+(ha+ca<<1)|0;_=ba(hb,Va)|0;gb=ba(Ta,Va)|0;_a=ba(hb,Ya)|0;Za=ba(Ta,Ya)|0;if((ha|0)<0){Uc=ia}else{ha=ba(T-Ta|0,Ya)|0;fa=(hb&T|0)==0;jb=ba(hb,Ra)|0;kb=(ha|0)<0;lb=ia;while(1){Eb=lb+(ha<<1)|0;if(kb){Vc=lb}else{if(ea){Mb=lb;while(1){mb=Mb+(_a<<1)|0;Ob=Mb+(_<<1)|0;Xb=Mb+(jb<<1)|0;Vb=b[Ob>>1]|0;Yb=(Vb&1)+(b[Mb>>1]|0)+(Vb>>1)|0;Wb=b[Xb>>1]|0;Ub=(Wb&1)+(b[mb>>1]|0)+(Wb>>1)|0;gc=Ub<<16;hc=gc>>16;ic=(gc>>17)+(Yb<<16>>16)+(hc&1)|0;b[Mb>>1]=ic;b[mb>>1]=ic-hc;hc=Ub-Wb<<16;Wb=hc>>16;Ub=(hc>>17)+(Yb-Vb<<16>>16)+(Wb&1)|0;b[Ob>>1]=Ub;b[Xb>>1]=Ub-Wb;Wb=Mb+(Za<<1)|0;if(Wb>>>0>Eb>>>0){Vc=Wb;break}else{Mb=Wb}}}else{Mb=lb;while(1){Wb=Mb+(_a<<1)|0;Ub=Mb+(_<<1)|0;Xb=Mb+(jb<<1)|0;Ob=e[Ub>>1]|0;Vb=(e[Mb>>1]|0)-(Ob>>>1)|0;Yb=e[Xb>>1]|0;hc=(e[Wb>>1]|0)-(Yb>>>1)|0;ic=Yb+32768+hc|0;Yb=(Ob+32768+Vb&65535)-(ic>>>1&32767)|0;b[Wb>>1]=Yb;b[Mb>>1]=ic+32768+Yb;Yb=(Vb&65535)-(hc>>>1&32767)|0;b[Xb>>1]=Yb;b[Ub>>1]=hc+32768+Yb;Yb=Mb+(Za<<1)|0;if(Yb>>>0>Eb>>>0){Vc=Yb;break}else{Mb=Yb}}}}if(!fa){Mb=Vc+(_<<1)|0;Eb=b[Vc>>1]|0;Yb=b[Mb>>1]|0;if(ea){hc=Yb<<16>>16;Ub=(hc&1)+(Eb<<16>>16)+(hc>>1)|0;b[Mb>>1]=Ub-hc;Wc=Ub&65535}else{Ub=Yb&65535;Yb=(Eb&65535)-(Ub>>>1)|0;b[Mb>>1]=Yb;Wc=Ub+32768+Yb&65535}b[Vc>>1]=Wc}Yb=lb+(gb<<1)|0;if(Yb>>>0>da>>>0){Uc=Yb;break}else{lb=Yb}}}do{if((hb&u|0)!=0){lb=ba(T-Ta|0,Ya)|0;da=Uc+(lb<<1)|0;if((lb|0)<0){break}if(ea){lb=Uc;do{gb=lb+(_a<<1)|0;_=b[gb>>1]|0;fa=(_&1)+(b[lb>>1]|0)+(_>>1)|0;b[gb>>1]=fa-_;b[lb>>1]=fa;lb=lb+(Za<<1)|0;}while(!(lb>>>0>da>>>0))}else{lb=Uc;do{fa=lb+(_a<<1)|0;_=e[fa>>1]|0;gb=(e[lb>>1]|0)-(_>>>1)|0;b[fa>>1]=gb;b[lb>>1]=_+32768+gb;lb=lb+(Za<<1)|0;}while(!(lb>>>0>da>>>0))}}}while(0);Za=hb>>1;if((Za|0)>0){Ta=hb;hb=Za}else{break}}}ca=ca+1|0;}while((ca|0)<(Ya|0))}ga=ga+((ba(Va,u)|0)<<1)|0;U=U+1|0;}while((U|0)<(V|0))}U=c[R>>2]|0;if((W|0)!=0){u=0;do{ga=y+(u<<1)|0;b[ga>>1]=b[U+(e[ga>>1]<<1)>>1]|0;u=u+1|0;}while((u|0)<(W|0))}W=c[K>>2]|0;if((W|0)<=0){break a}u=0;U=c[H>>2]|0;R=V;ga=W;while(1){if((R|0)>0){W=0;ea=U;T=c[r>>2]|0;Z=ga;while(1){UGb(ea|0,y+((ba((ba(W,Z)|0)+u|0,T)|0)<<1)|0,T<<1)|0;Y=c[r>>2]|0;Q=ea+(Y<<1)|0;X=W+1|0;P=c[O>>2]|0;Ya=c[K>>2]|0;if((X|0)<(P|0)){W=X;ea=Q;T=Y;Z=Ya}else{Xc=Q;Yc=P;Zc=Ya;break}}}else{Xc=U;Yc=R;Zc=ga}Z=u+1|0;if((Z|0)<(Zc|0)){u=Z;U=Xc;R=Yc;ga=Zc}else{break}}break};default:{}}}while(0);_c=c[H>>2]|0}else{_c=D}D=_c+(ba(c[n+16>>2]|0,s)|0)|0;H=_c+(ba(c[n+20>>2]|0,s)|0)|0;Zc=_c+(ba(c[n+24>>2]|0,s)|0)|0;Yc=c[n+28>>2]|0;if((Yc|0)>-1){$c=_c+(ba(Yc,s)|0)|0}else{$c=0}Yc=o+32|0;if((c[I>>2]|0)<=0){B=0;i=g;return B|0}_c=ba(c[Yc>>2]|0,G)|0;Xc=n+12|0;n=(s|0)==0;K=0;r=(c[o>>2]|0)+_c|0;_c=D;D=H;H=Zc;Zc=$c;$c=0;while(1){if(($c+G|0)>>>0>(c[E>>2]|0)>>>0){B=0;Ga=271;break}o=(Zc|0)!=0;Uc=o?Zc:K;TGb(r|0,0,w|0)|0;Wc=r+((ba(d[(c[t>>2]|0)+4|0]|0,c[f>>2]|0)|0)<<1)|0;do{if((c[Xc>>2]|0)==2){if(n){ad=Wc;bd=Uc;break}else{cd=_c;dd=D;ed=H;fd=Uc;gd=Wc;hd=0}while(1){Vc=cd+4|0;Qa=cd;M=d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0;Qa=M>>>23;do{if(M>>>0<931135488>>>0){id=0}else{if(M>>>0>1065353215>>>0){id=-1;break}id=(M&8388607|8388608)>>>((134-Qa|0)>>>0)&65535}}while(0);Qa=gd+2|0;b[gd>>1]=id;M=dd+4|0;Lc=dd;Ic=d[Lc]|d[Lc+1|0]<<8|d[Lc+2|0]<<16|d[Lc+3|0]<<24|0;Lc=Ic>>>23;do{if(Ic>>>0<931135488>>>0){jd=0}else{if(Ic>>>0>1065353215>>>0){jd=-1;break}jd=(Ic&8388607|8388608)>>>((134-Lc|0)>>>0)&65535}}while(0);Lc=gd+4|0;b[Qa>>1]=jd;Ic=ed+4|0;Tc=ed;Sc=d[Tc]|d[Tc+1|0]<<8|d[Tc+2|0]<<16|d[Tc+3|0]<<24|0;Tc=Sc>>>23;do{if(Sc>>>0<931135488>>>0){kd=0}else{if(Sc>>>0>1065353215>>>0){kd=-1;break}kd=(Sc&8388607|8388608)>>>((134-Tc|0)>>>0)&65535}}while(0);Tc=gd+6|0;b[Lc>>1]=kd;if(o){Sc=fd+4|0;Qa=fd;Qc=d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0;Qa=Qc>>>23;do{if(Qc>>>0<931135488>>>0){ld=0}else{if(Qc>>>0>1065353215>>>0){ld=-1;break}ld=(Qc&8388607|8388608)>>>((134-Qa|0)>>>0)&65535}}while(0);b[Tc>>1]=ld;md=gd+8|0;nd=Sc}else{md=Tc;nd=fd}Qa=hd+1|0;if(Qa>>>0<s>>>0){cd=Vc;dd=M;ed=Ic;fd=nd;gd=md;hd=Qa}else{ad=md;bd=nd;break}}}else{if(n){ad=Wc;bd=Uc;break}else{od=_c;pd=D;qd=H;rd=Uc;sd=Wc;td=0}while(1){Qa=od+2|0;Qc=od;Lc=(d[Qc]|d[Qc+1|0]<<8)<<16>>16;Qc=(Lc&65535)>>>10;Pc=14-Qc|0;do{if(Pc>>>0>13>>>0){if((Qc|0)==0){ud=(Lc&65535)>>>9&1;break}else{ud=((Lc&65535)>>>15)-1&65535;break}}else{ud=(Lc<<6&65535|65536)>>>((Pc+1|0)>>>0)&65535}}while(0);Pc=sd+2|0;b[sd>>1]=ud;Lc=pd+2|0;Qc=pd;Ic=(d[Qc]|d[Qc+1|0]<<8)<<16>>16;Qc=(Ic&65535)>>>10;M=14-Qc|0;do{if(M>>>0>13>>>0){if((Qc|0)==0){vd=(Ic&65535)>>>9&1;break}else{vd=((Ic&65535)>>>15)-1&65535;break}}else{vd=(Ic<<6&65535|65536)>>>((M+1|0)>>>0)&65535}}while(0);M=sd+4|0;b[Pc>>1]=vd;Ic=qd+2|0;Qc=qd;Vc=(d[Qc]|d[Qc+1|0]<<8)<<16>>16;Qc=(Vc&65535)>>>10;Tc=14-Qc|0;do{if(Tc>>>0>13>>>0){if((Qc|0)==0){wd=(Vc&65535)>>>9&1;break}else{wd=((Vc&65535)>>>15)-1&65535;break}}else{wd=(Vc<<6&65535|65536)>>>((Tc+1|0)>>>0)&65535}}while(0);Tc=sd+6|0;b[M>>1]=wd;if(o){Vc=rd+2|0;Qc=rd;Pc=(d[Qc]|d[Qc+1|0]<<8)<<16>>16;Qc=(Pc&65535)>>>10;Sc=14-Qc|0;do{if(Sc>>>0>13>>>0){if((Qc|0)==0){xd=(Pc&65535)>>>9&1;break}else{xd=((Pc&65535)>>>15)-1&65535;break}}else{xd=(Pc<<6&65535|65536)>>>((Sc+1|0)>>>0)&65535}}while(0);b[Tc>>1]=xd;yd=sd+8|0;zd=Vc}else{yd=Tc;zd=rd}Sc=td+1|0;if(Sc>>>0<s>>>0){od=Qa;pd=Lc;qd=Ic;rd=zd;sd=yd;td=Sc}else{ad=yd;bd=zd;break}}}}while(0);TGb(ad|0,0,v|0)|0;Wc=c[L>>2]|0;if(o){Ad=Zc+Wc|0}else{Ad=0}Uc=$c+1|0;if((Uc|0)>=(c[I>>2]|0)){B=0;Ga=271;break}K=bd;r=r+(c[Yc>>2]|0)|0;_c=_c+Wc|0;D=D+Wc|0;H=H+Wc|0;Zc=Ad;$c=Uc}if((Ga|0)==271){i=g;return B|0}return 0}function U8(a){a=a|0;var c=0,d=0,e=0,f=0,h=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0.0,E=0.0;c=i;i=i+256|0;d=c|0;e=0;while(1){f=b[a+(e<<1)>>1]|0;h=e|7;j=b[a+(h<<1)>>1]|0;k=+(j+f|0);l=f-j|0;m=+(l|0);j=e|1;f=b[a+(j<<1)>>1]|0;n=e|6;o=b[a+(n<<1)>>1]|0;p=+(o+f|0);q=f-o|0;o=e|2;f=b[a+(o<<1)>>1]|0;r=e|5;s=b[a+(r<<1)>>1]|0;t=+(s+f|0);u=f-s|0;s=e|3;f=b[a+(s<<1)>>1]|0;v=e|4;w=b[a+(v<<1)>>1]|0;x=+(w+f|0);y=k+x;z=k-x;x=p+t;g[d+(e<<2)>>2]=x+y;g[d+(v<<2)>>2]=y-x;x=(p-t+z)*.7071067811865476;g[d+(o<<2)>>2]=z+x;g[d+(n<<2)>>2]=z-x;x=+(u+f-w|0);z=+(q+l|0);t=x*.9238795325112867-z*.3826834323650898;p=z*.9238795325112867+x*.3826834323650898;x=+(u+q|0)*.7071067811865476;z=m+x;y=m-x;g[d+(r<<2)>>2]=y+t;g[d+(s<<2)>>2]=y-t;g[d+(j<<2)>>2]=z+p;g[d+(h<<2)>>2]=z-p;h=e+8|0;if((h|0)<64){e=h}else{A=0;break}}do{p=+g[d+(A<<2)>>2];e=A+56|0;z=+g[d+(e<<2)>>2];t=p+z;y=p-z;h=A+8|0;z=+g[d+(h<<2)>>2];j=A+48|0;p=+g[d+(j<<2)>>2];x=z+p;m=z-p;s=A+16|0;p=+g[d+(s<<2)>>2];r=A+40|0;z=+g[d+(r<<2)>>2];k=p+z;B=p-z;q=A+24|0;z=+g[d+(q<<2)>>2];u=A+32|0;p=+g[d+(u<<2)>>2];C=z+p;D=t+C;E=t-C;C=x+k;b[a+(A<<1)>>1]=Gc(+(+g[563208+(A<<2)>>2]*(C+D)))|0;b[a+(u<<1)>>1]=Gc(+(+g[563208+(u<<2)>>2]*(D-C)))|0;C=(x-k+E)*.7071067811865476;b[a+(s<<1)>>1]=Gc(+(+g[563208+(s<<2)>>2]*(E+C)))|0;b[a+(j<<1)>>1]=Gc(+(+g[563208+(j<<2)>>2]*(E-C)))|0;C=B+(z-p);p=y+m;z=C*.9238795325112867-p*.3826834323650898;E=p*.9238795325112867+C*.3826834323650898;C=(m+B)*.7071067811865476;B=y+C;m=y-C;b[a+(r<<1)>>1]=Gc(+((m+z)*+g[563208+(r<<2)>>2]))|0;b[a+(q<<1)>>1]=Gc(+((m-z)*+g[563208+(q<<2)>>2]))|0;b[a+(h<<1)>>1]=Gc(+((B+E)*+g[563208+(h<<2)>>2]))|0;b[a+(e<<1)>>1]=Gc(+((B-E)*+g[563208+(e<<2)>>2]))|0;A=A+1|0;}while((A|0)<8);i=c;return}function V8(a){a=a|0;var c=0,d=0,e=0,f=0,h=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0;c=i;i=i+256|0;d=c|0;e=0;while(1){f=b[a+(e<<1)>>1]|0;h=e|7;j=b[a+(h<<1)>>1]|0;k=+(j+f|0);l=f-j|0;m=+(l|0);j=e|1;f=b[a+(j<<1)>>1]|0;n=e|6;o=b[a+(n<<1)>>1]|0;p=+(o+f|0);q=f-o|0;o=e|2;f=b[a+(o<<1)>>1]|0;r=e|5;s=b[a+(r<<1)>>1]|0;t=+(s+f|0);u=f-s|0;s=e|3;f=b[a+(s<<1)>>1]|0;v=e|4;w=b[a+(v<<1)>>1]|0;x=+(w+f|0);y=k+x;z=k-x;x=p+t;g[d+(e<<2)>>2]=x+y;g[d+(v<<2)>>2]=y-x;x=(p-t+z)*.7071067811865476;g[d+(o<<2)>>2]=z+x;g[d+(n<<2)>>2]=z-x;x=+(u+f-w|0);z=+(q+l|0);t=x*.9238795325112867-z*.3826834323650898;p=z*.9238795325112867+x*.3826834323650898;x=+(u+q|0)*.7071067811865476;z=m+x;y=m-x;g[d+(r<<2)>>2]=y+t;g[d+(s<<2)>>2]=y-t;g[d+(j<<2)>>2]=z+p;g[d+(h<<2)>>2]=z-p;h=e+8|0;if((h|0)<64){e=h}else{A=0;break}}do{p=+g[d+(A<<2)>>2];e=A+8|0;z=+g[d+(e<<2)>>2];t=p+z;h=A+16|0;y=+g[d+(h<<2)>>2];j=A+24|0;x=+g[d+(j<<2)>>2];m=y+x;s=A+32|0;k=+g[d+(s<<2)>>2];r=A+40|0;B=+g[d+(r<<2)>>2];C=k+B;q=A+48|0;D=+g[d+(q<<2)>>2];u=A+56|0;E=+g[d+(u<<2)>>2];F=D+E;G=p-z;z=y-x;x=k-B;B=D-E;E=t+F;D=m+C;k=t-F;F=+g[563208+(A<<2)>>2];b[a+(A<<1)>>1]=Gc(+(F*(D+E)))|0;t=+g[563208+(s<<2)>>2];b[a+(s<<1)>>1]=Gc(+(t*(E-D)))|0;D=(m-C+k)*.7071067811865476;C=+g[563208+(h<<2)>>2];b[a+(h<<1)>>1]=Gc(+(C*(k+D)))|0;m=+g[563208+(q<<2)>>2];b[a+(q<<1)>>1]=Gc(+(m*(k-D)))|0;D=G+B;k=z+x;E=G-B;b[a+(e<<1)>>1]=Gc(+((k+D)*F))|0;b[a+(r<<1)>>1]=Gc(+((D-k)*t))|0;t=(z-x+E)*.7071067811865476;b[a+(j<<1)>>1]=Gc(+((E+t)*C))|0;b[a+(u<<1)>>1]=Gc(+((E-t)*m))|0;A=A+1|0;}while((A|0)<8);i=c;return}function W8(a){a=a|0;var c=0,d=0,e=0;c=i;i=i+256|0;d=c|0;e=0;do{g[d+(e<<2)>>2]=+(b[a+(e<<1)>>1]|0)*+g[561992+(e<<2)>>2];e=e+1|0;}while((e|0)<64);e=d|0;X8(a,e,0,0,1,8,0);X8(a,e,0,0,8,1,1);i=c;return}function X8(c,e,f,h,i,j,k){c=c|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0.0,F=0.0,G=0,H=0,I=0.0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;l=j<<3;if((l|0)<=0){return}m=i*7|0;n=i*5|0;o=i*3|0;p=i<<1;q=i*6|0;r=i<<2;s=h*7|0;t=h*6|0;u=h<<1;v=h*5|0;w=h*3|0;x=h<<2;y=0;do{z=y+i|0;A=e+(z<<2)|0;B=+g[A>>2];C=y+m|0;D=e+(C<<2)|0;E=+g[D>>2];F=B+E;G=y+n|0;H=e+(G<<2)|0;I=+g[H>>2];J=y+o|0;K=e+(J<<2)|0;L=+g[K>>2];M=I+L;N=F+M;O=B-E;E=I-L;L=O*1.8477590650225735+E*-.7653668647301797-N;I=(F-M)*1.4142135623730951-L;M=O*-.7653668647301795-E*1.8477590650225735+I;P=y+p|0;Q=e+(P<<2)|0;E=+g[Q>>2];R=y+q|0;S=e+(R<<2)|0;O=+g[S>>2];F=E+O;B=(E-O)*1.4142135623730951-F;T=e+(y<<2)|0;O=+g[T>>2];U=y+r|0;V=e+(U<<2)|0;E=+g[V>>2];W=O+E;X=O-E;E=F+W;O=W-F;F=X+B;W=X-B;if((k|0)==2){Y=f+y|0;Z=d[Y]|0;_=Z+(Gc(+(N+E))|0)|0;if(_>>>0>255>>>0){$=-_>>31&255}else{$=_&255}a[Y]=$;Y=f+(y+s)|0;_=d[Y]|0;Z=_+(Gc(+(E-N))|0)|0;if(Z>>>0>255>>>0){aa=-Z>>31&255}else{aa=Z&255}a[Y]=aa;Y=f+(y+h)|0;Z=d[Y]|0;_=Z+(Gc(+(L+F))|0)|0;if(_>>>0>255>>>0){ba=-_>>31&255}else{ba=_&255}a[Y]=ba;Y=f+(y+t)|0;_=d[Y]|0;Z=_+(Gc(+(F-L))|0)|0;if(Z>>>0>255>>>0){ca=-Z>>31&255}else{ca=Z&255}a[Y]=ca;Y=f+(y+u)|0;Z=d[Y]|0;_=Z+(Gc(+(I+W))|0)|0;if(_>>>0>255>>>0){da=-_>>31&255}else{da=_&255}a[Y]=da;Y=f+(y+v)|0;_=d[Y]|0;Z=_+(Gc(+(W-I))|0)|0;if(Z>>>0>255>>>0){ea=-Z>>31&255}else{ea=Z&255}a[Y]=ea;Y=f+(y+w)|0;Z=d[Y]|0;_=Z+(Gc(+(O-M))|0)|0;if(_>>>0>255>>>0){fa=-_>>31&255}else{fa=_&255}a[Y]=fa;Y=f+(y+x)|0;_=d[Y]|0;Z=_+(Gc(+(O+M))|0)|0;if(Z>>>0>255>>>0){ga=-Z>>31&255}else{ga=Z&255}a[Y]=ga}else if((k|0)==0){g[T>>2]=N+E;g[D>>2]=E-N;g[A>>2]=L+F;g[S>>2]=F-L;g[Q>>2]=I+W;g[H>>2]=W-I;g[K>>2]=O-M;g[V>>2]=O+M}else if((k|0)==1){b[c+(y<<1)>>1]=Gc(+(N+E))|0;b[c+(C<<1)>>1]=Gc(+(E-N))|0;b[c+(z<<1)>>1]=Gc(+(L+F))|0;b[c+(R<<1)>>1]=Gc(+(F-L))|0;b[c+(P<<1)>>1]=Gc(+(I+W))|0;b[c+(G<<1)>>1]=Gc(+(W-I))|0;b[c+(J<<1)>>1]=Gc(+(O-M))|0;b[c+(U<<1)>>1]=Gc(+(O+M))|0}else{U=Gc(+(N+E))|0;if(U>>>0>255>>>0){ha=-U>>31&255}else{ha=U&255}a[f+y|0]=ha;U=Gc(+(E-N))|0;if(U>>>0>255>>>0){ia=-U>>31&255}else{ia=U&255}a[f+(y+s)|0]=ia;U=Gc(+(L+F))|0;if(U>>>0>255>>>0){ja=-U>>31&255}else{ja=U&255}a[f+(y+h)|0]=ja;U=Gc(+(F-L))|0;if(U>>>0>255>>>0){ka=-U>>31&255}else{ka=U&255}a[f+(y+t)|0]=ka;U=Gc(+(I+W))|0;if(U>>>0>255>>>0){la=-U>>31&255}else{la=U&255}a[f+(y+u)|0]=la;U=Gc(+(W-I))|0;if(U>>>0>255>>>0){ma=-U>>31&255}else{ma=U&255}a[f+(y+v)|0]=ma;U=Gc(+(O-M))|0;if(U>>>0>255>>>0){na=-U>>31&255}else{na=U&255}a[f+(y+w)|0]=na;U=Gc(+(O+M))|0;if(U>>>0>255>>>0){oa=-U>>31&255}else{oa=U&255}a[f+(y+x)|0]=oa}y=y+j|0;}while((y|0)<(l|0));return}function Y8(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,h=0;e=i;i=i+256|0;f=e|0;h=0;do{g[f+(h<<2)>>2]=+(b[d+(h<<1)>>1]|0)*+g[561992+(h<<2)>>2];h=h+1|0;}while((h|0)<64);h=f|0;X8(d,h,0,0,1,8,0);X8(0,h,a,c,8,1,2);i=e;return}function Z8(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,h=0;e=i;i=i+256|0;f=e|0;h=0;do{g[f+(h<<2)>>2]=+(b[d+(h<<1)>>1]|0)*+g[561992+(h<<2)>>2];h=h+1|0;}while((h|0)<64);h=f|0;X8(d,h,0,0,1,8,0);X8(0,h,a,c,8,1,3);i=e;return}function _8(a){a=a|0;var b=0,d=0.0,e=0,f=0;b=1<<a;d=6.283185307179586/+(b|0);e=c[1237600+(a<<2)>>2]|0;a=(b|0)/4|0;if((b|0)<-3){return}else{f=0}do{g[e+(f<<2)>>2]=+T(d*+(f|0));f=f+1|0;}while((f|0)<=(a|0));if((b|0)<=7){return}f=(b|0)/2|0;b=1;do{g[e+(f-b<<2)>>2]=+g[e+(b<<2)>>2];b=b+1|0;}while((b|0)<(a|0));return}function $8(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0;do{if((d-2|0)>>>0>14>>>0){f=a+8|0}else{c[a>>2]=d;h=1<<d;i=WDb(h<<1)|0;j=a+8|0;c[j>>2]=i;if((i|0)==0){f=j;break}i=WDb(h<<3)|0;c[a+12>>2]=i;if((i|0)==0){f=j;break}c[a+4>>2]=e;c[a+56>>2]=0;c[a+32>>2]=354;c[a+36>>2]=408;c[a+40>>2]=946;c[a+44>>2]=436;c[a+48>>2]=862;c[a+52>>2]=862;if((d|0)>=4){i=4;do{k=1<<i;l=6.283185307179586/+(k|0);m=c[1237600+(i<<2)>>2]|0;n=(k|0)/4|0;do{if(!((k|0)<-3)){o=0;do{g[m+(o<<2)>>2]=+T(l*+(o|0));o=o+1|0;}while((o|0)<=(n|0));if((k|0)<=7){break}o=(k|0)/2|0;p=1;do{g[m+(o-p<<2)>>2]=+g[m+(p<<2)>>2];p=p+1|0;}while((p|0)<(n|0))}}while(0);i=i+1|0;}while((i|0)<=(d|0))}if((h|0)<=0){q=0;return q|0}i=h-1|0;n=c[j>>2]|0;m=0;while(1){b[n+((i&-(c9(m,h,e)|0))<<1)>>1]=m;k=m+1|0;if((k|0)<(h|0)){m=k}else{q=0;break}}return q|0}}while(0);$Db(f);$Db(a+12|0);q=-1;return q|0}function a9(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[a+8>>2]|0;f=1<<c[a>>2];g=a+12|0;if((f|0)>0){h=0}else{i=b;j=c[g>>2]|0;k=j;l=f<<3;UGb(i|0,k|0,l)|0;return}do{a=b+(h<<3)|0;m=(c[g>>2]|0)+((e[d+(h<<1)>>1]|0)<<3)|0;n=c[a+4>>2]|0;c[m>>2]=c[a>>2];c[m+4>>2]=n;h=h+1|0;}while((h|0)<(f|0));i=b;j=c[g>>2]|0;k=j;l=f<<3;UGb(i|0,k|0,l)|0;return}function b9(a,b){a=a|0;b=b|0;me[c[1075080+((c[a>>2]|0)-2<<2)>>2]&511](b);return}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if((b|0)<3){d=a&1;return d|0}e=b>>1;if((e&a|0)==0){return(c9(a,e,c)|0)<<1|0}e=b>>2;b=(c9(a,e,c)|0)<<2;if(((e&a|0)==0|0)==(c|0)){d=b|1;return d|0}else{d=b-1|0;return d|0}return 0}function d9(a){a=a|0;$Db(a+8|0);$Db(a+12|0);return}function e9(a){a=a|0;var b=0,c=0.0,d=0,e=0.0,f=0.0,h=0.0,i=0,j=0,k=0.0,l=0.0,m=0,n=0,o=0.0,p=0.0;b=a|0;c=+g[b>>2];d=a+8|0;e=+g[d>>2];f=c-e;h=c+e;i=a+24|0;e=+g[i>>2];j=a+16|0;c=+g[j>>2];k=e-c;l=e+c;g[j>>2]=h-l;g[b>>2]=h+l;b=a+4|0;l=+g[b>>2];j=a+12|0;h=+g[j>>2];c=l-h;e=l+h;m=a+20|0;h=+g[m>>2];n=a+28|0;l=+g[n>>2];o=h-l;p=h+l;g[n>>2]=c-k;g[j>>2]=k+c;g[i>>2]=f-o;g[d>>2]=f+o;g[m>>2]=e-p;g[b>>2]=e+p;return}function f9(a){a=a|0;var b=0,c=0.0,d=0,e=0.0,f=0.0,h=0.0,i=0,j=0,k=0.0,l=0.0,m=0,n=0,o=0.0,p=0.0,q=0,r=0,s=0.0,t=0.0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0.0,B=0.0,C=0,D=0,E=0.0,F=0,G=0.0,H=0,I=0.0,J=0.0,K=0.0,L=0.0;b=a|0;c=+g[b>>2];d=a+8|0;e=+g[d>>2];f=c-e;h=c+e;i=a+24|0;e=+g[i>>2];j=a+16|0;c=+g[j>>2];k=e-c;l=e+c;c=h-l;e=h+l;m=a+4|0;l=+g[m>>2];n=a+12|0;h=+g[n>>2];o=l-h;p=l+h;q=a+20|0;h=+g[q>>2];r=a+28|0;l=+g[r>>2];s=h-l;t=h+l;l=o-k;h=k+o;o=f-s;k=f+s;s=p-t;f=p+t;u=a+32|0;t=+g[u>>2];v=a+40|0;p=+g[v>>2];w=t+p;x=t-p;y=a+36|0;p=+g[y>>2];z=a+44|0;t=+g[z>>2];A=p+t;B=p-t;C=a+48|0;t=+g[C>>2];D=a+56|0;p=+g[D>>2];E=t+p;F=a+52|0;G=+g[F>>2];H=a+60|0;I=+g[H>>2];J=G+I;K=E-w;L=w+E;g[u>>2]=e-L;g[b>>2]=L+e;g[F>>2]=s-K;g[q>>2]=K+s;s=A-J;K=A+J;g[C>>2]=c-s;g[j>>2]=s+c;g[y>>2]=f-K;g[m>>2]=f+K;K=x*.7071067690849304-B*-.7071067690849304;f=x*-.7071067690849304+B*.7071067690849304;B=(t-p)*.7071067690849304;p=(G-I)*.7071067690849304;I=B-p;G=B+p;p=I-K;B=K+I;g[v>>2]=k-B;g[d>>2]=k+B;g[H>>2]=l-p;g[r>>2]=p+l;l=f-G;p=f+G;g[D>>2]=o-l;g[i>>2]=o+l;g[z>>2]=h-p;g[n>>2]=h+p;return}function g9(a){a=a|0;var b=0.0,c=0.0,d=0,e=0.0,f=0,h=0.0,i=0.0,j=0.0,k=0,l=0,m=0.0,n=0.0,o=0,p=0,q=0.0,r=0.0,s=0,t=0,u=0.0,v=0.0,w=0,x=0,y=0.0,z=0.0,A=0,B=0,C=0.0,D=0.0,E=0,F=0,G=0.0,H=0.0,I=0.0,J=0,K=0,L=0.0,M=0.0,N=0,O=0,P=0.0,Q=0,R=0.0,S=0,T=0.0,U=0.0,V=0.0;b=+g[1987245];c=+g[1987247];f9(a);d=a+64|0;e=+g[d>>2];f=a+72|0;h=+g[f>>2];i=e-h;j=e+h;k=a+88|0;h=+g[k>>2];l=a+80|0;e=+g[l>>2];m=h-e;n=h+e;e=j-n;h=j+n;o=a+68|0;n=+g[o>>2];p=a+76|0;j=+g[p>>2];q=n-j;r=n+j;s=a+84|0;j=+g[s>>2];t=a+92|0;n=+g[t>>2];u=j-n;v=j+n;n=q-m;j=m+q;q=i-u;m=i+u;u=r-v;i=r+v;w=a+96|0;v=+g[w>>2];x=a+104|0;r=+g[x>>2];y=v-r;z=v+r;A=a+120|0;r=+g[A>>2];B=a+112|0;v=+g[B>>2];C=r-v;D=r+v;v=z+D;E=a+100|0;r=+g[E>>2];F=a+108|0;G=+g[F>>2];H=r-G;I=r+G;J=a+116|0;G=+g[J>>2];K=a+124|0;r=+g[K>>2];L=G-r;M=G+r;r=H-C;G=C+H;H=y-L;C=y+L;L=I+M;N=a|0;y=+g[N>>2];O=a+4|0;P=+g[O>>2];Q=a+32|0;R=+g[Q>>2];S=a+36|0;T=+g[S>>2];U=v-h;V=h+v;g[d>>2]=y-V;g[N>>2]=y+V;g[E>>2]=T-U;g[S>>2]=U+T;T=i-L;U=i+L;g[w>>2]=R-T;g[Q>>2]=T+R;g[o>>2]=P-U;g[O>>2]=U+P;P=e*.7071067690849304-u*-.7071067690849304;U=e*-.7071067690849304+u*.7071067690849304;u=(z-D)*.7071067690849304;D=(I-M)*.7071067690849304;M=u-D;I=u+D;O=a+16|0;D=+g[O>>2];o=a+20|0;u=+g[o>>2];Q=a+48|0;z=+g[Q>>2];w=a+52|0;e=+g[w>>2];R=M-P;T=P+M;g[l>>2]=D-T;g[O>>2]=D+T;g[J>>2]=e-R;g[w>>2]=R+e;e=U-I;R=U+I;g[B>>2]=z-e;g[Q>>2]=z+e;g[s>>2]=u-R;g[o>>2]=u+R;R=-0.0-c;u=b*m-j*R;e=m*R+b*j;j=b*C-c*G;R=c*C+b*G;o=a+8|0;G=+g[o>>2];s=a+12|0;C=+g[s>>2];Q=a+40|0;m=+g[Q>>2];B=a+44|0;z=+g[B>>2];I=j-u;U=u+j;g[f>>2]=G-U;g[o>>2]=G+U;g[F>>2]=z-I;g[B>>2]=I+z;z=e-R;I=e+R;g[x>>2]=m-z;g[Q>>2]=m+z;g[p>>2]=C-I;g[s>>2]=C+I;I=-0.0-b;C=c*q-n*I;z=q*I+c*n;n=c*H-b*r;I=b*H+c*r;s=a+24|0;r=+g[s>>2];p=a+28|0;c=+g[p>>2];Q=a+56|0;H=+g[Q>>2];x=a+60|0;b=+g[x>>2];q=n-C;m=C+n;g[k>>2]=r-m;g[s>>2]=r+m;g[K>>2]=b-q;g[x>>2]=q+b;b=z-I;q=z+I;g[A>>2]=H-b;g[Q>>2]=H+b;g[t>>2]=c-q;g[p>>2]=c+q;return}function h9(a){a=a|0;g9(a);f9(a+128|0);f9(a+192|0);u9(a,7892832,4);return}function i9(a){a=a|0;g9(a);f9(a+128|0);f9(a+192|0);u9(a,7892832,4);g9(a+256|0);g9(a+384|0);u9(a,7780544,8);return}function j9(a){a=a|0;var b=0;g9(a);f9(a+128|0);f9(a+192|0);u9(a,7892832,4);g9(a+256|0);g9(a+384|0);u9(a,7780544,8);b=a+512|0;g9(b);f9(a+640|0);f9(a+704|0);u9(b,7892832,4);b=a+768|0;g9(b);f9(a+896|0);f9(a+960|0);u9(b,7892832,4);u9(a,7949136,16);return}function k9(a){a=a|0;var b=0;j9(a);b=a+1024|0;g9(b);f9(a+1152|0);f9(a+1216|0);u9(b,7892832,4);g9(a+1280|0);g9(a+1408|0);u9(b,7780544,8);b=a+1536|0;g9(b);f9(a+1664|0);f9(a+1728|0);u9(b,7892832,4);g9(a+1792|0);g9(a+1920|0);u9(b,7780544,8);u9(a,7893152,32);return}function l9(a){a=a|0;k9(a);j9(a+2048|0);j9(a+3072|0);u9(a,7781184,64);return}function m9(a){a=a|0;k9(a);j9(a+2048|0);j9(a+3072|0);u9(a,7781184,64);k9(a+4096|0);k9(a+6144|0);t9(a,7950416,128);return}function n9(a){a=a|0;var b=0;k9(a);j9(a+2048|0);j9(a+3072|0);u9(a,7781184,64);k9(a+4096|0);k9(a+6144|0);t9(a,7950416,128);b=a+8192|0;k9(b);j9(a+10240|0);j9(a+11264|0);u9(b,7781184,64);b=a+12288|0;k9(b);j9(a+14336|0);j9(a+15360|0);u9(b,7781184,64);t9(a,7895712,256);return}function o9(a){a=a|0;var b=0;n9(a);b=a+16384|0;k9(b);j9(a+18432|0);j9(a+19456|0);u9(b,7781184,64);k9(a+20480|0);k9(a+22528|0);t9(b,7950416,128);b=a+24576|0;k9(b);j9(a+26624|0);j9(a+27648|0);u9(b,7781184,64);k9(a+28672|0);k9(a+30720|0);t9(b,7950416,128);t9(a,7786304,512);return}function p9(a){a=a|0;o9(a);n9(a+32768|0);n9(a+49152|0);t9(a,7567488,1024);return}function q9(a){a=a|0;o9(a);n9(a+32768|0);n9(a+49152|0);t9(a,7567488,1024);o9(a+65536|0);o9(a+98304|0);t9(a,7916208,2048);return}function r9(a){a=a|0;var b=0;o9(a);n9(a+32768|0);n9(a+49152|0);t9(a,7567488,1024);o9(a+65536|0);o9(a+98304|0);t9(a,7916208,2048);b=a+131072|0;o9(b);n9(a+163840|0);n9(a+180224|0);t9(b,7567488,1024);b=a+196608|0;o9(b);n9(a+229376|0);n9(a+245760|0);t9(b,7567488,1024);t9(a,7827296,4096);return}function s9(a){a=a|0;var b=0;r9(a);b=a+262144|0;o9(b);n9(a+294912|0);n9(a+311296|0);t9(b,7567488,1024);o9(a+327680|0);o9(a+360448|0);t9(b,7916208,2048);b=a+393216|0;o9(b);n9(a+425984|0);n9(a+442368|0);t9(b,7567488,1024);o9(a+458752|0);o9(a+491520|0);t9(b,7916208,2048);t9(a,7649408,8192);return}function t9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0.0,j=0,k=0.0,l=0,m=0.0,n=0,o=0.0,p=0,q=0.0,r=0,s=0.0,t=0,u=0.0,v=0,w=0.0,x=0.0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=c<<1;e=c<<2;f=c*6|0;h=a+(e<<3)|0;i=+g[h>>2];j=a+(e<<3)+4|0;k=+g[j>>2];l=a+(f<<3)|0;m=+g[l>>2];n=a+(f<<3)+4|0;o=+g[n>>2];p=a|0;q=+g[p>>2];r=a+4|0;s=+g[r>>2];t=a+(d<<3)|0;u=+g[t>>2];v=a+(d<<3)+4|0;w=+g[v>>2];x=m-i;y=i+m;g[h>>2]=q-y;g[p>>2]=y+q;g[n>>2]=w-x;g[v>>2]=x+w;w=k-o;x=k+o;g[l>>2]=u-w;g[t>>2]=w+u;g[j>>2]=s-x;g[r>>2]=x+s;r=e|1;j=a+(r<<3)|0;s=+g[j>>2];x=+g[b+4>>2];t=a+(r<<3)+4|0;u=+g[t>>2];w=+g[b+(d-1<<2)>>2];o=-0.0-w;k=s*x-u*o;q=x*u+s*o;r=f|1;l=a+(r<<3)|0;o=+g[l>>2];v=a+(r<<3)+4|0;s=+g[v>>2];u=x*o-w*s;y=w*o+x*s;n=a+8|0;s=+g[n>>2];p=a+12|0;x=+g[p>>2];h=d|1;z=a+(h<<3)|0;o=+g[z>>2];A=a+(h<<3)+4|0;w=+g[A>>2];m=u-k;i=k+u;g[j>>2]=s-i;g[n>>2]=s+i;g[v>>2]=w-m;g[A>>2]=m+w;w=q-y;m=q+y;g[l>>2]=o-w;g[z>>2]=o+w;g[t>>2]=x-m;g[p>>2]=x+m;p=e|2;t=f+2|0;f=d+2|0;z=e|3;e=r+2|0;r=h+2|0;h=a;a=b;l=c-1|0;c=b+(d<<2)|0;while(1){d=h+16|0;b=a+8|0;A=c-8|0;v=h+(p<<3)|0;m=+g[v>>2];x=+g[b>>2];n=h+(p<<3)+4|0;w=+g[n>>2];o=+g[A>>2];y=-0.0-o;q=m*x-w*y;i=x*w+m*y;j=h+(t<<3)|0;y=+g[j>>2];B=h+(t<<3)+4|0;m=+g[B>>2];w=x*y-o*m;s=o*y+x*m;C=d|0;m=+g[C>>2];D=h+20|0;x=+g[D>>2];E=h+(f<<3)|0;y=+g[E>>2];F=h+(f<<3)+4|0;o=+g[F>>2];u=w-q;k=q+w;g[v>>2]=m-k;g[C>>2]=m+k;g[B>>2]=o-u;g[F>>2]=u+o;o=i-s;u=i+s;g[j>>2]=y-o;g[E>>2]=y+o;g[n>>2]=x-u;g[D>>2]=x+u;D=h+(z<<3)|0;u=+g[D>>2];x=+g[a+12>>2];n=h+(z<<3)+4|0;o=+g[n>>2];y=+g[c-12>>2];s=-0.0-y;i=u*x-o*s;k=x*o+u*s;E=h+(e<<3)|0;s=+g[E>>2];j=h+(e<<3)+4|0;u=+g[j>>2];o=x*s-y*u;m=y*s+x*u;F=h+24|0;u=+g[F>>2];B=h+28|0;x=+g[B>>2];C=h+(r<<3)|0;s=+g[C>>2];v=h+(r<<3)+4|0;y=+g[v>>2];w=o-i;q=i+o;g[D>>2]=u-q;g[F>>2]=u+q;g[j>>2]=y-w;g[v>>2]=w+y;y=k-m;w=k+m;g[E>>2]=s-y;g[C>>2]=s+y;g[n>>2]=x-w;g[B>>2]=x+w;B=l-1|0;if((B|0)==0){break}else{h=d;a=b;l=B;c=A}}return}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0.0,j=0,k=0.0,l=0,m=0.0,n=0,o=0.0,p=0.0,q=0.0,r=0,s=0.0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c<<1;e=c<<2;f=c*6|0;h=a+(e<<3)|0;i=+g[h>>2];j=a+(e<<3)+4|0;k=+g[j>>2];l=a+(f<<3)|0;m=+g[l>>2];n=a+(f<<3)+4|0;o=+g[n>>2];p=m-i;q=i+m;r=a|0;g[h>>2]=+g[r>>2]-q;g[r>>2]=q+ +g[r>>2];r=a+(d<<3)+4|0;g[n>>2]=+g[r>>2]-p;g[r>>2]=p+ +g[r>>2];p=k-o;q=k+o;r=a+(d<<3)|0;g[l>>2]=+g[r>>2]-p;g[r>>2]=p+ +g[r>>2];r=a+4|0;g[j>>2]=+g[r>>2]-q;g[r>>2]=q+ +g[r>>2];r=e|1;j=a+(r<<3)|0;q=+g[j>>2];p=+g[b+4>>2];l=a+(r<<3)+4|0;o=+g[l>>2];k=+g[b+(d-1<<2)>>2];m=-0.0-k;i=q*p-o*m;s=p*o+q*m;r=f|1;n=a+(r<<3)|0;m=+g[n>>2];h=a+(r<<3)+4|0;q=+g[h>>2];o=p*m-k*q;t=k*m+p*q;q=o-i;p=i+o;u=a+8|0;g[j>>2]=+g[u>>2]-p;g[u>>2]=+g[u>>2]+p;u=d|1;j=a+(u<<3)+4|0;g[h>>2]=+g[j>>2]-q;g[j>>2]=q+ +g[j>>2];q=s-t;p=s+t;j=a+(u<<3)|0;g[n>>2]=+g[j>>2]-q;g[j>>2]=q+ +g[j>>2];j=a+12|0;g[l>>2]=+g[j>>2]-p;g[j>>2]=p+ +g[j>>2];j=e|2;l=f+2|0;f=d+2|0;n=e|3;e=r+2|0;r=u+2|0;u=b+(d<<2)|0;d=a;a=b;b=c-1|0;while(1){c=d+16|0;h=a+8|0;v=u-8|0;w=d+(j<<3)|0;p=+g[w>>2];q=+g[h>>2];x=d+(j<<3)+4|0;t=+g[x>>2];s=+g[v>>2];o=-0.0-s;i=p*q-t*o;m=q*t+p*o;y=d+(l<<3)|0;o=+g[y>>2];z=d+(l<<3)+4|0;p=+g[z>>2];t=q*o-s*p;k=s*o+q*p;p=t-i;q=i+t;A=c|0;g[w>>2]=+g[A>>2]-q;g[A>>2]=+g[A>>2]+q;A=d+(f<<3)+4|0;g[z>>2]=+g[A>>2]-p;g[A>>2]=p+ +g[A>>2];p=m-k;q=m+k;A=d+(f<<3)|0;g[y>>2]=+g[A>>2]-p;g[A>>2]=p+ +g[A>>2];A=d+20|0;g[x>>2]=+g[A>>2]-q;g[A>>2]=q+ +g[A>>2];A=d+(n<<3)|0;q=+g[A>>2];p=+g[a+12>>2];x=d+(n<<3)+4|0;k=+g[x>>2];m=+g[u-12>>2];t=-0.0-m;i=q*p-k*t;o=p*k+q*t;y=d+(e<<3)|0;t=+g[y>>2];z=d+(e<<3)+4|0;q=+g[z>>2];k=p*t-m*q;s=m*t+p*q;q=k-i;p=i+k;w=d+24|0;g[A>>2]=+g[w>>2]-p;g[w>>2]=+g[w>>2]+p;w=d+(r<<3)+4|0;g[z>>2]=+g[w>>2]-q;g[w>>2]=q+ +g[w>>2];q=o-s;p=o+s;w=d+(r<<3)|0;g[y>>2]=+g[w>>2]-q;g[w>>2]=q+ +g[w>>2];w=d+28|0;g[x>>2]=+g[w>>2]-p;g[w>>2]=p+ +g[w>>2];w=b-1|0;if((w|0)==0){break}else{u=v;d=c;a=h;b=w}}return}function v9(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+1056|0;f=e+32|0;g=c[b+60>>2]|0;h=g;j=Vkb(b)|0;if((j|0)<0){k=j;i=e;return k|0}a:do{if((c[b+96>>2]|0)!=0){j=e|0;l=g+8|0;m=l;TGb(f|0,-128|0,1024)|0;TGb(j|0,-128|0,32)|0;n=g+4|0;o=c[n>>2]|0;fUa(m,c[o+96>>2]|0,c[o+100>>2]|0);gUa(m,214748364,248);o=A9(m,j,0)|0;p=g+4720|0;c[p>>2]=o;if((o|0)<2){yDb(c[n>>2]|0,16,2165936,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;k=-1094995529;i=e;return k|0}if((o|0)>2){o=g+544|0;c[o>>2]=(c[o>>2]|0)-4;c[g+4724>>2]=A9(m,j,0)|0}o=A9(m,j,0)|0;c[(c[n>>2]|0)+568>>2]=o;r=g+4796|0;c[r>>2]=o;if((o|0)>1){o=1;do{s=A9(m,j,1)|0;a[h+38196+o|0]=(d[h+280+o|0]|0)+s;o=o+1|0;}while((o|0)<256)}o=g+38488|0;c[o>>2]=A9(m,j,0)|0;s=A9(m,j,0)|0;c[(c[n>>2]|0)+796>>2]=s;s=g+12|0;t=c[s>>2]|0;u=d[j]|0;v=(ba(u,t)|0)>>8;w=t-v|0;c[s>>2]=w;t=l;x=c[t>>2]|0;do{if((x|0)<(w|0)){a[j]=a[h+24+u|0]|0;if((w|0)>=256){y=0;break}c[s>>2]=w<<8;z=x<<8;c[t>>2]=z;A=g+540|0;B=c[A>>2]|0;if(B>>>0<(c[g+544>>2]|0)>>>0){c[t>>2]=d[B]|0|z}c[A>>2]=B+1;y=0}else{B=x-w|0;c[t>>2]=B;a[j]=a[h+280+u|0]|0;c[s>>2]=v;if((v|0)>=256){y=1;break}c[s>>2]=v<<8;A=B<<8;c[t>>2]=A;B=g+540|0;z=c[B>>2]|0;if(z>>>0<(c[g+544>>2]|0)>>>0){c[t>>2]=d[z]|0|A}c[B>>2]=z+1;y=1}}while(0);v=g+4736|0;c[v>>2]=y;u=g+4740|0;c[u>>2]=A9(m,j,0)|0;w=g+4744|0;c[w>>2]=A9(m,j,0)|0;x=c[s>>2]|0;l=d[j]|0;z=(ba(l,x)|0)>>8;B=x-z|0;c[s>>2]=B;x=c[t>>2]|0;do{if((x|0)<(B|0)){a[j]=a[h+24+l|0]|0;if((B|0)>=256){C=0;break}c[s>>2]=B<<8;A=x<<8;c[t>>2]=A;D=g+540|0;E=c[D>>2]|0;if(E>>>0<(c[g+544>>2]|0)>>>0){c[t>>2]=d[E]|0|A}c[D>>2]=E+1;C=0}else{E=x-B|0;c[t>>2]=E;a[j]=a[h+280+l|0]|0;c[s>>2]=z;if((z|0)>=256){C=1;break}c[s>>2]=z<<8;D=E<<8;c[t>>2]=D;E=g+540|0;A=c[E>>2]|0;if(A>>>0<(c[g+544>>2]|0)>>>0){c[t>>2]=d[A]|0|D}c[E>>2]=A+1;C=1}}while(0);z=g+4748|0;c[z>>2]=C;if((c[v>>2]|0)==0){F=(c[p>>2]|0)<4?2:1}else{F=2}c[g+4792>>2]=F+C;l=g+40804|0;c[l>>2]=(A9(m,j,0)|0)+1;B=(A9(m,j,0)|0)+1|0;x=g+40800|0;c[x>>2]=B;A=c[l>>2]|0;do{if(!(A>>>0>(c[g+4728>>2]|0)>>>0|(A|0)==0)){if(B>>>0>(c[g+4732>>2]|0)>>>0|(B|0)==0){break}E=A9(m,j,0)|0;D=g+38524|0;c[D>>2]=E;if(E>>>0>8>>>0){k=-1094995529;i=e;return k|0}b:do{if((E|0)>0){G=0;while(1){H=B9(m,h+17684+(G*2560|0)|0)|0;c[h+38164+(G<<2)>>2]=H;if((H|0)<0){break}G=G+1|0;if((G|0)>=(c[D>>2]|0)){break b}}yDb(c[n>>2]|0,16,2201448,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;k=-1094995529;i=e;return k|0}}while(0);E=Zkb(h)|0;if((E|0)<0){k=E;i=e;return k|0}E=c[D>>2]|0;if((E|0)>0){G=g+540|0;H=g+544|0;I=0;J=a[j]|0;K=E;while(1){E=c[s>>2]|0;L=J&255;M=(ba(E,L)|0)>>8;N=E-M|0;c[s>>2]=N;E=c[t>>2]|0;do{if((E|0)<(N|0)){O=a[h+24+L|0]|0;a[j]=O;if((N|0)>=256){P=O;Q=K;break}c[s>>2]=N<<8;R=E<<8;c[t>>2]=R;S=c[G>>2]|0;if(S>>>0<(c[H>>2]|0)>>>0){c[t>>2]=d[S]|0|R}c[G>>2]=S+1;P=O;Q=K}else{O=E-N|0;c[t>>2]=O;S=a[h+280+L|0]|0;a[j]=S;c[s>>2]=M;if((M|0)<256){c[s>>2]=M<<8;R=O<<8;c[t>>2]=R;O=c[G>>2]|0;if(O>>>0<(c[H>>2]|0)>>>0){c[t>>2]=d[O]|0|R}c[G>>2]=O+1}O=h+38164+(I<<2)|0;if((c[O>>2]|0)<=0){P=S;Q=K;break}R=h+38452+(I<<2)|0;T=0;do{U=T-1|0;if((T|0)==0){V=0;do{W=(A9(m,f+(V<<5)|0,1)|0)+128&255;a[(c[R>>2]|0)+V|0]=W;V=V+1|0;}while((V|0)<32)}else{V=0;do{W=d[(c[R>>2]|0)+(U<<5)+V|0]|0;X=(A9(m,f+(V<<5)|0,1)|0)+W&255;a[(c[R>>2]|0)+(T<<5)+V|0]=X;V=V+1|0;}while((V|0)<32)}T=T+1|0;}while((T|0)<(c[O>>2]|0));P=S;Q=c[D>>2]|0}}while(0);M=I+1|0;if((M|0)<(Q|0)){I=M;J=P;K=Q}else{break}}}do{if((c[p>>2]|0)>2){c[g+38496>>2]=A9(m,j,0)|0;if((c[g+4724>>2]|0)>2){c[g+38500>>2]=A9(m,j,0)|0}if((c[p>>2]|0)<=2){break}K=tBb(3)|0;J=c[n>>2]|0;I=uBb(K,0,c[J+96>>2]|0,c[J+100>>2]|0)|0;if((I|0)==0){break}yDb(J,16,2152288,(q=i,i=i+8|0,c[q>>2]=I,q)|0);i=q;k=-1094995529;i=e;return k|0}}while(0);I=c[n>>2]|0;if((c[I+688>>2]&1|0)==0){break a}J=c[g+4724>>2]|0;K=c[r>>2]|0;G=c[o>>2]|0;H=c[I+796>>2]|0;M=c[v>>2]|0;L=c[u>>2]|0;N=c[w>>2]|0;E=c[z>>2]|0;O=c[l>>2]|0;T=c[x>>2]|0;R=c[D>>2]|0;V=c[g+38496>>2]|0;U=c[g+38500>>2]|0;yDb(I,48,2145344,(q=i,i=i+112|0,c[q>>2]=c[p>>2],c[q+8>>2]=J,c[q+16>>2]=K,c[q+24>>2]=G,c[q+32>>2]=H,c[q+40>>2]=M,c[q+48>>2]=L,c[q+56>>2]=N,c[q+64>>2]=E,c[q+72>>2]=O,c[q+80>>2]=T,c[q+88>>2]=R,c[q+96>>2]=V,c[q+104>>2]=U,q)|0);i=q;break a}}while(0);yDb(c[n>>2]|0,16,2159288,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;k=-1094995529;i=e;return k|0}}while(0);q=Ykb(h)|0;if((q|0)<0){k=q;i=e;return k|0}c[(c[b+64>>2]|0)+4>>2]=1;k=0;i=e;return k|0}function w9(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;j=i;i=i+80|0;k=j|0;l=j+48|0;m=j+64|0;n=c[g+24>>2]|0;o=c[g+28>>2]|0;p=c[b+60>>2]|0;q=p;r=p+39772|0;s=r;t=r;u=c[t>>2]|0;v=u+8|0;w=p+4772|0;x=w;y=w;if((c[y>>2]|0)!=0){U0a(b,x)}z=j+32|0;c[z>>2]=c[w>>2];c[z+4>>2]=c[w+4>>2];c[z+8>>2]=c[w+8>>2];A=p+4760|0;B=A;c[w>>2]=c[A>>2];c[w+4>>2]=c[A+4>>2];c[w+8>>2]=c[A+8>>2];c[A>>2]=c[z>>2];c[A+4>>2]=c[z+4>>2];c[A+8>>2]=c[z+8>>2];z=A;A=c[z>>2]|0;w=p+4788|0;c[w>>2]=A;C=p+4720|0;do{if((c[C>>2]|0)<3){D=c[b+408>>2]|0;if(!(D>>>0>1>>>0)){break}c[A+296>>2]=1;if(!((D|0)==2|(D|0)==4)){break}c[A+300>>2]=1}}while(0);D=p+4|0;c[D>>2]=b;fUa(v,n,o);gUa(v,214748364,248);c[A+88>>2]=1;E=u+12|0;G=c[E>>2]|0;H=G>>1;I=G-H|0;c[E>>2]=I;G=v|0;v=c[G>>2]|0;do{if((v|0)<(I|0)){if((I|0)<256){c[E>>2]=I<<8;J=v<<8;c[G>>2]=J;K=u+540|0;L=c[K>>2]|0;if(L>>>0<(c[u+544>>2]|0)>>>0){c[G>>2]=d[L]|0|J}c[K>>2]=L+1}if((c[p+38508>>2]|0)!=0){c[A+84>>2]=0;break}yDb(b,16,2189168,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}else{L=v-I|0;c[G>>2]=L;c[E>>2]=H;if((H|0)<256){c[E>>2]=H<<8;K=L<<8;c[G>>2]=K;L=u+540|0;J=c[L>>2]|0;if(J>>>0<(c[u+544>>2]|0)>>>0){c[G>>2]=d[J]|0|K}c[L>>2]=J+1}c[A+84>>2]=1;J=p+38508|0;c[J>>2]=0;L=k|0;K=c[t>>2]|0;O=K+8|0;TGb(L|0,-128|0,32)|0;if((c[C>>2]|0)<2){P=A9(O,L,0)|0;if(P>>>0>1>>>0){yDb(c[D>>2]|0,16,2258584,(M=i,i=i+8|0,c[M>>2]=P,M)|0);i=M;N=-1094995529;i=j;return N|0}c[C>>2]=P;P=A9(O,L,0)|0;c[(c[D>>2]|0)+568>>2]=P;c[p+4796>>2]=P;if((P|0)>1){P=1;do{Q=A9(O,L,1)|0;a[q+38196+P|0]=(d[K+280+P|0]|0)+Q;P=P+1|0;}while((P|0)<256)}P=A9(O,L,0)|0;if((c[C>>2]|0)>0){R=A9(O,L,0)|0}else{R=c[(c[D>>2]|0)+796>>2]|0}Q=K+12|0;S=c[Q>>2]|0;T=d[L]|0;U=(ba(T,S)|0)>>8;V=S-U|0;c[Q>>2]=V;S=O|0;W=c[S>>2]|0;do{if((W|0)<(V|0)){a[L]=a[K+24+T|0]|0;if((V|0)>=256){X=0;break}c[Q>>2]=V<<8;Y=W<<8;c[S>>2]=Y;Z=K+540|0;_=c[Z>>2]|0;if(_>>>0<(c[K+544>>2]|0)>>>0){c[S>>2]=d[_]|0|Y}c[Z>>2]=_+1;X=0}else{_=W-V|0;c[S>>2]=_;a[L]=a[K+280+T|0]|0;c[Q>>2]=U;if((U|0)>=256){X=1;break}c[Q>>2]=U<<8;Z=_<<8;c[S>>2]=Z;_=K+540|0;Y=c[_>>2]|0;if(Y>>>0<(c[K+544>>2]|0)>>>0){c[S>>2]=d[Y]|0|Z}c[_>>2]=Y+1;X=1}}while(0);U=A9(O,L,0)|0;T=A9(O,L,0)|0;V=c[Q>>2]|0;W=d[L]|0;Y=(ba(W,V)|0)>>8;_=V-Y|0;c[Q>>2]=_;V=c[S>>2]|0;do{if((V|0)<(_|0)){a[L]=a[K+24+W|0]|0;if((_|0)>=256){$=0;break}c[Q>>2]=_<<8;Z=V<<8;c[S>>2]=Z;aa=K+540|0;ca=c[aa>>2]|0;if(ca>>>0<(c[K+544>>2]|0)>>>0){c[S>>2]=d[ca]|0|Z}c[aa>>2]=ca+1;$=0}else{ca=V-_|0;c[S>>2]=ca;a[L]=a[K+280+W|0]|0;c[Q>>2]=Y;if((Y|0)>=256){$=1;break}c[Q>>2]=Y<<8;aa=ca<<8;c[S>>2]=aa;ca=K+540|0;Z=c[ca>>2]|0;if(Z>>>0<(c[K+544>>2]|0)>>>0){c[S>>2]=d[Z]|0|aa}c[ca>>2]=Z+1;$=1}}while(0);S=p+4792|0;a:do{if((c[S>>2]|0)==0){da=c[D>>2]|0;ea=p+38488|0;fa=p+4736|0;ga=p+4740|0;ha=p+4744|0;ia=p+4748|0}else{Y=p+38488|0;Q=c[D>>2]|0;do{if((P|0)==(c[Y>>2]|0)){if((R|0)!=(c[Q+796>>2]|0)){break}W=p+4736|0;if((X|0)!=(c[W>>2]|0)){break}_=p+4740|0;if((U|0)!=(c[_>>2]|0)){break}V=p+4744|0;if((T|0)!=(c[V>>2]|0)){break}Z=p+4748|0;if(($|0)==(c[Z>>2]|0)){da=Q;ea=Y;fa=W;ga=_;ha=V;ia=Z;break a}}}while(0);yDb(Q,16,2244232,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}}while(0);c[ea>>2]=P;c[da+796>>2]=R;c[fa>>2]=X;c[ga>>2]=U;c[ha>>2]=T;c[ia>>2]=$;c[S>>2]=$|2;ja=ea}else{ja=p+38488|0}Y=c[ja>>2]|0;b:do{if((Y|0)==0){Z=c[D>>2]|0;V=p+4748|0;if((c[Z+944>>2]|0)==0){if((c[V>>2]|0)==0){ka=57}else{la=0}}else{c[V>>2]=0;ka=57}do{if((ka|0)==57){if((c[p+4736>>2]|0)!=0){la=1;break}V=Z+140|0;if((c[Z+796>>2]|0)<9){c[V>>2]=8;ma=Z;break b}else{c[V>>2]=32;ma=Z;break b}}}while(0);Q=c[Z+796>>2]|0;if((Q|0)<9){V=(c[p+4740>>2]<<4)+(c[p+4744>>2]|0)|0;if(!la){if((V|0)==0){c[Z+140>>2]=299;ma=Z;break}else if((V|0)==16){c[Z+140>>2]=300;ma=Z;break}else if((V|0)==17){c[Z+140>>2]=35;ma=Z;break}else{ma=Z;break}}switch(V|0){case 0:{c[Z+140>>2]=5;ma=Z;break b;break};case 1:{c[Z+140>>2]=33;ma=Z;break b;break};case 16:{c[Z+140>>2]=4;ma=Z;break b;break};case 17:{c[Z+140>>2]=0;ma=Z;break b;break};case 32:{c[Z+140>>2]=7;ma=Z;break b;break};case 34:{c[Z+140>>2]=6;ma=Z;break b;break};default:{ma=Z;break b}}}if((Q|0)==9){c[p+38516>>2]=1;V=(c[p+4740>>2]<<4)+(c[p+4744>>2]|0)|0;if(la){if((V|0)==0){c[Z+140>>2]=76;ma=Z;break}else if((V|0)==16){c[Z+140>>2]=80;ma=Z;break}else if((V|0)==17){c[Z+140>>2]=70;ma=Z;break}else{ma=Z;break}}else{if((V|0)==0){c[Z+140>>2]=96;ma=Z;break}else if((V|0)==16){c[Z+140>>2]=94;ma=Z;break}else if((V|0)==17){c[Z+140>>2]=92;ma=Z;break}else{ma=Z;break}}}else if((Q|0)==10){c[p+38516>>2]=1;V=(c[p+4740>>2]<<4)+(c[p+4744>>2]|0)|0;if(la){if((V|0)==0){c[Z+140>>2]=78;ma=Z;break}else if((V|0)==16){c[Z+140>>2]=74;ma=Z;break}else if((V|0)==17){c[Z+140>>2]=72;ma=Z;break}else{ma=Z;break}}else{if((V|0)==0){c[Z+140>>2]=102;ma=Z;break}else if((V|0)==16){c[Z+140>>2]=100;ma=Z;break}else if((V|0)==17){c[Z+140>>2]=98;ma=Z;break}else{ma=Z;break}}}else if((Q|0)==16){Q=(c[p+4740>>2]<<4)+(c[p+4744>>2]|0)|0;if(la){if((Q|0)==0){c[Z+140>>2]=58;ma=Z;break}else if((Q|0)==16){c[Z+140>>2]=56;ma=Z;break}else if((Q|0)==17){c[Z+140>>2]=54;ma=Z;break}else{ma=Z;break}}else{if((Q|0)==0){c[Z+140>>2]=108;ma=Z;break}else if((Q|0)==16){c[Z+140>>2]=106;ma=Z;break}else if((Q|0)==17){c[Z+140>>2]=104;ma=Z;break}else{ma=Z;break}}}else{ma=Z;break}}else if((Y|0)==1){do{if((c[p+4740>>2]|0)==0){if((c[p+4744>>2]|0)!=0){break}Q=c[D>>2]|0;V=c[Q+796>>2]|0;if((V|0)==9){c[Q+140>>2]=84;ma=Q;break b}else if((V|0)==10){c[Q+140>>2]=86;ma=Q;break b}else if((V|0)==12){c[Q+140>>2]=314;ma=Q;break b}else if((V|0)==14){c[Q+140>>2]=316;ma=Q;break b}else{V=Q+140|0;if((c[p+4748>>2]|0)==0){c[V>>2]=298;ma=Q;break b}else{c[V>>2]=30;ma=Q;break b}}}}while(0);yDb(c[D>>2]|0,16,2231728,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-38;i=j;return N|0}else{yDb(c[D>>2]|0,16,2219536,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-38;i=j;return N|0}}while(0);if((c[ma+140>>2]|0)==-1){yDb(ma,16,2210240,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-38;i=j;return N|0}Y=c[C>>2]|0;c:do{if((Y|0)<2){S=B9(O,p+15124|0)|0;if((S|0)>=0){na=S;oa=c[p+40796>>2]|0;break}yDb(c[D>>2]|0,16,2201448,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}else{if((Y|0)<3){S=A9(O,L,0)|0;c[p+40796>>2]=S;na=-1;oa=S;break}S=c[K+544>>2]|0;T=p+40796|0;U=K+536|0;P=p+38496|0;c[T>>2]=0;Z=0;Q=S;while(1){S=Q-(c[U>>2]|0)|0;if((S|0)<=3){na=-1;oa=Z;break c}V=-((c[P>>2]|0)!=0|0)&5;_=-3-V|0;W=V+3+((d[Q+(_+1)|0]|0)<<8|(d[Q+_|0]|0)<<16|(d[Q+(_+2)|0]|0))|0;if((W|0)>(S|0)){na=-1;oa=Z;break c}S=Z+1|0;c[T>>2]=S;if((S|0)<256){Z=S;Q=Q+(-W|0)|0}else{na=-1;oa=S;break}}}}while(0);K=p+40796|0;if(oa>>>0>256>>>0|(oa|0)<1){yDb(c[D>>2]|0,16,2193088,(M=i,i=i+8|0,c[M>>2]=oa,M)|0);i=M;N=-1094995529;i=j;return N|0}d:do{if((oa|0)>0){Y=p+4796|0;Q=p+38516|0;Z=p+4728|0;T=p+4732|0;P=p+40804|0;U=p+40800|0;S=p+4792|0;W=p+38524|0;_=p+15124|0;V=na;ca=0;e:while(1){aa=c[q+39772+(ca<<2)>>2]|0;c[aa+4796>>2]=c[Y>>2];c[aa+38516>>2]=c[Q>>2];c[aa+38504>>2]=0;if((c[C>>2]|0)==2){pa=A9(O,L,0)|0;qa=aa+40816|0;c[qa>>2]=ba(c[Z>>2]|0,pa)|0;pa=A9(O,L,0)|0;ra=aa+40820|0;c[ra>>2]=ba(c[T>>2]|0,pa)|0;pa=(A9(O,L,0)|0)+1|0;sa=ba(pa,c[Z>>2]|0)|0;pa=aa+40808|0;c[pa>>2]=sa+(c[qa>>2]|0);sa=(A9(O,L,0)|0)+1|0;ta=ba(sa,c[T>>2]|0)|0;sa=c[ra>>2]|0;ua=ta+sa|0;ta=aa+40812|0;c[ta>>2]=ua;va=(c[qa>>2]|0)/(c[P>>2]|0)|0;c[qa>>2]=va;qa=(sa|0)/(c[U>>2]|0)|0;c[ra>>2]=qa;ra=((c[pa>>2]|0)/(c[P>>2]|0)|0)-va|0;c[pa>>2]=ra;pa=((ua|0)/(c[U>>2]|0)|0)-qa|0;c[ta>>2]=pa;ta=c[Z>>2]|0;if(ra>>>0>ta>>>0){N=-1094995529;ka=188;break}ua=c[T>>2]|0;if(pa>>>0>ua>>>0){N=-1094995529;ka=188;break}sa=YGb(ra,(ra|0)<0|0?-1:0,va,0)|0;va=F;ra=(ta|0)<0|0?-1:0;if(va>>>0>ra>>>0|va>>>0==ra>>>0&sa>>>0>ta>>>0){N=-1094995529;ka=188;break}ta=YGb(pa,(pa|0)<0|0?-1:0,qa,0)|0;qa=F;pa=(ua|0)<0|0?-1:0;if(qa>>>0>pa>>>0|qa>>>0==pa>>>0&ta>>>0>ua>>>0){N=-1094995529;ka=188;break}}if((c[S>>2]|0)>0){ua=V;ta=0;while(1){pa=aa+4804+(ta*2580|0)|0;if((c[C>>2]|0)==2){qa=A9(O,L,0)|0;if(qa>>>0>(c[W>>2]|0)>>>0){ka=138;break e}c[aa+4804+(ta*2580|0)+2560>>2]=qa;UGb(pa|0,q+17684+(qa*2560|0)|0,2560)|0;wa=c[q+38164+(qa<<2)>>2]|0}else{UGb(pa|0,_|0,2560)|0;wa=ua}if((c[C>>2]|0)<3){if(!((wa|0)>-1)){ka=143;break e}pa=aa+4804+(ta*2580|0)+2564|0;if((c[pa>>2]|0)<(wa|0)){$Db(aa+4804+(ta*2580|0)+2568|0);$Db(aa+4804+(ta*2580|0)+2572|0)}c[pa>>2]=wa}pa=ta+1|0;if((pa|0)<(c[S>>2]|0)){ua=wa;ta=pa}else{xa=wa;break}}}else{xa=V}ta=ca+1|0;if((ta|0)<(c[K>>2]|0)){V=xa;ca=ta}else{break d}}if((ka|0)==138){yDb(c[D>>2]|0,16,2290232,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}else if((ka|0)==143){yDb(0,0,2353472,(M=i,i=i+24|0,c[M>>2]=2176664,c[M+8>>2]=2308824,c[M+16>>2]=814,M)|0);i=M;Cd();return 0}else if((ka|0)==188){i=j;return N|0}}}while(0);c[J>>2]=1}}while(0);xa=W0a(b,B,1)|0;if((xa|0)<0){N=xa;i=j;return N|0}if((c[b+688>>2]&1|0)==0){ya=p+40796|0}else{xa=c[A+84>>2]|0;wa=c[p+4796>>2]|0;q=c[p+38496>>2]|0;na=p+40796|0;oa=c[na>>2]|0;ma=c[(c[D>>2]|0)+796>>2]|0;yDb(b,48,2112008,(M=i,i=i+48|0,c[M>>2]=c[C>>2],c[M+8>>2]=xa,c[M+16>>2]=wa,c[M+24>>2]=q,c[M+32>>2]=oa,c[M+40>>2]=ma,M)|0);i=M;ya=na}X0a(b);na=c[ya>>2]|0;if((na|0)>0){ma=p+38496|0;oa=u+536|0;u=g+8|0;q=g+16|0;g=b+888|0;wa=b+892|0;xa=n+o|0;n=na;while(1){la=n-1|0;za=c[s+(la<<2)>>2]|0;ja=c[ma>>2]|0;ea=-((ja|0)!=0|0)&5;$=ea+3|0;ia=(la|0)!=0;do{if(ia){ka=161}else{if((c[C>>2]|0)>2){ka=161;break}ha=c[oa>>2]|0;ga=xa;Aa=ga-ha|0;Ba=ha;Ca=ga}}while(0);if((ka|0)==161){ka=0;J=-3-ea|0;Aa=$+((d[xa+(J+1)|0]|0)<<8|(d[xa+J|0]|0)<<16|(d[xa+(J+2)|0]|0))|0;Ba=c[oa>>2]|0;Ca=xa}if((Ca-Ba|0)<(Aa|0)){ka=164;break}J=xa+(-Aa|0)|0;do{if((ja|0)!=0){ga=uBb(tBb(3)|0,0,J,Aa)|0;if((ga|0)==0){break}ha=c[u>>2]|0;X=c[u+4>>2]|0;do{if((ha|0)==0&(X|0)==(-2147483648|0)){fa=c[q>>2]|0;R=c[q+4>>2]|0;yDb(c[D>>2]|0,16,2007680,(M=i,i=i+8|0,c[M>>2]=ga,M)|0);i=M;if(!((fa|0)==0&(R|0)==(-2147483648|0))){Da=R;Ea=fa;ka=171;break}yDb(c[D>>2]|0,16,1916896,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M}else{yDb(c[D>>2]|0,16,2007680,(M=i,i=i+8|0,c[M>>2]=ga,M)|0);i=M;Da=X;Ea=ha;ka=171}}while(0);do{if((ka|0)==171){ka=0;ha=c[g>>2]|0;X=c[D>>2]|0;if((ha|0)==0){yDb(X,16,1941144,(M=i,i=i+16|0,c[M>>2]=Ea,c[M+8>>2]=Da,M)|0);i=M;break}else{yDb(X,16,1969688,(M=i,i=i+8|0,h[M>>3]=(+(Ea>>>0)+ +(Da|0)*4294967296.0)*(+(ha|0)/+(c[wa>>2]|0)),M)|0);i=M;break}}}while(0);c[za+38504>>2]=1}}while(0);if(!ia){ka=176;break}fUa(za+8|0,J,Aa);c[za+4>>2]=b;c[za+4788>>2]=A;if((la|0)>0){xa=J;n=la}else{break}}if((ka|0)==164){yDb(b,16,2053432,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}else if((ka|0)==176){c[za+544>>2]=xa;c[za+4>>2]=b;c[za+4788>>2]=A}Fa=c[ya>>2]|0}else{Fa=na}oe[c[b+824>>2]&63](b,522,r,0,Fa,4)|0;Fa=c[ya>>2]|0;if((Fa|0)>0){ya=p+4740|0;r=p+4744|0;na=m|0;za=A+32|0;xa=l|0;ka=b+140|0;M=Fa;do{M=M-1|0;Fa=c[s+(M<<2)>>2]|0;do{if((c[Fa+38504>>2]|0)!=0){if((c[c[y>>2]>>2]|0)==0){break}Z0a(x,2147483647,0);n=c[Fa+40820>>2]|0;Aa=c[Fa+40816>>2]|0;c[na>>2]=(c[A>>2]|0)+((ba(n,c[za>>2]|0)|0)+Aa);wa=c[y>>2]|0;c[xa>>2]=(c[wa>>2]|0)+((ba(n,c[wa+32>>2]|0)|0)+Aa);wa=n>>c[r>>2];Da=Aa>>c[ya>>2];c[m+4>>2]=(c[A+4>>2]|0)+((ba(wa,c[A+36>>2]|0)|0)+Da);Ea=c[y>>2]|0;c[l+4>>2]=(c[Ea+4>>2]|0)+((ba(wa,c[Ea+36>>2]|0)|0)+Da);Da=n>>c[r>>2];Ea=Aa>>c[ya>>2];c[m+8>>2]=(c[A+8>>2]|0)+((ba(Da,c[A+40>>2]|0)|0)+Ea);wa=c[y>>2]|0;c[l+8>>2]=(c[wa+8>>2]|0)+((ba(Da,c[wa+40>>2]|0)|0)+Ea);c[m+12>>2]=(c[A+12>>2]|0)+((ba(n,c[A+44>>2]|0)|0)+Aa);Ea=c[y>>2]|0;c[l+12>>2]=(c[Ea+12>>2]|0)+((ba(n,c[Ea+44>>2]|0)|0)+Aa);jDb(na,za,xa,(c[y>>2]|0)+32|0,c[ka>>2]|0,c[Fa+40808>>2]|0,c[Fa+40812>>2]|0)}}while(0);}while((M|0)>0)}Y0a(B,2147483647,0);B=p+4756|0;c[B>>2]=(c[B>>2]|0)+1;if((c[y>>2]|0)!=0){U0a(b,x)}c[w>>2]=0;w=MCb(e,c[z>>2]|0)|0;if((w|0)<0){N=w;i=j;return N|0}c[f>>2]=1;N=o;i=j;return N|0}function x9(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0;h=i;i=i+64|0;j=h|0;k=h+32|0;l=c[g>>2]|0;g=l;m=l+4|0;n=c[(c[m>>2]|0)+60>>2]|0;o=(e[(bFb(c[f+140>>2]|0)|0)+8>>1]|0)>>>2&7;f=n+4788|0;p=c[f>>2]|0;q=n+39772|0;r=0;while(1){s=q+(r<<2)|0;if((g|0)==(c[s>>2]|0)){break}else{r=r+1|0}}q=n;t=o+1|0;o=n+4784|0;do{if((c[o>>2]|0)!=0){u=p+84|0;if((c[u>>2]|0)!=0){break}Z0a(n+4772|0,r,0);v=c[o>>2]|0;if((v|0)==0){break}if((c[u>>2]|0)!=0){break}u=c[v+39772+(r<<2)>>2]|0;v=c[s>>2]|0;w=v+38504|0;c[w>>2]=c[w>>2]|c[u+38504>>2];w=n+4792|0;if((c[w>>2]|0)<=0){break}x=u+4796|0;y=0;do{z=v+4804+(y*2580|0)+2568|0;ZDb(c[z>>2]|0);A=v+4804+(y*2580|0)+2572|0;ZDb(c[A>>2]|0);UGb(v+4804+(y*2580|0)|0,u+4804+(y*2580|0)|0,2580)|0;c[z>>2]=0;c[A>>2]=0;B=u+4804+(y*2580|0)+2564|0;C=c[B>>2]|0;if((c[x>>2]|0)==0){D=WDb(C*6|0)|0;c[A>>2]=D;UGb(D|0,c[u+4804+(y*2580|0)+2572>>2]|0,(c[B>>2]|0)*6|0)|0}else{D=WDb(C<<5)|0;c[z>>2]=D;UGb(D|0,c[u+4804+(y*2580|0)+2568>>2]|0,c[B>>2]<<5)|0}y=y+1|0;}while((y|0)<(c[w>>2]|0))}}while(0);s=l+40832|0;c[s>>2]=1;o=l+40836|0;c[o>>2]=1;w=n+4720|0;a:do{if((c[w>>2]|0)>2){if((Wkb(q,g)|0)<0){E=-12;i=h;return E|0}y=k|0;u=l+8|0;x=u;TGb(y|0,-128|0,32)|0;if((c[w>>2]|0)<=2){yDb(0,0,2353472,(G=i,i=i+24|0,c[G>>2]=2333392,c[G+8>>2]=2308824,c[G+16>>2]=286,G)|0);i=G;Cd();return 0}v=A9(x,y,0)|0;B=n+4728|0;D=l+40816|0;c[D>>2]=ba(c[B>>2]|0,v)|0;v=A9(x,y,0)|0;z=n+4732|0;C=l+40820|0;c[C>>2]=ba(c[z>>2]|0,v)|0;v=(A9(x,y,0)|0)+1|0;A=ba(v,c[B>>2]|0)|0;v=l+40808|0;c[v>>2]=A+(c[D>>2]|0);A=(A9(x,y,0)|0)+1|0;H=ba(A,c[z>>2]|0)|0;A=c[C>>2]|0;I=H+A|0;H=l+40812|0;c[H>>2]=I;J=n+40804|0;K=(c[D>>2]|0)/(c[J>>2]|0)|0;c[D>>2]=K;D=n+40800|0;L=(A|0)/(c[D>>2]|0)|0;c[C>>2]=L;C=((c[v>>2]|0)/(c[J>>2]|0)|0)-K|0;c[v>>2]=C;v=((I|0)/(c[D>>2]|0)|0)-L|0;c[H>>2]=v;H=c[B>>2]|0;b:do{if(!(C>>>0>H>>>0)){B=c[z>>2]|0;if(v>>>0>B>>>0){break}D=YGb(C,(C|0)<0|0?-1:0,K,0)|0;I=F;J=(H|0)<0|0?-1:0;if(I>>>0>J>>>0|I>>>0==J>>>0&D>>>0>H>>>0){break}D=YGb(v,(v|0)<0|0?-1:0,L,0)|0;J=F;I=(B|0)<0|0?-1:0;if(J>>>0>I>>>0|J>>>0==I>>>0&D>>>0>B>>>0){break}B=n+4792|0;D=(c[B>>2]|0)==0;I=A9(x,y,0)|0;c:do{if(D){M=I}else{J=n+38524|0;A=0;N=I;while(1){if(N>>>0>(c[J>>2]|0)>>>0){break}c[g+4804+(A*2580|0)+2560>>2]=N;UGb(g+4804+(A*2580|0)|0,q+17684+(N*2560|0)|0,2560)|0;O=c[q+38164+(N<<2)>>2]|0;P=g+4804+(A*2580|0)+2564|0;if((c[P>>2]|0)>>>0<O>>>0){$Db(g+4804+(A*2580|0)+2568|0);$Db(g+4804+(A*2580|0)+2572|0)}c[P>>2]=O;O=A+1|0;P=O>>>0<(c[B>>2]|0)>>>0;Q=A9(x,y,0)|0;if(P){A=O;N=Q}else{M=Q;break c}}yDb(c[n+4>>2]|0,16,2290232,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;break b}}while(0);if((M|0)==1){B=c[f>>2]|0;c[B+296>>2]=1;c[B+300>>2]=1}else if((M|0)==2){B=c[f>>2]|0;c[B+296>>2]=1;c[B+300>>2]=0}else if((M|0)==3){c[(c[f>>2]|0)+296>>2]=0}B=A9(x,y,0)|0;c[(c[f>>2]|0)+124>>2]=B;B=A9(x,y,0)|0;c[(c[f>>2]|0)+128>>2]=B;if((c[l+4720>>2]|0)<=3){break a}B=l+12|0;I=c[B>>2]|0;D=d[y]|0;N=(ba(D,I)|0)>>8;A=I-N|0;c[B>>2]=A;I=u;J=c[I>>2]|0;do{if((J|0)<(A|0)){a[y]=a[g+24+D|0]|0;if((A|0)>=256){R=0;break}c[B>>2]=A<<8;Q=J<<8;c[I>>2]=Q;O=l+540|0;P=c[O>>2]|0;if(P>>>0<(c[l+544>>2]|0)>>>0){c[I>>2]=d[P]|Q}c[O>>2]=P+1;R=0}else{P=J-A|0;c[I>>2]=P;a[y]=a[g+280+D|0]|0;c[B>>2]=N;if((N|0)>=256){R=1;break}c[B>>2]=N<<8;O=P<<8;c[I>>2]=O;P=l+540|0;Q=c[P>>2]|0;if(Q>>>0<(c[l+544>>2]|0)>>>0){c[I>>2]=d[Q]|O}c[P>>2]=Q+1;R=1}}while(0);c[l+40824>>2]=R;I=A9(x,y,0)|0;c[l+40828>>2]=I;if((I|0)==1){break a}c[s>>2]=A9(x,y,0)|0;I=A9(x,y,0)|0;c[o>>2]=I;N=c[s>>2]|0;B=YGb(N,(N|0)<0|0?-1:0,I,(I|0)<0|0?-1:0)|0;I=F;N=0;if(!(I>>>0>N>>>0|I>>>0==N>>>0&B>>>0>4>>>0)){break a}yDb(c[n+4>>2]|0,16,2274384,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G}}while(0);c[l+38504>>2]=1;E=-1094995529;i=h;return E|0}}while(0);R=Wkb(q,g)|0;if((R|0)<0){E=R;i=h;return E|0}if((c[(c[f>>2]|0)+84>>2]|0)==0){if((c[l+40824>>2]|0)!=0){S=49}}else{S=49}if((S|0)==49){_kb(q,g)}q=c[l+40808>>2]|0;f=c[l+40812>>2]|0;R=c[l+40816>>2]|0;M=c[l+40820>>2]|0;k=l+4796|0;if((c[k>>2]|0)==0){y=c[w>>2]|0;if((y|0)==3){if((c[n+4724>>2]|0)>1){S=54}}else{if((y|0)>3){S=54}}do{if((S|0)==54){y=l+12|0;x=c[y>>2]|0;u=(x*129|0)>>8;L=x-u|0;c[y>>2]=L;x=l+8|0;v=c[x>>2]|0;if((v|0)<(L|0)){if((L|0)>=256){break}c[y>>2]=L<<8;H=v<<8;c[x>>2]=H;K=l+540|0;C=c[K>>2]|0;if(C>>>0<(c[l+544>>2]|0)>>>0){c[x>>2]=d[C]|H}c[K>>2]=C+1;break}else{C=v-L|0;c[x>>2]=C;c[y>>2]=u;if((u|0)>=256){break}c[y>>2]=u<<8;u=C<<8;c[x>>2]=u;C=l+540|0;y=c[C>>2]|0;if(y>>>0<(c[l+544>>2]|0)>>>0){c[x>>2]=d[y]|u}c[C>>2]=y+1;break}}}while(0);do{if((c[w>>2]|0)>2){S=66}else{if((M|R|0)==0){S=66;break}T=0;U=c[l+536>>2]|0}}while(0);if((S|0)==66){S=c[l+536>>2]|0;T=(c[l+540>>2]|0)-1-S|0;U=S}c[l+4800>>2]=T;S=U+T|0;y=(c[l+544>>2]|0)-(U+T)<<3;T=y>>>0>2147483639>>>0|(S|0)==0;U=T?0:S;S=T?0:y;c[l+548>>2]=U;c[l+560>>2]=S;c[l+564>>2]=S+8;c[l+552>>2]=U+(S>>3);c[l+556>>2]=0}do{if((c[n+38488>>2]|0)==0){S=c[n+4740>>2]|0;U=-(-q>>S)|0;y=c[n+4744>>2]|0;T=-(-f>>y)|0;C=M>>y;y=ba(R,t)|0;u=c[p+32>>2]|0;y9(g,(c[p>>2]|0)+((ba(u,M)|0)+y)|0,q,f,u,0);if((c[n+4736>>2]|0)!=0){u=ba(R>>S,t)|0;S=c[p+36>>2]|0;y9(g,(c[p+4>>2]|0)+((ba(S,C)|0)+u)|0,U,T,S,1);S=c[p+40>>2]|0;y9(g,(c[p+8>>2]|0)+((ba(S,C)|0)+u)|0,U,T,S,1)}if((c[l+4748>>2]|0)==0){break}S=c[p+44>>2]|0;y9(g,(c[p+12>>2]|0)+((ba(S,M)|0)+y)|0,q,f,S,2)}else{S=c[p>>2]|0;y=ba(R,t)|0;T=p+32|0;U=(ba(c[T>>2]|0,M)|0)+y|0;u=c[p+4>>2]|0;C=p+36|0;x=c[C>>2]|0;L=c[p+8>>2]|0;v=p+40|0;K=c[v>>2]|0;H=c[(c[m>>2]|0)+796>>2]|0;z=(H|0)>0?H:8;B=c[l+38492>>2]|0;N=q+6|0;c[j>>2]=B+6;I=j+4|0;c[I>>2]=B+(q+9<<1);c[j+8>>2]=B+((N<<1)+3<<1);D=j+12|0;c[D>>2]=B+((N*3|0)+3<<1);c[j+16>>2]=B+((N<<2|3)<<1);A=j+20|0;c[A>>2]=B+((N*5|0)+3<<1);c[j+24>>2]=B+((N*6|0)+3<<1);J=j+28|0;c[J>>2]=B+((N*7|0)+3<<1);N=(H|0)<9;H=1<<z;Q=l+38484|0;c[Q>>2]=0;TGb(B|0,0,(q<<4)+96|0)|0;if((f|0)<=0){break}B=l+4748|0;P=(q|0)>0;O=l+40828|0;V=q-1|0;W=l+548|0;X=W;Y=l+556|0;Z=W;W=l+564|0;_=l+12|0;$=l+8|0;aa=l+540|0;ca=l+544|0;da=q<<1;ea=(ba(x,M)|0)+y|0;x=(ba(K,M)|0)+y|0;y=0;do{if(((c[B>>2]|0)+3|0)>0){K=0;do{fa=j+(K<<3)|0;ga=c[fa>>2]|0;ha=j+(K<<3)+4|0;ia=c[ha>>2]|0;c[fa>>2]=ia;c[ha>>2]=ga;ha=ga-2|0;b[ha>>1]=b[ia>>1]|0;b[ia+(q<<1)>>1]=b[ia+(V<<1)>>1]|0;fa=c[O>>2]|0;K=K+1|0;ja=(K|0)/2|0;d:do{if(N&(fa|0)==0){ka=c[Q>>2]|0;if(P){la=g+4804+(ja*2580|0)+1790|0;ma=g+4804+(ja*2580|0)+2572|0;na=g+4804+(ja*2580|0)+2568|0;oa=0;pa=0;qa=0;ra=ka;sa=b[ha>>1]|0;while(1){ta=ia+(oa<<1)|0;ua=oa+1|0;va=oa-1|0;wa=ia+(va<<1)|0;xa=b[wa>>1]|0;ya=b[ta>>1]|0;za=b[ia+(ua<<1)>>1]|0;Aa=sa<<16>>16;if((b[la>>1]|0)==0){Ba=(b[g+4804+(ja*2580|0)+512+((xa-ya&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+((Aa-xa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1024+((ya-za&255)<<1)>>1]|0)|0}else{Ba=(b[g+4804+(ja*2580|0)+512+((xa-ya&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+((Aa-xa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1024+((ya-za&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1536+(((e[ga+(oa-2<<1)>>1]|0)-Aa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+2048+(((e[ga+(oa<<1)>>1]|0)-ya&255)<<1)>>1]|0)|0}ya=(Ba|0)<0?-Ba|0:Ba;do{if((c[k>>2]|0)==0){Aa=(ya|qa|0)==0?1:qa;if((Aa|0)==0){Ca=z9(X,(c[ma>>2]|0)+(ya*6|0)|0,9)|0;Da=ra;Ea=0;Fa=pa;break}do{if((pa|0)==0&(Aa|0)==1){za=c[Y>>2]|0;xa=c[Z>>2]|0;Ga=d[xa+(za>>>3)|0]|0;Ha=c[W>>2]|0;Ia=((za|0)<(Ha|0))+za|0;c[Y>>2]=Ia;Ja=a[1192248+ra|0]|0;if((Ga&128>>>((za&7)>>>0)|0)!=0){za=1<<(Ja&255);Ka=((za+oa|0)<=(q|0))+ra|0;La=1;Ma=za;break}if(Ja<<24>>24==0){Na=0}else{za=Ja&255;Ja=xa+(Ia>>>3)|0;xa=(fe(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Ia&7)>>>((32-za|0)>>>0);Ja=Ia+za|0;c[Y>>2]=Ha>>>0>Ja>>>0?Ja:Ha;Na=xa}Ka=(ra|0)==0?0:ra-1|0;La=2;Ma=Na}else{Ka=ra;La=Aa;Ma=pa}}while(0);Aa=Ma-1|0;if((Aa|0)>=0){Ca=0;Da=Ka;Ea=La;Fa=Aa;break}Aa=z9(X,(c[ma>>2]|0)+(ya*6|0)|0,9)|0;Ca=(Aa>>>31^1)+Aa|0;Da=Ka;Ea=0;Fa=0}else{Aa=c[na>>2]|0;xa=Aa+(ya<<5)|0;Ha=c[_>>2]|0;Ja=(ba(d[xa]|0,Ha)|0)>>8;za=Ha-Ja|0;c[_>>2]=za;Ha=c[$>>2]|0;if((Ha|0)>=(za|0)){c[$>>2]=Ha-za;a[xa]=a[(d[xa]|0)+(g+280)|0]|0;c[_>>2]=Ja;if((Ja|0)>=256){Ca=0;Da=ra;Ea=qa;Fa=pa;break}c[_>>2]=Ja<<8;Ja=c[$>>2]<<8;c[$>>2]=Ja;za=c[aa>>2]|0;if(za>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[za]|Ja}c[aa>>2]=za+1;Ca=0;Da=ra;Ea=qa;Fa=pa;break}a[xa]=a[(d[xa]|0)+(g+24)|0]|0;xa=c[_>>2]|0;if((xa|0)<256){za=xa<<8;c[_>>2]=za;Ja=c[$>>2]<<8;c[$>>2]=Ja;Ha=c[aa>>2]|0;if(Ha>>>0<(c[ca>>2]|0)>>>0){Ia=d[Ha]|Ja;c[$>>2]=Ia;Oa=Ia}else{Oa=Ja}c[aa>>2]=Ha+1;Pa=za;Qa=Oa}else{Pa=xa;Qa=c[$>>2]|0}xa=Aa+(ya<<5)+1|0;za=(ba(d[xa]|0,Pa)|0)>>8;Ha=Pa-za|0;c[_>>2]=Ha;if((Qa|0)<(Ha|0)){Ra=0;Sa=xa}else{Ja=1;Ia=xa;xa=za;za=Ha;Ha=Qa;while(1){c[$>>2]=Ha-za;a[Ia]=a[(d[Ia]|0)+(g+280)|0]|0;c[_>>2]=xa;if((xa|0)<256){Ga=xa<<8;c[_>>2]=Ga;Ta=c[$>>2]<<8;c[$>>2]=Ta;Ua=c[aa>>2]|0;if(Ua>>>0<(c[ca>>2]|0)>>>0){Va=d[Ua]|Ta;c[$>>2]=Va;Wa=Va}else{Wa=Ta}c[aa>>2]=Ua+1;Xa=Ga;Ya=Wa}else{Xa=xa;Ya=c[$>>2]|0}Ga=Ja+1|0;Ua=((Ja|0)>9?10:Ga)+(Aa+(ya<<5))|0;Ta=(ba(d[Ua]|0,Xa)|0)>>8;Va=Xa-Ta|0;c[_>>2]=Va;if((Ya|0)<(Va|0)){Ra=Ja;Sa=Ua;break}else{Ja=Ga;Ia=Ua;xa=Ta;za=Va;Ha=Ya}}}a[Sa]=a[(d[Sa]|0)+(g+24)|0]|0;Ha=c[_>>2]|0;if((Ha|0)<256){za=Ha<<8;c[_>>2]=za;xa=c[$>>2]<<8;c[$>>2]=xa;Ia=c[aa>>2]|0;if(Ia>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[Ia]|xa}c[aa>>2]=Ia+1;Za=za}else{Za=Ha}e:do{if((Ra|0)>0){Ha=2;za=Ra;Ia=Za;while(1){xa=za-1|0;Ja=((xa|0)>9?31:za+21|0)+(Aa+(ya<<5))|0;Va=(ba(d[Ja]|0,Ia)|0)>>8;Ta=Ia-Va|0;c[_>>2]=Ta;Ua=c[$>>2]|0;do{if((Ua|0)<(Ta|0)){a[Ja]=a[(d[Ja]|0)+(g+24)|0]|0;Ga=c[_>>2]|0;if((Ga|0)>=256){_a=0;$a=Ga;break}ab=Ga<<8;c[_>>2]=ab;Ga=c[$>>2]<<8;c[$>>2]=Ga;bb=c[aa>>2]|0;if(bb>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[bb]|Ga}c[aa>>2]=bb+1;_a=0;$a=ab}else{c[$>>2]=Ua-Ta;a[Ja]=a[(d[Ja]|0)+(g+280)|0]|0;c[_>>2]=Va;if((Va|0)>=256){_a=1;$a=Va;break}ab=Va<<8;c[_>>2]=ab;bb=c[$>>2]<<8;c[$>>2]=bb;Ga=c[aa>>2]|0;if(Ga>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[Ga]|bb}c[aa>>2]=Ga+1;_a=1;$a=ab}}while(0);Va=_a|Ha;if((xa|0)<=0){cb=Va;db=$a;break e}Ha=Va<<1;za=xa;Ia=$a}}else{cb=1;db=Za}}while(0);Ia=((Ra|0)>10?21:Ra+11|0)+(Aa+(ya<<5))|0;za=(ba(d[Ia]|0,db)|0)>>8;Ha=db-za|0;c[_>>2]=Ha;Va=c[$>>2]|0;do{if((Va|0)<(Ha|0)){a[Ia]=a[(d[Ia]|0)+(g+24)|0]|0;Ja=c[_>>2]|0;if((Ja|0)>=256){eb=0;break}c[_>>2]=Ja<<8;Ja=c[$>>2]<<8;c[$>>2]=Ja;Ta=c[aa>>2]|0;if(Ta>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[Ta]|Ja}c[aa>>2]=Ta+1;eb=0}else{c[$>>2]=Va-Ha;a[Ia]=a[(d[Ia]|0)+(g+280)|0]|0;c[_>>2]=za;if((za|0)>=256){eb=1;break}c[_>>2]=za<<8;Ta=c[$>>2]<<8;c[$>>2]=Ta;Ja=c[aa>>2]|0;if(Ja>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[Ja]|Ta}c[aa>>2]=Ja+1;eb=1}}while(0);Ca=(cb^-eb)+eb|0;Da=ra;Ea=qa;Fa=pa}}while(0);ya=(Ba|0)>-1?Ca:-Ca|0;za=b[ta>>1]|0;Ia=b[ga+(va<<1)>>1]|0;Ha=za+Ia-(b[wa>>1]|0)|0;do{if((Ia|0)>(Ha|0)){if((za|0)<=(Ha|0)){fb=Ha;break}fb=(za|0)>(Ia|0)?Ia:za}else{if((Ha|0)<=(za|0)){fb=Ha;break}fb=(za|0)>(Ia|0)?za:Ia}}while(0);Ia=fb+ya&511;b[ga+(oa<<1)>>1]=Ia;if((ua|0)<(q|0)){oa=ua;pa=Fa;qa=Ea;ra=Da;sa=Ia}else{gb=Da;break}}}else{gb=ka}c[Q>>2]=gb}else{sa=((fa|0)!=1)+z|0;ra=c[Q>>2]|0;if((fa|0)==1){if(!P){break}if((sa|0)<=0){TGb(ga|0,0,da|0)|0;break}qa=0;pa=c[_>>2]|0;oa=c[$>>2]|0;while(1){na=1;ma=0;la=pa;Ia=oa;while(1){za=la>>1;Ha=la-za|0;c[_>>2]=Ha;do{if((Ia|0)<(Ha|0)){if((Ha|0)>=256){hb=0;ib=Ha;jb=Ia;break}wa=Ha<<8;c[_>>2]=wa;va=Ia<<8;c[$>>2]=va;ta=c[aa>>2]|0;if(ta>>>0<(c[ca>>2]|0)>>>0){Va=d[ta]|va;c[$>>2]=Va;kb=Va}else{kb=va}c[aa>>2]=ta+1;hb=0;ib=wa;jb=kb}else{wa=Ia-Ha|0;c[$>>2]=wa;c[_>>2]=za;if((za|0)>=256){hb=1;ib=za;jb=wa;break}ta=za<<8;c[_>>2]=ta;va=wa<<8;c[$>>2]=va;wa=c[aa>>2]|0;if(wa>>>0<(c[ca>>2]|0)>>>0){Va=d[wa]|va;c[$>>2]=Va;lb=Va}else{lb=va}c[aa>>2]=wa+1;hb=1;ib=ta;jb=lb}}while(0);mb=hb|ma;if((na|0)>=(sa|0)){break}na=na+1|0;ma=mb<<1;la=ib;Ia=jb}b[ga+(qa<<1)>>1]=mb;Ia=qa+1|0;if((Ia|0)<(q|0)){qa=Ia;pa=ib;oa=jb}else{break d}}}if(P){oa=g+4804+(ja*2580|0)+1790|0;pa=g+4804+(ja*2580|0)+2572|0;qa=(1<<sa)+65535|0;ka=g+4804+(ja*2580|0)+2568|0;Ia=0;la=0;ma=0;na=ra;ua=b[ha>>1]|0;while(1){ya=ia+(Ia<<1)|0;za=Ia+1|0;Ha=Ia-1|0;ta=ia+(Ha<<1)|0;wa=b[ta>>1]|0;va=b[ya>>1]|0;Va=b[ia+(za<<1)>>1]|0;Aa=ua<<16>>16;if((b[oa>>1]|0)==0){nb=(b[g+4804+(ja*2580|0)+512+((wa-va&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+((Aa-wa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1024+((va-Va&255)<<1)>>1]|0)|0}else{nb=(b[g+4804+(ja*2580|0)+512+((wa-va&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+((Aa-wa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1024+((va-Va&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1536+(((e[ga+(Ia-2<<1)>>1]|0)-Aa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+2048+(((e[ga+(Ia<<1)>>1]|0)-va&255)<<1)>>1]|0)|0}va=(nb|0)<0?-nb|0:nb;do{if((c[k>>2]|0)==0){Aa=(va|ma|0)==0?1:ma;if((Aa|0)==0){ob=z9(X,(c[pa>>2]|0)+(va*6|0)|0,sa)|0;pb=na;qb=0;rb=la;break}do{if((la|0)==0&(Aa|0)==1){Va=c[Y>>2]|0;wa=c[Z>>2]|0;Ja=d[wa+(Va>>>3)|0]|0;Ta=c[W>>2]|0;Ua=((Va|0)<(Ta|0))+Va|0;c[Y>>2]=Ua;ab=a[1192248+na|0]|0;if((Ja&128>>>((Va&7)>>>0)|0)!=0){Va=1<<(ab&255);sb=((Va+Ia|0)<=(q|0))+na|0;tb=1;ub=Va;break}if(ab<<24>>24==0){vb=0}else{Va=ab&255;ab=wa+(Ua>>>3)|0;wa=(fe(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(Ua&7)>>>((32-Va|0)>>>0);ab=Ua+Va|0;c[Y>>2]=Ta>>>0>ab>>>0?ab:Ta;vb=wa}sb=(na|0)==0?0:na-1|0;tb=2;ub=vb}else{sb=na;tb=Aa;ub=la}}while(0);Aa=ub-1|0;if((Aa|0)>=0){ob=0;pb=sb;qb=tb;rb=Aa;break}Aa=z9(X,(c[pa>>2]|0)+(va*6|0)|0,sa)|0;ob=(Aa>>>31^1)+Aa|0;pb=sb;qb=0;rb=0}else{Aa=c[ka>>2]|0;wa=Aa+(va<<5)|0;Ta=c[_>>2]|0;ab=(ba(d[wa]|0,Ta)|0)>>8;Va=Ta-ab|0;c[_>>2]=Va;Ta=c[$>>2]|0;if((Ta|0)>=(Va|0)){c[$>>2]=Ta-Va;a[wa]=a[(d[wa]|0)+(g+280)|0]|0;c[_>>2]=ab;if((ab|0)>=256){ob=0;pb=na;qb=ma;rb=la;break}c[_>>2]=ab<<8;ab=c[$>>2]<<8;c[$>>2]=ab;Va=c[aa>>2]|0;if(Va>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[Va]|ab}c[aa>>2]=Va+1;ob=0;pb=na;qb=ma;rb=la;break}a[wa]=a[(d[wa]|0)+(g+24)|0]|0;wa=c[_>>2]|0;if((wa|0)<256){Va=wa<<8;c[_>>2]=Va;ab=c[$>>2]<<8;c[$>>2]=ab;Ta=c[aa>>2]|0;if(Ta>>>0<(c[ca>>2]|0)>>>0){Ua=d[Ta]|ab;c[$>>2]=Ua;wb=Ua}else{wb=ab}c[aa>>2]=Ta+1;xb=Va;yb=wb}else{xb=wa;yb=c[$>>2]|0}wa=Aa+(va<<5)+1|0;Va=(ba(d[wa]|0,xb)|0)>>8;Ta=xb-Va|0;c[_>>2]=Ta;if((yb|0)<(Ta|0)){zb=0;Ab=wa}else{ab=1;Ua=wa;wa=Va;Va=Ta;Ta=yb;while(1){c[$>>2]=Ta-Va;a[Ua]=a[(d[Ua]|0)+(g+280)|0]|0;c[_>>2]=wa;if((wa|0)<256){Ja=wa<<8;c[_>>2]=Ja;Ga=c[$>>2]<<8;c[$>>2]=Ga;bb=c[aa>>2]|0;if(bb>>>0<(c[ca>>2]|0)>>>0){Bb=d[bb]|Ga;c[$>>2]=Bb;Cb=Bb}else{Cb=Ga}c[aa>>2]=bb+1;Db=Ja;Eb=Cb}else{Db=wa;Eb=c[$>>2]|0}Ja=ab+1|0;bb=((ab|0)>9?10:Ja)+(Aa+(va<<5))|0;Ga=(ba(d[bb]|0,Db)|0)>>8;Bb=Db-Ga|0;c[_>>2]=Bb;if((Eb|0)<(Bb|0)){zb=ab;Ab=bb;break}else{ab=Ja;Ua=bb;wa=Ga;Va=Bb;Ta=Eb}}}a[Ab]=a[(d[Ab]|0)+(g+24)|0]|0;Ta=c[_>>2]|0;if((Ta|0)<256){Va=Ta<<8;c[_>>2]=Va;wa=c[$>>2]<<8;c[$>>2]=wa;Ua=c[aa>>2]|0;if(Ua>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[Ua]|wa}c[aa>>2]=Ua+1;Fb=Va}else{Fb=Ta}f:do{if((zb|0)>0){Ta=2;Va=zb;Ua=Fb;while(1){wa=Va-1|0;ab=((wa|0)>9?31:Va+21|0)+(Aa+(va<<5))|0;Bb=(ba(d[ab]|0,Ua)|0)>>8;Ga=Ua-Bb|0;c[_>>2]=Ga;bb=c[$>>2]|0;do{if((bb|0)<(Ga|0)){a[ab]=a[(d[ab]|0)+(g+24)|0]|0;Ja=c[_>>2]|0;if((Ja|0)>=256){Gb=0;Hb=Ja;break}Ib=Ja<<8;c[_>>2]=Ib;Ja=c[$>>2]<<8;c[$>>2]=Ja;Jb=c[aa>>2]|0;if(Jb>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[Jb]|Ja}c[aa>>2]=Jb+1;Gb=0;Hb=Ib}else{c[$>>2]=bb-Ga;a[ab]=a[(d[ab]|0)+(g+280)|0]|0;c[_>>2]=Bb;if((Bb|0)>=256){Gb=1;Hb=Bb;break}Ib=Bb<<8;c[_>>2]=Ib;Jb=c[$>>2]<<8;c[$>>2]=Jb;Ja=c[aa>>2]|0;if(Ja>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[Ja]|Jb}c[aa>>2]=Ja+1;Gb=1;Hb=Ib}}while(0);Bb=Gb|Ta;if((wa|0)<=0){Kb=Bb;Lb=Hb;break f}Ta=Bb<<1;Va=wa;Ua=Hb}}else{Kb=1;Lb=Fb}}while(0);Ua=((zb|0)>10?21:zb+11|0)+(Aa+(va<<5))|0;Va=(ba(d[Ua]|0,Lb)|0)>>8;Ta=Lb-Va|0;c[_>>2]=Ta;Bb=c[$>>2]|0;do{if((Bb|0)<(Ta|0)){a[Ua]=a[(d[Ua]|0)+(g+24)|0]|0;ab=c[_>>2]|0;if((ab|0)>=256){Mb=0;break}c[_>>2]=ab<<8;ab=c[$>>2]<<8;c[$>>2]=ab;Ga=c[aa>>2]|0;if(Ga>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[Ga]|ab}c[aa>>2]=Ga+1;Mb=0}else{c[$>>2]=Bb-Ta;a[Ua]=a[(d[Ua]|0)+(g+280)|0]|0;c[_>>2]=Va;if((Va|0)>=256){Mb=1;break}c[_>>2]=Va<<8;Ga=c[$>>2]<<8;c[$>>2]=Ga;ab=c[aa>>2]|0;if(ab>>>0<(c[ca>>2]|0)>>>0){c[$>>2]=d[ab]|Ga}c[aa>>2]=ab+1;Mb=1}}while(0);ob=(Kb^-Mb)+Mb|0;pb=na;qb=ma;rb=la}}while(0);va=(nb|0)>-1?ob:-ob|0;Va=b[ya>>1]|0;Ua=b[ga+(Ha<<1)>>1]|0;Ta=Va+Ua-(b[ta>>1]|0)|0;do{if((Ua|0)>(Ta|0)){if((Va|0)<=(Ta|0)){Nb=Ta;break}Nb=(Va|0)>(Ua|0)?Ua:Va}else{if((Ta|0)<=(Va|0)){Nb=Ta;break}Nb=(Va|0)>(Ua|0)?Va:Ua}}while(0);Ua=Nb+va&qa&65535;b[ga+(Ia<<1)>>1]=Ua;if((za|0)<(q|0)){Ia=za;la=rb;ma=qb;na=pb;ua=Ua}else{Ob=pb;break}}}else{Ob=ra}c[Q>>2]=Ob}}while(0);}while((K|0)<((c[B>>2]|0)+3|0))}if(P){K=c[I>>2]|0;ga=c[D>>2]|0;ja=c[A>>2]|0;ia=c[J>>2]|0;ha=0;do{fa=b[K+(ha<<1)>>1]|0;ua=b[ga+(ha<<1)>>1]|0;na=b[ja+(ha<<1)>>1]|0;if((c[O>>2]|0)==1){Pb=na;Qb=ua;Rb=fa}else{ma=ua-H|0;ua=na-H|0;na=ba(c[s>>2]|0,ma)|0;la=fa-((ba(c[o>>2]|0,ua)|0)+na>>2)|0;Pb=la+ua|0;Qb=la+ma|0;Rb=la}if(N){c[S+((ha<<2)+U+(ba(c[T>>2]|0,y)|0))>>2]=(Rb<<8)+(e[ia+(ha<<1)>>1]<<24)+Qb+(Pb<<16)}else{la=ha<<1;b[S+(la+U+(ba(c[T>>2]|0,y)|0))>>1]=Qb;b[u+(ea+la+(ba(c[C>>2]|0,y)|0))>>1]=Rb;b[L+(x+la+(ba(c[v>>2]|0,y)|0))>>1]=Pb}ha=ha+1|0;}while((ha|0)<(q|0))}y=y+1|0;}while((y|0)<(f|0))}}while(0);do{if((c[k>>2]|0)!=0){if((c[w>>2]|0)<=2){break}f=l+12|0;q=c[f>>2]|0;Pb=(q*129|0)>>8;Rb=q-Pb|0;c[f>>2]=Rb;q=l+8|0;Qb=c[q>>2]|0;do{if((Qb|0)<(Rb|0)){if((Rb|0)>=256){break}c[f>>2]=Rb<<8;o=Qb<<8;c[q>>2]=o;s=l+540|0;Ob=c[s>>2]|0;if(Ob>>>0<(c[l+544>>2]|0)>>>0){c[q>>2]=d[Ob]|o}c[s>>2]=Ob+1}else{Ob=Qb-Rb|0;c[q>>2]=Ob;c[f>>2]=Pb;if((Pb|0)>=256){break}c[f>>2]=Pb<<8;s=Ob<<8;c[q>>2]=s;Ob=l+540|0;o=c[Ob>>2]|0;if(o>>>0<(c[l+544>>2]|0)>>>0){c[q>>2]=d[o]|s}c[Ob>>2]=o+1}}while(0);q=(c[l+544>>2]|0)-2-(c[l+540>>2]|0)+((c[n+38496>>2]|0)*-5|0)|0;if((q|0)==0){break}yDb(c[n+4>>2]|0,16,1896240,(G=i,i=i+8|0,c[G>>2]=q,G)|0);i=G;c[l+38504>>2]=1}}while(0);Y0a(n+4760|0,r,0);E=0;i=h;return E|0}function y9(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0;l=c[f+38492>>2]|0;m=f+38484|0;c[m>>2]=0;TGb(l|0,0,(h<<2)+24|0)|0;if((i|0)<=0){return}n=h-1|0;o=f+4|0;p=f+40828|0;q=(h|0)>0;r=f+12|0;s=f+8|0;t=f+540|0;u=f+544|0;v=f+4804+(k*2580|0)+1790|0;w=f+4796|0;x=f+548|0;y=f+4804+(k*2580|0)+2572|0;z=f+556|0;A=f+548|0;B=f+564|0;C=f+4804+(k*2580|0)+2568|0;D=f+38516|0;E=h<<1;F=l+(h+9<<1)|0;G=l+6|0;l=0;while(1){H=G;I=G-2|0;b[I>>1]=b[F>>1]|0;b[F+(h<<1)>>1]=b[F+(n<<1)>>1]|0;J=c[(c[o>>2]|0)+796>>2]|0;K=c[m>>2]|0;L=(c[p>>2]|0)==1;do{if((J|0)<9){if(L){if(!q){break}M=0;N=c[r>>2]|0;O=c[s>>2]|0;while(1){P=1;Q=0;R=N;S=O;while(1){T=R>>1;U=R-T|0;c[r>>2]=U;do{if((S|0)<(U|0)){if((U|0)>=256){V=0;W=U;X=S;break}Y=U<<8;c[r>>2]=Y;Z=S<<8;c[s>>2]=Z;_=c[t>>2]|0;if(_>>>0<(c[u>>2]|0)>>>0){$=d[_]|Z;c[s>>2]=$;aa=$}else{aa=Z}c[t>>2]=_+1;V=0;W=Y;X=aa}else{Y=S-U|0;c[s>>2]=Y;c[r>>2]=T;if((T|0)>=256){V=1;W=T;X=Y;break}_=T<<8;c[r>>2]=_;Z=Y<<8;c[s>>2]=Z;Y=c[t>>2]|0;if(Y>>>0<(c[u>>2]|0)>>>0){$=d[Y]|Z;c[s>>2]=$;ca=$}else{ca=Z}c[t>>2]=Y+1;V=1;W=_;X=ca}}while(0);da=V|Q;if((P|0)>=8){break}P=P+1|0;Q=da<<1;R=W;S=X}b[G+(M<<1)>>1]=da;S=M+1|0;if((S|0)<(h|0)){M=S;N=W;O=X}else{break}}}else{if(q){O=0;N=0;M=0;S=K;R=b[I>>1]|0;while(1){Q=F+(O<<1)|0;P=O+1|0;T=O-1|0;U=F+(T<<1)|0;_=b[U>>1]|0;Y=b[Q>>1]|0;Z=b[F+(P<<1)>>1]|0;$=R<<16>>16;if((b[v>>1]|0)==0){ea=(b[f+4804+(k*2580|0)+512+((_-Y&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+(($-_&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1024+((Y-Z&255)<<1)>>1]|0)|0}else{ea=(b[f+4804+(k*2580|0)+512+((_-Y&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+(($-_&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1024+((Y-Z&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1536+(((e[G+(O-2<<1)>>1]|0)-$&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+2048+(((e[G+(O<<1)>>1]|0)-Y&255)<<1)>>1]|0)|0}Y=(ea|0)<0?-ea|0:ea;do{if((c[w>>2]|0)==0){$=(Y|M|0)==0?1:M;if(($|0)==0){fa=z9(x,(c[y>>2]|0)+(Y*6|0)|0,8)|0;ga=S;ha=0;ia=N;break}do{if((N|0)==0&($|0)==1){Z=c[z>>2]|0;_=c[A>>2]|0;ja=d[_+(Z>>>3)|0]|0;ka=c[B>>2]|0;la=((Z|0)<(ka|0))+Z|0;c[z>>2]=la;ma=a[1192248+S|0]|0;if((ja&128>>>((Z&7)>>>0)|0)!=0){Z=1<<(ma&255);na=((Z+O|0)<=(h|0))+S|0;oa=1;pa=Z;break}if(ma<<24>>24==0){qa=0}else{Z=ma&255;ma=_+(la>>>3)|0;_=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7)>>>((32-Z|0)>>>0);ma=la+Z|0;c[z>>2]=ka>>>0>ma>>>0?ma:ka;qa=_}na=(S|0)==0?0:S-1|0;oa=2;pa=qa}else{na=S;oa=$;pa=N}}while(0);$=pa-1|0;if(($|0)>=0){fa=0;ga=na;ha=oa;ia=$;break}$=z9(x,(c[y>>2]|0)+(Y*6|0)|0,8)|0;fa=($>>>31^1)+$|0;ga=na;ha=0;ia=0}else{$=c[C>>2]|0;_=$+(Y<<5)|0;ka=c[r>>2]|0;ma=(ba(d[_]|0,ka)|0)>>8;Z=ka-ma|0;c[r>>2]=Z;ka=c[s>>2]|0;if((ka|0)>=(Z|0)){c[s>>2]=ka-Z;a[_]=a[(d[_]|0)+(f+280)|0]|0;c[r>>2]=ma;if((ma|0)>=256){fa=0;ga=S;ha=M;ia=N;break}c[r>>2]=ma<<8;ma=c[s>>2]<<8;c[s>>2]=ma;Z=c[t>>2]|0;if(Z>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[Z]|ma}c[t>>2]=Z+1;fa=0;ga=S;ha=M;ia=N;break}a[_]=a[(d[_]|0)+(f+24)|0]|0;_=c[r>>2]|0;if((_|0)<256){Z=_<<8;c[r>>2]=Z;ma=c[s>>2]<<8;c[s>>2]=ma;ka=c[t>>2]|0;if(ka>>>0<(c[u>>2]|0)>>>0){la=d[ka]|ma;c[s>>2]=la;ra=la}else{ra=ma}c[t>>2]=ka+1;sa=Z;ta=ra}else{sa=_;ta=c[s>>2]|0}_=$+(Y<<5)+1|0;Z=(ba(d[_]|0,sa)|0)>>8;ka=sa-Z|0;c[r>>2]=ka;if((ta|0)<(ka|0)){ua=0;va=_}else{ma=1;la=_;_=Z;Z=ka;ka=ta;while(1){c[s>>2]=ka-Z;a[la]=a[(d[la]|0)+(f+280)|0]|0;c[r>>2]=_;if((_|0)<256){ja=_<<8;c[r>>2]=ja;wa=c[s>>2]<<8;c[s>>2]=wa;xa=c[t>>2]|0;if(xa>>>0<(c[u>>2]|0)>>>0){ya=d[xa]|wa;c[s>>2]=ya;za=ya}else{za=wa}c[t>>2]=xa+1;Aa=ja;Ba=za}else{Aa=_;Ba=c[s>>2]|0}ja=ma+1|0;xa=((ma|0)>9?10:ja)+($+(Y<<5))|0;wa=(ba(d[xa]|0,Aa)|0)>>8;ya=Aa-wa|0;c[r>>2]=ya;if((Ba|0)<(ya|0)){ua=ma;va=xa;break}else{ma=ja;la=xa;_=wa;Z=ya;ka=Ba}}}a[va]=a[(d[va]|0)+(f+24)|0]|0;ka=c[r>>2]|0;if((ka|0)<256){Z=ka<<8;c[r>>2]=Z;_=c[s>>2]<<8;c[s>>2]=_;la=c[t>>2]|0;if(la>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[la]|_}c[t>>2]=la+1;Ca=Z}else{Ca=ka}a:do{if((ua|0)>0){ka=2;Z=ua;la=Ca;while(1){_=Z-1|0;ma=((_|0)>9?31:Z+21|0)+($+(Y<<5))|0;ya=(ba(d[ma]|0,la)|0)>>8;wa=la-ya|0;c[r>>2]=wa;xa=c[s>>2]|0;do{if((xa|0)<(wa|0)){a[ma]=a[(d[ma]|0)+(f+24)|0]|0;ja=c[r>>2]|0;if((ja|0)>=256){Da=0;Ea=ja;break}Fa=ja<<8;c[r>>2]=Fa;ja=c[s>>2]<<8;c[s>>2]=ja;Ga=c[t>>2]|0;if(Ga>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[Ga]|ja}c[t>>2]=Ga+1;Da=0;Ea=Fa}else{c[s>>2]=xa-wa;a[ma]=a[(d[ma]|0)+(f+280)|0]|0;c[r>>2]=ya;if((ya|0)>=256){Da=1;Ea=ya;break}Fa=ya<<8;c[r>>2]=Fa;Ga=c[s>>2]<<8;c[s>>2]=Ga;ja=c[t>>2]|0;if(ja>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[ja]|Ga}c[t>>2]=ja+1;Da=1;Ea=Fa}}while(0);ya=Da|ka;if((_|0)<=0){Ha=ya;Ia=Ea;break a}ka=ya<<1;Z=_;la=Ea}}else{Ha=1;Ia=Ca}}while(0);la=((ua|0)>10?21:ua+11|0)+($+(Y<<5))|0;Z=(ba(d[la]|0,Ia)|0)>>8;ka=Ia-Z|0;c[r>>2]=ka;ya=c[s>>2]|0;do{if((ya|0)<(ka|0)){a[la]=a[(d[la]|0)+(f+24)|0]|0;ma=c[r>>2]|0;if((ma|0)>=256){Ja=0;break}c[r>>2]=ma<<8;ma=c[s>>2]<<8;c[s>>2]=ma;wa=c[t>>2]|0;if(wa>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[wa]|ma}c[t>>2]=wa+1;Ja=0}else{c[s>>2]=ya-ka;a[la]=a[(d[la]|0)+(f+280)|0]|0;c[r>>2]=Z;if((Z|0)>=256){Ja=1;break}c[r>>2]=Z<<8;wa=c[s>>2]<<8;c[s>>2]=wa;ma=c[t>>2]|0;if(ma>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[ma]|wa}c[t>>2]=ma+1;Ja=1}}while(0);fa=(Ha^-Ja)+Ja|0;ga=S;ha=M;ia=N}}while(0);Y=(ea|0)>-1?fa:-fa|0;Z=b[Q>>1]|0;la=b[G+(T<<1)>>1]|0;ka=Z+la-(b[U>>1]|0)|0;do{if((la|0)>(ka|0)){if((Z|0)<=(ka|0)){Ka=ka;break}Ka=(Z|0)>(la|0)?la:Z}else{if((ka|0)<=(Z|0)){Ka=ka;break}Ka=(Z|0)>(la|0)?Z:la}}while(0);la=Ka+Y&255;b[G+(O<<1)>>1]=la;if((P|0)<(h|0)){O=P;N=ia;M=ha;S=ga;R=la}else{La=ga;break}}}else{La=K}c[m>>2]=La}if(!q){break}R=ba(l,j)|0;S=0;do{a[g+(S+R)|0]=b[G+(S<<1)>>1];S=S+1|0;}while((S|0)<(h|0))}else{do{if(L){if(!q){break}if((J|0)<=0){TGb(H|0,0,E|0)|0;break}S=0;R=c[r>>2]|0;M=c[s>>2]|0;while(1){N=1;O=0;la=R;Z=M;while(1){ka=la>>1;U=la-ka|0;c[r>>2]=U;do{if((Z|0)<(U|0)){if((U|0)>=256){Ma=0;Na=U;Oa=Z;break}T=U<<8;c[r>>2]=T;Q=Z<<8;c[s>>2]=Q;ya=c[t>>2]|0;if(ya>>>0<(c[u>>2]|0)>>>0){$=d[ya]|Q;c[s>>2]=$;Pa=$}else{Pa=Q}c[t>>2]=ya+1;Ma=0;Na=T;Oa=Pa}else{T=Z-U|0;c[s>>2]=T;c[r>>2]=ka;if((ka|0)>=256){Ma=1;Na=ka;Oa=T;break}ya=ka<<8;c[r>>2]=ya;Q=T<<8;c[s>>2]=Q;T=c[t>>2]|0;if(T>>>0<(c[u>>2]|0)>>>0){$=d[T]|Q;c[s>>2]=$;Qa=$}else{Qa=Q}c[t>>2]=T+1;Ma=1;Na=ya;Oa=Qa}}while(0);Ra=Ma|O;if((N|0)>=(J|0)){break}N=N+1|0;O=Ra<<1;la=Na;Z=Oa}b[G+(S<<1)>>1]=Ra;Z=S+1|0;if((Z|0)<(h|0)){S=Z;R=Na;M=Oa}else{break}}}else{if(q){M=(1<<J)+65535|0;R=0;S=0;P=0;Y=K;Z=b[I>>1]|0;while(1){la=F+(R<<1)|0;O=R+1|0;N=R-1|0;ka=F+(N<<1)|0;U=b[ka>>1]|0;ya=b[la>>1]|0;T=b[F+(O<<1)>>1]|0;Q=Z<<16>>16;if((b[v>>1]|0)==0){Sa=(b[f+4804+(k*2580|0)+512+((U-ya&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+((Q-U&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1024+((ya-T&255)<<1)>>1]|0)|0}else{Sa=(b[f+4804+(k*2580|0)+512+((U-ya&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+((Q-U&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1024+((ya-T&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1536+(((e[G+(R-2<<1)>>1]|0)-Q&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+2048+(((e[G+(R<<1)>>1]|0)-ya&255)<<1)>>1]|0)|0}ya=(Sa|0)<0?-Sa|0:Sa;do{if((c[w>>2]|0)==0){Q=(ya|P|0)==0?1:P;if((Q|0)==0){Ta=z9(x,(c[y>>2]|0)+(ya*6|0)|0,J)|0;Ua=Y;Va=0;Wa=S;break}do{if((S|0)==0&(Q|0)==1){T=c[z>>2]|0;U=c[A>>2]|0;$=d[U+(T>>>3)|0]|0;ma=c[B>>2]|0;wa=((T|0)<(ma|0))+T|0;c[z>>2]=wa;xa=a[1192248+Y|0]|0;if(($&128>>>((T&7)>>>0)|0)!=0){T=1<<(xa&255);Xa=((T+R|0)<=(h|0))+Y|0;Ya=1;Za=T;break}if(xa<<24>>24==0){_a=0}else{T=xa&255;xa=U+(wa>>>3)|0;U=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(wa&7)>>>((32-T|0)>>>0);xa=wa+T|0;c[z>>2]=ma>>>0>xa>>>0?xa:ma;_a=U}Xa=(Y|0)==0?0:Y-1|0;Ya=2;Za=_a}else{Xa=Y;Ya=Q;Za=S}}while(0);Q=Za-1|0;if((Q|0)>=0){Ta=0;Ua=Xa;Va=Ya;Wa=Q;break}Q=z9(x,(c[y>>2]|0)+(ya*6|0)|0,J)|0;Ta=(Q>>>31^1)+Q|0;Ua=Xa;Va=0;Wa=0}else{Q=c[C>>2]|0;U=Q+(ya<<5)|0;ma=c[r>>2]|0;xa=(ba(d[U]|0,ma)|0)>>8;T=ma-xa|0;c[r>>2]=T;ma=c[s>>2]|0;if((ma|0)>=(T|0)){c[s>>2]=ma-T;a[U]=a[(d[U]|0)+(f+280)|0]|0;c[r>>2]=xa;if((xa|0)>=256){Ta=0;Ua=Y;Va=P;Wa=S;break}c[r>>2]=xa<<8;xa=c[s>>2]<<8;c[s>>2]=xa;T=c[t>>2]|0;if(T>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[T]|xa}c[t>>2]=T+1;Ta=0;Ua=Y;Va=P;Wa=S;break}a[U]=a[(d[U]|0)+(f+24)|0]|0;U=c[r>>2]|0;if((U|0)<256){T=U<<8;c[r>>2]=T;xa=c[s>>2]<<8;c[s>>2]=xa;ma=c[t>>2]|0;if(ma>>>0<(c[u>>2]|0)>>>0){wa=d[ma]|xa;c[s>>2]=wa;$a=wa}else{$a=xa}c[t>>2]=ma+1;ab=T;bb=$a}else{ab=U;bb=c[s>>2]|0}U=Q+(ya<<5)+1|0;T=(ba(d[U]|0,ab)|0)>>8;ma=ab-T|0;c[r>>2]=ma;if((bb|0)<(ma|0)){cb=0;db=U}else{xa=1;wa=U;U=T;T=ma;ma=bb;while(1){c[s>>2]=ma-T;a[wa]=a[(d[wa]|0)+(f+280)|0]|0;c[r>>2]=U;if((U|0)<256){$=U<<8;c[r>>2]=$;Fa=c[s>>2]<<8;c[s>>2]=Fa;ja=c[t>>2]|0;if(ja>>>0<(c[u>>2]|0)>>>0){Ga=d[ja]|Fa;c[s>>2]=Ga;eb=Ga}else{eb=Fa}c[t>>2]=ja+1;fb=$;gb=eb}else{fb=U;gb=c[s>>2]|0}$=xa+1|0;ja=((xa|0)>9?10:$)+(Q+(ya<<5))|0;Fa=(ba(d[ja]|0,fb)|0)>>8;Ga=fb-Fa|0;c[r>>2]=Ga;if((gb|0)<(Ga|0)){cb=xa;db=ja;break}else{xa=$;wa=ja;U=Fa;T=Ga;ma=gb}}}a[db]=a[(d[db]|0)+(f+24)|0]|0;ma=c[r>>2]|0;if((ma|0)<256){T=ma<<8;c[r>>2]=T;U=c[s>>2]<<8;c[s>>2]=U;wa=c[t>>2]|0;if(wa>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[wa]|U}c[t>>2]=wa+1;hb=T}else{hb=ma}b:do{if((cb|0)>0){ma=2;T=cb;wa=hb;while(1){U=T-1|0;xa=((U|0)>9?31:T+21|0)+(Q+(ya<<5))|0;Ga=(ba(d[xa]|0,wa)|0)>>8;Fa=wa-Ga|0;c[r>>2]=Fa;ja=c[s>>2]|0;do{if((ja|0)<(Fa|0)){a[xa]=a[(d[xa]|0)+(f+24)|0]|0;$=c[r>>2]|0;if(($|0)>=256){ib=0;jb=$;break}kb=$<<8;c[r>>2]=kb;$=c[s>>2]<<8;c[s>>2]=$;lb=c[t>>2]|0;if(lb>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[lb]|$}c[t>>2]=lb+1;ib=0;jb=kb}else{c[s>>2]=ja-Fa;a[xa]=a[(d[xa]|0)+(f+280)|0]|0;c[r>>2]=Ga;if((Ga|0)>=256){ib=1;jb=Ga;break}kb=Ga<<8;c[r>>2]=kb;lb=c[s>>2]<<8;c[s>>2]=lb;$=c[t>>2]|0;if($>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[$]|lb}c[t>>2]=$+1;ib=1;jb=kb}}while(0);Ga=ib|ma;if((U|0)<=0){mb=Ga;nb=jb;break b}ma=Ga<<1;T=U;wa=jb}}else{mb=1;nb=hb}}while(0);wa=((cb|0)>10?21:cb+11|0)+(Q+(ya<<5))|0;T=(ba(d[wa]|0,nb)|0)>>8;ma=nb-T|0;c[r>>2]=ma;_=c[s>>2]|0;do{if((_|0)<(ma|0)){a[wa]=a[(d[wa]|0)+(f+24)|0]|0;Ga=c[r>>2]|0;if((Ga|0)>=256){ob=0;break}c[r>>2]=Ga<<8;Ga=c[s>>2]<<8;c[s>>2]=Ga;xa=c[t>>2]|0;if(xa>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[xa]|Ga}c[t>>2]=xa+1;ob=0}else{c[s>>2]=_-ma;a[wa]=a[(d[wa]|0)+(f+280)|0]|0;c[r>>2]=T;if((T|0)>=256){ob=1;break}c[r>>2]=T<<8;xa=c[s>>2]<<8;c[s>>2]=xa;Ga=c[t>>2]|0;if(Ga>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[Ga]|xa}c[t>>2]=Ga+1;ob=1}}while(0);Ta=(mb^-ob)+ob|0;Ua=Y;Va=P;Wa=S}}while(0);ya=(Sa|0)>-1?Ta:-Ta|0;T=b[la>>1]|0;wa=b[G+(N<<1)>>1]|0;ma=T+wa-(b[ka>>1]|0)|0;do{if((wa|0)>(ma|0)){if((T|0)<=(ma|0)){pb=ma;break}pb=(T|0)>(wa|0)?wa:T}else{if((ma|0)<=(T|0)){pb=ma;break}pb=(T|0)>(wa|0)?T:wa}}while(0);wa=pb+ya&M&65535;b[G+(R<<1)>>1]=wa;if((O|0)<(h|0)){R=O;S=Wa;P=Va;Y=Ua;Z=wa}else{qb=Ua;break}}}else{qb=K}c[m>>2]=qb}}while(0);if((c[D>>2]|0)==0){if(!q){break}Z=16-(c[(c[o>>2]|0)+796>>2]|0)|0;Y=g+(ba(l,j)|0)|0;P=0;do{b[Y+(P<<1)>>1]=b[G+(P<<1)>>1]<<Z;P=P+1|0;}while((P|0)<(h|0))}else{if(!q){break}P=g+(ba(l,j)|0)|0;Z=0;do{b[P+(Z<<1)>>1]=b[G+(Z<<1)>>1]|0;Z=Z+1|0;}while((Z|0)<(h|0))}}}while(0);K=l+1|0;if((K|0)<(i|0)){J=F;F=G;l=K;G=J}else{break}}return}function z9(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=g+5|0;j=d[i]|0;k=g+2|0;l=e[k>>1]|0;if(j>>>0<l>>>0){m=j;j=0;while(1){n=j+1|0;o=m<<1;if((o|0)<(l|0)){m=o;j=n}else{p=n;break}}}else{p=0}j=f+8|0;m=c[j>>2]|0;n=c[f+16>>2]|0;o=c[f>>2]|0;f=o+(m>>>3)|0;q=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(m&7);f=q>>>0>65535>>>0;r=f?q>>>16:q;s=f?16:0;if((r&65280|0)==0){t=s;u=r}else{t=s|8;u=r>>>8}r=(d[1191992+u|0]|0)+t|0;if((r|0)>19){t=p+32+m-r|0;c[j>>2]=n>>>0>t>>>0?t:n;v=(q>>>((r-p|0)>>>0))+(30-r<<p)|0}else{p=m+12|0;m=n>>>0>p>>>0?p:n;p=o+(m>>>3)|0;o=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>((32-h|0)>>>0);p=m+h|0;c[j>>2]=n>>>0>p>>>0?p:n;v=o+11|0}o=v+1|0;v=o>>1;n=g|0;p=b[n>>1]|0;j=a[i]|0;m=j&255;r=(p<<1)+m>>31^((o&1|0)==0?-v|0:v);v=g+4|0;g=a[v]|0;o=r+(g<<24>>24)|0;if((h|0)==8){w=o<<24>>24}else{q=1<<h-1;w=(o+q&(1<<h)-1)-q|0}q=l+((r|0)>-1?r:-r|0)|0;l=p+r|0;if(j<<24>>24==-128){x=m>>>1;y=l>>1;z=q>>>1&32767}else{x=m;y=l;z=q&65535}b[k>>1]=z;z=x+1|0;k=~x;if((y|0)>(k|0)){if((y|0)<=0){A=y&65535;b[n>>1]=A;B=z&255;a[i]=B;return w|0}if(!(g<<24>>24==127)){a[v]=g+1}q=y-z|0;A=(q|0)>0?0:q&65535;b[n>>1]=A;B=z&255;a[i]=B;return w|0}else{if(!(g<<24>>24==-128)){a[v]=g-1}g=z+y|0;if((g|0)>(k|0)){A=g&65535;b[n>>1]=A;B=z&255;a[i]=B;return w|0}A=-x&65535;b[n>>1]=A;B=z&255;a[i]=B;return w|0}return 0}function A9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=b+4|0;h=c[g>>2]|0;i=(ba(d[e]|0,h)|0)>>8;j=h-i|0;c[g>>2]=j;h=b|0;k=c[h>>2]|0;if((k|0)>=(j|0)){c[h>>2]=k-j;a[e]=a[(d[e]|0)+(b+272)|0]|0;c[g>>2]=i;if((i|0)>=256){l=0;return l|0}c[g>>2]=i<<8;i=c[h>>2]<<8;c[h>>2]=i;j=b+532|0;k=c[j>>2]|0;if(k>>>0<(c[b+536>>2]|0)>>>0){c[h>>2]=d[k]|0|i}c[j>>2]=k+1;l=0;return l|0}a[e]=a[(d[e]|0)+(b+16)|0]|0;k=c[g>>2]|0;if((k|0)<256){j=k<<8;c[g>>2]=j;i=c[h>>2]<<8;c[h>>2]=i;m=b+532|0;n=c[m>>2]|0;if(n>>>0<(c[b+536>>2]|0)>>>0){o=d[n]|0|i;c[h>>2]=o;p=o}else{p=i}c[m>>2]=n+1;q=j;r=p}else{q=k;r=c[h>>2]|0}k=e+1|0;p=(ba(d[k]|0,q)|0)>>8;j=q-p|0;c[g>>2]=j;if((r|0)<(j|0)){s=0;t=k}else{q=b+532|0;n=b+536|0;m=1;i=k;k=p;p=j;j=r;while(1){c[h>>2]=j-p;a[i]=a[(d[i]|0)+(b+272)|0]|0;c[g>>2]=k;if((k|0)<256){r=k<<8;c[g>>2]=r;o=c[h>>2]<<8;c[h>>2]=o;u=c[q>>2]|0;if(u>>>0<(c[n>>2]|0)>>>0){v=d[u]|0|o;c[h>>2]=v;w=v}else{w=o}c[q>>2]=u+1;x=r;y=w}else{x=k;y=c[h>>2]|0}r=m+1|0;u=e+((m|0)>9?10:r)|0;o=(ba(d[u]|0,x)|0)>>8;v=x-o|0;c[g>>2]=v;if((y|0)<(v|0)){s=m;t=u;break}else{m=r;i=u;k=o;p=v;j=y}}}a[t]=a[(d[t]|0)+(b+16)|0]|0;t=c[g>>2]|0;if((t|0)<256){y=t<<8;c[g>>2]=y;j=c[h>>2]<<8;c[h>>2]=j;p=b+532|0;k=c[p>>2]|0;if(k>>>0<(c[b+536>>2]|0)>>>0){c[h>>2]=d[k]|0|j}c[p>>2]=k+1;z=y}else{z=t}a:do{if((s|0)>0){t=b+532|0;y=b+536|0;k=2;p=s;j=z;while(1){i=p-1|0;m=e+((i|0)>9?31:p+21|0)|0;x=(ba(d[m]|0,j)|0)>>8;w=j-x|0;c[g>>2]=w;q=c[h>>2]|0;do{if((q|0)<(w|0)){a[m]=a[(d[m]|0)+(b+16)|0]|0;n=c[g>>2]|0;if((n|0)>=256){A=0;B=n;break}v=n<<8;c[g>>2]=v;n=c[h>>2]<<8;c[h>>2]=n;o=c[t>>2]|0;if(o>>>0<(c[y>>2]|0)>>>0){c[h>>2]=d[o]|0|n}c[t>>2]=o+1;A=0;B=v}else{c[h>>2]=q-w;a[m]=a[(d[m]|0)+(b+272)|0]|0;c[g>>2]=x;if((x|0)>=256){A=1;B=x;break}v=x<<8;c[g>>2]=v;o=c[h>>2]<<8;c[h>>2]=o;n=c[t>>2]|0;if(n>>>0<(c[y>>2]|0)>>>0){c[h>>2]=d[n]|0|o}c[t>>2]=n+1;A=1;B=v}}while(0);x=A|k;if((i|0)<=0){C=x;D=B;break a}k=x<<1;p=i;j=B}}else{C=1;D=z}}while(0);do{if((f|0)==0){E=0}else{z=e+((s|0)>10?21:s+11|0)|0;B=(ba(d[z]|0,D)|0)>>8;A=D-B|0;c[g>>2]=A;j=c[h>>2]|0;if((j|0)<(A|0)){a[z]=a[(d[z]|0)+(b+16)|0]|0;p=c[g>>2]|0;if((p|0)>=256){E=0;break}c[g>>2]=p<<8;p=c[h>>2]<<8;c[h>>2]=p;k=b+532|0;t=c[k>>2]|0;if(t>>>0<(c[b+536>>2]|0)>>>0){c[h>>2]=d[t]|0|p}c[k>>2]=t+1;E=0;break}else{c[h>>2]=j-A;a[z]=a[(d[z]|0)+(b+272)|0]|0;c[g>>2]=B;if((B|0)>=256){E=1;break}c[g>>2]=B<<8;B=c[h>>2]<<8;c[h>>2]=B;z=b+532|0;A=c[z>>2]|0;if(A>>>0<(c[b+536>>2]|0)>>>0){c[h>>2]=d[A]|0|B}c[z>>2]=A+1;E=1;break}}}while(0);l=(C^-E)+E|0;return l|0}function B9(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+32|0;e=d|0;f=1;g=0;while(1){if((g|0)>=5){break}TGb(e|0,-128|0,32)|0;h=0;j=0;while(1){k=(A9(a,e,0)|0)+1|0;if(k>>>0>(128-j|0)>>>0){l=-1094995529;break}if((k|0)==0){m=j}else{n=(ba(h,f)|0)&65535;o=j;p=k;while(1){q=p-1|0;b[c+(g<<9)+(o<<1)>>1]=n;if((q|0)==0){break}else{o=o+1|0;p=q}}m=k+j|0}r=h+1|0;if((m|0)<128){h=r;j=m}else{s=1;t=10;break}}if((t|0)==10){while(1){t=0;b[c+(g<<9)+(256-s<<1)>>1]=-(b[c+(g<<9)+(s<<1)>>1]|0);j=s+1|0;if((j|0)<128){s=j;t=10}else{break}}b[c+(g<<9)+256>>1]=-(b[c+(g<<9)+254>>1]|0);l=(r<<1)-1|0}j=ba(l,f)|0;if(j>>>0>32768>>>0){u=-1094995529;t=14;break}else{f=j;g=g+1|0}}if((t|0)==14){i=d;return u|0}u=(f+1|0)/2|0;i=d;return u|0}function C9(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0,pa=0,qa=0.0,ra=0.0,sa=0.0,ta=0.0,ua=0,va=0.0,wa=0,xa=0.0,ya=0,za=0.0,Aa=0.0,Ba=0,Ca=0.0,Da=0,Ea=0.0,Fa=0.0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0.0,Oa=0,Pa=0.0,Qa=0,Ra=0,Sa=0,Ta=0.0,Ua=0,Va=0.0,Wa=0.0,Xa=0,Ya=0,Za=0,_a=0,$a=0.0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;f=i;i=i+74792|0;g=f|0;j=f+32|0;k=f+1056|0;l=f+3104|0;m=f+5152|0;n=f+7200|0;o=f+9248|0;p=f+74784|0;q=c[e+60>>2]|0;r=q;s=e+140|0;t=bFb(c[s>>2]|0)|0;u=Vkb(e)|0;if((u|0)<0){v=u;i=f;return v|0}u=q+4720|0;c[u>>2]=0;w=e+88|0;y=e+404|0;if((c[w>>2]&1536|0)==0){z=c[y>>2]|0;if((z|0)>1){A=4}else{B=z;C=0}}else{A=4}if((A|0)==4){c[u>>2]=2;B=c[y>>2]|0;C=2}y=e+404|0;z=e+844|0;do{if((B|0)==0){if((c[z>>2]|0)>=0){D=C;break}if((ba(c[e+124>>2]|0,c[e+120>>2]|0)|0)<=414720){D=C;break}c[u>>2]=2;D=2}else{D=C}}while(0);C=c[z>>2]|0;if((C|0)<1&(D|0)==2){c[u>>2]=3;E=c[z>>2]|0;G=3}else{E=C;G=D}if(E>>>0<5>>>0){D=(G|0)>(E|0)?G:E;c[u>>2]=D;H=D}else{H=G}G=q+38496|0;if((c[G>>2]|0)<0){c[G>>2]=(H|0)>2}do{if((H|0)==2|(H|0)>3){if(!((c[e+680>>2]|0)>-2)){break}yDb(e,16,2274296,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-1094995529;i=f;return v|0}}while(0);D=e+568|0;E=(c[D>>2]|0)>0;C=q+4796|0;c[C>>2]=E?2:0;z=q+4792|0;c[z>>2]=3;a:do{switch(c[s>>2]|0){case 78:case 72:case 74:case 102:case 100:case 98:{A=24;break};case 32:case 58:case 56:case 54:case 108:case 106:case 104:{A=27;break};case 8:case 5:case 33:case 4:case 0:case 7:case 6:case 299:case 300:case 35:{A=39;break};case 30:{c[q+38488>>2]=1;c[q+4748>>2]=1;c[q+4736>>2]=1;break};case 84:{B=e+796|0;if((c[B>>2]|0)!=0){J=B;A=44;break a}c[q+38512>>2]=9;J=B;A=44;break};case 298:{c[q+38488>>2]=1;c[q+4736>>2]=1;break};case 86:{J=e+796|0;A=44;break};case 314:{K=e+796|0;A=47;break};case 316:{L=e+796|0;A=50;break};case 76:case 80:case 70:case 96:case 94:case 92:{if((c[e+796>>2]|0)!=0){A=24;break a}c[q+38512>>2]=9;A=24;break};default:{yDb(e,16,2219512,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-38;i=f;return v|0}}}while(0);do{if((A|0)==24){c[q+38516>>2]=1;if((c[e+796>>2]|0)!=0){A=27;break}B=q+38512|0;if((c[B>>2]|0)!=0){A=27;break}c[B>>2]=10;A=27}else if((A|0)==44){if((c[J>>2]|0)!=0){K=J;A=47;break}B=q+38512|0;if((c[B>>2]|0)!=0){K=J;A=47;break}c[B>>2]=10;K=J;A=47}}while(0);do{if((A|0)==27){J=c[e+796>>2]|0;B=q+38512|0;M=c[B>>2]|0;N=(M|0)==0;do{if((J|0)==0){if(!N){O=M;A=32;break}c[B>>2]=16}else{if(!N){O=M;A=32;break}c[q+38512>>2]=J;O=J;A=32}}while(0);do{if((A|0)==32){if((O|0)>=9){break}yDb(e,16,2258552,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-1094995529;i=f;return v|0}}while(0);do{if(E){P=H}else{J=e;if((c[D>>2]|0)==-1){yDb(J,32,2244184,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;c[C>>2]=2;P=c[u>>2]|0;break}yDb(J,16,2231664,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-38;i=f;return v|0}}while(0);c[u>>2]=(P|0)>1?P:1;A=39}else if((A|0)==47){if((c[K>>2]|0)!=0){L=K;A=50;break}J=q+38512|0;if((c[J>>2]|0)!=0){L=K;A=50;break}c[J>>2]=12;L=K;A=50}}while(0);do{if((A|0)==39){K=t+4|0;c[q+4736>>2]=(d[K]|0)>>>0>2>>>0;c[q+38488>>2]=0;c[q+4748>>2]=(a[K]|0)==4}else if((A|0)==50){K=c[L>>2]|0;P=q+38512|0;D=(c[P>>2]|0)==0;do{if((K|0)==0){if(!D){break}c[P>>2]=14}else{if(!D){break}c[q+38512>>2]=K}}while(0);c[q+38488>>2]=1;c[q+4736>>2]=1;c[u>>2]=(H|0)>1?H:1;if(E){break}yDb(e,16,2231664,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-38;i=f;return v|0}}while(0);E=q+4748|0;if((c[E>>2]|0)!=0){yDb(e,24,2210160,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}H=e+572|0;L=c[H>>2]|0;if(L>>>0>1>>>0){yDb(e,16,2201392,(I=i,i=i+8|0,c[I>>2]=L,I)|0);i=I;v=-22;i=f;return v|0}if((c[C>>2]|0)>1){L=1;do{a[q+(L+38196)|0]=a[141744+L|0]|0;L=L+1|0;}while((L|0)<256)}L=q+38524|0;t=q+38512|0;K=q+17684|0;D=K;P=q+18196|0;O=q+18708|0;J=q+20244|0;M=q+20756|0;N=q+21268|0;B=q+21780|0;Q=q+22292|0;R=0;do{c[L>>2]=2;if((c[t>>2]|0)<9){S=a[554160+R|0]|0;b[D+(R<<1)>>1]=S;T=S*11&65535;b[P+(R<<1)>>1]=T;b[O+(R<<1)>>1]=S*121;b[J+(R<<1)>>1]=S;b[M+(R<<1)>>1]=T;T=a[553904+R|0]|0;b[N+(R<<1)>>1]=T*121;b[B+(R<<1)>>1]=T*605;b[Q+(R<<1)>>1]=T*3025}else{T=a[553392+R|0]|0;b[D+(R<<1)>>1]=T;S=T*11&65535;b[P+(R<<1)>>1]=S;b[O+(R<<1)>>1]=T*121;b[J+(R<<1)>>1]=T;b[M+(R<<1)>>1]=S;S=a[553648+R|0]|0;b[N+(R<<1)>>1]=S*121;b[B+(R<<1)>>1]=S*605;b[Q+(R<<1)>>1]=S*3025}R=R+1|0;}while((R|0)<256);R=q+38164|0;Q=R;c[R>>2]=666;c[q+38168>>2]=7563;R=q+15124|0;UGb(R|0,K+((c[H>>2]|0)*2560|0)|0,2560)|0;if((c[z>>2]|0)>0){K=q+4804|0;B=0;do{UGb(K+(B*2580|0)|0,R|0,2560)|0;N=c[H>>2]|0;c[K+(B*2580|0)+2560>>2]=N;c[K+(B*2580|0)+2564>>2]=c[Q+(N<<2)>>2];B=B+1|0;}while((B|0)<(c[z>>2]|0))}B=Zkb(r)|0;if((B|0)<0){v=B;i=f;return v|0}B=ICb()|0;c[e+804>>2]=B;if((B|0)==0){v=-12;i=f;return v|0}c[B+88>>2]=1;if((c[E>>2]|0)==0){c[z>>2]=2}B=q+4736|0;do{if((c[B>>2]|0)==0){if((c[u>>2]|0)<=3){break}c[z>>2]=(c[z>>2]|0)-1}}while(0);z=q+4740|0;K=q+4744|0;_Ga(c[s>>2]|0,z,K);c[q+4756>>2]=0;b:do{if((c[w>>2]&1536|0)!=0){s=q+4688|0;H=0;while(1){if((H|0)>=(c[L>>2]|0)){break b}R=cEb(c[Q+(H<<2)>>2]<<9)|0;c[s+(H<<2)>>2]=R;if((R|0)==0){v=-12;break}else{H=H+1|0}}i=f;return v|0}}while(0);H=c[e+672>>2]|0;do{if((H|0)!=0){if((c[u>>2]|0)<=1){yDb(0,0,2007648,(I=i,i=i+24|0,c[I>>2]=2193072,c[I+8>>2]=1941120,c[I+16>>2]=869,I)|0);i=I;Cd();return 0}s=q+4688|0;R=q+592|0;N=H;M=0;c:while(1){if((M|0)<256){U=N;V=0;while(1){if((V|0)>=2){break}J=kb(U|0,p|0,0)|0;O=R+(M<<4)+(V<<3)|0;c[O>>2]=J;c[O+4>>2]=(J|0)<0|0?-1:0;J=c[p>>2]|0;if((J|0)==(U|0)){A=91;break c}else{U=J;V=V+1|0}}N=U;M=M+1|0;continue}J=c[L>>2]|0;if((J|0)>0){W=0;O=N;P=J;while(1){J=Q+(W<<2)|0;if((c[J>>2]|0)>0){D=s+(W<<2)|0;X=0;S=O;while(1){Y=0;T=S;while(1){Z=T;_=0;while(1){if((_|0)>=2){break}$=kb(Z|0,p|0,0)|0;aa=(c[D>>2]|0)+(X<<9)+(Y<<4)+(_<<3)|0;c[aa>>2]=$;c[aa+4>>2]=($|0)<0|0?-1:0;$=c[p>>2]|0;if(($|0)==(Z|0)){A=99;break c}else{Z=$;_=_+1|0}}$=Y+1|0;if(($|0)<32){Y=$;T=Z}else{break}}T=X+1|0;if((T|0)<(c[J>>2]|0)){X=T;S=Z}else{break}}ca=Z;da=c[L>>2]|0}else{ca=O;da=P}S=W+1|0;if((S|0)<(da|0)){W=S;O=ca;P=da}else{ea=ca;break}}}else{ea=N}fa=kb(ea|0,p|0,0)|0;P=c[p>>2]|0;if((P|0)==(ea|0)|(fa|0)<1){A=105;break}else{ga=P}while(1){P=a[ga]|0;if((P<<24>>24|0)==0){ha=12;ia=0;A=108;break c}else if(!((P<<24>>24|0)==32|(P<<24>>24|0)==10)){N=ga;M=0;continue c}ga=ga+1|0}}if((A|0)==91){yDb(e,16,2176600,(I=i,i=i+24|0,c[I>>2]=M,c[I+8>>2]=V,c[I+16>>2]=U,I)|0);i=I;v=-1094995529;i=f;return v|0}else if((A|0)==99){yDb(e,16,2165896,(I=i,i=i+40|0,c[I>>2]=W,c[I+8>>2]=X,c[I+16>>2]=Y,c[I+24>>2]=_,c[I+32>>2]=Z,I)|0);i=I;v=-1094995529;i=f;return v|0}else if((A|0)==105){yDb(e,16,2159264,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-1094995529;i=f;return v|0}else if((A|0)==108){d:while(1){A=0;N=ha;while(1){if((N|0)>=244){A=131;break}ja=N+1|0;ka=N+4|0;if((ja|0)<245){break}else{N=ja}}if((A|0)==131){A=0;if((ia|0)==0){break}else{ha=12;ia=0;A=108;continue}}R=r+592+(N<<4)|0;P=256-N|0;la=-0.0- +gc(+(+(P|0)*.00390625));O=r+592+(N<<4)+8|0;ma=-0.0- +gc(+(+(N|0)*.00390625));S=r+592+(P<<4)|0;J=r+592+(P<<4)+8|0;D=(N|0)==128;T=q+(N+38196)|0;$=q+(P+38196)|0;aa=P&255;na=N&255;oa=ia;pa=ja;while(1){qa=+((c[R>>2]|0)>>>0)+ +((c[R+4>>2]|0)>>>0)*4294967296.0;ra=+((c[O>>2]|0)>>>0)+ +((c[O+4>>2]|0)>>>0)*4294967296.0;sa=+((c[S>>2]|0)>>>0)+ +((c[S+4>>2]|0)>>>0)*4294967296.0;ta=+((c[J>>2]|0)>>>0)+ +((c[J+4>>2]|0)>>>0)*4294967296.0;ua=r+592+(pa<<4)|0;va=+((c[ua>>2]|0)>>>0)+ +((c[ua+4>>2]|0)>>>0)*4294967296.0;wa=256-pa|0;xa=-0.0- +gc(+(+(wa|0)*.00390625));ya=r+592+(pa<<4)+8|0;za=+((c[ya>>2]|0)>>>0)+ +((c[ya+4>>2]|0)>>>0)*4294967296.0;Aa=-0.0- +gc(+(+(pa|0)*.00390625));Ba=r+592+(wa<<4)|0;Ca=+((c[Ba>>2]|0)>>>0)+ +((c[Ba+4>>2]|0)>>>0)*4294967296.0;Da=r+592+(wa<<4)+8|0;Ea=+((c[Da>>2]|0)>>>0)+ +((c[Da+4>>2]|0)>>>0)*4294967296.0;Fa=qa*la+ra*ma+sa*ma+ta*la+va*xa+za*Aa+Ca*Aa+Ea*xa;e:do{if(Fa-(Ea*la+(Ca*ma+(za*ma+(va*la+(ta*xa+(sa*Aa+(qa*xa+ra*Aa)))))))<=Fa*1.0e-14|D|(pa|0)==128){Ga=oa}else{Ha=q+(pa+38196)|0;Ia=a[Ha]|0;a[Ha]=a[T]|0;a[T]=Ia;Ia=c[ua>>2]|0;Ha=c[R+4>>2]|0;c[ua>>2]=c[R>>2];c[ua+4>>2]=Ha;Ha=Ia;c[R>>2]=Ha;c[R+4>>2]=(Ha|0)<0|0?-1:0;Ha=c[ya>>2]|0;Ia=c[O+4>>2]|0;c[ya>>2]=c[O>>2];c[ya+4>>2]=Ia;Ia=Ha;c[O>>2]=Ia;c[O+4>>2]=(Ia|0)<0|0?-1:0;if((N|0)==(wa|0)){Ia=pa&255;Ha=1;while(1){Ja=q+(Ha+38196)|0;Ka=d[Ja]|0;do{if((Ka|0)==(N|0)){a[Ja]=Ia}else{if((Ka|0)!=(pa|0)){break}a[Ja]=na}}while(0);Ja=Ha+1|0;if((Ja|0)<256){Ha=Ja}else{Ga=1;break e}}}Ha=q+(wa+38196)|0;Ia=a[Ha]|0;a[Ha]=a[$]|0;a[$]=Ia;Ia=c[Ba>>2]|0;Ha=c[S+4>>2]|0;c[Ba>>2]=c[S>>2];c[Ba+4>>2]=Ha;Ha=Ia;c[S>>2]=Ha;c[S+4>>2]=(Ha|0)<0|0?-1:0;Ha=c[Da>>2]|0;Ia=c[J+4>>2]|0;c[Da>>2]=c[J>>2];c[Da+4>>2]=Ia;Ia=Ha;c[J>>2]=Ia;c[J+4>>2]=(Ia|0)<0|0?-1:0;Ia=pa&255;Ha=wa&255;Ja=1;while(1){Ka=q+(Ja+38196)|0;La=d[Ka]|0;do{if((La|0)==(N|0)){a[Ka]=Ia}else{if((La|0)!=(pa|0)){break}a[Ka]=na}}while(0);Ka=q+(38452-Ja)|0;La=d[Ka]|0;do{if((La|0)==(P|0)){a[Ka]=Ha}else{if((La|0)!=(wa|0)){break}a[Ka]=aa}}while(0);Ka=Ja+1|0;if((Ka|0)<256){Ja=Ka}else{Ga=1;break}}}}while(0);wa=pa+1|0;if((wa|0)<245&(wa|0)<(ka|0)){oa=Ga;pa=wa}else{ha=ja;ia=Ga;A=108;continue d}}}M=m;pa=n;oa=1;while(1){h[k+(oa<<3)>>3]=+gc(+(+(oa|0)*.00390625));aa=oa+1|0;if((aa|0)<256){oa=aa}else{Ma=0;break}}do{oa=0;do{h[l+(oa<<3)>>3]=1073741824.0;oa=oa+1|0;}while((oa|0)<256);la=+(Ma|0)*.00390625;oa=Ma-10|0;aa=(oa|0)>1?oa:1;oa=Ma+11|0;P=(oa|0)>256?256:oa;if((aa|0)<(P|0)){ma=1.0-la;oa=aa;do{TGb(M|0,0,2048)|0;h[m+(oa<<3)>>3]=1.0;aa=oa&255;na=0;Fa=0.0;while(1){TGb(pa|0,0,2048)|0;N=1;Aa=Fa;while(1){ra=+h[m+(N<<3)>>3];if(ra!=0.0){Na=Aa-ra*(la*+h[k+(N<<3)>>3]+ma*+h[k+(256-N<<3)>>3])}else{Na=Aa}J=N+1|0;if((J|0)<256){N=J;Aa=Na}else{break}}N=l+(na<<3)|0;if(Na<+h[N>>3]){h[N>>3]=Na;a[o+(Ma<<8)+na|0]=aa;Oa=0}else{Oa=0}do{Aa=+h[m+(Oa<<3)>>3];if(Aa!=0.0){N=n+(d[q+(Oa+38196)|0]<<3)|0;h[N>>3]=la*Aa+ +h[N>>3];N=n+(256-(d[q+(38452-Oa)|0]|0)<<3)|0;h[N>>3]=ma*Aa+ +h[N>>3]}Oa=Oa+1|0;}while((Oa|0)<256);UGb(M|0,pa|0,2048)|0;N=na+1|0;if((N|0)<256){na=N;Fa=Na}else{break}}oa=oa+1|0;}while((oa|0)<(P|0))}Ma=Ma+1|0;}while((Ma|0)<256);if((c[L>>2]|0)<=0){break}ma=+(fa|0);pa=q+38452|0;M=0;do{P=Q+(M<<2)|0;oa=s+(M<<2)|0;na=pa+(M<<2)|0;aa=0;N=c[P>>2]|0;while(1){if((N|0)>0){la=0.0;Fa=0.0;J=0;S=0;while(1){$=c[oa>>2]|0;O=$+(S<<9)+(aa<<4)|0;R=c[O>>2]|0;T=c[O+4>>2]|0;O=$+(S<<9)+(aa<<4)+8|0;$=c[O>>2]|0;D=c[O+4>>2]|0;O=YGb($,D,R,T)|0;wa=F;Aa=la+Fa;Da=0;if((S|0)!=0&(wa>>>0>Da>>>0|wa>>>0==Da>>>0&O>>>0>200>>>0)|Aa>200.0){if(Aa!=0.0){Pa=Fa*256.0/Aa}else{Pa=128.0}O=~~(Aa/ma);if((O|0)<0){Qa=0}else{Qa=(O|0)>255?255:O}O=~~+Hb(+Pa);if((O|0)<1){Ra=1}else{Ra=(O|0)>255?255:O}a[(c[na>>2]|0)+(J<<5)+aa|0]=a[o+(Ra<<8)+Qa|0]|0;O=J+1|0;if((O|0)<(S|0)){Da=J;wa=O;while(1){Ba=c[na>>2]|0;a[Ba+(wa<<5)+aa|0]=a[Ba+(Da<<5)+aa|0]|0;Ba=wa+1|0;if((Ba|0)<(S|0)){Da=wa;wa=Ba}else{Sa=S;break}}}else{Sa=O}wa=c[oa>>2]|0;Da=wa+(S<<9)+(aa<<4)|0;Ba=wa+(S<<9)+(aa<<4)+8|0;Ta=Pa;Ua=Sa;Va=0.0;Wa=0.0;Xa=c[Da+4>>2]|0;Ya=c[Da>>2]|0;Za=c[Ba+4>>2]|0;_a=c[Ba>>2]|0}else{Ta=128.0;Ua=J;Va=Fa;Wa=la;Xa=T;Ya=R;Za=D;_a=$}Aa=Wa+(+(Ya>>>0)+ +(Xa>>>0)*4294967296.0);ra=Va+(+(_a>>>0)+ +(Za>>>0)*4294967296.0);xa=Aa+ra;if(xa!=0.0){$a=ra*256.0/xa}else{$a=Ta}Ba=~~(xa/ma);if((Ba|0)<0){ab=0}else{ab=(Ba|0)>255?255:Ba}Ba=~~+Hb(+$a);if((Ba|0)<1){bb=1}else{bb=(Ba|0)>255?255:Ba}a[(c[na>>2]|0)+(S<<5)+aa|0]=a[o+(bb<<8)+ab|0]|0;Ba=S+1|0;Da=c[P>>2]|0;if((Ba|0)<(Da|0)){la=Aa;Fa=ra;J=Ua;S=Ba}else{cb=Da;break}}}else{cb=N}S=aa+1|0;if((S|0)<32){aa=S;N=cb}else{break}}M=M+1|0;}while((M|0)<(c[L>>2]|0))}}}while(0);if((c[u>>2]|0)>1){do{if((c[e+120>>2]|0)>352){db=2}else{if((c[e+124>>2]|0)>288){db=2;break}db=(c[y>>2]|0)==0?2:1}}while(0);cb=q+40800|0;c[cb>>2]=db;Ua=q+40804|0;ab=db;f:while(1){db=ab;while(1){c[Ua>>2]=db;if((db|0)>=(ab<<1|0)){break}bb=c[y>>2]|0;if((bb|0)==(ba(ab,db)|0)&(bb|0)<65|(bb|0)==0){break f}else{db=db+1|0}}db=ab+1|0;c[cb>>2]=db;if((db|0)<9){ab=db}else{A=183;break}}if((A|0)==183){yDb(e,16,2152168,(I=i,i=i+8|0,c[I>>2]=c[y>>2],I)|0);i=I;v=-38;i=f;return v|0}y=g|0;g=q+8|0;TGb(j|0,-128|0,1024)|0;TGb(y|0,-128|0,32)|0;ab=q+4|0;c[(c[ab>>2]|0)+100>>2]=536596;db=WDb(536596)|0;c[(c[ab>>2]|0)+96>>2]=db;db=c[ab>>2]|0;bb=c[db+96>>2]|0;if((bb|0)==0){v=-12;i=f;return v|0}eUa(g,bb,c[db+100>>2]|0);gUa(g,214748364,248);I9(g,y,c[u>>2]|0,0);db=c[u>>2]|0;if((db|0)>2){if((db|0)==3){c[q+4724>>2]=4;eb=4}else if((db|0)==4){c[q+4724>>2]=2;eb=2}else{eb=c[q+4724>>2]|0}I9(g,y,eb,0)}I9(g,y,c[C>>2]|0,0);if((c[C>>2]|0)>1){C=1;do{I9(g,y,(d[r+38196+C|0]|0)-(d[r+280+C|0]|0)|0,1);C=C+1|0;}while((C|0)<256)}I9(g,y,c[q+38488>>2]|0,0);I9(g,y,c[t>>2]|0,0);F9(g,y,c[B>>2]|0);I9(g,y,c[z>>2]|0,0);I9(g,y,c[K>>2]|0,0);F9(g,y,c[E>>2]|0);I9(g,y,(c[Ua>>2]|0)-1|0,0);I9(g,y,(c[cb>>2]|0)-1|0,0);I9(g,y,c[L>>2]|0,0);do{if((c[L>>2]|0)>0){cb=0;do{J9(g,r+17684+(cb*2560|0)|0);cb=cb+1|0;fb=c[L>>2]|0;}while((cb|0)<(fb|0));if((fb|0)>0){gb=0}else{break}do{cb=r+38164+(gb<<2)|0;Ua=c[cb>>2]|0;E=Ua<<5;g:do{if((E|0)>0){K=c[r+38452+(gb<<2)>>2]|0;if((K|0)==0){hb=Ua<<5;break}else{ib=0}while(1){if(!((a[K+ib|0]|0)==-128)){hb=ib;break g}z=ib+1|0;if((z|0)<(E|0)){ib=z}else{hb=z;break}}}else{hb=0}}while(0);do{if((hb|0)<(E|0)){F9(g,y,1);if((c[cb>>2]|0)<=0){break}Ua=r+38452+(gb<<2)|0;K=0;do{z=K-1|0;if((K|0)==0){B=0;do{I9(g,j+(B<<5)|0,(a[(c[Ua>>2]|0)+B|0]^-128)<<24>>24,1);B=B+1|0;}while((B|0)<32)}else{B=0;do{$=c[Ua>>2]|0;I9(g,j+(B<<5)|0,((a[$+(K<<5)+B|0]|0)-(a[$+(z<<5)+B|0]|0)&255)<<24>>24,1);B=B+1|0;}while((B|0)<32)}K=K+1|0;}while((K|0)<(c[cb>>2]|0))}else{F9(g,y,0)}}while(0);gb=gb+1|0;}while((gb|0)<(c[L>>2]|0))}}while(0);if((c[u>>2]|0)>2){I9(g,y,c[G>>2]|0,0);G=(c[(c[ab>>2]|0)+136>>2]|0)<2|0;c[q+38500>>2]=G;I9(g,y,G,0)}G=hUa(g)|0;c[(c[ab>>2]|0)+100>>2]=G;G=tBb(3)|0;g=c[ab>>2]|0;y=c[g+96>>2]|0;u=c[g+100>>2]|0;g=y+u|0;x=uBb(G,0,y,u)|0;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;g=(c[ab>>2]|0)+100|0;c[g>>2]=(c[g>>2]|0)+4}g=Ykb(r)|0;if((g|0)<0){v=g;i=f;return v|0}g=Xkb(r)|0;if((g|0)<0){v=g;i=f;return v|0}if((c[w>>2]&512|0)==0){v=0;i=f;return v|0}w=cEb(6291456)|0;c[e+668>>2]=w;if((w|0)==0){v=-12;i=f;return v|0}if((c[L>>2]|0)<=0){v=0;i=f;return v|0}w=q+40796|0;e=q+39772|0;q=0;h:while(1){g=Q+(q<<2)|0;r=0;while(1){if((r|0)>=(c[w>>2]|0)){break}ab=(c[e+(r<<2)>>2]|0)+4688+(q<<2)|0;if((c[ab>>2]|0)!=0){A=222;break h}u=cEb(c[g>>2]<<9)|0;c[ab>>2]=u;if((u|0)==0){v=-12;A=226;break h}r=r+1|0}r=q+1|0;if((r|0)<(c[L>>2]|0)){q=r}else{v=0;A=226;break}}if((A|0)==222){yDb(0,0,2007648,(I=i,i=i+24|0,c[I>>2]=2145320,c[I+8>>2]=1941120,c[I+16>>2]=969,I)|0);i=I;Cd();return 0}else if((A|0)==226){i=f;return v|0}return 0}function D9(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;h=i;i=i+48|0;j=h|0;k=h+32|0;l=h+40|0;m=c[b+60>>2]|0;n=m;o=m+39772|0;p=o;q=o;r=c[q>>2]|0;s=r+8|0;t=c[m+4760>>2]|0;a[k]=-128;u=ba(c[b+124>>2]|0,c[b+120>>2]|0)|0;v=u;w=(u|0)<0|0?-1:0;if((f|0)==0){if((c[b+88>>2]&512|0)==0){y=0;i=h;return y|0}u=c[b+668>>2]|0;z=u+6291456|0;A=m+592|0;B=A;TGb(A|0,0,4096)|0;A=m+38524|0;if((c[A>>2]|0)>0){C=m+4688|0;D=m+38164|0;E=0;do{TGb(c[C+(E<<2)>>2]|0,0,c[D+(E<<2)>>2]<<9|0)|0;E=E+1|0;}while((E|0)<(c[A>>2]|0))}E=m+40796|0;if((c[E>>2]|0)>0){D=m+38164|0;C=m+4688|0;G=0;do{H=c[p+(G<<2)>>2]|0;I=0;do{J=H+592+(I<<4)|0;K=B+(I<<4)|0;L=YGb(c[K>>2]|0,c[K+4>>2]|0,c[J>>2]|0,c[J+4>>2]|0)|0;c[K>>2]=L;c[K+4>>2]=F;K=H+592+(I<<4)+8|0;L=B+(I<<4)+8|0;J=YGb(c[L>>2]|0,c[L+4>>2]|0,c[K>>2]|0,c[K+4>>2]|0)|0;c[L>>2]=J;c[L+4>>2]=F;I=I+1|0;}while((I|0)<256);I=c[A>>2]|0;if((I|0)>0){L=0;do{J=c[D+(L<<2)>>2]|0;if((J|0)>0){K=c[H+4688+(L<<2)>>2]|0;M=c[C+(L<<2)>>2]|0;N=0;do{O=0;do{P=K+(N<<9)+(O<<4)|0;Q=M+(N<<9)+(O<<4)|0;R=YGb(c[Q>>2]|0,c[Q+4>>2]|0,c[P>>2]|0,c[P+4>>2]|0)|0;c[Q>>2]=R;c[Q+4>>2]=F;Q=K+(N<<9)+(O<<4)+8|0;R=M+(N<<9)+(O<<4)+8|0;P=YGb(c[R>>2]|0,c[R+4>>2]|0,c[Q>>2]|0,c[Q+4>>2]|0)|0;c[R>>2]=P;c[R+4>>2]=F;O=O+1|0;}while((O|0)<32);N=N+1|0;}while((N|0)<(J|0))}L=L+1|0;}while((L|0)<(I|0))}G=G+1|0;}while((G|0)<(c[E>>2]|0))}E=z;z=u;u=0;G=6291456;do{C=B+(u<<4)|0;D=c[C+4>>2]|0;I=B+(u<<4)+8|0;L=c[I>>2]|0;H=c[I+4>>2]|0;Lb(z|0,G|0,2189144,(S=i,i=i+32|0,c[S>>2]=c[C>>2],c[S+8>>2]=D,c[S+16>>2]=L,c[S+24>>2]=H,S)|0)|0;i=S;z=z+(SGb(z|0)|0)|0;u=u+1|0;G=E-z|0}while((u|0)<256);Lb(z|0,G|0,2111984,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S;G=c[A>>2]|0;if((G|0)>0){u=m+38164|0;B=m+4688|0;H=z;L=0;D=G;while(1){G=u+(L<<2)|0;if((c[G>>2]|0)>0){C=B+(L<<2)|0;I=H;J=0;while(1){N=0;T=I;do{M=c[C>>2]|0;K=M+(J<<9)+(N<<4)|0;O=c[K+4>>2]|0;R=M+(J<<9)+(N<<4)+8|0;M=c[R>>2]|0;P=c[R+4>>2]|0;Lb(T|0,E-T|0,2189144,(S=i,i=i+32|0,c[S>>2]=c[K>>2],c[S+8>>2]=O,c[S+16>>2]=M,c[S+24>>2]=P,S)|0)|0;i=S;T=T+(SGb(T|0)|0)|0;N=N+1|0;}while((N|0)<32);N=J+1|0;if((N|0)<(c[G>>2]|0)){I=T;J=N}else{break}}U=T;V=c[A>>2]|0}else{U=H;V=D}J=L+1|0;if((J|0)<(V|0)){H=U;L=J;D=V}else{W=U;break}}}else{W=z}Lb(W|0,E-W|0,2053424,(S=i,i=i+8|0,c[S>>2]=c[m+38520>>2],S)|0)|0;i=S;y=0;i=h;return y|0}W=gHb(v,w,140,0)|0;E=F;z=m+4720|0;if((c[z>>2]|0)>3){U=gHb(v,w,12,0)|0;X=F;Y=U}else{X=E;Y=W}W=YGb(Y,X,16384,0)|0;X=r0a(b,e,W,F)|0;if((X|0)<0){y=X;i=h;return y|0}X=e+24|0;W=e+28|0;eUa(s,c[X>>2]|0,c[W>>2]|0);gUa(s,214748364,248);KCb(t);Y=MCb(t,f)|0;if((Y|0)<0){y=Y;i=h;return y|0}Y=b+804|0;c[(c[Y>>2]|0)+88>>2]=1;t=c[b+136>>2]|0;do{if((t|0)==0){Z=36}else{if(((c[m+4756>>2]|0)%(t|0)|0|0)==0){Z=36;break}F9(s,k,0);c[(c[Y>>2]|0)+84>>2]=0}}while(0);a:do{if((Z|0)==36){F9(s,k,1);c[(c[Y>>2]|0)+84>>2]=1;t=m+38520|0;c[t>>2]=(c[t>>2]|0)+1;t=j|0;E=c[q>>2]|0;U=E+8|0;TGb(t|0,-128|0,32)|0;w=c[z>>2]|0;if((w|0)<2){I9(U,t,w,0);v=m+4796|0;I9(U,t,c[v>>2]|0,0);if((c[v>>2]|0)>1){v=1;do{I9(U,t,(d[n+38196+v|0]|0)-(d[E+280+v|0]|0)|0,1);v=v+1|0;}while((v|0)<256)}I9(U,t,c[m+38488>>2]|0,0);if((c[z>>2]|0)>0){I9(U,t,c[m+38512>>2]|0,0)}F9(U,t,c[m+4736>>2]|0);I9(U,t,c[m+4740>>2]|0,0);I9(U,t,c[m+4744>>2]|0,0);F9(U,t,c[m+4748>>2]|0);J9(U,m+15124|0);break}if((w|0)>=3){break}v=m+40796|0;I9(U,t,c[v>>2]|0,0);if((c[v>>2]|0)<=0){break}E=m+40804|0;V=m+4728|0;D=m+40800|0;L=m+4732|0;H=m+4792|0;A=m+4|0;T=0;b:while(1){B=c[n+39772+(T<<2)>>2]|0;u=ba((c[B+40816>>2]|0)+1|0,c[E>>2]|0)|0;I9(U,t,(u|0)/(c[V>>2]|0)|0,0);u=ba((c[B+40820>>2]|0)+1|0,c[D>>2]|0)|0;I9(U,t,(u|0)/(c[L>>2]|0)|0,0);u=ba((c[B+40808>>2]|0)+1|0,c[E>>2]|0)|0;I9(U,t,((u|0)/(c[V>>2]|0)|0)-1|0,0);u=ba((c[B+40812>>2]|0)+1|0,c[D>>2]|0)|0;I9(U,t,((u|0)/(c[L>>2]|0)|0)-1|0,0);u=0;while(1){if((u|0)>=(c[H>>2]|0)){break}B=n+4804+(u*2580|0)+2560|0;I9(U,t,c[B>>2]|0,0);if((c[B>>2]|0)==(c[(c[A>>2]|0)+572>>2]|0)){u=u+1|0}else{break b}}T=T+1|0;if((T|0)>=(c[v>>2]|0)){break a}}yDb(0,0,2007648,(S=i,i=i+24|0,c[S>>2]=2290168,c[S+8>>2]=1941120,c[S+16>>2]=533,S)|0);i=S;Cd();return 0}}while(0);if((c[m+4796>>2]|0)>1){n=1;do{q=a[m+(n+38196)|0]|0;a[r+280+n|0]=q;a[256-n+(r+24)|0]=-q;n=n+1|0;}while((n|0)<256)}n=m+40796|0;r=c[n>>2]|0;if((r|0)>1){q=1;j=r;while(1){k=c[p+(q<<2)>>2]|0;s=c[X>>2]|0;v=c[W>>2]|0;T=gHb(v,(v|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;A=eHb(T,F,j,(j|0)<0|0?-1:0)|0;eUa(k+8|0,s+A|0,(v|0)/(j|0)|0);v=q+1|0;A=c[n>>2]|0;if((v|0)<(A|0)){q=v;j=A}else{_=A;break}}}else{_=r}oe[c[b+824>>2]&63](b,710,o,0,_,4)|0;_=c[X>>2]|0;c:do{if((c[n>>2]|0)>0){o=m+38496|0;r=0;j=_;while(1){q=c[p+(r<<2)>>2]|0;if((c[q+4796>>2]|0)==0){A=q+572|0;v=c[A>>2]|0;s=q+568|0;if((v|0)<32){k=c[s>>2]<<v;c[s>>2]=k;v=q+580|0;T=k>>>24&255;while(1){k=c[v>>2]|0;c[v>>2]=k+1;a[k]=T;k=c[s>>2]|0;c[s>>2]=k<<8;t=(c[A>>2]|0)+8|0;c[A>>2]=t;if((t|0)<32){T=k>>>16&255}else{$=v;break}}}else{$=q+580|0}c[A>>2]=32;c[s>>2]=0;aa=(((c[$>>2]|0)-(c[q+576>>2]|0)<<3|7|0)/8|0)+(c[q+4800>>2]|0)|0}else{a[l]=-127;v=q+8|0;F9(v,l,0);aa=hUa(v)|0}if((r|0)>0){Z=66}else{if((c[z>>2]|0)>2){Z=66}else{ca=aa}}if((Z|0)==66){Z=0;if((aa|0)>=((c[W>>2]|0)/(c[n>>2]|0)|0|0)){Z=67;break}VGb(j|0,c[q+536>>2]|0,aa|0)|0;if((aa|0)>=16777216){Z=69;break}a[j+(aa+2)|0]=aa;a[j+(aa+1)|0]=aa>>>8;a[j+aa|0]=aa>>>16;ca=aa+3|0}if((c[o>>2]|0)==0){da=ca}else{v=ca+1|0;a[j+ca|0]=0;T=j+v|0;x=uBb(tBb(3)|0,0,j,v)|0;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;da=ca+5|0}T=j+da|0;v=r+1|0;if((v|0)<(c[n>>2]|0)){r=v;j=T}else{ea=T;break c}}if((Z|0)==67){yDb(0,0,2007648,(S=i,i=i+24|0,c[S>>2]=1969648,c[S+8>>2]=1941120,c[S+16>>2]=1281,S)|0);i=S;Cd();return 0}else if((Z|0)==69){yDb(0,0,2007648,(S=i,i=i+24|0,c[S>>2]=1916872,c[S+8>>2]=1941120,c[S+16>>2]=1283,S)|0);i=S;Cd();return 0}}else{ea=_}}while(0);if((c[b+88>>2]&512|0)!=0){a[c[b+668>>2]|0]=0}b=m+4756|0;c[b>>2]=(c[b>>2]|0)+1;c[W>>2]=ea-(c[X>>2]|0);X=f+136|0;f=c[X>>2]|0;ea=c[X+4>>2]|0;X=e+16|0;c[X>>2]=f;c[X+4>>2]=ea;X=e+8|0;c[X>>2]=f;c[X+4>>2]=ea;ea=e+36|0;c[ea>>2]=c[ea>>2]|c[(c[Y>>2]|0)+84>>2];c[g>>2]=1;y=0;i=h;return y|0}function E9(a){a=a|0;JCb(a+804|0);$kb(a)|0;return 0}function F9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b+4|0;h=c[g>>2]|0;i=(ba(d[e]|0,h)|0)>>8;j=h-i|0;if((f|0)==0){c[g>>2]=j;k=(d[e]|0)+(b+16)|0}else{f=b|0;c[f>>2]=(c[f>>2]|0)+j;c[g>>2]=i;k=(d[e]|0)+(b+272)|0}a[e]=a[k]|0;if((c[g>>2]|0)>=256){return}k=b+12|0;e=b|0;i=b+532|0;j=b+8|0;b=c[k>>2]|0;f=c[e>>2]|0;while(1){do{if((b|0)<0){h=f>>8;c[k>>2]=h;l=h;m=f}else{if((f|0)<65281){h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=-1;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>8;c[k>>2]=n;l=n;m=h;break}if((f|0)<=65535){c[j>>2]=(c[j>>2]|0)+1;l=b;m=f;break}h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b+1;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=0;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>>8&255;c[k>>2]=n;l=n;m=h}}while(0);h=m<<8&65280;c[e>>2]=h;n=c[g>>2]<<8;c[g>>2]=n;if((n|0)<256){b=l;f=h}else{break}}return}function G9(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0;h=i;i=i+704|0;j=h|0;k=h+32|0;l=h+40|0;m=h+88|0;n=h+696|0;o=c[g>>2]|0;g=o;p=o+4|0;q=c[(c[p>>2]|0)+60>>2]|0;r=q;s=o+40808|0;t=c[s>>2]|0;u=o+40812|0;v=c[u>>2]|0;w=o+40816|0;y=c[w>>2]|0;z=o+40820|0;A=c[z>>2]|0;B=q+4760|0;C=c[B>>2]|0;D=((e[(bFb(c[f+140>>2]|0)|0)+8>>1]|0)>>>2&7)+1|0;E=o+8|0;G=E;H=h+152|0;UGb(H|0,E|0,540)|0;I=C|0;J=c[I>>2]|0;K=ba(D,y)|0;L=C+32|0;M=K+(ba(c[L>>2]|0,A)|0)|0;N=C+4|0;O=c[N>>2]|0;P=C+36|0;Q=(ba(c[P>>2]|0,A)|0)+K|0;R=C+8|0;S=c[R>>2]|0;T=C+40|0;U=(ba(c[T>>2]|0,A)|0)+K|0;V=o+40828|0;c[V>>2]=0;W=q+4720|0;if((c[W>>2]|0)>3){TGb(m|0,0,60)|0;X=o+38512|0;Y=(c[X>>2]|0)<9;if((v|0)>0){Z=c[o+38492>>2]|0;_=(t|0)>0;$=t<<1;aa=0;do{if(_){ca=(aa|0)==0;da=0;ea=0;fa=0;ga=0;while(1){if(Y){ha=c[J+((ga<<2)+M+(ba(c[L>>2]|0,aa)|0))>>2]|0;ia=ha>>>16&255;ja=ha>>>8&255;ka=ha&255}else{ha=ga<<1;la=e[J+(ha+M+(ba(c[L>>2]|0,aa)|0))>>1]|0;ma=e[O+(ha+Q+(ba(c[P>>2]|0,aa)|0))>>1]|0;ia=e[S+(ha+U+(ba(c[T>>2]|0,aa)|0))>>1]|0;ja=ma;ka=la}la=ia-da|0;ma=ja-ea|0;ha=ka-fa|0;na=Z+(ga<<1)|0;if((ga|0)==0|ca){oa=Z+(ga+t<<1)|0;pa=Z+(ga+$<<1)|0}else{qa=ma-(b[na>>1]|0)|0;ra=Z+(ga+t<<1)|0;sa=Z+(ga+$<<1)|0;ta=la-qa-(b[sa>>1]|0)|0;ua=ha-qa-(b[ra>>1]|0)|0;va=0;while(1){wa=ba(c[1487496+(va<<3)>>2]|0,ta)|0;xa=((ba(c[1487500+(va<<3)>>2]|0,ua)|0)+wa>>2)+qa|0;wa=m+(va<<2)|0;c[wa>>2]=((xa|0)>-1?xa:-xa|0)+(c[wa>>2]|0);wa=va+1|0;if((wa|0)<15){va=wa}else{oa=ra;pa=sa;break}}}b[na>>1]=ma;b[oa>>1]=ha;b[pa>>1]=la;sa=ga+1|0;if((sa|0)<(t|0)){da=ia;ea=ja;fa=ka;ga=sa}else{break}}}aa=aa+1|0;}while((aa|0)<(v|0));ya=c[m+4>>2]|0;za=c[m>>2]|0;Aa=c[m+8>>2]|0;Ba=c[m+12>>2]|0;Ca=c[m+16>>2]|0;Da=c[m+20>>2]|0;Ea=c[m+24>>2]|0;Fa=c[m+28>>2]|0;Ga=c[m+32>>2]|0;Ha=c[m+36>>2]|0;Ia=c[m+40>>2]|0;Ja=c[m+44>>2]|0;Ka=c[m+48>>2]|0;La=c[m+52>>2]|0;Ma=c[m+56>>2]|0}else{ya=0;za=0;Aa=0;Ba=0;Ca=0;Da=0;Ea=0;Fa=0;Ga=0;Ha=0;Ia=0;Ja=0;Ka=0;La=0;Ma=0}aa=(ya|0)<(za|0)|0;za=(Aa|0)<(c[m+(aa<<2)>>2]|0)?2:aa;aa=(Ba|0)<(c[m+(za<<2)>>2]|0)?3:za;za=(Ca|0)<(c[m+(aa<<2)>>2]|0)?4:aa;aa=(Da|0)<(c[m+(za<<2)>>2]|0)?5:za;za=(Ea|0)<(c[m+(aa<<2)>>2]|0)?6:aa;aa=(Fa|0)<(c[m+(za<<2)>>2]|0)?7:za;za=(Ga|0)<(c[m+(aa<<2)>>2]|0)?8:aa;aa=(Ha|0)<(c[m+(za<<2)>>2]|0)?9:za;za=(Ia|0)<(c[m+(aa<<2)>>2]|0)?10:aa;aa=(Ja|0)<(c[m+(za<<2)>>2]|0)?11:za;za=(Ka|0)<(c[m+(aa<<2)>>2]|0)?12:aa;aa=(La|0)<(c[m+(za<<2)>>2]|0)?13:za;za=(Ma|0)<(c[m+(aa<<2)>>2]|0)?14:aa;c[o+40832>>2]=c[1487500+(za<<3)>>2];c[o+40836>>2]=c[1487496+(za<<3)>>2];Na=X}else{c[o+40832>>2]=1;c[o+40836>>2]=1;Na=o+38512|0}X=f+804|0;za=j|0;j=q+40804|0;aa=q+4728|0;m=q+40800|0;Ma=q+4732|0;La=q+4792|0;Ka=q+4|0;Ja=o+40832|0;Ia=o+40836|0;Ha=o+4796|0;Ga=n|0;n=o+4800|0;Fa=o+536|0;Ea=o+544|0;Da=o+588|0;Ca=o+576|0;Ba=o+584|0;Aa=o+580|0;ya=o+572|0;ka=o+568|0;ja=(A|y|0)==0;ia=q+38488|0;pa=-t|0;oa=q+4740|0;$=-v|0;Z=q+4744|0;Y=q+4736|0;q=o+4748|0;_=C+12|0;ga=C+44|0;C=o+4720|0;fa=f;f=o+38484|0;ea=o+38492|0;da=t+6|0;ca=da<<3;sa=(v|0)>0;ra=(t|0)>0;va=t-1|0;qa=t<<2;ua=o+4752|0;ta=o+592|0;wa=(ta|0)==0;xa=(ta|0)!=0;ta=o+540|0;o=t*35|0;Oa=l|0;Pa=l+12|0;Qa=l+24|0;Ra=l+36|0;a:while(1){if((c[(c[X>>2]|0)+84>>2]|0)!=0){_kb(r,g)}do{if((c[W>>2]|0)>2){TGb(za|0,-128|0,32)|0;Sa=ba((c[w>>2]|0)+1|0,c[j>>2]|0)|0;I9(G,za,(Sa|0)/(c[aa>>2]|0)|0,0);Sa=ba((c[z>>2]|0)+1|0,c[m>>2]|0)|0;I9(G,za,(Sa|0)/(c[Ma>>2]|0)|0,0);Sa=ba((c[s>>2]|0)+1|0,c[j>>2]|0)|0;I9(G,za,((Sa|0)/(c[aa>>2]|0)|0)-1|0,0);Sa=ba((c[u>>2]|0)+1|0,c[m>>2]|0)|0;I9(G,za,((Sa|0)/(c[Ma>>2]|0)|0)-1|0,0);Sa=0;while(1){if((Sa|0)>=(c[La>>2]|0)){break}Ta=r+4804+(Sa*2580|0)+2560|0;I9(G,za,c[Ta>>2]|0,0);if((c[Ta>>2]|0)==(c[(c[Ka>>2]|0)+572>>2]|0)){Sa=Sa+1|0}else{Ua=25;break a}}Sa=c[B>>2]|0;if((c[Sa+296>>2]|0)==0){I9(G,za,3,0)}else{I9(G,za,(c[Sa+300>>2]|0)==0?2:1,0)}I9(G,za,c[(c[B>>2]|0)+124>>2]|0,0);I9(G,za,c[(c[B>>2]|0)+128>>2]|0,0);if((c[W>>2]|0)<=3){break}F9(G,za,(c[V>>2]|0)==1|0);Sa=c[V>>2]|0;if((Sa|0)==1){_kb(r,g);Va=c[V>>2]|0}else{Va=Sa}I9(G,za,Va,0);if((c[V>>2]|0)==1){break}I9(G,za,c[Ja>>2]|0,0);I9(G,za,c[Ia>>2]|0,0)}}while(0);if((c[Ha>>2]|0)==0){if((c[W>>2]|0)>2){a[Ga]=-127;F9(G,Ga,0);if((c[W>>2]|0)>2|ja){Ua=38}else{Wa=0}}else{if(ja){Ua=38}else{Wa=0}}if((Ua|0)==38){Ua=0;Wa=hUa(G)|0}c[n>>2]=Wa;Sa=c[Fa>>2]|0;la=(c[Ea>>2]|0)-Sa-Wa|0;ha=(la|0)<0;ma=ha?0:Sa+Wa|0;Sa=ha?0:la;c[Da>>2]=Sa<<3;c[Ca>>2]=ma;c[Ba>>2]=ma+Sa;c[Aa>>2]=ma;c[ya>>2]=32;c[ka>>2]=0}do{if((c[ia>>2]|0)==0){ma=c[oa>>2]|0;Sa=-(pa>>ma)|0;la=c[Z>>2]|0;ha=-($>>la)|0;na=A>>la;la=c[L>>2]|0;Ta=H9(g,(c[I>>2]|0)+((ba(la,A)|0)+K)|0,t,v,la,0)|0;if((c[Y>>2]|0)==0){Xa=Ta}else{la=ba(y>>ma,D)|0;ma=c[P>>2]|0;Ya=H9(g,(c[N>>2]|0)+((ba(ma,na)|0)+la)|0,Sa,ha,ma,1)|0|Ta;Ta=c[T>>2]|0;Xa=Ya|(H9(g,(c[R>>2]|0)+((ba(Ta,na)|0)+la)|0,Sa,ha,Ta,1)|0)}if((c[q>>2]|0)==0){Za=Xa}else{Ta=c[ga>>2]|0;Za=H9(g,(c[_>>2]|0)+((ba(Ta,A)|0)+K)|0,t,v,Ta,2)|0|Xa}if((Za|0)<0){_a=Za}else{$a=0;Ua=314;break a}}else{Ta=(c[(c[p>>2]|0)+572>>2]|0)!=0?3:2;ha=c[Na>>2]|0;Sa=(ha|0)<9;la=(ha|0)>0?ha:8;ha=1<<la;c[f>>2]=0;TGb(c[ea>>2]|0,0,ba(ca,Ta)|0)|0;if(!sa){$a=0;Ua=314;break a}na=Ta<<1;Ya=Ta*3|0;ma=0;ab=0;b:while(1){bb=c[ea>>2]|0;cb=v-ma|0;db=0;do{eb=(cb+db|0)%(Ta|0)|0;c[l+(db<<2)>>2]=bb+((ba(eb,da)|0)+3<<1);c[l+12+(db<<2)>>2]=bb+((ba(eb+Ta|0,da)|0)+3<<1);c[l+24+(db<<2)>>2]=bb+((ba(eb+na|0,da)|0)+3<<1);c[l+36+(db<<2)>>2]=bb+((ba(eb+Ya|0,da)|0)+3<<1);db=db+1|0;}while((db|0)<(Ta|0));if(ra){db=c[Oa>>2]|0;bb=c[Pa>>2]|0;cb=c[Qa>>2]|0;eb=c[Ra>>2]|0;fb=0;gb=ab;while(1){if(Sa){hb=c[J+((fb<<2)+M+(ba(c[L>>2]|0,ma)|0))>>2]|0;ib=hb>>>24&65535;jb=hb>>>16&255;kb=hb>>>8&255;lb=hb&255}else{hb=fb<<1;mb=e[J+(hb+M+(ba(c[L>>2]|0,ma)|0))>>1]|0;nb=e[O+(hb+Q+(ba(c[P>>2]|0,ma)|0))>>1]|0;ib=gb;jb=e[S+(hb+U+(ba(c[T>>2]|0,ma)|0))>>1]|0;kb=nb;lb=mb}if((c[V>>2]|0)==1){ob=jb&65535;pb=kb&65535;qb=lb&65535}else{mb=lb-kb|0;nb=jb-kb|0;hb=ba(c[Ja>>2]|0,mb)|0;ob=nb+ha&65535;pb=(((ba(c[Ia>>2]|0,nb)|0)+hb|0)>>>2)+kb&65535;qb=mb+ha&65535}b[db+(fb<<1)>>1]=pb;b[bb+(fb<<1)>>1]=qb;b[cb+(fb<<1)>>1]=ob;b[eb+(fb<<1)>>1]=ib;mb=fb+1|0;if((mb|0)<(t|0)){fb=mb;gb=ib}else{rb=ib;break}}}else{rb=ab}if(((c[q>>2]|0)+3|0)>0){gb=0;while(1){fb=c[l+(gb*12|0)+4>>2]|0;eb=c[l+(gb*12|0)>>2]|0;b[eb-2>>1]=b[fb>>1]|0;b[fb+(t<<1)>>1]=b[fb+(va<<1)>>1]|0;cb=c[V>>2]|0;bb=gb+1|0;db=(bb|0)/2|0;c:do{if(Sa&(cb|0)==0){mb=c[f>>2]|0;if((c[Ha>>2]|0)==0){hb=c[Ca>>2]|0;if(((c[Ba>>2]|0)-hb-(32-(c[ya>>2]|0)+((c[Aa>>2]|0)-hb<<3)>>3)|0)<(qa|0)){Ua=63;break b}}else{if(((c[Ea>>2]|0)-(c[ta>>2]|0)|0)<(o|0)){Ua=61;break b}}do{if(ra){hb=g+4804+(db*2580|0)+1790|0;nb=g+4804+(db*2580|0)+2572|0;sb=g+4804+(db*2580|0)+2568|0;tb=g+4804+(db*2580|0)+2560|0;ub=l+(gb*12|0)+8|0;vb=0;wb=mb;xb=0;yb=0;while(1){zb=vb+1|0;Ab=vb-1|0;Bb=b[fb+(Ab<<1)>>1]|0;Cb=b[fb+(vb<<1)>>1]|0;Db=b[fb+(zb<<1)>>1]|0;Eb=b[eb+(Ab<<1)>>1]|0;if((b[hb>>1]|0)==0){Fb=(b[g+4804+(db*2580|0)+512+((Bb-Cb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+((Eb-Bb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1024+((Cb-Db&255)<<1)>>1]|0)|0}else{Fb=(b[g+4804+(db*2580|0)+512+((Bb-Cb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+((Eb-Bb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1024+((Cb-Db&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1536+(((e[eb+(vb-2<<1)>>1]|0)-Eb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+2048+(((e[(c[ub>>2]|0)+(vb<<1)>>1]|0)-Cb&255)<<1)>>1]|0)|0}Db=b[eb+(vb<<1)>>1]|0;Ab=Cb-Bb+Eb|0;do{if((Eb|0)>(Ab|0)){if((Cb|0)<=(Ab|0)){Gb=Ab;break}Gb=(Cb|0)>(Eb|0)?Eb:Cb}else{if((Ab|0)<=(Cb|0)){Gb=Ab;break}Gb=(Cb|0)>(Eb|0)?Cb:Eb}}while(0);Eb=Db-Gb|0;if((Fb|0)<0){Hb=-Fb|0;Ib=-Eb|0}else{Hb=Fb;Ib=Eb}Eb=Ib+256&511;Cb=Eb-256|0;do{if((c[Ha>>2]|0)==0){Ab=(Hb|0)==0?1:yb;if((Ab|0)==0){Jb=Cb;Kb=xb;Lb=wb}else{if((Cb|0)==0){Mb=Ab;Nb=xb+1|0;Ob=wb;break}Ab=d[1192248+wb|0]|0;Bb=1<<Ab;Pb=c[ka>>2]|0;Qb=c[ya>>2]|0;if((xb|0)<(Bb|0)){Rb=wb;Sb=xb;Tb=Ab;Ub=Pb;Vb=Qb}else{Ab=wb;Wb=xb;Xb=Bb;Bb=Pb;Pb=Qb;while(1){Qb=Wb-Xb|0;Yb=Ab+1|0;if((Pb|0)>1){Zb=Pb-1|0;_b=Bb<<1|1}else{$b=fe(1>>>((1-Pb|0)>>>0)|Bb<<Pb|0)|0;ac=c[Aa>>2]|0;x=$b;a[ac]=x;x=x>>8;a[ac+1|0]=x;x=x>>8;a[ac+2|0]=x;x=x>>8;a[ac+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;Zb=Pb+31|0;_b=1}c[ka>>2]=_b;c[ya>>2]=Zb;ac=d[1192248+Yb|0]|0;$b=1<<ac;if((Qb|0)<($b|0)){Rb=Yb;Sb=Qb;Tb=ac;Ub=_b;Vb=Zb;break}else{Ab=Yb;Wb=Qb;Xb=$b;Bb=_b;Pb=Zb}}}Pb=Tb+1|0;if((Vb|0)>(Pb|0)){bc=Vb-Pb|0;cc=Ub<<Pb|Sb}else{Bb=fe(Sb>>>((Pb-Vb|0)>>>0)|Ub<<Vb|0)|0;Pb=c[Aa>>2]|0;x=Bb;a[Pb]=x;x=x>>8;a[Pb+1|0]=x;x=x>>8;a[Pb+2|0]=x;x=x>>8;a[Pb+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;bc=Vb+31-Tb|0;cc=Sb}c[ka>>2]=cc;c[ya>>2]=bc;Jb=(((Cb|0)>0)<<31>>31)+Cb|0;Kb=0;Lb=(Rb|0)==0?0:Rb-1|0}Pb=c[nb>>2]|0;Bb=Pb+(Hb*6|0)+4|0;Xb=Jb+256-(a[Bb]|0)&511;Wb=Xb-256|0;Ab=Pb+(Hb*6|0)+5|0;$b=d[Ab]|0;Qb=Pb+(Hb*6|0)+2|0;Yb=e[Qb>>1]|0;if($b>>>0<Yb>>>0){ac=$b;dc=0;while(1){ec=dc+1|0;fc=ac<<1;if((fc|0)<(Yb|0)){ac=fc;dc=ec}else{gc=ec;break}}}else{gc=0}dc=Pb+(Hb*6|0)|0;ac=(((b[dc>>1]<<1)+$b>>31^Wb)*-2|0)-1|0;Yb=ac>>31^ac;ac=Yb>>gc;do{if((ac|0)<12){ec=ac+gc|0;fc=ec+1|0;hc=1<<gc;ic=(Yb&hc-1)+hc|0;hc=c[ka>>2]|0;jc=c[ya>>2]|0;if((jc|0)>(fc|0)){kc=jc-fc|0;lc=hc<<fc|ic;break}else{mc=fe(ic>>>((fc-jc|0)>>>0)|hc<<jc|0)|0;hc=c[Aa>>2]|0;x=mc;a[hc]=x;x=x>>8;a[hc+1|0]=x;x=x>>8;a[hc+2|0]=x;x=x>>8;a[hc+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;kc=31-ec+jc|0;lc=ic;break}}else{ic=Yb-11|0;jc=c[ka>>2]|0;ec=c[ya>>2]|0;if((ec|0)>21){kc=ec-21|0;lc=jc<<21|ic;break}else{hc=fe(ic>>>((21-ec|0)>>>0)|jc<<ec|0)|0;jc=c[Aa>>2]|0;x=hc;a[jc]=x;x=x>>8;a[jc+1|0]=x;x=x>>8;a[jc+2|0]=x;x=x>>8;a[jc+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;kc=ec+11|0;lc=ic;break}}}while(0);c[ka>>2]=lc;c[ya>>2]=kc;Yb=a[Ab]|0;ac=Yb&255;$b=(e[Qb>>1]|0)+((Wb|0)>-1?Wb:256-Xb|0)|0;Pb=(b[dc>>1]|0)+Wb|0;if(Yb<<24>>24==-128){nc=ac>>>1;oc=Pb>>1;pc=$b>>>1&32767}else{nc=ac;oc=Pb;pc=$b&65535}b[Qb>>1]=pc;$b=nc+1|0;Pb=~nc;do{if((oc|0)>(Pb|0)){if((oc|0)<=0){qc=oc&65535;break}ac=a[Bb]|0;if(!(ac<<24>>24==127)){a[Bb]=ac+1}ac=oc-$b|0;qc=(ac|0)>0?0:ac&65535}else{ac=a[Bb]|0;if(!(ac<<24>>24==-128)){a[Bb]=ac-1}ac=$b+oc|0;if((ac|0)>(Pb|0)){qc=ac&65535;break}qc=-nc&65535}}while(0);b[dc>>1]=qc;a[Ab]=$b;Mb=0;Nb=Kb;Ob=Lb}else{Pb=c[sb>>2]|0;Bb=Pb+(Hb<<5)|0;if((c[ua>>2]&512|0)==0){if((Cb|0)==0){F9(G,Bb,1);Mb=yb;Nb=xb;Ob=wb;break}Qb=(Cb|0)>-1?Cb:256-Eb|0;Wb=Qb>>>0>65535>>>0;Xb=Wb?Qb>>>16:Qb;ac=Wb?16:0;if((Xb&65280|0)==0){rc=ac;sc=Xb}else{rc=ac|8;sc=Xb>>>8}Xb=(d[1191992+sc|0]|0)+rc|0;F9(G,Bb,0);if((Xb|0)>=10){ac=0;while(1){Wb=ac+1|0;F9(G,((ac|0)>9?10:Wb)+(Pb+(Hb<<5))|0,1);if((Wb|0)<(Xb|0)){ac=Wb}else{break}}F9(G,Pb+(Hb<<5)+10|0,0);ac=Xb;while(1){$b=ac-1|0;F9(G,(($b|0)>9?31:ac+21|0)+(Pb+(Hb<<5))|0,Qb>>>($b>>>0)&1);if(($b|0)>0){ac=$b}else{break}}F9(G,Pb+(Hb<<5)+21|0,Cb>>>31);Mb=yb;Nb=xb;Ob=wb;break}if((Xb|0)>0){ac=0;do{ac=ac+1|0;F9(G,Pb+(Hb<<5)+ac|0,1);}while((ac|0)<(Xb|0));F9(G,Xb+1+(Pb+(Hb<<5))|0,0);ac=Xb;while(1){$b=ac-1|0;F9(G,ac+21+(Pb+(Hb<<5))|0,Qb>>>($b>>>0)&1);if(($b|0)>0){ac=$b}else{break}}}else{F9(G,Pb+(Hb<<5)+1|0,0)}F9(G,Xb+11+(Pb+(Hb<<5))|0,Cb>>>31);Mb=yb;Nb=xb;Ob=wb;break}ac=c[g+4688+(c[tb>>2]<<2)>>2]|0;if((Cb|0)==0){if(!wa){Qb=g+592+(d[Bb]<<4)+8|0;$b=YGb(c[Qb>>2]|0,c[Qb+4>>2]|0,1,0)|0;c[Qb>>2]=$b;c[Qb+4>>2]=F;Qb=ac+(Hb<<9)+8|0;$b=YGb(c[Qb>>2]|0,c[Qb+4>>2]|0,1,0)|0;c[Qb>>2]=$b;c[Qb+4>>2]=F}F9(G,Bb,1);Mb=yb;Nb=xb;Ob=wb;break}Qb=(Cb|0)>-1?Cb:256-Eb|0;$b=Qb>>>0>65535>>>0;Ab=$b?Qb>>>16:Qb;dc=$b?16:0;if((Ab&65280|0)==0){tc=dc;uc=Ab}else{tc=dc|8;uc=Ab>>>8}Ab=(d[1191992+uc|0]|0)+tc|0;if(xa){dc=g+592+(d[Bb]<<4)|0;$b=YGb(c[dc>>2]|0,c[dc+4>>2]|0,1,0)|0;c[dc>>2]=$b;c[dc+4>>2]=F;dc=ac+(Hb<<9)|0;$b=YGb(c[dc>>2]|0,c[dc+4>>2]|0,1,0)|0;c[dc>>2]=$b;c[dc+4>>2]=F}F9(G,Bb,0);if((Ab|0)>=10){dc=0;while(1){if(xa){$b=dc+1|0;Wb=(dc|0)>9?10:$b;Yb=g+592+(d[Pb+(Hb<<5)+Wb|0]<<4)+8|0;ic=YGb(c[Yb>>2]|0,c[Yb+4>>2]|0,1,0)|0;c[Yb>>2]=ic;c[Yb+4>>2]=F;Yb=ac+(Hb<<9)+(Wb<<4)+8|0;Wb=YGb(c[Yb>>2]|0,c[Yb+4>>2]|0,1,0)|0;c[Yb>>2]=Wb;c[Yb+4>>2]=F;vc=$b}else{vc=dc+1|0}F9(G,((dc|0)>9?10:vc)+(Pb+(Hb<<5))|0,1);if((vc|0)<(Ab|0)){dc=vc}else{break}}dc=Pb+(Hb<<5)+10|0;if(xa){Bb=g+592+(d[dc]<<4)|0;Xb=YGb(c[Bb>>2]|0,c[Bb+4>>2]|0,1,0)|0;c[Bb>>2]=Xb;c[Bb+4>>2]=F;Bb=ac+(Hb<<9)+160|0;Xb=YGb(c[Bb>>2]|0,c[Bb+4>>2]|0,1,0)|0;c[Bb>>2]=Xb;c[Bb+4>>2]=F;F9(G,dc,0);Bb=Ab;while(1){Xb=Bb-1|0;$b=Qb>>>(Xb>>>0)&1;Yb=(Xb|0)>9?31:Bb+21|0;Wb=Pb+(Hb<<5)+Yb|0;ic=g+592+(d[Wb]<<4)+($b<<3)|0;ec=YGb(c[ic>>2]|0,c[ic+4>>2]|0,1,0)|0;c[ic>>2]=ec;c[ic+4>>2]=F;ic=ac+(Hb<<9)+(Yb<<4)+($b<<3)|0;Yb=YGb(c[ic>>2]|0,c[ic+4>>2]|0,1,0)|0;c[ic>>2]=Yb;c[ic+4>>2]=F;F9(G,Wb,$b);if((Xb|0)>0){Bb=Xb}else{break}}}else{F9(G,dc,0);Bb=Ab;while(1){Xb=Bb-1|0;F9(G,((Xb|0)>9?31:Bb+21|0)+(Pb+(Hb<<5))|0,Qb>>>(Xb>>>0)&1);if((Xb|0)>0){Bb=Xb}else{break}}}if(xa){Bb=Cb>>>31;dc=Pb+(Hb<<5)+21|0;Xb=g+592+(d[dc]<<4)+(Bb<<3)|0;$b=YGb(c[Xb>>2]|0,c[Xb+4>>2]|0,1,0)|0;c[Xb>>2]=$b;c[Xb+4>>2]=F;Xb=ac+(Hb<<9)+336+(Bb<<3)|0;$b=YGb(c[Xb>>2]|0,c[Xb+4>>2]|0,1,0)|0;c[Xb>>2]=$b;c[Xb+4>>2]=F;wc=dc;xc=Bb}else{wc=Pb+(Hb<<5)+21|0;xc=Cb>>>31}F9(G,wc,xc);Mb=yb;Nb=xb;Ob=wb;break}Bb=(Ab|0)>0;if(Bb){if(xa){dc=0;do{dc=dc+1|0;Xb=Pb+(Hb<<5)+dc|0;$b=g+592+(d[Xb]<<4)+8|0;Wb=YGb(c[$b>>2]|0,c[$b+4>>2]|0,1,0)|0;c[$b>>2]=Wb;c[$b+4>>2]=F;$b=ac+(Hb<<9)+(dc<<4)+8|0;Wb=YGb(c[$b>>2]|0,c[$b+4>>2]|0,1,0)|0;c[$b>>2]=Wb;c[$b+4>>2]=F;F9(G,Xb,1);}while((dc|0)<(Ab|0))}else{dc=0;do{dc=dc+1|0;F9(G,Pb+(Hb<<5)+dc|0,1);}while((dc|0)<(Ab|0))}yc=Ab+1|0}else{yc=1}dc=Pb+(Hb<<5)+yc|0;if(xa){Xb=g+592+(d[dc]<<4)|0;$b=YGb(c[Xb>>2]|0,c[Xb+4>>2]|0,1,0)|0;c[Xb>>2]=$b;c[Xb+4>>2]=F;Xb=ac+(Hb<<9)+(yc<<4)|0;$b=YGb(c[Xb>>2]|0,c[Xb+4>>2]|0,1,0)|0;c[Xb>>2]=$b;c[Xb+4>>2]=F}F9(G,dc,0);dc=Ab-1|0;if(Bb){if(xa){Xb=Ab;$b=dc;while(1){Wb=Qb>>>($b>>>0)&1;ic=Xb+21|0;Yb=Pb+(Hb<<5)+ic|0;ec=g+592+(d[Yb]<<4)+(Wb<<3)|0;jc=YGb(c[ec>>2]|0,c[ec+4>>2]|0,1,0)|0;c[ec>>2]=jc;c[ec+4>>2]=F;ec=ac+(Hb<<9)+(ic<<4)+(Wb<<3)|0;ic=YGb(c[ec>>2]|0,c[ec+4>>2]|0,1,0)|0;c[ec>>2]=ic;c[ec+4>>2]=F;F9(G,Yb,Wb);if(($b|0)>0){Xb=$b;$b=$b-1|0}else{break}}}else{$b=Ab;Xb=dc;while(1){F9(G,$b+21+(Pb+(Hb<<5))|0,Qb>>>(Xb>>>0)&1);if((Xb|0)>0){$b=Xb;Xb=Xb-1|0}else{break}}}}if(xa){Xb=Cb>>>31;$b=Ab+11|0;Qb=Pb+(Hb<<5)+$b|0;dc=g+592+(d[Qb]<<4)+(Xb<<3)|0;Bb=YGb(c[dc>>2]|0,c[dc+4>>2]|0,1,0)|0;c[dc>>2]=Bb;c[dc+4>>2]=F;dc=ac+(Hb<<9)+($b<<4)+(Xb<<3)|0;$b=YGb(c[dc>>2]|0,c[dc+4>>2]|0,1,0)|0;c[dc>>2]=$b;c[dc+4>>2]=F;zc=Qb;Ac=Xb}else{zc=Ab+11+(Pb+(Hb<<5))|0;Ac=Cb>>>31}F9(G,zc,Ac);Mb=yb;Nb=xb;Ob=wb}}while(0);if((zb|0)<(t|0)){vb=zb;wb=Ob;xb=Nb;yb=Mb}else{break}}if((Mb|0)==0){Bc=Ob;break}yb=1<<d[1192248+Ob|0];if((Nb|0)<(yb|0)){Cc=Ob;Dc=Nb}else{xb=Ob;wb=Nb;vb=yb;yb=c[ka>>2]|0;tb=c[ya>>2]|0;while(1){sb=wb-vb|0;nb=xb+1|0;if((tb|0)>1){Ec=tb-1|0;Fc=yb<<1|1}else{ub=fe(1>>>((1-tb|0)>>>0)|yb<<tb|0)|0;hb=c[Aa>>2]|0;x=ub;a[hb]=x;x=x>>8;a[hb+1|0]=x;x=x>>8;a[hb+2|0]=x;x=x>>8;a[hb+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;Ec=tb+31|0;Fc=1}c[ka>>2]=Fc;c[ya>>2]=Ec;hb=1<<d[1192248+nb|0];if((sb|0)<(hb|0)){Cc=nb;Dc=sb;break}else{xb=nb;wb=sb;vb=hb;yb=Fc;tb=Ec}}}if((Dc|0)==0){Bc=Cc;break}tb=c[ka>>2]|0;yb=c[ya>>2]|0;if((yb|0)>1){Gc=yb-1|0;Hc=tb<<1|1}else{vb=fe(1>>>((1-yb|0)>>>0)|tb<<yb|0)|0;tb=c[Aa>>2]|0;x=vb;a[tb]=x;x=x>>8;a[tb+1|0]=x;x=x>>8;a[tb+2|0]=x;x=x>>8;a[tb+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;Gc=yb+31|0;Hc=1}c[ka>>2]=Hc;c[ya>>2]=Gc;Bc=Cc}else{Bc=mb}}while(0);c[f>>2]=Bc}else{mb=((cb|0)!=1)+la|0;yb=c[f>>2]|0;if((c[Ha>>2]|0)==0){tb=c[Ca>>2]|0;if(((c[Ba>>2]|0)-tb-(32-(c[ya>>2]|0)+((c[Aa>>2]|0)-tb<<3)>>3)|0)<(qa|0)){Ua=181;break b}}else{if(((c[Ea>>2]|0)-(c[ta>>2]|0)|0)<(o|0)){Ua=179;break b}}if((cb|0)==1){if(!ra){break}tb=(mb|0)>0;vb=0;while(1){wb=b[eb+(vb<<1)>>1]|0;if(tb){xb=mb;do{xb=xb-1|0;a[k]=-128;F9(G,k,wb>>>(xb>>>0)&1);}while((xb|0)>0)}vb=vb+1|0;if((vb|0)>=(t|0)){break c}}}do{if(ra){vb=g+4804+(db*2580|0)+1790|0;tb=(mb|0)==8;xb=g+4804+(db*2580|0)+2572|0;wb=mb+12|0;hb=20-mb|0;sb=1<<mb-1;nb=(1<<mb)-1|0;ub=g+4804+(db*2580|0)+2568|0;Cb=g+4804+(db*2580|0)+2560|0;Eb=l+(gb*12|0)+8|0;Db=0;Xb=yb;Qb=0;dc=0;while(1){$b=Db+1|0;Bb=Db-1|0;Wb=b[fb+(Bb<<1)>>1]|0;Yb=b[fb+(Db<<1)>>1]|0;ec=b[fb+($b<<1)>>1]|0;ic=b[eb+(Bb<<1)>>1]|0;if((b[vb>>1]|0)==0){Ic=(b[g+4804+(db*2580|0)+512+((Wb-Yb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+((ic-Wb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1024+((Yb-ec&255)<<1)>>1]|0)|0}else{Ic=(b[g+4804+(db*2580|0)+512+((Wb-Yb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+((ic-Wb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1024+((Yb-ec&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1536+(((e[eb+(Db-2<<1)>>1]|0)-ic&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+2048+(((e[(c[Eb>>2]|0)+(Db<<1)>>1]|0)-Yb&255)<<1)>>1]|0)|0}ec=b[eb+(Db<<1)>>1]|0;Bb=Yb-Wb+ic|0;do{if((ic|0)>(Bb|0)){if((Yb|0)<=(Bb|0)){Jc=Bb;break}Jc=(Yb|0)>(ic|0)?ic:Yb}else{if((Bb|0)<=(Yb|0)){Jc=Bb;break}Jc=(Yb|0)>(ic|0)?Yb:ic}}while(0);ic=ec-Jc|0;if((Ic|0)<0){Kc=-Ic|0;Lc=-ic|0}else{Kc=Ic;Lc=ic}if(tb){Mc=Lc<<24>>24}else{Mc=(Lc+sb&nb)-sb|0}do{if((c[Ha>>2]|0)==0){ic=(Kc|0)==0?1:dc;if((ic|0)==0){Nc=Mc;Oc=Qb;Pc=Xb}else{if((Mc|0)==0){Qc=ic;Rc=Qb+1|0;Sc=Xb;break}ic=d[1192248+Xb|0]|0;Yb=1<<ic;Bb=c[ka>>2]|0;zb=c[ya>>2]|0;if((Qb|0)<(Yb|0)){Tc=Xb;Uc=Qb;Vc=ic;Wc=Bb;Xc=zb}else{ic=Xb;Wb=Qb;jc=Yb;Yb=Bb;Bb=zb;while(1){zb=Wb-jc|0;hc=ic+1|0;if((Bb|0)>1){Yc=Bb-1|0;Zc=Yb<<1|1}else{mc=fe(1>>>((1-Bb|0)>>>0)|Yb<<Bb|0)|0;fc=c[Aa>>2]|0;x=mc;a[fc]=x;x=x>>8;a[fc+1|0]=x;x=x>>8;a[fc+2|0]=x;x=x>>8;a[fc+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;Yc=Bb+31|0;Zc=1}c[ka>>2]=Zc;c[ya>>2]=Yc;fc=d[1192248+hc|0]|0;mc=1<<fc;if((zb|0)<(mc|0)){Tc=hc;Uc=zb;Vc=fc;Wc=Zc;Xc=Yc;break}else{ic=hc;Wb=zb;jc=mc;Yb=Zc;Bb=Yc}}}Bb=Vc+1|0;if((Xc|0)>(Bb|0)){_c=Xc-Bb|0;$c=Wc<<Bb|Uc}else{Yb=fe(Uc>>>((Bb-Xc|0)>>>0)|Wc<<Xc|0)|0;Bb=c[Aa>>2]|0;x=Yb;a[Bb]=x;x=x>>8;a[Bb+1|0]=x;x=x>>8;a[Bb+2|0]=x;x=x>>8;a[Bb+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;_c=Xc+31-Vc|0;$c=Uc}c[ka>>2]=$c;c[ya>>2]=_c;Nc=(((Mc|0)>0)<<31>>31)+Mc|0;Oc=0;Pc=(Tc|0)==0?0:Tc-1|0}Bb=c[xb>>2]|0;Yb=Bb+(Kc*6|0)+4|0;jc=Nc-(a[Yb]|0)|0;if(tb){ad=jc<<24>>24}else{ad=(jc+sb&nb)-sb|0}jc=Bb+(Kc*6|0)+5|0;Wb=d[jc]|0;ic=Bb+(Kc*6|0)+2|0;Pb=e[ic>>1]|0;if(Wb>>>0<Pb>>>0){Ab=Wb;ac=0;while(1){mc=ac+1|0;zb=Ab<<1;if((zb|0)<(Pb|0)){Ab=zb;ac=mc}else{bd=mc;break}}}else{bd=0}ac=Bb+(Kc*6|0)|0;Ab=(((b[ac>>1]<<1)+Wb>>31^ad)*-2|0)-1|0;Pb=Ab>>31^Ab;Ab=Pb>>bd;do{if((Ab|0)<12){mc=Ab+bd|0;zb=mc+1|0;hc=1<<bd;fc=(Pb&hc-1)+hc|0;hc=c[ka>>2]|0;cd=c[ya>>2]|0;if((cd|0)>(zb|0)){dd=cd-zb|0;ed=hc<<zb|fc;break}else{fd=fe(fc>>>((zb-cd|0)>>>0)|hc<<cd|0)|0;hc=c[Aa>>2]|0;x=fd;a[hc]=x;x=x>>8;a[hc+1|0]=x;x=x>>8;a[hc+2|0]=x;x=x>>8;a[hc+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;dd=31-mc+cd|0;ed=fc;break}}else{fc=Pb-11|0;cd=c[ka>>2]|0;mc=c[ya>>2]|0;if((mc|0)>(wb|0)){dd=mc-wb|0;ed=cd<<wb|fc;break}else{hc=fe(fc>>>((wb-mc|0)>>>0)|cd<<mc|0)|0;cd=c[Aa>>2]|0;x=hc;a[cd]=x;x=x>>8;a[cd+1|0]=x;x=x>>8;a[cd+2|0]=x;x=x>>8;a[cd+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;dd=hb+mc|0;ed=fc;break}}}while(0);c[ka>>2]=ed;c[ya>>2]=dd;Pb=a[jc]|0;Ab=Pb&255;Wb=(e[ic>>1]|0)+((ad|0)>-1?ad:-ad|0)|0;Bb=(b[ac>>1]|0)+ad|0;if(Pb<<24>>24==-128){gd=Ab>>>1;hd=Bb>>1;id=Wb>>>1&32767}else{gd=Ab;hd=Bb;id=Wb&65535}b[ic>>1]=id;Wb=gd+1|0;Bb=~gd;do{if((hd|0)>(Bb|0)){if((hd|0)<=0){jd=hd&65535;break}Ab=a[Yb]|0;if(!(Ab<<24>>24==127)){a[Yb]=Ab+1}Ab=hd-Wb|0;jd=(Ab|0)>0?0:Ab&65535}else{Ab=a[Yb]|0;if(!(Ab<<24>>24==-128)){a[Yb]=Ab-1}Ab=Wb+hd|0;if((Ab|0)>(Bb|0)){jd=Ab&65535;break}jd=-gd&65535}}while(0);b[ac>>1]=jd;a[jc]=Wb;Qc=0;Rc=Oc;Sc=Pc}else{Bb=c[ub>>2]|0;Yb=Bb+(Kc<<5)|0;if((c[ua>>2]&512|0)==0){if((Mc|0)==0){F9(G,Yb,1);Qc=dc;Rc=Qb;Sc=Xb;break}ic=(Mc|0)>-1?Mc:-Mc|0;Ab=ic>>>0>65535>>>0;Pb=Ab?ic>>>16:ic;fc=Ab?16:0;if((Pb&65280|0)==0){kd=fc;ld=Pb}else{kd=fc|8;ld=Pb>>>8}Pb=(d[1191992+ld|0]|0)+kd|0;F9(G,Yb,0);if((Pb|0)>=10){fc=0;while(1){Ab=fc+1|0;F9(G,((fc|0)>9?10:Ab)+(Bb+(Kc<<5))|0,1);if((Ab|0)<(Pb|0)){fc=Ab}else{break}}F9(G,Bb+(Kc<<5)+10|0,0);fc=Pb;while(1){Wb=fc-1|0;F9(G,((Wb|0)>9?31:fc+21|0)+(Bb+(Kc<<5))|0,ic>>>(Wb>>>0)&1);if((Wb|0)>0){fc=Wb}else{break}}F9(G,Bb+(Kc<<5)+21|0,Mc>>>31);Qc=dc;Rc=Qb;Sc=Xb;break}if((Pb|0)>0){fc=0;do{fc=fc+1|0;F9(G,Bb+(Kc<<5)+fc|0,1);}while((fc|0)<(Pb|0));F9(G,Pb+1+(Bb+(Kc<<5))|0,0);fc=Pb;while(1){Wb=fc-1|0;F9(G,fc+21+(Bb+(Kc<<5))|0,ic>>>(Wb>>>0)&1);if((Wb|0)>0){fc=Wb}else{break}}}else{F9(G,Bb+(Kc<<5)+1|0,0)}F9(G,Pb+11+(Bb+(Kc<<5))|0,Mc>>>31);Qc=dc;Rc=Qb;Sc=Xb;break}fc=c[g+4688+(c[Cb>>2]<<2)>>2]|0;if((Mc|0)==0){ic=g+592+(d[Yb]<<4)+8|0;Wb=YGb(c[ic>>2]|0,c[ic+4>>2]|0,1,0)|0;c[ic>>2]=Wb;c[ic+4>>2]=F;ic=fc+(Kc<<9)+8|0;Wb=YGb(c[ic>>2]|0,c[ic+4>>2]|0,1,0)|0;c[ic>>2]=Wb;c[ic+4>>2]=F;F9(G,Yb,1);Qc=dc;Rc=Qb;Sc=Xb;break}ic=(Mc|0)>-1?Mc:-Mc|0;Wb=ic>>>0>65535>>>0;jc=Wb?ic>>>16:ic;ac=Wb?16:0;if((jc&65280|0)==0){md=ac;nd=jc}else{md=ac|8;nd=jc>>>8}jc=(d[1191992+nd|0]|0)+md|0;if(xa){ac=g+592+(d[Yb]<<4)|0;Wb=YGb(c[ac>>2]|0,c[ac+4>>2]|0,1,0)|0;c[ac>>2]=Wb;c[ac+4>>2]=F;ac=fc+(Kc<<9)|0;Wb=YGb(c[ac>>2]|0,c[ac+4>>2]|0,1,0)|0;c[ac>>2]=Wb;c[ac+4>>2]=F}F9(G,Yb,0);if((jc|0)>=10){ac=0;while(1){if(xa){Wb=ac+1|0;Ab=(ac|0)>9?10:Wb;mc=g+592+(d[Bb+(Kc<<5)+Ab|0]<<4)+8|0;cd=YGb(c[mc>>2]|0,c[mc+4>>2]|0,1,0)|0;c[mc>>2]=cd;c[mc+4>>2]=F;mc=fc+(Kc<<9)+(Ab<<4)+8|0;Ab=YGb(c[mc>>2]|0,c[mc+4>>2]|0,1,0)|0;c[mc>>2]=Ab;c[mc+4>>2]=F;od=Wb}else{od=ac+1|0}F9(G,((ac|0)>9?10:od)+(Bb+(Kc<<5))|0,1);if((od|0)<(jc|0)){ac=od}else{break}}ac=Bb+(Kc<<5)+10|0;if(xa){Yb=g+592+(d[ac]<<4)|0;Pb=YGb(c[Yb>>2]|0,c[Yb+4>>2]|0,1,0)|0;c[Yb>>2]=Pb;c[Yb+4>>2]=F;Yb=fc+(Kc<<9)+160|0;Pb=YGb(c[Yb>>2]|0,c[Yb+4>>2]|0,1,0)|0;c[Yb>>2]=Pb;c[Yb+4>>2]=F;F9(G,ac,0);Yb=jc;while(1){Pb=Yb-1|0;Wb=ic>>>(Pb>>>0)&1;mc=(Pb|0)>9?31:Yb+21|0;Ab=Bb+(Kc<<5)+mc|0;cd=g+592+(d[Ab]<<4)+(Wb<<3)|0;hc=YGb(c[cd>>2]|0,c[cd+4>>2]|0,1,0)|0;c[cd>>2]=hc;c[cd+4>>2]=F;cd=fc+(Kc<<9)+(mc<<4)+(Wb<<3)|0;mc=YGb(c[cd>>2]|0,c[cd+4>>2]|0,1,0)|0;c[cd>>2]=mc;c[cd+4>>2]=F;F9(G,Ab,Wb);if((Pb|0)>0){Yb=Pb}else{break}}}else{F9(G,ac,0);Yb=jc;while(1){Pb=Yb-1|0;F9(G,((Pb|0)>9?31:Yb+21|0)+(Bb+(Kc<<5))|0,ic>>>(Pb>>>0)&1);if((Pb|0)>0){Yb=Pb}else{break}}}if(xa){Yb=Mc>>>31;ac=Bb+(Kc<<5)+21|0;Pb=g+592+(d[ac]<<4)+(Yb<<3)|0;Wb=YGb(c[Pb>>2]|0,c[Pb+4>>2]|0,1,0)|0;c[Pb>>2]=Wb;c[Pb+4>>2]=F;Pb=fc+(Kc<<9)+336+(Yb<<3)|0;Wb=YGb(c[Pb>>2]|0,c[Pb+4>>2]|0,1,0)|0;c[Pb>>2]=Wb;c[Pb+4>>2]=F;pd=ac;qd=Yb}else{pd=Bb+(Kc<<5)+21|0;qd=Mc>>>31}F9(G,pd,qd);Qc=dc;Rc=Qb;Sc=Xb;break}Yb=(jc|0)>0;if(Yb){if(xa){ac=0;do{ac=ac+1|0;Pb=Bb+(Kc<<5)+ac|0;Wb=g+592+(d[Pb]<<4)+8|0;Ab=YGb(c[Wb>>2]|0,c[Wb+4>>2]|0,1,0)|0;c[Wb>>2]=Ab;c[Wb+4>>2]=F;Wb=fc+(Kc<<9)+(ac<<4)+8|0;Ab=YGb(c[Wb>>2]|0,c[Wb+4>>2]|0,1,0)|0;c[Wb>>2]=Ab;c[Wb+4>>2]=F;F9(G,Pb,1);}while((ac|0)<(jc|0))}else{ac=0;do{ac=ac+1|0;F9(G,Bb+(Kc<<5)+ac|0,1);}while((ac|0)<(jc|0))}rd=jc+1|0}else{rd=1}ac=Bb+(Kc<<5)+rd|0;if(xa){Pb=g+592+(d[ac]<<4)|0;Wb=YGb(c[Pb>>2]|0,c[Pb+4>>2]|0,1,0)|0;c[Pb>>2]=Wb;c[Pb+4>>2]=F;Pb=fc+(Kc<<9)+(rd<<4)|0;Wb=YGb(c[Pb>>2]|0,c[Pb+4>>2]|0,1,0)|0;c[Pb>>2]=Wb;c[Pb+4>>2]=F}F9(G,ac,0);ac=jc-1|0;if(Yb){if(xa){Pb=jc;Wb=ac;while(1){Ab=ic>>>(Wb>>>0)&1;cd=Pb+21|0;mc=Bb+(Kc<<5)+cd|0;hc=g+592+(d[mc]<<4)+(Ab<<3)|0;fd=YGb(c[hc>>2]|0,c[hc+4>>2]|0,1,0)|0;c[hc>>2]=fd;c[hc+4>>2]=F;hc=fc+(Kc<<9)+(cd<<4)+(Ab<<3)|0;cd=YGb(c[hc>>2]|0,c[hc+4>>2]|0,1,0)|0;c[hc>>2]=cd;c[hc+4>>2]=F;F9(G,mc,Ab);if((Wb|0)>0){Pb=Wb;Wb=Wb-1|0}else{break}}}else{Wb=jc;Pb=ac;while(1){F9(G,Wb+21+(Bb+(Kc<<5))|0,ic>>>(Pb>>>0)&1);if((Pb|0)>0){Wb=Pb;Pb=Pb-1|0}else{break}}}}if(xa){Pb=Mc>>>31;Wb=jc+11|0;ic=Bb+(Kc<<5)+Wb|0;ac=g+592+(d[ic]<<4)+(Pb<<3)|0;Yb=YGb(c[ac>>2]|0,c[ac+4>>2]|0,1,0)|0;c[ac>>2]=Yb;c[ac+4>>2]=F;ac=fc+(Kc<<9)+(Wb<<4)+(Pb<<3)|0;Wb=YGb(c[ac>>2]|0,c[ac+4>>2]|0,1,0)|0;c[ac>>2]=Wb;c[ac+4>>2]=F;sd=ic;td=Pb}else{sd=jc+11+(Bb+(Kc<<5))|0;td=Mc>>>31}F9(G,sd,td);Qc=dc;Rc=Qb;Sc=Xb}}while(0);if(($b|0)<(t|0)){Db=$b;Xb=Sc;Qb=Rc;dc=Qc}else{break}}if((Qc|0)==0){ud=Sc;break}dc=1<<d[1192248+Sc|0];if((Rc|0)<(dc|0)){vd=Sc;wd=Rc}else{Qb=Sc;Xb=Rc;Db=dc;dc=c[ka>>2]|0;Cb=c[ya>>2]|0;while(1){ub=Xb-Db|0;hb=Qb+1|0;if((Cb|0)>1){xd=Cb-1|0;yd=dc<<1|1}else{wb=fe(1>>>((1-Cb|0)>>>0)|dc<<Cb|0)|0;sb=c[Aa>>2]|0;x=wb;a[sb]=x;x=x>>8;a[sb+1|0]=x;x=x>>8;a[sb+2|0]=x;x=x>>8;a[sb+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;xd=Cb+31|0;yd=1}c[ka>>2]=yd;c[ya>>2]=xd;sb=1<<d[1192248+hb|0];if((ub|0)<(sb|0)){vd=hb;wd=ub;break}else{Qb=hb;Xb=ub;Db=sb;dc=yd;Cb=xd}}}if((wd|0)==0){ud=vd;break}Cb=c[ka>>2]|0;dc=c[ya>>2]|0;if((dc|0)>1){zd=dc-1|0;Ad=Cb<<1|1}else{Db=fe(1>>>((1-dc|0)>>>0)|Cb<<dc|0)|0;Cb=c[Aa>>2]|0;x=Db;a[Cb]=x;x=x>>8;a[Cb+1|0]=x;x=x>>8;a[Cb+2|0]=x;x=x>>8;a[Cb+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;zd=dc+31|0;Ad=1}c[ka>>2]=Ad;c[ya>>2]=zd;ud=vd}else{ud=yb}}while(0);c[f>>2]=ud}}while(0);if((bb|0)<((c[q>>2]|0)+3|0)){gb=bb}else{break}}}gb=ma+1|0;if((gb|0)<(v|0)){ma=gb;ab=rb}else{$a=0;Ua=314;break a}}if((Ua|0)==61){Ua=0;yDb(c[p>>2]|0,16,2308776,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;_a=-1094995529;break}else if((Ua|0)==63){Ua=0;yDb(c[p>>2]|0,16,2308776,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;_a=-1094995529;break}else if((Ua|0)==179){Ua=0;yDb(c[p>>2]|0,16,2308776,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;_a=-1094995529;break}else if((Ua|0)==181){Ua=0;yDb(c[p>>2]|0,16,2308776,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;_a=-1094995529;break}}}while(0);if((c[V>>2]|0)!=0){Ua=309;break}if((c[C>>2]|0)<4){Ua=312;break}if((c[Ha>>2]|0)==0){Ua=312;break}yDb(fa,48,2333368,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;c[V>>2]=1;UGb(E|0,H|0,540)|0}if((Ua|0)==25){yDb(0,0,2007648,(Bd=i,i=i+24|0,c[Bd>>2]=2290168,c[Bd+8>>2]=1941120,c[Bd+16>>2]=993,Bd)|0);i=Bd;Cd();return 0}else if((Ua|0)==309){yDb(0,0,2007648,(Bd=i,i=i+24|0,c[Bd>>2]=1896208,c[Bd+8>>2]=1941120,c[Bd+16>>2]=1154,Bd)|0);i=Bd;Cd();return 0}else if((Ua|0)==312){yDb(fa,16,2353448,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;$a=_a;i=h;return $a|0}else if((Ua|0)==314){i=h;return $a|0}return 0}function H9(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0;m=i;i=i+32|0;n=m|0;o=m+8|0;p=m+16|0;q=f+4|0;r=(c[(c[q>>2]|0)+572>>2]|0)!=0?3:2;s=f+38484|0;c[s>>2]=0;t=f+38492|0;u=h+6|0;TGb(c[t>>2]|0,0,ba(u<<1,r)|0)|0;if((j|0)<=0){v=0;i=m;return v|0}w=p+4|0;y=p|0;z=h-1|0;A=f+38512|0;B=f+38516|0;C=f+8|0;D=f+4796|0;E=f+584|0;G=f+576|0;H=f+572|0;I=f+580|0;J=h<<2;K=f+40828|0;L=(h|0)>0;M=f+4804+(l*2580|0)+1790|0;N=f+4804+(l*2580|0)+2572|0;O=f+568|0;P=f+4752|0;Q=f+4804+(l*2580|0)+2568|0;R=f+592|0;S=f+4804+(l*2580|0)+2560|0;T=(R|0)==0;U=(R|0)!=0;R=p+8|0;V=f+544|0;W=f+540|0;X=h*35|0;Y=0;a:while(1){Z=c[t>>2]|0;_=j-Y|0;$=0;do{c[p+($<<2)>>2]=Z+((ba((_+$|0)%(r|0)|0,u)|0)+3<<1);$=$+1|0;}while(($|0)<(r|0));$=c[w>>2]|0;_=c[y>>2]|0;b[_-2>>1]=b[$>>1]|0;b[$+(h<<1)>>1]=b[$+(z<<1)>>1]|0;Z=c[A>>2]|0;b:do{if((Z|0)<9){if(L){aa=ba(Y,k)|0;ca=0;do{b[_+(ca<<1)>>1]=d[g+(ca+aa)|0]|0;ca=ca+1|0;}while((ca|0)<(h|0))}ca=c[s>>2]|0;if((c[D>>2]|0)==0){aa=c[G>>2]|0;if(((c[E>>2]|0)-aa-(32-(c[H>>2]|0)+((c[I>>2]|0)-aa<<3)>>3)|0)<(J|0)){da=13;break a}}else{if(((c[V>>2]|0)-(c[W>>2]|0)|0)<(X|0)){da=11;break a}}if((c[K>>2]|0)==1){if(L){ea=0}else{break}while(1){aa=b[_+(ea<<1)>>1]|0;a[o]=-128;F9(C,o,aa>>>7&1);a[o]=-128;F9(C,o,aa>>>6&1);a[o]=-128;F9(C,o,aa>>>5&1);a[o]=-128;F9(C,o,aa>>>4&1);a[o]=-128;F9(C,o,aa>>>3&1);a[o]=-128;F9(C,o,aa>>>2&1);a[o]=-128;F9(C,o,aa>>>1&1);a[o]=-128;F9(C,o,aa&1);ea=ea+1|0;if((ea|0)>=(h|0)){break b}}}do{if(L){aa=c[R>>2]|0;fa=0;ga=ca;ha=0;ia=0;while(1){ja=fa+1|0;ka=fa-1|0;la=b[$+(ka<<1)>>1]|0;ma=b[$+(fa<<1)>>1]|0;na=b[$+(ja<<1)>>1]|0;oa=b[_+(ka<<1)>>1]|0;if((b[M>>1]|0)==0){pa=(b[f+4804+(l*2580|0)+512+((la-ma&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+((oa-la&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1024+((ma-na&255)<<1)>>1]|0)|0}else{pa=(b[f+4804+(l*2580|0)+512+((la-ma&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+((oa-la&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1024+((ma-na&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1536+(((e[_+(fa-2<<1)>>1]|0)-oa&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+2048+(((e[aa+(fa<<1)>>1]|0)-ma&255)<<1)>>1]|0)|0}na=b[_+(fa<<1)>>1]|0;ka=ma-la+oa|0;do{if((oa|0)>(ka|0)){if((ma|0)<=(ka|0)){qa=ka;break}qa=(ma|0)>(oa|0)?oa:ma}else{if((ka|0)<=(ma|0)){qa=ka;break}qa=(ma|0)>(oa|0)?ma:oa}}while(0);oa=na-qa|0;if((pa|0)<0){ra=-pa|0;sa=-oa|0}else{ra=pa;sa=oa}oa=sa<<24;ma=oa>>24;do{if((c[D>>2]|0)==0){ka=(ra|0)==0?1:ia;if((ka|0)==0){ta=ma;ua=ha;va=ga}else{if((ma|0)==0){wa=ka;xa=ha+1|0;ya=ga;break}ka=d[1192248+ga|0]|0;la=1<<ka;za=c[O>>2]|0;Aa=c[H>>2]|0;if((ha|0)<(la|0)){Ba=ga;Ca=ha;Da=ka;Ea=za;Fa=Aa}else{ka=ga;Ga=ha;Ha=la;la=za;za=Aa;while(1){Aa=Ga-Ha|0;Ia=ka+1|0;if((za|0)>1){Ja=za-1|0;Ka=la<<1|1}else{La=fe(1>>>((1-za|0)>>>0)|la<<za|0)|0;Ma=c[I>>2]|0;x=La;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Ja=za+31|0;Ka=1}c[O>>2]=Ka;c[H>>2]=Ja;Ma=d[1192248+Ia|0]|0;La=1<<Ma;if((Aa|0)<(La|0)){Ba=Ia;Ca=Aa;Da=Ma;Ea=Ka;Fa=Ja;break}else{ka=Ia;Ga=Aa;Ha=La;la=Ka;za=Ja}}}za=Da+1|0;if((Fa|0)>(za|0)){Na=Fa-za|0;Oa=Ea<<za|Ca}else{la=fe(Ca>>>((za-Fa|0)>>>0)|Ea<<Fa|0)|0;za=c[I>>2]|0;x=la;a[za]=x;x=x>>8;a[za+1|0]=x;x=x>>8;a[za+2|0]=x;x=x>>8;a[za+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Na=Fa+31-Da|0;Oa=Ca}c[O>>2]=Oa;c[H>>2]=Na;ta=(((oa|0)>0)<<31>>31)+ma|0;ua=0;va=(Ba|0)==0?0:Ba-1|0}za=c[N>>2]|0;la=za+(ra*6|0)+4|0;Ha=ta-(d[la]|0)<<24;Ga=Ha>>24;ka=za+(ra*6|0)+5|0;La=d[ka]|0;Aa=za+(ra*6|0)+2|0;Ia=e[Aa>>1]|0;if(La>>>0<Ia>>>0){Ma=La;Pa=0;while(1){Qa=Pa+1|0;Ra=Ma<<1;if((Ra|0)<(Ia|0)){Ma=Ra;Pa=Qa}else{Sa=Qa;break}}}else{Sa=0}Pa=za+(ra*6|0)|0;Ma=(((b[Pa>>1]<<1)+La>>31^Ga)*-2|0)-1|0;Ia=Ma>>31^Ma;Ma=Ia>>Sa;do{if((Ma|0)<12){Qa=Ma+Sa|0;Ra=Qa+1|0;Ta=1<<Sa;Ua=(Ia&Ta-1)+Ta|0;Ta=c[O>>2]|0;Va=c[H>>2]|0;if((Va|0)>(Ra|0)){Wa=Va-Ra|0;Xa=Ta<<Ra|Ua;break}else{Ya=fe(Ua>>>((Ra-Va|0)>>>0)|Ta<<Va|0)|0;Ta=c[I>>2]|0;x=Ya;a[Ta]=x;x=x>>8;a[Ta+1|0]=x;x=x>>8;a[Ta+2|0]=x;x=x>>8;a[Ta+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Wa=31-Qa+Va|0;Xa=Ua;break}}else{Ua=Ia-11|0;Va=c[O>>2]|0;Qa=c[H>>2]|0;if((Qa|0)>20){Wa=Qa-20|0;Xa=Va<<20|Ua;break}else{Ta=fe(Ua>>>((20-Qa|0)>>>0)|Va<<Qa|0)|0;Va=c[I>>2]|0;x=Ta;a[Va]=x;x=x>>8;a[Va+1|0]=x;x=x>>8;a[Va+2|0]=x;x=x>>8;a[Va+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Wa=Qa+12|0;Xa=Ua;break}}}while(0);c[O>>2]=Xa;c[H>>2]=Wa;Ia=a[ka]|0;Ma=Ia&255;La=(e[Aa>>1]|0)+((Ha|0)>-16777216?Ga:-Ga|0)|0;za=(b[Pa>>1]|0)+Ga|0;if(Ia<<24>>24==-128){Za=Ma>>>1;_a=za>>1;$a=La>>>1&32767}else{Za=Ma;_a=za;$a=La&65535}b[Aa>>1]=$a;La=Za+1|0;za=~Za;do{if((_a|0)>(za|0)){if((_a|0)<=0){ab=_a&65535;break}Ma=a[la]|0;if(!(Ma<<24>>24==127)){a[la]=Ma+1}Ma=_a-La|0;ab=(Ma|0)>0?0:Ma&65535}else{Ma=a[la]|0;if(!(Ma<<24>>24==-128)){a[la]=Ma-1}Ma=La+_a|0;if((Ma|0)>(za|0)){ab=Ma&65535;break}ab=-Za&65535}}while(0);b[Pa>>1]=ab;a[ka]=La;wa=0;xa=ua;ya=va}else{za=c[Q>>2]|0;la=za+(ra<<5)|0;if((c[P>>2]&512|0)==0){if((ma|0)==0){F9(C,la,1);wa=ia;xa=ha;ya=ga;break}Aa=(oa|0)>-16777216?ma:-ma|0;Ga=Aa>>>0>65535>>>0;Ha=Ga?Aa>>>16:Aa;Ma=Ga?16:0;if((Ha&65280|0)==0){bb=Ma;cb=Ha}else{bb=Ma|8;cb=Ha>>>8}Ha=(d[1191992+cb|0]|0)+bb|0;F9(C,la,0);if((Ha|0)>=10){Ma=0;while(1){Ga=Ma+1|0;F9(C,((Ma|0)>9?10:Ga)+(za+(ra<<5))|0,1);if((Ga|0)<(Ha|0)){Ma=Ga}else{break}}F9(C,za+(ra<<5)+10|0,0);Ma=Ha;while(1){La=Ma-1|0;F9(C,((La|0)>9?31:Ma+21|0)+(za+(ra<<5))|0,Aa>>>(La>>>0)&1);if((La|0)>0){Ma=La}else{break}}F9(C,za+(ra<<5)+21|0,ma>>>31);wa=ia;xa=ha;ya=ga;break}if((Ha|0)>0){Ma=0;do{Ma=Ma+1|0;F9(C,za+(ra<<5)+Ma|0,1);}while((Ma|0)<(Ha|0));F9(C,Ha+1+(za+(ra<<5))|0,0);Ma=Ha;while(1){La=Ma-1|0;F9(C,Ma+21+(za+(ra<<5))|0,Aa>>>(La>>>0)&1);if((La|0)>0){Ma=La}else{break}}}else{F9(C,za+(ra<<5)+1|0,0)}F9(C,Ha+11+(za+(ra<<5))|0,ma>>>31);wa=ia;xa=ha;ya=ga;break}Ma=c[f+4688+(c[S>>2]<<2)>>2]|0;if((ma|0)==0){if(!T){Aa=f+592+(d[la]<<4)+8|0;La=YGb(c[Aa>>2]|0,c[Aa+4>>2]|0,1,0)|0;c[Aa>>2]=La;c[Aa+4>>2]=F;Aa=Ma+(ra<<9)+8|0;La=YGb(c[Aa>>2]|0,c[Aa+4>>2]|0,1,0)|0;c[Aa>>2]=La;c[Aa+4>>2]=F}F9(C,la,1);wa=ia;xa=ha;ya=ga;break}Aa=(oa|0)>-16777216?ma:-ma|0;La=Aa>>>0>65535>>>0;ka=La?Aa>>>16:Aa;Pa=La?16:0;if((ka&65280|0)==0){db=Pa;eb=ka}else{db=Pa|8;eb=ka>>>8}ka=(d[1191992+eb|0]|0)+db|0;if(U){Pa=f+592+(d[la]<<4)|0;La=YGb(c[Pa>>2]|0,c[Pa+4>>2]|0,1,0)|0;c[Pa>>2]=La;c[Pa+4>>2]=F;Pa=Ma+(ra<<9)|0;La=YGb(c[Pa>>2]|0,c[Pa+4>>2]|0,1,0)|0;c[Pa>>2]=La;c[Pa+4>>2]=F}F9(C,la,0);if((ka|0)>=10){Pa=0;while(1){if(U){La=Pa+1|0;Ga=(Pa|0)>9?10:La;Ia=f+592+(d[za+(ra<<5)+Ga|0]<<4)+8|0;Ua=YGb(c[Ia>>2]|0,c[Ia+4>>2]|0,1,0)|0;c[Ia>>2]=Ua;c[Ia+4>>2]=F;Ia=Ma+(ra<<9)+(Ga<<4)+8|0;Ga=YGb(c[Ia>>2]|0,c[Ia+4>>2]|0,1,0)|0;c[Ia>>2]=Ga;c[Ia+4>>2]=F;fb=La}else{fb=Pa+1|0}F9(C,((Pa|0)>9?10:fb)+(za+(ra<<5))|0,1);if((fb|0)<(ka|0)){Pa=fb}else{break}}Pa=za+(ra<<5)+10|0;if(U){la=f+592+(d[Pa]<<4)|0;Ha=YGb(c[la>>2]|0,c[la+4>>2]|0,1,0)|0;c[la>>2]=Ha;c[la+4>>2]=F;la=Ma+(ra<<9)+160|0;Ha=YGb(c[la>>2]|0,c[la+4>>2]|0,1,0)|0;c[la>>2]=Ha;c[la+4>>2]=F;F9(C,Pa,0);la=ka;while(1){Ha=la-1|0;La=Aa>>>(Ha>>>0)&1;Ia=(Ha|0)>9?31:la+21|0;Ga=za+(ra<<5)+Ia|0;Ua=f+592+(d[Ga]<<4)+(La<<3)|0;Qa=YGb(c[Ua>>2]|0,c[Ua+4>>2]|0,1,0)|0;c[Ua>>2]=Qa;c[Ua+4>>2]=F;Ua=Ma+(ra<<9)+(Ia<<4)+(La<<3)|0;Ia=YGb(c[Ua>>2]|0,c[Ua+4>>2]|0,1,0)|0;c[Ua>>2]=Ia;c[Ua+4>>2]=F;F9(C,Ga,La);if((Ha|0)>0){la=Ha}else{break}}}else{F9(C,Pa,0);la=ka;while(1){Ha=la-1|0;F9(C,((Ha|0)>9?31:la+21|0)+(za+(ra<<5))|0,Aa>>>(Ha>>>0)&1);if((Ha|0)>0){la=Ha}else{break}}}if(U){la=ma>>>31;Pa=za+(ra<<5)+21|0;Ha=f+592+(d[Pa]<<4)+(la<<3)|0;La=YGb(c[Ha>>2]|0,c[Ha+4>>2]|0,1,0)|0;c[Ha>>2]=La;c[Ha+4>>2]=F;Ha=Ma+(ra<<9)+336+(la<<3)|0;La=YGb(c[Ha>>2]|0,c[Ha+4>>2]|0,1,0)|0;c[Ha>>2]=La;c[Ha+4>>2]=F;gb=Pa;hb=la}else{gb=za+(ra<<5)+21|0;hb=ma>>>31}F9(C,gb,hb);wa=ia;xa=ha;ya=ga;break}la=(ka|0)>0;if(la){if(U){Pa=0;do{Pa=Pa+1|0;Ha=za+(ra<<5)+Pa|0;La=f+592+(d[Ha]<<4)+8|0;Ga=YGb(c[La>>2]|0,c[La+4>>2]|0,1,0)|0;c[La>>2]=Ga;c[La+4>>2]=F;La=Ma+(ra<<9)+(Pa<<4)+8|0;Ga=YGb(c[La>>2]|0,c[La+4>>2]|0,1,0)|0;c[La>>2]=Ga;c[La+4>>2]=F;F9(C,Ha,1);}while((Pa|0)<(ka|0))}else{Pa=0;do{Pa=Pa+1|0;F9(C,za+(ra<<5)+Pa|0,1);}while((Pa|0)<(ka|0))}ib=ka+1|0}else{ib=1}Pa=za+(ra<<5)+ib|0;if(U){Ha=f+592+(d[Pa]<<4)|0;La=YGb(c[Ha>>2]|0,c[Ha+4>>2]|0,1,0)|0;c[Ha>>2]=La;c[Ha+4>>2]=F;Ha=Ma+(ra<<9)+(ib<<4)|0;La=YGb(c[Ha>>2]|0,c[Ha+4>>2]|0,1,0)|0;c[Ha>>2]=La;c[Ha+4>>2]=F}F9(C,Pa,0);Pa=ka-1|0;if(la){if(U){Ha=ka;La=Pa;while(1){Ga=Aa>>>(La>>>0)&1;Ua=Ha+21|0;Ia=za+(ra<<5)+Ua|0;Qa=f+592+(d[Ia]<<4)+(Ga<<3)|0;Va=YGb(c[Qa>>2]|0,c[Qa+4>>2]|0,1,0)|0;c[Qa>>2]=Va;c[Qa+4>>2]=F;Qa=Ma+(ra<<9)+(Ua<<4)+(Ga<<3)|0;Ua=YGb(c[Qa>>2]|0,c[Qa+4>>2]|0,1,0)|0;c[Qa>>2]=Ua;c[Qa+4>>2]=F;F9(C,Ia,Ga);if((La|0)>0){Ha=La;La=La-1|0}else{break}}}else{La=ka;Ha=Pa;while(1){F9(C,La+21+(za+(ra<<5))|0,Aa>>>(Ha>>>0)&1);if((Ha|0)>0){La=Ha;Ha=Ha-1|0}else{break}}}}if(U){Ha=ma>>>31;La=ka+11|0;Aa=za+(ra<<5)+La|0;Pa=f+592+(d[Aa]<<4)+(Ha<<3)|0;la=YGb(c[Pa>>2]|0,c[Pa+4>>2]|0,1,0)|0;c[Pa>>2]=la;c[Pa+4>>2]=F;Pa=Ma+(ra<<9)+(La<<4)+(Ha<<3)|0;La=YGb(c[Pa>>2]|0,c[Pa+4>>2]|0,1,0)|0;c[Pa>>2]=La;c[Pa+4>>2]=F;jb=Aa;kb=Ha}else{jb=ka+11+(za+(ra<<5))|0;kb=ma>>>31}F9(C,jb,kb);wa=ia;xa=ha;ya=ga}}while(0);if((ja|0)<(h|0)){fa=ja;ga=ya;ha=xa;ia=wa}else{break}}if((wa|0)==0){lb=ya;break}ia=1<<d[1192248+ya|0];if((xa|0)<(ia|0)){mb=ya;nb=xa}else{ha=ya;ga=xa;fa=ia;ia=c[O>>2]|0;aa=c[H>>2]|0;while(1){ma=ga-fa|0;oa=ha+1|0;if((aa|0)>1){ob=aa-1|0;pb=ia<<1|1}else{na=fe(1>>>((1-aa|0)>>>0)|ia<<aa|0)|0;Ha=c[I>>2]|0;x=na;a[Ha]=x;x=x>>8;a[Ha+1|0]=x;x=x>>8;a[Ha+2|0]=x;x=x>>8;a[Ha+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;ob=aa+31|0;pb=1}c[O>>2]=pb;c[H>>2]=ob;Ha=1<<d[1192248+oa|0];if((ma|0)<(Ha|0)){mb=oa;nb=ma;break}else{ha=oa;ga=ma;fa=Ha;ia=pb;aa=ob}}}if((nb|0)==0){lb=mb;break}aa=c[O>>2]|0;ia=c[H>>2]|0;if((ia|0)>1){qb=ia-1|0;rb=aa<<1|1}else{fa=fe(1>>>((1-ia|0)>>>0)|aa<<ia|0)|0;aa=c[I>>2]|0;x=fa;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;qb=ia+31|0;rb=1}c[O>>2]=rb;c[H>>2]=qb;lb=mb}else{lb=ca}}while(0);c[s>>2]=lb}else{do{if((c[B>>2]|0)==0){if(!L){break}ca=g+(ba(Y,k)|0)|0;ia=16-Z|0;aa=0;do{b[_+(aa<<1)>>1]=(e[ca+(aa<<1)>>1]|0)>>>(ia>>>0);aa=aa+1|0;}while((aa|0)<(h|0))}else{if(!L){break}aa=g+(ba(Y,k)|0)|0;ia=0;do{b[_+(ia<<1)>>1]=b[aa+(ia<<1)>>1]|0;ia=ia+1|0;}while((ia|0)<(h|0))}}while(0);ia=c[s>>2]|0;if((c[D>>2]|0)==0){aa=c[G>>2]|0;if(((c[E>>2]|0)-aa-(32-(c[H>>2]|0)+((c[I>>2]|0)-aa<<3)>>3)|0)<(J|0)){da=141;break a}}else{if(((c[V>>2]|0)-(c[W>>2]|0)|0)<(X|0)){da=139;break a}}if((c[K>>2]|0)==1){if(!L){break}aa=(Z|0)>0;ca=0;while(1){fa=b[_+(ca<<1)>>1]|0;if(aa){ga=Z;do{ga=ga-1|0;a[n]=-128;F9(C,n,fa>>>(ga>>>0)&1);}while((ga|0)>0)}ca=ca+1|0;if((ca|0)>=(h|0)){break b}}}do{if(L){ca=(Z|0)==8;aa=Z+12|0;ga=20-Z|0;fa=1<<Z-1;ha=(1<<Z)-1|0;Ha=c[R>>2]|0;ma=0;oa=ia;na=0;Aa=0;while(1){Pa=ma+1|0;La=ma-1|0;la=b[$+(La<<1)>>1]|0;Ga=b[$+(ma<<1)>>1]|0;Ia=b[$+(Pa<<1)>>1]|0;Qa=b[_+(La<<1)>>1]|0;if((b[M>>1]|0)==0){sb=(b[f+4804+(l*2580|0)+512+((la-Ga&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+((Qa-la&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1024+((Ga-Ia&255)<<1)>>1]|0)|0}else{sb=(b[f+4804+(l*2580|0)+512+((la-Ga&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+((Qa-la&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1024+((Ga-Ia&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1536+(((e[_+(ma-2<<1)>>1]|0)-Qa&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+2048+(((e[Ha+(ma<<1)>>1]|0)-Ga&255)<<1)>>1]|0)|0}Ia=b[_+(ma<<1)>>1]|0;La=Ga-la+Qa|0;do{if((Qa|0)>(La|0)){if((Ga|0)<=(La|0)){tb=La;break}tb=(Ga|0)>(Qa|0)?Qa:Ga}else{if((La|0)<=(Ga|0)){tb=La;break}tb=(Ga|0)>(Qa|0)?Ga:Qa}}while(0);Qa=Ia-tb|0;if((sb|0)<0){ub=-sb|0;vb=-Qa|0}else{ub=sb;vb=Qa}if(ca){wb=vb<<24>>24}else{wb=(vb+fa&ha)-fa|0}do{if((c[D>>2]|0)==0){Qa=(ub|0)==0?1:Aa;if((Qa|0)==0){xb=wb;yb=na;zb=oa}else{if((wb|0)==0){Ab=Qa;Bb=na+1|0;Cb=oa;break}Qa=d[1192248+oa|0]|0;Ga=1<<Qa;La=c[O>>2]|0;ja=c[H>>2]|0;if((na|0)<(Ga|0)){Db=oa;Eb=na;Fb=Qa;Gb=La;Hb=ja}else{Qa=oa;la=na;Ua=Ga;Ga=La;La=ja;while(1){ja=la-Ua|0;Va=Qa+1|0;if((La|0)>1){Ib=La-1|0;Jb=Ga<<1|1}else{Ta=fe(1>>>((1-La|0)>>>0)|Ga<<La|0)|0;Ya=c[I>>2]|0;x=Ta;a[Ya]=x;x=x>>8;a[Ya+1|0]=x;x=x>>8;a[Ya+2|0]=x;x=x>>8;a[Ya+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Ib=La+31|0;Jb=1}c[O>>2]=Jb;c[H>>2]=Ib;Ya=d[1192248+Va|0]|0;Ta=1<<Ya;if((ja|0)<(Ta|0)){Db=Va;Eb=ja;Fb=Ya;Gb=Jb;Hb=Ib;break}else{Qa=Va;la=ja;Ua=Ta;Ga=Jb;La=Ib}}}La=Fb+1|0;if((Hb|0)>(La|0)){Kb=Hb-La|0;Lb=Gb<<La|Eb}else{Ga=fe(Eb>>>((La-Hb|0)>>>0)|Gb<<Hb|0)|0;La=c[I>>2]|0;x=Ga;a[La]=x;x=x>>8;a[La+1|0]=x;x=x>>8;a[La+2|0]=x;x=x>>8;a[La+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Kb=Hb+31-Fb|0;Lb=Eb}c[O>>2]=Lb;c[H>>2]=Kb;xb=(((wb|0)>0)<<31>>31)+wb|0;yb=0;zb=(Db|0)==0?0:Db-1|0}La=c[N>>2]|0;Ga=La+(ub*6|0)+4|0;Ua=xb-(a[Ga]|0)|0;if(ca){Mb=Ua<<24>>24}else{Mb=(Ua+fa&ha)-fa|0}Ua=La+(ub*6|0)+5|0;la=d[Ua]|0;Qa=La+(ub*6|0)+2|0;za=e[Qa>>1]|0;if(la>>>0<za>>>0){ka=la;Ma=0;while(1){Ta=Ma+1|0;ja=ka<<1;if((ja|0)<(za|0)){ka=ja;Ma=Ta}else{Nb=Ta;break}}}else{Nb=0}Ma=La+(ub*6|0)|0;ka=(((b[Ma>>1]<<1)+la>>31^Mb)*-2|0)-1|0;za=ka>>31^ka;ka=za>>Nb;do{if((ka|0)<12){Ta=ka+Nb|0;ja=Ta+1|0;Va=1<<Nb;Ya=(za&Va-1)+Va|0;Va=c[O>>2]|0;Ra=c[H>>2]|0;if((Ra|0)>(ja|0)){Ob=Ra-ja|0;Pb=Va<<ja|Ya;break}else{Qb=fe(Ya>>>((ja-Ra|0)>>>0)|Va<<Ra|0)|0;Va=c[I>>2]|0;x=Qb;a[Va]=x;x=x>>8;a[Va+1|0]=x;x=x>>8;a[Va+2|0]=x;x=x>>8;a[Va+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Ob=31-Ta+Ra|0;Pb=Ya;break}}else{Ya=za-11|0;Ra=c[O>>2]|0;Ta=c[H>>2]|0;if((Ta|0)>(aa|0)){Ob=Ta-aa|0;Pb=Ra<<aa|Ya;break}else{Va=fe(Ya>>>((aa-Ta|0)>>>0)|Ra<<Ta|0)|0;Ra=c[I>>2]|0;x=Va;a[Ra]=x;x=x>>8;a[Ra+1|0]=x;x=x>>8;a[Ra+2|0]=x;x=x>>8;a[Ra+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Ob=ga+Ta|0;Pb=Ya;break}}}while(0);c[O>>2]=Pb;c[H>>2]=Ob;za=a[Ua]|0;ka=za&255;la=(e[Qa>>1]|0)+((Mb|0)>-1?Mb:-Mb|0)|0;La=(b[Ma>>1]|0)+Mb|0;if(za<<24>>24==-128){Rb=ka>>>1;Sb=La>>1;Tb=la>>>1&32767}else{Rb=ka;Sb=La;Tb=la&65535}b[Qa>>1]=Tb;la=Rb+1|0;La=~Rb;do{if((Sb|0)>(La|0)){if((Sb|0)<=0){Ub=Sb&65535;break}ka=a[Ga]|0;if(!(ka<<24>>24==127)){a[Ga]=ka+1}ka=Sb-la|0;Ub=(ka|0)>0?0:ka&65535}else{ka=a[Ga]|0;if(!(ka<<24>>24==-128)){a[Ga]=ka-1}ka=la+Sb|0;if((ka|0)>(La|0)){Ub=ka&65535;break}Ub=-Rb&65535}}while(0);b[Ma>>1]=Ub;a[Ua]=la;Ab=0;Bb=yb;Cb=zb}else{La=c[Q>>2]|0;Ga=La+(ub<<5)|0;if((c[P>>2]&512|0)==0){if((wb|0)==0){F9(C,Ga,1);Ab=Aa;Bb=na;Cb=oa;break}Qa=(wb|0)>-1?wb:-wb|0;ka=Qa>>>0>65535>>>0;za=ka?Qa>>>16:Qa;Ya=ka?16:0;if((za&65280|0)==0){Vb=Ya;Wb=za}else{Vb=Ya|8;Wb=za>>>8}za=(d[1191992+Wb|0]|0)+Vb|0;F9(C,Ga,0);if((za|0)>=10){Ya=0;while(1){ka=Ya+1|0;F9(C,((Ya|0)>9?10:ka)+(La+(ub<<5))|0,1);if((ka|0)<(za|0)){Ya=ka}else{break}}F9(C,La+(ub<<5)+10|0,0);Ya=za;while(1){la=Ya-1|0;F9(C,((la|0)>9?31:Ya+21|0)+(La+(ub<<5))|0,Qa>>>(la>>>0)&1);if((la|0)>0){Ya=la}else{break}}F9(C,La+(ub<<5)+21|0,wb>>>31);Ab=Aa;Bb=na;Cb=oa;break}if((za|0)>0){Ya=0;do{Ya=Ya+1|0;F9(C,La+(ub<<5)+Ya|0,1);}while((Ya|0)<(za|0));F9(C,za+1+(La+(ub<<5))|0,0);Ya=za;while(1){la=Ya-1|0;F9(C,Ya+21+(La+(ub<<5))|0,Qa>>>(la>>>0)&1);if((la|0)>0){Ya=la}else{break}}}else{F9(C,La+(ub<<5)+1|0,0)}F9(C,za+11+(La+(ub<<5))|0,wb>>>31);Ab=Aa;Bb=na;Cb=oa;break}Ya=c[f+4688+(c[S>>2]<<2)>>2]|0;if((wb|0)==0){Qa=f+592+(d[Ga]<<4)+8|0;la=YGb(c[Qa>>2]|0,c[Qa+4>>2]|0,1,0)|0;c[Qa>>2]=la;c[Qa+4>>2]=F;Qa=Ya+(ub<<9)+8|0;la=YGb(c[Qa>>2]|0,c[Qa+4>>2]|0,1,0)|0;c[Qa>>2]=la;c[Qa+4>>2]=F;F9(C,Ga,1);Ab=Aa;Bb=na;Cb=oa;break}Qa=(wb|0)>-1?wb:-wb|0;la=Qa>>>0>65535>>>0;Ua=la?Qa>>>16:Qa;Ma=la?16:0;if((Ua&65280|0)==0){Xb=Ma;Yb=Ua}else{Xb=Ma|8;Yb=Ua>>>8}Ua=(d[1191992+Yb|0]|0)+Xb|0;if(U){Ma=f+592+(d[Ga]<<4)|0;la=YGb(c[Ma>>2]|0,c[Ma+4>>2]|0,1,0)|0;c[Ma>>2]=la;c[Ma+4>>2]=F;Ma=Ya+(ub<<9)|0;la=YGb(c[Ma>>2]|0,c[Ma+4>>2]|0,1,0)|0;c[Ma>>2]=la;c[Ma+4>>2]=F}F9(C,Ga,0);if((Ua|0)>=10){Ma=0;while(1){if(U){la=Ma+1|0;ka=(Ma|0)>9?10:la;Ta=f+592+(d[La+(ub<<5)+ka|0]<<4)+8|0;Ra=YGb(c[Ta>>2]|0,c[Ta+4>>2]|0,1,0)|0;c[Ta>>2]=Ra;c[Ta+4>>2]=F;Ta=Ya+(ub<<9)+(ka<<4)+8|0;ka=YGb(c[Ta>>2]|0,c[Ta+4>>2]|0,1,0)|0;c[Ta>>2]=ka;c[Ta+4>>2]=F;Zb=la}else{Zb=Ma+1|0}F9(C,((Ma|0)>9?10:Zb)+(La+(ub<<5))|0,1);if((Zb|0)<(Ua|0)){Ma=Zb}else{break}}Ma=La+(ub<<5)+10|0;if(U){Ga=f+592+(d[Ma]<<4)|0;za=YGb(c[Ga>>2]|0,c[Ga+4>>2]|0,1,0)|0;c[Ga>>2]=za;c[Ga+4>>2]=F;Ga=Ya+(ub<<9)+160|0;za=YGb(c[Ga>>2]|0,c[Ga+4>>2]|0,1,0)|0;c[Ga>>2]=za;c[Ga+4>>2]=F;F9(C,Ma,0);Ga=Ua;while(1){za=Ga-1|0;la=Qa>>>(za>>>0)&1;Ta=(za|0)>9?31:Ga+21|0;ka=La+(ub<<5)+Ta|0;Ra=f+592+(d[ka]<<4)+(la<<3)|0;Va=YGb(c[Ra>>2]|0,c[Ra+4>>2]|0,1,0)|0;c[Ra>>2]=Va;c[Ra+4>>2]=F;Ra=Ya+(ub<<9)+(Ta<<4)+(la<<3)|0;Ta=YGb(c[Ra>>2]|0,c[Ra+4>>2]|0,1,0)|0;c[Ra>>2]=Ta;c[Ra+4>>2]=F;F9(C,ka,la);if((za|0)>0){Ga=za}else{break}}}else{F9(C,Ma,0);Ga=Ua;while(1){za=Ga-1|0;F9(C,((za|0)>9?31:Ga+21|0)+(La+(ub<<5))|0,Qa>>>(za>>>0)&1);if((za|0)>0){Ga=za}else{break}}}if(U){Ga=wb>>>31;Ma=La+(ub<<5)+21|0;za=f+592+(d[Ma]<<4)+(Ga<<3)|0;la=YGb(c[za>>2]|0,c[za+4>>2]|0,1,0)|0;c[za>>2]=la;c[za+4>>2]=F;za=Ya+(ub<<9)+336+(Ga<<3)|0;la=YGb(c[za>>2]|0,c[za+4>>2]|0,1,0)|0;c[za>>2]=la;c[za+4>>2]=F;_b=Ma;$b=Ga}else{_b=La+(ub<<5)+21|0;$b=wb>>>31}F9(C,_b,$b);Ab=Aa;Bb=na;Cb=oa;break}Ga=(Ua|0)>0;if(Ga){if(U){Ma=0;do{Ma=Ma+1|0;za=La+(ub<<5)+Ma|0;la=f+592+(d[za]<<4)+8|0;ka=YGb(c[la>>2]|0,c[la+4>>2]|0,1,0)|0;c[la>>2]=ka;c[la+4>>2]=F;la=Ya+(ub<<9)+(Ma<<4)+8|0;ka=YGb(c[la>>2]|0,c[la+4>>2]|0,1,0)|0;c[la>>2]=ka;c[la+4>>2]=F;F9(C,za,1);}while((Ma|0)<(Ua|0))}else{Ma=0;do{Ma=Ma+1|0;F9(C,La+(ub<<5)+Ma|0,1);}while((Ma|0)<(Ua|0))}ac=Ua+1|0}else{ac=1}Ma=La+(ub<<5)+ac|0;if(U){za=f+592+(d[Ma]<<4)|0;la=YGb(c[za>>2]|0,c[za+4>>2]|0,1,0)|0;c[za>>2]=la;c[za+4>>2]=F;za=Ya+(ub<<9)+(ac<<4)|0;la=YGb(c[za>>2]|0,c[za+4>>2]|0,1,0)|0;c[za>>2]=la;c[za+4>>2]=F}F9(C,Ma,0);Ma=Ua-1|0;if(Ga){if(U){za=Ua;la=Ma;while(1){ka=Qa>>>(la>>>0)&1;Ra=za+21|0;Ta=La+(ub<<5)+Ra|0;Va=f+592+(d[Ta]<<4)+(ka<<3)|0;Qb=YGb(c[Va>>2]|0,c[Va+4>>2]|0,1,0)|0;c[Va>>2]=Qb;c[Va+4>>2]=F;Va=Ya+(ub<<9)+(Ra<<4)+(ka<<3)|0;Ra=YGb(c[Va>>2]|0,c[Va+4>>2]|0,1,0)|0;c[Va>>2]=Ra;c[Va+4>>2]=F;F9(C,Ta,ka);if((la|0)>0){za=la;la=la-1|0}else{break}}}else{la=Ua;za=Ma;while(1){F9(C,la+21+(La+(ub<<5))|0,Qa>>>(za>>>0)&1);if((za|0)>0){la=za;za=za-1|0}else{break}}}}if(U){za=wb>>>31;la=Ua+11|0;Qa=La+(ub<<5)+la|0;Ma=f+592+(d[Qa]<<4)+(za<<3)|0;Ga=YGb(c[Ma>>2]|0,c[Ma+4>>2]|0,1,0)|0;c[Ma>>2]=Ga;c[Ma+4>>2]=F;Ma=Ya+(ub<<9)+(la<<4)+(za<<3)|0;la=YGb(c[Ma>>2]|0,c[Ma+4>>2]|0,1,0)|0;c[Ma>>2]=la;c[Ma+4>>2]=F;bc=Qa;cc=za}else{bc=Ua+11+(La+(ub<<5))|0;cc=wb>>>31}F9(C,bc,cc);Ab=Aa;Bb=na;Cb=oa}}while(0);if((Pa|0)<(h|0)){ma=Pa;oa=Cb;na=Bb;Aa=Ab}else{break}}if((Ab|0)==0){dc=Cb;break}Aa=1<<d[1192248+Cb|0];if((Bb|0)<(Aa|0)){ec=Cb;fc=Bb}else{na=Cb;oa=Bb;ma=Aa;Aa=c[O>>2]|0;ga=c[H>>2]|0;while(1){aa=oa-ma|0;fa=na+1|0;if((ga|0)>1){gc=ga-1|0;hc=Aa<<1|1}else{ha=fe(1>>>((1-ga|0)>>>0)|Aa<<ga|0)|0;ca=c[I>>2]|0;x=ha;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;gc=ga+31|0;hc=1}c[O>>2]=hc;c[H>>2]=gc;ca=1<<d[1192248+fa|0];if((aa|0)<(ca|0)){ec=fa;fc=aa;break}else{na=fa;oa=aa;ma=ca;Aa=hc;ga=gc}}}if((fc|0)==0){dc=ec;break}ga=c[O>>2]|0;Aa=c[H>>2]|0;if((Aa|0)>1){ic=Aa-1|0;jc=ga<<1|1}else{ma=fe(1>>>((1-Aa|0)>>>0)|ga<<Aa|0)|0;ga=c[I>>2]|0;x=ma;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;ic=Aa+31|0;jc=1}c[O>>2]=jc;c[H>>2]=ic;dc=ec}else{dc=ia}}while(0);c[s>>2]=dc}}while(0);_=Y+1|0;if((_|0)<(j|0)){Y=_}else{v=0;da=266;break}}if((da|0)==11){yDb(c[q>>2]|0,16,2308776,(kc=i,i=i+1|0,i=i+7&-8,c[kc>>2]=0,kc)|0);i=kc;v=-1094995529;i=m;return v|0}else if((da|0)==13){yDb(c[q>>2]|0,16,2308776,(kc=i,i=i+1|0,i=i+7&-8,c[kc>>2]=0,kc)|0);i=kc;v=-1094995529;i=m;return v|0}else if((da|0)==139){yDb(c[q>>2]|0,16,2308776,(kc=i,i=i+1|0,i=i+7&-8,c[kc>>2]=0,kc)|0);i=kc;v=-1094995529;i=m;return v|0}else if((da|0)==141){yDb(c[q>>2]|0,16,2308776,(kc=i,i=i+1|0,i=i+7&-8,c[kc>>2]=0,kc)|0);i=kc;v=-1094995529;i=m;return v|0}else if((da|0)==266){i=m;return v|0}return 0}function I9(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((c|0)==0){F9(a,b,1);return}f=(c|0)>-1?c:-c|0;g=f>>>0>65535>>>0;h=g?f>>>16:f;i=g?16:0;if((h&65280|0)==0){j=i;k=h}else{j=i|8;k=h>>>8}h=(d[1191992+k|0]|0)+j|0;F9(a,b,0);if((h|0)>=10){j=0;while(1){k=j+1|0;F9(a,b+((j|0)>9?10:k)|0,1);if((k|0)<(h|0)){j=k}else{break}}F9(a,b+10|0,0);j=h;while(1){k=j-1|0;F9(a,b+((k|0)>9?31:j+21|0)|0,f>>>(k>>>0)&1);if((k|0)>0){j=k}else{break}}if((e|0)==0){return}F9(a,b+21|0,c>>>31);return}if((h|0)>0){j=0;do{j=j+1|0;F9(a,b+j|0,1);}while((j|0)<(h|0));F9(a,b+(h+1)|0,0);j=h;while(1){k=j-1|0;F9(a,b+(j+21)|0,f>>>(k>>>0)&1);if((k|0)>0){j=k}else{break}}}else{F9(a,b+1|0,0)}if((e|0)==0){return}F9(a,b+(h+11)|0,c>>>31);return}function J9(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+32|0;e=d|0;TGb(e|0,-128|0,32)|0;f=0;g=1;h=-1;while(1){if((b[c+(g<<1)>>1]|0)==(b[c+(g-1<<1)>>1]|0)){j=f}else{I9(a,e,g+h|0,0);j=g}k=g+1|0;if((k|0)>=128){break}f=j;g=k;h=~j}I9(a,e,127-j|0,0);TGb(e|0,-128|0,32)|0;j=0;h=1;g=-1;while(1){if((b[c+512+(h<<1)>>1]|0)==(b[c+512+(h-1<<1)>>1]|0)){l=j}else{I9(a,e,h+g|0,0);l=h}f=h+1|0;if((f|0)>=128){break}j=l;h=f;g=~l}I9(a,e,127-l|0,0);TGb(e|0,-128|0,32)|0;l=0;g=1;h=-1;while(1){if((b[c+1024+(g<<1)>>1]|0)==(b[c+1024+(g-1<<1)>>1]|0)){m=l}else{I9(a,e,g+h|0,0);m=g}j=g+1|0;if((j|0)>=128){break}l=m;g=j;h=~m}I9(a,e,127-m|0,0);TGb(e|0,-128|0,32)|0;m=0;h=1;g=-1;while(1){if((b[c+1536+(h<<1)>>1]|0)==(b[c+1536+(h-1<<1)>>1]|0)){n=m}else{I9(a,e,h+g|0,0);n=h}l=h+1|0;if((l|0)>=128){break}m=n;h=l;g=~n}I9(a,e,127-n|0,0);TGb(e|0,-128|0,32)|0;n=0;g=1;h=-1;while(1){if((b[c+2048+(g<<1)>>1]|0)==(b[c+2048+(g-1<<1)>>1]|0)){o=n}else{I9(a,e,g+h|0,0);o=g}m=g+1|0;if((m|0)>=128){break}n=o;g=m;h=~o}I9(a,e,127-o|0,0);i=d;return}function K9(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;b=i;e=c[a+60>>2]|0;f=e;if((c[a+416>>2]|0)>32){yDb(a,16,2189016,(g=i,i=i+8|0,c[g>>2]=32,g)|0);i=g;h=-22;i=b;return h|0}j=c[a+100>>2]|0;a:do{if((j|0)<4){k=-22;l=34}else{m=c[a+96>>2]|0;n=m+j|0;o=m;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+552|0;c[o>>2]=p;if((p|0)<0){k=-22;l=34;break}q=m+4|0;m=dEb(p,96)|0;p=m;r=e+20|0;c[r>>2]=p;if((m|0)==0){k=-12;l=34;break}if((c[o>>2]|0)>0){m=n;s=a+412|0;t=q;u=-2147483648;v=0;w=0;while(1){if((m-t|0)<24){k=-22;l=34;break a}x=t;y=x|0;z=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=x+4|0;x=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=p+(w*96|0)|0;c[y>>2]=z;c[y+4>>2]=x;y=t+8|0;A=y|0;B=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;A=y+4|0;y=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;A=p+(w*96|0)+8|0;c[A>>2]=B;c[A+4>>2]=y;A=t+16|0;C=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;c[p+(w*96|0)+84>>2]=C;A=t+20|0;c[p+(w*96|0)+80>>2]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=t+24|0;if(!((x|0)>=(u|0)&((x|0)>(u|0)|z>>>0>=v>>>0)&((y|0)>(x|0)|(y|0)==(x|0)&B>>>0>z>>>0))){k=-22;l=34;break a}D=ZGb(B,y,z,x)|0;y=F;do{if((C|0)==1162758483){if((m-A|0)<20){k=-22;l=34;break a}B=A;E=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=t+28|0;G=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=t+32|0;H=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=t+36|0;I=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=t+40|0;J=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=t+44|0;K=E;L=(E|0)<0|0?-1:0;E=c[s>>2]|0;M=E;N=M<<16|0>>>16;O=((E|0)<0|0?-1:0)<<16|M>>>16;M=1;do{if(O>>>0<M>>>0|O>>>0==M>>>0&N>>>0<0>>>0){E=0;Q=K;R=hHb(E,Q,N,O)|0;S=iHb(E,Q,N,O)|0;Q=hHb(0,S,N,O)|0;S=Q|0;Q=F|R;R=G;(G|0)<0|0?-1:0;E=0;T=R;R=hHb(E,T,N,O)|0;V=iHb(E,T,N,O)|0;T=hHb(0,V,N,O)|0;W=F|R;X=T|0;Y=Q;Z=S}else{S=65536;if(O>>>0<S>>>0|O>>>0==S>>>0&N>>>0<0>>>0){S=K<<16|0>>>16;Q=L<<16|K>>>16;T=hHb(S,Q,N,O)|0;R=F;V=iHb(S,Q,N,O)|0;Q=V<<16|0>>>16;S=F<<16|V>>>16;V=hHb(Q,S,N,O)|0;E=V|(T<<16|0>>>16);V=F|(R<<16|T>>>16);T=iHb(Q,S,N,O)|0;S=T<<16|0>>>16;Q=F<<16|T>>>16;T=hHb(S,Q,N,O)|0;R=T|(E<<16|0>>>16);T=F|(V<<16|E>>>16);E=iHb(S,Q,N,O)|0;Q=hHb(E<<16|0>>>16,F<<16|E>>>16,N,O)|0;E=F|(T<<16|R>>>16);T=G;S=T<<16|0>>>16;V=((G|0)<0|0?-1:0)<<16|T>>>16;T=hHb(S,V,N,O)|0;_=F;$=iHb(S,V,N,O)|0;V=$<<16|0>>>16;S=F<<16|$>>>16;$=hHb(V,S,N,O)|0;aa=$|(T<<16|0>>>16);$=F|(_<<16|T>>>16);T=iHb(V,S,N,O)|0;S=T<<16|0>>>16;V=F<<16|T>>>16;T=hHb(S,V,N,O)|0;_=T|(aa<<16|0>>>16);T=F|($<<16|aa>>>16);aa=iHb(S,V,N,O)|0;V=hHb(aa<<16|0>>>16,F<<16|aa>>>16,N,O)|0;W=F|(T<<16|_>>>16);X=V|(_<<16|0>>>16);Y=E;Z=Q|(R<<16|0>>>16);break}else{ba=L;ca=K;da=0;ea=0;fa=63}while(1){R=-1;Q=ca<<1|0>>>31;E=ba<<1|ca>>>31;if(((ba|0)>(R|0)|(ba|0)==(R|0)&ca>>>0>-1>>>0)&(E>>>0<O>>>0|E>>>0==O>>>0&Q>>>0<N>>>0)){ga=da;ha=ea;ia=E;ja=Q}else{R=_Gb(1,0,fa|0)|0;_=F|da;V=ZGb(Q,E,N,O)|0;ga=_;ha=R|ea;ia=F;ja=V}if((fa|0)>0){ba=ia;ca=ja;da=ga;ea=ha;fa=fa-1|0}else{break}}V=(G|0)<0|0?-1:0;R=G;_=0;E=0;Q=63;while(1){T=-1;aa=R<<1|0>>>31;S=V<<1|R>>>31;if(((V|0)>(T|0)|(V|0)==(T|0)&R>>>0>-1>>>0)&(S>>>0<O>>>0|S>>>0==O>>>0&aa>>>0<N>>>0)){ka=_;la=E;ma=S;na=aa}else{T=_Gb(1,0,Q|0)|0;$=F|_;oa=ZGb(aa,S,N,O)|0;ka=$;la=T|E;ma=F;na=oa}if((Q|0)>0){V=ma;R=na;_=ka;E=la;Q=Q-1|0}else{W=ka;X=la;Y=ga;Z=ha;break}}}}while(0);O=p+(w*96|0)+24|0;c[O>>2]=Z;c[O+4>>2]=Y;O=ZGb(X,W,Z,Y)|0;N=eHb(O,F,D,y)|0;O=p+(w*96|0)+32|0;c[O>>2]=N;c[O+4>>2]=F;if((J|0)>=0){O=p+(w*96|0)+16|0;c[O>>2]=0<<1|0>>>31;c[O+4>>2]=J<<1|0>>>31;pa=B;qa=H;ra=I;break}O=J&2147483647;if(!(O>>>0<w>>>0)){k=-22;l=34;break a}N=p+(O*96|0)|0;G=ZGb(z,x,c[N>>2]|0,c[N+4>>2]|0)|0;N=F;if((G&1|0)==0&(N&0|0)==0){K=YGb(G,N,-1,-1)|0;L=gHb(G>>>1|N<<31,N>>>1|0<<31,K,F)|0;sa=F;ta=L}else{L=YGb(G,N,-1,-1)|0;K=F;M=gHb(L>>>1|K<<31,K>>>1|0<<31,G,N)|0;sa=F;ta=M}M=p+(O*96|0)+16|0;K=c[M>>2]|0;L=c[M+4>>2]|0;M=p+(O*96|0)+24|0;Q=gHb(c[M>>2]|0,c[M+4>>2]|0,G,N)|0;N=YGb(Q,F,K,L)|0;L=F;K=p+(O*96|0)+32|0;O=gHb(c[K>>2]|0,c[K+4>>2]|0,ta,sa)|0;K=YGb(N,L,O,F)|0;O=p+(w*96|0)+16|0;c[O>>2]=K;c[O+4>>2]=F;pa=B;qa=H;ra=I}else if((C|0)==1397313358){if((m-A|0)<8){k=-22;l=34;break a}O=A;K=t+28|0;pa=t+32|0;qa=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;ra=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0}else{k=-22;l=34;break a}}while(0);A=0;C=qa;K=p+(w*96|0)+40|0;c[K>>2]=A;c[K+4>>2]=C;K=ZGb(0,ra,A,C)|0;C=eHb(K,F,D,y)|0;K=p+(w*96|0)+48|0;c[K>>2]=C;c[K+4>>2]=F;K=w+1|0;if((K|0)<(c[o>>2]|0)){t=pa;u=x;v=z;w=K}else{ua=pa;break}}}else{ua=q}w=(ua|0)==(n|0);if(!w){k=w?0:-22;l=34;break}w=WDb(65536)|0;v=w;u=e+16|0;c[u>>2]=v;if((w|0)==0){va=-12;wa=r;xa=u;break}else{ya=0}do{c[v+(ya<<2)>>2]=~~+P(+U(+(ya|0)*6.283185307179586*6103515625.0e-14)*32767.0);ya=ya+1|0;}while((ya|0)<16384);c[e+24>>2]=1213483332;v=c[o>>2]|0;if((v|0)>0){n=c[r>>2]|0;q=e+544|0;u=0;w=c[q>>2]|0;do{w=((c[n+(u*96|0)+84>>2]|0)==1397313358)+w|0;u=u+1|0;}while((u|0)<(v|0));c[q>>2]=w}c[e+28>>2]=1263421776;c[e+548>>2]=128;N9(f,0,0);c[a+420>>2]=1;h=0;i=b;return h|0}}while(0);if((l|0)==34){yDb(a,16,2111944,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;va=k;wa=e+20|0;xa=e+16|0}ZDb(c[wa>>2]|0);ZDb(c[xa>>2]|0);h=va;i=b;return h|0}function L9(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0;h=i;i=i+128|0;j=h|0;k=c[a+60>>2]|0;l=k;c[f>>2]=0;m=g+28|0;if((c[m>>2]|0)!=12){n=-1094995529;i=h;return n|0}o=g+24|0;g=c[o>>2]|0;p=g;q=p|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k;if((r|0)==(c[q>>2]|0)&(p|0)==(c[q+4>>2]|0)){s=g}else{N9(l,r,p);s=c[o>>2]|0}o=s+8|0;s=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;if((s|0)<1){n=-22;i=h;return n|0}c[e+76>>2]=s;o=_$a(a,e,0)|0;if((o|0)<0){n=o;i=h;return n|0}o=j;g=a+416|0;a=k+8|0;t=j|0;u=k+556|0;v=k+548|0;w=k+20|0;x=k+16|0;y=k+24|0;z=k+560|0;A=k+552|0;k=p;p=r;r=1;B=c[e>>2]|0;e=c[g>>2]|0;while(1){TGb(o|0,0,e<<2|0)|0;C=c[a+4>>2]|0;if(!((k|0)<(C|0)|(k|0)==(C|0)&p>>>0<(c[a>>2]|0)>>>0)){C=c[u>>2]|0;if((C|0)>-1){D=c[w>>2]|0;E=C;while(1){C=D+(E*96|0)+88|0;G=c[C>>2]|0;if((G|0)>-1){E=G}else{H=C;break}}}else{H=u}E=c[z>>2]|0;D=c[A>>2]|0;a:do{if((E|0)<(D|0)){C=c[w>>2]|0;G=E;I=H;J=D;while(1){K=C+(G*96|0)|0;L=c[K+4>>2]|0;if((L|0)>(k|0)|(L|0)==(k|0)&(c[K>>2]|0)>>>0>p>>>0){M=G;N=I;O=J;break a}K=C+(G*96|0)+8|0;L=c[K+4>>2]|0;if((L|0)>(k|0)|(L|0)==(k|0)&(c[K>>2]|0)>>>0>p>>>0){c[I>>2]=G;K=C+(G*96|0)+16|0;L=c[K+4>>2]|0;P=C+(G*96|0)+56|0;c[P>>2]=c[K>>2];c[P+4>>2]=L;L=C+(G*96|0)+24|0;P=c[L+4>>2]|0;K=C+(G*96|0)+64|0;c[K>>2]=c[L>>2];c[K+4>>2]=P;P=C+(G*96|0)+40|0;K=c[P+4>>2]|0;L=C+(G*96|0)+72|0;c[L>>2]=c[P>>2];c[L+4>>2]=K;Q=C+(G*96|0)+88|0;R=c[A>>2]|0}else{Q=I;R=J}K=G+1|0;if((K|0)<(R|0)){G=K;I=Q;J=R}else{M=K;N=Q;O=R;break}}}else{M=E;N=H;O=D}}while(0);c[z>>2]=M;if((M|0)<(O|0)){D=(c[w>>2]|0)+(M*96|0)|0;S=c[D+4>>2]|0;T=c[D>>2]|0}else{S=2147483647;T=-1}c[a>>2]=T;c[a+4>>2]=S;c[N>>2]=-1}D=c[u>>2]|0;E=c[v>>2]|0;if((E|0)==128){O9(l);U=c[v>>2]|0}else{U=E}c[v>>2]=U+1;E=c[l+32+(U<<2)>>2]>>16;do{if((D|0)>-1){J=c[w>>2]|0;I=D;G=u;C=0;b:while(1){K=I;while(1){V=J+(K*96|0)+88|0;W=c[V>>2]|0;L=J+(K*96|0)+8|0;P=c[L+4>>2]|0;if((P|0)>(k|0)|(P|0)==(k|0)&(c[L>>2]|0)>>>0>p>>>0){break}c[G>>2]=W;if((W|0)>-1){K=W}else{X=C;break b}}L=J+(K*96|0)+72|0;P=c[L+4>>2]|0;Y=P;Z=J+(K*96|0)+48|0;_=YGb(c[Z>>2]|0,c[Z+4>>2]|0,c[L>>2]|0,P)|0;c[L>>2]=_;c[L+4>>2]=F;L=c[J+(K*96|0)+84>>2]|0;if((L|0)==1397313358){$=ba(Y,E)|0}else if((L|0)==1162758483){L=J+(K*96|0)+56|0;_=c[L+4>>2]|0;P=ba(c[(c[x>>2]|0)+((_>>>18|0<<14)<<2)>>2]|0,Y)|0;Y=J+(K*96|0)+64|0;Z=c[Y>>2]|0;aa=c[Y+4>>2]|0;ca=YGb(Z,aa,c[L>>2]|0,_)|0;c[L>>2]=ca;c[L+4>>2]=F;L=J+(K*96|0)+32|0;ca=YGb(c[L>>2]|0,c[L+4>>2]|0,Z,aa)|0;c[Y>>2]=ca;c[Y+4>>2]=F;$=P}else{$=0}P=c[J+(K*96|0)+80>>2]|0;Y=P|C;if((P|0)!=0){ca=t;aa=P;while(1){if((aa&1|0)!=0){c[ca>>2]=(c[ca>>2]|0)+$}P=aa>>>1;if((P|0)==0){break}else{ca=ca+4|0;aa=P}}}if((W|0)>-1){I=W;G=V;C=Y}else{X=Y;break}}C=(ba(c[y>>2]|0,1284865837)|0)-144211633|0;c[y>>2]=C;G=C>>16;if((X|0)==0){break}else{da=t;ea=X}while(1){if((ea&1|0)!=0){c[da>>2]=(c[da>>2]|0)+G}C=ea>>>1;if((C|0)==0){break}else{da=da+4|0;ea=C}}}else{c[y>>2]=(ba(c[y>>2]|0,1284865837)|0)-144211633}}while(0);E=c[g>>2]|0;if((E|0)>0){D=(E|0)>1?E:1;G=0;C=B;while(1){b[C>>1]=(c[j+(G<<2)>>2]|0)>>>16;I=G+1|0;if((I|0)<(E|0)){G=I;C=C+2|0}else{break}}fa=B+(D<<1)|0}else{fa=B}if((r|0)>=(s|0)){break}C=YGb(p,k,1,0)|0;k=F;p=C;r=r+1|0;B=fa;e=E}e=YGb(c[q>>2]|0,c[q+4>>2]|0,s,(s|0)<0|0?-1:0)|0;c[q>>2]=e;c[q+4>>2]=F;c[f>>2]=1;n=c[m>>2]|0;i=h;return n|0}function M9(a){a=a|0;var b=0;b=c[a+60>>2]|0;ZDb(c[b+16>>2]|0);ZDb(c[b+20>>2]|0);return 0}function N9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;e=a+556|0;f=a+552|0;g=c[f>>2]|0;a:do{if((g|0)>0){h=c[a+20>>2]|0;i=0;j=e;k=g;while(1){l=h+(i*96|0)|0;m=c[l>>2]|0;n=c[l+4>>2]|0;if((n|0)>(d|0)|(n|0)==(d|0)&m>>>0>b>>>0){o=i;p=j;q=k;break a}l=h+(i*96|0)+8|0;r=c[l+4>>2]|0;if((r|0)>(d|0)|(r|0)==(d|0)&(c[l>>2]|0)>>>0>b>>>0){c[j>>2]=i;l=ZGb(b,d,m,n)|0;n=F;if((l&1|0)==0&(n&0|0)==0){m=YGb(l,n,-1,-1)|0;r=gHb(l>>>1|n<<31,n>>>1|0<<31,m,F)|0;s=F;t=r}else{r=YGb(l,n,-1,-1)|0;m=F;u=gHb(r>>>1|m<<31,m>>>1|0<<31,l,n)|0;s=F;t=u}u=h+(i*96|0)+16|0;m=c[u>>2]|0;r=c[u+4>>2]|0;u=h+(i*96|0)+24|0;v=c[u>>2]|0;w=c[u+4>>2]|0;u=gHb(v,w,l,n)|0;x=YGb(u,F,m,r)|0;r=F;m=h+(i*96|0)+32|0;u=c[m>>2]|0;y=c[m+4>>2]|0;m=gHb(u,y,t,s)|0;z=YGb(x,r,m,F)|0;m=h+(i*96|0)+56|0;c[m>>2]=z;c[m+4>>2]=F;m=gHb(l,n,u,y)|0;y=YGb(m,F,v,w)|0;w=h+(i*96|0)+64|0;c[w>>2]=y;c[w+4>>2]=F;w=h+(i*96|0)+40|0;y=c[w>>2]|0;v=c[w+4>>2]|0;w=h+(i*96|0)+48|0;m=gHb(l,n,c[w>>2]|0,c[w+4>>2]|0)|0;w=YGb(m,F,y,v)|0;v=h+(i*96|0)+72|0;c[v>>2]=w;c[v+4>>2]=F;A=h+(i*96|0)+88|0;B=c[f>>2]|0}else{A=j;B=k}v=i+1|0;if((v|0)<(B|0)){i=v;j=A;k=B}else{o=v;p=A;q=B;break}}}else{o=0;p=e;q=g}}while(0);c[a+560>>2]=o;if((o|0)<(q|0)){q=(c[a+20>>2]|0)+(o*96|0)|0;C=c[q+4>>2]|0;D=c[q>>2]|0}else{C=2147483647;D=-1}q=a+8|0;c[q>>2]=D;c[q+4>>2]=C;c[p>>2]=-1;p=a+24|0;C=a|0;q=c[C>>2]|0;D=c[C+4>>2]|0;o=ZGb(b,d,q,D)|0;g=F;e=c[p>>2]|0;B=-1;A=(g|0)>(B|0)|(g|0)==(B|0)&o>>>0>-1>>>0;B=ZGb(0,0,o,g)|0;f=A?o:B;B=A?g:F;if((f|0)==0&(B|0)==0){E=e}else{g=B;B=f;f=A?1284865837:849225893;o=A?-144211633:-559108117;A=e;while(1){if((B&1|0)==0&(g&0|0)==0){G=A}else{G=(ba(f,A)|0)+o|0}e=ba(f+1|0,o)|0;s=ba(f,f)|0;t=B>>>1|g<<31;k=g>>1|((g|0)<0|0?-1:0)<<31;if((t|0)==0&(k|0)==0){E=G;break}else{g=k;B=t;f=s;o=e;A=G}}}c[p>>2]=E;if((c[a+544>>2]|0)==0){H=C|0;c[H>>2]=b;I=C+4|0;c[I>>2]=d;return}E=YGb(q,D,127,0)|0;D=b&127;q=a+28|0;p=ZGb(b&-128,d&2147483647,E&-128,F&2147483647)|0;E=p<<1|0>>>31;G=F<<1|p>>>31;p=c[q>>2]|0;A=-1;o=(G|0)>(A|0)|(G|0)==(A|0)&E>>>0>-1>>>0;A=ZGb(0,0,E,G)|0;f=o?E:A;A=o?G:F;if((f|0)==0&(A|0)==0){J=p}else{G=A;A=f;f=o?1284865837:849225893;E=o?-144211633:-559108117;o=p;while(1){if((A&1|0)==0&(G&0|0)==0){K=o}else{K=(ba(f,o)|0)+E|0}p=ba(f+1|0,E)|0;B=ba(f,f)|0;g=A>>>1|G<<31;e=G>>1|((G|0)<0|0?-1:0)<<31;if((g|0)==0&(e|0)==0){J=K;break}else{G=e;A=g;f=B;E=p;o=K}}}c[q>>2]=J;if((D|0)==0){c[a+548>>2]=128;H=C|0;c[H>>2]=b;I=C+4|0;c[I>>2]=d;return}else{O9(a);c[a+548>>2]=D;H=C|0;c[H>>2]=b;I=C+4|0;c[I>>2]=d;return}}function O9(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;c[a+548>>2]=0;if((c[a+544>>2]|0)==0){return}b=a+28|0;d=0;e=0;f=0;g=0;h=0;i=0;j=0;k=0;l=0;while(1){do{if((e&1|0)==0){m=(ba(c[b>>2]|0,1284865837)|0)-144211633|0;c[b>>2]=m;n=m>>3;o=d-f+n|0;if((e&2|0)!=0){p=o;q=n;r=g;s=h;t=i;u=j;v=k;w=l;x=m;break}y=(ba(m,1284865837)|0)-144211633|0;c[b>>2]=y;m=y>>3;z=o-g+m|0;if((e&4|0)!=0){p=z;q=n;r=m;s=h;t=i;u=j;v=k;w=l;x=y;break}o=(ba(y,1284865837)|0)-144211633|0;c[b>>2]=o;y=o>>3;A=z-h+y|0;if((e&8|0)!=0){p=A;q=n;r=m;s=y;t=i;u=j;v=k;w=l;x=o;break}z=(ba(o,1284865837)|0)-144211633|0;c[b>>2]=z;o=z>>3;B=A-i+o|0;if((e&16|0)!=0){p=B;q=n;r=m;s=y;t=o;u=j;v=k;w=l;x=z;break}A=(ba(z,1284865837)|0)-144211633|0;c[b>>2]=A;z=A>>3;C=B-j+z|0;if((e&32|0)!=0){p=C;q=n;r=m;s=y;t=o;u=z;v=k;w=l;x=A;break}B=(ba(A,1284865837)|0)-144211633|0;c[b>>2]=B;A=B>>3;D=C-k+A|0;if((e&64|0)!=0){p=D;q=n;r=m;s=y;t=o;u=z;v=A;w=l;x=B;break}C=(ba(B,1284865837)|0)-144211633|0;c[b>>2]=C;B=C>>3;p=D-l+B|0;q=n;r=m;s=y;t=o;u=z;v=A;w=B;x=C}else{p=d;q=f;r=g;s=h;t=i;u=j;v=k;w=l;x=c[b>>2]|0}}while(0);C=(ba(x,1284865837)|0)-144211633|0;c[b>>2]=C;c[a+32+(e<<2)>>2]=(C>>3)+p;C=e+1|0;if((C|0)<128){d=p;e=C;f=q;g=r;h=s;i=t;j=u;k=v;l=w}else{break}}c[b>>2]=(ba(c[b>>2]|0,1284865837)|0)-144211633;return}function P9(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+1400>>2]=(c[a+120>>2]|0)+15&-16;c[b+1404>>2]=(c[a+124>>2]|0)+15&-16;c[a+140>>2]=0;c[a+796>>2]=8;d=ICb()|0;c[b+4>>2]=d;if((d|0)==0){e=-12;return e|0}Z3(b+8|0,a);x2(b+1136|0,b+1252|0,1075976);e=0;return e|0}function Q9(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;j=c[b+60>>2]|0;k=c[g+24>>2]|0;l=j+4|0;m=$$a(b,c[l>>2]|0)|0;if((m|0)<0){yDb(b,16,2188992,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=m;i=h;return o|0}m=g+28|0;if((c[m>>2]|0)<31){yDb(b,16,2111872,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}if((PGb(k,1071880,7)|0)!=0){yDb(b,24,2053400,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}do{if((a[k+17|0]|0)==0){g=a[k+13|0]|0;p=g&255;if(g<<24>>24==0){yDb(b,16,2007624,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}c[j+1392>>2]=(a[k+23|0]|0)!=0?1071816:1071752;g=d[k+25|0]<<8|d[k+24|0]<<16|d[k+26|0];if((g|0)>((c[m>>2]|0)-27|0)){yDb(b,16,1969616,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}q=(c[j+1404>>2]>>4<<4|0)/(p|0)|0;r=j+1412|0;if((q&15|0)==0){s=q}else{s=q-1&-16}c[r>>2]=s;q=g+27|0;t=p<<2;u=q+t|0;v=-27-t-g+(c[m>>2]|0)|0;if((v|0)<1){yDb(b,16,1941080,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}g=c[l>>2]|0;c[g+84>>2]=1;c[g+88>>2]=1;g=j+1384|0;t=g;w=j+1388|0;x=p*144|0;kEb(g,w,x);if((c[w>>2]|0)==0){yDb(b,16,1916840,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=h;return o|0}TGb(c[t>>2]|0,0,x|0)|0;x=p-1|0;w=b+124|0;g=0;do{y=(g<<2)+q|0;z=k+y|0;A=fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0;z=c[r>>2]|0;B=ba(z,g)|0;if((g|0)==(x|0)){C=15-(ba(z,x)|0)+(c[w>>2]|0)&-16;D=v}else{E=k+(y+4)|0;C=z;D=fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0}if(!(D>>>0<A>>>0|D>>>0>v>>>0)){c[(c[t>>2]|0)+(g*144|0)+128>>2]=k+(u+A);E=c[t>>2]|0;c[E+(g*144|0)+136>>2]=D-A;c[E+(g*144|0)+132>>2]=C;c[E+(g*144|0)+140>>2]=B}g=g+1|0;}while((g|0)<(p|0));g=oe[c[b+824>>2]&63](b,304,c[t>>2]|0,0,p,144)|0;if((g|0)>=0){break}o=g>>>31;i=h;return o|0}}while(0);c[f>>2]=1;f=MCb(e,c[l>>2]|0)|0;if((f|0)<0){o=f;i=h;return o|0}o=c[m>>2]|0;i=h;return o|0}function R9(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+1384|0);JCb(b+4|0);return 0}function S9(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=c[e+60>>2]|0;e=g;h=c[f+128>>2]|0;i=c[f+132>>2]|0;j=c[f+140>>2]|0;k=c[f+136>>2]<<3;l=k>>>0>2147483639>>>0|(h|0)==0;m=l?0:h;h=l?8:k+8|0;k=g+4|0;l=g+1400|0;n=f;f=g+44|0;o=g+1128|0;p=g+1392|0;g=0;q=0;a:while(1){r=c[k>>2]|0;s=c[r+32+(q<<2)>>2]|0;t=(q|0)!=0|0;u=i>>t;if((u|0)>0){v=ba(s,j>>t)|0;w=s<<3;x=g;y=0;z=(c[r+(q<<2)>>2]|0)+v|0;v=c[l>>2]|0;while(1){if((v>>t|0)>0){r=x;A=0;while(1){B=z+A|0;C=((r|0)<(h|0))+r|0;if((d[m+(r>>>3)|0]&128>>>((r&7)>>>0)|0)==0){me[c[f>>2]&511](n);D=m+(C>>>3)|0;E=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7);D=E>>>25;F=C+7|0;G=h>>>0>F>>>0?F:h;if(E>>>0>2181038079>>>0){H=-1094995529;I=19;break a}if((D|0)==0){J=G}else{E=0;F=G;while(1){G=m+(F>>>3)|0;K=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(F&7);if(K>>>0>134217727>>>0){G=K>>>23;L=(d[1213744+G|0]|0)+F|0;M=a[1139096+G|0]|0;N=h>>>0>L>>>0?L:h}else{L=K>>>0>65535>>>0;G=L?K>>>16:K;K=L?16:0;if((G&65280|0)==0){O=K;P=G}else{O=K|8;P=G>>>8}G=(d[1191992+P|0]|0)+O|0;K=31-G+F|0;L=h>>>0>K>>>0?K:h;K=m+(L>>>3)|0;Q=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(L&7)>>>(G>>>0);K=L+(32-G)|0;G=Q>>>1;M=(Q&1|0)==0?G:-G|0;N=h>>>0>K>>>0?K:h}K=(ba(d[(c[p>>2]|0)+E|0]|0,M)|0)&65535;b[n+(d[e+1256+E|0]<<1)>>1]=K;K=E+1|0;if((K|0)<(D|0)){E=K;F=N}else{J=N;break}}}Xe[c[o>>2]&4095](B,s,n);R=J}else{F=c[k>>2]|0;c[F+84>>2]=0;c[F+88>>2]=2;R=C}F=A+8|0;E=c[l>>2]|0;if((F|0)<(E>>t|0)){r=R;A=F}else{S=R;T=E;break}}}else{S=x;T=v}A=y+8|0;if((A|0)<(u|0)){x=S;y=A;z=z+w|0;v=T}else{U=S;break}}}else{U=g}v=q+1|0;if((v|0)<3){g=U;q=v}else{H=0;I=19;break}}if((I|0)==19){return H|0}return 0}function T9(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;h=i;j=e+8|0;k=c[j>>2]|0;l=e+16|0;m=c[l>>2]|0;n=e|0;e=c[n>>2]|0;o=e+(k>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(k&7);o=k+15|0;k=m>>>0>o>>>0?o:m;c[j>>2]=k;if(!((p&-131072|0)==-524288)){yDb(b,g+16|0,2296048,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}p=d[e+(k>>>3)|0]<<(k&7)>>>7;c[j>>2]=((k|0)<(m|0))+k;c[f+32>>2]=p&1;p=c[j>>2]|0;k=c[l>>2]|0;m=e+(p>>>3)|0;o=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>28;m=p+4|0;p=k>>>0>m>>>0?m:k;c[j>>2]=p;m=e+(p>>>3)|0;s=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7);m=s>>>28;t=p+4|0;p=k>>>0>t>>>0?t:k;c[j>>2]=p;t=e+(p>>>3)|0;e=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(p&7);t=e>>>28;u=p+4|0;c[j>>2]=k>>>0>u>>>0?u:k;k=f+16|0;c[k>>2]=t;do{if((e|0)>-1){c[f+4>>2]=t+1;v=0}else{if(e>>>0<2952790016>>>0){c[f+4>>2]=2;v=t-7|0;break}yDb(b,g+16|0,2325856,(q=i,i=i+8|0,c[q>>2]=t,q)|0);i=q;r=-1094995529;i=h;return r|0}}while(0);c[k>>2]=v;v=c[j>>2]|0;k=c[l>>2]|0;t=c[n>>2]|0;e=t+(v>>>3)|0;u=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(v&7)>>>29;e=v+3|0;c[j>>2]=k>>>0>e>>>0?e:k;if((u|0)==7|(u|0)==3){yDb(b,g+16|0,2188960,(q=i,i=i+8|0,c[q>>2]=u,q)|0);i=q;r=-1094995529;i=h;return r|0}c[f+8>>2]=a[483168+u|0]|0;u=c[j>>2]|0;k=d[t+(u>>>3)|0]|0;e=c[l>>2]|0;v=((u|0)<(e|0))+u|0;c[j>>2]=v;if((k&128>>>((u&7)>>>0)|0)!=0){yDb(b,g+16|0,2111840,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}u=t+(v>>>3)|0;k=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(v&7);u=k>>>24;p=v+8|0;v=e>>>0>p>>>0?p:e;c[j>>2]=v;p=u;w=0;x=k>>>25&64;a:do{if(!((p&192|0)==128&(w&0|0)==0|k>>>0>4261412863>>>0)){if((x&u|0)==0){y=w;z=p;A=x;B=v}else{C=w;D=p;E=x;G=v;while(1){H=t+(G>>>3)|0;I=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(G&7)>>>24;H=G+8|0;J=e>>>0>H>>>0?H:e;c[j>>2]=J;H=I-128|0;if(H>>>0>63>>>0){break a}I=YGb(H,(H|0)<0|0?-1:0,D<<6|0>>>26,C<<6|D>>>26)|0;H=F;K=E<<5;if((I&K|0)==0&(H&0|0)==0){y=H;z=I;A=K;B=J;break}else{C=H;D=I;E=K;G=J}}}G=f+24|0;c[G>>2]=(A<<1)-1&z;c[G+4>>2]=0&y;if((o|0)==0){yDb(b,g+16|0,2007592,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}else if((o|0)==7){G=t+(B>>>3)|0;E=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(B&7)>>>16;G=B+16|0;c[j>>2]=e>>>0>G>>>0?G:e;c[f+12>>2]=E+1}else if((o|0)==6){E=t+(B>>>3)|0;G=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(B&7)>>>24;E=B+8|0;c[j>>2]=e>>>0>E>>>0?E:e;c[f+12>>2]=G+1}else{c[f+12>>2]=c[1220720+(o<<2)>>2]}do{if(s>>>0<3221225472>>>0){c[f>>2]=c[1220192+(m<<2)>>2]}else{if((m|0)==13){G=c[j>>2]|0;E=c[l>>2]|0;D=t+(G>>>3)|0;C=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(G&7)>>>16;D=G+16|0;c[j>>2]=E>>>0>D>>>0?D:E;c[f>>2]=C;break}else if((m|0)==14){C=c[j>>2]|0;E=c[l>>2]|0;D=t+(C>>>3)|0;G=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>>16;D=C+16|0;c[j>>2]=E>>>0>D>>>0?D:E;c[f>>2]=G*10|0;break}else if((m|0)==12){G=c[j>>2]|0;E=c[l>>2]|0;D=t+(G>>>3)|0;C=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(G&7)>>>24;D=G+8|0;c[j>>2]=E>>>0>D>>>0?D:E;c[f>>2]=C*1e3|0;break}else{yDb(b,g+16|0,1969584,(q=i,i=i+8|0,c[q>>2]=m,q)|0);i=q;r=-1094995529;i=h;return r|0}}}while(0);C=c[l>>2]|0;E=(c[j>>2]|0)+8|0;c[j>>2]=C>>>0>E>>>0?E:C;C=tBb(0)|0;if((uBb(C,0,c[n>>2]|0,(c[j>>2]|0)/8|0)|0)==0){r=0;i=h;return r|0}yDb(b,g+16|0,1941056,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}}while(0);j=f+24|0;c[j>>2]=-1;c[j+4>>2]=-1;yDb(b,g+16|0,2053352,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}function U9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ba((c+14|0)/8|0,b)|0;if((b|0)==2){e=c<<1|1}else{e=ba(c,b)|0}return d+18+(((ba(e,a)|0)+7|0)/8|0)|0}function V9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=a+96|0;h=c[g>>2]|0;do{if((h|0)!=0){j=c[a+100>>2]|0;if((j|0)<34){break}k=h;do{if((d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)==1130450022){if((j|0)>=42){c[b>>2]=1;l=h+8|0;break}yDb(a,16,2353424,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=f;return n|0}else{if((j|0)==34){o=h}else{yDb(a,24,1896152,(m=i,i=i+8|0,c[m>>2]=34-j,m)|0);i=m;o=c[g>>2]|0}c[b>>2]=0;l=o}}while(0);c[e>>2]=l;n=1;i=f;return n|0}}while(0);yDb(a,16,1916808,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=f;return n|0}function W9(a){a=a|0;var b=0,d=0,e=0;b=c[a+416>>2]|0;if(b>>>0<9>>>0){d=1049520+(b-1<<3)|0;b=c[d+4>>2]|0;e=a+448|0;c[e>>2]=c[d>>2];c[e+4>>2]=b;return}else{b=a+448|0;c[b>>2]=0;c[b+4>>2]=0;return}}function X9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=(e|0)==0?8:280;h=g>>>0>16>>>0?16:g;j=e+(h>>>3)|0;k=fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;j=k>>>16;l=h+16|0;h=b+12|0;c[h>>2]=j;if(k>>>0<1048576>>>0){yDb(a,24,2333336,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;c[h>>2]=16}h=(g>>>0>l>>>0?l:g)+24|0;l=g>>>0>h>>>0?h:g;h=e+(l>>>3)|0;k=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(l&7)>>>8;h=l+24|0;l=g>>>0>h>>>0?h:g;c[b+16>>2]=k;k=e+(l>>>3)|0;h=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(l&7)>>>12;k=l+20|0;l=g>>>0>k>>>0?k:g;k=b|0;c[k>>2]=h;h=e+(l>>>3)|0;j=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(l&7)>>>29;h=l+3|0;l=g>>>0>h>>>0?h:g;h=j+1|0;c[b+4>>2]=h;m=e+(l>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(l&7)>>>27;m=l+5|0;l=g>>>0>m>>>0?m:g;m=b+8|0;c[m>>2]=n+1;c[a+416>>2]=h;c[a+412>>2]=c[k>>2];c[a+796>>2]=c[m>>2];if(h>>>0<9>>>0){h=1049520+(j<<3)|0;j=c[h+4>>2]|0;m=a+448|0;c[m>>2]=c[h>>2];c[m+4>>2]=j}else{j=a+448|0;c[j>>2]=0;c[j+4>>2]=0}j=e+(l>>>3)|0;a=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(l&7)>>>28;j=l+4|0;l=g>>>0>j>>>0?j:g;j=e+(l>>>3)|0;m=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(l&7)&-65536;j=l+16|0;l=g>>>0>j>>>0?j:g;g=e+(l>>>3)|0;e=b+24|0;c[e>>2]=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(l&7)>>>16|m;c[e+4>>2]=a;i=f;return}function Y9(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;g=d[a]|0;if((b|0)!=0){c[b>>2]=g&128}if((e|0)!=0){c[e>>2]=g&127}if((f|0)==0){return}c[f>>2]=(d[a+2|0]|0)<<8|(d[a+1|0]|0)<<16|(d[a+3|0]|0);return}function Z9(a){a=a|0;var b=0;b=c[a>>2]|0;c[b>>2]=a;a=UBb(106496)|0;c[b+28>>2]=a;return((a|0)==0?-12:0)|0}function _9(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;j=i;i=i+80|0;k=j|0;l=j+24|0;m=j+64|0;n=c[a>>2]|0;o=n;if((c[a+176>>2]&1|0)!=0){p=(g|0)==0?0:128;c[k>>2]=g;c[k+12>>2]=p;c[k+16>>2]=p|8;c[k+4>>2]=g+(p>>>3);c[k+8>>2]=0;do{if((T9(b,k,l,127)|0)==0){c[a+304>>2]=c[l+12>>2];p=b+412|0;if((c[p>>2]|0)!=0){break}c[p>>2]=c[l>>2]}}while(0);c[e>>2]=g;c[f>>2]=h;q=h;i=j;return q|0}c[n+4>>2]=b;l=n+24|0;if((c[l>>2]|0)!=0){q=aaa(o,e,f)|0;i=j;return q|0}k=n+12|0;p=k;r=c[p>>2]|0;do{if((r|0)!=0){s=c[r+60>>2]|0;t=n+8|0;u=c[t>>2]|0;if((s|0)==0){if((u|0)==(r|0)){v=r}else{w=u;while(1){x=c[w+56>>2]|0;$Db(w+4|0);ZDb(w);if((x|0)==(c[p>>2]|0)){v=x;break}else{w=x}}}c[t>>2]=c[v+56>>2];$Db(v+4|0);$Db(k);break}a:do{if((u|0)!=(s|0)){w=n+20|0;x=b;y=u;z=r;while(1){if((y|0)==(z|0)){A=y+56|0}else{B=c[y>>2]|0;C=y+56|0;D=c[c[C>>2]>>2]|0;yDb(x,48,2295560,(E=i,i=i+24|0,c[E>>2]=c[y+8>>2],c[E+8>>2]=B,c[E+16>>2]=D,E)|0);i=E;A=C}C=c[A>>2]|0;$Db(y+4|0);ZDb(y);c[w>>2]=(c[w>>2]|0)-1;if((C|0)==(s|0)){break a}y=C;z=c[p>>2]|0}}}while(0);u=s|0;$Bb(c[n+28>>2]|0,c[u>>2]|0);z=c[s+56>>2]|0;if((z|0)!=0){y=z;do{z=y|0;c[z>>2]=(c[z>>2]|0)-(c[u>>2]|0);y=c[y+56>>2]|0;}while((y|0)!=0)}y=n+20|0;c[y>>2]=(c[y>>2]|0)-1;c[u>>2]=0;c[t>>2]=s;if((c[y>>2]|0)<=9){c[p>>2]=0;break}c[p>>2]=s;q=aaa(o,e,f)|0;i=j;return q|0}}while(0);A=(g|0)!=0;r=A^1;k=n+20|0;v=n+32|0;y=n+28|0;z=m|0;m=n+16|0;w=n+8|0;x=h;h=g;b:while(1){C=h+16|0;D=h;B=x;F=h;while(1){G=(B|0)==0;H=G|r;I=g+B|0;do{if(A&(G^1)&F>>>0<I>>>0){J=c[k>>2]|0;if((J|0)>=10){K=29;break}if(H){K=32;break}L=I-F|0;M=(10-J<<13)+8192|0;N=B;O=F+((L|0)>(M|0)?M:L)|0}else{K=29}}while(0);if((K|0)==29){K=0;if(!H){P=0;K=69;break b}if((c[v>>2]|0)==0){K=32}else{P=G;K=69;break b}}if((K|0)==32){K=0;c[v>>2]=1;N=16;O=C}Q=O-D|0;if((XBb(c[y>>2]|0)|0)<(Q|0)){I=c[y>>2]|0;if((YBb(I,((WBb(I)|0)<<1)+Q|0)|0)<0){K=36;break b}}if((N|0)==0|r){TGb(z|0,0,16)|0;_Bb(c[y>>2]|0,z,16,0)|0}else{_Bb(c[y>>2]|0,h,Q,0)|0}I=-15-Q+(WBb(c[y>>2]|0)|0)|0;L=(I|0)<0?0:I;c[m>>2]=0;I=(WBb(c[y>>2]|0)|0)-15|0;M=I-L+1|0;J=c[y>>2]|0;R=c[J+4>>2]|0;S=R+L|0;T=c[J+12>>2]|0;if(S>>>0<T>>>0){U=S;V=T}else{S=T;U=R+(L-S+(c[J>>2]|0))|0;V=S}S=V-U|0;J=(M|0)>(S|0)?S:M;M=faa(o,U,J,L)|0;S=J-1|0;R=S+L|0;if((R|0)==(I|0)){W=M}else{T=I-R+1|0;I=J+L|0;L=c[y>>2]|0;J=c[L+4>>2]|0;X=J+I|0;Y=c[L+12>>2]|0;if(X>>>0<Y>>>0){Z=X;_=Y}else{X=Y;Z=J+(I-X+(c[L>>2]|0))|0;_=X}X=_-Z|0;if(((de((d[Z]|0)<<8|(d[U+S|0]|0)|0)|0)&-2)<<16>>16==-8){S=gaa(o,R)|0;$=(M|0)>(S|0)?M:S}else{$=M}M=faa(o,Z,(T|0)>(X|0)?X:T,I)|0;W=($|0)>(M|0)?$:M}do{if((W|0)==0){M=c[w>>2]|0;if((M|0)==0){aa=0;break}else{ba=0;ca=M}while(1){M=ba+1|0;I=c[ca+56>>2]|0;if((I|0)==0){da=M;K=53;break}else{ba=M;ca=I}}}else{da=W;K=53}}while(0);if((K|0)==53){K=0;if((da|0)<0){K=54;break b}else{aa=da}}c[k>>2]=aa;G=(c[v>>2]|0)==0;if(G&(aa|0)<10){K=56;break}if(G){if((c[m>>2]|0)!=0){K=60}}else{K=60}do{if((K|0)==60){K=0;G=c[w>>2]|0;if((G|0)==0){break}else{ea=G}do{c[ea+8>>2]=-1e5;ea=c[ea+56>>2]|0;}while((ea|0)!=0);G=c[w>>2]|0;if((G|0)==0){break}else{fa=0;ga=G}while(1){if((caa(o,ga)|0)>(fa|0)){c[p>>2]=ga;ha=c[ga+8>>2]|0}else{ha=fa}G=c[ga+56>>2]|0;if((G|0)==0){break}else{fa=ha;ga=G}}}}while(0);if((c[v>>2]|0)==0){B=N;F=O}else{K=67;break}}if((K|0)==56){K=0;if(!A){ia=O;break}if(O>>>0<(g+N|0)>>>0){x=N;h=O;continue}else{ia=O;break}}else if((K|0)==67){K=0;B=c[y>>2]|0;D=B+8|0;C=c[D>>2]|0;s=(C-(c[B>>2]|0)|0)<16;c[D>>2]=C-16;C=c[y>>2]|0;D=C+20|0;c[D>>2]=(c[D>>2]|0)-16;if(!s){x=0;h=0;continue}s=C+8|0;c[s>>2]=(c[s>>2]|0)+((c[C+12>>2]|0)-(c[C>>2]|0));x=0;h=0;continue}}do{if((K|0)==36){h=(WBb(c[y>>2]|0)|0)+Q|0;yDb(b,16,2325752,(E=i,i=i+8|0,c[E>>2]=h,E)|0);i=E;ia=O}else if((K|0)==54){yDb(b,16,2188904,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;ia=O}else if((K|0)==69){h=c[w>>2]|0;if((h|0)!=0){x=h;do{h=c[x+8>>2]|0;do{if((h|0)>0){N=c[p>>2]|0;if((N|0)!=0){if((h|0)<=(c[N+8>>2]|0)){break}}c[p>>2]=x}}while(0);x=c[x+56>>2]|0;}while((x|0)!=0)}x=c[p>>2]|0;if((x|0)==0){ia=F;break}c[l>>2]=1;h=c[x>>2]|0;if((h|0)<=0){if(!P){ia=F;break}q=aaa(o,e,f)|0;i=j;return q|0}yDb(b,48,2111808,(E=i,i=i+8|0,c[E>>2]=h,E)|0);i=E;c[a+304>>2]=0;h=c[c[p>>2]>>2]|0;c[f>>2]=h;c[e>>2]=baa(o,0,h,n+36|0,n+40|0)|0;if(P){h=c[c[p>>2]>>2]|0;q=h-(WBb(c[y>>2]|0)|0)|0;i=j;return q|0}else{q=F-g|0;i=j;return q|0}}}while(0);c[e>>2]=0;c[f>>2]=0;q=ia-g|0;i=j;return q|0}function $9(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;a=c[b+8>>2]|0;if((a|0)!=0){d=a;while(1){a=c[d+56>>2]|0;$Db(d+4|0);ZDb(d);if((a|0)==0){break}else{d=a}}}VBb(c[b+28>>2]|0);ZDb(c[b+36>>2]|0);return}function aaa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[a+12>>2]|0;f=c[e+60>>2]|0;g=(f|0)!=0;if(g){c[d>>2]=(c[f>>2]|0)-(c[e>>2]|0);eaa(a,e,f,0)|0}else{h=WBb(c[a+28>>2]|0)|0;c[d>>2]=h-(c[e>>2]|0)}h=e+16|0;i=c[e+20>>2]|0;j=a+4|0;k=c[j>>2]|0;l=k+416|0;if((i|0)==(c[l>>2]|0)){m=k+448|0;if((c[m>>2]|0)==0&(c[m+4>>2]|0)==0){n=6}else{o=k}}else{n=6}if((n|0)==6){c[l>>2]=i;W9(k);o=c[j>>2]|0}c[o+412>>2]=c[h>>2];c[(c[a>>2]|0)+304>>2]=c[e+28>>2];c[b>>2]=baa(a,c[e>>2]|0,c[d>>2]|0,a+36|0,a+40|0)|0;c[a+24>>2]=0;c[a+88>>2]=1;d=a+48|0;e=h;c[d>>2]=c[e>>2];c[d+4>>2]=c[e+4>>2];c[d+8>>2]=c[e+8>>2];c[d+12>>2]=c[e+12>>2];c[d+16>>2]=c[e+16>>2];c[d+20>>2]=c[e+20>>2];c[d+24>>2]=c[e+24>>2];c[d+28>>2]=c[e+28>>2];c[d+32>>2]=c[e+32>>2];c[d+36>>2]=c[e+36>>2];if(!g){p=0;return p|0}g=c[f>>2]|0;p=g-(WBb(c[a+28>>2]|0)|0)|0;return p|0}function baa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=c[a+28>>2]|0;j=c[h+4>>2]|0;k=j+b|0;l=h+12|0;m=c[l>>2]|0;if(k>>>0<m>>>0){n=k;o=m}else{k=m;n=j+(b-k+(c[h>>2]|0))|0;o=k}if((o-n|0)>=(d|0)){p=n;i=g;return p|0}o=jEb(c[e>>2]|0,f,d)|0;if((o|0)==0){yDb(c[a+4>>2]|0,16,2053288,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;p=0;i=g;return p|0}c[e>>2]=o;a=h|0;h=o;o=n;n=d;d=c[l>>2]|0;while(1){f=d-o|0;k=(f|0)>(n|0)?n:f;UGb(h|0,o|0,k)|0;f=c[l>>2]|0;b=n-k|0;if((b|0)>0){h=h+k|0;o=o+((c[a>>2]|0)-f+k)|0;n=b;d=f}else{break}}p=c[e>>2]|0;i=g;return p|0}function caa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b+8|0;e=c[d>>2]|0;if(!((e|0)==-1e5)){f=e;return f|0}if((c[a+88>>2]|0)==0){g=10}else{g=10-(daa(a,a+48|0,b+16|0,48)|0)|0}c[d>>2]=g;e=c[b+56>>2]|0;if((e|0)==0){f=g;return f|0}h=b+4|0;i=b+60|0;j=0;k=e;e=c[h>>2]|0;while(1){if((c[e+(j<<2)>>2]|0)==1e5){l=eaa(a,b,k,48)|0;c[(c[h>>2]|0)+(j<<2)>>2]=l}l=caa(a,k)|0;m=c[h>>2]|0;n=l-(c[m+(j<<2)>>2]|0)|0;l=c[d>>2]|0;if((n+10|0)>(l|0)){c[i>>2]=k;o=n+g|0;c[d>>2]=o;p=o}else{p=l}l=j+1|0;o=c[k+56>>2]|0;if((l|0)>2|(o|0)==0){f=p;break}else{j=l;k=o;e=m}}return f|0}function daa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;if((c[d>>2]|0)==(c[b>>2]|0)){g=0}else{yDb(c[a+4>>2]|0,e+24|0,1941008,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=7}if((c[d+8>>2]|0)==(c[b+8>>2]|0)){j=g}else{yDb(c[a+4>>2]|0,e+24|0,1916752,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=g+7|0}if((c[d+32>>2]|0)==(c[b+32>>2]|0)){k=j}else{yDb(c[a+4>>2]|0,e+24|0,1896096,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;k=j+10|0}if((c[d+4>>2]|0)==(c[b+4>>2]|0)){l=k;i=f;return l|0}yDb(c[a+4>>2]|0,e+24|0,2353368,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;l=k+7|0;i=f;return l|0}function eaa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=i;g=daa(a,b+16|0,d+16|0,e)|0;h=d+40|0;j=c[h>>2]|0;k=c[h+4>>2]|0;l=b+40|0;m=c[l>>2]|0;n=c[l+4>>2]|0;o=ZGb(j,k,m,n)|0;p=c[b+28>>2]|0;q=(o|0)==(p|0)&(F|0)==(((p|0)<0|0?-1:0)|0);p=YGb(m,n,1,0)|0;if(q|(j|0)==(p|0)&(k|0)==(F|0)){r=0;s=g}else{p=m;if((b|0)==(d|0)){t=p;u=p}else{m=b;q=p;n=p;while(1){p=m+4|0;o=0;while(1){if((o|0)>=3){v=n;w=q;break}if((c[(c[p>>2]|0)+(o<<2)>>2]|0)<50){x=6;break}else{o=o+1|0}}if((x|0)==6){x=0;v=(c[m+28>>2]|0)+n|0;w=q+1|0}o=c[m+56>>2]|0;if((o|0)==(d|0)){t=w;u=v;break}else{m=o;q=w;n=v}}}if((t|0)==(j|0)&(((t|0)<0|0?-1:0)|0)==(k|0)){x=10}else{if((u|0)==(j|0)&(((u|0)<0|0?-1:0)|0)==(k|0)){x=10}else{y=0}}if((x|0)==10){y=(g|0)==0|0}yDb(c[a+4>>2]|0,e+24|0,2007536,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;r=y;s=g+7|0}if(!((s|0)!=0&(r|0)==0)){A=s;i=f;return A|0}r=c[b+56>>2]|0;if((r|0)==(d|0)){B=0}else{g=0;y=r;while(1){x=g+1|0;k=c[y+56>>2]|0;if((x|0)>2|(k|0)==(d|0)){B=x;break}else{g=x;y=k}}}y=c[b+4>>2]|0;g=c[y+(B<<2)>>2]|0;do{if((g|0)<50|(g|0)==1e5){a:do{if((B|0)>0){k=B-1|0;if((c[y+(k<<2)>>2]|0)>49){C=b;D=r}else{x=(c[(c[r+4>>2]|0)+(k<<2)>>2]|0)>49;E=x?r:d;G=b;H=x&1;break}while(1){if((D|0)==(d|0)){E=d;G=C;H=1;break a}C=D;D=c[D+56>>2]|0}}else{E=d;G=b;H=0}}while(0);x=E|0;k=G|0;u=c[k>>2]|0;j=(c[x>>2]|0)-u|0;t=a+28|0;v=c[t>>2]|0;n=c[v+4>>2]|0;w=n+u|0;q=c[v+12>>2]|0;if(w>>>0<q>>>0){I=w;J=q}else{w=q;I=n+(u-w+(c[v>>2]|0))|0;J=w}w=J-I|0;v=(j|0)>(w|0)?w:j;j=uBb(tBb(1)|0,0,I,v)|0;w=c[x>>2]|0;x=w-(c[k>>2]|0)|0;k=x-v|0;if((x|0)==(v|0)){K=j}else{v=w-k|0;w=c[t>>2]|0;t=c[w+4>>2]|0;x=t+v|0;u=c[w+12>>2]|0;if(x>>>0<u>>>0){L=x;M=u}else{x=u;L=t+(v-x+(c[w>>2]|0))|0;M=x}x=M-L|0;K=uBb(tBb(1)|0,j,L,(k|0)>(x|0)?x:k)|0}if((K|0)==0^(H|0)==0){break}else{A=s}i=f;return A|0}}while(0);H=c[l>>2]|0;K=c[l+4>>2]|0;l=c[d>>2]|0;d=c[h>>2]|0;L=c[h+4>>2]|0;yDb(c[a+4>>2]|0,e+24|0,1969512,(z=i,i=i+48|0,c[z>>2]=c[b>>2],c[z+8>>2]=H,c[z+16>>2]=K,c[z+24>>2]=l,c[z+32>>2]=d,c[z+40>>2]=L,z)|0);i=z;A=s+50|0;i=f;return A|0}function faa(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c-1|0;c=(f|0)%4|0;if((c|0)>0){g=0;h=0;while(1){i=b+g|0;if(((de((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-8){j=gaa(a,g+e|0)|0}else{j=h}i=g+1|0;if((i|0)<(c|0)){g=i;h=j}else{k=c;l=j;break}}}else{k=0;l=0}if((k|0)<(f|0)){m=k;n=l}else{o=l;return o|0}while(1){l=b+m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=fe(k|0)|0;do{if((l&-2139062144&-16843010-l|0)==0){p=n}else{j=m+e|0;if(((de(k&65535|0)|0)&-2)<<16>>16==-8){q=gaa(a,j)|0}else{q=n}c=b+(m+1)|0;if(((de((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-8){r=gaa(a,j+1|0)|0}else{r=q}c=b+(m+2)|0;if(((de((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-8){s=gaa(a,j+2|0)|0}else{s=r}c=b+(m+3)|0;if(!(((de((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-8)){p=s;break}p=gaa(a,j+3|0)|0}}while(0);k=m+4|0;if((k|0)<(f|0)){m=k;n=p}else{o=p;break}}return o|0}function gaa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+64|0;e=d|0;f=d+24|0;g=baa(a,b,16,a+36|0,a+40|0)|0;h=a+4|0;j=c[h>>2]|0;k=(g|0)==0?0:128;c[e>>2]=g;c[e+12>>2]=k;c[e+16>>2]=k|8;c[e+4>>2]=g+(k>>>3);c[e+8>>2]=0;if((T9(j,e,f,127)|0)!=0){l=0;i=d;return l|0}e=a+8|0;j=c[e>>2]|0;if((j|0)==0){m=1;n=e}else{e=1;k=j;while(1){j=k+56|0;g=e+1|0;o=c[j>>2]|0;if((o|0)==0){m=g;n=j;break}else{e=g;k=o}}}k=cEb(64)|0;c[n>>2]=k;if((k|0)==0){yDb(c[h>>2]|0,16,2333288,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;l=-12;i=d;return l|0}else{h=k+16|0;k=f;c[h>>2]=c[k>>2];c[h+4>>2]=c[k+4>>2];c[h+8>>2]=c[k+8>>2];c[h+12>>2]=c[k+12>>2];c[h+16>>2]=c[k+16>>2];c[h+20>>2]=c[k+20>>2];c[h+24>>2]=c[k+24>>2];c[h+28>>2]=c[k+28>>2];c[h+32>>2]=c[k+32>>2];c[h+36>>2]=c[k+36>>2];c[c[n>>2]>>2]=b;b=WDb(12)|0;c[(c[n>>2]|0)+4>>2]=b;b=c[(c[n>>2]|0)+4>>2]|0;c[b>>2]=1e5;c[b+4>>2]=1e5;c[b+8>>2]=1e5;b=a+16|0;c[b>>2]=(c[b>>2]|0)+1;l=m;i=d;return l|0}return 0}function haa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+16|0;d=b+8|0;e=c[a+60>>2]|0;f=e+32|0;c[f>>2]=a;if((c[a+96>>2]|0)==0){g=0;i=b;return g|0}if((V9(a,b|0,d)|0)==0){g=-1094995529;i=b;return g|0}X9(a,e,c[d>>2]|0);d=kaa(e)|0;if((d|0)<0){g=d;i=b;return g|0}d=c[(c[f>>2]|0)+468>>2]|0;h=e+8|0;j=(c[h>>2]|0)>16;k=BFb(d)|0;l=(CFb(d)|0)==0;d=(c[f>>2]|0)+420|0;if(j|(k|0)>2){c[d>>2]=l?2:7;k=c[h>>2]|0;c[e+60>>2]=32-k;m=k}else{c[d>>2]=l?1:6;l=c[h>>2]|0;c[e+60>>2]=16-l;m=l}maa(e+112|0,c[a+420>>2]|0,m);c[e+68>>2]=1;g=0;i=b;return g|0}function iaa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;h=i;i=i+216|0;j=h|0;k=h+128|0;l=h+168|0;m=h+176|0;n=h+184|0;o=h+192|0;p=h+200|0;c[p>>2]=e;c[p+4>>2]=0;c[p+8>>2]=0;q=c[g+24>>2]|0;r=c[g+28>>2]|0;s=c[b+60>>2]|0;t=s;c[f>>2]=0;u=s+16|0;if((c[u>>2]|0)==0){v=c[s+12>>2]|0;c[u>>2]=U9((v|0)==0?65535:v,8,32)|0}do{if((r|0)>5){if((PGb(q,2188888,5)|0)!=0){break}yDb(c[s+32>>2]|0,48,2111776,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=r;i=h;return x|0}}while(0);if((r|0)<=0){x=r;i=h;return x|0}if((a[q]&127)==4){yDb(c[s+32>>2]|0,48,2053264,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=r;i=h;return x|0}if((r|0)<11){x=r;i=h;return x|0}v=q;if((d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)==1130450022){v=s+68|0;a:do{if((c[v>>2]|0)==0){if((r|0)<42){break}Y9(q+4|0,0,n,o);do{if((c[n>>2]|0)==0){if((c[o>>2]|0)!=34){y=-1094995529;break}z=s+32|0;X9(c[z>>2]|0,s,q+8|0);A=kaa(t)|0;if((A|0)<0){y=A;break}A=c[(c[z>>2]|0)+468>>2]|0;B=s+8|0;C=(c[B>>2]|0)>16;D=BFb(A)|0;E=(CFb(A)|0)==0;A=(c[z>>2]|0)+420|0;if(C|(D|0)>2){c[A>>2]=E?2:7;D=c[B>>2]|0;c[s+60>>2]=32-D;F=D}else{c[A>>2]=E?1:6;E=c[B>>2]|0;c[s+60>>2]=16-E;F=E}maa(s+112|0,c[(c[z>>2]|0)+420>>2]|0,F);c[v>>2]=1;break a}else{y=-1094995529}}while(0);yDb(c[s+32>>2]|0,16,2007496,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=y;i=h;return x|0}}while(0);y=q+r|0;v=q+4|0;while(1){if((y-v|0)<4){x=0;G=154;break}Y9(v,l,0,m);F=c[m>>2]|0;if((y-(v+4)|0)<(F|0)){x=0;G=154;break}H=v+(F+4)|0;if((c[l>>2]|0)==0){v=H}else{G=25;break}}if((G|0)==25){x=r-y+H|0;i=h;return x|0}else if((G|0)==154){i=h;return x|0}}H=s+36|0;y=r>>>0>268435455>>>0?-8:r<<3;v=y>>>0>2147483639>>>0|(q|0)==0;l=v?0:q;m=v?0:y;y=H;c[y>>2]=l;F=s+48|0;c[F>>2]=m;o=s+52|0;c[o>>2]=m+8;c[s+40>>2]=l+(m>>3);m=s+44|0;c[m>>2]=0;if(v){x=v?-1094995529:0;i=h;return x|0}v=s+32|0;l=T9(c[v>>2]|0,H,k,0)|0;b:do{if((l|0)<0){yDb(c[v>>2]|0,16,2353344,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=l}else{H=s+4|0;n=c[H>>2]|0;z=k+4|0;do{if((n|0)!=0){E=c[z>>2]|0;if((E|0)==(n|0)){break}if((c[s+68>>2]|0)==0){break}B=c[v>>2]|0;c[B+416>>2]=E;c[H>>2]=E;W9(B);B=kaa(t)|0;if((B|0)<0){I=B;break b}}}while(0);n=c[z>>2]|0;B=c[v>>2]|0;c[B+416>>2]=n;c[H>>2]=n;n=B+448|0;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){W9(B)}B=s+64|0;c[B>>2]=c[k+16>>2];n=s+8|0;E=c[n>>2]|0;A=k+8|0;D=c[A>>2]|0;C=(D|0)==0;do{if((E|0)==0){J=c[v>>2]|0;if(C){yDb(J,16,2333240,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}c[J+796>>2]=D;c[n>>2]=D;K=c[J+468>>2]|0;J=BFb(K)|0;L=(CFb(K)|0)==0;K=(c[v>>2]|0)+420|0;if((D|0)>16|(J|0)>2){c[K>>2]=L?2:7;c[s+60>>2]=32-(c[n>>2]|0);break}else{c[K>>2]=L?1:6;c[s+60>>2]=16-(c[n>>2]|0);break}}else{if(C){c[A>>2]=E;break}if((D|0)==(E|0)){break}yDb(c[v>>2]|0,16,2308704,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}}while(0);E=s+12|0;D=c[E>>2]|0;if((D|0)==0){c[E>>2]=65535;M=65535}else{M=D}D=c[k+12>>2]|0;if((D|0)>(M|0)){yDb(c[v>>2]|0,16,2290144,(w=i,i=i+16|0,c[w>>2]=D,c[w+8>>2]=M,w)|0);i=w;I=-1094995529;break}A=s+56|0;c[A>>2]=D;D=s;C=c[D>>2]|0;z=k|0;L=c[z>>2]|0;K=(L|0)==0;do{if((C|0)==0){if(!K){N=L;break}yDb(c[v>>2]|0,16,2274240,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}else{if(!K){N=L;break}c[z>>2]=C;N=C}}while(0);c[(c[v>>2]|0)+412>>2]=N;c[D>>2]=N;C=s+68|0;if((c[C>>2]|0)==0){z=kaa(t)|0;if((z|0)<0){I=z;break}maa(s+112|0,c[(c[v>>2]|0)+420>>2]|0,c[n>>2]|0);c[C>>2]=1;C=c[v>>2]|0;yDb(C,48,2152144,(w=i,i=i+8|0,c[w>>2]=c[E>>2],w)|0);i=w;yDb(C,48,2145296,(w=i,i=i+8|0,c[w>>2]=c[u>>2],w)|0);i=w;yDb(C,48,2139448,(w=i,i=i+8|0,c[w>>2]=c[D>>2],w)|0);i=w;yDb(C,48,2133136,(w=i,i=i+8|0,c[w>>2]=c[H>>2],w)|0);i=w;yDb(C,48,2126736,(w=i,i=i+8|0,c[w>>2]=c[n>>2],w)|0);i=w}c:do{if((c[H>>2]|0)>0){C=s+128|0;z=j|0;L=0;d:while(1){K=c[t+72+(L<<2)>>2]|0;J=c[n>>2]|0;O=c[B>>2]|0;do{if((L|0)==0){P=((O|0)==2)+J|0}else{if(!((O|0)==1|(O|0)==3)){P=J;break}P=J+1|0}}while(0);J=c[m>>2]|0;O=c[y>>2]|0;Q=d[O+(J>>>3)|0]|0;R=c[o>>2]|0;S=((J|0)<(R|0))+J|0;c[m>>2]=S;if((Q&128>>>((J&7)>>>0)|0)!=0){G=64;break}J=O+(S>>>3)|0;Q=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(S&7);J=Q>>>26;T=S+6|0;S=R>>>0>T>>>0?T:R;c[m>>2]=S;T=d[O+(S>>>3)|0]|0;U=((S|0)<(R|0))+S|0;c[m>>2]=U;if((T&128>>>((S&7)>>>0)|0)==0){V=0;W=P;X=U}else{Y=(c[F>>2]|0)-U|0;if((Y|0)<0){G=77;break}if((Y|0)<(P|0)){S=O+(U>>>3)|0;T=d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0;S=U&7;Z=(fe(T|0)|0)<<S;if((Y|0)<26){_=Z>>>((32-Y|0)>>>0)}else{$=U+16|0;aa=R>>>0>$>>>0?$:R;$=O+(aa>>>3)|0;_=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(aa&7)>>>((48-Y|0)>>>0)|Z>>>16<<Y-16}if((_|0)==0){G=77;break}else{ba=S;ca=T}}else{T=O+(U>>>3)|0;ba=U&7;ca=d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0}T=(fe(ca|0)|0)<<ba;if((P|0)<26){da=T>>>((32-P|0)>>>0)}else{S=U+16|0;Z=R>>>0>S>>>0?S:R;S=O+(Z>>>3)|0;da=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Z&7)>>>((48-P|0)>>>0)|T>>>16<<P-16}if((da|0)==0){G=77;break}else{ea=0;fa=U}while(1){if((ea|0)>=(Y|0)){G=79;break}U=d[O+(fa>>>3)|0]|0;T=((fa|0)<(R|0))+fa|0;c[m>>2]=T;Z=ea+1|0;if((U&128>>>((fa&7)>>>0)|0)==0){ea=Z;fa=T}else{ga=T;ha=Z;break}}if((G|0)==79){G=0;ga=fa;ha=ea+1|0}V=ha;W=P-ha|0;X=ga}if((W|0)>32){G=83;break}e:do{if((J|0)==1){if((c[A>>2]|0)<=0){break}Z=(W|0)==0;T=32-W|0;U=(W|0)<26;S=W-16|0;aa=48-W|0;$=0;do{do{if(Z){ia=0}else{ja=c[m>>2]|0;ka=c[o>>2]|0;la=O+(ja>>>3)|0;ma=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ja&7);if(U){la=ja+W|0;c[m>>2]=ka>>>0>la>>>0?la:ka;ia=ma>>>(T>>>0);break}else{la=ja+16|0;ja=ka>>>0>la>>>0?la:ka;c[m>>2]=ja;la=O+(ja>>>3)|0;na=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ja&7)>>>(aa>>>0);la=ja+S|0;c[m>>2]=ka>>>0>la>>>0?la:ka;ia=na|ma>>>16<<S;break}}}while(0);c[K+($<<2)>>2]=ia<<T>>T;$=$+1|0;}while(($|0)<(c[A>>2]|0))}else if((J|0)==0){do{if((W|0)==0){oa=0}else{$=O+(X>>>3)|0;T=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(X&7);if((W|0)<26){$=W+X|0;c[m>>2]=R>>>0>$>>>0?$:R;oa=T>>>((32-W|0)>>>0);break}else{$=X+16|0;S=R>>>0>$>>>0?$:R;c[m>>2]=S;$=W-16|0;aa=O+(S>>>3)|0;U=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(S&7)>>>((48-W|0)>>>0);aa=S+$|0;c[m>>2]=R>>>0>aa>>>0?aa:R;oa=U|T>>>16<<$;break}}}while(0);$=32-W|0;T=oa<<$>>$;if((c[A>>2]|0)>0){pa=0}else{break}do{c[K+(pa<<2)>>2]=T;pa=pa+1|0;}while((pa|0)<(c[A>>2]|0))}else{if(!((J-8|0)>>>0<5>>>0)){if((Q|0)>=0){G=137;break d}T=J&31;$=T+1|0;U=(W|0)==0;aa=32-W|0;S=(W|0)<26;Z=W-16|0;ma=48-W|0;na=0;do{do{if(U){qa=0}else{ka=c[m>>2]|0;la=c[o>>2]|0;ja=O+(ka>>>3)|0;ra=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ka&7);if(S){ja=ka+W|0;c[m>>2]=la>>>0>ja>>>0?ja:la;qa=ra>>>(aa>>>0);break}else{ja=ka+16|0;ka=la>>>0>ja>>>0?ja:la;c[m>>2]=ka;ja=O+(ka>>>3)|0;sa=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ka&7)>>>(ma>>>0);ja=ka+Z|0;c[m>>2]=la>>>0>ja>>>0?ja:la;qa=sa|ra>>>16<<Z;break}}}while(0);c[K+(na<<2)>>2]=qa<<aa>>aa;na=na+1|0;}while((na|0)<($|0));na=c[m>>2]|0;aa=c[o>>2]|0;Z=O+(na>>>3)|0;ma=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(na&7)>>>28;Z=na+4|0;na=aa>>>0>Z>>>0?Z:aa;c[m>>2]=na;Z=ma+1|0;if((Z|0)==16){G=130;break d}S=O+(na>>>3)|0;ta=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(na&7)>>27;S=na+5|0;na=aa>>>0>S>>>0?S:aa;c[m>>2]=na;if((ta|0)<0){G=133;break d}S=ma^31;ma=0;U=na;do{na=O+(U>>>3)|0;ra=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(U&7)>>S;na=U+Z|0;U=aa>>>0>na>>>0?na:aa;c[m>>2]=U;c[j+(T-ma<<2)>>2]=ra;ma=ma+1|0;}while((ma|0)<($|0));ma=laa(t,K,$)|0;if((ma|0)<0){I=ma;break b}le[c[C>>2]&1023](K,z,$,ta,c[A>>2]|0);break}ua=J&55;ma=c[A>>2]|0;T=(ua|0)!=0;if(T){U=(W|0)==0;aa=32-W|0;Z=(W|0)<26;S=W-16|0;ra=48-W|0;na=0;do{do{if(U){va=0}else{sa=c[m>>2]|0;la=c[o>>2]|0;ja=O+(sa>>>3)|0;ka=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(sa&7);if(Z){ja=sa+W|0;c[m>>2]=la>>>0>ja>>>0?ja:la;va=ka>>>(aa>>>0);break}else{ja=sa+16|0;sa=la>>>0>ja>>>0?ja:la;c[m>>2]=sa;ja=O+(sa>>>3)|0;wa=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(sa&7)>>>(ra>>>0);ja=sa+S|0;c[m>>2]=la>>>0>ja>>>0?ja:la;va=wa|ka>>>16<<S;break}}}while(0);c[K+(na<<2)>>2]=va<<aa>>aa;na=na+1|0;}while((na|0)<(ua|0))}na=laa(t,K,ua)|0;if((na|0)<0){I=na;break b}if(!T){break}na=c[K+(ua-1<<2)>>2]|0;if(!(ua>>>0>1>>>0)){if((ma|0)>1){xa=na;ya=1}else{break}while(1){aa=K+(ya<<2)|0;xa=(c[aa>>2]|0)+xa|0;c[aa>>2]=xa;ya=ya+1|0;if((ya|0)>=(ma|0)){break e}}}T=c[K+(ua-2<<2)>>2]|0;aa=na-T|0;if(!(ua>>>0>2>>>0)){if((ma|0)>2){za=na;Aa=aa;Ba=2}else{break}while(1){S=K+(Ba<<2)|0;Aa=(c[S>>2]|0)+Aa|0;za=Aa+za|0;c[S>>2]=za;Ba=Ba+1|0;if((Ba|0)>=(ma|0)){break e}}}S=c[K+(ua-3<<2)>>2]|0;ra=S+(aa-T)|0;if(!(ua>>>0>3>>>0)){if((ma|0)>3){Ca=na;Da=aa;Ea=ra;Fa=3}else{break}while(1){Z=K+(Fa<<2)|0;Ea=(c[Z>>2]|0)+Ea|0;Da=Ea+Da|0;Ca=Da+Ca|0;c[Z>>2]=Ca;Fa=Fa+1|0;if((Fa|0)>=(ma|0)){break e}}}if((ua|0)!=4){G=121;break d}if((ma|0)<=4){break}Z=na;U=aa;$=ra;ka=ra-T+(S<<1)-(c[K>>2]|0)|0;wa=4;do{la=K+(wa<<2)|0;ka=(c[la>>2]|0)+ka|0;$=ka+$|0;U=$+U|0;Z=U+Z|0;c[la>>2]=Z;wa=wa+1|0;}while((wa|0)<(ma|0))}}while(0);do{if((V|0)!=0){if((c[A>>2]|0)>0){Ga=0}else{break}do{O=K+(Ga<<2)|0;c[O>>2]=c[O>>2]<<V;Ga=Ga+1|0;}while((Ga|0)<(c[A>>2]|0))}}while(0);L=L+1|0;if((L|0)>=(c[H>>2]|0)){break c}}if((G|0)==64){yDb(c[v>>2]|0,16,2258520,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}else if((G|0)==77){yDb(c[v>>2]|0,16,2244120,(w=i,i=i+16|0,c[w>>2]=P,c[w+8>>2]=Y,w)|0);i=w;I=-1094995529;break b}else if((G|0)==83){EDb(c[v>>2]|0,2231632,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1163346256;break b}else if((G|0)==121){yDb(c[v>>2]|0,16,2159240,(w=i,i=i+8|0,c[w>>2]=ua,w)|0);i=w;I=-1094995529;break b}else if((G|0)==130){yDb(c[v>>2]|0,16,2210128,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}else if((G|0)==133){yDb(c[v>>2]|0,16,2201344,(w=i,i=i+8|0,c[w>>2]=ta,w)|0);i=w;I=-1094995529;break b}else if((G|0)==137){yDb(c[v>>2]|0,16,2219488,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}}}while(0);n=c[m>>2]|0;D=-n&7;E=c[o>>2]|0;if((D|0)==0){Ha=n}else{L=D+n|0;n=E>>>0>L>>>0?L:E;c[m>>2]=n;Ha=n}n=Ha+16|0;c[m>>2]=E>>>0>n>>>0?n:E;E=(c[m>>2]|0)/8|0;do{if((c[(c[v>>2]|0)+696>>2]&131073|0)!=0){if((uBb(tBb(1)|0,0,q,E)|0)==0){break}n=g+8|0;L=c[n+4>>2]|0;yDb(c[v>>2]|0,16,1940984,(w=i,i=i+16|0,c[w>>2]=c[n>>2],c[w+8>>2]=L,w)|0);i=w;if((c[(c[v>>2]|0)+696>>2]&8|0)==0){break}else{x=-1094995529}i=h;return x|0}}while(0);c[e+76>>2]=c[A>>2];L=W0a(b,p,0)|0;if((L|0)<0){x=L;i=h;return x|0}le[c[s+112+(c[B>>2]<<2)>>2]&1023](e,s+72|0,c[H>>2]|0,c[A>>2]|0,c[s+60>>2]|0);if((E|0)>(r|0)){yDb(c[v>>2]|0,16,1916736,(w=i,i=i+8|0,c[w>>2]=E-r,w)|0);i=w;x=-1094995529;i=h;return x|0}if((E|0)<(r|0)){yDb(c[v>>2]|0,48,1896064,(w=i,i=i+16|0,c[w>>2]=r-E,c[w+8>>2]=r,w)|0);i=w}c[f>>2]=1;x=E;i=h;return x|0}}while(0);yDb(c[v>>2]|0,16,1969480,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=I;i=h;return x|0}function jaa(a){a=a|0;$Db((c[a+60>>2]|0)+104|0);return 0}function kaa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+12|0;e=c[d>>2]|0;if((e|0)==0){yDb(0,0,2120880,(f=i,i=i+24|0,c[f>>2]=2114816,c[f+8>>2]=2100608,c[f+16>>2]=134,f)|0);i=f;Cd();return 0}f=a+4|0;g=DFb(0,c[f>>2]|0,e,7,0)|0;if((g|0)<0){h=g;i=b;return h|0}e=a+104|0;kEb(e,a+108|0,g);g=c[e>>2]|0;if((g|0)==0){h=-12;i=b;return h|0}h=EFb(a+72|0,0,g,c[f>>2]|0,c[d>>2]|0,7,0)|0;i=b;return h|0}function laa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;g=a+44|0;h=c[g>>2]|0;j=a+52|0;k=c[j>>2]|0;l=c[a+36>>2]|0;m=l+(h>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(h&7);m=n>>>30;o=h+2|0;h=k>>>0>o>>>0?o:k;c[g>>2]=h;if((n|0)<0){yDb(c[a+32>>2]|0,16,2193008,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;q=-1094995529;i=f;return q|0}n=l+(h>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>28;n=h+4|0;h=k>>>0>n>>>0?n:k;c[g>>2]=h;n=c[a+56>>2]|0;r=n>>o;if((r<<o|0)!=(n|0)){yDb(c[a+32>>2]|0,16,2176560,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=n,p)|0);i=p;q=-1094995529;i=f;return q|0}if((r|0)<(e|0)){yDb(c[a+32>>2]|0,16,2165856,(p=i,i=i+16|0,c[p>>2]=e,c[p+8>>2]=r,p)|0);i=p;q=-1094995529;i=f;return q|0}p=m|4;m=(1<<p)-1|0;n=1<<o;if((n|0)<=0){q=0;i=f;return q|0}o=32-p|0;s=a+48|0;a=1;t=e;u=b+(e<<2)|0;e=h;h=k;while(1){k=l+(e>>>3)|0;b=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(e&7)>>>(o>>>0);k=e+p|0;v=h>>>0>k>>>0?k:h;c[g>>2]=v;do{if((b|0)==(m|0)){k=l+(v>>>3)|0;w=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(v&7);k=w>>>27;x=v+5|0;c[g>>2]=h>>>0>x>>>0?x:h;if((t|0)>=(r|0)){y=u;break}x=(k|0)==0;z=32-k|0;A=w>>>0<3489660928>>>0;w=k-16|0;B=48-k|0;C=t;D=u;while(1){do{if(x){E=0}else{F=c[g>>2]|0;G=c[j>>2]|0;H=l+(F>>>3)|0;I=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7);if(A){H=F+k|0;c[g>>2]=G>>>0>H>>>0?H:G;E=I>>>(z>>>0);break}else{H=F+16|0;F=G>>>0>H>>>0?H:G;c[g>>2]=F;H=l+(F>>>3)|0;J=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>(B>>>0);H=F+w|0;c[g>>2]=G>>>0>H>>>0?H:G;E=J|I>>>16<<w;break}}}while(0);c[D>>2]=E<<z>>z;I=C+1|0;if((I|0)<(r|0)){C=I;D=D+4|0}else{break}}y=u+(r-t<<2)|0}else{if((t|0)>=(r|0)){y=u;break}D=32-b|0;C=b+32|0;a:do{if((b|0)==0){z=t;w=u;B=v;k=h;while(1){A=l+(B>>>3)|0;x=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(B&7);A=x>>>0>65535>>>0;I=A?x>>>16:x;J=A?16:0;if((I&65280|0)==0){K=J;L=I}else{K=J|8;L=I>>>8}I=(d[1191992+L|0]|0)+K|0;b:do{if((I|0)<7){do{if((x|0)>-1){J=c[s>>2]|0;A=B;G=0;do{if(!(J>>>0>A>>>0)){M=-1;break b}H=A+1|0;A=k>>>0>H>>>0?H:k;H=l+(A>>>3)|0;G=G+1|0;}while((G|0)!=2147483647&((fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(A&7)|0)>-1);J=A+1|0;H=k>>>0>J>>>0?J:k;if((G|0)<2147483646){N=G;O=H;break}if((G|0)!=2147483646){M=-1;break b}c[g>>2]=H;M=0;break b}else{H=B+1|0;N=0;O=k>>>0>H>>>0?H:k}}while(0);c[g>>2]=O;M=N}else{H=C+B-I|0;c[g>>2]=k>>>0>H>>>0?H:k;M=(x>>>(I>>>0))+(30-I)|0}}while(0);c[w>>2]=M>>1^-(M&1);I=z+1|0;if((I|0)>=(r|0)){break a}z=I;w=w+4|0;B=c[g>>2]|0;k=c[j>>2]|0}}else{k=t;B=u;w=v;z=h;while(1){I=l+(w>>>3)|0;x=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(w&7);I=x>>>0>65535>>>0;H=I?x>>>16:x;J=I?16:0;if((H&65280|0)==0){P=J;Q=H}else{P=J|8;Q=H>>>8}H=(d[1191992+Q|0]|0)+P|0;J=H-b|0;c:do{if((J|0)<7|(H|0)==-2147483615){do{if((x|0)>-1){I=c[s>>2]|0;F=w;R=0;do{if(!(I>>>0>F>>>0)){S=-1;break c}T=F+1|0;F=z>>>0>T>>>0?T:z;T=l+(F>>>3)|0;U=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(F&7);R=R+1|0;}while((R|0)!=2147483647&(U|0)>-1);I=F+1|0;G=z>>>0>I>>>0?I:z;if((R|0)<2147483646){V=R;W=U;X=G;break}if((R|0)!=2147483646){S=-1;break c}c[g>>2]=G;S=0;break c}else{G=w+1|0;V=0;W=x;X=z>>>0>G>>>0?G:z}}while(0);G=X+b|0;c[g>>2]=z>>>0>G>>>0?G:z;S=(W<<1>>>(D>>>0))+(V<<b)|0}else{G=C+w-H|0;c[g>>2]=z>>>0>G>>>0?G:z;S=(x>>>(J>>>0))+(30-H<<b)|0}}while(0);c[B>>2]=S>>1^-(S&1);H=k+1|0;if((H|0)>=(r|0)){break a}k=H;B=B+4|0;w=c[g>>2]|0;z=c[j>>2]|0}}}while(0);y=u+(r-t<<2)|0}}while(0);if((a|0)>=(n|0)){q=0;break}a=a+1|0;t=0;u=y;e=c[g>>2]|0;h=c[j>>2]|0}i=f;return q|0}function maa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+16|0;if((d|0)>16){c[e>>2]=86;c[a+20>>2]=120}else{c[e>>2]=288;c[a+20>>2]=82}if((b|0)==1){c[a>>2]=428;c[a+4>>2]=414;c[a+8>>2]=20;c[a+12>>2]=224;return}else if((b|0)==7){c[a>>2]=124;c[a+4>>2]=76;c[a+8>>2]=462;c[a+12>>2]=496;return}else if((b|0)==2){c[a>>2]=392;c[a+4>>2]=384;c[a+8>>2]=44;c[a+12>>2]=250;return}else if((b|0)==6){c[a>>2]=202;c[a+4>>2]=314;c[a+8>>2]=266;c[a+12>>2]=358;return}else{return}}function naa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d|0)>=(f|0)){return}g=e;if((d|0)>0){h=a;i=d}else{return}while(1){a=0;e=0;j=0;do{k=c[b+(a<<2)>>2]|0;l=c[h+(a<<2)>>2]|0;m=gHb(l,(l|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;j=YGb(m,F,j,e)|0;e=F;a=a+1|0;}while((a|0)<(d|0));a=aHb(j|0,e|0,g|0)|0;m=h+(d<<2)|0;k=YGb(c[m>>2]|0,0,a,F)|0;c[m>>2]=k;k=i+1|0;if((k|0)<(f|0)){h=h+4|0;i=k}else{break}}return}function oaa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0;if((e|0)>0){h=0;do{c[a+(h<<2)>>2]=c[b+(h<<2)>>2];h=h+1|0;}while((h|0)<(e|0))}switch(e|0){case 2:{if((d|0)<=2){return}h=f+4|0;i=g;j=2;do{k=c[b+(j-2<<2)>>2]|0;l=c[h>>2]|0;m=l;n=(l|0)<0|0?-1:0;l=gHb(m,n,k,(k|0)<0|0?-1:0)|0;k=F;o=c[b+(j-1<<2)>>2]|0;p=o;q=(o|0)<0|0?-1:0;o=gHb(p,q,m,n)|0;n=F;m=c[f>>2]|0;r=m;s=(m|0)<0|0?-1:0;m=gHb(r,s,p,q)|0;q=YGb(m,F,l,k)|0;k=F;l=c[b+(j<<2)>>2]|0;m=gHb(l,(l|0)<0|0?-1:0,r,s)|0;s=YGb(m,F,o,n)|0;n=F;o=aHb(q|0,k|0,i|0)|0;k=F;q=YGb(o,k,-2147483648,0)|0;m=F;r=0;if(m>>>0>r>>>0|m>>>0==r>>>0&q>>>0>-1>>>0){((k|0)<0|0?-1:0)>>31|((k|0)<0|0?-1:0)<<1;t=(k>>31|((k|0)<0|0?-1:0)<<1)^2147483647}else{t=o}c[a+(j<<2)>>2]=l-t;l=j|1;o=c[b+(l<<2)>>2]|0;k=aHb(s|0,n|0,i|0)|0;n=F;s=YGb(k,n,-2147483648,0)|0;q=F;r=0;if(q>>>0>r>>>0|q>>>0==r>>>0&s>>>0>-1>>>0){((n|0)<0|0?-1:0)>>31|((n|0)<0|0?-1:0)<<1;u=(n>>31|((n|0)<0|0?-1:0)<<1)^2147483647}else{u=k}c[a+(l<<2)>>2]=o-u;j=j+2|0;}while((j|0)<(d|0));return};case 7:{if((d|0)<=7){return}j=f+24|0;u=f+20|0;i=f+16|0;t=f+12|0;h=f+8|0;o=f+4|0;l=g;k=7;do{n=c[b+(k-7<<2)>>2]|0;s=c[j>>2]|0;r=s;q=(s|0)<0|0?-1:0;s=gHb(r,q,n,(n|0)<0|0?-1:0)|0;n=F;m=c[b+(k-6<<2)>>2]|0;p=m;v=(m|0)<0|0?-1:0;m=gHb(p,v,r,q)|0;q=F;r=c[u>>2]|0;w=r;x=(r|0)<0|0?-1:0;r=gHb(w,x,p,v)|0;v=YGb(r,F,s,n)|0;n=F;s=c[b+(k-5<<2)>>2]|0;r=s;p=(s|0)<0|0?-1:0;s=gHb(r,p,w,x)|0;x=YGb(s,F,m,q)|0;q=F;m=c[i>>2]|0;s=m;w=(m|0)<0|0?-1:0;m=gHb(s,w,r,p)|0;p=YGb(v,n,m,F)|0;m=F;n=c[b+(k-4<<2)>>2]|0;v=n;r=(n|0)<0|0?-1:0;n=gHb(v,r,s,w)|0;w=YGb(x,q,n,F)|0;n=F;q=c[t>>2]|0;x=q;s=(q|0)<0|0?-1:0;q=gHb(x,s,v,r)|0;r=YGb(p,m,q,F)|0;q=F;m=c[b+(k-3<<2)>>2]|0;p=m;v=(m|0)<0|0?-1:0;m=gHb(p,v,x,s)|0;s=YGb(w,n,m,F)|0;m=F;n=c[h>>2]|0;w=n;x=(n|0)<0|0?-1:0;n=gHb(w,x,p,v)|0;v=YGb(r,q,n,F)|0;n=F;q=c[b+(k-2<<2)>>2]|0;r=q;p=(q|0)<0|0?-1:0;q=gHb(r,p,w,x)|0;x=YGb(s,m,q,F)|0;q=F;m=c[o>>2]|0;s=m;w=(m|0)<0|0?-1:0;m=gHb(s,w,r,p)|0;p=YGb(v,n,m,F)|0;m=F;n=c[b+(k-1<<2)>>2]|0;v=n;r=(n|0)<0|0?-1:0;n=gHb(v,r,s,w)|0;w=YGb(x,q,n,F)|0;n=F;q=c[f>>2]|0;x=q;s=(q|0)<0|0?-1:0;q=gHb(x,s,v,r)|0;r=YGb(p,m,q,F)|0;q=F;m=c[b+(k<<2)>>2]|0;p=gHb(m,(m|0)<0|0?-1:0,x,s)|0;s=YGb(w,n,p,F)|0;p=F;n=aHb(r|0,q|0,l|0)|0;q=F;r=YGb(n,q,-2147483648,0)|0;w=F;x=0;if(w>>>0>x>>>0|w>>>0==x>>>0&r>>>0>-1>>>0){((q|0)<0|0?-1:0)>>31|((q|0)<0|0?-1:0)<<1;y=(q>>31|((q|0)<0|0?-1:0)<<1)^2147483647}else{y=n}c[a+(k<<2)>>2]=m-y;m=k+1|0;n=c[b+(m<<2)>>2]|0;q=aHb(s|0,p|0,l|0)|0;p=F;s=YGb(q,p,-2147483648,0)|0;r=F;x=0;if(r>>>0>x>>>0|r>>>0==x>>>0&s>>>0>-1>>>0){((p|0)<0|0?-1:0)>>31|((p|0)<0|0?-1:0)<<1;z=(p>>31|((p|0)<0|0?-1:0)<<1)^2147483647}else{z=q}c[a+(m<<2)>>2]=n-z;k=k+2|0;}while((k|0)<(d|0));return};case 4:{if((d|0)<=4){return}k=f+12|0;z=f+8|0;l=f+4|0;y=g;o=4;do{h=c[b+(o-4<<2)>>2]|0;t=c[k>>2]|0;i=t;u=(t|0)<0|0?-1:0;t=gHb(i,u,h,(h|0)<0|0?-1:0)|0;h=F;j=c[b+(o-3<<2)>>2]|0;n=j;m=(j|0)<0|0?-1:0;j=gHb(n,m,i,u)|0;u=F;i=c[z>>2]|0;q=i;p=(i|0)<0|0?-1:0;i=gHb(q,p,n,m)|0;m=YGb(i,F,t,h)|0;h=F;t=c[b+(o-2<<2)>>2]|0;i=t;n=(t|0)<0|0?-1:0;t=gHb(i,n,q,p)|0;p=YGb(t,F,j,u)|0;u=F;j=c[l>>2]|0;t=j;q=(j|0)<0|0?-1:0;j=gHb(t,q,i,n)|0;n=YGb(m,h,j,F)|0;j=F;h=c[b+(o-1<<2)>>2]|0;m=h;i=(h|0)<0|0?-1:0;h=gHb(m,i,t,q)|0;q=YGb(p,u,h,F)|0;h=F;u=c[f>>2]|0;p=u;t=(u|0)<0|0?-1:0;u=gHb(p,t,m,i)|0;i=YGb(n,j,u,F)|0;u=F;j=c[b+(o<<2)>>2]|0;n=gHb(j,(j|0)<0|0?-1:0,p,t)|0;t=YGb(q,h,n,F)|0;n=F;h=aHb(i|0,u|0,y|0)|0;u=F;i=YGb(h,u,-2147483648,0)|0;q=F;p=0;if(q>>>0>p>>>0|q>>>0==p>>>0&i>>>0>-1>>>0){((u|0)<0|0?-1:0)>>31|((u|0)<0|0?-1:0)<<1;A=(u>>31|((u|0)<0|0?-1:0)<<1)^2147483647}else{A=h}c[a+(o<<2)>>2]=j-A;j=o|1;h=c[b+(j<<2)>>2]|0;u=aHb(t|0,n|0,y|0)|0;n=F;t=YGb(u,n,-2147483648,0)|0;i=F;p=0;if(i>>>0>p>>>0|i>>>0==p>>>0&t>>>0>-1>>>0){((n|0)<0|0?-1:0)>>31|((n|0)<0|0?-1:0)<<1;B=(n>>31|((n|0)<0|0?-1:0)<<1)^2147483647}else{B=u}c[a+(j<<2)>>2]=h-B;o=o+2|0;}while((o|0)<(d|0));return};case 6:{if((d|0)<=6){return}o=f+20|0;B=f+16|0;y=f+12|0;A=f+8|0;l=f+4|0;z=g;k=6;do{h=c[b+(k-6<<2)>>2]|0;j=c[o>>2]|0;u=j;n=(j|0)<0|0?-1:0;j=gHb(u,n,h,(h|0)<0|0?-1:0)|0;h=F;t=c[b+(k-5<<2)>>2]|0;p=t;i=(t|0)<0|0?-1:0;t=gHb(p,i,u,n)|0;n=F;u=c[B>>2]|0;q=u;m=(u|0)<0|0?-1:0;u=gHb(q,m,p,i)|0;i=YGb(u,F,j,h)|0;h=F;j=c[b+(k-4<<2)>>2]|0;u=j;p=(j|0)<0|0?-1:0;j=gHb(u,p,q,m)|0;m=YGb(j,F,t,n)|0;n=F;t=c[y>>2]|0;j=t;q=(t|0)<0|0?-1:0;t=gHb(j,q,u,p)|0;p=YGb(i,h,t,F)|0;t=F;h=c[b+(k-3<<2)>>2]|0;i=h;u=(h|0)<0|0?-1:0;h=gHb(i,u,j,q)|0;q=YGb(m,n,h,F)|0;h=F;n=c[A>>2]|0;m=n;j=(n|0)<0|0?-1:0;n=gHb(m,j,i,u)|0;u=YGb(p,t,n,F)|0;n=F;t=c[b+(k-2<<2)>>2]|0;p=t;i=(t|0)<0|0?-1:0;t=gHb(p,i,m,j)|0;j=YGb(q,h,t,F)|0;t=F;h=c[l>>2]|0;q=h;m=(h|0)<0|0?-1:0;h=gHb(q,m,p,i)|0;i=YGb(u,n,h,F)|0;h=F;n=c[b+(k-1<<2)>>2]|0;u=n;p=(n|0)<0|0?-1:0;n=gHb(u,p,q,m)|0;m=YGb(j,t,n,F)|0;n=F;t=c[f>>2]|0;j=t;q=(t|0)<0|0?-1:0;t=gHb(j,q,u,p)|0;p=YGb(i,h,t,F)|0;t=F;h=c[b+(k<<2)>>2]|0;i=gHb(h,(h|0)<0|0?-1:0,j,q)|0;q=YGb(m,n,i,F)|0;i=F;n=aHb(p|0,t|0,z|0)|0;t=F;p=YGb(n,t,-2147483648,0)|0;m=F;j=0;if(m>>>0>j>>>0|m>>>0==j>>>0&p>>>0>-1>>>0){((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1;C=(t>>31|((t|0)<0|0?-1:0)<<1)^2147483647}else{C=n}c[a+(k<<2)>>2]=h-C;h=k|1;n=c[b+(h<<2)>>2]|0;t=aHb(q|0,i|0,z|0)|0;i=F;q=YGb(t,i,-2147483648,0)|0;p=F;j=0;if(p>>>0>j>>>0|p>>>0==j>>>0&q>>>0>-1>>>0){((i|0)<0|0?-1:0)>>31|((i|0)<0|0?-1:0)<<1;D=(i>>31|((i|0)<0|0?-1:0)<<1)^2147483647}else{D=t}c[a+(h<<2)>>2]=n-D;k=k+2|0;}while((k|0)<(d|0));return};case 8:{if((d|0)<=8){return}k=f+28|0;D=f+24|0;z=f+20|0;C=f+16|0;l=f+12|0;A=f+8|0;y=f+4|0;B=g;o=8;do{n=c[b+(o-8<<2)>>2]|0;h=c[k>>2]|0;t=h;i=(h|0)<0|0?-1:0;h=gHb(t,i,n,(n|0)<0|0?-1:0)|0;n=F;q=c[b+(o-7<<2)>>2]|0;j=q;p=(q|0)<0|0?-1:0;q=gHb(j,p,t,i)|0;i=F;t=c[D>>2]|0;m=t;u=(t|0)<0|0?-1:0;t=gHb(m,u,j,p)|0;p=YGb(t,F,h,n)|0;n=F;h=c[b+(o-6<<2)>>2]|0;t=h;j=(h|0)<0|0?-1:0;h=gHb(t,j,m,u)|0;u=YGb(h,F,q,i)|0;i=F;q=c[z>>2]|0;h=q;m=(q|0)<0|0?-1:0;q=gHb(h,m,t,j)|0;j=YGb(p,n,q,F)|0;q=F;n=c[b+(o-5<<2)>>2]|0;p=n;t=(n|0)<0|0?-1:0;n=gHb(p,t,h,m)|0;m=YGb(u,i,n,F)|0;n=F;i=c[C>>2]|0;u=i;h=(i|0)<0|0?-1:0;i=gHb(u,h,p,t)|0;t=YGb(j,q,i,F)|0;i=F;q=c[b+(o-4<<2)>>2]|0;j=q;p=(q|0)<0|0?-1:0;q=gHb(j,p,u,h)|0;h=YGb(m,n,q,F)|0;q=F;n=c[l>>2]|0;m=n;u=(n|0)<0|0?-1:0;n=gHb(m,u,j,p)|0;p=YGb(t,i,n,F)|0;n=F;i=c[b+(o-3<<2)>>2]|0;t=i;j=(i|0)<0|0?-1:0;i=gHb(t,j,m,u)|0;u=YGb(h,q,i,F)|0;i=F;q=c[A>>2]|0;h=q;m=(q|0)<0|0?-1:0;q=gHb(h,m,t,j)|0;j=YGb(p,n,q,F)|0;q=F;n=c[b+(o-2<<2)>>2]|0;p=n;t=(n|0)<0|0?-1:0;n=gHb(p,t,h,m)|0;m=YGb(u,i,n,F)|0;n=F;i=c[y>>2]|0;u=i;h=(i|0)<0|0?-1:0;i=gHb(u,h,p,t)|0;t=YGb(j,q,i,F)|0;i=F;q=c[b+(o-1<<2)>>2]|0;j=q;p=(q|0)<0|0?-1:0;q=gHb(j,p,u,h)|0;h=YGb(m,n,q,F)|0;q=F;n=c[f>>2]|0;m=n;u=(n|0)<0|0?-1:0;n=gHb(m,u,j,p)|0;p=YGb(t,i,n,F)|0;n=F;i=c[b+(o<<2)>>2]|0;t=gHb(i,(i|0)<0|0?-1:0,m,u)|0;u=YGb(h,q,t,F)|0;t=F;q=aHb(p|0,n|0,B|0)|0;n=F;p=YGb(q,n,-2147483648,0)|0;h=F;m=0;if(h>>>0>m>>>0|h>>>0==m>>>0&p>>>0>-1>>>0){((n|0)<0|0?-1:0)>>31|((n|0)<0|0?-1:0)<<1;E=(n>>31|((n|0)<0|0?-1:0)<<1)^2147483647}else{E=q}c[a+(o<<2)>>2]=i-E;i=o|1;q=c[b+(i<<2)>>2]|0;n=aHb(u|0,t|0,B|0)|0;t=F;u=YGb(n,t,-2147483648,0)|0;p=F;m=0;if(p>>>0>m>>>0|p>>>0==m>>>0&u>>>0>-1>>>0){((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1;G=(t>>31|((t|0)<0|0?-1:0)<<1)^2147483647}else{G=n}c[a+(i<<2)>>2]=q-G;o=o+2|0;}while((o|0)<(d|0));return};case 3:{if((d|0)<=3){return}o=f+8|0;G=f+4|0;B=g;E=3;do{y=c[b+(E-3<<2)>>2]|0;A=c[o>>2]|0;l=A;C=(A|0)<0|0?-1:0;A=gHb(l,C,y,(y|0)<0|0?-1:0)|0;y=F;z=c[b+(E-2<<2)>>2]|0;D=z;k=(z|0)<0|0?-1:0;z=gHb(D,k,l,C)|0;C=F;l=c[G>>2]|0;q=l;i=(l|0)<0|0?-1:0;l=gHb(q,i,D,k)|0;k=YGb(l,F,A,y)|0;y=F;A=c[b+(E-1<<2)>>2]|0;l=A;D=(A|0)<0|0?-1:0;A=gHb(l,D,q,i)|0;i=YGb(A,F,z,C)|0;C=F;z=c[f>>2]|0;A=z;q=(z|0)<0|0?-1:0;z=gHb(A,q,l,D)|0;D=YGb(k,y,z,F)|0;z=F;y=c[b+(E<<2)>>2]|0;k=gHb(y,(y|0)<0|0?-1:0,A,q)|0;q=YGb(i,C,k,F)|0;k=F;C=aHb(D|0,z|0,B|0)|0;z=F;D=YGb(C,z,-2147483648,0)|0;i=F;A=0;if(i>>>0>A>>>0|i>>>0==A>>>0&D>>>0>-1>>>0){((z|0)<0|0?-1:0)>>31|((z|0)<0|0?-1:0)<<1;H=(z>>31|((z|0)<0|0?-1:0)<<1)^2147483647}else{H=C}c[a+(E<<2)>>2]=y-H;y=E+1|0;C=c[b+(y<<2)>>2]|0;z=aHb(q|0,k|0,B|0)|0;k=F;q=YGb(z,k,-2147483648,0)|0;D=F;A=0;if(D>>>0>A>>>0|D>>>0==A>>>0&q>>>0>-1>>>0){((k|0)<0|0?-1:0)>>31|((k|0)<0|0?-1:0)<<1;I=(k>>31|((k|0)<0|0?-1:0)<<1)^2147483647}else{I=z}c[a+(y<<2)>>2]=C-I;E=E+2|0;}while((E|0)<(d|0));return};case 5:{if((d|0)<=5){return}E=f+16|0;I=f+12|0;B=f+8|0;H=f+4|0;G=g;o=5;do{C=c[b+(o-5<<2)>>2]|0;y=c[E>>2]|0;z=y;k=(y|0)<0|0?-1:0;y=gHb(z,k,C,(C|0)<0|0?-1:0)|0;C=F;q=c[b+(o-4<<2)>>2]|0;A=q;D=(q|0)<0|0?-1:0;q=gHb(A,D,z,k)|0;k=F;z=c[I>>2]|0;i=z;l=(z|0)<0|0?-1:0;z=gHb(i,l,A,D)|0;D=YGb(z,F,y,C)|0;C=F;y=c[b+(o-3<<2)>>2]|0;z=y;A=(y|0)<0|0?-1:0;y=gHb(z,A,i,l)|0;l=YGb(y,F,q,k)|0;k=F;q=c[B>>2]|0;y=q;i=(q|0)<0|0?-1:0;q=gHb(y,i,z,A)|0;A=YGb(D,C,q,F)|0;q=F;C=c[b+(o-2<<2)>>2]|0;D=C;z=(C|0)<0|0?-1:0;C=gHb(D,z,y,i)|0;i=YGb(l,k,C,F)|0;C=F;k=c[H>>2]|0;l=k;y=(k|0)<0|0?-1:0;k=gHb(l,y,D,z)|0;z=YGb(A,q,k,F)|0;k=F;q=c[b+(o-1<<2)>>2]|0;A=q;D=(q|0)<0|0?-1:0;q=gHb(A,D,l,y)|0;y=YGb(i,C,q,F)|0;q=F;C=c[f>>2]|0;i=C;l=(C|0)<0|0?-1:0;C=gHb(i,l,A,D)|0;D=YGb(z,k,C,F)|0;C=F;k=c[b+(o<<2)>>2]|0;z=gHb(k,(k|0)<0|0?-1:0,i,l)|0;l=YGb(y,q,z,F)|0;z=F;q=aHb(D|0,C|0,G|0)|0;C=F;D=YGb(q,C,-2147483648,0)|0;y=F;i=0;if(y>>>0>i>>>0|y>>>0==i>>>0&D>>>0>-1>>>0){((C|0)<0|0?-1:0)>>31|((C|0)<0|0?-1:0)<<1;J=(C>>31|((C|0)<0|0?-1:0)<<1)^2147483647}else{J=q}c[a+(o<<2)>>2]=k-J;k=o+1|0;q=c[b+(k<<2)>>2]|0;C=aHb(l|0,z|0,G|0)|0;z=F;l=YGb(C,z,-2147483648,0)|0;D=F;i=0;if(D>>>0>i>>>0|D>>>0==i>>>0&l>>>0>-1>>>0){((z|0)<0|0?-1:0)>>31|((z|0)<0|0?-1:0)<<1;K=(z>>31|((z|0)<0|0?-1:0)<<1)^2147483647}else{K=C}c[a+(k<<2)>>2]=q-K;o=o+2|0;}while((o|0)<(d|0));return};case 1:{if((d|0)<=1){return}o=g;K=1;do{G=c[b+(K-1<<2)>>2]|0;J=c[f>>2]|0;H=J;B=(J|0)<0|0?-1:0;J=gHb(H,B,G,(G|0)<0|0?-1:0)|0;G=F;I=c[b+(K<<2)>>2]|0;E=gHb(I,(I|0)<0|0?-1:0,H,B)|0;B=F;H=aHb(J|0,G|0,o|0)|0;G=F;J=YGb(H,G,-2147483648,0)|0;q=F;k=0;if(q>>>0>k>>>0|q>>>0==k>>>0&J>>>0>-1>>>0){((G|0)<0|0?-1:0)>>31|((G|0)<0|0?-1:0)<<1;L=(G>>31|((G|0)<0|0?-1:0)<<1)^2147483647}else{L=H}c[a+(K<<2)>>2]=I-L;I=K+1|0;H=c[b+(I<<2)>>2]|0;G=aHb(E|0,B|0,o|0)|0;B=F;E=YGb(G,B,-2147483648,0)|0;J=F;k=0;if(J>>>0>k>>>0|J>>>0==k>>>0&E>>>0>-1>>>0){((B|0)<0|0?-1:0)>>31|((B|0)<0|0?-1:0)<<1;M=(B>>31|((B|0)<0|0?-1:0)<<1)^2147483647}else{M=G}c[a+(I<<2)>>2]=H-M;K=K+2|0;}while((K|0)<(d|0));return};default:{if((e|0)>=(d|0)){return}K=f+28|0;M=f+24|0;o=f+20|0;L=f+16|0;H=f+12|0;I=f+8|0;G=f+4|0;B=g;g=f+124|0;E=f+120|0;k=f+116|0;J=f+112|0;q=f+108|0;C=f+104|0;z=f+100|0;l=f+96|0;i=f+92|0;D=f+88|0;y=f+84|0;A=f+80|0;n=f+76|0;t=f+72|0;u=f+68|0;m=f+64|0;p=f+60|0;h=f+56|0;j=f+52|0;s=f+48|0;x=f+44|0;r=f+40|0;w=f+36|0;v=f+32|0;N=e;do{O=c[b+(N-e<<2)>>2]|0;switch(e|0){case 20:{P=O;Q=0;R=0;S=0;T=0;U=76;break};case 32:{V=c[g>>2]|0;W=V;X=(V|0)<0|0?-1:0;V=gHb(W,X,O,(O|0)<0|0?-1:0)|0;Y=F;Z=c[b+(N-31<<2)>>2]|0;_=gHb(Z,(Z|0)<0|0?-1:0,W,X)|0;$=Z;aa=Y;ba=V;ca=F;da=_;U=65;break};case 31:{$=O;aa=0;ba=0;ca=0;da=0;U=65;break};case 30:{ea=O;fa=0;ga=0;ha=0;ia=0;U=66;break};case 11:{ja=O;ka=0;la=0;ma=0;na=0;U=85;break};case 10:{oa=O;pa=0;qa=0;ra=0;sa=0;U=86;break};case 9:{ta=O;ua=0;va=0;wa=0;xa=0;U=87;break};case 19:{ya=O;za=0;Aa=0;Ba=0;Ca=0;U=77;break};case 18:{Da=O;Ea=0;Fa=0;Ga=0;Ha=0;U=78;break};case 17:{Ia=O;Ja=0;Ka=0;La=0;Ma=0;U=79;break};case 26:{Na=O;Oa=0;Pa=0;Qa=0;Ra=0;U=70;break};case 25:{Sa=O;Ta=0;Ua=0;Va=0;Wa=0;U=71;break};case 24:{Xa=O;Ya=0;Za=0;_a=0;$a=0;U=72;break};case 15:{ab=O;bb=0;cb=0;db=0;eb=0;U=81;break};case 14:{fb=O;gb=0;hb=0;ib=0;jb=0;U=82;break};case 13:{kb=O;lb=0;mb=0;nb=0;ob=0;U=83;break};case 12:{pb=O;qb=0;rb=0;sb=0;tb=0;U=84;break};case 29:{ub=O;vb=0;wb=0;xb=0;yb=0;U=67;break};case 28:{zb=O;Ab=0;Bb=0;Cb=0;Db=0;U=68;break};case 27:{Eb=O;Fb=0;Gb=0;Hb=0;Ib=0;U=69;break};case 23:{Jb=O;Kb=0;Lb=0;Mb=0;Nb=0;U=73;break};case 22:{Ob=O;Pb=0;Qb=0;Rb=0;Sb=0;U=74;break};case 21:{Tb=O;Ub=0;Vb=0;Wb=0;Xb=0;U=75;break};case 16:{Yb=O;Zb=0;_b=0;$b=0;ac=0;U=80;break};default:{bc=0;cc=0;dc=0;ec=0;fc=c[b+(N<<2)>>2]|0}}if((U|0)==65){U=0;O=c[E>>2]|0;_=O;V=(O|0)<0|0?-1:0;O=gHb(_,V,$,($|0)<0|0?-1:0)|0;Y=YGb(O,F,ba,aa)|0;O=F;Z=c[b+(N-30<<2)>>2]|0;X=gHb(Z,(Z|0)<0|0?-1:0,_,V)|0;V=YGb(X,F,da,ca)|0;ea=Z;fa=O;ga=Y;ha=F;ia=V;U=66}if((U|0)==66){U=0;V=c[k>>2]|0;Y=V;O=(V|0)<0|0?-1:0;V=gHb(Y,O,ea,(ea|0)<0|0?-1:0)|0;Z=YGb(V,F,ga,fa)|0;V=F;X=c[b+(N-29<<2)>>2]|0;_=gHb(X,(X|0)<0|0?-1:0,Y,O)|0;O=YGb(_,F,ia,ha)|0;ub=X;vb=V;wb=Z;xb=F;yb=O;U=67}if((U|0)==67){U=0;O=c[J>>2]|0;Z=O;V=(O|0)<0|0?-1:0;O=gHb(Z,V,ub,(ub|0)<0|0?-1:0)|0;X=YGb(O,F,wb,vb)|0;O=F;_=c[b+(N-28<<2)>>2]|0;Y=gHb(_,(_|0)<0|0?-1:0,Z,V)|0;V=YGb(Y,F,yb,xb)|0;zb=_;Ab=O;Bb=X;Cb=F;Db=V;U=68}if((U|0)==68){U=0;V=c[q>>2]|0;X=V;O=(V|0)<0|0?-1:0;V=gHb(X,O,zb,(zb|0)<0|0?-1:0)|0;_=YGb(V,F,Bb,Ab)|0;V=F;Y=c[b+(N-27<<2)>>2]|0;Z=gHb(Y,(Y|0)<0|0?-1:0,X,O)|0;O=YGb(Z,F,Db,Cb)|0;Eb=Y;Fb=V;Gb=_;Hb=F;Ib=O;U=69}if((U|0)==69){U=0;O=c[C>>2]|0;_=O;V=(O|0)<0|0?-1:0;O=gHb(_,V,Eb,(Eb|0)<0|0?-1:0)|0;Y=YGb(O,F,Gb,Fb)|0;O=F;Z=c[b+(N-26<<2)>>2]|0;X=gHb(Z,(Z|0)<0|0?-1:0,_,V)|0;V=YGb(X,F,Ib,Hb)|0;Na=Z;Oa=O;Pa=Y;Qa=F;Ra=V;U=70}if((U|0)==70){U=0;V=c[z>>2]|0;Y=V;O=(V|0)<0|0?-1:0;V=gHb(Y,O,Na,(Na|0)<0|0?-1:0)|0;Z=YGb(V,F,Pa,Oa)|0;V=F;X=c[b+(N-25<<2)>>2]|0;_=gHb(X,(X|0)<0|0?-1:0,Y,O)|0;O=YGb(_,F,Ra,Qa)|0;Sa=X;Ta=V;Ua=Z;Va=F;Wa=O;U=71}if((U|0)==71){U=0;O=c[l>>2]|0;Z=O;V=(O|0)<0|0?-1:0;O=gHb(Z,V,Sa,(Sa|0)<0|0?-1:0)|0;X=YGb(O,F,Ua,Ta)|0;O=F;_=c[b+(N-24<<2)>>2]|0;Y=gHb(_,(_|0)<0|0?-1:0,Z,V)|0;V=YGb(Y,F,Wa,Va)|0;Xa=_;Ya=O;Za=X;_a=F;$a=V;U=72}if((U|0)==72){U=0;V=c[i>>2]|0;X=V;O=(V|0)<0|0?-1:0;V=gHb(X,O,Xa,(Xa|0)<0|0?-1:0)|0;_=YGb(V,F,Za,Ya)|0;V=F;Y=c[b+(N-23<<2)>>2]|0;Z=gHb(Y,(Y|0)<0|0?-1:0,X,O)|0;O=YGb(Z,F,$a,_a)|0;Jb=Y;Kb=V;Lb=_;Mb=F;Nb=O;U=73}if((U|0)==73){U=0;O=c[D>>2]|0;_=O;V=(O|0)<0|0?-1:0;O=gHb(_,V,Jb,(Jb|0)<0|0?-1:0)|0;Y=YGb(O,F,Lb,Kb)|0;O=F;Z=c[b+(N-22<<2)>>2]|0;X=gHb(Z,(Z|0)<0|0?-1:0,_,V)|0;V=YGb(X,F,Nb,Mb)|0;Ob=Z;Pb=O;Qb=Y;Rb=F;Sb=V;U=74}if((U|0)==74){U=0;V=c[y>>2]|0;Y=V;O=(V|0)<0|0?-1:0;V=gHb(Y,O,Ob,(Ob|0)<0|0?-1:0)|0;Z=YGb(V,F,Qb,Pb)|0;V=F;X=c[b+(N-21<<2)>>2]|0;_=gHb(X,(X|0)<0|0?-1:0,Y,O)|0;O=YGb(_,F,Sb,Rb)|0;Tb=X;Ub=V;Vb=Z;Wb=F;Xb=O;U=75}if((U|0)==75){U=0;O=c[A>>2]|0;Z=O;V=(O|0)<0|0?-1:0;O=gHb(Z,V,Tb,(Tb|0)<0|0?-1:0)|0;X=YGb(O,F,Vb,Ub)|0;O=F;_=c[b+(N-20<<2)>>2]|0;Y=gHb(_,(_|0)<0|0?-1:0,Z,V)|0;V=YGb(Y,F,Xb,Wb)|0;P=_;Q=O;R=X;S=F;T=V;U=76}if((U|0)==76){U=0;V=c[n>>2]|0;X=V;O=(V|0)<0|0?-1:0;V=gHb(X,O,P,(P|0)<0|0?-1:0)|0;_=YGb(V,F,R,Q)|0;V=F;Y=c[b+(N-19<<2)>>2]|0;Z=gHb(Y,(Y|0)<0|0?-1:0,X,O)|0;O=YGb(Z,F,T,S)|0;ya=Y;za=V;Aa=_;Ba=F;Ca=O;U=77}if((U|0)==77){U=0;O=c[t>>2]|0;_=O;V=(O|0)<0|0?-1:0;O=gHb(_,V,ya,(ya|0)<0|0?-1:0)|0;Y=YGb(O,F,Aa,za)|0;O=F;Z=c[b+(N-18<<2)>>2]|0;X=gHb(Z,(Z|0)<0|0?-1:0,_,V)|0;V=YGb(X,F,Ca,Ba)|0;Da=Z;Ea=O;Fa=Y;Ga=F;Ha=V;U=78}if((U|0)==78){U=0;V=c[u>>2]|0;Y=V;O=(V|0)<0|0?-1:0;V=gHb(Y,O,Da,(Da|0)<0|0?-1:0)|0;Z=YGb(V,F,Fa,Ea)|0;V=F;X=c[b+(N-17<<2)>>2]|0;_=gHb(X,(X|0)<0|0?-1:0,Y,O)|0;O=YGb(_,F,Ha,Ga)|0;Ia=X;Ja=V;Ka=Z;La=F;Ma=O;U=79}if((U|0)==79){U=0;O=c[m>>2]|0;Z=O;V=(O|0)<0|0?-1:0;O=gHb(Z,V,Ia,(Ia|0)<0|0?-1:0)|0;X=YGb(O,F,Ka,Ja)|0;O=F;_=c[b+(N-16<<2)>>2]|0;Y=gHb(_,(_|0)<0|0?-1:0,Z,V)|0;V=YGb(Y,F,Ma,La)|0;Yb=_;Zb=O;_b=X;$b=F;ac=V;U=80}if((U|0)==80){U=0;V=c[p>>2]|0;X=V;O=(V|0)<0|0?-1:0;V=gHb(X,O,Yb,(Yb|0)<0|0?-1:0)|0;_=YGb(V,F,_b,Zb)|0;V=F;Y=c[b+(N-15<<2)>>2]|0;Z=gHb(Y,(Y|0)<0|0?-1:0,X,O)|0;O=YGb(Z,F,ac,$b)|0;ab=Y;bb=V;cb=_;db=F;eb=O;U=81}if((U|0)==81){U=0;O=c[h>>2]|0;_=O;V=(O|0)<0|0?-1:0;O=gHb(_,V,ab,(ab|0)<0|0?-1:0)|0;Y=YGb(O,F,cb,bb)|0;O=F;Z=c[b+(N-14<<2)>>2]|0;X=gHb(Z,(Z|0)<0|0?-1:0,_,V)|0;V=YGb(X,F,eb,db)|0;fb=Z;gb=O;hb=Y;ib=F;jb=V;U=82}if((U|0)==82){U=0;V=c[j>>2]|0;Y=V;O=(V|0)<0|0?-1:0;V=gHb(Y,O,fb,(fb|0)<0|0?-1:0)|0;Z=YGb(V,F,hb,gb)|0;V=F;X=c[b+(N-13<<2)>>2]|0;_=gHb(X,(X|0)<0|0?-1:0,Y,O)|0;O=YGb(_,F,jb,ib)|0;kb=X;lb=V;mb=Z;nb=F;ob=O;U=83}if((U|0)==83){U=0;O=c[s>>2]|0;Z=O;V=(O|0)<0|0?-1:0;O=gHb(Z,V,kb,(kb|0)<0|0?-1:0)|0;X=YGb(O,F,mb,lb)|0;O=F;_=c[b+(N-12<<2)>>2]|0;Y=gHb(_,(_|0)<0|0?-1:0,Z,V)|0;V=YGb(Y,F,ob,nb)|0;pb=_;qb=O;rb=X;sb=F;tb=V;U=84}if((U|0)==84){U=0;V=c[x>>2]|0;X=V;O=(V|0)<0|0?-1:0;V=gHb(X,O,pb,(pb|0)<0|0?-1:0)|0;_=YGb(V,F,rb,qb)|0;V=F;Y=c[b+(N-11<<2)>>2]|0;Z=gHb(Y,(Y|0)<0|0?-1:0,X,O)|0;O=YGb(Z,F,tb,sb)|0;ja=Y;ka=V;la=_;ma=F;na=O;U=85}if((U|0)==85){U=0;O=c[r>>2]|0;_=O;V=(O|0)<0|0?-1:0;O=gHb(_,V,ja,(ja|0)<0|0?-1:0)|0;Y=YGb(O,F,la,ka)|0;O=F;Z=c[b+(N-10<<2)>>2]|0;X=gHb(Z,(Z|0)<0|0?-1:0,_,V)|0;V=YGb(X,F,na,ma)|0;oa=Z;pa=O;qa=Y;ra=F;sa=V;U=86}if((U|0)==86){U=0;V=c[w>>2]|0;Y=V;O=(V|0)<0|0?-1:0;V=gHb(Y,O,oa,(oa|0)<0|0?-1:0)|0;Z=YGb(V,F,qa,pa)|0;V=F;X=c[b+(N-9<<2)>>2]|0;_=gHb(X,(X|0)<0|0?-1:0,Y,O)|0;O=YGb(_,F,sa,ra)|0;ta=X;ua=V;va=Z;wa=F;xa=O;U=87}if((U|0)==87){U=0;O=c[v>>2]|0;Z=O;V=(O|0)<0|0?-1:0;O=gHb(Z,V,ta,(ta|0)<0|0?-1:0)|0;X=YGb(O,F,va,ua)|0;O=F;_=c[b+(N-8<<2)>>2]|0;Y=_;W=(_|0)<0|0?-1:0;_=gHb(Y,W,Z,V)|0;V=YGb(_,F,xa,wa)|0;_=F;Z=c[K>>2]|0;gc=Z;hc=(Z|0)<0|0?-1:0;Z=gHb(gc,hc,Y,W)|0;W=YGb(X,O,Z,F)|0;Z=F;O=c[b+(N-7<<2)>>2]|0;X=O;Y=(O|0)<0|0?-1:0;O=gHb(X,Y,gc,hc)|0;hc=YGb(V,_,O,F)|0;O=F;_=c[M>>2]|0;V=_;gc=(_|0)<0|0?-1:0;_=gHb(V,gc,X,Y)|0;Y=YGb(W,Z,_,F)|0;_=F;Z=c[b+(N-6<<2)>>2]|0;W=Z;X=(Z|0)<0|0?-1:0;Z=gHb(W,X,V,gc)|0;gc=YGb(hc,O,Z,F)|0;Z=F;O=c[o>>2]|0;hc=O;V=(O|0)<0|0?-1:0;O=gHb(hc,V,W,X)|0;X=YGb(Y,_,O,F)|0;O=F;_=c[b+(N-5<<2)>>2]|0;Y=_;W=(_|0)<0|0?-1:0;_=gHb(Y,W,hc,V)|0;V=YGb(gc,Z,_,F)|0;_=F;Z=c[L>>2]|0;gc=Z;hc=(Z|0)<0|0?-1:0;Z=gHb(gc,hc,Y,W)|0;W=YGb(X,O,Z,F)|0;Z=F;O=c[b+(N-4<<2)>>2]|0;X=O;Y=(O|0)<0|0?-1:0;O=gHb(X,Y,gc,hc)|0;hc=YGb(V,_,O,F)|0;O=F;_=c[H>>2]|0;V=_;gc=(_|0)<0|0?-1:0;_=gHb(V,gc,X,Y)|0;Y=YGb(W,Z,_,F)|0;_=F;Z=c[b+(N-3<<2)>>2]|0;W=Z;X=(Z|0)<0|0?-1:0;Z=gHb(W,X,V,gc)|0;gc=YGb(hc,O,Z,F)|0;Z=F;O=c[I>>2]|0;hc=O;V=(O|0)<0|0?-1:0;O=gHb(hc,V,W,X)|0;X=YGb(Y,_,O,F)|0;O=F;_=c[b+(N-2<<2)>>2]|0;Y=_;W=(_|0)<0|0?-1:0;_=gHb(Y,W,hc,V)|0;V=YGb(gc,Z,_,F)|0;_=F;Z=c[G>>2]|0;gc=Z;hc=(Z|0)<0|0?-1:0;Z=gHb(gc,hc,Y,W)|0;W=YGb(X,O,Z,F)|0;Z=F;O=c[b+(N-1<<2)>>2]|0;X=O;Y=(O|0)<0|0?-1:0;O=gHb(X,Y,gc,hc)|0;hc=YGb(V,_,O,F)|0;O=F;_=c[f>>2]|0;V=_;gc=(_|0)<0|0?-1:0;_=gHb(V,gc,X,Y)|0;Y=YGb(W,Z,_,F)|0;_=F;Z=c[b+(N<<2)>>2]|0;W=gHb(Z,(Z|0)<0|0?-1:0,V,gc)|0;gc=YGb(hc,O,W,F)|0;bc=_;cc=Y;dc=F;ec=gc;fc=Z}Z=aHb(cc|0,bc|0,B|0)|0;gc=F;Y=YGb(Z,gc,-2147483648,0)|0;_=F;W=0;if(_>>>0>W>>>0|_>>>0==W>>>0&Y>>>0>-1>>>0){((gc|0)<0|0?-1:0)>>31|((gc|0)<0|0?-1:0)<<1;ic=(gc>>31|((gc|0)<0|0?-1:0)<<1)^2147483647}else{ic=Z}c[a+(N<<2)>>2]=fc-ic;Z=N+1|0;gc=c[b+(Z<<2)>>2]|0;Y=aHb(ec|0,dc|0,B|0)|0;W=F;_=YGb(Y,W,-2147483648,0)|0;O=F;hc=0;if(O>>>0>hc>>>0|O>>>0==hc>>>0&_>>>0>-1>>>0){((W|0)<0|0?-1:0)>>31|((W|0)<0|0?-1:0)<<1;jc=(W>>31|((W|0)<0|0?-1:0)<<1)^2147483647}else{jc=Y}c[a+(Z<<2)>>2]=gc-jc;N=N+2|0;}while((N|0)<(d|0));return}}}function paa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=f-1|0;a:do{if((g|0)>(d|0)){if((d|0)>1){h=a;i=d}else{j=a;k=d;l=c[a>>2]|0;while(1){m=c[b>>2]|0;n=(ba(m,l)|0)>>e;o=j+4|0;p=(c[o>>2]|0)+n|0;c[o>>2]=p;o=(ba(p,m)|0)>>e;m=j+8|0;p=o+(c[m>>2]|0)|0;c[m>>2]=p;o=k+2|0;if((o|0)<(g|0)){j=m;k=o;l=p}else{q=m;r=o;break a}}}while(1){l=c[b>>2]|0;k=1;j=0;o=l;m=ba(l,c[h>>2]|0)|0;while(1){l=c[h+(k<<2)>>2]|0;s=(ba(l,o)|0)+j|0;p=k+1|0;t=c[b+(k<<2)>>2]|0;u=(ba(t,l)|0)+m|0;if((p|0)<(d|0)){k=p;j=s;o=t;m=u}else{break}}m=h+(d<<2)|0;o=(c[m>>2]|0)+(u>>e)|0;c[m>>2]=o;m=(ba(o,t)|0)+s>>e;o=h+(d+1<<2)|0;c[o>>2]=m+(c[o>>2]|0);o=i+2|0;m=h+8|0;if((o|0)<(g|0)){h=m;i=o}else{q=m;r=o;break}}}else{q=a;r=d}}while(0);if((r|0)>=(f|0)){return}if((d|0)>0){f=0;r=0;while(1){a=(ba(c[q+(f<<2)>>2]|0,c[b+(f<<2)>>2]|0)|0)+r|0;i=f+1|0;if((i|0)<(d|0)){f=i;r=a}else{v=d;w=a;break}}}else{v=0;w=0}d=q+(v<<2)|0;c[d>>2]=(c[d>>2]|0)+(w>>e);return}function qaa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0;if((e|0)>0){h=0;do{c[a+(h<<2)>>2]=c[b+(h<<2)>>2];h=h+1|0;}while((h|0)<(e|0))}switch(e|0){case 6:{if((d|0)<=6){return}h=f+20|0;i=f+16|0;j=f+12|0;k=f+8|0;l=f+4|0;m=6;do{n=c[h>>2]|0;o=ba(n,c[b+(m-6<<2)>>2]|0)|0;p=c[b+(m-5<<2)>>2]|0;q=ba(p,n)|0;n=c[i>>2]|0;r=(ba(n,p)|0)+o|0;o=c[b+(m-4<<2)>>2]|0;p=(ba(o,n)|0)+q|0;q=c[j>>2]|0;n=r+(ba(q,o)|0)|0;o=c[b+(m-3<<2)>>2]|0;r=p+(ba(o,q)|0)|0;q=c[k>>2]|0;p=n+(ba(q,o)|0)|0;o=c[b+(m-2<<2)>>2]|0;n=r+(ba(o,q)|0)|0;q=c[l>>2]|0;r=p+(ba(q,o)|0)|0;o=c[b+(m-1<<2)>>2]|0;p=n+(ba(o,q)|0)|0;q=c[f>>2]|0;n=r+(ba(q,o)|0)|0;o=c[b+(m<<2)>>2]|0;r=p+(ba(o,q)|0)|0;c[a+(m<<2)>>2]=o-(n>>g);n=m|1;c[a+(n<<2)>>2]=(c[b+(n<<2)>>2]|0)-(r>>g);m=m+2|0;}while((m|0)<(d|0));return};case 3:{if((d|0)<=3){return}m=f+8|0;l=f+4|0;k=3;do{j=c[m>>2]|0;i=ba(j,c[b+(k-3<<2)>>2]|0)|0;h=c[b+(k-2<<2)>>2]|0;r=ba(h,j)|0;j=c[l>>2]|0;n=(ba(j,h)|0)+i|0;i=c[b+(k-1<<2)>>2]|0;h=(ba(i,j)|0)+r|0;r=c[f>>2]|0;j=n+(ba(r,i)|0)|0;i=c[b+(k<<2)>>2]|0;n=h+(ba(i,r)|0)|0;c[a+(k<<2)>>2]=i-(j>>g);j=k+1|0;c[a+(j<<2)>>2]=(c[b+(j<<2)>>2]|0)-(n>>g);k=k+2|0;}while((k|0)<(d|0));return};case 2:{if((d|0)<=2){return}k=f+4|0;l=2;do{m=c[k>>2]|0;n=ba(m,c[b+(l-2<<2)>>2]|0)|0;j=c[b+(l-1<<2)>>2]|0;i=ba(j,m)|0;m=c[f>>2]|0;r=(ba(m,j)|0)+n|0;n=c[b+(l<<2)>>2]|0;j=(ba(n,m)|0)+i|0;c[a+(l<<2)>>2]=n-(r>>g);r=l|1;c[a+(r<<2)>>2]=(c[b+(r<<2)>>2]|0)-(j>>g);l=l+2|0;}while((l|0)<(d|0));return};case 1:{if((d|0)>1){s=1}else{return}do{l=c[f>>2]|0;k=ba(l,c[b+(s-1<<2)>>2]|0)|0;j=c[b+(s<<2)>>2]|0;r=ba(j,l)|0;c[a+(s<<2)>>2]=j-(k>>g);k=s+1|0;c[a+(k<<2)>>2]=(c[b+(k<<2)>>2]|0)-(r>>g);s=s+2|0;}while((s|0)<(d|0));return};case 8:{if((d|0)<=8){return}s=f+28|0;r=f+24|0;k=f+20|0;j=f+16|0;l=f+12|0;n=f+8|0;i=f+4|0;m=8;do{h=c[s>>2]|0;o=ba(h,c[b+(m-8<<2)>>2]|0)|0;q=c[b+(m-7<<2)>>2]|0;p=ba(q,h)|0;h=c[r>>2]|0;t=(ba(h,q)|0)+o|0;o=c[b+(m-6<<2)>>2]|0;q=(ba(o,h)|0)+p|0;p=c[k>>2]|0;h=t+(ba(p,o)|0)|0;o=c[b+(m-5<<2)>>2]|0;t=q+(ba(o,p)|0)|0;p=c[j>>2]|0;q=h+(ba(p,o)|0)|0;o=c[b+(m-4<<2)>>2]|0;h=t+(ba(o,p)|0)|0;p=c[l>>2]|0;t=q+(ba(p,o)|0)|0;o=c[b+(m-3<<2)>>2]|0;q=h+(ba(o,p)|0)|0;p=c[n>>2]|0;h=t+(ba(p,o)|0)|0;o=c[b+(m-2<<2)>>2]|0;t=q+(ba(o,p)|0)|0;p=c[i>>2]|0;q=h+(ba(p,o)|0)|0;o=c[b+(m-1<<2)>>2]|0;h=t+(ba(o,p)|0)|0;p=c[f>>2]|0;t=q+(ba(p,o)|0)|0;o=c[b+(m<<2)>>2]|0;q=h+(ba(o,p)|0)|0;c[a+(m<<2)>>2]=o-(t>>g);t=m|1;c[a+(t<<2)>>2]=(c[b+(t<<2)>>2]|0)-(q>>g);m=m+2|0;}while((m|0)<(d|0));return};case 4:{if((d|0)<=4){return}m=f+12|0;i=f+8|0;n=f+4|0;l=4;do{j=c[m>>2]|0;k=ba(j,c[b+(l-4<<2)>>2]|0)|0;r=c[b+(l-3<<2)>>2]|0;s=ba(r,j)|0;j=c[i>>2]|0;q=(ba(j,r)|0)+k|0;k=c[b+(l-2<<2)>>2]|0;r=(ba(k,j)|0)+s|0;s=c[n>>2]|0;j=q+(ba(s,k)|0)|0;k=c[b+(l-1<<2)>>2]|0;q=r+(ba(k,s)|0)|0;s=c[f>>2]|0;r=j+(ba(s,k)|0)|0;k=c[b+(l<<2)>>2]|0;j=q+(ba(k,s)|0)|0;c[a+(l<<2)>>2]=k-(r>>g);r=l|1;c[a+(r<<2)>>2]=(c[b+(r<<2)>>2]|0)-(j>>g);l=l+2|0;}while((l|0)<(d|0));return};case 7:{if((d|0)<=7){return}l=f+24|0;n=f+20|0;i=f+16|0;m=f+12|0;j=f+8|0;r=f+4|0;k=7;do{s=c[l>>2]|0;q=ba(s,c[b+(k-7<<2)>>2]|0)|0;t=c[b+(k-6<<2)>>2]|0;o=ba(t,s)|0;s=c[n>>2]|0;p=(ba(s,t)|0)+q|0;q=c[b+(k-5<<2)>>2]|0;t=(ba(q,s)|0)+o|0;o=c[i>>2]|0;s=p+(ba(o,q)|0)|0;q=c[b+(k-4<<2)>>2]|0;p=t+(ba(q,o)|0)|0;o=c[m>>2]|0;t=s+(ba(o,q)|0)|0;q=c[b+(k-3<<2)>>2]|0;s=p+(ba(q,o)|0)|0;o=c[j>>2]|0;p=t+(ba(o,q)|0)|0;q=c[b+(k-2<<2)>>2]|0;t=s+(ba(q,o)|0)|0;o=c[r>>2]|0;s=p+(ba(o,q)|0)|0;q=c[b+(k-1<<2)>>2]|0;p=t+(ba(q,o)|0)|0;o=c[f>>2]|0;t=s+(ba(o,q)|0)|0;q=c[b+(k<<2)>>2]|0;s=p+(ba(q,o)|0)|0;c[a+(k<<2)>>2]=q-(t>>g);t=k+1|0;c[a+(t<<2)>>2]=(c[b+(t<<2)>>2]|0)-(s>>g);k=k+2|0;}while((k|0)<(d|0));return};case 5:{if((d|0)<=5){return}k=f+16|0;r=f+12|0;j=f+8|0;m=f+4|0;i=5;do{n=c[k>>2]|0;l=ba(n,c[b+(i-5<<2)>>2]|0)|0;s=c[b+(i-4<<2)>>2]|0;t=ba(s,n)|0;n=c[r>>2]|0;q=(ba(n,s)|0)+l|0;l=c[b+(i-3<<2)>>2]|0;s=(ba(l,n)|0)+t|0;t=c[j>>2]|0;n=q+(ba(t,l)|0)|0;l=c[b+(i-2<<2)>>2]|0;q=s+(ba(l,t)|0)|0;t=c[m>>2]|0;s=n+(ba(t,l)|0)|0;l=c[b+(i-1<<2)>>2]|0;n=q+(ba(l,t)|0)|0;t=c[f>>2]|0;q=s+(ba(t,l)|0)|0;l=c[b+(i<<2)>>2]|0;s=n+(ba(l,t)|0)|0;c[a+(i<<2)>>2]=l-(q>>g);q=i+1|0;c[a+(q<<2)>>2]=(c[b+(q<<2)>>2]|0)-(s>>g);i=i+2|0;}while((i|0)<(d|0));return};default:{if((e|0)>=(d|0)){return}i=f+28|0;m=f+24|0;j=f+20|0;r=f+16|0;k=f+12|0;s=f+8|0;q=f+4|0;l=f+124|0;t=f+120|0;n=f+116|0;o=f+112|0;p=f+108|0;h=f+104|0;u=f+100|0;v=f+96|0;w=f+92|0;x=f+88|0;y=f+84|0;z=f+80|0;A=f+76|0;B=f+72|0;C=f+68|0;D=f+64|0;E=f+60|0;F=f+56|0;G=f+52|0;H=f+48|0;I=f+44|0;J=f+40|0;K=f+36|0;L=f+32|0;M=e;do{N=c[b+(M-e<<2)>>2]|0;switch(e|0){case 30:{O=N;P=0;Q=0;R=33;break};case 26:{S=N;T=0;U=0;R=37;break};case 13:{V=N;W=0;X=0;R=50;break};case 23:{Y=N;Z=0;_=0;R=40;break};case 17:{$=N;aa=0;ca=0;R=46;break};case 10:{da=N;ea=0;fa=0;R=53;break};case 29:{ga=N;ha=0;ia=0;R=34;break};case 19:{ja=N;ka=0;la=0;R=44;break};case 16:{ma=N;na=0;oa=0;R=47;break};case 22:{pa=N;qa=0;ra=0;R=41;break};case 14:{sa=N;ta=0;ua=0;R=49;break};case 28:{va=N;wa=0;xa=0;R=35;break};case 31:{ya=N;za=0;Aa=0;R=32;break};case 11:{Ba=N;Ca=0;Da=0;R=52;break};case 18:{Ea=N;Fa=0;Ga=0;R=45;break};case 27:{Ha=N;Ia=0;Ja=0;R=36;break};case 12:{Ka=N;La=0;Ma=0;R=51;break};case 15:{Na=N;Oa=0;Pa=0;R=48;break};case 25:{Qa=N;Ra=0;Sa=0;R=38;break};case 9:{Ta=N;Ua=0;Va=0;R=54;break};case 32:{Wa=c[l>>2]|0;Xa=ba(Wa,N)|0;Ya=c[b+(M-31<<2)>>2]|0;ya=Ya;za=Xa;Aa=ba(Ya,Wa)|0;R=32;break};case 21:{Za=N;_a=0;$a=0;R=42;break};case 20:{ab=N;bb=0;cb=0;R=43;break};case 24:{db=N;eb=0;fb=0;R=39;break};default:{gb=0;hb=0;ib=c[b+(M<<2)>>2]|0}}if((R|0)==32){R=0;N=c[t>>2]|0;Wa=(ba(N,ya)|0)+za|0;Ya=c[b+(M-30<<2)>>2]|0;O=Ya;P=Wa;Q=(ba(Ya,N)|0)+Aa|0;R=33}if((R|0)==33){R=0;N=c[n>>2]|0;Ya=(ba(N,O)|0)+P|0;Wa=c[b+(M-29<<2)>>2]|0;ga=Wa;ha=Ya;ia=(ba(Wa,N)|0)+Q|0;R=34}if((R|0)==34){R=0;N=c[o>>2]|0;Wa=(ba(N,ga)|0)+ha|0;Ya=c[b+(M-28<<2)>>2]|0;va=Ya;wa=Wa;xa=(ba(Ya,N)|0)+ia|0;R=35}if((R|0)==35){R=0;N=c[p>>2]|0;Ya=(ba(N,va)|0)+wa|0;Wa=c[b+(M-27<<2)>>2]|0;Ha=Wa;Ia=Ya;Ja=(ba(Wa,N)|0)+xa|0;R=36}if((R|0)==36){R=0;N=c[h>>2]|0;Wa=(ba(N,Ha)|0)+Ia|0;Ya=c[b+(M-26<<2)>>2]|0;S=Ya;T=Wa;U=(ba(Ya,N)|0)+Ja|0;R=37}if((R|0)==37){R=0;N=c[u>>2]|0;Ya=(ba(N,S)|0)+T|0;Wa=c[b+(M-25<<2)>>2]|0;Qa=Wa;Ra=Ya;Sa=(ba(Wa,N)|0)+U|0;R=38}if((R|0)==38){R=0;N=c[v>>2]|0;Wa=(ba(N,Qa)|0)+Ra|0;Ya=c[b+(M-24<<2)>>2]|0;db=Ya;eb=Wa;fb=(ba(Ya,N)|0)+Sa|0;R=39}if((R|0)==39){R=0;N=c[w>>2]|0;Ya=(ba(N,db)|0)+eb|0;Wa=c[b+(M-23<<2)>>2]|0;Y=Wa;Z=Ya;_=(ba(Wa,N)|0)+fb|0;R=40}if((R|0)==40){R=0;N=c[x>>2]|0;Wa=(ba(N,Y)|0)+Z|0;Ya=c[b+(M-22<<2)>>2]|0;pa=Ya;qa=Wa;ra=(ba(Ya,N)|0)+_|0;R=41}if((R|0)==41){R=0;N=c[y>>2]|0;Ya=(ba(N,pa)|0)+qa|0;Wa=c[b+(M-21<<2)>>2]|0;Za=Wa;_a=Ya;$a=(ba(Wa,N)|0)+ra|0;R=42}if((R|0)==42){R=0;N=c[z>>2]|0;Wa=(ba(N,Za)|0)+_a|0;Ya=c[b+(M-20<<2)>>2]|0;ab=Ya;bb=Wa;cb=(ba(Ya,N)|0)+$a|0;R=43}if((R|0)==43){R=0;N=c[A>>2]|0;Ya=(ba(N,ab)|0)+bb|0;Wa=c[b+(M-19<<2)>>2]|0;ja=Wa;ka=Ya;la=(ba(Wa,N)|0)+cb|0;R=44}if((R|0)==44){R=0;N=c[B>>2]|0;Wa=(ba(N,ja)|0)+ka|0;Ya=c[b+(M-18<<2)>>2]|0;Ea=Ya;Fa=Wa;Ga=(ba(Ya,N)|0)+la|0;R=45}if((R|0)==45){R=0;N=c[C>>2]|0;Ya=(ba(N,Ea)|0)+Fa|0;Wa=c[b+(M-17<<2)>>2]|0;$=Wa;aa=Ya;ca=(ba(Wa,N)|0)+Ga|0;R=46}if((R|0)==46){R=0;N=c[D>>2]|0;Wa=(ba(N,$)|0)+aa|0;Ya=c[b+(M-16<<2)>>2]|0;ma=Ya;na=Wa;oa=(ba(Ya,N)|0)+ca|0;R=47}if((R|0)==47){R=0;N=c[E>>2]|0;Ya=(ba(N,ma)|0)+na|0;Wa=c[b+(M-15<<2)>>2]|0;Na=Wa;Oa=Ya;Pa=(ba(Wa,N)|0)+oa|0;R=48}if((R|0)==48){R=0;N=c[F>>2]|0;Wa=(ba(N,Na)|0)+Oa|0;Ya=c[b+(M-14<<2)>>2]|0;sa=Ya;ta=Wa;ua=(ba(Ya,N)|0)+Pa|0;R=49}if((R|0)==49){R=0;N=c[G>>2]|0;Ya=(ba(N,sa)|0)+ta|0;Wa=c[b+(M-13<<2)>>2]|0;V=Wa;W=Ya;X=(ba(Wa,N)|0)+ua|0;R=50}if((R|0)==50){R=0;N=c[H>>2]|0;Wa=(ba(N,V)|0)+W|0;Ya=c[b+(M-12<<2)>>2]|0;Ka=Ya;La=Wa;Ma=(ba(Ya,N)|0)+X|0;R=51}if((R|0)==51){R=0;N=c[I>>2]|0;Ya=(ba(N,Ka)|0)+La|0;Wa=c[b+(M-11<<2)>>2]|0;Ba=Wa;Ca=Ya;Da=(ba(Wa,N)|0)+Ma|0;R=52}if((R|0)==52){R=0;N=c[J>>2]|0;Wa=(ba(N,Ba)|0)+Ca|0;Ya=c[b+(M-10<<2)>>2]|0;da=Ya;ea=Wa;fa=(ba(Ya,N)|0)+Da|0;R=53}if((R|0)==53){R=0;N=c[K>>2]|0;Ya=(ba(N,da)|0)+ea|0;Wa=c[b+(M-9<<2)>>2]|0;Ta=Wa;Ua=Ya;Va=(ba(Wa,N)|0)+fa|0;R=54}if((R|0)==54){R=0;N=c[L>>2]|0;Wa=(ba(N,Ta)|0)+Ua|0;Ya=c[b+(M-8<<2)>>2]|0;Xa=(ba(Ya,N)|0)+Va|0;N=c[i>>2]|0;jb=Wa+(ba(N,Ya)|0)|0;Ya=c[b+(M-7<<2)>>2]|0;Wa=Xa+(ba(Ya,N)|0)|0;N=c[m>>2]|0;Xa=jb+(ba(N,Ya)|0)|0;Ya=c[b+(M-6<<2)>>2]|0;jb=Wa+(ba(Ya,N)|0)|0;N=c[j>>2]|0;Wa=Xa+(ba(N,Ya)|0)|0;Ya=c[b+(M-5<<2)>>2]|0;Xa=jb+(ba(Ya,N)|0)|0;N=c[r>>2]|0;jb=Wa+(ba(N,Ya)|0)|0;Ya=c[b+(M-4<<2)>>2]|0;Wa=Xa+(ba(Ya,N)|0)|0;N=c[k>>2]|0;Xa=jb+(ba(N,Ya)|0)|0;Ya=c[b+(M-3<<2)>>2]|0;jb=Wa+(ba(Ya,N)|0)|0;N=c[s>>2]|0;Wa=Xa+(ba(N,Ya)|0)|0;Ya=c[b+(M-2<<2)>>2]|0;Xa=jb+(ba(Ya,N)|0)|0;N=c[q>>2]|0;jb=Wa+(ba(N,Ya)|0)|0;Ya=c[b+(M-1<<2)>>2]|0;Wa=Xa+(ba(Ya,N)|0)|0;N=c[f>>2]|0;Xa=jb+(ba(N,Ya)|0)|0;Ya=c[b+(M<<2)>>2]|0;gb=Xa;hb=Wa+(ba(Ya,N)|0)|0;ib=Ya}c[a+(M<<2)>>2]=ib-(gb>>g);Ya=M+1|0;c[a+(Ya<<2)>>2]=(c[b+(Ya<<2)>>2]|0)-(hb>>g);M=M+2|0;}while((M|0)<(d|0));return}}}function raa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)>0&(d|0)>0){g=c[a>>2]|0;h=0}else{return}while(1){a=g;i=0;while(1){c[a>>2]=c[(c[b+(i<<2)>>2]|0)+(h<<2)>>2]<<f;j=i+1|0;if((j|0)<(d|0)){a=a+4|0;i=j}else{break}}i=h+1|0;if((i|0)<(e|0)){g=g+(d<<2)|0;h=i}else{break}}return}function saa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((e|0)<=0){return}d=c[b>>2]|0;g=c[b+4>>2]|0;b=0;h=c[a>>2]|0;while(1){a=c[d+(b<<2)>>2]|0;i=c[g+(b<<2)>>2]|0;c[h>>2]=a<<f;c[h+4>>2]=a-i<<f;i=b+1|0;if((i|0)<(e|0)){b=i;h=h+8|0}else{break}}return}function taa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)<=0){return}d=c[b>>2]|0;g=c[b+4>>2]|0;b=0;h=c[a>>2]|0;while(1){a=c[g+(b<<2)>>2]|0;c[h>>2]=a+(c[d+(b<<2)>>2]|0)<<f;c[h+4>>2]=a<<f;a=b+1|0;if((a|0)<(e|0)){b=a;h=h+8|0}else{break}}return}function uaa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((e|0)<=0){return}d=c[b>>2]|0;g=c[b+4>>2]|0;b=0;h=c[a>>2]|0;while(1){a=c[g+(b<<2)>>2]|0;i=(c[d+(b<<2)>>2]|0)-(a>>1)|0;c[h>>2]=i+a<<f;c[h+4>>2]=i<<f;i=b+1|0;if((i|0)<(e|0)){b=i;h=h+8|0}else{break}}return}function vaa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)>0&(d|0)>0){g=0}else{return}do{h=0;do{c[(c[a+(h<<2)>>2]|0)+(g<<2)>>2]=c[(c[b+(h<<2)>>2]|0)+(g<<2)>>2]<<f;h=h+1|0;}while((h|0)<(d|0));g=g+1|0;}while((g|0)<(e|0));return}function waa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)<=0){return}d=a+4|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=0;do{i=c[g+(b<<2)>>2]|0;j=c[h+(b<<2)>>2]|0;c[(c[a>>2]|0)+(b<<2)>>2]=i<<f;c[(c[d>>2]|0)+(b<<2)>>2]=i-j<<f;b=b+1|0;}while((b|0)<(e|0));return}function xaa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((e|0)<=0){return}d=a+4|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=0;do{i=c[h+(b<<2)>>2]|0;c[(c[a>>2]|0)+(b<<2)>>2]=i+(c[g+(b<<2)>>2]|0)<<f;c[(c[d>>2]|0)+(b<<2)>>2]=i<<f;b=b+1|0;}while((b|0)<(e|0));return}function yaa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)<=0){return}d=a+4|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=0;do{i=c[h+(b<<2)>>2]|0;j=(c[g+(b<<2)>>2]|0)-(i>>1)|0;c[(c[a>>2]|0)+(b<<2)>>2]=j+i<<f;c[(c[d>>2]|0)+(b<<2)>>2]=j<<f;b=b+1|0;}while((b|0)<(e|0));return}function zaa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((f|0)>0&(e|0)>0){h=c[a>>2]|0;i=0}else{return}while(1){a=h;j=0;while(1){b[a>>1]=c[(c[d+(j<<2)>>2]|0)+(i<<2)>>2]<<g;k=j+1|0;if((k|0)<(e|0)){a=a+2|0;j=k}else{break}}j=i+1|0;if((j|0)<(f|0)){h=h+(e<<1)|0;i=j}else{break}}return}function Aaa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)<=0){return}e=c[d>>2]|0;h=c[d+4>>2]|0;d=0;i=c[a>>2]|0;while(1){a=c[e+(d<<2)>>2]|0;j=c[h+(d<<2)>>2]|0;b[i>>1]=a<<g;b[i+2>>1]=a-j<<g;j=d+1|0;if((j|0)<(f|0)){d=j;i=i+4|0}else{break}}return}function Baa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;if((f|0)<=0){return}e=c[d>>2]|0;h=c[d+4>>2]|0;d=0;i=c[a>>2]|0;while(1){a=c[h+(d<<2)>>2]|0;b[i>>1]=a+(c[e+(d<<2)>>2]|0)<<g;b[i+2>>1]=a<<g;a=d+1|0;if((a|0)<(f|0)){d=a;i=i+4|0}else{break}}return}function Caa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)<=0){return}e=c[d>>2]|0;h=c[d+4>>2]|0;d=0;i=c[a>>2]|0;while(1){a=c[h+(d<<2)>>2]|0;j=(c[e+(d<<2)>>2]|0)-(a>>1)|0;b[i>>1]=j+a<<g;b[i+2>>1]=j<<g;j=d+1|0;if((j|0)<(f|0)){d=j;i=i+4|0}else{break}}return}function Daa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)<=0){return}h=(e|0)>0;i=0;do{if(h){j=0;do{b[(c[a+(j<<2)>>2]|0)+(i<<1)>>1]=c[(c[d+(j<<2)>>2]|0)+(i<<2)>>2]<<g;j=j+1|0;}while((j|0)<(e|0))}i=i+1|0;}while((i|0)<(f|0));return}function Eaa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((f|0)<=0){return}e=a+4|0;h=c[d>>2]|0;i=c[d+4>>2]|0;d=0;do{j=c[h+(d<<2)>>2]|0;k=c[i+(d<<2)>>2]|0;b[(c[a>>2]|0)+(d<<1)>>1]=j<<g;b[(c[e>>2]|0)+(d<<1)>>1]=j-k<<g;d=d+1|0;}while((d|0)<(f|0));return}function Faa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)<=0){return}e=a+4|0;h=c[d>>2]|0;i=c[d+4>>2]|0;d=0;do{j=c[i+(d<<2)>>2]|0;b[(c[a>>2]|0)+(d<<1)>>1]=j+(c[h+(d<<2)>>2]|0)<<g;b[(c[e>>2]|0)+(d<<1)>>1]=j<<g;d=d+1|0;}while((d|0)<(f|0));return}function Gaa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((f|0)<=0){return}e=a+4|0;h=c[d>>2]|0;i=c[d+4>>2]|0;d=0;do{j=c[i+(d<<2)>>2]|0;k=(c[h+(d<<2)>>2]|0)-(j>>1)|0;b[(c[a>>2]|0)+(d<<1)>>1]=k+j<<g;b[(c[e>>2]|0)+(d<<1)>>1]=k<<g;d=d+1|0;}while((d|0)<(f|0));return}function Haa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=i;i=i+392|0;d=b|0;e=b+56|0;f=b+112|0;g=b+168|0;h=b+224|0;j=b+280|0;k=b+336|0;l=c[a+412>>2]|0;m=c[a+416>>2]|0;n=c[a+60>>2]|0;o=n;p=n+4203908|0;c[p>>2]=a;q=a+420|0;r=c[q>>2]|0;if((r|0)==1){c[a+796>>2]=16;c[n+44>>2]=4}else if((r|0)==2){r=a+796|0;if((c[r>>2]|0)!=24){yDb(a,24,2053224,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}c[r>>2]=24;c[n+44>>2]=6}if((m-1|0)>>>0>7>>>0){yDb(a,16,2007456,(s=i,i=i+16|0,c[s>>2]=m,c[s+8>>2]=8,s)|0);i=s;t=-22;i=b;return t|0}r=n+28|0;c[r>>2]=m;if((l|0)<1){t=-1;i=b;return t|0}else{u=4}while(1){if((u|0)>=12){v=12;break}if((l|0)==(c[1220192+(u<<2)>>2]|0)){v=11;break}else{u=u+1|0}}do{if((v|0)==11){c[n+32>>2]=l;c[n+36>>2]=u;c[n+40>>2]=0}else if((v|0)==12){if((u|0)!=12){break}do{if(((l|0)%1e3|0|0)==0&(l|0)<255e3){c[n+36>>2]=12;c[n+40>>2]=(l|0)/1e3|0}else{if(((l|0)%10|0|0)==0&(l|0)<655350){c[n+36>>2]=14;c[n+40>>2]=(l|0)/10|0;break}if((l|0)<65535){c[n+36>>2]=13;c[n+40>>2]=l;break}yDb(a,16,1969456,(s=i,i=i+8|0,c[s>>2]=l,s)|0);i=s;t=-22;i=b;return t|0}}while(0);c[n+32>>2]=l}}while(0);l=c[a+84>>2]|0;u=n+4203864|0;do{if((l|0)<0){c[u>>2]=5;w=5}else{c[u>>2]=l;if((l|0)<=12){w=l;break}yDb(a,16,1940944,(s=i,i=i+8|0,c[s>>2]=l,s)|0);i=s;t=-22;i=b;return t|0}}while(0);c[d>>2]=27;c[d+4>>2]=27;c[d+8>>2]=27;c[d+12>>2]=105;c[d+16>>2]=105;c[d+20>>2]=105;c[d+24>>2]=105;c[d+28>>2]=105;c[d+32>>2]=105;c[d+36>>2]=105;c[d+40>>2]=105;c[d+44>>2]=105;c[d+48>>2]=105;l=c[d+(w<<2)>>2]|0;c[n+4203868>>2]=l;d=n+4203872|0;x=c[d>>2]|0;if((x|0)==-1){c[e>>2]=1;c[e+4>>2]=1;c[e+8>>2]=1;c[e+12>>2]=2;c[e+16>>2]=2;c[e+20>>2]=2;c[e+24>>2]=2;c[e+28>>2]=2;c[e+32>>2]=2;c[e+36>>2]=2;c[e+40>>2]=2;c[e+44>>2]=2;c[e+48>>2]=2;y=c[e+(w<<2)>>2]|0;c[d>>2]=y;z=y}else{z=x}c[f>>2]=2;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=1;c[f+16>>2]=1;c[f+20>>2]=1;c[f+24>>2]=1;c[f+28>>2]=1;c[f+32>>2]=1;c[f+36>>2]=1;c[f+40>>2]=1;c[f+44>>2]=1;c[f+48>>2]=1;x=c[f+(w<<2)>>2]|0;f=n+4203884|0;c[f>>2]=x;c[g>>2]=3;c[g+4>>2]=4;c[g+8>>2]=4;c[g+12>>2]=6;c[g+16>>2]=8;c[g+20>>2]=8;c[g+24>>2]=8;c[g+28>>2]=8;c[g+32>>2]=12;c[g+36>>2]=12;c[g+40>>2]=12;c[g+44>>2]=32;c[g+48>>2]=32;y=c[g+(w<<2)>>2]|0;g=n+4203888|0;c[g>>2]=y;e=n+4203892|0;if((c[e>>2]|0)<0){TGb(h|0,0,24)|0;c[h+24>>2]=2;c[h+28>>2]=5;c[h+32>>2]=2;c[h+36>>2]=5;c[h+40>>2]=4;c[h+44>>2]=5;c[h+48>>2]=4;c[e>>2]=c[h+(w<<2)>>2]}h=n+4203896|0;A=c[h>>2]|0;B=n+4203900|0;C=c[B>>2]|0;if((A|0)>(C|0)){yDb(a,16,1916560,(s=i,i=i+16|0,c[s>>2]=A,c[s+8>>2]=C,s)|0);i=s;t=-22;i=b;return t|0}if((A|0)<0){TGb(j|0,0,52)|0;c[j>>2]=2;c[j+4>>2]=2;c[h>>2]=c[j+(w<<2)>>2]}if((C|0)<0){c[k>>2]=2;c[k+4>>2]=2;c[k+8>>2]=3;c[k+12>>2]=3;c[k+16>>2]=3;c[k+20>>2]=8;c[k+24>>2]=8;c[k+28>>2]=8;c[k+32>>2]=8;c[k+36>>2]=8;c[k+40>>2]=8;c[k+44>>2]=8;c[k+48>>2]=8;c[B>>2]=c[k+(w<<2)>>2]}do{if((z|0)==0){c[f>>2]=0;c[g>>2]=0}else{w=c[a+604>>2]|0;do{if((w|0)>-1){if((z|0)==1){if((w|0)<=4){c[f>>2]=w;D=w;break}yDb(a,16,1895992,(s=i,i=i+8|0,c[s>>2]=w,s)|0);i=s;t=-22;i=b;return t|0}else{if(!((w-1|0)>>>0>31>>>0)){c[f>>2]=w;D=w;break}yDb(a,16,1895992,(s=i,i=i+8|0,c[s>>2]=w,s)|0);i=s;t=-22;i=b;return t|0}}else{D=x}}while(0);w=c[a+608>>2]|0;if((w|0)>-1){do{if((z|0)==1){if((w|0)<=4){break}yDb(a,16,2353272,(s=i,i=i+8|0,c[s>>2]=w,s)|0);i=s;t=-22;i=b;return t|0}else{if(!((w-1|0)>>>0>31>>>0)){break}yDb(a,16,2353272,(s=i,i=i+8|0,c[s>>2]=w,s)|0);i=s;t=-22;i=b;return t|0}}while(0);c[g>>2]=w;E=w}else{E=y}if((E|0)>=(D|0)){break}yDb(a,16,2333192,(s=i,i=i+16|0,c[s>>2]=D,c[s+8>>2]=E,s)|0);i=s;t=-22;i=b;return t|0}}while(0);E=a+424|0;D=c[E>>2]|0;do{if((D|0)>0){if(!((D-16|0)>>>0>65519>>>0)){y=c[p>>2]|0;F=m;G=y;H=c[y+424>>2]|0;break}yDb(a,16,2308680,(s=i,i=i+8|0,c[s>>2]=D,s)|0);i=s;t=-22;i=b;return t|0}else{y=c[n+32>>2]|0;if((y|0)>0){z=c[305181]|0;x=(ba(l,y)|0)/1e3|0;y=c[305180]|0;k=(x|0)>=(y|0)&(y|0)>(z|0)?y:z;y=(x|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[305182]|0;z=(x|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[305183]|0;k=(x|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[305184]|0;y=(x|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[305185]|0;z=(x|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[305186]|0;k=(x|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[305187]|0;y=(x|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[305188]|0;z=(x|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[305189]|0;k=(x|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[305190]|0;y=(x|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[305191]|0;z=(x|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[305192]|0;k=(x|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[305193]|0;y=(x|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[305194]|0;z=(x|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[305195]|0;k=(x|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[p>>2]|0;c[z+424>>2]=k;F=c[r>>2]|0;G=z;H=k;break}else{yDb(0,0,2093840,(s=i,i=i+24|0,c[s>>2]=2088728,c[s+8>>2]=2083944,c[s+16>>2]=157,s)|0);i=s;Cd();return 0}}}while(0);c[n+48>>2]=H;H=n+56|0;c[H>>2]=U9(c[G+424>>2]|0,F,c[G+796>>2]|0)|0;G=PDb()|0;c[n+4203940>>2]=G;if((G|0)==0){t=-12;i=b;return t|0}QDb(G);G=WDb(34)|0;if((G|0)==0){t=-12;i=b;return t|0}Kaa(o,G);c[a+96>>2]=G;c[a+100>>2]=34;c[n+64>>2]=0;c[n+52>>2]=c[H>>2];if((m|0)==4){H=a+448|0;G=c[H>>2]|0;o=c[H+4>>2]|0;if(!((G|0)==1539&(o|0)==0|(G|0)==51&(o|0)==0)){I=o;J=G;v=68}}else if((m|0)==5){G=a+448|0;o=c[G>>2]|0;H=c[G+4>>2]|0;if(!((o|0)==1543&(H|0)==0|(o|0)==55&(H|0)==0)){I=H;J=o;v=68}}else if((m|0)==3){o=a+448|0;H=c[o>>2]|0;G=c[o+4>>2]|0;if(!((H|0)==7&(G|0)==0)){I=G;J=H;v=68}}else if((m|0)==6){H=a+448|0;G=c[H>>2]|0;o=c[H+4>>2]|0;if(!((G|0)==1551&(o|0)==0|(G|0)==63&(o|0)==0)){I=o;J=G;v=68}}do{if((v|0)==68){G=a;if((J|0)==0&(I|0)==0){yDb(G,24,2274152,(s=i,i=i+8|0,c[s>>2]=m,s)|0);i=s;break}else{yDb(G,16,2290048,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;break}}}while(0);m=FKa(n+4203912|0,c[E>>2]|0,c[g>>2]|0,2)|0;Z3(n+4203952|0,a);maa(n+4205196|0,c[q>>2]|0,c[a+796>>2]|0);a=c[p>>2]|0;p=a;yDb(p,48,2258480,(s=i,i=i+8|0,c[s>>2]=c[u>>2],s)|0);i=s;u=c[d>>2]|0;if((u|0)==3){d=c[n+4203876>>2]|0;yDb(p,48,2210048,(s=i,i=i+16|0,c[s>>2]=d,c[s+8>>2]=(d|0)==1?9203440:2193e3,s)|0);i=s}else if((u|0)==2){yDb(p,48,2219432,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}else if((u|0)==0){yDb(p,48,2244096,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}else if((u|0)==1){yDb(p,48,2231584,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}u=c[g>>2]|0;yDb(p,48,2176520,(s=i,i=i+16|0,c[s>>2]=c[f>>2],c[s+8>>2]=u,s)|0);i=s;switch(c[e>>2]|0){case 3:{yDb(p,48,2165832,(s=i,i=i+8|0,c[s>>2]=2139440,s)|0);i=s;break};case 4:{yDb(p,48,2165832,(s=i,i=i+8|0,c[s>>2]=2133120,s)|0);i=s;break};case 1:{yDb(p,48,2165832,(s=i,i=i+8|0,c[s>>2]=2152136,s)|0);i=s;break};case 2:{yDb(p,48,2165832,(s=i,i=i+8|0,c[s>>2]=2145288,s)|0);i=s;break};case 0:{yDb(p,48,2165832,(s=i,i=i+8|0,c[s>>2]=2159224,s)|0);i=s;break};case 5:{yDb(p,48,2165832,(s=i,i=i+8|0,c[s>>2]=2126720,s)|0);i=s;break};default:{}}e=c[B>>2]|0;yDb(p,48,2120848,(s=i,i=i+16|0,c[s>>2]=c[h>>2],c[s+8>>2]=e,s)|0);i=s;yDb(p,48,2114792,(s=i,i=i+8|0,c[s>>2]=c[a+424>>2],s)|0);i=s;yDb(p,48,2100552,(s=i,i=i+8|0,c[s>>2]=c[n+4203880>>2],s)|0);i=s;t=m;i=b;return t|0}function Iaa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0;j=i;i=i+72|0;k=j|0;l=j+32|0;m=j+64|0;n=c[e+60>>2]|0;o=n;if((g|0)==0){c[n+56>>2]=c[n+60>>2];TDb(c[n+4203940>>2]|0,n+80|0);Kaa(o,c[e+96>>2]|0);p=0;i=j;return p|0}q=g+76|0;r=c[q>>2]|0;s=n+4203840|0;if((r|0)<(c[s>>2]|0)){c[n+56>>2]=U9(r,c[n+28>>2]|0,c[e+796>>2]|0)|0;t=c[q>>2]|0}else{t=r}r=0;while(1){if((r|0)>=16){u=9;break}if((c[1220720+(r<<2)>>2]|0)==(t|0)){u=8;break}else{r=r+1|0}}do{if((u|0)==8){c[s>>2]=t;c[n+4203844>>2]=r;c[n+4203848>>2]=0}else if((u|0)==9){if((r|0)!=16){break}c[s>>2]=t;v=n+4203844|0;if((t|0)<257){c[v>>2]=6;c[n+4203848>>2]=t-1;break}else{c[v>>2]=7;c[n+4203848>>2]=t-1;break}}}while(0);t=n+28|0;r=n+4203908|0;if((c[t>>2]|0)>0){v=0;do{c[o+96+(v*525468|0)+12>>2]=0;w=c[(c[r>>2]|0)+796>>2]|0;c[o+96+(v*525468|0)+8>>2]=w;c[o+96+(v*525468|0)+152>>2]=(w|0)>16?5:4;v=v+1|0;}while((v|0)<(c[t>>2]|0))}v=n+4203860|0;c[v>>2]=0;w=g|0;y=c[w>>2]|0;z=(BFb(c[(c[r>>2]|0)+420>>2]|0)|0)<<3;A=c[r>>2]|0;B=z-(c[A+796>>2]|0)|0;do{if((c[A+420>>2]|0)==1){z=y;C=c[s>>2]|0;if((C|0)<=0){D=C;break}E=0;G=0;H=c[t>>2]|0;I=C;while(1){if((H|0)>0){C=0;J=E;do{c[o+96+(C*525468|0)+1184+(G<<2)>>2]=b[z+(J<<1)>>1]>>B;C=C+1|0;J=J+1|0;K=c[t>>2]|0;}while((C|0)<(K|0));L=J;M=K;N=c[s>>2]|0}else{L=E;M=H;N=I}C=G+1|0;if((C|0)<(N|0)){E=L;G=C;H=M;I=N}else{D=N;break}}}else{I=y;H=c[s>>2]|0;if((H|0)<=0){D=H;break}G=0;E=0;z=c[t>>2]|0;C=H;while(1){if((z|0)>0){H=0;O=G;do{c[o+96+(H*525468|0)+1184+(E<<2)>>2]=c[I+(O<<2)>>2]>>B;H=H+1|0;O=O+1|0;P=c[t>>2]|0;}while((H|0)<(P|0));Q=O;R=P;S=c[s>>2]|0}else{Q=G;R=z;S=C}H=E+1|0;if((H|0)<(S|0)){G=Q;E=H;z=R;C=S}else{D=S;break}}}}while(0);do{if((c[t>>2]|0)==2){S=c[n+4203904>>2]|0;if((S|0)<0){R=(1<<c[n+248>>2])-2|0;Q=k+24|0;P=k+16|0;B=k+8|0;y=k|0;TGb(k|0,0,32)|0;if((D|0)>2){N=2;M=0;L=0;K=0;A=0;C=0;z=0;E=0;G=0;I=c[n+1284>>2]|0;H=c[n+526752>>2]|0;while(1){J=c[o+1280+(N<<2)>>2]|0;T=N-2|0;U=J-(I<<1)+(c[o+1280+(T<<2)>>2]|0)|0;V=c[o+526748+(N<<2)>>2]|0;W=V-(H<<1)+(c[o+526748+(T<<2)>>2]|0)|0;T=W+U>>1;X=(T|0)>-1?T:-T|0;Y=YGb(X,(X|0)<0|0?-1:0,L,M)|0;Z=F;X=U-W|0;T=(X|0)>-1?X:-X|0;_=YGb(T,(T|0)<0|0?-1:0,A,K)|0;$=F;T=(U|0)>-1?U:-U|0;aa=YGb(T,(T|0)<0|0?-1:0,z,C)|0;ca=F;T=(W|0)>-1?W:-W|0;da=YGb(T,(T|0)<0|0?-1:0,G,E)|0;ea=F;T=N+1|0;if((T|0)<(D|0)){N=T;M=Z;L=Y;K=$;A=_;C=ca;z=aa;E=ea;G=da;I=J;H=V}else{break}}c[P>>2]=Y;c[P+4>>2]=Z;c[Q>>2]=_;c[Q+4>>2]=$;c[y>>2]=aa;c[y+4>>2]=ca;c[B>>2]=da;c[B+4>>2]=ea;fa=ca;ga=aa}else{fa=0;ga=0}H=D>>1;I=H;G=(H|0)<0|0?-1:0;H=D;E=(D|0)<0|0?-1:0;z=0;C=fa;A=ga;while(1){K=k+(z<<3)|0;L=A<<1|0>>>31;M=C<<1|A>>>31;N=ZGb(L,M,I,G)|0;V=F;if(G>>>0<M>>>0|G>>>0==M>>>0&I>>>0<L>>>0){L=hHb(N,V,H,E)|0;M=F;J=YGb(L,M,-2147483648,0)|0;T=F;W=0;if(T>>>0>W>>>0|T>>>0==W>>>0&J>>>0>-1>>>0){((M|0)<0|0?-1:0)>>31|((M|0)<0|0?-1:0)<<1;ha=(M>>31|((M|0)<0|0?-1:0)<<1)^2147483647}else{ha=L}L=ha>>>0>65535>>>0;M=L?ha>>>16:ha;J=L?16:0;if((M&65280|0)==0){ia=J;ja=M}else{ia=J|8;ja=M>>>8}M=(d[1191992+ja|0]|0)+ia|0;ka=(M|0)>(R|0)?R:M}else{ka=0}M=ba(ka+1|0,D)|0;J=$Gb(N|0,V|0,ka|0)|0;V=YGb(M,(M|0)<0|0?-1:0,J,F)|0;c[K>>2]=V;c[K+4>>2]=F;K=z+1|0;if((K|0)>=4){break}V=k+(K<<3)|0;z=K;C=c[V+4>>2]|0;A=c[V>>2]|0}A=c[y>>2]|0;C=c[y+4>>2]|0;z=c[B>>2]|0;R=c[B+4>>2]|0;E=YGb(z,R,A,C)|0;H=F;I=l|0;c[I>>2]=E;c[I+4>>2]=H;I=c[Q>>2]|0;G=c[Q+4>>2]|0;V=YGb(I,G,A,C)|0;C=F;A=l+8|0;c[A>>2]=V;c[A+4>>2]=C;A=YGb(I,G,z,R)|0;R=F;z=l+16|0;c[z>>2]=A;c[z+4>>2]=R;z=YGb(c[P>>2]|0,c[P+4>>2]|0,I,G)|0;G=F;I=l+24|0;c[I>>2]=z;c[I+4>>2]=G;I=(C>>>0<H>>>0|C>>>0==H>>>0&V>>>0<E>>>0)&1;E=l+(I<<3)|0;V=c[E+4>>2]|0;H=R>>>0<V>>>0|R>>>0==V>>>0&A>>>0<(c[E>>2]|0)>>>0?2:I;I=l+(H<<3)|0;E=c[I+4>>2]|0;A=G>>>0<E>>>0|G>>>0==E>>>0&z>>>0<(c[I>>2]|0)>>>0?3:H;c[n+4203856>>2]=A;la=A}else{c[n+4203856>>2]=S;la=S}if((la|0)==0){break}else if((la|0)==3){if((D|0)>0){A=0;do{H=o+1280+(A<<2)|0;I=c[H>>2]|0;z=o+526748+(A<<2)|0;E=c[z>>2]|0;c[H>>2]=E+I>>1;c[z>>2]=I-E;A=A+1|0;}while((A|0)<(D|0))}A=n+525572|0;c[A>>2]=(c[A>>2]|0)+1;break}else if((la|0)==1){if((D|0)>0){A=0;do{S=o+526748+(A<<2)|0;c[S>>2]=(c[o+1280+(A<<2)>>2]|0)-(c[S>>2]|0);A=A+1|0;}while((A|0)<(D|0))}A=n+525572|0;c[A>>2]=(c[A>>2]|0)+1;break}else{if((D|0)>0){A=0;do{S=o+1280+(A<<2)|0;c[S>>2]=(c[S>>2]|0)-(c[o+526748+(A<<2)>>2]|0);A=A+1|0;}while((A|0)<(D|0))}A=n+104|0;c[A>>2]=(c[A>>2]|0)+1;break}}else{c[n+4203856>>2]=0}}while(0);if((c[t>>2]|0)>0){D=0;do{la=c[s>>2]|0;l=0;k=0;while(1){if((k|0)>=(la|0)){ma=l;break}ka=c[o+96+(D*525468|0)+1184+(k<<2)>>2]|l;if((ka&1|0)==0){l=ka;k=k+1|0}else{ma=ka;break}}do{if((ma|0)!=0&(ma&1|0)==0){k=nDb(ma)|0;if((c[s>>2]|0)>0){l=0;do{la=o+96+(D*525468|0)+1184+(l<<2)|0;c[la>>2]=c[la>>2]>>k;l=l+1|0;}while((l|0)<(c[s>>2]|0))}c[o+96+(D*525468|0)+12>>2]=k;l=o+96+(D*525468|0)+8|0;O=(c[l>>2]|0)-k|0;c[l>>2]=O;if((O|0)>=18){break}c[o+96+(D*525468|0)+152>>2]=4}}while(0);D=D+1|0;}while((D|0)<(c[t>>2]|0))}D=Laa(o)|0;if((D|0)<0){u=68}else{if((D|0)>(c[n+56>>2]|0)){u=68}else{na=D}}do{if((u|0)==68){c[v>>2]=1;D=Laa(o)|0;if((D|0)>=0){na=D;break}yDb(e,16,2188840,(oa=i,i=i+1|0,i=i+7&-8,c[oa>>2]=0,oa)|0);i=oa;p=D;i=j;return p|0}}while(0);v=r0a(e,f,na,(na|0)<0|0?-1:0)|0;if((v|0)<0){p=v;i=j;return p|0}v=f+28|0;na=c[v>>2]|0;u=(na|0)<0;D=u?0:c[f+24>>2]|0;ma=u?0:na;c[n+24>>2]=ma<<3;na=n+12|0;c[na>>2]=D;c[n+20>>2]=D+ma;ma=n+16|0;c[ma>>2]=D;u=n+8|0;O=n+4|0;l=n+4203844|0;la=n+36|0;ka=c[l>>2]<<4|c[la>>2]|16775168;c[O>>2]=ka;c[u>>2]=8;ia=c[n+4203856>>2]|0;if((ia|0)==0){pa=(c[t>>2]|0)-1|ka<<4}else{pa=ka<<4|ia+7}ia=D;x=fe((c[n+44>>2]|pa<<3)<<1|0)|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=(c[ma>>2]|0)+4|0;c[ma>>2]=ia;c[O>>2]=0;c[u>>2]=32;pa=n+64|0;D=c[pa>>2]|0;do{if(D>>>0<128>>>0){ka=D&255;c[O>>2]=ka;c[u>>2]=24;qa=ka;ra=24;sa=ia}else{ka=D>>>0>65535>>>0;ja=ka?D>>>16:D;ha=ka?16:0;if((ja&65280|0)==0){ta=ha;ua=ja}else{ta=ha|8;ua=ja>>>8}ja=(ta+4+(d[1191992+ua|0]|0)|0)/5|0;ha=(ja*6|0)-6|0;ka=(D>>>(ha>>>0)|256-(256>>>(ja>>>0)))&255;c[O>>2]=ka;c[u>>2]=24;if((ha|0)>5){va=ha;wa=ka;xa=24;ya=ia}else{qa=ka;ra=24;sa=ia;break}while(1){ka=va-6|0;ha=D>>>(ka>>>0)&63|128;if((xa|0)>8){za=xa-8|0;Aa=ha|wa<<8;Ba=ya}else{ja=ya;x=fe(ha>>>((8-xa|0)>>>0)|wa<<xa|0)|0;a[ja]=x;x=x>>8;a[ja+1|0]=x;x=x>>8;a[ja+2|0]=x;x=x>>8;a[ja+3|0]=x;ja=(c[ma>>2]|0)+4|0;c[ma>>2]=ja;za=xa+24|0;Aa=ha;Ba=ja}c[O>>2]=Aa;c[u>>2]=za;if((ka|0)>5){va=ka;wa=Aa;xa=za;ya=Ba}else{qa=Aa;ra=za;sa=Ba;break}}}}while(0);Ba=c[l>>2]|0;if((Ba|0)==7){l=c[n+4203848>>2]|0;if((ra|0)>16){Ca=ra-16|0;Da=l|qa<<16;Ea=sa}else{za=sa;x=fe(l>>>((16-ra|0)>>>0)|qa<<ra|0)|0;a[za]=x;x=x>>8;a[za+1|0]=x;x=x>>8;a[za+2|0]=x;x=x>>8;a[za+3|0]=x;za=(c[ma>>2]|0)+4|0;c[ma>>2]=za;Ca=ra+16|0;Da=l;Ea=za}c[O>>2]=Da;c[u>>2]=Ca;Fa=Da;Ga=Ca;Ha=Ea}else if((Ba|0)==6){Ba=c[n+4203848>>2]|0;if((ra|0)>8){Ia=ra-8|0;Ja=Ba|qa<<8;Ka=sa}else{Ea=sa;x=fe(Ba>>>((8-ra|0)>>>0)|qa<<ra|0)|0;a[Ea]=x;x=x>>8;a[Ea+1|0]=x;x=x>>8;a[Ea+2|0]=x;x=x>>8;a[Ea+3|0]=x;Ea=(c[ma>>2]|0)+4|0;c[ma>>2]=Ea;Ia=ra+24|0;Ja=Ba;Ka=Ea}c[O>>2]=Ja;c[u>>2]=Ia;Fa=Ja;Ga=Ia;Ha=Ka}else{Fa=qa;Ga=ra;Ha=sa}sa=c[la>>2]|0;do{if((sa|0)==12){la=c[n+40>>2]|0;if((Ga|0)>8){La=Ga-8|0;Ma=la|Fa<<8;Na=Ha}else{ra=Ha;x=fe(la>>>((8-Ga|0)>>>0)|Fa<<Ga|0)|0;a[ra]=x;x=x>>8;a[ra+1|0]=x;x=x>>8;a[ra+2|0]=x;x=x>>8;a[ra+3|0]=x;ra=(c[ma>>2]|0)+4|0;c[ma>>2]=ra;La=Ga+24|0;Ma=la;Na=ra}c[O>>2]=Ma;c[u>>2]=La;Oa=La;Pa=Ma;Qa=Na}else{if((sa|0)<=12){Oa=Ga;Pa=Fa;Qa=Ha;break}ra=c[n+40>>2]|0;if((Ga|0)>16){Ra=Ga-16|0;Sa=ra|Fa<<16;Ta=Ha}else{la=Ha;x=fe(ra>>>((16-Ga|0)>>>0)|Fa<<Ga|0)|0;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;la=(c[ma>>2]|0)+4|0;c[ma>>2]=la;Ra=Ga+16|0;Sa=ra;Ta=la}c[O>>2]=Sa;c[u>>2]=Ra;Oa=Ra;Pa=Sa;Qa=Ta}}while(0);do{if((Oa|0)<32){Ta=Pa<<Oa;c[O>>2]=Ta;c[ma>>2]=Qa+1;a[Qa]=Ta>>>24;Ta=c[O>>2]|0;c[O>>2]=Ta<<8;Sa=(c[u>>2]|0)+8|0;c[u>>2]=Sa;if((Sa|0)>=32){break}Sa=Ta>>>16&255;while(1){Ta=c[ma>>2]|0;c[ma>>2]=Ta+1;a[Ta]=Sa;Ta=c[O>>2]|0;c[O>>2]=Ta<<8;Ra=(c[u>>2]|0)+8|0;c[u>>2]=Ra;if((Ra|0)<32){Sa=Ta>>>16&255}else{break}}}}while(0);c[u>>2]=32;c[O>>2]=0;Qa=tBb(0)|0;Oa=c[na>>2]|0;Pa=c[u>>2]|0;Sa=c[ma>>2]|0;Ta=uBb(Qa,0,Oa,32-Pa+(Sa-Oa<<3)>>3)|0;Oa=c[O>>2]|0;if((Pa|0)>8){Ua=Pa-8|0;Va=Oa<<8|Ta;Wa=Sa}else{Qa=Sa;x=fe(Oa<<Pa|Ta>>>((8-Pa|0)>>>0)|0)|0;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;Qa=(c[ma>>2]|0)+4|0;c[ma>>2]=Qa;Ua=Pa+24|0;Va=Ta;Wa=Qa}c[O>>2]=Va;c[u>>2]=Ua;if((c[t>>2]|0)>0){Qa=n+4203880|0;Ta=0;Pa=Va;Oa=Ua;Sa=Wa;while(1){Ra=o+96+(Ta*525468|0)+263324|0;Ga=c[s>>2]|0;Fa=o+96+(Ta*525468|0)+263324+(Ga<<2)|0;if((Oa|0)>1){Xa=Oa-1|0;Ya=Pa<<1;Za=Sa}else{Ha=Sa;x=fe(Pa<<Oa|0)|0;a[Ha]=x;x=x>>8;a[Ha+1|0]=x;x=x>>8;a[Ha+2|0]=x;x=x>>8;a[Ha+3|0]=x;Ha=(c[ma>>2]|0)+4|0;c[ma>>2]=Ha;Xa=Oa+31|0;Ya=0;Za=Ha}c[O>>2]=Ya;c[u>>2]=Xa;Ha=c[o+96+(Ta*525468|0)+4>>2]|0;if((Xa|0)>6){_a=Xa-6|0;$a=Ha|Ya<<6;ab=Za}else{sa=Za;x=fe(Ha>>>((6-Xa|0)>>>0)|Ya<<Xa|0)|0;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;sa=(c[ma>>2]|0)+4|0;c[ma>>2]=sa;_a=Xa+26|0;$a=Ha;ab=sa}c[O>>2]=$a;c[u>>2]=_a;sa=o+96+(Ta*525468|0)+12|0;Ha=(c[sa>>2]|0)!=0|0;if((_a|0)>1){bb=_a-1|0;cb=Ha|$a<<1;db=ab}else{Na=ab;x=fe(Ha>>>((1-_a|0)>>>0)|$a<<_a|0)|0;a[Na]=x;x=x>>8;a[Na+1|0]=x;x=x>>8;a[Na+2|0]=x;x=x>>8;a[Na+3|0]=x;Na=(c[ma>>2]|0)+4|0;c[ma>>2]=Na;bb=_a+31|0;cb=Ha;db=Na}c[O>>2]=cb;c[u>>2]=bb;Na=c[sa>>2]|0;if((Na|0)==0){eb=cb;fb=bb;gb=db}else{if((bb|0)>(Na|0)){hb=bb;ib=cb<<Na|1;jb=db}else{sa=db;x=fe(1>>>((Na-bb|0)>>>0)|cb<<bb|0)|0;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;sa=(c[ma>>2]|0)+4|0;c[ma>>2]=sa;hb=bb+32|0;ib=1;jb=sa}sa=hb-Na|0;c[O>>2]=ib;c[u>>2]=sa;eb=ib;fb=sa;gb=jb}sa=o+96+(Ta*525468|0)|0;Na=c[sa>>2]|0;do{if((Na|0)==1){if((Ga|0)<=0){kb=eb;lb=fb;mb=gb;break}Ha=o+96+(Ta*525468|0)+8|0;Ma=Ra;La=eb;la=fb;ra=gb;while(1){qa=c[Ha>>2]|0;Ka=Ma+4|0;Ia=(1<<qa)-1&c[Ma>>2];if((la|0)>(qa|0)){nb=la;ob=Ia|La<<qa;pb=ra}else{Ja=ra;x=fe(Ia>>>((qa-la|0)>>>0)|La<<la|0)|0;a[Ja]=x;x=x>>8;a[Ja+1|0]=x;x=x>>8;a[Ja+2|0]=x;x=x>>8;a[Ja+3|0]=x;Ja=(c[ma>>2]|0)+4|0;c[ma>>2]=Ja;nb=la+32|0;ob=Ia;pb=Ja}Ja=nb-qa|0;c[O>>2]=ob;c[u>>2]=Ja;if(Ka>>>0<Fa>>>0){Ma=Ka;La=ob;la=Ja;ra=pb}else{kb=ob;lb=Ja;mb=pb;break}}}else if((Na|0)==0){ra=c[o+96+(Ta*525468|0)+8>>2]|0;la=(1<<ra)-1&c[Ra>>2];if((fb|0)>(ra|0)){qb=fb;rb=la|eb<<ra;sb=gb}else{La=gb;x=fe(la>>>((ra-fb|0)>>>0)|eb<<fb|0)|0;a[La]=x;x=x>>8;a[La+1|0]=x;x=x>>8;a[La+2|0]=x;x=x>>8;a[La+3|0]=x;La=(c[ma>>2]|0)+4|0;c[ma>>2]=La;qb=fb+32|0;rb=la;sb=La}La=qb-ra|0;c[O>>2]=rb;c[u>>2]=La;kb=rb;lb=La;mb=sb}else{La=o+96+(Ta*525468|0)+16|0;if((c[La>>2]|0)>0){ra=o+96+(Ta*525468|0)+8|0;la=Ra;Ma=0;Ha=eb;k=fb;Ja=gb;while(1){Ka=c[ra>>2]|0;tb=la+4|0;qa=(1<<Ka)-1&c[la>>2];if((k|0)>(Ka|0)){ub=k;vb=qa|Ha<<Ka;wb=Ja}else{Ia=Ja;x=fe(qa>>>((Ka-k|0)>>>0)|Ha<<k|0)|0;a[Ia]=x;x=x>>8;a[Ia+1|0]=x;x=x>>8;a[Ia+2|0]=x;x=x>>8;a[Ia+3|0]=x;Ia=(c[ma>>2]|0)+4|0;c[ma>>2]=Ia;ub=k+32|0;vb=qa;wb=Ia}xb=ub-Ka|0;c[O>>2]=vb;c[u>>2]=xb;Ka=Ma+1|0;if((Ka|0)<(c[La>>2]|0)){la=tb;Ma=Ka;Ha=vb;k=xb;Ja=wb}else{break}}yb=tb;zb=c[sa>>2]|0;Ab=vb;Bb=xb;Cb=wb}else{yb=Ra;zb=Na;Ab=eb;Bb=fb;Cb=gb}do{if((zb|0)==32){Ja=c[Qa>>2]|0;k=Ja-1|0;if((Bb|0)>4){Db=Bb-4|0;Eb=k|Ab<<4;Fb=Cb}else{Ha=Cb;x=fe(k>>>((4-Bb|0)>>>0)|Ab<<Bb|0)|0;a[Ha]=x;x=x>>8;a[Ha+1|0]=x;x=x>>8;a[Ha+2|0]=x;x=x>>8;a[Ha+3|0]=x;Ha=(c[ma>>2]|0)+4|0;c[ma>>2]=Ha;Db=Bb+28|0;Eb=k;Fb=Ha}c[O>>2]=Eb;c[u>>2]=Db;Ha=c[o+96+(Ta*525468|0)+148>>2]&31;if((Db|0)>5){Gb=Db-5|0;Hb=Ha|Eb<<5;Ib=Fb}else{k=Fb;x=fe(Ha>>>((5-Db|0)>>>0)|Eb<<Db|0)|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=(c[ma>>2]|0)+4|0;c[ma>>2]=k;Gb=Db+27|0;Hb=Ha;Ib=k}c[O>>2]=Hb;c[u>>2]=Gb;if((c[La>>2]|0)<=0){Jb=Hb;Kb=Gb;Lb=Ib;break}k=(1<<Ja)-1|0;Ha=32-Ja|0;Ma=0;la=Hb;ra=Gb;Ka=Ib;while(1){Ia=c[o+96+(Ta*525468|0)+20+(Ma<<2)>>2]&k;if((ra|0)>(Ja|0)){Mb=ra-Ja|0;Nb=Ia|la<<Ja;Ob=Ka}else{qa=Ka;x=fe(Ia>>>((Ja-ra|0)>>>0)|la<<ra|0)|0;a[qa]=x;x=x>>8;a[qa+1|0]=x;x=x>>8;a[qa+2|0]=x;x=x>>8;a[qa+3|0]=x;qa=(c[ma>>2]|0)+4|0;c[ma>>2]=qa;Mb=Ha+ra|0;Nb=Ia;Ob=qa}c[O>>2]=Nb;c[u>>2]=Mb;qa=Ma+1|0;if((qa|0)<(c[La>>2]|0)){Ma=qa;la=Nb;ra=Mb;Ka=Ob}else{Jb=Nb;Kb=Mb;Lb=Ob;break}}}else{Jb=Ab;Kb=Bb;Lb=Cb}}while(0);La=o+96+(Ta*525468|0)+152|0;Ka=(c[La>>2]|0)-4|0;if((Kb|0)>2){Pb=Kb-2|0;Qb=Ka|Jb<<2;Rb=Lb}else{ra=Lb;x=fe(Ka>>>((2-Kb|0)>>>0)|Jb<<Kb|0)|0;a[ra]=x;x=x>>8;a[ra+1|0]=x;x=x>>8;a[ra+2|0]=x;x=x>>8;a[ra+3|0]=x;ra=(c[ma>>2]|0)+4|0;c[ma>>2]=ra;Pb=Kb+30|0;Qb=Ka;Rb=ra}c[O>>2]=Qb;c[u>>2]=Pb;ra=c[o+96+(Ta*525468|0)+156>>2]|0;Ka=c[s>>2]>>ra;if((Pb|0)>4){Sb=Pb-4|0;Tb=ra|Qb<<4;Ub=Rb}else{la=Rb;x=fe(ra>>>((4-Pb|0)>>>0)|Qb<<Pb|0)|0;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;la=(c[ma>>2]|0)+4|0;c[ma>>2]=la;Sb=Pb+28|0;Tb=ra;Ub=la}c[O>>2]=Tb;c[u>>2]=Sb;la=1<<ra;if((la|0)<=0){kb=Tb;lb=Sb;mb=Ub;break}ra=o+96+(Ta*525468|0)+263324+(Ka<<2)|0;Ma=yb;Ha=0;Ja=Tb;k=Sb;qa=Ub;while(1){Ia=c[o+96+(Ta*525468|0)+160+(Ha<<2)>>2]|0;Ea=c[La>>2]|0;if((k|0)>(Ea|0)){Vb=k;Wb=Ja<<Ea|Ia;Xb=qa}else{Ba=qa;x=fe(Ia>>>((Ea-k|0)>>>0)|Ja<<k|0)|0;a[Ba]=x;x=x>>8;a[Ba+1|0]=x;x=x>>8;a[Ba+2|0]=x;x=x>>8;a[Ba+3|0]=x;Ba=(c[ma>>2]|0)+4|0;c[ma>>2]=Ba;Vb=k+32|0;Wb=Ia;Xb=Ba}Ba=Vb-Ea|0;c[O>>2]=Wb;c[u>>2]=Ba;if(Ma>>>0<ra>>>0){Ea=(Ia|0)==0;Ca=(1<<Ia)-1|0;Da=32-Ia|0;za=Ma;l=Wb;Aa=Ba;ya=Xb;while(1){xa=za+4|0;wa=((c[za>>2]|0)*-2|0)-1|0;va=wa>>31^wa;wa=va>>Ia;D=wa+1|0;do{if((D|0)==2147483647){ia=2147483647;ua=l;ta=Aa;ka=ya;while(1){if((ta|0)>31){Yb=ta-31|0;Zb=ua<<31;_b=ka}else{ja=ka;x=fe(ua<<ta|0)|0;a[ja]=x;x=x>>8;a[ja+1|0]=x;x=x>>8;a[ja+2|0]=x;x=x>>8;a[ja+3|0]=x;ja=(c[ma>>2]|0)+4|0;c[ma>>2]=ja;Yb=ta+1|0;Zb=0;_b=ja}c[O>>2]=Zb;c[u>>2]=Yb;ja=ia-31|0;if((ja|0)>31){ia=ja;ua=Zb;ta=Yb;ka=_b}else{break}}if((Yb|0)>1){$b=Yb-1|0;ac=_b}else{ka=_b;x=fe(1>>>((1-Yb|0)>>>0)|Zb<<Yb|0)|0;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;ka=(c[ma>>2]|0)+4|0;c[ma>>2]=ka;$b=Yb+31|0;ac=ka}c[O>>2]=1;c[u>>2]=$b;ka=va-1|0;if(($b|0)>0){bc=$b;cc=ka|1;dc=ac}else{ta=ac;x=fe(1<<$b|ka>>>((-$b|0)>>>0)|0)|0;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;ta=(c[ma>>2]|0)+4|0;c[ma>>2]=ta;bc=$b+32|0;cc=ka;dc=ta}c[O>>2]=cc;c[u>>2]=bc;ec=cc;fc=bc;gc=dc}else{if((D|0)>31){ta=D;ka=l;ua=Aa;ia=ya;while(1){if((ua|0)>31){hc=ua-31|0;ic=ka<<31;jc=ia}else{ja=ia;x=fe(ka<<ua|0)|0;a[ja]=x;x=x>>8;a[ja+1|0]=x;x=x>>8;a[ja+2|0]=x;x=x>>8;a[ja+3|0]=x;ja=(c[ma>>2]|0)+4|0;c[ma>>2]=ja;hc=ua+1|0;ic=0;jc=ja}c[O>>2]=ic;c[u>>2]=hc;ja=ta-31|0;if((ja|0)>31){ta=ja;ka=ic;ua=hc;ia=jc}else{break}}kc=(((wa-31|0)>>>0)%31|0)+1|0;lc=ic;mc=hc;nc=jc}else{kc=D;lc=l;mc=Aa;nc=ya}if((mc|0)>(kc|0)){oc=mc;pc=lc<<kc|1;qc=nc}else{ia=nc;x=fe(1>>>((kc-mc|0)>>>0)|lc<<mc|0)|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=(c[ma>>2]|0)+4|0;c[ma>>2]=ia;oc=mc+32|0;pc=1;qc=ia}ia=oc-kc|0;c[O>>2]=pc;c[u>>2]=ia;if(Ea){ec=pc;fc=ia;gc=qc;break}ua=va&Ca;if((ia|0)>(Ia|0)){rc=ia-Ia|0;sc=pc<<Ia|ua;tc=qc}else{ka=qc;x=fe(ua>>>((Ia-ia|0)>>>0)|pc<<ia|0)|0;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;ka=(c[ma>>2]|0)+4|0;c[ma>>2]=ka;rc=Da+ia|0;sc=ua;tc=ka}c[O>>2]=sc;c[u>>2]=rc;ec=sc;fc=rc;gc=tc}}while(0);if(xa>>>0<ra>>>0){za=xa;l=ec;Aa=fc;ya=gc}else{uc=xa;vc=ec;wc=fc;xc=gc;break}}}else{uc=Ma;vc=Wb;wc=Ba;xc=Xb}ya=ra+(Ka<<2)|0;Aa=Ha+1|0;if((Aa|0)<(la|0)){ra=Fa>>>0>ya>>>0?ya:Fa;Ma=uc;Ha=Aa;Ja=vc;k=wc;qa=xc}else{kb=vc;lb=wc;mb=xc;break}}}}while(0);Fa=Ta+1|0;if((Fa|0)<(c[t>>2]|0)){Ta=Fa;Pa=kb;Oa=lb;Sa=mb}else{yc=lb;zc=kb;Ac=mb;break}}}else{yc=Ua;zc=Va;Ac=Wa}do{if((yc|0)<32){Wa=zc<<yc;c[O>>2]=Wa;c[ma>>2]=Ac+1;a[Ac]=Wa>>>24;Wa=c[O>>2]|0;c[O>>2]=Wa<<8;Va=(c[u>>2]|0)+8|0;c[u>>2]=Va;if((Va|0)>=32){break}Va=Wa>>>16&255;while(1){Wa=c[ma>>2]|0;c[ma>>2]=Wa+1;a[Wa]=Va;Wa=c[O>>2]|0;c[O>>2]=Wa<<8;Ua=(c[u>>2]|0)+8|0;c[u>>2]=Ua;if((Ua|0)<32){Va=Wa>>>16&255}else{break}}}}while(0);c[u>>2]=32;c[O>>2]=0;Ac=tBb(1)|0;yc=c[na>>2]|0;zc=c[u>>2]|0;Va=c[ma>>2]|0;Wa=(de((uBb(Ac,0,yc,32-zc+(Va-yc<<3)>>3)|0)&65535|0)|0)&65535;yc=c[O>>2]|0;if((zc|0)>16){Bc=zc-16|0;Cc=yc<<16|Wa;Dc=Va}else{Ac=Va;x=fe(Wa>>>((16-zc|0)>>>0)|yc<<zc|0)|0;a[Ac]=x;x=x>>8;a[Ac+1|0]=x;x=x>>8;a[Ac+2|0]=x;x=x>>8;a[Ac+3|0]=x;Ac=(c[ma>>2]|0)+4|0;c[ma>>2]=Ac;Bc=zc+16|0;Cc=Wa;Dc=Ac}c[O>>2]=Cc;c[u>>2]=Bc;if((Bc|0)<32){Ac=Cc<<Bc;c[O>>2]=Ac;c[ma>>2]=Dc+1;a[Dc]=Ac>>>24;Ac=c[O>>2]|0;c[O>>2]=Ac<<8;Bc=(c[u>>2]|0)+8|0;c[u>>2]=Bc;if((Bc|0)<32){Bc=Ac>>>16&255;while(1){Ac=c[ma>>2]|0;c[ma>>2]=Ac+1;a[Ac]=Bc;Ac=c[O>>2]|0;c[O>>2]=Ac<<8;Cc=(c[u>>2]|0)+8|0;c[u>>2]=Cc;if((Cc|0)<32){Bc=Ac>>>16&255}else{break}}}Ec=c[ma>>2]|0}else{Ec=Dc}c[u>>2]=32;c[O>>2]=0;O=Ec-(c[na>>2]|0)<<3>>3;c[pa>>2]=(c[pa>>2]|0)+1;pa=c[q>>2]|0;na=n+72|0;Ec=YGb(c[na>>2]|0,c[na+4>>2]|0,pa,(pa|0)<0|0?-1:0)|0;c[na>>2]=Ec;c[na+4>>2]=F;na=c[w>>2]|0;w=ba(c[t>>2]|0,c[s>>2]|0)|0;Ec=c[(c[r>>2]|0)+796>>2]|0;pa=ba(w,(Ec+7|0)/8|0)|0;do{if((Ec|0)>16){w=n+4203944|0;u=w;kEb(w,n+4203948|0,pa);w=c[u>>2]|0;if((w|0)==0){yDb(e,16,2111720,(oa=i,i=i+1|0,i=i+7&-8,c[oa>>2]=0,oa)|0);i=oa;p=-12;i=j;return p|0}if((c[(c[r>>2]|0)+796>>2]|0)<17){Fc=na;break}Dc=na;if((ba(c[t>>2]|0,c[s>>2]|0)|0)>0){Gc=0;Hc=w}else{Fc=w;break}while(1){w=c[Dc+(Gc<<2)>>2]|0;a[Hc]=w>>>8;a[Hc+1|0]=w>>>16;a[Hc+2|0]=w>>>24;w=Gc+1|0;if((w|0)<(ba(c[t>>2]|0,c[s>>2]|0)|0)){Gc=w;Hc=Hc+3|0}else{break}}Fc=c[u>>2]|0}else{Fc=na}}while(0);RDb(c[n+4203940>>2]|0,Fc,pa);pa=n+60|0;if((O|0)>(c[pa>>2]|0)){c[pa>>2]=O}pa=n+52|0;if((O|0)<(c[pa>>2]|0)){c[pa>>2]=O}pa=g+136|0;g=c[pa+4>>2]|0;n=f+8|0;c[n>>2]=c[pa>>2];c[n+4>>2]=g;g=c[q>>2]|0;c[m>>2]=1;c[m+4>>2]=c[e+412>>2];q=KDb(g,(g|0)<0|0?-1:0,m,e+104|0)|0;c[f+48>>2]=q;c[v>>2]=O;c[h>>2]=1;p=0;i=j;return p|0}function Jaa(a){a=a|0;var b=0;b=c[a+60>>2]|0;if((b|0)!=0){$Db(b+4203940|0);$Db(b+4203944|0);EKa(b+4203912|0)}$Db(a+96|0);c[a+100>>2]=0;return 0}function Kaa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;TGb(d|0,0,34)|0;f=c[b+48>>2]|0;g=d;x=fe(f|f<<16|0)|0;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;g=c[b+56>>2]|0;f=d+4|0;x=fe(g>>>16|c[b+52>>2]<<8|0)|0;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;f=c[b+32>>2]|0;h=d+8|0;x=fe(f>>>4|g<<16|0)|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=b+72|0;g=c[h>>2]|0;j=d+12|0;x=fe((g>>>16|c[h+4>>2]<<16)&1048575|((c[(c[b+4203908>>2]|0)+796>>2]|0)+4095|((c[b+28>>2]|0)+127|f<<3)<<5)<<20|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=c[h>>2]&4095|g&-4096;g=j<<16;h=j>>>8&255;j=16;f=d+16|0;while(1){a[f]=h;k=g;g=k<<8;l=j+8|0;if((l|0)<32){h=k>>>16&255;j=l;f=f+1|0}else{break}}UGb(d+18|0,b+80|0,16)|0;i=e;return}function Laa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;b=i;i=i+4840|0;e=b|0;f=b+4096|0;g=b+4224|0;h=b+4264|0;j=b+4328|0;k=b+4584|0;l=c[a+64>>2]|0;if(l>>>0<128>>>0){m=40}else{n=l>>>0>65535>>>0;o=n?l>>>16:l;l=n?16:0;if((o&65280|0)==0){p=l;q=o}else{p=l|8;q=o>>>8}o=((p+4+(d[1191992+q|0]|0)|0)/5|0)*6|0;q=40;while(1){p=o-6|0;if((p|0)>5){o=p;q=q+8|0}else{m=q;break}}}q=c[a+4203844>>2]|0;if((q|0)==7){r=m+16|0}else if((q|0)==6){r=m+8|0}else{r=m}m=c[a+36>>2]|0;q=r+8+(((m|0)==12)+((m|0)>12)<<3)|0;m=q;r=(q|0)<0|0?-1:0;q=a+28|0;if((c[q>>2]|0)>0){o=k;p=a+4203840|0;l=a+4203860|0;n=a+4203884|0;s=a+4203888|0;t=a+4203892|0;u=a+4203872|0;v=a+4203912|0;w=a+4203880|0;x=e|0;y=f|0;z=a+4203876|0;A=a+4205216|0;B=j|0;C=g|0;D=0;E=r;G=m;while(1){H=a+96+(D*525468|0)|0;I=a+96+(D*525468|0)+263324|0;J=a+96+(D*525468|0)+1184|0;K=c[p>>2]|0;L=1;while(1){if((L|0)>=(K|0)){break}if((c[a+96+(D*525468|0)+1184+(L<<2)>>2]|0)==(c[J>>2]|0)){L=L+1|0}else{break}}do{if((L|0)==(K|0)){c[a+96+(D*525468|0)+4>>2]=0;c[H>>2]=0;c[I>>2]=c[J>>2];M=Maa(a,H,0)|0;N=M}else{if((c[l>>2]|0)!=0|(K|0)<5){c[a+96+(D*525468|0)+4>>2]=1;c[H>>2]=1;UGb(I|0,J|0,K<<2)|0;M=Maa(a,H,0)|0;N=M;break}M=c[n>>2]|0;O=c[s>>2]|0;P=c[t>>2]|0;Q=H|0;c[Q>>2]=8;if(!((c[u>>2]|0)>>>0>1>>>0&(K|0)>(O|0))){R=(O|0)>4?4:O;c[C>>2]=-1;c[C+4>>2]=0;if((M|0)>(R|0)){S=0;T=8}else{U=0;V=M;do{Naa(I,J,K,V);W=Oaa(a,H,V)|0;X=F;Y=g+(V<<3)|0;c[Y>>2]=W;c[Y+4>>2]=X;Y=g+(U<<3)|0;Z=c[Y+4>>2]|0;U=X>>>0<Z>>>0|X>>>0==Z>>>0&W>>>0<(c[Y>>2]|0)>>>0?V:U;V=V+1|0;}while((V|0)<=(R|0));S=U;T=c[Q>>2]|0}V=a+96+(D*525468|0)+16|0;c[V>>2]=S;c[a+96+(D*525468|0)+4>>2]=S|T;if((S|0)==(R|0)){_=R}else{Naa(I,J,K,S);Oaa(a,H,c[V>>2]|0)|0;_=c[V>>2]|0}V=Maa(a,H,_)|0;N=V;break}c[Q>>2]=32;V=DKa(v,J,K,M,O,c[w>>2]|0,x,y,c[u>>2]|0,c[z>>2]|0,P,15,0)|0;do{if((P-1|0)>>>0<3>>>0){Y=1<<P;W=Y-1|0;Z=O-1|0;X=h+(W<<3)|0;c[X>>2]=-1;c[X+4>>2]=0;if((Y|0)>0){X=1-M+O|0;$=M-1|0;aa=Z;ca=-1;da=W;ea=W;while(1){W=((ba(ea+1|0,X)|0)/(Y|0)|0)+$|0;if((W|0)<($|0)){fa=$}else{fa=(W|0)>(Z|0)?Z:W}if((fa|0)==(ca|0)){ga=da;ha=aa}else{W=fa+1|0;Se[c[A>>2]&511](I,J,K,W,e+(fa<<7)|0,c[f+(fa<<2)>>2]|0);ia=Oaa(a,H,W)|0;W=F;ja=h+(ea<<3)|0;c[ja>>2]=ia;c[ja+4>>2]=W;ja=h+(da<<3)|0;ka=c[ja+4>>2]|0;la=W>>>0<ka>>>0|W>>>0==ka>>>0&ia>>>0<(c[ja>>2]|0)>>>0;ga=la?ea:da;ha=la?fa:aa}if((ea|0)>0){aa=ha;ca=fa;da=ga;ea=ea-1|0}else{ma=ha;break}}}else{ma=Z}na=ma+1|0}else{if((P|0)==4){c[B>>2]=-1;c[B+4>>2]=0;ea=M-1|0;if((ea|0)<(O|0)){oa=0;pa=ea}else{na=1;break}while(1){ea=pa+1|0;Se[c[A>>2]&511](I,J,K,ea,e+(pa<<7)|0,c[f+(pa<<2)>>2]|0);da=Oaa(a,H,ea)|0;ca=F;aa=j+(pa<<3)|0;c[aa>>2]=da;c[aa+4>>2]=ca;aa=j+(oa<<3)|0;$=c[aa+4>>2]|0;qa=ca>>>0<$>>>0|ca>>>0==$>>>0&da>>>0<(c[aa>>2]|0)>>>0?pa:oa;if((ea|0)<(O|0)){oa=qa;pa=ea}else{break}}na=qa+1|0;break}else if((P|0)!=5){na=V;break}Z=M-1|0;TGb(o|0,-1|0,256)|0;ea=((O-M|0)/3|0)+Z|0;aa=16;while(1){da=ea-aa|0;$=ea+aa|0;if((da|0)>($|0)){ra=ea}else{ca=ea;Y=da;while(1){do{if((Y|0)>=(Z|0)&(Y|0)<(O|0)){da=k+(Y<<3)|0;X=c[da+4>>2]|0;la=0;if(X>>>0<la>>>0|X>>>0==la>>>0&(c[da>>2]|0)>>>0<-1>>>0){sa=ca;break}la=Y+1|0;Se[c[A>>2]&511](I,J,K,la,e+(Y<<7)|0,c[f+(Y<<2)>>2]|0);X=Oaa(a,H,la)|0;la=F;c[da>>2]=X;c[da+4>>2]=la;da=k+(ca<<3)|0;ja=c[da+4>>2]|0;sa=la>>>0<ja>>>0|la>>>0==ja>>>0&X>>>0<(c[da>>2]|0)>>>0?Y:ca}else{sa=ca}}while(0);da=Y+aa|0;if((da|0)>($|0)){ra=sa;break}else{ca=sa;Y=da}}}Y=aa>>1;if((Y|0)==0){break}else{ea=ra;aa=Y}}na=ra+1|0}}while(0);O=a+96+(D*525468|0)+16|0;c[O>>2]=na;M=na-1|0;c[a+96+(D*525468|0)+4>>2]=c[Q>>2]|M;V=c[f+(M<<2)>>2]|0;M=a+96+(D*525468|0)+148|0;c[M>>2]=V;if((na|0)>0){P=0;R=na;do{c[a+96+(D*525468|0)+20+(P<<2)>>2]=c[e+(R-1<<7)+(P<<2)>>2];P=P+1|0;R=c[O>>2]|0;}while((P|0)<(R|0));ta=R;ua=c[M>>2]|0}else{ta=na;ua=V}Se[c[A>>2]&511](I,J,K,ta,a+96+(D*525468|0)+20|0,ua);Oaa(a,H,c[O>>2]|0)|0;P=Maa(a,H,c[O>>2]|0)|0;N=P}}while(0);H=YGb(N,(N|0)<0|0?-1:0,G,E)|0;K=F;J=D+1|0;if((J|0)<(c[q>>2]|0)){D=J;E=K;G=H}else{va=K;wa=H;break}}}else{va=r;wa=m}m=ZGb(0,0,wa,va)|0;r=F&0;G=YGb(wa,va,16,0)|0;va=YGb(G,F,m&7,r)|0;r=F;m=3;if(r>>>0>m>>>0|r>>>0==m>>>0&va>>>0>-1>>>0){xa=-558323010;i=b;return xa|0}xa=va>>>3|r<<29;i=b;return xa|0}function Maa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=c[b>>2]|0;if((e|0)==1){f=ba(c[b+8>>2]|0,c[a+4203840>>2]|0)|0;g=YGb(f,(f|0)<0|0?-1:0,8,0)|0;h=F;i=g;return(F=h,i)|0}else if((e|0)==0){g=c[b+8>>2]|0;f=YGb(g,(g|0)<0|0?-1:0,8,0)|0;h=F;i=f;return(F=h,i)|0}else{f=ba(c[b+8>>2]|0,d)|0;g=YGb(f,(f|0)<0|0?-1:0,8,0)|0;f=F;if((e|0)==32){e=(ba(c[a+4203880>>2]|0,d)|0)+9|0;j=YGb(e,(e|0)<0|0?-1:0,g,f)|0;k=F;l=j}else{k=f;l=g}g=c[b+156>>2]|0;f=c[a+4203840>>2]|0;a=f>>g;j=YGb(l,k,6,0)|0;k=F;l=1<<g;if((l|0)<=0){h=k;i=j;return(F=h,i)|0}g=c[b+152>>2]|0;e=0;m=d;d=a;n=k;k=j;j=0;while(1){o=c[b+160+(j<<2)>>2]|0;p=YGb(g,e,k,n)|0;q=F;r=d-m|0;if((r|0)>0){s=o+1|0;t=0;u=0;v=0;while(1){w=((c[b+263324+(v+m<<2)>>2]|0)*-2|0)-1|0;x=s+((w>>31^w)>>o)|0;w=YGb(x,(x|0)<0|0?-1:0,u,t)|0;x=F;y=v+1|0;if((y|0)<(r|0)){t=x;u=w;v=y}else{z=x;A=w;break}}}else{z=0;A=0}v=YGb(p,q,A,z)|0;u=F;t=d+a|0;r=j+1|0;if((r|0)<(l|0)){m=d;d=(f|0)>(t|0)?t:f;n=u;k=v;j=r}else{h=u;i=v;break}}return(F=h,i)|0}return 0}function Naa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((e|0)>0){f=0;do{c[a+(f<<2)>>2]=c[b+(f<<2)>>2];f=f+1|0;}while((f|0)<(e|0))}if((e|0)==2){if((d|0)<=2){return}f=(c[b+4>>2]|0)-(c[b>>2]|0)|0;g=2;do{h=b+(g<<2)|0;i=(c[h>>2]|0)-(c[b+(g-1<<2)>>2]|0)|0;c[a+(g<<2)>>2]=i-f;j=g|1;f=(c[b+(j<<2)>>2]|0)-(c[h>>2]|0)|0;c[a+(j<<2)>>2]=f-i;g=g+2|0;}while((g|0)<(d|0));return}else if((e|0)==1){if((d|0)>1){k=1}else{return}do{c[a+(k<<2)>>2]=(c[b+(k<<2)>>2]|0)-(c[b+(k-1<<2)>>2]|0);k=k+1|0;}while((k|0)<(d|0));return}else if((e|0)==0){if((d|0)>0){l=0}else{return}do{c[a+(l<<2)>>2]=c[b+(l<<2)>>2];l=l+1|0;}while((l|0)<(d|0));return}else{l=c[b+(e-1<<2)>>2]|0;k=c[b+(e-2<<2)>>2]|0;g=l-k|0;f=c[b+(e-3<<2)>>2]|0;i=l-(k<<1)+f|0;if((e|0)==3){if((d|0)>3){m=i;n=g;o=3}else{return}do{j=b+(o<<2)|0;h=(c[j>>2]|0)-(c[b+(o-1<<2)>>2]|0)|0;p=h-n|0;c[a+(o<<2)>>2]=p-m;q=o+1|0;n=(c[b+(q<<2)>>2]|0)-(c[j>>2]|0)|0;m=n-h|0;c[a+(q<<2)>>2]=m-p;o=o+2|0;}while((o|0)<(d|0));return}if((e|0)>=(d|0)){return}o=g;g=i;i=l-(c[b+(e-4<<2)>>2]|0)+((f-k|0)*3|0)|0;k=e;e=l;while(1){l=b+(k<<2)|0;f=(c[l>>2]|0)-e|0;m=f-o|0;n=m-g|0;c[a+(k<<2)>>2]=n-i;p=k+1|0;q=b+(p<<2)|0;h=(c[q>>2]|0)-(c[l>>2]|0)|0;l=h-f|0;f=l-m|0;c[a+(p<<2)>>2]=f-n;n=k+2|0;if((n|0)>=(d|0)){break}o=h;g=l;i=f;k=n;e=c[q>>2]|0}return}}function Oaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;i=i+19544|0;g=f|0;h=f+72|0;j=f+1104|0;k=f+1112|0;l=c[a+4203896>>2]|0;m=c[a+4203840>>2]|0;n=m-1^m;o=n>>>0>65535>>>0;p=o?n>>>16:n;n=o?16:0;o=(p&65280|0)==0;if(o){q=n;r=p}else{q=n|8;r=p>>>8}s=(d[1191992+r|0]|0)+q|0;q=(s|0)<(l|0)?s:l;l=(e|0)>0;if(l){s=(m|0)/(e|0)|0;r=s>>>0>65535>>>0;t=r?s>>>16:s;s=r?16:0;if((t&65280|0)==0){u=s;v=t}else{u=s|8;v=t>>>8}t=(d[1191992+v|0]|0)+u|0;w=(q|0)>(t|0)?t:q}else{w=q}q=c[a+4203900>>2]|0;if(o){x=n;y=p}else{x=n|8;y=p>>>8}p=(d[1191992+y|0]|0)+x|0;x=(p|0)<(q|0)?p:q;if(l){l=(m|0)/(e|0)|0;q=l>>>0>65535>>>0;p=q?l>>>16:l;l=q?16:0;if((p&65280|0)==0){z=l;A=p}else{z=l|8;A=p>>>8}p=(d[1191992+A|0]|0)+z|0;B=(x|0)>(p|0)?p:x}else{B=x}x=(ba(c[b+8>>2]|0,e)|0)+10|0;p=b+152|0;z=c[p>>2]|0;A=x+z|0;x=0;if((c[b>>2]|0)==32){l=(ba(c[a+4203880>>2]|0,e)|0)+9|0;a=YGb(l,(l|0)<0|0?-1:0,A,x)|0;C=F;D=a}else{C=x;D=A}A=h;x=j;a=h|0;c[a>>2]=z;l=WDb(m<<2)|0;c[j>>2]=l;if((m|0)>0){j=0;do{q=c[b+263324+(j<<2)>>2]|0;c[l+(j<<2)>>2]=q<<1^q>>31;j=j+1|0;}while((j|0)<(m|0))}j=1<<B;b=m>>B;if((j|0)>0){q=0;y=l+(e<<2)|0;n=l;while(1){l=n+(b<<2)|0;if(y>>>0<l>>>0){o=y;t=0;u=0;while(1){v=o+4|0;s=YGb(c[o>>2]|0,0,u,t)|0;r=F;if(v>>>0<l>>>0){o=v;t=r;u=s}else{E=v;G=r;H=s;break}}}else{E=y;G=0;H=0}u=k+(B<<11)+(q<<3)|0;c[u>>2]=H;c[u+4>>2]=G;u=q+1|0;if((u|0)<(j|0)){q=u;y=E;n=l}else{break}}}n=B-1|0;if((n|0)>=(w|0)){E=B;y=n;while(1){n=1<<y;if((n|0)>0){q=0;do{j=q<<1;G=k+(E<<11)+(j<<3)|0;H=k+(E<<11)+((j|1)<<3)|0;j=YGb(c[H>>2]|0,c[H+4>>2]|0,c[G>>2]|0,c[G+4>>2]|0)|0;G=k+(y<<11)+(q<<3)|0;c[G>>2]=j;c[G+4>>2]=F;q=q+1|0;}while((q|0)<(n|0))}n=y-1|0;if((n|0)<(w|0)){break}else{E=y;y=n}}}y=g+(w<<3)|0;c[y>>2]=-1;c[y+4>>2]=0;if((w|0)>(B|0)){I=0;J=-1;$Db(x);K=YGb(J,I,D,C)|0;L=F;i=f;return(F=L,K)|0}y=h+4|0;E=p;p=w;n=w;w=z;while(1){z=(1<<w)-2|0;q=1<<p;l=q<<2;G=l;j=(l|0)<0|0?-1:0;l=m>>p;if((q|0)>0){H=l-e|0;b=0;u=j;t=G;while(1){o=k+(p<<11)+(b<<3)|0;s=c[o>>2]|0;r=c[o+4>>2]|0;o=H>>1;v=o;M=(o|0)<0|0?-1:0;o=ZGb(s,r,v,M)|0;N=F;if(M>>>0<r>>>0|M>>>0==r>>>0&v>>>0<s>>>0){s=hHb(o,N,H,(H|0)<0|0?-1:0)|0;v=F;r=YGb(s,v,-2147483648,0)|0;M=F;O=0;if(M>>>0>O>>>0|M>>>0==O>>>0&r>>>0>-1>>>0){((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1;P=(v>>31|((v|0)<0|0?-1:0)<<1)^2147483647}else{P=s}s=P>>>0>65535>>>0;v=s?P>>>16:P;r=s?16:0;if((v&65280|0)==0){Q=r;R=v}else{Q=r|8;R=v>>>8}v=(d[1191992+R|0]|0)+Q|0;S=(v|0)>(z|0)?z:v}else{S=0}c[h+8+(b<<2)>>2]=S;v=ba(S+1|0,H)|0;r=$Gb(o|0,N|0,S|0)|0;N=YGb(r,F,t,u)|0;r=YGb(N,F,v,(v|0)<0|0?-1:0)|0;v=F;N=b+1|0;if((N|0)<(q|0)){H=l;b=N;u=v;t=r}else{T=v;U=r;break}}}else{T=j;U=G}c[y>>2]=p;t=g+(p<<3)|0;c[t>>2]=U;c[t+4>>2]=T;t=g+(n<<3)|0;u=c[t+4>>2]|0;if(T>>>0>u>>>0|T>>>0==u>>>0&U>>>0>(c[t>>2]|0)>>>0){V=n}else{UGb(E|0,A|0,1032)|0;V=p}t=p+1|0;if((t|0)>(B|0)){break}p=t;n=V;w=c[a>>2]|0}a=g+(V<<3)|0;I=c[a+4>>2]|0;J=c[a>>2]|0;$Db(x);K=YGb(J,I,D,C)|0;L=F;i=f;return(F=L,K)|0}function Paa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+60|0;e=c[d>>2]|0;c[e>>2]=a;c[e+64>>2]=0;c[e+68>>2]=0;c[e+72>>2]=0;f=Qd(e+32|0,2145280,56)|0;if((f|0)!=0){yDb(a,16,2139416,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=1;i=b;return h|0}c[a+140>>2]=3;a=ICb()|0;c[e+4>>2]=a;if((a|0)!=0){h=0;i=b;return h|0}a=c[d>>2]|0;he(a+32|0)|0;JCb(a+4|0);$Db(a+24|0);h=-12;i=b;return h|0}function Qaa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0;h=i;i=i+112|0;j=h|0;k=h+56|0;l=g+28|0;m=c[l>>2]|0;n=b+60|0;o=c[n>>2]|0;p=o+16|0;q=c[p>>2]|0;r=o+20|0;s=c[r>>2]|0;if((m|0)==0){t=0;i=h;return t|0}if((m|0)<4){t=-1;i=h;return t|0}u=g+24|0;v=c[u>>2]|0;w=m>>>0>268435455>>>0?-8:m<<3;x=w>>>0>2147483639>>>0|(v|0)==0;y=x?0:v;v=x?0:w;w=v+8|0;if(x){t=x?-1094995529:0;i=h;return t|0}x=y;z=w>>>0>4>>>0?4:w;A=((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24)&240)+16|0;c[p>>2]=A;x=y+(z>>>3)|0;B=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&4)>>>20;x=z+12|0;z=w>>>0>x>>>0?x:w;x=o+8|0;c[x>>2]=B;B=y+(z>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7)>>>28;B=z+4|0;z=w>>>0>B>>>0?B:w;B=(C<<4)+16|0;c[r>>2]=B;C=y+(z>>>3)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(z&7)>>>20;C=z+12|0;z=w>>>0>C>>>0?C:w;C=o+12|0;c[C>>2]=D;if(!((q|0)==(A|0)&(s|0)==(B|0))){$Db(o+108|0)}B=o+88|0;do{if((c[B>>2]|0)==2){s=z+6|0;A=w>>>0>s>>>0?s:w;s=((A|0)<(w|0))+A|0;if(((d[y+(A>>>3)|0]|0)&128>>>((A&7)>>>0)|0)!=0){DDb(b,2007440,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1163346256;i=h;return t|0}if(((d[y+(s>>>3)|0]|0)&128>>>((s&7)>>>0)|0)==0){F=((s|0)<(w|0))+s|0;break}DDb(b,1969440,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1163346256;i=h;return t|0}else{F=z}}while(0);z=c[x>>2]|0;s=c[p>>2]|0;A=(z|0)/(s|0)|0;q=(z|0)%(s|0)|0;z=c[C>>2]|0;D=c[r>>2]|0;G=(z|0)/(D|0)|0;H=(z|0)%(D|0)|0;z=o+28|0;a:do{if((c[z>>2]|0)<(ba(D,s)|0)){I=ba(s*3|0,D)|0;J=_Db(o+24|0,I)|0;if((J|0)<0){c[z>>2]=0;yDb(b,16,1940904,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=J;i=h;return t|0}if((c[B>>2]|0)!=2){break}c[j+32>>2]=0;c[j+36>>2]=0;c[j+40>>2]=0;do{if((Sb(j|0,0,2145280,56)|0)==0){J=ob(j|0,I|0)|0;Zc(j|0)|0;c[o+116>>2]=J;if((J|0)<1){break}K=_Db(o+112|0,J)|0;if((K|0)>=0){break a}c[z>>2]=0;yDb(b,16,1895952,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=K;i=h;return t|0}else{c[o+116>>2]=-1}}while(0);yDb(b,16,1916520,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1;i=h;return t|0}}while(0);c[z>>2]=ba(c[r>>2]|0,c[p>>2]|0)|0;z=b+120|0;j=c[z>>2]|0;do{if((j|0)==0){if((c[b+124>>2]|0)!=0){L=0;break}D=V$a(b,c[x>>2]|0,c[C>>2]|0)|0;if((D|0)<0){t=D;i=h;return t|0}else{L=c[z>>2]|0;break}}else{L=j}}while(0);j=b+124|0;do{if((L|0)==(c[x>>2]|0)){if((c[j>>2]|0)!=(c[C>>2]|0)){break}do{if((c[g+36>>2]&1|0)==0){D=o+96|0;c[D>>2]=0;M=D}else{D=(c[B>>2]|0)==2;s=o+96|0;c[s>>2]=D&1;if(!D){M=s;break}D=o+100|0;I=_Db(D,c[l>>2]|0)|0;if((I|0)<0){t=I;i=h;return t|0}else{UGb(c[D>>2]|0,c[u>>2]|0,c[l>>2]|0)|0;M=s;break}}}while(0);do{if((c[B>>2]|0)==2){s=o+108|0;if((c[s>>2]|0)!=0){break}c[s>>2]=cEb(ba(((q|0)!=0)+A<<3,((H|0)!=0)+G|0)|0)|0}}while(0);s=o+4|0;D=$$a(b,c[s>>2]|0)|0;if((D|0)<0){t=D;i=h;return t|0}D=((H|0)!=0)+G|0;b:do{if((D|0)>0){I=((q|0)!=0)+A|0;K=(I|0)>0;J=o+120|0;N=J;O=o+124|0;P=o+128|0;Q=o+132|0;R=o+136|0;S=b;T=k+32|0;U=k+36|0;V=k+40|0;W=k|0;X=k+4|0;Y=k+12|0;Z=k+16|0;_=o+108|0;$=o+104|0;aa=F;ca=0;c:while(1){da=c[r>>2]|0;ea=ba(da,ca)|0;fa=(ca|0)<(G|0)?da:H;if(K){da=ba(ca,I)|0;ga=~ea;ha=(fa|0)>0;ia=aa;ja=0;while(1){ka=c[p>>2]|0;la=ba(ka,ja)|0;ma=(ja|0)<(A|0)?ka:q;ka=y+(ia>>>3)|0;na=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ia&7)>>>16;ka=ia+16|0;oa=w>>>0>ka>>>0?ka:w;TGb(J|0,0,16)|0;c[R>>2]=fa;if((na<<3|0)>(v-oa|0)){pa=43;break c}d:do{if((c[B>>2]|0)!=2|(na|0)==0){qa=oa;ra=na}else{ka=oa+3|0;sa=w>>>0>ka>>>0?ka:w;ka=y+(sa>>>3)|0;ta=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(sa&7)>>>30;ka=sa+2|0;sa=w>>>0>ka>>>0?ka:w;c[N>>2]=ta;ka=d[y+(sa>>>3)|0]|0;ua=((sa|0)<(w|0))+sa|0;va=((ua|0)<(w|0))+ua|0;c[O>>2]=(d[y+(ua>>>3)|0]|0)<<(ua&7)>>>7&1;ua=((va|0)<(w|0))+va|0;wa=(d[y+(va>>>3)|0]|0)<<(va&7)>>>7&1;c[P>>2]=wa;if(!((ta|0)==0|(ta|0)==2)){pa=46;break c}va=(ka&128>>>((sa&7)>>>0)|0)==0;if(va){xa=na;ya=ua;za=wa}else{if((c[$>>2]|0)==0){pa=49;break c}wa=y+(ua>>>3)|0;Aa=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ua&7)>>>24;wa=ua+8|0;ua=w>>>0>wa>>>0?wa:w;c[Q>>2]=Aa;wa=y+(ua>>>3)|0;Ba=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ua&7)>>>24;wa=ua+8|0;c[R>>2]=Ba;if((Ba+Aa|0)>(fa|0)){pa=51;break c}yDb(S,48,2258416,(E=i,i=i+32|0,c[E>>2]=ja,c[E+8>>2]=ca,c[E+16>>2]=Aa,c[E+24>>2]=Ba,E)|0);i=E;xa=na-2|0;ya=w>>>0>wa>>>0?wa:w;za=c[P>>2]|0}if((za|0)!=0){yDb(S,48,2244e3,(E=i,i=i+16|0,c[E>>2]=ja,c[E+8>>2]=ca,E)|0);i=E}if((c[O>>2]|0)!=0){pa=56;break c}if((c[_>>2]|0)==0){if((c[P>>2]|0)!=0){pa=59;break c}}wa=xa-1|0;if(va){qa=ya;ra=wa;break}va=c[s>>2]|0;ua=c[va+32>>2]|0;sa=ba(ua,(c[C>>2]|0)+ga|0)|0;if(!ha){qa=ya;ra=wa;break}ka=la*3|0;Ca=ma*3|0;Da=0;Ea=va;va=ua;while(1){ua=sa-(ba(va,Da)|0)+ka|0;UGb((c[Ea>>2]|0)+ua|0,(c[$>>2]|0)+ua|0,Ca)|0;ua=Da+1|0;if((ua|0)>=(fa|0)){qa=ya;ra=wa;break d}Fa=c[s>>2]|0;Da=ua;Ea=Fa;va=c[Fa+32>>2]|0}}}while(0);e:do{if((ra|0)==0){Ga=qa}else{na=ja+da|0;oa=c[n>>2]|0;va=oa+24|0;Ea=c[va>>2]|0;Da=oa+32|0;wa=Da;Ca=bc(wa|0)|0;f:do{if((Ca|0)==0){do{if((c[oa+124>>2]|0)==0){if((c[oa+128>>2]|0)!=0){pa=71;break}Ha=Da;Ia=oa+36|0;Ja=oa+44|0;Ka=oa+28|0;La=oa+48|0}else{pa=71}}while(0);do{if((pa|0)==71){pa=0;ka=c[oa+108>>2]|0;sa=c[ka+(na<<3)>>2]|0;Fa=c[ka+(na<<3)+4>>2]|0;if((sa|0)==0){break f}c[T>>2]=0;c[U>>2]=0;c[V>>2]=0;ka=Da;c[ka>>2]=sa;sa=oa+36|0;c[sa>>2]=Fa;Fa=oa+44|0;c[Fa>>2]=c[va>>2];ua=oa+28|0;Ma=oa+48|0;c[Ma>>2]=(c[ua>>2]|0)*3|0;$c(wa|0,2)|0;if((Sb(k|0,0,2145280,56)|0)!=0){break f}c[W>>2]=c[va>>2];c[X>>2]=((c[ua>>2]|0)*3|0)-(c[Ma>>2]|0);Na=oa+112|0;c[Y>>2]=c[Na>>2];Oa=oa+116|0;c[Z>>2]=c[Oa>>2];Yd(k|0,2)|0;Zc(k|0)|0;Pa=bc(wa|0)|0;if((Pa|0)==0){c[ka>>2]=c[Na>>2];c[sa>>2]=(c[Oa>>2]|0)-(c[Z>>2]|0);c[Fa>>2]=c[va>>2];c[Ma>>2]=(c[ua>>2]|0)*3|0;$c(wa|0,2)|0;Ha=ka;Ia=sa;Ja=Fa;Ka=ua;La=Ma;break}else{yDb(c[oa>>2]|0,16,2165800,(E=i,i=i+8|0,c[E>>2]=Pa,E)|0);i=E;break f}}}while(0);Pa=(qa|0)/8|0;c[Ha>>2]=(c[u>>2]|0)+Pa;c[Ia>>2]=ra;c[Ja>>2]=c[va>>2];c[La>>2]=(c[Ka>>2]|0)*3|0;if(($c(wa|0,4)|0)==-3){yDb(S,16,2159200,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;Jd(wa|0)|0;$c(wa|0,4)|0}if((c[oa+96>>2]|0)!=0){Ma=oa+108|0;c[(c[Ma>>2]|0)+(na<<3)>>2]=(c[oa+100>>2]|0)+Pa;c[(c[Ma>>2]|0)+(na<<3)+4>>2]=ra}Ma=(c[oa+132>>2]|0)+ea|0;do{if((c[oa+120>>2]|0)==0){Pa=oa+136|0;if((c[Pa>>2]|0)<1){break}ua=oa+4|0;Fa=la*3|0;sa=oa+12|0;ka=ma*3|0;Oa=Ea;Na=1;while(1){Qa=c[ua>>2]|0;UGb((c[Qa>>2]|0)+((ba((c[sa>>2]|0)-(Na+Ma)|0,c[Qa+32>>2]|0)|0)+Fa)|0,Oa|0,ka)|0;Qa=Na+1|0;if((Qa|0)>(c[Pa>>2]|0)){break}else{Oa=Oa+ka|0;Na=Qa}}}else{Na=c[va>>2]|0;ka=c[Ja>>2]|0;Oa=c[oa+4>>2]|0;Pa=c[Oa>>2]|0;Fa=c[oa+136>>2]|0;sa=(c[oa+12>>2]|0)+~Ma|0;ua=sa-Fa|0;Qa=c[Oa+32>>2]|0;Oa=c[oa+92>>2]|0;g:do{if((Fa|0)>0){Ra=la*3|0;if((ma|0)>0){Sa=sa;Ta=Na}else{Ua=Na;pa=93;break}while(1){Va=Pa+((ba(Sa,Qa)|0)+Ra)|0;Wa=0;Xa=Ta;while(1){if(!(Xa>>>0<ka>>>0)){break g}Ya=d[Xa]|0;if((Ya&128|0)==0){Za=c[Oa+(Ya<<2)>>2]|0;a[Va]=Za;a[Va+1|0]=Za>>>8;a[Va+2|0]=Za>>>16;_a=Xa+1|0}else{Za=Xa;Ya=(de((d[Za]|d[Za+1|0]<<8)<<16>>16|0)|0)&65535;a[Va]=Ya>>>2&7|Ya<<3;a[Va+1|0]=Ya>>>5<<3|Ya>>>7&7;a[Va+2|0]=Ya>>>10<<3|Ya>>>12&7;_a=Xa+2|0}Ya=Wa+1|0;if((Ya|0)<(ma|0)){Va=Va+3|0;Wa=Ya;Xa=_a}else{break}}Xa=Sa-1|0;if((Xa|0)>(ua|0)){Sa=Xa;Ta=_a}else{Ua=_a;pa=93;break}}}else{Ua=Na;pa=93}}while(0);if((pa|0)==93){pa=0;if((Ua-Na|0)>=0){break}}yDb(S,16,2152112,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;break f}}while(0);Ma=ra<<3;ua=-qa|0;Oa=w-qa|0;if((Ma|0)<(ua|0)){$a=ua}else{$a=(Oa|0)<(Ma|0)?Oa:Ma}Ga=$a+qa|0;break e}else{yDb(S,16,2165800,(E=i,i=i+8|0,c[E>>2]=Ca,E)|0);i=E}}while(0);yDb(S,16,2201304,(E=i,i=i+16|0,c[E>>2]=ja,c[E+8>>2]=ca,E)|0);i=E;Ga=qa}}while(0);ma=ja+1|0;if((ma|0)<(I|0)){ia=Ga;ja=ma}else{ab=Ga;break}}}else{ab=aa}ia=ca+1|0;if((ia|0)<(D|0)){aa=ab;ca=ia}else{bb=ab;break b}}if((pa|0)==43){KCb(c[s>>2]|0);t=-1094995529;i=h;return t|0}else if((pa|0)==46){yDb(S,16,2308616,(E=i,i=i+24|0,c[E>>2]=ja,c[E+8>>2]=ca,c[E+16>>2]=ta,E)|0);i=E;t=-1094995529;i=h;return t|0}else if((pa|0)==49){yDb(S,16,2290008,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1094995529;i=h;return t|0}else if((pa|0)==51){yDb(S,16,2274104,(E=i,i=i+24|0,c[E>>2]=Aa,c[E+8>>2]=Ba,c[E+16>>2]=fa,E)|0);i=E;t=-1094995529;i=h;return t|0}else if((pa|0)==56){aa=y+(ya>>>3)|0;I=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ya&7)>>>24;aa=ya+8|0;Z=w>>>0>aa>>>0?aa:w;aa=y+(Z>>>3)|0;Y=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(Z&7)>>>24;yDb(S,48,2231504,(E=i,i=i+32|0,c[E>>2]=ja,c[E+8>>2]=ca,c[E+16>>2]=I,c[E+24>>2]=Y,E)|0);i=E;DDb(S,2219376,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1163346256;i=h;return t|0}else if((pa|0)==59){yDb(S,16,2210008,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1094995529;i=h;return t|0}}else{bb=F}}while(0);do{if((c[M>>2]|0)!=0){if((c[B>>2]|0)!=2){break}D=o+104|0;Y=c[D>>2]|0;do{if((Y|0)==0){I=WDb(ba(c[j>>2]|0,c[(c[s>>2]|0)+32>>2]|0)|0)|0;c[D>>2]=I;if((I|0)!=0){cb=I;break}yDb(b,16,2192928,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-12;i=h;return t|0}else{cb=Y}}while(0);Y=c[s>>2]|0;UGb(cb|0,c[Y>>2]|0,ba(c[j>>2]|0,c[Y+32>>2]|0)|0)|0}}while(0);Y=MCb(e,c[s>>2]|0)|0;if((Y|0)<0){t=Y;i=h;return t|0}c[f>>2]=1;Y=(bb|0)/8|0;if((Y|0)==(m|0)){t=m;i=h;return t|0}yDb(b,16,2176480,(E=i,i=i+16|0,c[E>>2]=m,c[E+8>>2]=Y,E)|0);i=E;t=m;i=h;return t|0}}while(0);m=b;yDb(m,16,2353216,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;b=c[z>>2]|0;z=c[C>>2]|0;C=c[x>>2]|0;yDb(m,16,2333112,(E=i,i=i+32|0,c[E>>2]=c[j>>2],c[E+8>>2]=b,c[E+16>>2]=z,c[E+24>>2]=C,E)|0);i=E;t=-1094995529;i=h;return t|0}function Raa(a){a=a|0;var b=0;b=c[a+60>>2]|0;he(b+32|0)|0;JCb(b+4|0);$Db(b+24|0);return 0}function Saa(a){a=a|0;var b=0;b=c[a+60>>2]|0;Paa(a)|0;c[b+92>>2]=1219576;c[b+88>>2]=2;return 0}function Taa(a){a=a|0;var b=0;b=a+60|0;a=c[b>>2]|0;$Db(a+100|0);$Db(a+108|0);$Db(a+104|0);$Db(a+112|0);a=c[b>>2]|0;he(a+32|0)|0;JCb(a+4|0);$Db(a+24|0);return 0}function Uaa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;e=c[b+60>>2]|0;f=e;c[e>>2]=b;g=c[b+84>>2]|0;h=(g|0)==-1?9:g;c[e+56>>2]=h;if(h>>>0>9>>>0){yDb(b,16,1895904,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;k=-1;i=d;return k|0}h=b+120|0;g=c[h>>2]|0;do{if((g|0)<=4095){l=b+124|0;m=c[l>>2]|0;if((m|0)>4095){break}n=b;if((g|0)<16|(m|0)<16){yDb(n,16,2333048,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=d;return k|0}if((hDb(g,m,0,n)|0)<0){k=-1;i=d;return k|0}c[e+68>>2]=0;m=c[h>>2]|0;c[e+72>>2]=m;o=c[l>>2]|0;c[e+76>>2]=o;l=((m|0)/12|0)&-16;p=e+80|0;c[p>>2]=l;q=((o|0)/12|0)&-16;r=e+84|0;c[r>>2]=q;if((l|0)==0){c[p>>2]=1;s=1}else{s=l}if((q|0)==0){c[r>>2]=1;t=1}else{t=q}q=(o-1+t|0)/(t|0)|0;c[e+60>>2]=q;r=(m-1+s|0)/(s|0)|0;c[e+64>>2]=r;l=ba(m*3|0,o)|0;o=e+40|0;c[o>>2]=l;m=e+44|0;c[m>>2]=ba(q<<5,r)|0;r=e+12|0;q=r;c[q>>2]=cEb(l)|0;l=e+16|0;p=l;c[p>>2]=cEb(c[o>>2]|0)|0;u=e+20|0;v=u;c[v>>2]=cEb((c[o>>2]|0)*6|0)|0;w=e+4|0;x=w;c[x>>2]=cEb(c[o>>2]|0)|0;y=e+8|0;z=y;c[z>>2]=cEb(c[o>>2]|0)|0;o=e+32|0;A=o;c[A>>2]=cEb(c[m>>2]|0)|0;B=e+36|0;C=B;c[C>>2]=cEb(c[m>>2]|0)|0;m=e+24|0;c[m>>2]=0;c[e+28>>2]=0;Yaa(f,c[A>>2]|0,c[q>>2]|0,c[v>>2]|0);Yaa(f,c[C>>2]|0,c[p>>2]|0,0);a[e+89|0]=0;a[e+90|0]=-1;do{if((c[q>>2]|0)!=0){if((c[p>>2]|0)==0){break}if((c[v>>2]|0)==0){break}if((c[x>>2]|0)==0){break}if((c[z>>2]|0)==0){break}if((c[C>>2]|0)==0){break}if((c[A>>2]|0)==0){break}else{k=0}i=d;return k|0}}while(0);yDb(n,16,2007408,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;$Db(r);$Db(l);$Db(u);$Db(m);$Db(w);$Db(y);$Db(o);$Db(B);k=-1;i=d;return k|0}}while(0);yDb(b,16,2353152,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=d;return k|0}function Vaa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0;h=i;i=i+56|0;j=h|0;k=c[b+60>>2]|0;l=k;m=k+40|0;n=(c[m>>2]|0)+16384|0;o=r0a(b,e,n,(n|0)<0|0?-1:0)|0;if((o|0)<0){p=o;i=h;return p|0}o=b+428|0;n=c[o>>2]|0;q=(n|0)==0;r=c[b+136>>2]|0;if((r|0)>0){if((n|0)<((c[k+68>>2]|0)+r|0)&(q^1)){s=1}else{t=5}}else{if(q){t=5}else{s=1}}do{if((t|0)==5){q=((c[k+76>>2]|0)+63|0)/64|0;r=k+60|0;c[r>>2]=q;n=((c[k+72>>2]|0)+63|0)/64|0;u=k+64|0;c[u>>2]=n;v=k+80|0;w=k+84|0;if((c[v>>2]|0)==64){if((c[w>>2]|0)!=64){t=7}}else{t=7}do{if((t|0)==7){c[v>>2]=64;c[w>>2]=64;y=ba(n,q)|0;z=k+44|0;A=k+32|0;B=c[A>>2]|0;do{if(y>>>0>(c[z>>2]|0)>>>5>>>0){c[A>>2]=XDb(B,y<<5)|0;C=k+36|0;D=XDb(c[C>>2]|0,ba(c[u>>2]<<5,c[r>>2]|0)|0)|0;c[C>>2]=D;E=c[A>>2]|0;if(!((E|0)==0|(D|0)==0)){c[z>>2]=ba(c[r>>2]<<5,c[u>>2]|0)|0;F=E;G=C;break}yDb(c[k>>2]|0,16,2007408,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;p=-1;i=h;return p|0}else{F=B;G=k+36|0}}while(0);Yaa(l,F,c[k+12>>2]|0,c[k+20>>2]|0);Yaa(l,c[G>>2]|0,c[k+16>>2]|0,0);B=k+24|0;kEb(B,k+28|0,24576);if((c[B>>2]|0)!=0){break}yDb(c[k>>2]|0,16,1969400,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;p=-12;i=h;return p|0}}while(0);u=k;r=(c[(c[u>>2]|0)+80>>2]|0)==0;c[k+48>>2]=r&1;if(!r){s=0;break}r=k+90|0;q=a[r]|0;if((a[k+89|0]|0)!=0){n=q<<24>>24!=1;if(n){p=n<<31>>31}else{s=0;break}i=h;return p|0}if(q<<24>>24==0){s=0;break}UGb(k+92|0,1401360,512)|0;q=4;do{n=q<<16;w=q<<7&31744;v=4;do{B=v<<8;z=v<<2&992|w;A=4;do{y=A|B;C=y>>>8&255;E=(y|n)>>>16&255;y=C+A+E|0;D=-1;I=2147483647;J=0;while(1){K=c[l+92+(J<<2)>>2]|0;L=K&255;M=K>>>8&255;N=K>>>16&255;K=L-y+M+N|0;O=L-A|0;L=M-C|0;M=N-E|0;N=((L|0)>-1?L:-L|0)+((O|0)>-1?O:-O|0)+((M|0)>-1?M:-M|0)+((K|0)>-1?K:-K|0)|0;K=(N|0)<(I|0);P=K?J:D;M=J+1|0;if((M|0)<128){D=P;I=K?N:I;J=M}else{break}}a[(z|A>>3)+(l+604)|0]=P;A=A+8|0;}while((A|0)<256);v=v+8|0;}while((v|0)<256);q=q+8|0;}while((q|0)<256);a[r]=0;yDb(c[u>>2]|0,48,1916488,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;s=0}}while(0);P=k+48|0;if((c[P>>2]|0)!=0){c[k+52>>2]=15}l=c[f>>2]|0;G=c[f+32>>2]|0;f=c[e+24>>2]|0;F=e+28|0;q=c[F>>2]|0;v=k+76|0;n=c[v>>2]|0;if((n|0)>0){w=k+64|0;A=k+32|0;z=k+84|0;B=k+80|0;J=k+72|0;I=k+4|0;D=k+8|0;E=n;n=c[w>>2]|0;while(1){C=E-1|0;if((n|0)>0){y=ba(C,G)|0;M=0;N=n;while(1){K=(c[v>>2]|0)-C-1|0;O=c[A>>2]|0;L=c[z>>2]|0;Q=(ba((K|0)/(L|0)|0,N)|0)+M|0;R=ba(c[B>>2]|0,M)|0;S=((ba(c[J>>2]|0,K)|0)+R|0)*3|0;T=l+((R*3|0)+y)|0;R=(c[I>>2]|0)+S|0;U=(c[D>>2]|0)+S|0;S=(K|0)%(L|0)|0;L=O+(Q<<5)+29|0;K=a[L]|0;V=(K&255)*3|0;if((PGb(T,R,V)|0)==0){W=K}else{a[O+(Q<<5)+26|0]=1;UGb(R|0,T|0,V)|0;W=a[L]|0}if((PGb(T,U,(W&255)*3|0)|0)!=0){U=O+(Q<<5)+25|0;if((a[U]|0)==0){T=S&255;a[O+(Q<<5)+24|0]=T;X=T}else{X=a[O+(Q<<5)+24|0]|0}a[U]=S+1-(X&255)}S=M+1|0;U=c[w>>2]|0;if((S|0)<(U|0)){M=S;N=U}else{Y=U;break}}}else{Y=n}if((C|0)>0){E=C;n=Y}else{break}}}Y=k+60|0;n=c[Y>>2]|0;a:do{if((n|0)>0){E=k+64|0;w=k+32|0;X=k+36|0;W=k+4|0;D=k+72|0;I=k+84|0;l=k+80|0;J=k+92|0;B=k+56|0;z=k+52|0;A=k+24|0;G=j+32|0;N=j+36|0;M=j+40|0;y=j|0;u=j+4|0;r=j+12|0;U=j+16|0;S=0;Q=c[E>>2]|0;O=n;while(1){if((Q|0)>0){T=0;L=Q;do{V=c[w>>2]|0;R=(ba(L,S)|0)+T|0;K=c[X>>2]|0;Z=(c[P>>2]|0)!=0;_=Z?16:0;$=V+(R<<5)+31|0;a[$]=_;do{if(s){aa=V+(R<<5)+24|0;if((a[V+(R<<5)+26|0]|0)==0){a[aa]=0;a[V+(R<<5)+25|0]=0;c[V+(R<<5)+20>>2]=0;break}ca=(a[aa]|0)==0;if(ca){aa=a[V+(R<<5)+25|0]|0;da=V+(R<<5)+30|0;ea=a[da]|0;if(aa<<24>>24==ea<<24>>24){fa=aa;ga=1;ha=da;t=53;break}else{ia=ea}}else{ia=a[V+(R<<5)+30|0]|0}a[$]=_|4;fa=ia;ga=ca;ha=V+(R<<5)+30|0;t=53}else{a[V+(R<<5)+24|0]=0;ca=V+(R<<5)+30|0;ea=a[ca]|0;a[V+(R<<5)+25|0]=ea;fa=ea;ga=1;ha=ca;t=53}}while(0);do{if((t|0)==53){t=0;_=c[W>>2]|0;ca=(c[D>>2]|0)*3|0;ea=ba(ba(c[I>>2]|0,S)|0,ca)|0;da=ea+(ba(T*3|0,c[l>>2]|0)|0)|0;ea=c[B>>2]|0;aa=c[z>>2]|0;ja=c[A>>2]|0;ka=V+(R<<5)+29|0;la=a[ka]|0;ma=la&255;na=ba((fa&255)*6|0,ma)|0;oa=V+(R<<5)|0;pa=c[oa>>2]|0;qa=V+(R<<5)+24|0;if(Z){do{if(ga){ra=0;sa=pa;ta=0}else{ua=pa+(Xaa(J,pa,_+da|0,ma,aa)|0)|0;va=a[qa]|0;if((va&255)>>>0>1>>>0){wa=ua;xa=1;while(1){ya=wa+(Xaa(J,wa,_+((ba(xa,ca)|0)+da)|0,d[ka]|0,aa)|0)|0;za=xa+1|0;Aa=d[qa]|0;if((za|0)<(Aa|0)){wa=ya;xa=za}else{ra=za;sa=ya;ta=Aa;break}}}else{ra=1;sa=ua;ta=va&255;break}}}while(0);c[V+(R<<5)+4>>2]=sa;xa=V+(R<<5)+25|0;if((ra|0)<((d[xa]|0)+ta|0)){wa=ra;Aa=sa;while(1){ya=_+((ba(wa,ca)|0)+da)|0;za=Aa+(Xaa(J,Aa,ya,d[ka]|0,aa)|0)|0;ya=wa+1|0;if((ya|0)<((d[xa]|0)+(d[qa]|0)|0)){wa=ya;Aa=za}else{Ba=ya;Ca=za;break}}}else{Ba=ra;Ca=sa}c[V+(R<<5)+8>>2]=Ca;if((Ba|0)<(d[ha]|0)){Aa=Ba;wa=Ca;while(1){xa=_+((ba(Aa,ca)|0)+da)|0;za=wa+(Xaa(J,wa,xa,d[ka]|0,aa)|0)|0;xa=Aa+1|0;if((xa|0)<(d[ha]|0)){Aa=xa;wa=za}else{Da=za;break}}}else{Da=Ca}c[V+(R<<5)+12>>2]=Da-(c[oa>>2]|0)}else{if(ga){Ea=0;Fa=pa;Ga=0;Ha=la}else{wa=0;Aa=ma;aa=pa;while(1){UGb(aa|0,_+((ba(wa,ca)|0)+da)|0,Aa*3|0)|0;za=wa+1|0;xa=d[qa]|0;ya=a[ka]|0;Ia=ya&255;Ja=pa+(ba(za*3|0,Ia)|0)|0;if((za|0)<(xa|0)){wa=za;Aa=Ia;aa=Ja}else{Ea=za;Fa=Ja;Ga=xa;Ha=ya;break}}}c[V+(R<<5)+4>>2]=Fa;aa=V+(R<<5)+25|0;Aa=Ha&255;wa=pa+(ba(Aa*3|0,Ea)|0)|0;if((Ea|0)<((d[aa]|0)+Ga|0)){ma=Ea;la=Aa;Aa=wa;while(1){UGb(Aa|0,_+((ba(ma,ca)|0)+da)|0,la*3|0)|0;ya=ma+1|0;xa=a[ka]|0;Ja=xa&255;za=pa+(ba(ya*3|0,Ja)|0)|0;if((ya|0)<((d[aa]|0)+(d[qa]|0)|0)){ma=ya;la=Ja;Aa=za}else{Ka=ya;La=za;Ma=xa;break}}}else{Ka=Ea;La=wa;Ma=Ha}c[V+(R<<5)+8>>2]=La;Aa=Ma&255;la=pa+(ba(Aa*3|0,Ka)|0)|0;if((Ka|0)<(d[ha]|0)){ma=Ka;qa=Aa;Aa=la;while(1){UGb(Aa|0,_+((ba(ma,ca)|0)+da)|0,qa*3|0)|0;aa=ma+1|0;xa=d[ka]|0;za=pa+(ba(aa*3|0,xa)|0)|0;if((aa|0)<(d[ha]|0)){ma=aa;qa=xa;Aa=za}else{Na=za;break}}}else{Na=la}c[V+(R<<5)+12>>2]=Na-(c[oa>>2]|0)}Aa=V+(R<<5)+20|0;if((a[V+(R<<5)+25|0]|0)==0){c[Aa>>2]=0;break}c[Aa>>2]=na;qa=V+(R<<5)+16|0;ma=V+(R<<5)+4|0;pa=c[ma>>2]|0;ka=V+(R<<5)+8|0;if((Gb(c[qa>>2]|0,Aa|0,pa|0,(c[ka>>2]|0)-pa|0,ea|0)|0)!=0){Oa=-1;t=101;break a}if(!s){break}c[G>>2]=0;c[N>>2]=0;c[M>>2]=0;if((Sb(j|0,ea|0,2053184,56)|0)<0){Pa=-1;break a}c[y>>2]=c[K+(R<<5)>>2];pa=c[K+(R<<5)+12>>2]|0;c[u>>2]=pa;if((pa|0)!=0){do{c[r>>2]=ja;c[U>>2]=na;if((Yd(j|0,2)|0)<0){Oa=-1;t=101;break a}}while((c[u>>2]|0)!=0)}ea=c[ma>>2]|0;c[y>>2]=ea;c[u>>2]=(c[ka>>2]|0)-ea;c[r>>2]=ja;c[U>>2]=na;ea=Yd(j|0,4)|0;Zc(j|0)|0;oa=na-(c[U>>2]|0)|0;if((ea|0)!=1){Oa=-1;t=101;break a}if(!(oa>>>0<(c[Aa>>2]|0)>>>0)){break}c[Aa>>2]=oa;UGb(c[qa>>2]|0,ja|0,oa)|0;a[$]=a[$]|1}}while(0);T=T+1|0;L=c[E>>2]|0;}while((T|0)<(L|0));Qa=L;Ra=c[Y>>2]|0}else{Qa=Q;Ra=O}T=S+1|0;if((T|0)<(Ra|0)){S=T;Q=Qa;O=Ra}else{t=84;break}}}else{t=84}}while(0);do{if((t|0)==84){if((q|0)<5){Oa=-1;t=101;break}Ra=fe(((((c[k+80>>2]|0)>>>4<<12)+61440|c[k+72>>2])<<4|((c[k+84>>2]|0)>>>4)+1048575)<<12|c[v>>2]|0)|0;Qa=(q&268435456|0)!=0?0:f;x=Ra;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;Qa=k+88|0;a[f+4|0]=a[Qa]|0;Ra=(a[Qa]&1)==0;Qa=Ra?5:-1;if(!Ra){Oa=Qa;t=101;break}Ra=q-Qa|0;j=c[Y>>2]|0;b:do{if((j|0)>0){Na=k+64|0;ha=k+32|0;Ka=Qa+2|0;Ma=Qa+3|0;La=Qa+4|0;Ha=Qa+1|0;Ea=0;Ga=0;Fa=c[Na>>2]|0;ga=j;while(1){if((Fa|0)>0){Da=0;Ca=Ea;Ba=Fa;do{sa=c[ha>>2]|0;ra=Da+(ba(Ba,Ga)|0)|0;ta=sa+(ra<<5)+20|0;fa=c[ta>>2]|0;ia=sa+(ra<<5)+31|0;P=a[ia]|0;n=(P&4)==0?fa:fa+2|0;fa=(P&2)==0?n:n+2|0;n=(fa|0)==0?0:fa+1|0;do{if((n+2|0)>>>0>(Ra-Ca|0)>>>0){Sa=-1}else{fa=Ca+Qa|0;a[f+fa|0]=n>>>8;P=Ha+Ca|0;a[f+P|0]=n;if((n|0)==0){Sa=2;break}a[f+(Ka+Ca)|0]=a[ia]|0;O=a[ia]|0;if((O&4)==0){Ta=3;Ua=O}else{a[f+(Ma+Ca)|0]=a[sa+(ra<<5)+24|0]|0;a[f+(La+Ca)|0]=a[sa+(ra<<5)+25|0]|0;Ta=5;Ua=a[ia]|0}if((Ua&2)==0){Va=Ta}else{a[f+(Ta+fa)|0]=a[sa+(ra<<5)+27|0]|0;a[f+(Ta+P)|0]=a[sa+(ra<<5)+28|0]|0;Va=Ta+2|0}UGb(f+(Va+fa)|0,c[sa+(ra<<5)+16>>2]|0,c[ta>>2]|0)|0;Sa=(c[ta>>2]|0)+Va|0}}while(0);a[sa+(ra<<5)+26|0]=0;a[sa+(ra<<5)+25|0]=0;a[sa+(ra<<5)+24|0]=0;if((Sa|0)<0){Wa=Sa;break b}Ca=Sa+Ca|0;Da=Da+1|0;Ba=c[Na>>2]|0;}while((Da|0)<(Ba|0));Xa=Ca;Ya=Ba;Za=c[Y>>2]|0}else{Xa=Ea;Ya=Fa;Za=ga}Da=Ga+1|0;if((Da|0)<(Za|0)){Ea=Xa;Ga=Da;Fa=Ya;ga=Za}else{Wa=Xa;break}}}else{Wa=0}}while(0);Ra=((Wa|0)<0?0:Qa)+Wa|0;if(s){Pa=Ra}else{_a=Ra;t=102}}}while(0);if((t|0)==101){if(s){Pa=Oa}else{_a=Oa;t=102}}if((t|0)==102){t=k+36|0;UGb(c[t>>2]|0,c[k+32>>2]|0,c[k+44>>2]|0)|0;UGb(c[k+8>>2]|0,c[k+4>>2]|0,c[m>>2]|0)|0;Oa=ba(c[k+64>>2]|0,c[Y>>2]|0)|0;Y=k+16|0;s=c[Y>>2]|0;Wa=k+12|0;Xa=c[Wa>>2]|0;if((Oa|0)>0){Za=0;Ya=s;Sa=Xa;while(1){Va=(c[t>>2]|0)+(Za<<5)|0;c[Va>>2]=(c[Va>>2]|0)+(Ya-Sa);c[(c[t>>2]|0)+(Za<<5)+4>>2]=0;c[(c[t>>2]|0)+(Za<<5)+8>>2]=0;c[(c[t>>2]|0)+(Za<<5)+16>>2]=0;Va=Za+1|0;f=c[Y>>2]|0;Ta=c[Wa>>2]|0;if((Va|0)<(Oa|0)){Za=Va;Ya=f;Sa=Ta}else{$a=f;ab=Ta;break}}}else{$a=s;ab=Xa}UGb($a|0,ab|0,c[m>>2]|0)|0;c[k+68>>2]=c[o>>2];k=e+36|0;c[k>>2]=c[k>>2]|1;yDb(b,48,2111648,(H=i,i=i+8|0,c[H>>2]=c[o>>2],H)|0);i=H;Pa=_a}c[F>>2]=Pa;c[g>>2]=1;p=0;i=h;return p|0}function Waa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+12|0);$Db(b+16|0);$Db(b+20|0);$Db(b+24|0);$Db(b+4|0);$Db(b+8|0);$Db(b+32|0);$Db(b+36|0);return 0}function Xaa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((g|0)>0){i=0;j=0}else{k=0;return k|0}while(1){l=e+i|0;m=j*3|0;n=d[f+m|0]|0;o=d[f+(m+1)|0]|0;p=o<<2&992|n>>>3;q=d[f+(m+2)|0]|0;m=p|q<<7&31744;r=n&248;s=o&248;t=q&248;u=o+n+q|0;v=u-(s+r)-t|0;w=n-r|0;r=o-s|0;s=q-t|0;t=a[b+512+m|0]|0;x=c[b+((t&255)<<2)>>2]|0;y=x&255;z=x>>>8&255;A=x>>>16&255;x=u-y-z-A|0;u=n-y|0;y=o-z|0;z=q-A|0;if((((w|0)>-1?w:-w|0)+h+((r|0)>-1?r:-r|0)+((s|0)>-1?s:-s|0)+((v|0)>-1?v:-v|0)|0)<(((y|0)>-1?y:-y|0)+((u|0)>-1?u:-u|0)+((z|0)>-1?z:-z|0)+((x|0)>-1?x:-x|0)|0)){a[l]=m>>>8|128;a[e+(i+1)|0]=p;B=2}else{a[l]=t;B=1}t=B+i|0;l=j+1|0;if((l|0)<(g|0)){i=t;j=l}else{k=t;break}}return k|0}function Yaa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=b+64|0;h=c[g>>2]|0;if((h|0)<=0){return}i=b+60|0;j=b+80|0;k=b+84|0;l=b+76|0;m=b+72|0;b=f;f=0;n=e;e=c[i>>2]|0;o=h;while(1){if((e|0)>0){h=f&255;p=b;q=0;r=n;s=o;while(1){t=(ba(s,q)|0)+f|0;if((f|0)<(s-1|0)){u=c[j>>2]&255}else{u=(c[m>>2]|0)-(ba(c[j>>2]|0,f)|0)&255}a[d+(t<<5)+29|0]=u;if((q|0)<((c[i>>2]|0)-1|0)){v=c[k>>2]&255}else{v=(c[l>>2]|0)-(ba(c[k>>2]|0,q)|0)&255}a[d+(t<<5)+30|0]=v;a[d+(t<<5)+28|0]=q;a[d+(t<<5)+27|0]=h;c[d+(t<<5)>>2]=r;c[d+(t<<5)+16>>2]=p;t=ba(v&255,u&255)|0;w=r+(t*3|0)|0;if((p|0)==0){x=0}else{x=t*6|0}t=p+x|0;y=q+1|0;z=c[i>>2]|0;A=c[g>>2]|0;if((y|0)<(z|0)){p=t;q=y;r=w;s=A}else{B=t;C=w;D=z;E=A;break}}}else{B=b;C=n;D=e;E=o}s=f+1|0;if((s|0)<(E|0)){b=B;f=s;n=C;e=D;o=E}else{break}}return}function Zaa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a+60|0;e=c[d>>2]|0;c[e>>2]=a;f=a+120|0;do{if((c[f>>2]|0)<=4095){g=a+124|0;if((c[g>>2]|0)>4095){break}TGb(e+36|0,0,60)|0;h=e+8|0;c[h>>2]=c[f>>2];j=e+12|0;c[j>>2]=c[g>>2];g=e+24|0;c[g>>2]=cEb(196608)|0;k=cEb(ba((c[h>>2]|0)*3|0,c[j>>2]|0)|0)|0;c[e+28>>2]=k;if((c[g>>2]|0)==0|(k|0)==0){yDb(a,16,2188712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-12;i=b;return m|0}k=ICb()|0;g=a+804|0;c[g>>2]=k;if((k|0)!=0){m=0;i=b;return m|0}k=c[d>>2]|0;Zc(k+36|0)|0;ZDb(c[k+28>>2]|0);ZDb(c[k+4>>2]|0);ZDb(c[k+24>>2]|0);JCb(g);m=-12;i=b;return m|0}}while(0);yDb(a,16,2053104,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=b;return m|0}function _aa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;g=i;i=i+8|0;h=g|0;j=c[b+60>>2]|0;k=b+428|0;do{if((c[k>>2]|0)==0){l=e+32|0;m=c[l>>2]|0;n=cEb(ba((m|0)>-1?m:-m|0,c[j+12>>2]|0)|0)|0;c[j+4>>2]=n;if((n|0)!=0){o=1;p=n;q=l;break}yDb(b,16,2188712,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-12;i=g;return s|0}else{o=0;p=c[j+4>>2]|0;q=e+32|0}}while(0);l=c[q>>2]|0;n=j+4|0;if((l|0)<0){t=p+(ba((c[j+12>>2]|0)-1|0,-l|0)|0)|0}else{t=p}p=c[b+136>>2]|0;if((p|0)>0){u=(c[k>>2]|0)<((c[j+92>>2]|0)+p|0)?o:1}else{u=o}o=j+8|0;p=j+12|0;l=ba((c[o>>2]|0)*3|0,c[p>>2]|0)|0;m=r0a(b,d,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){s=m;i=g;return s|0}m=c[d+24>>2]|0;l=d+28|0;v=(c[l>>2]&268435456|0)!=0;w=fe(c[p>>2]|c[o>>2]<<16|805318656|0)|0;y=v?0:m;x=w;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;y=c[o>>2]|0;o=(y|0)/64|0;w=(y|0)%64|0;y=c[p>>2]|0;v=(y|0)/64|0;z=(y|0)%64|0;y=((z|0)!=0)+v|0;if((y|0)>0){A=((w|0)!=0)+o|0;B=(A|0)>0;C=e|0;D=j+24|0;E=j;F=(u|0)==0;G=0;H=4;I=0;while(1){J=(I|0)<(v|0)?64:z;a:do{if(B){K=~(I<<6);L=K-J|0;M=J*3|0;if((J|0)>0){N=G;O=H;P=0}else{Q=G;R=H;S=0;while(1){T=m+R|0;if(F){U=T;x=0;a[U]=x;x=x>>8;a[U+1|0]=x;V=2;W=Q+1|0}else{c[h>>2]=12288;if((Gb(m+(R+2)|0,h|0,c[D>>2]|0,ba((S|0)<(o|0)?64:w,M)|0,9)|0)!=0){yDb(c[E>>2]|0,16,2111608,(r=i,i=i+16|0,c[r>>2]=S,c[r+8>>2]=I,r)|0);i=r}U=c[h>>2]|0;X=T;x=de(U&65535|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;V=U+2|0;W=Q}U=V+R|0;X=S+1|0;if((X|0)<(A|0)){Q=W;R=U;S=X}else{Y=W;Z=U;break a}}}while(1){S=(P|0)<(o|0)?64:w;R=m+O|0;Q=c[C>>2]|0;U=c[p>>2]|0;X=L+U|0;T=c[q>>2]|0;_=P*192|0;$=S*3|0;if(($|0)>0){aa=U+K|0;U=c[D>>2]|0;ca=0;while(1){da=(ba(aa,T)|0)+_|0;ea=0;fa=ca;do{ga=da+ea|0;ha=a[Q+ga|0]|0;fa=(ha^a[t+ga|0])&255|fa;a[U+ea|0]=ha;ea=ea+1|0;}while((ea|0)<($|0));ea=aa-1|0;if((ea|0)>(X|0)){aa=ea;U=U+$|0;ca=fa}else{break}}if((fa|u|0)==0){ia=24}else{ia=21}}else{if(F){ia=24}else{ia=21}}if((ia|0)==21){ia=0;c[h>>2]=12288;if((Gb(m+(O+2)|0,h|0,c[D>>2]|0,ba(S,M)|0,9)|0)!=0){yDb(c[E>>2]|0,16,2111608,(r=i,i=i+16|0,c[r>>2]=P,c[r+8>>2]=I,r)|0);i=r}ca=c[h>>2]|0;$=R;x=de(ca&65535|0)|0;a[$]=x;x=x>>8;a[$+1|0]=x;ja=ca+2|0;ka=N}else if((ia|0)==24){ia=0;ca=R;x=0;a[ca]=x;x=x>>8;a[ca+1|0]=x;ja=2;ka=N+1|0}ca=ja+O|0;$=P+1|0;if(($|0)<(A|0)){N=ka;O=ca;P=$}else{Y=ka;Z=ca;break}}}else{Y=G;Z=H}}while(0);J=I+1|0;if((J|0)<(y|0)){G=Y;H=Z;I=J}else{la=Y;ma=Z;na=C;break}}}else{la=0;ma=4;na=e|0}c[l>>2]=ma;ma=c[q>>2]|0;q=c[n>>2]|0;n=c[na>>2]|0;na=c[p>>2]|0;if((ma|0)>0){UGb(q|0,n|0,ba(na,ma)|0)|0}else{p=n+(ba(na-1|0,ma)|0)|0;UGb(q|0,p|0,ba(na,(ma|0)>-1?ma:-ma|0)|0)|0}ma=c[b+804>>2]|0;b=ma+88|0;do{if((la|0)==0){c[b>>2]=1;na=ma+84|0;c[na>>2]=1;c[j+92>>2]=c[k>>2];if((c[na>>2]|0)==0){break}na=d+36|0;c[na>>2]=c[na>>2]|1}else{c[b>>2]=2;c[ma+84>>2]=0}}while(0);c[f>>2]=1;s=0;i=g;return s|0}function $aa(a){a=a|0;var b=0;b=c[a+60>>2]|0;Zc(b+36|0)|0;ZDb(c[b+28>>2]|0);ZDb(c[b+4>>2]|0);ZDb(c[b+24>>2]|0);JCb(a+804|0);return 0}function aba(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=c[a+60>>2]|0;f=a+96|0;g=c[f>>2]|0;h=c[a+100>>2]|0;switch(h|0){case 0:case 12:case 128:case 256:case 904:case 1024:{break};default:{yDb(a,16,2209976,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;k=-1094995529;i=b;return k|0}}c[e>>2]=a;switch(h|0){case 1024:{h=e+8|0;l=c[f>>2]|0;f=0;while(1){m=l;c[h+(f<<2)>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=f+1|0;if((m|0)<256){l=l+4|0;f=m}else{break}}n=8;o=c[e+1036>>2]|0;break};case 12:{c[e+1036>>2]=44819;n=8;o=44819;break};case 0:case 256:case 904:{c[e+1036>>2]=44817;n=8;o=44817;break};default:{f=g+4|0;l=(d[f]|d[f+1|0]<<8)<<16>>16&65535;c[e+1036>>2]=l;f=g+12|0;n=(d[f]|d[f+1|0]<<8)<<16>>16&65535;o=l}}l=(n|0)==0?8:n;n=(o|0)==44818&(l|0)==16?15:l;if((n|0)==8){c[a+140>>2]=11}else if((n|0)==15){c[a+140>>2]=46}else if((n|0)==16){c[a+140>>2]=44}else if((n|0)==24){c[a+140>>2]=3;DDb(a,2201288,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1163346256;i=b;return k|0}else{yDb(a,16,2192872,(j=i,i=i+8|0,c[j>>2]=n,j)|0);i=j;k=-1094995529;i=b;return k|0}j=ICb()|0;c[e+4>>2]=j;if((j|0)==0){k=-12;i=b;return k|0}c[e+1032>>2]=0;k=0;i=b;return k|0}function bba(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=c[e+140>>2]|0;if((h|0)==3){yDb(e,16,2111552,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1163346256;i=j;return n|0}else if((h|0)==11){o=c[e+60>>2]|0;if(!((l|0)>-1)){yDb(0,0,2289976,(m=i,i=i+24|0,c[m>>2]=2274088,c[m+8>>2]=2258392,c[m+16>>2]=135,m)|0);i=m;Cd();return 0}p=o+4|0;q=$$a(e,c[p>>2]|0)|0;if((q|0)<0){n=q;i=j;return n|0}q=c[p>>2]|0;r=c[q>>2]|0;s=o;t=ba(c[q+32>>2]|0,c[(c[s>>2]|0)+124>>2]|0)|0;if((l-16|0)>>>0>2147482847>>>0){n=-1094995529;i=j;return n|0}q=k+l|0;u=k;if((l|0)<4){v=0;w=k}else{x=k;v=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;w=k+4|0}x=q-w|0;y=x>>>0>2>>>0?2:x;x=w+y|0;if((q-x|0)<2){z=0;A=x}else{B=x;z=(d[B]|d[B+1|0]<<8)<<16>>16&65535;A=w+(y+2)|0}y=q-A|0;w=A+(y>>>0>8>>>0?8:y)|0;y=(v>>>0>l>>>0?l:v)-16|0;a:do{if(y>>>0>5>>>0&(z|0)!=0){v=-4-u|0;A=e;B=2-u|0;x=1-u|0;C=o+1036|0;D=o+8|0;E=o+1032|0;F=w;G=z;H=y;b:while(1){I=q-F|0;if(!(I>>>0>3>>>0)){J=F;break a}do{if((I|0)<4){K=0;L=F}else{M=F+4|0;N=F;O=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;if(!(O>>>0>H>>>0)){K=O;L=M;break}yDb(A,24,2053056,(m=i,i=i+16|0,c[m>>2]=O,c[m+8>>2]=H,m)|0);i=m;K=H;L=M}}while(0);I=L;M=v+I+K|0;c:do{if((q-I|0)<2){P=L;Q=0;R=151}else{O=L+2|0;N=L;S=(d[N]|d[N+1|0]<<8)<<16>>16&65535;switch(S|0){case 15:{N=c[s>>2]|0;if((c[N+124>>2]|0)>0){T=O;U=0;V=0;W=N}else{X=O;break c}while(1){N=q-T|0;Y=T+(N>>>0>1>>>0?1:N)|0;N=c[W+120>>2]|0;if((N|0)>0){Z=Y;_=N;N=V;d:while(1){$=Z;if(($+x|0)>(M|0)){aa=Z;break}if((q-$|0)<1){R=125;break b}$=Z+1|0;ca=a[Z]|0;da=ca<<24>>24;ea=-da|0;if(ca<<24>>24==0){R=125;break b}do{if(ca<<24>>24>0){if((q-$|0)<1){fa=0;ga=$}else{fa=a[$]|0;ga=Z+2|0}ha=da+N|0;if(ha>>>0>t>>>0){R=130;break b}else{ia=0;ja=_;ka=N}while(1){a[r+ka|0]=fa;la=ja-1|0;if((la|0)<0){yDb(A,16,1916448,(m=i,i=i+16|0,c[m>>2]=la,c[m+8>>2]=U,m)|0);i=m}ma=ia+1|0;if((ma|0)<(da|0)){ia=ma;ja=la;ka=ka+1|0}else{break}}na=ha;oa=_-da|0;pa=ga}else{qa=N-da|0;if(qa>>>0>t>>>0){R=135;break b}if(($-u-da|0)>(M|0)){aa=$;break d}if(!(ca<<24>>24<0)){na=N;oa=_;pa=$;break}la=(ea|0)>1?ea:1;ma=$;ra=0;sa=_;ta=N;while(1){if((q-ma|0)<1){ua=0;va=ma}else{ua=a[ma]|0;va=ma+1|0}a[r+ta|0]=ua;wa=sa-1|0;if((wa|0)<0){yDb(A,16,1916448,(m=i,i=i+16|0,c[m>>2]=wa,c[m+8>>2]=U,m)|0);i=m}xa=ra+1|0;if((xa|0)<(ea|0)){ma=va;ra=xa;sa=wa;ta=ta+1|0}else{break}}na=la+N|0;oa=_-la|0;pa=va}}while(0);if((oa|0)>0){Z=pa;_=oa;N=na}else{aa=pa;break}}ya=aa;za=c[s>>2]|0}else{ya=Y;za=W}N=U+1|0;if((N|0)<(c[za+124>>2]|0)){T=ya;U=N;V=(c[(c[p>>2]|0)+32>>2]|0)+V|0;W=za}else{X=ya;break c}}break};case 4:{if((c[C>>2]|0)==44819){R=20}else{Aa=0}break};case 7:{if((q-O|0)<2){X=O;break c}N=L+4|0;_=O;Z=(d[_]|d[_+1|0]<<8)<<16>>16;if(Z<<16>>16==0){X=N;break c}_=N;N=Z&65535;Z=0;while(1){ea=_;if((ea+B|0)>(M|0)){X=_;break c}else{Ba=_;Ca=Z;Da=ea}e:while(1){ea=Ca-1|0;$=Ba;ca=Da;while(1){if((q-ca|0)<2){Ea=$;Fa=0;break e}Ga=$+2|0;da=$;ta=(d[da]|d[da+1|0]<<8)<<16>>16;Ha=ta<<16>>16;da=Ha&49152;if((da|0)==49152){break}else if((da|0)==32768){Ia=ea+(c[(c[p>>2]|0)+32>>2]|0)|0;if(Ia>>>0>t>>>0){R=61;break b}a[r+Ia|0]=ta}else if((da|0)==16384){yDb(A,16,2243960,(m=i,i=i+8|0,c[m>>2]=Ha,m)|0);i=m}else{Ea=Ga;Fa=Ha;break e}da=Ga;if((da+B|0)>(M|0)){X=Ga;break c}else{$=Ga;ca=da}}ca=(ba(c[(c[p>>2]|0)+32>>2]|0,-Ha<<16>>16)|0)+Ca|0;$=Ga;if(($+B|0)>(M|0)){X=Ga;break c}else{Ba=Ga;Ca=ca;Da=$}}Y=N-1|0;if(Ca>>>0>t>>>0){R=63;break b}f:do{if((Fa|0)>0){$=Ea;ca=0;ea=Ca;while(1){da=$;if((da+B|0)>(M|0)){Ja=$;break f}if((q-da|0)<1){Ka=0;La=$}else{Ka=d[$]|0;La=$+1|0}da=Ka+ea|0;do{if((q-La|0)<1){Ma=La;Na=0;R=77}else{ta=La+1|0;sa=a[La]|0;ra=sa<<24>>24;if(!(sa<<24>>24<0)){Ma=ta;Na=ra;R=77;break}sa=-ra|0;if((q-ta|0)<1){Oa=0;Pa=ta}else{Oa=a[ta]|0;Pa=La+2|0}if((q-Pa|0)<1){Qa=0;Ra=Pa}else{Qa=a[Pa]|0;Ra=Pa+1|0}ta=sa<<1;Sa=ta+da|0;if(Sa>>>0>t>>>0){R=75;break b}else{Ta=0;Ua=da}while(1){a[r+Ua|0]=Oa;a[r+(Ua+1)|0]=Qa;ra=Ta+1|0;if((ra|0)<(sa|0)){Ta=ra;Ua=Ua+2|0}else{break}}Va=((sa|0)>1?ta:2)+da|0;Wa=Ra}}while(0);do{if((R|0)==77){R=0;la=Na<<1;Xa=la+da|0;if(Xa>>>0>t>>>0){R=78;break b}if((la-u+Ma|0)>(M|0)){Ja=Ma;break f}if((la|0)>0){Ya=Ma;Za=0;_a=da}else{Va=da;Wa=Ma;break}while(1){if((q-Ya|0)<1){$a=0;ab=Ya}else{$a=a[Ya]|0;ab=Ya+1|0}a[r+_a|0]=$a;ra=Za+1|0;if((ra|0)<(la|0)){Ya=ab;Za=ra;_a=_a+1|0}else{Va=Xa;Wa=ab;break}}}}while(0);da=ca+1|0;if((da|0)<(Fa|0)){$=Wa;ca=da;ea=Va}else{Ja=Wa;break}}}else{Ja=Ea}}while(0);if((Y|0)>0){_=Ja;N=Y;Z=(c[(c[p>>2]|0)+32>>2]|0)+Ca|0}else{X=Ja;break c}}break};case 11:{R=20;break};case 12:{if((q-O|0)<2){bb=0;cb=O}else{Z=O;bb=(d[Z]|d[Z+1|0]<<8)<<16>>16&65535;cb=L+4|0}Z=c[p>>2]|0;if((q-cb|0)<2){X=cb;break c}N=ba(c[Z+32>>2]|0,bb)|0;_=cb+2|0;ea=cb;ca=(d[ea]|d[ea+1|0]<<8)<<16>>16;if(ca<<16>>16==0){X=_;break c}if(N>>>0>t>>>0){db=N;R=92;break b}else{eb=Z;fb=N;gb=ca&65535;hb=_}while(1){_=hb;if((_+x|0)>(M|0)){X=hb;break c}do{if((q-_|0)<1){ib=hb;jb=eb}else{ca=hb+1|0;N=a[hb]|0;Z=N&255;if(N<<24>>24==0){ib=ca;jb=eb;break}else{kb=ca;lb=0;mb=fb}g:while(1){ca=kb;if((ca+x|0)>(M|0)){nb=kb;break}if((q-ca|0)<1){ob=0;pb=kb}else{ob=d[kb]|0;pb=kb+1|0}ca=ob+mb|0;do{if((q-pb|0)<1){qb=ca;rb=pb}else{N=pb+1|0;ea=a[pb]|0;$=ea<<24>>24;if(ea<<24>>24>0){sb=$+ca|0;if(sb>>>0>t>>>0){R=102;break b}if((N-u+$|0)>(M|0)){nb=N;break g}else{tb=N;ub=0;vb=ca}while(1){if((q-tb|0)<1){wb=0;xb=tb}else{wb=a[tb]|0;xb=tb+1|0}a[r+vb|0]=wb;da=ub+1|0;if((da|0)<($|0)){tb=xb;ub=da;vb=vb+1|0}else{qb=sb;rb=xb;break}}}else{if(!(ea<<24>>24<0)){qb=ca;rb=N;break}if((q-N|0)<1){yb=0;zb=N}else{yb=a[N]|0;zb=pb+2|0}Ab=ca-$|0;if(Ab>>>0>t>>>0){R=111;break b}da=-$|0;la=(da|0)>1?da:1;TGb(r+ca|0,yb|0,la|0)|0;qb=la+ca|0;rb=zb;break}}}while(0);ca=lb+1|0;if((ca|0)<(Z|0)){kb=rb;lb=ca;mb=qb}else{nb=rb;break}}ib=nb;jb=c[p>>2]|0}}while(0);_=gb-1|0;if((_|0)<=0){X=ib;break c}Y=(c[jb+32>>2]|0)+fb|0;if(Y>>>0>t>>>0){db=Y;R=92;break b}else{eb=jb;fb=Y;gb=_;hb=ib}}break};case 18:{X=O;break c;break};case 16:{_=K-6|0;Y=c[s>>2]|0;Z=c[Y+120>>2]|0;ca=c[Y+124>>2]|0;if((_|0)!=(ba(ca,Z)|0)){yDb(A,16,2219288,(m=i,i=i+8|0,c[m>>2]=_,m)|0);i=m;Y=q-O|0;X=L+((Y>>>0>_>>>0?_:Y)+2)|0;break c}if((ba(c[(c[p>>2]|0)+32>>2]|0,ca)|0)<=0){X=O;break c}ca=q-O|0;Y=ca>>>0>Z>>>0?Z:ca;UGb(r|0,O|0,Y)|0;ca=L+(Y+2)|0;Y=c[(c[p>>2]|0)+32>>2]|0;Z=c[s>>2]|0;if((Y|0)<(ba(c[Z+124>>2]|0,Y)|0)){Bb=ca;Cb=Y;Db=Z}else{X=ca;break c}while(1){ca=c[Db+120>>2]|0;Z=q-Bb|0;Y=Z>>>0>ca>>>0?ca:Z;UGb(r+Cb|0,Bb|0,Y)|0;Z=Bb+Y|0;Y=c[(c[p>>2]|0)+32>>2]|0;ca=Y+Cb|0;_=c[s>>2]|0;if((ca|0)<(ba(c[_+124>>2]|0,Y)|0)){Bb=Z;Cb=ca;Db=_}else{X=Z;break c}}break};case 13:{TGb(r|0,0,ba(c[(c[s>>2]|0)+124>>2]|0,c[(c[p>>2]|0)+32>>2]|0)|0)|0;X=O;break c;break};default:{P=O;Q=S;R=151;break c}}if((R|0)==20){R=0;Aa=2}if((q-O|0)<2){X=O;break}Z=L+4|0;_=O;ca=(d[_]|d[_+1|0]<<8)<<16>>16;_=ca&65535;if(ca<<16>>16==0){X=Z;break}ca=(Aa|0)==2;Y=Z;Z=0;la=0;while(1){if((q-Y|0)<1){Eb=0;Fb=Y}else{Eb=d[Y]|0;Fb=Y+1|0}da=Eb+la|0;if((q-Fb|0)<1){Gb=0;Hb=Fb}else{Gb=d[Fb]|0;Hb=Fb+1|0}ta=(Gb|0)==0?256:Gb;if((Hb-u+(ta*3|0)|0)>(M|0)){X=Hb;break c}if(ca){sa=Hb;ra=0;ma=da;while(1){wa=ma>>>0>255>>>0?0:ma;if((q-sa|0)<1){Ib=0;Jb=sa}else{Ib=(d[sa]|0)<<18;Jb=sa+1|0}if((q-Jb|0)<1){Kb=0;Lb=Jb}else{Kb=(d[Jb]|0)<<10&64512;Lb=Jb+1|0}if((q-Lb|0)<1){Mb=0;Nb=Lb}else{Mb=(d[Lb]|0)<<2&252;Nb=Lb+1|0}xa=Kb|Ib|Mb;Ob=xa|xa>>>6&197379|-16777216;xa=D+(wa<<2)|0;if((c[xa>>2]|0)!=(Ob|0)){c[E>>2]=1}Pb=wa+1|0;c[xa>>2]=Ob;Ob=ra+1|0;if((Ob|0)<(ta|0)){sa=Nb;ra=Ob;ma=Pb}else{Qb=Nb;Rb=Pb;break}}}else{ma=Hb;ra=0;sa=da;while(1){Pb=sa>>>0>255>>>0?0:sa;if((q-ma|0)<1){Sb=0;Tb=ma}else{Sb=d[ma]|0;Tb=ma+1|0}if((q-Tb|0)<1){Ub=0;Vb=Tb}else{Ub=d[Tb]|0;Vb=Tb+1|0}if((q-Vb|0)<1){Wb=0;Xb=Vb}else{Wb=d[Vb]|0;Xb=Vb+1|0}Ob=Sb<<Aa<<16|Ub<<Aa<<8&65280|Wb<<Aa&255|-16777216;xa=D+(Pb<<2)|0;if((c[xa>>2]|0)!=(Ob|0)){c[E>>2]=1}wa=Pb+1|0;c[xa>>2]=Ob;Ob=ra+1|0;if((Ob|0)<(ta|0)){ma=Xb;ra=Ob;sa=wa}else{Qb=Xb;Rb=wa;break}}}sa=Z+1|0;if((sa|0)<(_|0)){Y=Qb;Z=sa;la=Rb}else{X=Qb;break}}}}while(0);if((R|0)==151){R=0;yDb(A,16,2333016,(m=i,i=i+8|0,c[m>>2]=Q,m)|0);i=m;X=P}I=X;la=u-I+M|0;if((la|0)>0){Z=q-I|0;Yb=X+(Z>>>0>la>>>0?la:Z)|0}else{Yb=X}Z=H-K|0;la=G-1|0;if(Z>>>0>5>>>0&(la|0)>0){F=Yb;G=la;H=Z}else{J=Yb;break a}}if((R|0)==61){yDb(c[s>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=Ia,c[m+8>>2]=t,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==63){yDb(c[s>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=Ca,c[m+8>>2]=t,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==75){yDb(c[s>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=Sa,c[m+8>>2]=t,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==78){yDb(c[s>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=Xa,c[m+8>>2]=t,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==92){yDb(c[s>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=db,c[m+8>>2]=t,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==102){yDb(c[s>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=sb,c[m+8>>2]=t,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==111){yDb(c[s>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=Ab,c[m+8>>2]=t,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==125){yDb(A,16,2231472,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==130){yDb(c[s>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=ha,c[m+8>>2]=t,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==135){yDb(c[s>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=qa,c[m+8>>2]=t,m)|0);i=m;n=-1094995529;i=j;return n|0}}else{J=w}}while(0);w=q-J|0;if(w>>>0>2>>>0){yDb(e,16,2308536,(m=i,i=i+16|0,c[m>>2]=l,c[m+8>>2]=l-w,m)|0);i=m}UGb(c[(c[p>>2]|0)+4>>2]|0,o+8|0,1024)|0;w=o+1032|0;o=c[p>>2]|0;if((c[w>>2]|0)!=0){c[o+304>>2]=1;c[w>>2]=0}w=MCb(f,o)|0;if((w|0)<0){n=w;i=j;return n|0}c[g>>2]=1;n=l;i=j;return n|0}else if((h|0)==46|(h|0)==44){h=c[e+60>>2]|0;if(!((l|0)>-1)){yDb(0,0,2289976,(m=i,i=i+24|0,c[m>>2]=2274088,c[m+8>>2]=2258392,c[m+16>>2]=135,m)|0);i=m;Cd();return 0}w=h+4|0;o=$$a(e,c[w>>2]|0)|0;if((o|0)<0){n=o;i=j;return n|0}o=c[w>>2]|0;p=c[o>>2]|0;J=h;h=ba(c[o+32>>2]|0,c[(c[J>>2]|0)+124>>2]|0)|0;o=k+l|0;q=k;if((l|0)<4){Zb=0;_b=k}else{t=k;Zb=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;_b=k+4|0}k=o-_b|0;t=k>>>0>2>>>0?2:k;k=_b+t|0;if((o-k|0)<2){$b=0;ac=k}else{qa=k;$b=(d[qa]|d[qa+1|0]<<8)<<16>>16&65535;ac=_b+(t+2)|0}t=o-ac|0;_b=ac+(t>>>0>8>>>0?8:t)|0;t=(Zb>>>0>l>>>0?l:Zb)-16|0;h:do{if((t|0)!=0&($b|0)!=0){Zb=-4-q|0;ac=e;qa=2-q|0;k=1-q|0;s=_b;ha=$b;Ab=t;i:while(1){sb=o-s|0;if(!(sb>>>0>3>>>0)){bc=s;break h}do{if((sb|0)<4){cc=0;dc=s}else{db=s+4|0;Xa=s;Sa=d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0;if(!(Sa>>>0>Ab>>>0)){cc=Sa;dc=db;break}yDb(ac,24,2053056,(m=i,i=i+16|0,c[m>>2]=Sa,c[m+8>>2]=Ab,m)|0);i=m;cc=Ab;dc=db}}while(0);sb=dc;M=Zb+sb+cc|0;j:do{if((o-sb|0)<2){ec=dc;fc=0;R=274}else{db=dc+2|0;Sa=dc;Xa=(d[Sa]|d[Sa+1|0]<<8)<<16>>16&65535;switch(Xa|0){case 18:{Sa=cc-6|0;Ca=o-db|0;gc=dc+((Ca>>>0>Sa>>>0?Sa:Ca)+2)|0;break j;break};case 16:case 26:{Ca=cc-6|0;Sa=c[J>>2]|0;Ia=c[Sa+120>>2]|0;Yb=c[Sa+124>>2]|0;if(Ca>>>0>(ba(Ia<<1,Yb)|0)>>>0){yDb(ac,16,2353064,(m=i,i=i+8|0,c[m>>2]=Ca,m)|0);i=m;Sa=o-db|0;gc=dc+((Sa>>>0>Ca>>>0?Ca:Sa)+2)|0;break j}Sa=c[(c[w>>2]|0)+32>>2]|0;Ca=ba(Sa,Yb)|0;if((Ca|0)<=0){gc=db;break j}Yb=(Ia|0)>0;K=db;X=0;while(1){if(Yb){u=K;P=Ia;Q=0;while(1){if((o-u|0)<2){hc=0;ic=u}else{Qb=u;hc=(d[Qb]|d[Qb+1|0]<<8)<<16>>16;ic=u+2|0}b[p+(Q+X)>>1]=hc;Qb=P-1|0;if((Qb|0)>0){u=ic;P=Qb;Q=Q+2|0}else{jc=ic;break}}}else{jc=K}Q=X+Sa|0;if((Q|0)<(Ca|0)){K=jc;X=Q}else{gc=jc;break}}break};case 15:{X=c[J>>2]|0;if((c[X+124>>2]|0)>0){kc=db;lc=0;mc=0;nc=X}else{gc=db;break j}while(1){X=o-kc|0;K=kc+(X>>>0>1>>>0?1:X)|0;X=c[nc+120>>2]<<1;if((X|0)>0){Ca=K;Sa=X;X=mc;k:while(1){Ia=Ca;if((Ia+k|0)>(M|0)){oc=Ca;break}do{if((o-Ia|0)<1){pc=Ca;qc=0;R=226}else{Yb=Ca+1|0;Q=a[Ca]|0;P=Q<<24>>24;if(!(Q<<24>>24>0)){pc=Yb;qc=P;R=226;break}if((o-Yb|0)<1){rc=0;sc=Yb}else{rc=a[Yb]|0;sc=Ca+2|0}tc=P+X|0;if(tc>>>0>h>>>0){R=222;break i}else{uc=0;vc=Sa;wc=X}while(1){a[p+wc|0]=rc;Yb=vc-1|0;if((Yb|0)<0){yDb(ac,16,1940864,(m=i,i=i+16|0,c[m>>2]=Yb,c[m+8>>2]=lc,m)|0);i=m}Q=uc+1|0;if((Q|0)<(P|0)){uc=Q;vc=Yb;wc=wc+1|0}else{break}}xc=tc;yc=Sa-P|0;zc=sc}}while(0);do{if((R|0)==226){R=0;Ia=-qc|0;if((pc-(qc+q)|0)>(M|0)){oc=pc;break k}Ac=X-qc|0;if(Ac>>>0>h>>>0){R=230;break i}if((qc|0)>=0){xc=X;yc=Sa;zc=pc;break}Yb=(Ia|0)>1?Ia:1;Q=pc;u=0;Qb=Sa;Rb=X;while(1){if((o-Q|0)<1){Bc=0;Cc=Q}else{Bc=a[Q]|0;Cc=Q+1|0}a[p+Rb|0]=Bc;Xb=Qb-1|0;if((Xb|0)<0){yDb(ac,16,1916448,(m=i,i=i+16|0,c[m>>2]=Xb,c[m+8>>2]=lc,m)|0);i=m}Aa=u+1|0;if((Aa|0)<(Ia|0)){Q=Cc;u=Aa;Qb=Xb;Rb=Rb+1|0}else{break}}xc=Yb+X|0;yc=Sa-Yb|0;zc=Cc}}while(0);if((yc|0)>0){Ca=zc;Sa=yc;X=xc}else{oc=zc;break}}Dc=oc;Ec=c[J>>2]|0}else{Dc=K;Ec=nc}X=lc+1|0;if((X|0)<(c[Ec+124>>2]|0)){kc=Dc;lc=X;mc=(c[(c[w>>2]|0)+32>>2]|0)+mc|0;nc=Ec}else{gc=Dc;break}}break};case 25:{X=c[J>>2]|0;if((c[X+124>>2]|0)>0){Fc=db;Gc=0;Hc=0;Ic=X}else{gc=db;break j}while(1){X=o-Fc|0;Sa=Fc+(X>>>0>1>>>0?1:X)|0;X=c[Ic+120>>2]|0;if((X|0)>0){Ca=Sa;Rb=X;X=Hc;l:while(1){Qb=Ca;if((Qb+k|0)>(M|0)){Jc=Ca;break}do{if((o-Qb|0)<1){Kc=Ca;Lc=0;R=252}else{u=Ca+1|0;Q=a[Ca]|0;Ia=Q<<24>>24;if(!(Q<<24>>24>0)){Kc=u;Lc=Ia;R=252;break}if((o-u|0)<2){Mc=0;Nc=u}else{Q=u;Mc=(d[Q]|d[Q+1|0]<<8)<<16>>16;Nc=Ca+3|0}Oc=(Ia<<1)+X|0;if(Oc>>>0>h>>>0){R=248;break i}else{Pc=0;Qc=Rb;Rc=X}while(1){b[p+Rc>>1]=Mc;Q=Qc-1|0;if((Q|0)<0){yDb(ac,16,1895872,(m=i,i=i+8|0,c[m>>2]=Q,m)|0);i=m}u=Pc+1|0;if((u|0)<(Ia|0)){Pc=u;Qc=Q;Rc=Rc+2|0}else{break}}Sc=Oc;Tc=Rb-Ia|0;Uc=Nc}}while(0);do{if((R|0)==252){R=0;Qb=-Lc|0;Yb=Qb<<1;if((Yb-q+Kc|0)>(M|0)){Jc=Kc;break l}Vc=Yb+X|0;if(Vc>>>0>h>>>0){R=256;break i}if((Lc|0)>=0){Sc=X;Tc=Rb;Uc=Kc;break}Yb=(Qb|0)>1?Qb:1;Q=Kc;u=0;P=Rb;Xb=X;while(1){if((o-Q|0)<2){Wc=0;Xc=Q}else{Aa=Q;Wc=(d[Aa]|d[Aa+1|0]<<8)<<16>>16;Xc=Q+2|0}b[p+Xb>>1]=Wc;Aa=P-1|0;if((Aa|0)<0){yDb(ac,16,1895872,(m=i,i=i+8|0,c[m>>2]=Aa,m)|0);i=m}Wb=u+1|0;if((Wb|0)<(Qb|0)){Q=Xc;u=Wb;P=Aa;Xb=Xb+2|0}else{break}}Sc=(Yb<<1)+X|0;Tc=Rb-Yb|0;Uc=Xc}}while(0);if((Tc|0)>0){Ca=Uc;Rb=Tc;X=Sc}else{Jc=Uc;break}}Yc=Jc;Zc=c[J>>2]|0}else{Yc=Sa;Zc=Ic}X=Gc+1|0;if((X|0)<(c[Zc+124>>2]|0)){Fc=Yc;Gc=X;Hc=(c[(c[w>>2]|0)+32>>2]|0)+Hc|0;Ic=Zc}else{gc=Yc;break}}break};case 4:case 11:{X=cc-6|0;Rb=o-db|0;gc=dc+((Rb>>>0>X>>>0?X:Rb)+2)|0;break j;break};case 7:case 27:{if((o-db|0)<2){gc=db;break j}Rb=dc+4|0;X=db;Ca=(d[X]|d[X+1|0]<<8)<<16>>16;if(Ca<<16>>16==0){gc=Rb;break j}X=Rb;Rb=Ca&65535;Ca=0;while(1){K=X;if((K+qa|0)>(M|0)){gc=X;break j}else{_c=Ca;$c=X;ad=K}while(1){if((o-ad|0)<2){bd=$c;cd=0;break}K=$c+2|0;Xb=$c;P=(d[Xb]|d[Xb+1|0]<<8)<<16>>16;Xb=P<<16>>16;if(!(P<<16>>16<0)){bd=K;cd=Xb;break}P=(ba(c[(c[w>>2]|0)+32>>2]|0,-Xb<<16>>16)|0)+_c|0;Xb=K;if((Xb+qa|0)>(M|0)){gc=K;break j}else{_c=P;$c=K;ad=Xb}}Sa=Rb-1|0;dd=c[J>>2]|0;if(_c>>>0>h>>>0){R=187;break i}m:do{if((cd|0)>0){Xb=bd;K=0;P=_c;while(1){u=Xb;if((u+qa|0)>(M|0)){ed=Xb;break m}if((o-u|0)<1){fd=0;gd=Xb}else{fd=(d[Xb]|0)<<1;gd=Xb+1|0}u=fd+P|0;do{if((o-gd|0)<1){hd=gd;id=0;R=200}else{Q=gd+1|0;Qb=a[gd]|0;Ia=Qb<<24>>24;if(!(Qb<<24>>24<0)){hd=Q;id=Ia;R=200;break}Qb=-Ia|0;if((o-Q|0)<2){jd=0;kd=Q}else{Ia=Q;jd=(d[Ia]|d[Ia+1|0]<<8)<<16>>16;kd=gd+3|0}Ia=Qb<<1;ld=Ia+u|0;if(ld>>>0>h>>>0){R=198;break i}Q=(Qb|0)>1?Ia:2;Ia=0;Aa=u;while(1){b[p+Aa>>1]=jd;Wb=Ia+1|0;if((Wb|0)<(Qb|0)){Ia=Wb;Aa=Aa+2|0}else{break}}md=u+Q|0;nd=kd}}while(0);do{if((R|0)==200){R=0;Yb=id<<1;if((Yb-q+hd|0)>(M|0)){ed=hd;break m}od=Yb+u|0;if(od>>>0>h>>>0){R=203;break i}if((id|0)>0){pd=hd;qd=0;rd=u}else{md=u;nd=hd;break}while(1){if((o-pd|0)<2){sd=0;td=pd}else{Yb=pd;sd=(d[Yb]|d[Yb+1|0]<<8)<<16>>16;td=pd+2|0}b[p+rd>>1]=sd;Yb=qd+1|0;if((Yb|0)<(id|0)){pd=td;qd=Yb;rd=rd+2|0}else{md=od;nd=td;break}}}}while(0);u=K+1|0;if((u|0)<(cd|0)){Xb=nd;K=u;P=md}else{ed=nd;break}}}else{ed=bd}}while(0);if((Sa|0)>0){X=ed;Rb=Sa;Ca=(c[(c[w>>2]|0)+32>>2]|0)+_c|0}else{gc=ed;break}}break};case 12:{yDb(ac,16,1969352,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;Ca=cc-6|0;Rb=o-db|0;gc=dc+((Rb>>>0>Ca>>>0?Ca:Rb)+2)|0;break j;break};case 13:{TGb(p|0,0,ba(c[(c[J>>2]|0)+124>>2]|0,c[(c[w>>2]|0)+32>>2]|0)|0)|0;gc=db;break j;break};default:{ec=db;fc=Xa;R=274;break j}}}}while(0);if((R|0)==274){R=0;yDb(ac,16,2333016,(m=i,i=i+8|0,c[m>>2]=fc,m)|0);i=m;gc=ec}M=ha-1|0;if((Ab|0)!=(cc|0)&(M|0)>0){s=gc;ha=M;Ab=Ab-cc|0}else{bc=gc;break h}}if((R|0)==187){yDb(dd,16,2007360,(m=i,i=i+16|0,c[m>>2]=_c,c[m+8>>2]=h,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==198){yDb(dd,16,2007360,(m=i,i=i+16|0,c[m>>2]=ld,c[m+8>>2]=h,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==203){yDb(dd,16,2007360,(m=i,i=i+16|0,c[m>>2]=od,c[m+8>>2]=h,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==222){yDb(c[J>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=tc,c[m+8>>2]=h,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==230){yDb(c[J>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=Ac,c[m+8>>2]=h,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==248){yDb(c[J>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=Oc,c[m+8>>2]=h,m)|0);i=m;n=-1094995529;i=j;return n|0}else if((R|0)==256){yDb(c[J>>2]|0,16,2007360,(m=i,i=i+16|0,c[m>>2]=Vc,c[m+8>>2]=h,m)|0);i=m;n=-1094995529;i=j;return n|0}}else{bc=_b}}while(0);_b=bc;if(!((o-_b|0)>>>0<2>>>0)){yDb(e,16,2308536,(m=i,i=i+16|0,c[m>>2]=l,c[m+8>>2]=_b-q,m)|0);i=m}q=MCb(f,c[w>>2]|0)|0;if((q|0)<0){n=q;i=j;return n|0}c[g>>2]=1;n=l;i=j;return n|0}else{yDb(e,16,2188640,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-558323010;i=j;return n|0}return 0}function cba(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function dba(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=a+8|0;h=c[g>>2]|0;i=c[a>>2]|0;j=d[i+(h>>>3)|0]|0;k=a+16|0;a=c[k>>2]|0;l=((h|0)<(a|0))+h|0;c[g>>2]=l;m=(d[i+(l>>>3)|0]|0)<<(l&7)>>>7;c[g>>2]=((l|0)<(a|0))+l;c[f>>2]=m&1;m=c[g>>2]|0;f=c[k>>2]|0;l=i+(m>>>3)|0;a=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>26;l=m+6|0;c[g>>2]=f>>>0>l>>>0?l:f;c[e>>2]=a;a=c[g>>2]|0;e=c[k>>2]|0;k=i+(a>>>3)|0;i=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(a&7);if((j&128>>>((h&7)>>>0)|0)==0){h=a+7|0;n=i>>25;o=e>>>0>h>>>0?h:e;c[g>>2]=o;c[b>>2]=n;return}else{h=a+11|0;n=i>>21;o=e>>>0>h>>>0?h:e;c[g>>2]=o;c[b>>2]=n;return}}function eba(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;e=a+14128|0;f=c[e>>2]|0;g=a+14136|0;h=c[g>>2]|0;j=a+14120|0;k=c[j>>2]|0;l=k+(f>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(f&7);l=f+17|0;f=h>>>0>l>>>0?l:h;c[e>>2]=f;if((m&-32768|0)!=32768){yDb(c[a+4>>2]|0,16,2293184,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=b;return o|0}m=k+(f>>>3)|0;l=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(f&7);m=f+5|0;f=h>>>0>m>>>0?m:h;c[e>>2]=f;if(l>>>0>268435455>>>0){yDb(c[a+4>>2]|0,16,2325416,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=b;return o|0}m=a+44|0;c[m>>2]=(l>>>27)+1;l=k+(f>>>3)|0;p=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(f&7)>>>24;l=f+8|0;f=h>>>0>l>>>0?l:h;c[e>>2]=f;l=a+108|0;c[l>>2]=p;p=k+(f>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(f&7)>>>29;p=f+3|0;f=h>>>0>p>>>0?p:h;c[e>>2]=f;switch(q|0){case 3:{r=144;s=176;break};case 6:{r=120;s=160;break};case 2:{r=288;s=352;break};case 0:{q=k+(f>>>3)|0;p=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(f&7)>>>24;q=f+8|0;t=h>>>0>q>>>0?q:h;c[e>>2]=t;q=k+(t>>>3)|0;u=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(t&7)>>>24;q=t+8|0;c[e>>2]=h>>>0>q>>>0?q:h;r=u;s=p;break};case 4:{r=96;s=128;break};case 5:{r=240;s=320;break};case 1:{p=k+(f>>>3)|0;u=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(f&7)>>>16;p=f+16|0;f=h>>>0>p>>>0?p:h;c[e>>2]=f;p=k+(f>>>3)|0;k=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(f&7)>>>16;p=f+16|0;c[e>>2]=h>>>0>p>>>0?p:h;r=k;s=u;break};default:{r=0;s=0}}u=a+4|0;if((hDb(s,r,0,c[u>>2]|0)|0)!=0){o=-22;i=b;return o|0}c[a+8>>2]=s;c[a+12>>2]=r;r=c[e>>2]|0;s=c[g>>2]|0;g=c[j>>2]|0;j=g+(r>>>3)|0;k=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(r&7)>>>30;j=r+2|0;r=s>>>0>j>>>0?j:s;c[e>>2]=r;j=k+1|0;k=a+9992|0;c[k>>2]=j;h=j>>>0>2>>>0;j=a+10008|0;c[j>>2]=h&1;if(h){c[k>>2]=2}h=r+1|0;r=s>>>0>h>>>0?h:s;c[e>>2]=r;h=g+(r>>>3)|0;p=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(r&7)>>>27;h=r+5|0;r=s>>>0>h>>>0?h:s;c[e>>2]=r;h=a+9960|0;c[h>>2]=p;c[a+9964>>2]=p;c[a+40>>2]=0;c[a+10048>>2]=1;c[a+10052>>2]=0;p=c[a+14132>>2]|0;if((p-r|0)<1){o=-1094995529;i=b;return o|0}else{v=r}while(1){r=d[g+(v>>>3)|0]|0;f=((v|0)<(s|0))+v|0;c[e>>2]=f;if((r&128>>>((v&7)>>>0)|0)==0){break}r=f+8|0;f=s>>>0>r>>>0?r:s;c[e>>2]=f;if((p-f|0)<1){o=-1094995529;w=26;break}else{v=f}}if((w|0)==26){i=b;return o|0}c[a+11556>>2]=1;if((c[a+13812>>2]|0)!=0){w=c[u>>2]|0;c[w+224>>2]=1;c[w+228>>2]=2}w=c[u>>2]|0;if((c[w+688>>2]&1|0)!=0){if((c[j>>2]|0)==0){x=(mGb(c[k>>2]|0)|0)<<24>>24}else{x=68}k=(c[m>>2]|0)-1|0;m=c[h>>2]|0;h=c[l>>2]|0;yDb(w,48,2188608,(n=i,i=i+32|0,c[n>>2]=x,c[n+8>>2]=k,c[n+16>>2]=m,c[n+24>>2]=h,n)|0);i=n}c[a+9892>>2]=1179688;c[a+9888>>2]=1179688;o=0;i=b;return o|0}function fba(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=b+784|0;K_(d);e=d|0;d=c[e>>2]|0;f=b+788|0;g=c[f>>2]|0;if((g|0)>17){h=g-17|0;i=d<<17|1}else{j=fe(1>>>((17-g|0)>>>0)|d<<g|0)|0;d=b+796|0;k=c[d>>2]|0;x=j;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[d>>2]=(c[d>>2]|0)+4;h=g+15|0;i=1}c[e>>2]=i;c[f>>2]=h;g=(c[b+44>>2]|0)-1|0;if((h|0)>5){l=h-5|0;m=i<<5|g}else{d=fe(g>>>((5-h|0)>>>0)|i<<h|0)|0;i=b+796|0;k=c[i>>2]|0;x=d;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;l=h+27|0;m=g}c[e>>2]=m;c[f>>2]=l;g=c[b+108>>2]|0;h=gHb(g,(g|0)<0|0?-1:0,30,0)|0;g=c[b+4>>2]|0;i=c[g+104>>2]|0;k=gHb(h,F,i,(i|0)<0|0?-1:0)|0;i=c[g+108>>2]|0;g=eHb(k,F,i,(i|0)<0|0?-1:0)|0;i=g&255;if((l|0)>8){n=l-8|0;o=m<<8|i}else{g=fe(i>>>((8-l|0)>>>0)|m<<l|0)|0;m=b+796|0;k=c[m>>2]|0;x=g;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;n=l+24|0;o=i}c[e>>2]=o;c[f>>2]=n;i=b+8|0;l=c[i>>2]|0;switch(l|0){case 320:{if((c[b+12>>2]|0)==240){p=5}else{q=18}break};case 128:{if((c[b+12>>2]|0)==96){p=4}else{q=17}break};case 176:{if((c[b+12>>2]|0)==144){p=3}else{q=17}break};case 352:{if((c[b+12>>2]|0)==288){p=2}else{q=18}break};case 160:{if((c[b+12>>2]|0)==120){p=6}else{q=17}break};default:{if((l|0)<256){q=17}else{q=18}}}if((q|0)==17){if((c[b+12>>2]|0)<256){p=0}else{q=18}}if((q|0)==18){p=1}if((n|0)>3){r=n-3|0;s=o<<3|p}else{q=fe(p>>>((3-n|0)>>>0)|o<<n|0)|0;o=b+796|0;l=c[o>>2]|0;x=q;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;r=n+29|0;s=p}c[e>>2]=s;c[f>>2]=r;if((p|0)==0){n=c[i>>2]|0;if((r|0)>8){t=r-8|0;u=s<<8|n}else{o=fe(s<<r|n>>>((8-r|0)>>>0)|0)|0;l=b+796|0;q=c[l>>2]|0;x=o;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;t=r+24|0;u=n}c[e>>2]=u;c[f>>2]=t;n=c[b+12>>2]|0;if((t|0)>8){v=t-8|0;w=u<<8|n}else{l=fe(u<<t|n>>>((8-t|0)>>>0)|0)|0;u=b+796|0;q=c[u>>2]|0;x=l;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=t+24|0;w=n}c[e>>2]=w;c[f>>2]=v;y=v;z=w}else if((p|0)==1){p=c[i>>2]|0;if((r|0)>16){A=r-16|0;B=s<<16|p}else{i=fe(s<<r|p>>>((16-r|0)>>>0)|0)|0;w=b+796|0;v=c[w>>2]|0;x=i;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;A=r+16|0;B=p}c[e>>2]=B;c[f>>2]=A;p=c[b+12>>2]|0;if((A|0)>16){C=A-16|0;D=B<<16|p}else{w=fe(B<<A|p>>>((16-A|0)>>>0)|0)|0;B=b+796|0;v=c[B>>2]|0;x=w;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;C=A+16|0;D=p}c[e>>2]=D;c[f>>2]=C;y=C;z=D}else{y=r;z=s}s=(c[b+9992>>2]|0)==2|0;if((y|0)>2){E=y-2|0;G=z<<2|s}else{r=fe(s>>>((2-y|0)>>>0)|z<<y|0)|0;z=b+796|0;D=c[z>>2]|0;x=r;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;E=y+30|0;G=s}c[e>>2]=G;c[f>>2]=E;if((E|0)>1){H=E-1|0;I=G<<1|1}else{s=fe(1>>>((1-E|0)>>>0)|G<<E|0)|0;G=b+796|0;y=c[G>>2]|0;x=s;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;H=E+31|0;I=1}c[e>>2]=I;c[f>>2]=H;E=c[b+9960>>2]|0;if((H|0)>5){J=H-5|0;K=I<<5|E}else{G=fe(I<<H|E>>>((5-H|0)>>>0)|0)|0;I=b+796|0;y=c[I>>2]|0;x=G;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;J=H+27|0;K=E}c[e>>2]=K;c[f>>2]=J;if((J|0)>1){L=J-1|0;M=K<<1}else{E=fe(K<<J|0)|0;K=b+796|0;H=c[K>>2]|0;x=E;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[K>>2]=(c[K>>2]|0)+4;L=J+31|0;M=0}c[e>>2]=M;c[f>>2]=L;L=b+9892|0;if((c[b+228>>2]|0)==0){c[L>>2]=1179688;c[b+9888>>2]=1179688;return}else{c[L>>2]=1265888;c[b+9888>>2]=1265888;return}}function gba(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0;h=b|0;i=c[h>>2]|0;j=b+4|0;k=c[j>>2]|0;l=(k|0)>1;if((e|0)<64){if(l){m=k-1|0;n=i<<1}else{e=fe(i<<k|0)|0;o=b+12|0;p=c[o>>2]|0;x=e;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;m=k+31|0;n=0}c[h>>2]=n;c[j>>2]=m;if((m|0)>1){q=m-1|0;r=n<<1|g}else{o=fe(g>>>((1-m|0)>>>0)|n<<m|0)|0;n=b+12|0;p=c[n>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;q=m+31|0;r=g}c[h>>2]=r;c[j>>2]=q;if((q|0)>6){s=q-6|0;t=r<<6|f}else{m=fe(f>>>((6-q|0)>>>0)|r<<q|0)|0;r=b+12|0;n=c[r>>2]|0;x=m;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;s=q+26|0;t=f}c[h>>2]=t;c[j>>2]=s;q=d&127;if((s|0)>7){u=s-7|0;v=t<<7|q;c[h>>2]=v;c[j>>2]=u;return}else{r=fe(q>>>((7-s|0)>>>0)|t<<s|0)|0;t=b+12|0;n=c[t>>2]|0;x=r;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;u=s+25|0;v=q;c[h>>2]=v;c[j>>2]=u;return}}else{if(l){w=k-1|0;y=i<<1|1}else{l=fe(1>>>((1-k|0)>>>0)|i<<k|0)|0;i=b+12|0;q=c[i>>2]|0;x=l;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;w=k+31|0;y=1}c[h>>2]=y;c[j>>2]=w;if((w|0)>1){z=w-1|0;A=y<<1|g}else{k=fe(g>>>((1-w|0)>>>0)|y<<w|0)|0;y=b+12|0;i=c[y>>2]|0;x=k;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;z=w+31|0;A=g}c[h>>2]=A;c[j>>2]=z;if((z|0)>6){B=z-6|0;C=A<<6|f}else{g=fe(f>>>((6-z|0)>>>0)|A<<z|0)|0;A=b+12|0;w=c[A>>2]|0;x=g;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;B=z+26|0;C=f}c[h>>2]=C;c[j>>2]=B;f=d&2047;if((B|0)>11){u=B-11|0;v=C<<11|f;c[h>>2]=v;c[j>>2]=u;return}else{d=fe(f>>>((11-B|0)>>>0)|C<<B|0)|0;C=b+12|0;b=c[C>>2]|0;x=d;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;u=B+21|0;v=f;c[h>>2]=v;c[j>>2]=u;return}}}function hba(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0;do{if((e|0)==2){if((d|0)==0){return}f=c[b>>2]|0;h=c[b+4>>2]|0;i=0;do{j=i<<1;g[a+(j<<2)>>2]=+g[f+(i<<2)>>2];g[a+((j|1)<<2)>>2]=+g[h+(i<<2)>>2];i=i+1|0;}while(i>>>0<d>>>0);return}else if((e|0)==1){if(!(d>>>0<536870911>>>0)){k=0;break}UGb(a|0,c[b>>2]|0,d<<2)|0;return}else{if(!((e|0)<1|(d|0)==0)){k=0;break}return}}while(0);do{i=c[b+(k<<2)>>2]|0;h=k;f=0;while(1){g[a+(h<<2)>>2]=+g[i+(f<<2)>>2];j=f+1|0;if(j>>>0<d>>>0){h=h+e|0;f=j}else{break}}k=k+1|0;}while((k|0)<(e|0));return}function iba(a,b){a=a|0;b=b|0;c[a>>2]=2;c[a+4>>2]=346;c[a+8>>2]=904;c[a+12>>2]=152;c[a+16>>2]=66;return}function jba(a,b,d,e){a=a|0;b=b|0;d=+d;e=e|0;var f=0;if((e|0)>0){f=0}else{return}do{g[a+(f<<2)>>2]=+(c[b+(f<<2)>>2]|0)*d;f=f+1|0;}while((f|0)<(e|0));return}function kba(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0;if((f|0)<=0){return}h=a|0;a=e;e=0;while(1){te[c[h>>2]&7](b+(e<<2)|0,d+(e<<2)|0,+g[a>>2],8);i=e+8|0;if((i|0)<(f|0)){a=a+4|0;e=i}else{break}}return}function lba(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,h=0;if((d|0)>0){e=0}else{return}do{f=Gc(+(+g[c+(e<<2)>>2]))|0;if((f+32768|0)>>>0>65535>>>0){h=(f>>31^32767)&65535}else{h=f&65535}b[a+(e<<1)>>1]=h;e=e+1|0;}while((e|0)<(d|0));return}function mba(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)!=2){if((f|0)>0&(e|0)>0){h=0}else{return}do{i=d+(h<<2)|0;j=0;k=h;while(1){l=Gc(+(+g[(c[i>>2]|0)+(j<<2)>>2]))|0;if((l+32768|0)>>>0>65535>>>0){m=(l>>31^32767)&65535}else{m=l&65535}b[a+(k<<1)>>1]=m;l=j+1|0;if((l|0)<(e|0)){j=l;k=k+f|0}else{break}}h=h+1|0;}while((h|0)<(f|0));return}if((e|0)<=0){return}f=d+4|0;h=0;do{m=Gc(+(+g[(c[d>>2]|0)+(h<<2)>>2]))|0;if((m+32768|0)>>>0>65535>>>0){n=(m>>31^32767)&65535}else{n=m&65535}m=h<<1;b[a+(m<<1)>>1]=n;k=Gc(+(+g[(c[f>>2]|0)+(h<<2)>>2]))|0;if((k+32768|0)>>>0>65535>>>0){o=(k>>31^32767)&65535}else{o=k&65535}b[a+((m|1)<<1)>>1]=o;h=h+1|0;}while((h|0)<(e|0));return}function nba(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+4>>2]=0;Z3(b+12|0,a);return 0}function oba(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;i=i+32|0;j=h|0;k=h+16|0;l=c[b+60>>2]|0;m=l;n=c[g+24>>2]|0;o=c[g+28>>2]|0;c[j>>2]=e;c[j+4>>2]=0;c[j+8>>2]=0;if((o|0)<4){yDb(b,16,2188568,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}g=n;r=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=r&255;s=r>>>28&4;t=s+4|0;if(g>>>0>5>>>0){yDb(b,16,2111448,(p=i,i=i+8|0,c[p>>2]=g,p)|0);i=p;q=-1163346256;i=h;return q|0}u=n+t|0;a:do{if(g>>>0<2>>>0){v=((ba((c[b+120>>2]|0)*3|0,c[b+124>>2]|0)|0)>>>(((g|0)==0|0)>>>0))+t|0;if((r|0)<0){c[f>>2]=0;q=o;i=h;return q|0}if((o|0)==(v|0)){w=0;break}yDb(b,16,2052944,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=v,p)|0);i=p;q=-1094995529;i=h;return q|0}else{if((o|0)==8){c[f>>2]=0;q=8;i=h;return q|0}v=u;if((d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)!=2018725958|(o|0)<3096){yDb(b,16,2007328,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}v=s|8;x=o-t|0;y=n+v|0;z=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;c[k>>2]=z;do{if(z>>>0<x>>>0){y=n+(v+4)|0;A=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;c[k+4>>2]=A;if(!(A>>>0<x>>>0)){B=1;break}if(!(A>>>0>(z+1024|0)>>>0)){B=1;break}y=n+(v+8)|0;C=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;c[k+8>>2]=C;if(!(C>>>0<x>>>0)){B=2;break}if(!(C>>>0>(A+1024|0)>>>0)){B=2;break}c[k+12>>2]=x;A=l+4|0;C=A;y=l+8|0;D=0;E=z;while(1){if((D|0)>=3){w=z;break a}F=D+1|0;G=c[k+(F<<2)>>2]|0;O$a(A,y,G-1024-E|0);if((c[C>>2]|0)==0){q=-12;break}else{D=F;E=G}}i=h;return q|0}else{B=0}}while(0);yDb(b,16,1969304,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;q=-1094995529;i=h;return q|0}}while(0);c[e+88>>2]=1;c[e+84>>2]=1;B=r&1;c[b+140>>2]=(B|0)!=0?3:12;c[b+396>>2]=B<<1^2;c[b+392>>2]=B+1;B=W0a(b,j,0)|0;if((B|0)<0){q=B;i=h;return q|0}b:do{switch(g|0){case 1:{B=b+124|0;j=c[B>>2]|0;if((j|0)==0){break b}r=e+32|0;l=e;s=b+120|0;z=0;x=j;do{j=ba(c[r>>2]|0,x+~z|0)|0;v=c[s>>2]|0;UGb((c[l>>2]|0)+j|0,n+((ba(z*3|0,v)|0)+t)|0,v*3|0)|0;z=z+1|0;x=c[B>>2]|0;}while(z>>>0<x>>>0);break};case 2:case 4:{x=e;z=e+32|0;B=b+120|0;l=b+124|0;s=0;r=w;while(1){if((s|0)>=3){break b}v=(s|0)!=0|0;j=s+1|0;E=c[k+(j<<2)>>2]|0;H=qba(m,c[x+(s<<2)>>2]|0,c[z+(s<<2)>>2]|0,c[B>>2]>>v,c[l>>2]>>v,n+(r+t)|0,E-r|0,v,1)|0;if((H|0)<0){break}else{s=j;r=E}}yDb(b,16,1916416,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;q=H;i=h;return q|0};case 5:case 3:{r=e;l=e+32|0;B=b+124|0;z=b+120|0;x=0;E=w;while(1){I=c[r>>2]|0;if((x|0)>=3){break}j=c[l>>2]|0;v=c[B>>2]|0;D=I+((ba(v-1|0,j)|0)+x)|0;C=x+1|0;y=c[k+(C<<2)>>2]|0;J=qba(m,D,-j|0,c[z>>2]|0,v,n+(E+t)|0,y-E|0,0,3)|0;if((J|0)<0){K=43;break}else{x=C;E=y}}if((K|0)==43){yDb(b,16,1916416,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=J;i=h;return q|0}E=c[B>>2]|0;if((E|0)<=0){break b}r=0;s=I;y=c[z>>2]|0;C=E;while(1){E=y*3|0;v=s+E|0;if((E|0)>0){E=s;do{j=a[E+1|0]|0;a[E]=(a[E]|0)+j;D=E+2|0;a[D]=(a[D]|0)+j;E=E+3|0;}while(E>>>0<v>>>0);L=E;M=c[z>>2]|0;N=c[B>>2]|0}else{L=s;M=y;N=C}v=r+1|0;if((v|0)<(N|0)){r=v;s=L+((M*-3|0)+(c[l>>2]|0))|0;y=M;C=N}else{break}}break};default:{C=b+120|0;y=c[C>>2]|0;l=b+124|0;s=c[l>>2]|0;do{if((y&7|0)==0){if((s&1|0)!=0){break}if(!((s+1|0)>>>0>2>>>0)){break b}r=e+32|0;B=c[e>>2]|0;z=e+36|0;x=c[e+4>>2]|0;v=e+40|0;j=c[e+8>>2]|0;D=0;A=u;G=y;F=s;while(1){O=D<<1;P=c[r>>2]|0;if((G|0)==0){Q=A;R=0;S=F}else{T=A;U=B+(ba(P,O)|0)|0;V=B+(ba(P,O|1)|0)|0;O=j+(ba(c[v>>2]|0,D)|0)|0;P=x+(ba(c[z>>2]|0,D)|0)|0;W=0;while(1){c[U>>2]=c[T>>2];c[U+4>>2]=c[T+4>>2];c[V>>2]=c[T+8>>2];c[V+4>>2]=c[T+12>>2];c[P>>2]=c[T+16>>2];X=T+24|0;c[O>>2]=c[T+20>>2];Y=W+8|0;Z=c[C>>2]|0;if(Y>>>0<Z>>>0){T=X;U=U+8|0;V=V+8|0;O=O+4|0;P=P+4|0;W=Y}else{break}}Q=X;R=Z;S=c[l>>2]|0}W=D+1|0;if(W>>>0<((S|0)/2|0)>>>0){D=W;A=Q;G=R;F=S}else{break b}}}}while(0);yDb(b,16,1940832,(p=i,i=i+16|0,c[p>>2]=y,c[p+8>>2]=s,p)|0);i=p;q=-1094995529;i=h;return q|0}}}while(0);c[f>>2]=1;q=o;i=h;return q|0}function pba(a){a=a|0;$Db((c[a+60>>2]|0)+4|0);return 0}function qba(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;o=i;i=i+4120|0;p=o|0;q=o+24|0;r=k;s=0;while(1){t=r;c[q+(s<<3)+4>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;t=s+1|0;if((t|0)<256){r=r+4|0;s=t}else{break}}s=l-1024|0;l=tGa(c[e>>2]|0,p,256,11,q|0,44,2)|0;if((l|0)<0){u=l;i=o;return u|0}l=e+4|0;Xe[c[e+1108>>2]&4095](c[l>>2]|0,k+1024|0,s>>2);k=c[l>>2]|0;l=s<<3;s=l>>>0>2147483639>>>0|(k|0)==0;e=s?0:k;k=s?0:l;l=k+8|0;a:do{if((j|0)>0){s=ba(n,h)|0;q=p+4|0;r=(m|0)==0;t=0;v=f;w=0;b:while(1){c:do{if((w|0)==0){x=0;y=t;while(1){if((x|0)>=(s|0)){z=y;break c}A=c[q>>2]|0;B=e+(y>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)>>>21;B=b[A+(C<<2)>>1]|0;D=b[A+(C<<2)+2>>1]|0;C=D<<16>>16;do{if(D<<16>>16<0){E=y+11|0;F=l>>>0>E>>>0?E:l;E=e+(F>>>3)|0;G=((fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(F&7)>>>((C+32|0)>>>0))+B|0;E=b[A+(G<<2)>>1]|0;H=b[A+(G<<2)+2>>1]|0;G=H<<16>>16;if(!(H<<16>>16<0)){I=G;J=E;K=F;break}H=F-C|0;F=l>>>0>H>>>0?H:l;H=e+(F>>>3)|0;L=((fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>((G+32|0)>>>0))+E|0;I=b[A+(L<<2)+2>>1]|0;J=b[A+(L<<2)>>1]|0;K=F}else{I=C;J=B;K=y}}while(0);B=I+K|0;C=l>>>0>B>>>0?B:l;if(r){M=J&255}else{M=J+128&255}a[v+x|0]=M;if((k-C|0)<0){break b}else{x=x+n|0;y=C}}}else{if(r){y=0;x=t;while(1){if((y|0)>=(s|0)){z=x;break c}C=c[q>>2]|0;B=e+(x>>>3)|0;A=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>21;B=b[C+(A<<2)>>1]|0;D=b[C+(A<<2)+2>>1]|0;A=D<<16>>16;do{if(D<<16>>16<0){F=x+11|0;L=l>>>0>F>>>0?F:l;F=e+(L>>>3)|0;E=((fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(L&7)>>>((A+32|0)>>>0))+B|0;F=b[C+(E<<2)>>1]|0;G=b[C+(E<<2)+2>>1]|0;E=G<<16>>16;if(!(G<<16>>16<0)){N=E;O=F;P=L;break}G=L-A|0;L=l>>>0>G>>>0?G:l;G=e+(L>>>3)|0;H=((fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(L&7)>>>((E+32|0)>>>0))+F|0;N=b[C+(H<<2)+2>>1]|0;O=b[C+(H<<2)>>1]|0;P=L}else{N=A;O=B;P=x}}while(0);B=N+P|0;A=l>>>0>B>>>0?B:l;B=v+y|0;a[B]=O;a[B]=(d[v+(y-g)|0]|0)+O;if((k-A|0)<0){break b}else{y=y+n|0;x=A}}}else{x=0;y=t;while(1){if((x|0)>=(s|0)){z=y;break c}A=c[q>>2]|0;B=e+(y>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)>>>21;B=b[A+(C<<2)>>1]|0;D=b[A+(C<<2)+2>>1]|0;C=D<<16>>16;do{if(D<<16>>16<0){L=y+11|0;H=l>>>0>L>>>0?L:l;L=e+(H>>>3)|0;F=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(H&7)>>>((C+32|0)>>>0))+B|0;L=b[A+(F<<2)>>1]|0;E=b[A+(F<<2)+2>>1]|0;F=E<<16>>16;if(!(E<<16>>16<0)){Q=F;R=L;S=H;break}E=H-C|0;H=l>>>0>E>>>0?E:l;E=e+(H>>>3)|0;G=((fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(H&7)>>>((F+32|0)>>>0))+L|0;Q=b[A+(G<<2)+2>>1]|0;R=b[A+(G<<2)>>1]|0;S=H}else{Q=C;R=B;S=y}}while(0);B=Q+S|0;C=l>>>0>B>>>0?B:l;B=v+x|0;a[B]=R;a[B]=(d[v+(x-g)|0]|0)+R;if((k-C|0)<0){break b}else{x=x+n|0;y=C}}}}}while(0);y=w+1|0;if((y|0)<(j|0)){t=z;v=v+g|0;w=y}else{break a}}Q_(p);u=-1094995529;i=o;return u|0}}while(0);Q_(p);u=0;i=o;return u|0}function rba(a,d){a=a|0;d=d|0;return((c[a+4>>2]|0)-(c[d+4>>2]|0)<<8)+(b[a>>1]|0)-(b[d>>1]|0)|0}function sba(a){a=a|0;var b=0,d=0;b=i;if((c[a+120>>2]&1|0)==0){c[a+140>>2]=17;d=0;i=b;return d|0}else{yDb(a,16,1969280,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;d=-22;i=b;return d|0}return 0}function tba(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;h=c[a+60>>2]|0;j=c[f+24>>2]|0;k=f+28|0;f=c[k>>2]|0;l=a+120|0;m=a+124|0;if((f|0)<((ba(c[l>>2]<<1,c[m>>2]|0)|0)+20|0)){yDb(a,16,2188512,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}p=j;if((d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)!=827806278){yDb(a,16,2111424,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}p=_$a(a,b,0)|0;if((p|0)<0){o=p;i=g;return o|0}c[b+88>>2]=1;c[b+84>>2]=1;p=b;q=j+f|0;f=h+4|0;h=b+32|0;b=j+4|0;j=0;r=c[l>>2]|0;while(1){s=(j|0)!=0;t=(c[m>>2]|0)+(s&1^1)>>1;u=ba(r<<1,t)|0;v=c[p>>2]|0;if((q-b|0)<8){o=-1094995529;w=26;break}x=b+8|0;y=b+4|0;z=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;if((z|0)<(u|0)){w=9;break}A=q-x|0;if((A|0)<(z|0)){w=11;break}y=c[f>>2]|0;do{if((j|0)==(y|0)){if((j|0)==0){B=v;break}B=v+(c[h>>2]<<1)|0}else{B=v+(c[h>>2]|0)|0}}while(0);a:do{if((t|0)>0){v=t-1|0;if(s){C=x;D=0;E=B;F=r;G=y}else{H=x;I=0;J=B;K=r;while(1){UGb(J|0,H|0,K<<1)|0;L=c[l>>2]|0;M=H+(L<<1)|0;N=I+1|0;if((N|0)<(t|0)){H=M;I=N;J=J+(c[h>>2]<<1)|0;K=L}else{O=M;P=L;break a}}}while(1){if((G|0)!=0&(D|0)==(v|0)){Q=c[p>>2]|0}else{Q=E}UGb(Q|0,C|0,F<<1)|0;K=c[l>>2]|0;J=C+(K<<1)|0;I=D+1|0;if((I|0)>=(t|0)){O=J;P=K;break a}C=J;D=I;E=Q+(c[h>>2]<<1)|0;F=K;G=c[f>>2]|0}}else{O=x;P=r}}while(0);x=j+1|0;if((x|0)>=2){w=25;break}b=O+(z-u)|0;j=x;r=P}if((w|0)==9){yDb(a,16,2052896,(n=i,i=i+16|0,c[n>>2]=z,c[n+8>>2]=u,n)|0);i=n;o=-1094995529;i=g;return o|0}else if((w|0)==11){yDb(a,16,2007288,(n=i,i=i+16|0,c[n>>2]=z,c[n+8>>2]=A,n)|0);i=n;o=-1094995529;i=g;return o|0}else if((w|0)==25){c[e>>2]=1;o=c[k>>2]|0;i=g;return o|0}else if((w|0)==26){i=g;return o|0}return 0}function uba(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+1280|0;e=d+256|0;f=d+768|0;g=c[a+60>>2]|0;h=d|0;j=e;k=f;TGb(h|0,0,256)|0;l=e|0;sLa(h,l,1744176,1743824);e=0;do{b[f+(e<<1)>>1]=e;e=e+1|0;}while((e|0)<256);e=g+1376|0;do{if((N_(e,9,12,h,1,1,j,2,2,k,2,2,0)|0)==0){TGb(h|0,0,256)|0;sLa(h,l,1744200,1743824);m=0;do{b[f+(m<<1)>>1]=m;m=m+1|0;}while((m|0)<256);m=g+1396|0;if((N_(m,9,12,h,1,1,j,2,2,k,2,2,0)|0)!=0){n=m;break}TGb(h|0,0,256)|0;sLa(h,l,1744224,1743840);o=0;do{b[f+(o<<1)>>1]=o+16;o=o+1|0;}while((o|0)<256);o=f|0;b[o>>1]=4096;if((N_(g+1416|0,9,251,h,1,1,j,2,2,k,2,2,0)|0)!=0){n=m;break}TGb(h|0,0,256)|0;sLa(h,l,1744248,1744008);p=0;do{b[f+(p<<1)>>1]=p+16;p=p+1|0;}while((p|0)<256);b[o>>1]=4096;if((N_(g+1436|0,9,251,h,1,1,j,2,2,k,2,2,0)|0)!=0){n=m;break}Z3(g,a);x2(g+1128|0,g+1244|0,1075976);c[a+140>>2]=2;q=0;i=d;return q|0}else{n=g+1396|0}}while(0);yDb(a,16,2126688,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;Q_(e);Q_(g+1416|0);Q_(n);Q_(g+1436|0);$Db(g+2240|0);q=-12;i=d;return q|0}function vba(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0;h=i;i=i+784|0;j=h|0;k=h+768|0;l=h+776|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;o=e;if((n|0)<12){yDb(b,16,2188448,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;q=-1094995529;i=h;return q|0}r=m+n|0;s=m;t=m+4|0;u=m;v=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;do{if((v&-16|0)==1194478896){u=v&15;if((u-2|0)>>>0>2>>>0){break}if((u|0)!=4){yDb(b,16,2052856,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-38;i=h;return q|0}u=n-4|0;do{if(u>>>0>5>>>0){w=b;y=g+2300|0;z=g+2264|0;A=g+2268|0;B=b+120|0;C=b+124|0;D=g+2260|0;E=g+2276|0;F=g+2280|0;G=g+2284|0;H=g+2288|0;I=g+2272|0;J=g+2304|0;K=g+2308|0;L=g+2320|0;M=g+2324|0;N=g+2328|0;O=g+2340|0;P=g+2344|0;Q=g+2332|0;R=g+2336|0;S=g+2312|0;T=g+2316|0;U=g+2292|0;V=g+2296|0;W=j|0;X=k|0;Y=g;Z=g+2368|0;_=g+2372|0;$=g+2360|0;aa=g+2364|0;ca=g+2348|0;da=ca;ea=g+2376|0;fa=g+2380|0;ga=g+2356|0;ha=g+2352|0;ia=t;ja=0;ka=u;a:while(1){if((ka|0)<4){la=0;ma=ia}else{na=ia;la=d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0;ma=ia+4|0}oa=la-1|0;if((r-ma|0)<1){pa=0;qa=ma}else{pa=d[ma]|0;qa=ma+1|0}na=qa;ra=na-s|0;sa=r-na|0;if(oa>>>0>sa>>>0){ta=15;break}b:do{switch(pa|0){case 204:case 205:{ua=ja;va=qa;break};case 201:{na=c[G>>2]|0;do{if((na|0)!=0){wa=c[H>>2]|0;if((wa|0)==0){break}if(oa>>>0<2>>>0){yDb(w,16,2274056,(p=i,i=i+8|0,c[p>>2]=oa,p)|0);i=p;ua=ja;va=qa;break b}if((sa|0)<1){xa=0;ya=qa}else{xa=d[qa]|0;ya=qa+1|0}c[U>>2]=xa;if((r-ya|0)<1){za=0;Aa=ya}else{za=d[ya]|0;Aa=ya+1|0}c[V>>2]=za;if(!((xa|0)<(na|0)&(za|0)<(wa|0))){yDb(w,16,2258352,(p=i,i=i+32|0,c[p>>2]=xa,c[p+8>>2]=za,c[p+16>>2]=na,c[p+24>>2]=wa,p)|0);i=p;ua=ja;va=Aa;break b}wa=c[D>>2]|0;if((wa|0)==2){ta=77;break a}else if((wa|0)!=3){ua=ja;va=Aa;break b}wa=Aa-s|0;Ba=la-3|0;Ca=m+(wa+Ba)|0;Da=c[E>>2]|0;Ea=c[F>>2]|0;c[l>>2]=ba(Da+1|0,Ea)|0;Fa=ba(Da,xa)|0;Ga=ba(Ea,za)|0;Ha=c[K>>2]|0;Ia=(c[J>>2]|0)+((ba(Ha,Ga)|0)+(Fa*3|0))|0;c:do{if((Ba|0)>=2){Ja=(c[z>>2]|0)-Fa|0;Ka=(Ja|0)>(Da|0)?Da:Ja;Ja=(c[A>>2]|0)-Ga|0;La=(Ja|0)>(Ea|0)?Ea:Ja;Ja=m+(wa+1)|0;Ma=(d[m+wa|0]|0)>>>5;if((Ma|0)==1){if((xba(Y,Ka,La,Ja,Ca-Ja|0,Ia,Ha,0,0,0)|0)==0){ua=ja;va=Aa;break b}else{break}}else if((Ma|0)==0){a[X]=a[Ja]|0;a[X+1|0]=a[Ja+1|0]|0;a[X+2|0]=a[Ja+2|0]|0;if((La|0)>0&(Ka|0)>0){Na=Ia;Oa=0}else{ua=ja;va=Aa;break b}while(1){Pa=0;do{Qa=Na+(Pa*3|0)|0;a[Qa]=a[X]|0;a[Qa+1|0]=a[X+1|0]|0;a[Qa+2|0]=a[X+2|0]|0;Pa=Pa+1|0;}while((Pa|0)<(Ka|0));Pa=Oa+1|0;if((Pa|0)<(La|0)){Na=Na+(c[K>>2]|0)|0;Oa=Pa}else{ua=ja;va=Aa;break b}}}else{Pa=(Ma|0)!=2;if(Pa){a[X]=a[Ja]|0;a[X+1|0]=a[Ja+1|0]|0;a[X+2|0]=a[Ja+2|0]|0;Ra=m+(wa+4)|0}else{Ra=Ja}Qa=Ra+1|0;Sa=(d[Ra]|0)+1|0;Ta=Ca;Ua=Sa*3|0;if((Ta-Qa|0)<(Ua|0)){break}UGb(W|0,Qa|0,Ua)|0;Qa=Ra+(Ua+1)|0;d:do{if(Pa){Va=0;while(1){if((Va|0)>=(Sa|0)){Wa=-1;break d}if((PGb(j+(Va*3|0)|0,X,3)|0)==0){Wa=Va;break}else{Va=Va+1|0}}}else{Wa=-1}}while(0);if((Ta-Qa|0)<2){ua=ja;va=Aa;break b}Ja=(d[Qa]|0)<<8|(d[Ra+(Ua+2)|0]|0);Va=Ua+3|0;Xa=Ra+Va|0;if((Ta-Xa|0)<(Ja+(Pa&1)|0)){break}if((Zb(c[O>>2]|0,l|0,Xa|0,Ja|0)|0)!=0){break}Xa=Ja+Va|0;if((Ma|0)==2){Va=c[O>>2]|0;Ja=c[K>>2]|0;Ya=c[l>>2]<<3;Za=Ya>>>0>2147483639>>>0|(Va|0)==0;_a=Za?0:Va;Va=Za?8:Ya+8|0;do{if(Sa>>>0<3>>>0){$a=1}else{if(Sa>>>0<5>>>0){$a=2;break}$a=Sa>>>0<17>>>0?4:8}}while(0);if((La|0)<=0){ua=ja;va=Aa;break b}Ma=(Ka|0)<1;Pa=32-$a|0;Ua=0;Qa=Ia;Ya=0;while(1){Za=_a+(Ya>>>3)|0;ab=fe(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0;Za=Ya+8|0;bb=Va>>>0>Za>>>0?Za:Va;if((ab&-16777216>>>((Ya&7)>>>0)|0)!=0|Ma){cb=bb}else{ab=0;Za=bb;while(1){bb=_a+(Za>>>3)|0;db=(fe(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(Za&7)>>>(Pa>>>0);bb=Za+$a|0;eb=Va>>>0>bb>>>0?bb:Va;bb=ab*3|0;fb=Qa+bb|0;if((db|0)==(Wa|0)){gb=bb|0;a[fb]=a[gb]|0;a[fb+1|0]=a[gb+1|0]|0;a[fb+2|0]=a[gb+2|0]|0}else{gb=j+(db*3|0)|0;a[fb]=a[gb]|0;a[fb+1|0]=a[gb+1|0]|0;a[fb+2|0]=a[gb+2|0]|0}gb=ab+1|0;if((gb|0)<(Ka|0)){ab=gb;Za=eb}else{cb=eb;break}}}Za=Ua+1|0;if((Za|0)<(La|0)){Ua=Za;Qa=Qa+Ja|0;Ya=cb}else{ua=ja;va=Aa;break b}}}Ya=Ra+(Xa+1)|0;Ja=(d[Ra+Xa|0]|0)+1|0;Qa=Ka+15|0;Ua=Qa>>3&-2;Va=La+15>>4;if((Va|0)>0){Pa=Qa>>4;Qa=(Pa|0)>0;_a=0;Ma=0;Za=Ya;ab=0;eb=0;while(1){if(Qa){gb=_a<<1;fb=ba(gb|1,Ua)|0;db=ba(gb,Ua)|0;gb=0;bb=Ma;hb=Za;ib=ab;jb=eb;while(1){if((ib|0)==0){if(!(hb>>>0<Ca>>>0)){break c}kb=d[hb]|0;lb=8;mb=hb+1|0}else{kb=jb;lb=ib;mb=hb}nb=kb&1;ob=nb+bb|0;if((ob|0)>(Ja|0)){break c}pb=kb>>1;qb=lb-1|0;rb=nb&255;nb=gb<<1;sb=nb|1;a[(c[P>>2]|0)+(sb+fb)|0]=rb;a[(c[P>>2]|0)+(nb+fb)|0]=rb;a[(c[P>>2]|0)+(sb+db)|0]=rb;a[(c[P>>2]|0)+(nb+db)|0]=rb;rb=gb+1|0;if((rb|0)<(Pa|0)){gb=rb;bb=ob;hb=mb;ib=qb;jb=pb}else{tb=ob;ub=mb;vb=qb;wb=pb;break}}}else{tb=Ma;ub=Za;vb=ab;wb=eb}jb=_a+1|0;if((jb|0)<(Va|0)){_a=jb;Ma=tb;Za=ub;ab=vb;eb=wb}else{xb=ub;break}}}else{xb=Ya}TGb(c[M>>2]|0,0,ba(c[N>>2]|0,La)|0)|0;xba(Y,Ka,La,xb,Ta-xb|0,c[M>>2]|0,c[N>>2]|0,c[P>>2]|0,Ua,Ja<<2)|0;eb=c[O>>2]|0;ab=c[K>>2]|0;Za=c[M>>2]|0;Ma=c[N>>2]|0;_a=c[l>>2]<<3;Va=_a>>>0>2147483639>>>0|(eb|0)==0;Pa=Va?0:eb;eb=Va?8:_a+8|0;do{if(Sa>>>0<3>>>0){yb=1}else{if(Sa>>>0<5>>>0){yb=2;break}yb=Sa>>>0<17>>>0?4:8}}while(0);if((La|0)<=0){ua=ja;va=Aa;break b}Sa=(Ka|0)<1;Ja=32-yb|0;Ua=Za;Ta=0;Ya=Ia;_a=0;while(1){Va=Pa+(_a>>>3)|0;Qa=fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0;Va=_a+8|0;Xa=eb>>>0>Va>>>0?Va:eb;if((Qa&-16777216>>>((_a&7)>>>0)|0)!=0|Sa){zb=Xa}else{Qa=0;Va=Xa;while(1){Xa=Pa+(Va>>>3)|0;jb=(fe(d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0)|0)<<(Va&7)>>>(Ja>>>0);Xa=Va+yb|0;ib=eb>>>0>Xa>>>0?Xa:eb;Xa=Qa*3|0;hb=Ya+Xa|0;if((jb|0)==(Wa|0)){bb=Ua+Xa|0;a[hb]=a[bb]|0;a[hb+1|0]=a[bb+1|0]|0;a[hb+2|0]=a[bb+2|0]|0}else{bb=j+(jb*3|0)|0;a[hb]=a[bb]|0;a[hb+1|0]=a[bb+1|0]|0;a[hb+2|0]=a[bb+2|0]|0}bb=Qa+1|0;if((bb|0)<(Ka|0)){Qa=bb;Va=ib}else{zb=ib;break}}}Va=Ta+1|0;if((Va|0)<(La|0)){Ua=Ua+Ma|0;Ta=Va;Ya=Ya+ab|0;_a=zb}else{ua=ja;va=Aa;break b}}}}}while(0);if((c[J>>2]|0)==0){ua=ja;va=Aa;break b}Ia=c[V>>2]|0;yDb(w,16,2231440,(p=i,i=i+16|0,c[p>>2]=c[U>>2],c[p+8>>2]=Ia,p)|0);i=p;ua=ja;va=Aa;break b}}while(0);yDb(w,24,2289936,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;ua=ja;va=qa;break};case 200:{c[y>>2]=0;if(oa>>>0<21>>>0){yDb(w,16,1969248,(p=i,i=i+8|0,c[p>>2]=oa,p)|0);i=p;ua=0;va=qa;break b}if((sa|0)<4){Ab=0;Bb=qa}else{na=qa;Ab=fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0;Bb=qa+4|0}c[z>>2]=Ab;if((r-Bb|0)<4){Cb=0;Db=Bb}else{na=Bb;Cb=fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0;Db=Bb+4|0}c[A>>2]=Cb;if((Ab|0)<16){ta=26;break a}na=c[B>>2]|0;if((Ab|0)>(na|0)|(Cb|0)<16){ta=26;break a}Ia=c[C>>2]|0;if((Cb|0)>(Ia|0)){ta=26;break a}if(!((Ab|0)==(na|0)&(Cb|0)==(Ia|0))){Ia=V$a(b,Ab,Cb)|0;if((Ia|0)<0){Eb=Ia;break a}}if((r-Db|0)<4){ta=30;break a}Ia=Db+4|0;na=Db;Ca=fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0;c[D>>2]=Ca;if(!((Ca-2|0)>>>0<2>>>0)){Fb=Ca;ta=32;break a}if((r-Ia|0)<4){Gb=0;Hb=Ia}else{Ca=Ia;Gb=fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0;Hb=Db+8|0}c[E>>2]=Gb;if((r-Hb|0)<4){ta=36;break a}Ca=Hb+4|0;Ia=Hb;na=d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0;Ia=fe(na|0)|0;c[F>>2]=Ia;if((Gb|0)==0|(na|0)==0){Ib=Ia;ta=39;break a}if(((Gb|Ia)&15|0)!=0){Ib=Ia;ta=39;break a}na=c[z>>2]|0;c[G>>2]=(Gb-1+na|0)/(Gb|0)|0;wa=c[A>>2]|0;c[H>>2]=(wa-1+Ia|0)/(Ia|0)|0;if((r-Ca|0)<1){ta=41;break a}Ia=Hb+5|0;Ha=a[Ca]|0;Ca=Ha&255;c[I>>2]=Ca;if(!(Ha<<24>>24==32)){Jb=Ca;ta=53;break a}Ca=r-Ia|0;if(Ca>>>0<16>>>0){ta=45;break a}if((la-22|0)>>>0<16>>>0){ta=45;break a}if((Ca|0)<4){Kb=0;Lb=Ia}else{Ca=Ia;Kb=fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0;Lb=Hb+9|0}if((r-Lb|0)<4){Mb=0;Nb=Lb}else{Ca=Lb;Mb=fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0;Nb=Lb+4|0}if((r-Nb|0)<4){Ob=0;ta=52;break a}Ca=Nb+4|0;Ia=Nb;Ha=d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0;Ia=fe(Ha|0)|0;if(!((Kb|0)==16711680&(Mb|0)==65280&(Ha|0)==-16777216)){Ob=Ia;ta=52;break a}Ia=c[J>>2]|0;do{if((Ia|0)==0){ta=57}else{if((c[S>>2]|0)<(na|0)){ta=57;break}if((c[T>>2]|0)<(wa|0)){ta=57}}}while(0);if((ta|0)==57){ta=0;c[K>>2]=(na+30&-16)*3|0;ZDb(Ia);Ha=cEb(ba(c[K>>2]|0,wa+15|0)|0)|0;c[J>>2]=Ha;if((Ha|0)==0){Eb=-12;break a}}Ha=c[L>>2]|0;do{if((Ha|0)!=0){if((c[M>>2]|0)==0){break}if((c[Q>>2]|0)<(c[E>>2]|0)){break}if((c[R>>2]|0)>=(c[F>>2]|0)){ua=1;va=Ca;break b}}}while(0);c[N>>2]=((c[E>>2]|0)+15&-16)*3|0;wa=(c[F>>2]|0)+15&-16;ZDb(Ha);ZDb(c[M>>2]|0);ZDb(c[O>>2]|0);ZDb(c[P>>2]|0);c[L>>2]=cEb(ba(c[N>>2]|0,wa)|0)|0;c[M>>2]=cEb(ba(c[N>>2]|0,wa)|0)|0;c[O>>2]=cEb((ba((c[E>>2]|0)+1|0,wa)|0)+16|0)|0;Ia=cEb(ba(c[E>>2]|0,wa)|0)|0;c[P>>2]=Ia;if((c[L>>2]|0)==0){Eb=-12;break a}if((c[M>>2]|0)==0){Eb=-12;break a}if((c[O>>2]|0)==0|(Ia|0)==0){Eb=-12;break a}else{ua=1;va=Ca}break};case 202:{if(oa>>>0<5>>>0){yDb(w,16,2219256,(p=i,i=i+8|0,c[p>>2]=oa,p)|0);i=p;ua=ja;va=qa;break b}if((sa|0)<2){Pb=0;Qb=qa}else{Ia=qa;Pb=(de((d[Ia]|d[Ia+1|0]<<8)<<16>>16|0)|0)&65535;Qb=qa+2|0}c[Z>>2]=Pb;if((r-Qb|0)<2){Rb=0;Sb=Qb}else{Ia=Qb;Rb=(de((d[Ia]|d[Ia+1|0]<<8)<<16>>16|0)|0)&65535;Sb=Qb+2|0}c[_>>2]=Rb;ua=ja;va=Sb;break};case 203:{if(oa>>>0<8>>>0){yDb(w,16,2209944,(p=i,i=i+8|0,c[p>>2]=oa,p)|0);i=p;ua=ja;va=qa;break b}Ia=m+ra|0;wa=la-5|0;if(!((wa|0)>-1)){ta=139;break a}na=m+(ra+wa)|0;if((wa|0)<4){Tb=0;Ub=Ia}else{wa=Ia;Tb=fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0;Ub=m+(ra+4)|0}if((na-Ub|0)<1){Vb=0;Wb=Ub}else{Vb=d[Ub]|0;Wb=Ub+1|0}if((na-Wb|0)<1){Xb=0;Yb=Wb}else{Xb=d[Wb]|0;Yb=Wb+1|0}if((na-Yb|0)<1){_b=0;$b=Yb}else{_b=d[Yb]|0;$b=Yb+1|0}if((na-$b|0)<1){ac=0;bc=$b}else{ac=d[$b]|0;bc=$b+1|0}if((na-bc|0)<1){cc=0;dc=bc}else{cc=d[bc]|0;dc=bc+1|0}wa=(cc|0)==1?32:1;Ia=(Vb+1073741823+wa&-wa)<<2;if((Vb|0)==0|(Xb|0)==0){yDb(w,16,2192832,(p=i,i=i+16|0,c[p>>2]=Vb,c[p+8>>2]=Xb,p)|0);i=p;ua=ja;va=qa;break b}if(_b>>>0>Vb>>>0|ac>>>0>Xb>>>0){yDb(w,24,2176448,(p=i,i=i+16|0,c[p>>2]=_b,c[p+8>>2]=ac,p)|0);i=p;wa=Vb-1|0;Ea=Xb-1|0;ec=ac>>>0>Ea>>>0?Ea:ac;fc=_b>>>0>wa>>>0?wa:_b}else{ec=ac;fc=_b}wa=na-dc|0;do{if(!((Tb-9|0)>>>0>wa>>>0)){if(((ba(c[aa>>2]|0,c[$>>2]|0)|0)/4|0)>>>0>Tb>>>0){break}if(!((cc|0)==32|(cc|0)==1)){EDb(w,2159176,(p=i,i=i+8|0,c[p>>2]=cc,p)|0);i=p;ua=ja;va=qa;break b}if((_Db(ca,ba(Ia,Xb)|0)|0)<0){yDb(w,16,2152080,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;ua=ja;va=qa;break b}c[$>>2]=Vb;c[aa>>2]=Xb;c[ea>>2]=fc;c[fa>>2]=ec;c[ga>>2]=cc;c[ha>>2]=Ia;Ea=c[da>>2]|0;if((cc|0)==1){gc=Ea;hc=0;ic=Vb;jc=Xb;kc=dc}else if((cc|0)==32){Ga=ba(Xb,(Vb+31|0)>>>3&60)|0;Da=Ea;Ea=0;Fa=Vb;Ba=Xb;_a=dc+(wa>>>0>Ga>>>0?Ga:wa)|0;while(1){if((Fa|0)>0){Ga=Da;ab=1;Ya=_a;while(1){if((na-Ya|0)<4){lc=0;mc=0;nc=0;oc=0;pc=Ya}else{Ta=Ya;Ma=fe(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0;lc=Ma>>>24&255;mc=Ma>>>16&255;nc=Ma>>>8&255;oc=Ma&255;pc=Ya+4|0}a[Ga]=oc;a[Ga+1|0]=nc;a[Ga+2|0]=mc;qc=Ga+4|0;a[Ga+3|0]=lc;rc=c[$>>2]|0;if((ab|0)<(rc|0)){Ga=qc;ab=ab+1|0;Ya=pc}else{break}}sc=qc;tc=rc;uc=c[aa>>2]|0;vc=pc}else{sc=Da;tc=Fa;uc=Ba;vc=_a}Ya=Ea+1|0;if((Ya|0)<(uc|0)){Da=sc;Ea=Ya;Fa=tc;Ba=uc;_a=vc}else{ua=ja;va=qa;break b}}}else{ua=ja;va=qa;break b}while(1){if((ic|0)>0){_a=gc;Ba=0;Fa=kc;while(1){if((na-Fa|0)<4){wc=0;xc=Fa}else{Ea=Fa;wc=fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0;xc=Fa+4|0}Ea=wc;Da=_a;Ya=0;while(1){a[Da]=Ea>>>31;ab=Ya+1|0;if((ab|0)<32){Ea=Ea<<1;Da=Da+4|0;Ya=ab}else{break}}yc=_a+128|0;Ya=Ba+32|0;zc=c[$>>2]|0;if((Ya|0)<(zc|0)){_a=yc;Ba=Ya;Fa=xc}else{break}}Ac=yc;Bc=zc;Cc=c[aa>>2]|0;Dc=xc}else{Ac=gc;Bc=ic;Cc=jc;Dc=kc}Fa=hc+1|0;if((Fa|0)<(Cc|0)){gc=Ac;hc=Fa;ic=Bc;jc=Cc;kc=Dc}else{break}}if((Cc|0)<=0){ua=ja;va=qa;break b}Fa=c[da>>2]|0;Ba=0;_a=Bc;Ya=Cc;Da=Dc;while(1){if((_a|0)>0){Ea=Fa;ab=0;Ga=Da;while(1){if((na-Ga|0)<4){Ec=0;Fc=Ga}else{Ma=Ga;Ec=fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0;Fc=Ga+4|0}Ma=Ec;Ta=Ea;Ua=0;while(1){La=(d[Ta]|0)<<1|Ma>>>31;if((La|0)==0){a[Ta]=-1;a[Ta+1|0]=0;a[Ta+2|0]=0;a[Ta+3|0]=0}else if((La|0)==1){La=Ta;x=-1;a[La]=x;x=x>>8;a[La+1|0]=x;x=x>>8;a[La+2|0]=x;x=x>>8;a[La+3|0]=x}else{La=Ta;x=0;a[La]=x;x=x>>8;a[La+1|0]=x;x=x>>8;a[La+2|0]=x;x=x>>8;a[La+3|0]=x}La=Ua+1|0;if((La|0)<32){Ma=Ma<<1;Ta=Ta+4|0;Ua=La}else{break}}Gc=Ea+128|0;Ua=ab+32|0;Hc=c[$>>2]|0;if((Ua|0)<(Hc|0)){Ea=Gc;ab=Ua;Ga=Fc}else{break}}Ic=Gc;Jc=Hc;Kc=c[aa>>2]|0;Lc=Fc}else{Ic=Fa;Jc=_a;Kc=Ya;Lc=Da}Ga=Ba+1|0;if((Ga|0)<(Kc|0)){Fa=Ic;Ba=Ga;_a=Jc;Ya=Kc;Da=Lc}else{ua=ja;va=qa;break b}}}}while(0);yDb(w,16,2165768,(p=i,i=i+16|0,c[p>>2]=Tb,c[p+8>>2]=wa,p)|0);i=p;ua=ja;va=qa;break};default:{yDb(w,24,2201256,(p=i,i=i+8|0,c[p>>2]=pa,p)|0);i=p;ua=ja;va=qa}}}while(0);sa=va;na=ra+oa+(s-sa)|0;Ia=r-sa|0;sa=va+(Ia>>>0>na>>>0?na:Ia)|0;Ia=r-sa|0;if(Ia>>>0>5>>>0){ia=sa;ja=ua;ka=Ia}else{Mc=ua;ta=195;break}}if((ta|0)==15){yDb(w,16,2007248,(p=i,i=i+16|0,c[p>>2]=oa,c[p+8>>2]=pa,p)|0);i=p;Mc=ja;ta=195}else if((ta|0)==26){yDb(w,16,1940784,(p=i,i=i+16|0,c[p>>2]=Ab,c[p+8>>2]=Cb,p)|0);i=p;Eb=-1094995529}else if((ta|0)==30){c[D>>2]=0;Fb=0;ta=32}else if((ta|0)==36){c[F>>2]=0;Ib=0;ta=39}else if((ta|0)==41){c[I>>2]=0;Jb=0;ta=53}else if((ta|0)==45){yDb(w,16,2353024,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Eb=-1094995529}else if((ta|0)==52){yDb(w,16,2332960,(p=i,i=i+24|0,c[p>>2]=Kb,c[p+8>>2]=Mb,c[p+16>>2]=Ob,p)|0);i=p;Eb=-1163346256}else if((ta|0)==77){yDb(w,16,2243912,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-38;i=h;return q|0}else if((ta|0)==139){yDb(0,0,2145248,(p=i,i=i+24|0,c[p>>2]=2139400,c[p+8>>2]=2133096,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}if((ta|0)==32){yDb(w,16,1916360,(p=i,i=i+8|0,c[p>>2]=Fb,p)|0);i=p;Eb=-1163346256}else if((ta|0)==39){yDb(w,16,1895816,(p=i,i=i+16|0,c[p>>2]=Gb,c[p+8>>2]=Ib,p)|0);i=p;Eb=-1094995529}else if((ta|0)==53){DDb(w,2308528,(p=i,i=i+8|0,c[p>>2]=Jb,p)|0);i=p;Eb=-1163346256}else if((ta|0)==195){if((Mc|0)==0){Nc=0;Oc=2;break}c[g+2300>>2]=1;Nc=Mc;Oc=1;break}c[A>>2]=0;c[z>>2]=0;c[H>>2]=0;c[G>>2]=0;q=Eb;i=h;return q|0}else{Nc=0;Oc=2}}while(0);u=g+2264|0;if((c[u>>2]|0)==0){q=n;i=h;return q|0}ka=g+2268|0;if((c[ka>>2]|0)==0){q=n;i=h;return q|0}ia=g+2304|0;if((c[ia>>2]|0)==0){q=n;i=h;return q|0}aa=_$a(b,o,0)|0;if((aa|0)<0){q=aa;i=h;return q|0}c[e+84>>2]=Nc;c[e+88>>2]=Oc;aa=b+124|0;$=e;da=c[$>>2]|0;ha=e+32|0;ga=c[ha>>2]|0;if((c[aa>>2]|0)>0){fa=g+2308|0;ea=0;ca=da;_=ga;while(1){Z=ca+(ba(_,ea)|0)|0;O=(c[ia>>2]|0)+(ba(c[fa>>2]|0,ea)|0)|0;UGb(Z|0,O|0,(c[u>>2]|0)*3|0)|0;O=ea+1|0;Z=c[$>>2]|0;M=c[ha>>2]|0;if((O|0)<(c[aa>>2]|0)){ea=O;ca=Z;_=M}else{Pc=Z;Qc=M;break}}}else{Pc=da;Qc=ga}_=c[g+2348>>2]|0;do{if((_|0)!=0){ca=(c[g+2368>>2]|0)-(c[g+2376>>2]|0)|0;ea=(c[g+2372>>2]|0)-(c[g+2380>>2]|0)|0;aa=c[g+2360>>2]|0;ha=c[g+2364>>2]|0;$=c[u>>2]|0;fa=(aa+ca|0)>($|0)?$-ca|0:aa;aa=c[ka>>2]|0;$=(ha+ea|0)>(aa|0)?aa-ea|0:ha;if((ca|0)<0){Rc=Pc;Sc=_+(-ca<<2)|0;Tc=fa+ca|0}else{Rc=Pc+(ca*3|0)|0;Sc=_;Tc=fa}if((ea|0)<0){Uc=Rc;Vc=Sc+(ba(c[g+2352>>2]|0,-ea|0)|0)|0;Wc=$+ea|0}else{Uc=Rc+(ba(ea,Qc)|0)|0;Vc=Sc;Wc=$}if(!((Wc|Tc|0)>-1&(Wc|0)>0)){break}$=(Tc|0)>0;ea=g+2352|0;fa=0;ca=Vc;ha=Uc;while(1){if($){aa=0;do{ia=aa<<2;M=aa*3|0;Z=ha+M|0;O=d[ca+ia|0]|0;L=256-O|0;P=ba(d[Z]|0,L)|0;a[Z]=((ba(d[ca+(ia|1)|0]|0,O)|0)+P|0)>>>8;P=ha+(M+1)|0;Z=ba(d[P]|0,L)|0;a[P]=((ba(d[ca+(ia|2)|0]|0,O)|0)+Z|0)>>>8;Z=ha+(M+2)|0;M=ba(d[Z]|0,L)|0;a[Z]=((ba(d[ca+(ia|3)|0]|0,O)|0)+M|0)>>>8;aa=aa+1|0;}while((aa|0)<(Tc|0))}aa=fa+1|0;if((aa|0)<(Wc|0)){fa=aa;ca=ca+(c[ea>>2]|0)|0;ha=ha+Qc|0}else{break}}}}while(0);c[f>>2]=1;q=n;i=h;return q|0}}while(0);yDb(b,16,2111376,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;q=-1094995529;i=h;return q|0}function wba(a){a=a|0;var b=0;b=c[a+60>>2]|0;Q_(b+1376|0);Q_(b+1416|0);Q_(b+1396|0);Q_(b+1436|0);$Db(b+2240|0);$Db(b+2340|0);$Db(b+2344|0);$Db(b+2320|0);$Db(b+2324|0);$Db(b+2348|0);$Db(b+2304|0);return 0}function xba(d,e,f,g,h,j,k,l,m,n){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;o=i;i=i+24|0;p=o|0;q=d+2240|0;r=_Db(q,h+16|0)|0;if((r|0)<0){s=r;i=o;return s|0}r=c[q>>2]|0;t=g+h|0;if((h|0)>0){h=r;u=g;while(1){g=u+1|0;v=a[u]|0;w=h+1|0;a[h]=v;if(v<<24>>24==-1){x=(a[g]|0)==0?u+2|0:g}else{x=g}if(x>>>0<t>>>0){h=w;u=x}else{break}}y=w;z=c[q>>2]|0}else{y=r;z=r}w=y-r|0;TGb(z+w|0,0,16)|0;z=c[q>>2]|0;q=w<<3;w=q>>>0>2147483639>>>0|(z|0)==0;r=w?0:z;z=w?0:q;c[p>>2]=r;c[p+12>>2]=z;c[p+16>>2]=z+8;c[p+4>>2]=r+(z>>3);c[p+8>>2]=0;z=e+15>>4;e=f+15>>4;if((n|0)==0){A=ba(z<<2,e)|0}else{A=n}c[d+1456>>2]=1024;c[d+1460>>2]=1024;c[d+1464>>2]=1024;n=d+1472|0;me[c[d+40>>2]&511](n);if((e|0)<=0){s=0;i=o;return s|0}f=(z|0)>0;r=m<<1;q=d+1116|0;w=0;y=0;x=A;A=l;a:while(1){if(f){l=(A|0)!=0;u=0;h=0;t=x;while(1){b:do{if(l){g=u<<1;if((a[A+g|0]|0)==0){v=g|1;do{if((a[A+v|0]|0)==0){if((a[A+(g+m)|0]|0)!=0){break}if((a[A+(v+m)|0]|0)==0){B=t;break b}}}while(0);if(!l){C=22;break}}if((a[A+g|0]|0)==0){D=t}else{v=yba(d,p,0,n)|0;if((v|0)!=0){s=v;C=39;break a}me[c[q>>2]&511](n);D=t-1|0}if((a[A+(g|1)|0]|0)==0){E=D}else{v=d+1600|0;F=yba(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}me[c[q>>2]&511](v);E=D-1|0}v=g+m|0;if((a[A+v|0]|0)==0){G=E}else{F=d+1728|0;H=yba(d,p,0,F)|0;if((H|0)!=0){s=H;C=39;break a}me[c[q>>2]&511](F);G=E-1|0}if((a[A+(v+1)|0]|0)==0){I=G;C=23;break}v=d+1856|0;F=yba(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}me[c[q>>2]&511](v);I=G-1|0;C=23}else{C=22}}while(0);if((C|0)==22){C=0;v=yba(d,p,0,n)|0;if((v|0)!=0){s=v;C=39;break a}me[c[q>>2]&511](n);v=d+1600|0;F=yba(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}me[c[q>>2]&511](v);v=d+1728|0;F=yba(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}me[c[q>>2]&511](v);v=d+1856|0;F=yba(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}me[c[q>>2]&511](v);I=t-4|0;C=23}if((C|0)==23){C=0;v=d+1984|0;F=yba(d,p,1,v)|0;if((F|0)!=0){s=F;C=39;break a}me[c[q>>2]&511](v);v=d+2112|0;F=yba(d,p,2,v)|0;if((F|0)!=0){s=F;C=39;break a}me[c[q>>2]&511](v);v=0;do{F=ba(v+y|0,k)|0;H=v<<3&56;J=v>>3<<1;K=v>>1<<3;L=0;do{M=b[d+1472+((L>>3)+J<<7)+((L&7|H)<<1)>>1]|0;N=(L>>1)+K|0;O=(b[d+1984+(N<<1)>>1]|0)-128|0;P=(b[d+2112+(N<<1)>>1]|0)-128|0;N=((L+h|0)*3|0)+F|0;Q=((P*91881|0)+32768>>16)+M|0;if(Q>>>0>255>>>0){R=-Q>>31&255}else{R=Q&255}a[j+N|0]=R;Q=((O*-22554|0)+32768+(P*-46802|0)>>16)+M|0;if(Q>>>0>255>>>0){S=-Q>>31&255}else{S=Q&255}a[j+(N+1)|0]=S;Q=((O*116130|0)+32768>>16)+M|0;if(Q>>>0>255>>>0){T=-Q>>31&255}else{T=Q&255}a[j+(N+2)|0]=T;L=L+1|0;}while((L|0)<16);v=v+1|0;}while((v|0)<16);if((I|0)==0){s=0;C=39;break a}else{B=I}}v=u+1|0;if((v|0)<(z|0)){u=v;h=h+16|0;t=B}else{U=B;break}}}else{U=x}if((A|0)==0){V=0}else{V=A+r|0}t=w+1|0;if((t|0)<(e|0)){w=t;y=y+16|0;x=U;A=V}else{s=0;C=39;break}}if((C|0)==39){i=o;return s|0}return 0}function yba(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=(f|0)!=0;i=h&1;j=h?1486008:688264;me[c[a+36>>2]&511](g);h=c[a+1376+(i*20|0)+4>>2]|0;k=e+8|0;l=c[k>>2]|0;m=e+16|0;n=c[m>>2]|0;o=c[e>>2]|0;e=o+(l>>>3)|0;p=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(l&7)>>>23;e=b[h+(p<<2)>>1]|0;q=b[h+(p<<2)+2>>1]|0;p=q<<16>>16;do{if(q<<16>>16<0){r=l+9|0;s=n>>>0>r>>>0?r:n;r=o+(s>>>3)|0;t=((fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((p+32|0)>>>0))+e|0;r=b[h+(t<<2)>>1]|0;u=b[h+(t<<2)+2>>1]|0;t=u<<16>>16;if(!(u<<16>>16<0)){v=t;w=r;x=s;break}u=s-p|0;s=n>>>0>u>>>0?u:n;u=o+(s>>>3)|0;y=((fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(s&7)>>>((t+32|0)>>>0))+r|0;v=b[h+(y<<2)+2>>1]|0;w=b[h+(y<<2)>>1]|0;x=s}else{v=p;w=e;x=l}}while(0);l=v+x|0;x=n>>>0>l>>>0?l:n;c[k>>2]=x;if((w|0)<0){z=-1094995529;return z|0}if((w|0)==0){A=0}else{l=o+(x>>>3)|0;v=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(x&7);l=(v^-2147483648)>>31;e=x+w|0;c[k>>2]=n>>>0>e>>>0?e:n;A=((l^v)>>>((32-w|0)>>>0)^l)-l|0}l=ba(d[j]|0,A)|0;A=a+1456+(f<<2)|0;f=l+(c[A>>2]|0)|0;b[g>>1]=f;c[A>>2]=f;f=c[a+1416+(i*20|0)+4>>2]|0;i=c[m>>2]|0;m=0;A=c[k>>2]|0;while(1){l=o+(A>>>3)|0;w=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(A&7)>>>23;l=b[f+(w<<2)>>1]|0;v=b[f+(w<<2)+2>>1]|0;w=v<<16>>16;do{if(v<<16>>16<0){n=A+9|0;e=i>>>0>n>>>0?n:i;n=o+(e>>>3)|0;x=((fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(e&7)>>>((w+32|0)>>>0))+l|0;n=b[f+(x<<2)>>1]|0;p=b[f+(x<<2)+2>>1]|0;x=p<<16>>16;if(!(p<<16>>16<0)){B=x;C=n;D=e;break}p=e-w|0;e=i>>>0>p>>>0?p:i;p=o+(e>>>3)|0;h=((fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(e&7)>>>((x+32|0)>>>0))+n|0;B=b[f+(h<<2)+2>>1]|0;C=b[f+(h<<2)>>1]|0;D=e}else{B=w;C=l;D=A}}while(0);l=B+D|0;w=i>>>0>l>>>0?l:i;c[k>>2]=w;if((C|0)<0){z=-1094995529;E=17;break}l=(C>>4)+m|0;v=C&15;F=(v|0)!=0;if((l|0)>63){E=13;break}if(F){e=o+(w>>>3)|0;h=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(w&7);e=(h^-2147483648)>>31;n=w+v|0;x=i>>>0>n>>>0?n:i;c[k>>2]=x;n=(ba(((e^h)>>>((32-v|0)>>>0)^e)-e|0,d[j+(d[1075976+l|0]|0)|0]|0)|0)&65535;b[g+(d[a+1248+l|0]<<1)>>1]=n;G=x}else{G=w}if((l|0)<63){m=l;A=G}else{z=0;E=17;break}}if((E|0)==13){z=F?-1094995529:0;return z|0}else if((E|0)==17){return z|0}return 0}function zba(a){a=a|0;var d=0,e=0;d=c[a+60>>2]|0;c[a+416>>2]=1;e=a+448|0;c[e>>2]=4;c[e+4>>2]=0;c[a+420>>2]=1;b[d+2114>>1]=8;b[d+2170>>1]=2;c[d+2056>>2]=22;return 0}function Aba(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[a+60>>2]|0;m=8-(c[l+4>>2]|0)|0;n=c[766664+(m<<2)>>2]|0;o=g+28|0;c[e+76>>2]=c[o>>2]<<1;p=_$a(a,e,0)|0;if((p|0)<0){q=p;i=h;return q|0}p=c[g+24>>2]|0;g=c[o>>2]|0;a=g<<3;r=a>>>0>2147483639>>>0|(p|0)==0;s=r?0:p;p=r?8:a+8|0;if((g|0)>0){g=6-m|0;a=32-g|0;r=l+2060|0;t=r;u=l+2114|0;v=r;r=2-m|0;w=l+2116|0;x=w;y=l+2170|0;z=w;w=l+2056|0;A=l+8|0;l=A;B=A;C=0;D=0;E=c[e>>2]|0;while(1){e=s+(C>>>3)|0;F=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(C&7)>>>30;e=C+2|0;G=p>>>0>e>>>0?e:p;e=s+(G>>>3)|0;H=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(G&7)>>>(a>>>0);e=G+g|0;G=(p>>>0>e>>>0?e:p)+m|0;e=(ba(b[n+(H<<1)>>1]|0,b[u>>1]|0)|0)>>10;I=e+(b[v>>1]|0)|0;if((I|0)<-16384){J=-16384}else{J=(I|0)>16383?16383:I}alb(t,H>>r);H=(ba(b[1217784+(F<<1)>>1]|0,b[y>>1]|0)|0)>>10;I=H+(b[z>>1]|0)|0;if((I|0)<-16384){K=-16384}else{K=(I|0)>16383?16383:I}clb(x,H,F);F=c[w>>2]|0;c[w>>2]=F+1;b[l+(F<<1)>>1]=K+J;F=c[w>>2]|0;c[w>>2]=F+1;b[l+(F<<1)>>1]=J-K;dlb(B+((c[w>>2]|0)-24<<1)|0,j,k);F=c[j>>2]|0;H=F>>11;if((H+32768|0)>>>0>65535>>>0){L=(F>>31^32767)&65535}else{L=H&65535}b[E>>1]=L;H=c[k>>2]|0;F=H>>11;if((F+32768|0)>>>0>65535>>>0){M=(H>>31^32767)&65535}else{M=F&65535}b[E+2>>1]=M;F=c[w>>2]|0;if((F|0)>1023){VGb(A|0,B+(F-22<<1)|0,44)|0;c[w>>2]=22}F=D+1|0;if((F|0)<(c[o>>2]|0)){C=p>>>0>G>>>0?G:p;D=F;E=E+4|0}else{break}}}c[f>>2]=1;q=c[o>>2]|0;i=h;return q|0}function Bba(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;e=a+60|0;f=c[e>>2]|0;if((c[a+416>>2]|0)!=1){yDb(a,16,2188392,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=d;return h|0}b[f+2114>>1]=8;b[f+2170>>1]=2;c[f+2056>>2]=22;j=a+600|0;k=c[j>>2]|0;a:do{if((k|0)!=0){l=1<<k;m=l<<10;n=f+2188|0;o=l<<7;p=f+2172|0;q=l<<3;l=f+2180|0;r=0;while(1){if((r|0)>=2){break a}s=n+(r<<2)|0;c[s>>2]=cEb(m)|0;t=p+(r<<2)|0;c[t>>2]=cEb(o)|0;u=cEb(q)|0;c[l+(r<<2)>>2]=u;if((c[s>>2]|0)==0){break}if((c[t>>2]|0)==0|(u|0)==0){break}else{r=r+1|0}}r=c[e>>2]|0;$Db(r+2188|0);$Db(r+2172|0);$Db(r+2180|0);$Db(r+2192|0);$Db(r+2176|0);$Db(r+2184|0);h=-12;i=d;return h|0}}while(0);e=a+424|0;f=c[e>>2]|0;do{if((f|0)==0){c[e>>2]=320}else{k=(f|0)>32768;if(!((f&1|0)!=0|k)){break}if((f|0)==1){v=2}else{v=k?32768:f-1|0}yDb(a,24,2111e3,(g=i,i=i+16|0,c[g>>2]=v,c[g+8>>2]=f,g)|0);i=g;c[e>>2]=v}}while(0);c[a+116>>2]=22;v=c[j>>2]|0;if((v|0)==0){h=0;i=d;return h|0}if(!(v>>>0>16>>>0)){h=0;i=d;return h|0}if((v|0)<0){w=0}else{w=(v|0)>16?16:v}yDb(a,24,2052704,(g=i,i=i+16|0,c[g>>2]=w,c[g+8>>2]=v,g)|0);i=g;c[j>>2]=w;h=0;i=d;return h|0}function Cba(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0;h=i;i=i+56|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=c[d+60>>2]|0;r=q;s=c[f>>2]|0;t=f+76|0;u=((c[t>>2]|0)+1|0)/2|0;v=r0a(d,e,u,(u|0)<0|0?-1:0)|0;if((v|0)<0){w=v;i=h;return w|0}v=c[t>>2]|0;u=v&-2;x=c[d+600>>2]|0;y=e+24|0;z=c[y>>2]|0;do{if((x|0)==0){if((u|0)<=0){break}A=q+2056|0;B=q+8|0;C=q+2116|0;D=C;E=C;C=q+2170|0;G=q+2060|0;H=G;I=G;G=q+2114|0;J=z;K=0;while(1){L=J+1|0;M=b[s+(K<<1)>>1]|0;N=c[A>>2]|0;c[A>>2]=N+1;b[r+8+(N<<1)>>1]=M;M=b[s+((K|1)<<1)>>1]|0;N=c[A>>2]|0;c[A>>2]=N+1;b[r+8+(N<<1)>>1]=M;dlb(r+8+((c[A>>2]|0)-24<<1)|0,m,n);M=c[m>>2]|0;N=c[n>>2]|0;O=c[A>>2]|0;if((O|0)>1023){VGb(B|0,r+8+(O-22<<1)|0,44)|0;c[A>>2]=22}O=(M-N>>14)-(b[E>>1]|0)|0;if((O+32768|0)>>>0>65535>>>0){P=(O>>31^32767)&65535}else{P=O&65535}O=P<<16>>16;Q=b[C>>1]|0;R=((O>>31^O|0)<((Q*141|0)>>8|0)|((P&65535)>>>15&65535)<<1)^2;O=(N+M>>14)-(b[I>>1]|0)|0;if((O+32768|0)>>>0>65535>>>0){S=(O>>31^32767)&65535}else{S=O&65535}O=S<<16>>16;M=((O>>31^O)<<10)+1024|0;O=b[G>>1]|0;N=(M|0)>(O*370|0|0)?9:0;while(1){if((N|0)>=29){break}if((M|0)>(ba(b[766560+(N<<1)>>1]|0,O)|0)){N=N+1|0}else{break}}if(S<<16>>16<0){T=(N|0)<2?63:33}else{T=61}O=T-N|0;clb(D,(ba(b[1217784+(R<<1)>>1]|0,Q)|0)>>10,R);alb(H,O>>2);a[J]=O|R<<6;O=K+2|0;if((O|0)<(u|0)){J=L;K=O}else{break}}}else{K=1<<x;J=K<<3;H=c[q+2180>>2]|0;TGb(H|0,0,J|0)|0;D=q+2172|0;G=c[D>>2]|0;I=G+(K<<6)|0;c[H>>2]=I;c[G+(K<<6)+56>>2]=0;c[G+(K<<6)+60>>2]=0;G=q+2060|0;UGb(I|0,G|0,56)|0;I=c[q+2184>>2]|0;TGb(I|0,0,J|0)|0;J=q+2176|0;C=c[J>>2]|0;E=C+(K<<6)|0;c[I>>2]=E;c[C+(K<<6)+56>>2]=0;c[C+(K<<6)+60>>2]=0;C=q+2116|0;UGb(E|0,C|0,56)|0;E=v>>1;if((E|0)>0){A=K<<2;B=q+2056|0;O=q+8|0;M=(K|0)>0;U=(K|0)/2|0;V=q+2188|0;W=K>>1;X=W-1|0;Y=q+2192|0;Z=(K|0)>1;_=A-4|0;$=-1;aa=0;ca=0;da=0;ea=H+(K<<2)|0;fa=I+(K<<2)|0;ga=H;ha=I;while(1){ia=(da&1)<<x;ja=(c[D>>2]|0)+(ia<<6)|0;TGb(ea|0,0,A|0)|0;ka=(c[J>>2]|0)+(ia<<6)|0;TGb(fa|0,0,A|0)|0;ia=da<<1;la=b[s+(ia<<1)>>1]|0;ma=c[B>>2]|0;c[B>>2]=ma+1;b[r+8+(ma<<1)>>1]=la;la=b[s+((ia|1)<<1)>>1]|0;ia=c[B>>2]|0;c[B>>2]=ia+1;b[r+8+(ia<<1)>>1]=la;dlb(r+8+((c[B>>2]|0)-24<<1)|0,o,p);la=c[o>>2]|0;ia=c[p>>2]|0;ma=ia+la>>14;na=la-ia>>14;ia=c[B>>2]|0;if((ia|0)>1023){VGb(O|0,r+8+(ia-22<<1)|0,44)|0;c[B>>2]=22}a:do{if(M){ia=0;la=aa;oa=0;pa=ja;while(1){qa=c[ga+(oa<<2)>>2]|0;if((qa|0)==0){ra=la;break}sa=(oa|0)<(U|0)?4:0;ta=qa|0;ua=ma-(b[ta>>1]|0)|0;if((ua+32768|0)>>>0>65535>>>0){va=(ua>>31^32767)&65535}else{va=ua&65535}ua=va<<16>>16;wa=((ua>>31^ua)<<10)+1024|0;ua=qa+54|0;xa=b[ua>>1]|0;ya=(wa|0)>(xa*370|0|0)?9:0;while(1){if((ya|0)>=29){break}if((wa|0)>(ba(b[766560+(ya<<1)>>1]|0,xa)|0)){ya=ya+1|0}else{break}}if(va<<16>>16<0){za=(ya|0)<2?63:33}else{za=61}xa=za-ya|0;wa=xa-sa|0;Aa=xa+sa|0;if((wa|0)<=(Aa|0)&(wa|0)<64){xa=qa+56|0;Ba=qa;Ca=qa+60|0;Da=ia;Ea=la;Fa=wa;wa=pa;while(1){b:do{if((Fa|0)<0){Ga=Ea;Ha=Da;Ia=wa}else{Ja=(ba(b[1217624+(Fa<<1)>>1]|0,b[ua>>1]|0)|0)>>10;Ka=Ja+(b[ta>>1]|0)|0;if((Ka|0)<-16384){La=-16384}else{La=(Ka|0)>16383?16383:Ka}Ka=ma-La|0;Ja=lc(c[xa>>2]|0,ba(Ka,Ka)|0)|0;Ka=Ja;if(F){Ga=Ea;Ha=Da;Ia=wa;break}if((Da|0)<(K|0)){c[ea+(Da<<2)>>2]=wa;c[wa+60>>2]=Ea;Ma=Ea+1|0;Na=wa;Oa=Da;Pa=wa+64|0}else{Ja=(Da&X)+W|0;Qa=c[ea+(Ja<<2)>>2]|0;if(Ka>>>0<(c[Qa+56>>2]|0)>>>0){Ma=Ea;Na=Qa;Oa=Ja;Pa=wa}else{Ga=Ea;Ha=Da;Ia=wa;break}}Ja=Da+1|0;c[Na+56>>2]=Ka;UGb(Na|0,Ba|0,56)|0;alb(Na|0,Fa>>2);Qa=Na+60|0;Ra=c[V>>2]|0;c[Ra+(c[Qa>>2]<<3)>>2]=Fa;c[Ra+(c[Qa>>2]<<3)+4>>2]=c[Ca>>2];if((Oa|0)>0){Sa=Oa}else{Ga=Ma;Ha=Ja;Ia=Pa;break}while(1){Qa=Sa-1>>1;Ra=ea+(Qa<<2)|0;Ta=c[Ra>>2]|0;if(!((c[Ta+56>>2]|0)>>>0>Ka>>>0)){Ga=Ma;Ha=Ja;Ia=Pa;break b}Ua=ea+(Sa<<2)|0;Va=c[Ua>>2]|0;c[Ua>>2]=Ta;c[Ra>>2]=Va;if((Qa|0)>0){Sa=Qa}else{Ga=Ma;Ha=Ja;Ia=Pa;break}}}}while(0);Ja=Fa+4|0;if((Ja|0)<=(Aa|0)&(Ja|0)<64){Da=Ha;Ea=Ga;Fa=Ja;wa=Ia}else{Wa=Ha;Xa=Ga;Ya=Ia;break}}}else{Wa=ia;Xa=la;Ya=pa}wa=oa+1|0;if((wa|0)<(K|0)){ia=Wa;la=Xa;oa=wa;pa=Ya}else{ra=Xa;break}}pa=0;oa=ca;la=0;ia=ka;while(1){wa=c[ha+(la<<2)>>2]|0;if((wa|0)==0){Za=oa;_a=ra;break a}Fa=wa+54|0;Ea=wa|0;Da=wa+56|0;Aa=wa;Ca=wa+60|0;wa=pa;Ba=0;xa=oa;ta=ia;while(1){ua=(ba(b[1217784+(Ba<<1)>>1]|0,b[Fa>>1]|0)|0)>>10;qa=ua+(b[Ea>>1]|0)|0;if((qa|0)<-16384){$a=-16384}else{$a=(qa|0)>16383?16383:qa}qa=na-$a|0;sa=lc(c[Da>>2]|0,ba(qa,qa)|0)|0;qa=sa;c:do{if(F){ab=xa;bb=wa;cb=ta}else{if((wa|0)<(K|0)){c[fa+(wa<<2)>>2]=ta;c[ta+60>>2]=xa;db=ta;eb=xa+1|0;fb=wa;gb=ta+64|0}else{sa=(wa&X)+W|0;ya=c[fa+(sa<<2)>>2]|0;if(qa>>>0<(c[ya+56>>2]|0)>>>0){db=ya;eb=xa;fb=sa;gb=ta}else{ab=xa;bb=wa;cb=ta;break}}sa=wa+1|0;c[db+56>>2]=qa;UGb(db|0,Aa|0,56)|0;clb(db|0,ua,Ba);ya=db+60|0;Ja=c[Y>>2]|0;c[Ja+(c[ya>>2]<<3)>>2]=Ba;c[Ja+(c[ya>>2]<<3)+4>>2]=c[Ca>>2];if((fb|0)>0){hb=fb}else{ab=eb;bb=sa;cb=gb;break}while(1){ya=hb-1>>1;Ja=fa+(ya<<2)|0;Ka=c[Ja>>2]|0;if(!((c[Ka+56>>2]|0)>>>0>qa>>>0)){ab=eb;bb=sa;cb=gb;break c}Qa=fa+(hb<<2)|0;Va=c[Qa>>2]|0;c[Qa>>2]=Ka;c[Ja>>2]=Va;if((ya|0)>0){hb=ya}else{ab=eb;bb=sa;cb=gb;break}}}}while(0);qa=Ba+1|0;if((qa|0)<4){wa=bb;Ba=qa;xa=ab;ta=cb}else{break}}ta=la+1|0;if((ta|0)<(K|0)){pa=bb;oa=ab;la=ta;ia=cb}else{Za=ab;_a=ra;break}}}else{Za=ca;_a=aa}}while(0);na=c[ea>>2]|0;ka=na+56|0;ma=(c[ka>>2]|0)>>>0>65536>>>0;do{if(Z){if(ma){ja=1;do{L=c[ea+(ja<<2)>>2]|0;if((L|0)==0){break}R=L+56|0;c[R>>2]=(c[R>>2]|0)-(c[ka>>2]|0);ja=ja+1|0;}while((ja|0)<(K|0));c[ka>>2]=0}ja=c[fa>>2]|0;R=ja+56|0;if((c[R>>2]|0)>>>0>65536>>>0){ib=1}else{jb=ja;break}do{L=c[fa+(ib<<2)>>2]|0;if((L|0)==0){break}Q=L+56|0;c[Q>>2]=(c[Q>>2]|0)-(c[R>>2]|0);ib=ib+1|0;}while((ib|0)<(K|0));c[R>>2]=0;jb=ja}else{if(ma){c[ka>>2]=0}Q=c[fa>>2]|0;L=Q+56|0;if(!((c[L>>2]|0)>>>0>65536>>>0)){jb=Q;break}c[L>>2]=0;jb=Q}}while(0);if((da|0)==($+128|0)){if((da|0)>($|0)){ka=(c[V>>2]|0)+(c[na+60>>2]<<3)|0;ma=(c[Y>>2]|0)+(c[jb+60>>2]<<3)|0;Q=da;while(1){a[z+Q|0]=c[ma>>2]<<6|c[ka>>2];L=Q-1|0;if((L|0)>($|0)){ka=(c[V>>2]|0)+(c[ka+4>>2]<<3)|0;ma=(c[Y>>2]|0)+(c[ma+4>>2]<<3)|0;Q=L}else{break}}}TGb(ea+4|0,0,_|0)|0;TGb(fa+4|0,0,_|0)|0;kb=0;lb=0;mb=da}else{kb=Za;lb=_a;mb=$}Q=da+1|0;if((Q|0)<(E|0)){ma=fa;ka=ea;ea=ga;fa=ha;$=mb;aa=lb;ca=kb;da=Q;ha=ma;ga=ka}else{break}}if((E|0)>(mb|0)){nb=Y;ob=V;pb=ea;qb=fa;rb=E;sb=mb;tb=61}else{ub=ea;vb=fa}}else{nb=q+2192|0;ob=q+2188|0;pb=H;qb=I;rb=0;sb=-1;tb=61}if((tb|0)==61){ga=(c[ob>>2]|0)+(c[(c[pb>>2]|0)+60>>2]<<3)|0;ha=(c[nb>>2]|0)+(c[(c[qb>>2]|0)+60>>2]<<3)|0;da=rb;while(1){a[z+da|0]=c[ha>>2]<<6|c[ga>>2];ca=da-1|0;if((ca|0)>(sb|0)){ga=(c[ob>>2]|0)+(c[ga+4>>2]<<3)|0;ha=(c[nb>>2]|0)+(c[ha+4>>2]<<3)|0;da=ca}else{ub=pb;vb=qb;break}}}UGb(G|0,c[ub>>2]|0,56)|0;UGb(C|0,c[vb>>2]|0,56)|0}}while(0);if((u|0)<(c[t>>2]|0)){t=b[s+(u<<1)>>1]|0;u=(c[y>>2]|0)+(v>>1)|0;v=q+2056|0;y=c[v>>2]|0;c[v>>2]=y+1;b[r+8+(y<<1)>>1]=t;y=c[v>>2]|0;c[v>>2]=y+1;b[r+8+(y<<1)>>1]=t;dlb(r+8+((c[v>>2]|0)-24<<1)|0,k,l);t=c[k>>2]|0;k=c[l>>2]|0;l=c[v>>2]|0;if((l|0)>1023){VGb(q+8|0,r+8+(l-22<<1)|0,44)|0;c[v>>2]=22}v=q+2116|0;l=v;r=(t-k>>14)-(b[v>>1]|0)|0;if((r+32768|0)>>>0>65535>>>0){wb=(r>>31^32767)&65535}else{wb=r&65535}r=wb<<16>>16;v=b[q+2170>>1]|0;y=((r>>31^r|0)<((v*141|0)>>8|0)|((wb&65535)>>>15&65535)<<1)^2;wb=q+2060|0;r=wb;s=(k+t>>14)-(b[wb>>1]|0)|0;if((s+32768|0)>>>0>65535>>>0){xb=(s>>31^32767)&65535}else{xb=s&65535}s=xb<<16>>16;wb=((s>>31^s)<<10)+1024|0;s=b[q+2114>>1]|0;q=(wb|0)>(s*370|0|0)?9:0;while(1){if((q|0)>=29){break}if((wb|0)>(ba(b[766560+(q<<1)>>1]|0,s)|0)){q=q+1|0}else{break}}if(xb<<16>>16<0){yb=(q|0)<2?63:33}else{yb=61}xb=yb-q|0;clb(l,(ba(b[1217784+(y<<1)>>1]|0,v)|0)>>10,y);alb(r,xb>>2);a[u]=xb|y<<6}y=f+136|0;f=c[y>>2]|0;xb=c[y+4>>2]|0;if(!((f|0)==0&(xb|0)==(-2147483648|0))){y=c[d+116>>2]|0;c[j>>2]=1;c[j+4>>2]=c[d+412>>2];u=KDb(y,(y|0)<0|0?-1:0,j,d+104|0)|0;d=ZGb(f,xb,u,F)|0;u=e+8|0;c[u>>2]=d;c[u+4>>2]=F}c[g>>2]=1;w=0;i=h;return w|0}function Dba(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+2188|0);$Db(b+2172|0);$Db(b+2180|0);$Db(b+2192|0);$Db(b+2176|0);$Db(b+2184|0);return 0}function Eba(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;c[a+420>>2]=1;c[a+416>>2]=1;c[b+1360>>2]=4096;UGb(b+144|0,1407920,20)|0;UGb(b+164|0,1407920,20)|0;c[b+1336>>2]=12345;c[b+120>>2]=1;return 0}function Fba(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0;k=i;i=i+2088|0;l=k|0;m=k+16|0;n=k+104|0;o=k+192|0;p=k+672|0;q=k+792|0;r=k+832|0;s=k+1832|0;t=k+1864|0;u=k+1888|0;v=k+1968|0;w=c[f+60>>2]|0;x=w;y=g;z=c[j+24>>2]|0;A=c[j+28>>2]|0;j=w+1368|0;B=j;C=j;D=d[1046632+(a[z]&3)|0]|0;if((A|0)<(D|0)){if((A|0)!=0){yDb(f,24,1969184,(E=i,i=i+16|0,c[E>>2]=D,c[E+8>>2]=A,E)|0);i=E}c[h>>2]=0;G=A;i=k;return G|0}E=A<<3;A=E>>>0>2147483639>>>0|(z|0)==0;H=A?0:z;z=A?8:E+8|0;E=H;A=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24)&3;E=z>>>0>2>>>0?2:z;a:do{if((A|0)==3){c[w+116>>2]=2;I=0}else{J=H+(E>>>3)|0;K=E+8|0;L=z>>>0>K>>>0?K:z;a[w+130|0]=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((E&2)>>>0);J=H+(L>>>3)|0;K=L+8|0;M=z>>>0>K>>>0?K:z;a[w+129|0]=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((L&7)>>>0);L=H+(M>>>3)|0;J=M+8|0;K=z>>>0>J>>>0?J:z;a[w+128|0]=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((M&7)>>>0);if((A|0)==2){c[w+116>>2]=1;M=H+(K>>>3)|0;c[w+24>>2]=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((K&7)>>>0)&63;I=0;break}M=w+124|0;c[M>>2]=(A|0)!=0;L=w+116|0;c[L>>2]=0;J=H+(K>>>3)|0;N=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((K&7)>>>0)&127;J=K+7|0;K=z>>>0>J>>>0?J:z;J=w+132|0;c[J>>2]=N;b:do{if(!(N>>>0>123>>>0)){c[J>>2]=N+18;O=H+(K>>>3)|0;P=K+2|0;Q=z>>>0>P>>>0?P:z;c[w+32>>2]=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((K&7)>>>0)&3;O=H+(Q>>>3)|0;P=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((Q&7)>>>0)&127;O=Q+7|0;Q=z>>>0>O>>>0?O:z;O=w+136|0;c[O>>2]=P;if(P>>>0>123>>>0){break}c[O>>2]=P+18;P=H+(Q>>>3)|0;O=Q+2|0;R=z>>>0>O>>>0?O:z;c[w+88>>2]=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((Q&7)>>>0)&3;c[w+4>>2]=1;c[w+60>>2]=1;Q=c[299912]|0;P=0;O=R;S=0;T=H+(R>>>3)|0;do{R=T;U=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((O&7)>>>0);R=U&4095;V=O+12|0;O=z>>>0>V>>>0?V:z;V=x+4+(S*28|0)+8|0;c[V>>2]=0;do{if((c[M>>2]|0)==0){if((c[x+132+(S>>1<<2)>>2]|0)>=58){W=R;X=170;break}c[V>>2]=R>>>11;W=U&2047;X=85}else{W=R;X=170}}while(0);gHb(W,0,Q,P)|0;R=F;c[x+4+(S*28|0)+4>>2]=R;if(!(R>>>0<X>>>0)){break b}c[x+4+(S*28|0)+20>>2]=(R*-24|0)+W;S=S+1|0;T=H+(O>>>3)|0}while((S|0)<4);S=((O|0)<(z|0))+O|0;c[w+20>>2]=(d[T]|0)>>>((O&7)>>>0)&1;P=((S|0)<(z|0))+S|0;c[w+48>>2]=(d[H+(S>>>3)|0]|0)>>>((S&7)>>>0)&1;S=((P|0)<(z|0))+P|0;c[w+76>>2]=(d[H+(P>>>3)|0]|0)>>>((P&7)>>>0)&1;P=((S|0)<(z|0))+S|0;c[w+104>>2]=(d[H+(S>>>3)|0]|0)>>>((S&7)>>>0)&1;if((c[M>>2]|0)==0){S=P+1|0;Q=z>>>0>S>>>0?S:z;S=H+(Q>>>3)|0;R=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((Q&7)>>>0)&8191;S=Q+13|0;Q=z>>>0>S>>>0?S:z;S=(R>>>0)/810|0;U=w+28|0;c[U>>2]=S;V=R+(S*-810|0)|0;gHb(V,(V|0)<0|0?-1:0,c[299978]|0,0)|0;R=F;Y=R;Z=w+56|0;c[Z>>2]=Y;_=(Y*-90|0)+V|0;gHb(_,(_|0)<0|0?-1:0,c[299897]|0,0)|0;V=F;Y=V;$=w+84|0;c[$>>2]=Y;aa=(Y*-9|0)+_|0;_=w+112|0;c[_>>2]=aa;Y=H+(Q>>>3)|0;ca=Q+16|0;da=z>>>0>ca>>>0?ca:z;c[U>>2]=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((Q&7)>>>0)&65535|S<<16;S=H+(da>>>3)|0;Q=da+14|0;Y=z>>>0>Q>>>0?Q:z;c[Z>>2]=R<<14|0>>>18|(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((da&7)>>>0)&16383;da=H+(Y>>>3)|0;S=Y+16|0;R=z>>>0>S>>>0?S:z;c[$>>2]=V<<16|0>>>16|(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((Y&7)>>>0)&65535;Y=H+(R>>>3)|0;da=R+14|0;V=z>>>0>da>>>0?da:z;c[_>>2]=aa<<14|(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&16383;R=H+(V>>>3)|0;Y=V+6|0;aa=z>>>0>Y>>>0?Y:z;c[w+16>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((V&7)>>>0)&63;V=H+(aa>>>3)|0;R=aa+5|0;Y=z>>>0>R>>>0?R:z;c[w+44>>2]=(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((aa&7)>>>0)&31;aa=H+(Y>>>3)|0;V=Y+6|0;R=z>>>0>V>>>0?V:z;c[w+72>>2]=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((Y&7)>>>0)&63;Y=H+(R>>>3)|0;c[w+100>>2]=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&31;I=0;break a}else{R=H+(P>>>3)|0;Y=P+12|0;aa=z>>>0>Y>>>0?Y:z;c[w+28>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((P&7)>>>0)&4095;P=H+(aa>>>3)|0;R=aa+12|0;Y=z>>>0>R>>>0?R:z;c[w+56>>2]=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((aa&7)>>>0)&4095;aa=H+(Y>>>3)|0;P=Y+12|0;R=z>>>0>P>>>0?P:z;c[w+84>>2]=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((Y&7)>>>0)&4095;Y=H+(R>>>3)|0;aa=R+12|0;P=z>>>0>aa>>>0?aa:z;c[w+112>>2]=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&4095;R=H+(P>>>3)|0;Y=P+4|0;aa=z>>>0>Y>>>0?Y:z;c[w+16>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((P&7)>>>0)&15;P=H+(aa>>>3)|0;R=aa+4|0;Y=z>>>0>R>>>0?R:z;c[w+44>>2]=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((aa&7)>>>0)&15;aa=H+(Y>>>3)|0;P=Y+4|0;R=z>>>0>P>>>0?P:z;c[w+72>>2]=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((Y&7)>>>0)&15;Y=H+(R>>>3)|0;c[w+100>>2]=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&15;I=0;break a}}}while(0);if((c[w+120>>2]|0)==0){c[L>>2]=0;I=1;break}else{c[L>>2]=2;I=1;break}}}while(0);c[g+76>>2]=240;H=_$a(f,y,0)|0;if((H|0)<0){G=H;i=k;return G|0}H=g;g=c[H>>2]|0;y=w+116|0;f=c[y>>2]|0;do{if((f|0)==0){z=w+140|0;do{if((I|0)==0){c[z>>2]=0}else{W=c[z>>2]|0;if((W|0)==3){break}c[z>>2]=W+1}}while(0);L=t|0;W=w+144|0;X=W;Jba(L,X,w+128|0,I);Kba(u|0,L,X);UGb(W|0,t|0,20)|0;W=w+474|0;X=W;L=w+184|0;UGb(W|0,L|0,290)|0;A=c[z>>2]|0;do{if((A|0)==0){E=w+764|0;M=w+4|0;c[w+1344>>2]=b[1049952+((c[w+108>>2]|0)+(c[w+80>>2]|0)>>1<<1)>>1]|0;K=w+124|0;N=w+132|0;J=p;R=v|0;Y=0;aa=E;while(1){P=M+(Y*28|0)|0;V=c[K>>2]|0;_=N+(Y>>1<<2)|0;da=c[_>>2]|0;$=aa;TGb($|0,0,120)|0;do{if((V|0)==0){S=c[M+(Y*28|0)+24>>2]|0;if((S|0)>=(c[679616+(Y<<2)>>2]|0)){break}Z=M+(Y*28|0)+12|0;Q=M+(Y*28|0)+20|0;U=M+(Y*28|0)+16|0;ca=6-(a[559728+Y|0]|0)|0;ea=0;fa=S;while(1){S=fa-(c[1421792+(ca*120|0)+(ea<<2)>>2]|0)|0;if((S|0)>-1){ga=S;ha=ca}else{S=ca+1|0;ia=b[1049952+(c[Q>>2]<<1)>>1]|0;if((c[Z>>2]&1<<5-ca|0)==0){b[aa+((c[U>>2]|0)+(ea<<1)<<1)>>1]=ia}else{b[aa+((c[U>>2]|0)+(ea<<1)<<1)>>1]=-ia}if((S|0)==6){break}else{ga=fa;ha=S}}S=ea+1|0;if((S|0)<30){ca=ha;ea=S;fa=ga}else{break}}if((c[M+(Y*28|0)+8>>2]|0)!=1){break}UGb(J|0,$|0,120)|0;if((da|0)<60){ja=da}else{break}do{fa=60-ja|0;if((fa|0)>0){ea=0;do{ca=aa+(ea+ja<<1)|0;b[ca>>1]=(b[ca>>1]|0)+(b[p+(ea<<1)>>1]|0);ea=ea+1|0;}while((ea|0)<(fa|0))}ja=ja+da|0;}while((ja|0)<60)}else{fa=b[1049952+(c[M+(Y*28|0)+20>>2]<<1)>>1]|0;ea=c[M+(Y*28|0)+16>>2]|0;ca=c[M+(Y*28|0)+12>>2]|0;U=c[M+(Y*28|0)+24>>2]|0;Z=-fa&65535;b[aa+((U<<3&56)+ea<<1)>>1]=(ca&1|0)!=0?fa:Z;b[aa+(ea+2+(U>>3<<3&56)<<1)>>1]=(ca&2|0)!=0?fa:Z;b[aa+(ea+4+(U>>6<<3&56)<<1)>>1]=(ca&4|0)!=0?fa:Z;b[aa+(ea+6+(U>>9<<3&56)<<1)>>1]=(ca&8|0)!=0?fa:Z;Z=c[M+(Y*28|0)+4>>2]<<1;fa=da-1+(b[588688+(Z<<1)>>1]|0)+(c[P>>2]|0)|0;ca=b[588688+((Z|1)<<1)>>1]|0;if((fa|0)<58){ka=fa}else{break}do{Z=(ba(b[aa+(ka-fa<<1)>>1]|0,ca)|0)>>>15;U=aa+(ka<<1)|0;b[U>>1]=Z+(e[U>>1]|0);ka=ka+1|0;}while((ka|0)<60)}}while(0);Mba(R,X+((Y*60|0)<<1)|0,c[_>>2]|0,P,c[K>>2]|0);da=0;do{$=aa+(da<<1)|0;V=b[$>>1]|0;ca=V<<1;if((ca+32768|0)>>>0>65535>>>0){la=(V>>30^32767)&65535}else{la=ca&65535}ca=(b[v+(da<<1)>>1]|0)+(la<<16>>16)|0;if((ca+32768|0)>>>0>65535>>>0){ma=(ca>>31^32767)&65535}else{ma=ca&65535}b[$>>1]=ma;da=da+1|0;}while((da|0)<60);da=Y+1|0;if((da|0)<4){Y=da;aa=aa+120|0}else{break}}aa=c[w+136>>2]|0;Y=w+1348|0;R=w+1352|0;M=0;J=0;do{O=b[x+474+(J<<1)>>1]|0;T=O<<16>>16;M=(O<<16>>16>-1?T:-T|0)|M;J=J+1|0;}while((J|0)<385);J=Y;T=R;O=(M&65280|0)==0;da=(O?14:6)-(d[1191992+(O?M:M>>>8)|0]|0)|0;O=(da|0)>0?da:0;da=0;do{b[x+1368+(da+10<<1)>>1]=b[x+474+(da<<1)>>1]<<O>>>3;da=da+1|0;}while((da|0)<385);c[T>>2]=O-3;da=w+1918|0;M=(aa|0)<142?aa:142;R=M+3|0;Y=0;P=M-3|0;M=0;do{_=C$(da,x+1368+(275-P<<1)|0,120)|0;$=_;_=0>>>31|$<<1;ca=YGb(_,$>>31|(($|0)<0|0?-1:0)<<1,-2147483648,0)|0;V=F;fa=0;if(V>>>0>fa>>>0|V>>>0==fa>>>0&ca>>>0>-1>>>0){(($|0)<0|0?-1:0)>>31|(($|0)<0|0?-1:0)<<1;na=($>>31|(($|0)<0|0?-1:0)<<1)^2147483647}else{na=_}_=(na|0)>(M|0);M=_?na:M;Y=_?P:Y;P=P+1|0;}while((P|0)<=(R|0));R=M;P=(M|0)<0|0?-1:0;aa=YGb(R,P,32768,0)|0;O=F;T=YGb(R,P,-2147450880,0)|0;P=F;R=0;if(P>>>0>R>>>0|P>>>0==R>>>0&T>>>0>-1>>>0){((O|0)<0|0?-1:0)>>31|((O|0)<0|0?-1:0)<<1;oa=(O>>31|((O|0)<0|0?-1:0)<<1)^2147483647}else{oa=aa}aa=oa>>16;O=C$(da,da,120)|0;T=O;O=0>>>31|T<<1;R=YGb(O,T>>31|((T|0)<0|0?-1:0)<<1,-2147483648,0)|0;P=F;_=0;if(P>>>0>_>>>0|P>>>0==_>>>0&R>>>0>-1>>>0){((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;pa=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{pa=O}O=pa;T=(pa|0)<0|0?-1:0;R=YGb(O,T,32768,0)|0;_=F;P=YGb(O,T,-2147450880,0)|0;T=F;O=0;if(T>>>0>O>>>0|T>>>0==O>>>0&P>>>0>-1>>>0){((_|0)<0|0?-1:0)>>31|((_|0)<0|0?-1:0)<<1;qa=(_>>31|((_|0)<0|0?-1:0)<<1)^2147483647}else{qa=R}c[J>>2]=qa>>16;if((aa|0)<1){ra=0}else{R=x+1368+(275-Y<<1)|0;_=C$(R,R,120)|0;R=_;_=0>>>31|R<<1;P=YGb(_,R>>31|((R|0)<0|0?-1:0)<<1,-2147483648,0)|0;O=F;T=0;if(O>>>0>T>>>0|O>>>0==T>>>0&P>>>0>-1>>>0){((R|0)<0|0?-1:0)>>31|((R|0)<0|0?-1:0)<<1;sa=(R>>31|((R|0)<0|0?-1:0)<<1)^2147483647}else{sa=_}_=sa;R=(sa|0)<0|0?-1:0;P=YGb(_,R,32768,0)|0;T=F;O=YGb(_,R,-2147450880,0)|0;R=F;_=0;if(R>>>0>_>>>0|R>>>0==_>>>0&O>>>0>-1>>>0){((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;ta=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{ta=P}P=((ba(ta>>16,c[J>>2]|0)|0)>>3|0)<(ba(aa,aa)|0);ra=P?Y:0}c[w+1340>>2]=ra;if((c[w+1364>>2]|0)==0){ua=w+744|0}else{P=0;aa=145;while(1){T=c[N+(P>>1<<2)>>2]|0;O=s+(P<<3)|0;_=c[K>>2]|0;R=aa+10|0;$=x+1368+(R<<1)|0;ca=(T|0)<142?T:142;T=385-aa-60|0;fa=ca+3|0;V=(T|0)>(fa|0)?fa:T;T=ca-3|0;if((T|0)>(V|0)){va=0;wa=0}else{ca=0;U=T;Z=0;while(1){ea=C$($,x+1368+(U+R<<1)|0,60)|0;Q=ea;ea=0>>>31|Q<<1;S=YGb(ea,Q>>31|((Q|0)<0|0?-1:0)<<1,-2147483648,0)|0;ia=F;xa=0;if(ia>>>0>xa>>>0|ia>>>0==xa>>>0&S>>>0>-1>>>0){((Q|0)<0|0?-1:0)>>31|((Q|0)<0|0?-1:0)<<1;ya=(Q>>31|((Q|0)<0|0?-1:0)<<1)^2147483647}else{ya=ea}ea=(ya|0)>(Z|0);Q=ea?ya:Z;S=ea?U:ca;ea=U+1|0;if((ea|0)>(V|0)){va=S;wa=Q;break}else{ca=S;U=ea;Z=Q}}}Z=0;U=T;ca=0;do{V=C$($,x+1368+(R-U<<1)|0,60)|0;Q=V;V=0>>>31|Q<<1;ea=YGb(V,Q>>31|((Q|0)<0|0?-1:0)<<1,-2147483648,0)|0;S=F;xa=0;if(S>>>0>xa>>>0|S>>>0==xa>>>0&ea>>>0>-1>>>0){((Q|0)<0|0?-1:0)>>31|((Q|0)<0|0?-1:0)<<1;za=(Q>>31|((Q|0)<0|0?-1:0)<<1)^2147483647}else{za=V}V=(za|0)>(ca|0);ca=V?za:ca;Z=V?U:Z;U=U+1|0;}while((U|0)<=(fa|0));c[O>>2]=0;b[s+(P<<3)+4>>1]=0;b[s+(P<<3)+6>>1]=32767;fa=(Z|0)!=0;do{if(!((va|0)==0&(fa^1))){U=C$($,$,60)|0;T=U;U=0>>>31|T<<1;V=YGb(U,T>>31|((T|0)<0|0?-1:0)<<1,-2147483648,0)|0;Q=F;ea=0;if(Q>>>0>ea>>>0|Q>>>0==ea>>>0&V>>>0>-1>>>0){((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;Aa=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{Aa=U}U=(va|0)!=0;do{if(U){T=x+1368+(va+R<<1)|0;V=C$(T,T,60)|0;T=V;V=0>>>31|T<<1;ea=YGb(V,T>>31|((T|0)<0|0?-1:0)<<1,-2147483648,0)|0;Q=F;xa=0;if(!(Q>>>0>xa>>>0|Q>>>0==xa>>>0&ea>>>0>-1>>>0)){Ba=V;break}((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;Ba=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{Ba=0}}while(0);do{if(fa){T=x+1368+(R-Z<<1)|0;V=C$(T,T,60)|0;T=V;V=0>>>31|T<<1;ea=YGb(V,T>>31|((T|0)<0|0?-1:0)<<1,-2147483648,0)|0;xa=F;Q=0;if(!(xa>>>0>Q>>>0|xa>>>0==Q>>>0&ea>>>0>-1>>>0)){Ca=V;break}((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;Ca=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{Ca=0}}while(0);T=(Aa|0)>0?Aa:0;V=(wa|0)>(T|0)?wa:T;T=(Ba|0)>(V|0)?Ba:V;V=(ca|0)>(T|0)?ca:T;T=(Ca|0)>(V|0)?Ca:V;V=T>>>0>65535>>>0;ea=V?T>>>16:T;T=V?16:0;if((ea&65280|0)==0){Da=T;Ea=ea}else{Da=T|8;Ea=ea>>>8}ea=30-Da-(d[1191992+Ea|0]|0)|0;T=Aa<<ea>>16;V=wa<<ea>>16;Q=Ba<<ea>>16;xa=ca<<ea>>16;S=Ca<<ea>>16;if(!(fa|U^1)){Pba(va,O,_,T,V,Q);break}if(!U){Pba(-Z|0,O,_,T,xa,S);break}if((ba(((ba(V,V)|0)+16384|0)>>>15,S)|0)<(ba(((ba(xa,xa)|0)+16384|0)>>>15,Q)|0)){Pba(-Z|0,O,_,T,xa,S);break}else{Pba(va,O,_,T,V,Q);break}}}while(0);_=P+1|0;if((_|0)<4){P=_;aa=aa+60|0}else{break}}Lgb(w+1388|0,E,E+(c[s>>2]<<1)|0,b[s+6>>1]|0,b[s+4>>1]|0,16384,15,60);Lgb(w+1508|0,w+884|0,E+((c[s+8>>2]|0)+60<<1)|0,b[s+14>>1]|0,b[s+12>>1]|0,16384,15,60);Lgb(w+1628|0,w+1004|0,E+((c[s+16>>2]|0)+120<<1)|0,b[s+22>>1]|0,b[s+20>>1]|0,16384,15,60);Lgb(w+1748|0,w+1124|0,E+((c[s+24>>2]|0)+180<<1)|0,b[s+30>>1]|0,b[s+28>>1]|0,16384,15,60);ua=C}UGb(L|0,w+954|0,290)|0;Fa=ua}else{aa=w+1344|0;P=((c[aa>>2]|0)*3|0)+2>>2;c[aa>>2]=P;if((A|0)==3){TGb(L|0,0,1060)|0;TGb(c[H>>2]|0,0,500)|0;Fa=C;break}aa=w+1388|0;K=W;N=c[w+1340>>2]|0;Y=w+1332|0;if((N|0)==0){J=0;da=c[Y>>2]|0;do{da=(da*521|0)+259|0;b[aa+(J<<1)>>1]=(ba(da,P)|0)>>>15;J=J+1|0;}while((J|0)<240);c[Y>>2]=da;TGb(W|0,0,770)|0}else{if((N|0)>0){J=145-N|0;P=0;do{b[aa+(P<<1)>>1]=((b[K+(J+P<<1)>>1]|0)*3|0)>>>2;P=P+1|0;}while((P|0)<(N|0))}iEb(aa+(N<<1)|0,N<<1,240-N<<1)}UGb(L|0,w+1578|0,290)|0;Fa=C}}while(0);c[w+1336>>2]=12345;Ga=Fa}else if((f|0)==1){L=c[w+24>>2]|0;do{if((L|0)<16){Ha=L<<6}else{if((L|0)<32){Ha=(L<<7)-1024|0;break}else{Ha=(L<<8)-5120|0;break}}}while(0);c[w+1348>>2]=Ha;Jba(w+164|0,w+144|0,w+128|0,0);if((c[w+120>>2]|0)==0){Ia=137}else{Ia=138}}else{if((c[w+120>>2]|0)!=0){Ia=138;break}L=w+1348|0;W=c[L>>2]|0;A=16-(c[w+1352>>2]<<1)|0;if((A|0)>0){Ja=W<<A}else{Ja=W>>-A}A=(Ja*273|0)>>16;if((A|0)>18431){Ka=4;La=3}else{Ka=3;La=(A|0)>2047|0}W=1<<Ka;X=La<<5;z=(W<<La)+X|0;P=W;J=0;K=W;W=ba(z,z)|0;do{K=K>>1;P=((A|0)<(W|0)?-K|0:K)+P|0;J=J+1|0;z=(P<<La)+X|0;W=ba(z,z)|0}while((J|0)<(Ka|0));J=W-A|0;do{if((J|0)<1){K=(P+1<<La)+X|0;z=(La<<4)-16+P|0;if(((ba(K,K)|0)-A|0)<(J|0)){Ma=z;break}Ma=z+1|0}else{z=(P-1<<La)+X|0;K=(La<<4)-16+P|0;if(((ba(z,z)|0)-A|0)<(J|0)){Ma=K;break}Ma=K-1|0}}while(0);c[L>>2]=Ma;Ia=137}}while(0);if((Ia|0)==137){c[w+1352>>2]=c[w+1348>>2];Ia=139}else if((Ia|0)==138){Ma=w+1352|0;c[Ma>>2]=((c[Ma>>2]|0)*7|0)+(c[w+1348>>2]|0)>>3;Ia=139}if((Ia|0)==139){Ma=w+1336|0;La=((c[Ma>>2]|0)*521|0)+259|0;c[w+132>>2]=(((La&32767)*21|0)>>>15)+123;Ka=((La&65535)*521|0)+259|0;c[w+136>>2]=(((Ka&32767)*19|0)>>>15)+123;La=((Ka&65535)*521|0)+259|0;c[w+8>>2]=(((La&32767)*50|0)>>>15)+1;c[w+4>>2]=1;Ka=((La&65535)*521|0)+259|0;c[w+36>>2]=(((Ka&32767)*50|0)>>>15)+1;c[w+32>>2]=0;La=((Ka&65535)*521|0)+259|0;c[w+64>>2]=(((La&32767)*50|0)>>>15)+1;c[w+60>>2]=1;Ka=((La&65535)*521|0)+259|0;La=Ka&65535;c[Ma>>2]=La;c[w+92>>2]=(((Ka&32767)*50|0)>>>15)+1;c[w+88>>2]=3;Ka=0;Ja=La;do{La=(Ja*521|0)+259|0;Ha=Ka<<1;c[l+(Ha<<2)>>2]=La>>>2&1;c[l+((Ha|1)<<2)>>2]=La>>>3&1|60;Ha=La>>>4&2047;f=Ka*11|0;c[m+(f<<2)>>2]=(Ha<<15&32768)-16384;c[m+(f+1<<2)>>2]=(Ha>>>1<<15&32768)-16384;c[m+(f+2<<2)>>2]=(Ha>>>2<<15&32768)-16384;c[m+(f+3<<2)>>2]=(Ha>>>3<<15&32768)-16384;c[m+(f+4<<2)>>2]=(Ha>>>4<<15&32768)-16384;c[m+(f+5<<2)>>2]=(Ha>>>5<<15&32768)-16384;c[m+(f+6<<2)>>2]=(Ha>>>6<<15&32768)-16384;c[m+(f+7<<2)>>2]=(Ha>>>7<<15&32768)-16384;c[m+(f+8<<2)>>2]=(Ha>>>8<<15&32768)-16384;c[m+(f+9<<2)>>2]=(Ha>>>9<<15&32768)-16384;c[m+(f+10<<2)>>2]=(Ha>>>10<<15)-16384;Ja=La&65535;Ka=Ka+1|0;}while((Ka|0)<2);c[Ma>>2]=Ja;Ka=o|0;La=o+4|0;Ha=o+8|0;f=o+12|0;Fa=o+16|0;H=o+20|0;ua=o+24|0;s=o+28|0;va=o+32|0;Ca=o+36|0;Ba=o+40|0;wa=o+44|0;Aa=o+48|0;Ea=o+52|0;Da=o+56|0;za=o+60|0;ya=o+64|0;ra=o+68|0;ta=o+72|0;sa=o+76|0;qa=o+80|0;pa=o+84|0;oa=o+88|0;na=o+92|0;ma=o+96|0;la=o+100|0;v=o+104|0;ka=o+108|0;ja=o+112|0;p=o+116|0;ga=0;ha=0;t=Ja;while(1){c[Ka>>2]=0;c[La>>2]=1;c[Ha>>2]=2;c[f>>2]=3;c[Fa>>2]=4;c[H>>2]=5;c[ua>>2]=6;c[s>>2]=7;c[va>>2]=8;c[Ca>>2]=9;c[Ba>>2]=10;c[wa>>2]=11;c[Aa>>2]=12;c[Ea>>2]=13;c[Da>>2]=14;c[za>>2]=15;c[ya>>2]=16;c[ra>>2]=17;c[ta>>2]=18;c[sa>>2]=19;c[qa>>2]=20;c[pa>>2]=21;c[oa>>2]=22;c[na>>2]=23;c[ma>>2]=24;c[la>>2]=25;c[v>>2]=26;c[ka>>2]=27;c[ja>>2]=28;c[p>>2]=29;Ja=c[l+(ha<<2)>>2]|0;I=a[559728+ha|0]|0;J=(I|0)>1;A=1;P=ga;X=30;W=t;while(1){K=(W*521|0)+259|0;Na=K&65535;c[Ma>>2]=Na;z=o+((ba(K&32767,X)|0)>>15<<2)|0;c[n+(P<<2)>>2]=(c[z>>2]<<1)+Ja;K=X-1|0;c[z>>2]=c[o+(K<<2)>>2];if((A|0)>=(I|0)){break}A=A+1|0;P=P+1|0;X=K;W=Na}W=ha+1|0;if((W|0)<4){ga=(J?I:1)+ga|0;ha=W;t=Na}else{break}}Na=w+1388|0;t=w+184|0;UGb(Na|0,t|0,290)|0;ha=w+124|0;ga=w+1352|0;Ma=Na;Na=0;while(1){l=x+132+(Na>>1<<2)|0;Mba(Ma,Ma,c[l>>2]|0,x+4+(Na*28|0)|0,c[ha>>2]|0);p=Ma+120|0;Mba(p,p,c[l>>2]|0,x+4+((Na|1)*28|0)|0,c[ha>>2]|0);l=0;p=0;do{ja=b[Ma+(l<<1)>>1]|0;ka=ja<<16>>16;p=(ja<<16>>16>-1?ka:-ka|0)|p;l=l+1|0;}while((l|0)<120);l=(p|0)>32767?32767:p;do{if((l|0)==0){Oa=0;Ia=150}else{I=l>>>0>65535>>>0;J=I?l>>>16:l;ka=I?16:0;if((J&65280|0)==0){Pa=ka;Qa=J}else{Pa=ka|8;Qa=J>>>8}J=Pa-10+(d[1191992+Qa|0]|0)|0;ka=(J|0)<-2?-2:J;if((ka|0)>=0){Oa=ka;Ia=150;break}J=-ka|0;I=0;ja=0;v=0;while(1){la=b[Ma+(I<<1)>>1]<<J;ma=YGb(ba(la,la)|0,0,v,ja)|0;na=F;c[o+(I<<2)>>2]=la;la=I+1|0;if((la|0)<120){I=la;ja=na;v=ma}else{Ra=na;Sa=ma;Ta=ka;break}}}}while(0);if((Ia|0)==150){Ia=0;l=0;p=0;ka=0;while(1){v=b[Ma+(l<<1)>>1]>>Oa;ja=YGb(ba(v,v)|0,0,ka,p)|0;I=F;c[o+(l<<2)>>2]=v;v=l+1|0;if((v|0)<120){l=v;p=I;ka=ja}else{Ra=I;Sa=ja;Ta=Oa;break}}}ka=((Na|0)/2|0)*11|0;p=ba(c[m+(ka<<2)>>2]|0,c[o+(c[n+(ka<<2)>>2]<<2)>>2]|0)|0;l=ka+1|0;ja=(ba(c[m+(l<<2)>>2]|0,c[o+(c[n+(l<<2)>>2]<<2)>>2]|0)|0)+p|0;p=ka+2|0;l=ja+(ba(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+3|0;ja=l+(ba(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+4|0;l=ja+(ba(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+5|0;ja=l+(ba(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+6|0;l=ja+(ba(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+7|0;ja=l+(ba(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+8|0;l=ja+(ba(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+9|0;ja=l+(ba(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+10|0;l=ja+(ba(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)<<1;p=gHb(l,(l|0)<0|0?-1:0,2979,0)|0;l=YGb(p,F,536870912,0)|0;p=l>>>30|F<<2;l=p;ja=c[ga>>2]|0;I=ba((ja*60|0)>>5,ja)|0;ja=Ta<<1;v=ja+3|0;if((v|0)>-1){Ua=I>>v}else{Ua=I<<-3-ja}ja=Sa<<1|0>>>31;I=Ra<<1|Sa>>>31;v=YGb(ja,I,-2147483648,0)|0;J=F;N=0;if(J>>>0>N>>>0|J>>>0==N>>>0&v>>>0>-1>>>0){((I|0)<0|0?-1:0)>>31|((I|0)<0|0?-1:0)<<1;Va=(I>>31|((I|0)<0|0?-1:0)<<1)^2147483647}else{Va=ja}ja=Va-Ua|0;I=gHb(ja,(ja|0)<0|0?-1:0,2979,0)|0;ja=(ba(p<<1|0>>>31,l)|0)-(I>>>15|F<<17)|0;if((ja|0)<1){Wa=-l|0}else{I=(Oba(ja)|0)<<16>>16;ja=I-l|0;p=I+l|0;l=-p|0;Wa=(((p|0)>-1?p:l)|0)<(((ja|0)>-1?ja:-ja|0)|0)?l:ja}ja=Ta+1|0;if((ja|0)<0){Xa=Wa>>~Ta}else{Xa=Wa<<ja}if((Xa|0)<-1e4){Ya=-1e4}else{Ya=(Xa|0)>1e4?1e4:Xa}ja=0;do{l=ja+ka|0;p=Ma+(c[n+(l<<2)>>2]<<1)|0;I=((ba(c[m+(l<<2)>>2]|0,Ya)|0)>>15)+(b[p>>1]|0)|0;if((I+32768|0)>>>0>65535>>>0){Za=(I>>31^32767)&65535}else{Za=I&65535}b[p>>1]=Za;ja=ja+1|0;}while((ja|0)<11);UGb(Ma+290|0,Ma|0,240)|0;ja=Na+2|0;if((ja|0)<4){Ma=Ma+240|0;Na=ja}else{break}}UGb(t|0,w+1868|0,290)|0;t=w+164|0;Na=w+144|0;Kba(u|0,t,Na);UGb(Na|0,t|0,20)|0;Ga=C}c[w+120>>2]=c[y>>2];y=w+1252|0;UGb(j|0,y|0,20)|0;t=u|0;x$(w+1388|0,t,Ga+20|0,60,10,0,1,4096)|0;x$(w+1508|0,u+20|0,Ga+140|0,60,10,0,1,4096)|0;x$(w+1628|0,u+40|0,Ga+260|0,60,10,0,1,4096)|0;x$(w+1748|0,u+60|0,Ga+380|0,60,10,0,1,4096)|0;Ga=w+1848|0;UGb(y|0,Ga|0,20)|0;if((c[w+1364>>2]|0)==0){y=0;do{u=b[B+(y+10<<1)>>1]|0;Na=u<<1;if((Na+32768|0)>>>0>65535>>>0){_a=(u>>30^32767)&65535}else{_a=Na&65535}b[g+(y<<1)>>1]=_a;y=y+1|0;}while((y|0)<240)}else{y=w+1272|0;UGb(j|0,y|0,20)|0;j=w+1292|0;UGb(r|0,j|0,40)|0;_a=0;B=10;Na=t;while(1){t=0;while(1){u=Na+(t<<1)|0;b[q+(t<<1)>>1]=(16384-(ba(b[563464+(t<<1)>>1]|0,b[u>>1]|0)|0)|0)>>>15;b[q+20+(t<<1)>>1]=(16384-(ba(b[563484+(t<<1)>>1]|0,b[u>>1]|0)|0)|0)>>>15;u=t+1|0;if((u|0)<10){t=u}else{$a=0;break}}do{t=1;u=0;Ma=0;do{Za=t-1|0;Ya=$a-t+B|0;m=ba(b[C+(Ya<<1)>>1]|0,b[q+(Za<<1)>>1]|0)|0;n=m-(ba(c[r+(Ya<<2)>>2]>>16,b[q+20+(Za<<1)>>1]|0)|0)|0;Ma=ZGb(Ma,u,n,(n|0)<0|0?-1:0)|0;u=F;t=t+1|0;}while((t|0)<11);t=$a+B|0;n=e[C+(t<<1)>>1]<<16;Za=YGb(n,(n|0)<0|0?-1:0,Ma<<3|0>>>29,u<<3|Ma>>>29)|0;n=F;Ya=YGb(Za,n,32768,0)|0;m=F;Xa=YGb(Za,n,-2147450880,0)|0;n=F;Za=0;if(n>>>0>Za>>>0|n>>>0==Za>>>0&Xa>>>0>-1>>>0){((m|0)<0|0?-1:0)>>31|((m|0)<0|0?-1:0)<<1;ab=(m>>31|((m|0)<0|0?-1:0)<<1)^2147483647}else{ab=Ya}c[r+(t<<2)>>2]=ab;$a=$a+1|0;}while(($a|0)<60);t=_a+1|0;if((t|0)<4){_a=t;B=B+60|0;Na=Na+20|0}else{break}}UGb(y|0,Ga|0,20)|0;UGb(j|0,r+960|0,40)|0;j=w+1356|0;Ga=w+1360|0;y=0;Na=r+40|0;r=g;g=w+1388|0;while(1){w=0;B=0;do{_a=b[g+(B<<1)>>1]|0;$a=_a<<16>>16;w=(_a<<16>>16>-1?$a:-$a|0)|w;B=B+1|0;}while((B|0)<60);B=(w&65280|0)==0;$a=(B?14:6)-(d[1191992+(B?w:w>>>8)|0]|0)|0;B=($a|0)>0?$a:0;$a=0;do{b[r+($a<<1)>>1]=b[g+($a<<1)>>1]<<B>>>3;$a=$a+1|0;}while(($a|0)<60);$a=C$(r,r+2|0,59)|0;w=$a;$a=0>>>31|w<<1;_a=YGb($a,w>>31|((w|0)<0|0?-1:0)<<1,-2147483648,0)|0;ab=F;C=0;if(ab>>>0>C>>>0|ab>>>0==C>>>0&_a>>>0>-1>>>0){((w|0)<0|0?-1:0)>>31|((w|0)<0|0?-1:0)<<1;bb=(w>>31|((w|0)<0|0?-1:0)<<1)^2147483647}else{bb=$a}$a=C$(r,r,60)|0;w=$a;$a=0>>>31|w<<1;_a=YGb($a,w>>31|((w|0)<0|0?-1:0)<<1,-2147483648,0)|0;C=F;ab=0;if(C>>>0>ab>>>0|C>>>0==ab>>>0&_a>>>0>-1>>>0){((w|0)<0|0?-1:0)>>31|((w|0)<0|0?-1:0)<<1;cb=(w>>31|((w|0)<0|0?-1:0)<<1)^2147483647}else{cb=$a}$a=cb>>16;if(($a|0)==0){db=2}else{db=((bb>>2|0)/($a|0)|0)+2|0}$a=((c[j>>2]|0)*3|0)+db>>2;c[j>>2]=$a;w=-$a>>1&-4;$a=0;_a=c[Na-4>>2]|0;while(1){ab=c[Na+($a<<2)>>2]|0;C=ba(_a>>16,w)|0;q=C;t=(C|0)<0|0?-1:0;C=q<<1|0>>>31;Ya=YGb(C,t<<1|q>>>31,-2147483648,0)|0;q=F;m=0;if(q>>>0>m>>>0|q>>>0==m>>>0&Ya>>>0>-1>>>0){((t|0)<0|0?-1:0)>>30|((t|0)<0|0?-1:0)<<2;eb=(t>>30|((t|0)<0|0?-1:0)<<2)^2147483647}else{eb=C}C=YGb(eb,(eb|0)<0|0?-1:0,ab,(ab|0)<0|0?-1:0)|0;t=F;Ya=YGb(C,t,-2147483648,0)|0;m=F;q=0;if(m>>>0>q>>>0|m>>>0==q>>>0&Ya>>>0>-1>>>0){((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1;fb=((t>>31|((t|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{fb=C>>>16&65535}b[r+($a<<1)>>1]=fb;C=$a+1|0;if((C|0)<60){$a=C;_a=ab}else{break}}_a=B<<1;$a=_a-2|0;do{if(($a|0)<0){w=_Gb(cb|0,((cb|0)<0|0?-1:0)|0,2-_a|0)|0;ab=F;C=YGb(w,ab,-2147483648,0)|0;t=F;Ya=0;if(!(t>>>0>Ya>>>0|t>>>0==Ya>>>0&C>>>0>-1>>>0)){gb=w;break}((ab|0)<0|0?-1:0)>>31|((ab|0)<0|0?-1:0)<<1;gb=(ab>>31|((ab|0)<0|0?-1:0)<<1)^2147483647}else{gb=cb>>$a}}while(0);$a=0;_a=0;while(1){B=b[r+(_a<<1)>>1]>>2;ab=ba(B,B)|0;B=YGb(ab<<1|0>>>31,0<<1|ab>>>31,-2147483648,0)|0;w=F;C=0;Ya=w>>>0>C>>>0|w>>>0==C>>>0&B>>>0>-1>>>0;B=ab<<1|0>>>31;ab=YGb(Ya?2147483647:B,Ya?0:(B|0)<0|0?-1:0,$a,($a|0)<0|0?-1:0)|0;B=F;Ya=YGb(ab,B,-2147483648,0)|0;C=F;w=0;if(C>>>0>w>>>0|C>>>0==w>>>0&Ya>>>0>-1>>>0){((B|0)<0|0?-1:0)>>31|((B|0)<0|0?-1:0)<<1;hb=(B>>31|((B|0)<0|0?-1:0)<<1)^2147483647}else{hb=ab}ab=_a+1|0;if((ab|0)<60){$a=hb;_a=ab}else{break}}if((gb|0)==0|(hb|0)==0){ib=4104}else{_a=gb>>>0>65535>>>0;$a=_a?gb>>>16:gb;ab=_a?16:0;if(($a&65280|0)==0){jb=ab;kb=$a}else{jb=ab|8;kb=$a>>>8}$a=30-jb-(d[1191992+kb|0]|0)|0;ab=hb>>>0>65535>>>0;_a=ab?hb>>>16:hb;B=ab?16:0;if((_a&65280|0)==0){lb=B;mb=_a}else{lb=B|8;mb=_a>>>8}_a=30-lb-(d[1191992+mb|0]|0)|0;B=$a+5-_a|0;ib=((Oba(((gb<<$a>>2|0)/(hb<<_a>>16|0)|0)<<16>>((B|0)<0?0:B))|0)<<16>>16)+8|0}B=0;_a=c[Ga>>2]|0;do{$a=(_a*15|0)+ib|0;_a=$a>>4;ab=r+(B<<1)|0;Ya=(ba(_a+($a>>8)|0,b[ab>>1]|0)|0)+1024|0;$a=Ya>>11;if(($a+32768|0)>>>0>65535>>>0){nb=(Ya>>31^32767)&65535}else{nb=$a&65535}b[ab>>1]=nb;B=B+1|0;}while((B|0)<60);c[Ga>>2]=_a;B=y+1|0;if((B|0)<4){y=B;Na=Na+240|0;r=r+120|0;g=g+120|0}else{break}}}c[h>>2]=1;G=D;i=k;return G|0}function Gba(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+60>>2]|0;if((c[a+412>>2]|0)!=8e3){yDb(a,16,2188272,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1;i=b;return f|0}if((c[a+416>>2]|0)!=1){yDb(a,16,2110976,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}g=c[a+72>>2]|0;if((g|0)==6300){c[d+124>>2]=0;c[a+424>>2]=240;UGb(d+144|0,1407920,20)|0;f=0;i=b;return f|0}d=a;if((g|0)==5300){yDb(d,16,2052656,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1163346256;i=b;return f|0}else{yDb(d,16,2007112,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}return 0}function Hba(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0;k=i;i=i+3808|0;l=k|0;m=k+120|0;n=k+184|0;o=k+784|0;p=k+1104|0;q=k+1168|0;r=k+1672|0;s=k+1680|0;t=k+1688|0;u=k+1696|0;v=k+1744|0;w=k+1768|0;y=k+2128|0;z=k+2216|0;A=k+2296|0;B=k+2376|0;C=k+2400|0;D=k+2560|0;E=k+3336|0;G=k+3368|0;H=k+3488|0;I=k+3616|0;J=k+3736|0;K=k+3760|0;L=k+3784|0;M=c[f+60>>2]|0;N=c[h>>2]|0;h=N;O=M+2696|0;P=M+2700|0;Q=0;R=c[P>>2]|0;do{S=h+(Q<<1)|0;T=b[S>>1]|0;U=(T<<16>>16)-(b[O>>1]|0)<<15;V=gHb(R,(R|0)<0|0?-1:0,32512,0)|0;W=F;X=YGb(U,0,V>>>15|W<<17,W>>>15|0<<17)|0;R=X;b[O>>1]=T;T=R;X=(R|0)<0|0?-1:0;W=YGb(T,X,32768,0)|0;V=F;U=YGb(T,X,-2147450880,0)|0;X=F;T=0;if(X>>>0>T>>>0|X>>>0==T>>>0&U>>>0>-1>>>0){((V|0)<0|0?-1:0)>>31|((V|0)<0|0?-1:0)<<1;Y=((V>>31|((V|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{Y=W>>>16&65535}b[S>>1]=Y;Q=Q+1|0;}while((Q|0)<240);Q=M;c[P>>2]=R;R=D;P=M+2166|0;UGb(R|0,P|0,240)|0;UGb(D+240|0,N|0,480)|0;Y=w|0;O=v;S=y|0;y=z|0;W=0;V=0;while(1){U=0;T=0;do{X=b[D+(T+W<<1)>>1]|0;Z=X<<16>>16;U=(X<<16>>16>-1?Z:-Z|0)|U;T=T+1|0;}while((T|0)<180);T=(U&65280|0)==0;Z=(T?14:6)-(d[1191992+(T?U:U>>>8)|0]|0)|0;T=(Z|0)>0?Z:0;Z=0;while(1){b[w+(Z<<1)>>1]=b[D+(Z+W<<1)>>1]<<T>>>3;X=Z+1|0;if((X|0)<180){Z=X}else{_=0;break}}do{Z=w+(_<<1)|0;b[Z>>1]=((ba(b[981768+(_<<1)>>1]|0,b[Z>>1]|0)|0)+16384|0)>>>15;_=_+1|0;}while((_|0)<180);Z=C$(Y,Y,180)|0;T=Z;Z=(T>>10)+T|0;T=Z>>>0>65535>>>0;U=T?Z>>>16:Z;X=T?16:0;if((U&65280|0)==0){$=X;aa=U}else{$=X|8;aa=U>>>8}U=30-$-(d[1191992+aa|0]|0)|0;X=Z<<U;Z=X;T=(X|0)<0|0?-1:0;X=YGb(Z,T,32768,0)|0;ca=F;da=YGb(Z,T,-2147450880,0)|0;T=F;Z=0;if(T>>>0>Z>>>0|T>>>0==Z>>>0&da>>>0>-1>>>0){((ca|0)<0|0?-1:0)>>31|((ca|0)<0|0?-1:0)<<1;ea=((ca>>31|((ca|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{ea=X>>>16&65535}b[S>>1]=ea;if(ea<<16>>16==0){TGb(S+2|0,0,20)|0}else{X=1;do{ca=C$(Y,w+(X<<1)|0,180-X|0)|0;da=ca<<U;ca=b[1693376+(X-1<<1)>>1]|0;Z=gHb(da,(da|0)<0|0?-1:0,ca<<16>>16,ca<<16>>16<0|0?-1:0)|0;ca=Z>>>15|F<<17;Z=ca;da=(ca|0)<0|0?-1:0;ca=YGb(Z,da,32768,0)|0;T=F;fa=YGb(Z,da,-2147450880,0)|0;da=F;Z=0;if(da>>>0>Z>>>0|da>>>0==Z>>>0&fa>>>0>-1>>>0){((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;ga=((T>>31|((T|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{ga=ca>>>16&65535}b[S+(X<<1)>>1]=ga;X=X+1|0;}while((X|0)<11)}X=b[S>>1]|0;U=y;TGb(U|0,0,20)|0;ca=X;X=0;while(1){T=(X|0)>0;if(T){fa=0;Z=0;while(1){da=Z-(ba(b[S+(X-fa<<1)>>1]|0,b[y+(fa<<1)>>1]|0)|0)|0;ha=fa+1|0;if((ha|0)<(X|0)){fa=ha;Z=da}else{ia=da;break}}}else{ia=0}Z=X+1|0;fa=(b[S+(Z<<1)>>1]<<13)+ia<<3;da=ca<<16>>16;ha=da<<16;if((((fa|0)>-1?fa:-fa|0)|0)>=(ha|0)){break}ja=((fa|0)/(da<<1|0)|0)&65535;da=ja<<16>>16;ka=(da<<14)+32768|0;la=(ka|0)<0|0?-1:0;ma=YGb(ka,la,-2147483648,0)|0;na=F;oa=0;if(na>>>0>oa>>>0|na>>>0==oa>>>0&ma>>>0>-1>>>0){((la|0)<0|0?-1:0)>>31|((la|0)<0|0?-1:0)<<1;pa=((la>>31|((la|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{pa=ka>>>16&65535}b[y+(X<<1)>>1]=pa;ka=gHb(ja<<16>>16,ja<<16>>16<0|0?-1:0,fa,(fa|0)<0|0?-1:0)|0;fa=ka>>>15|F<<17;ka=ZGb(ha,(ha|0)<0|0?-1:0,fa,(fa|0)<0|0?-1:0)|0;fa=F;ha=YGb(ka,fa,32768,0)|0;ja=F;la=YGb(ka,fa,-2147450880,0)|0;fa=F;ka=0;if(fa>>>0>ka>>>0|fa>>>0==ka>>>0&la>>>0>-1>>>0){((ja|0)<0|0?-1:0)>>31|((ja|0)<0|0?-1:0)<<1;qa=((ja>>31|((ja|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{qa=ha>>>16&65535}UGb(O|0,U|0,X<<1)|0;if(T){ha=X-1|0;ja=da<<1;da=0;do{la=ba(ja,b[v+(ha-da<<1)>>1]|0)|0;ka=y+(da<<1)|0;fa=e[ka>>1]<<16;ma=ZGb(fa,(fa|0)<0|0?-1:0,la,(la|0)<0|0?-1:0)|0;la=F;fa=YGb(ma,la,32768,0)|0;oa=F;na=YGb(ma,la,-2147450880,0)|0;la=F;ma=0;if(la>>>0>ma>>>0|la>>>0==ma>>>0&na>>>0>-1>>>0){((oa|0)<0|0?-1:0)>>31|((oa|0)<0|0?-1:0)<<1;ra=((oa>>31|((oa|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{ra=fa>>>16&65535}b[ka>>1]=ra;da=da+1|0;}while((da|0)<(X|0))}if((Z|0)<10){ca=qa;X=Z}else{break}}X=V+1|0;if((X|0)<4){S=S+22|0;y=y+20|0;W=W+60|0;V=X}else{break}}V=D|0;W=M+144|0;y=B|0;S=(((b[z+60>>1]|0)*32571|0)+16384|0)>>>15&65535;b[y>>1]=S;qa=B+2|0;b[qa>>1]=(((b[z+62>>1]|0)*32376|0)+16384|0)>>>15;b[B+4>>1]=(((b[z+64>>1]|0)*32182|0)+16384|0)>>>15;ra=B+6|0;b[ra>>1]=(((b[z+66>>1]|0)*31989|0)+16384|0)>>>15;b[B+8>>1]=(((b[z+68>>1]|0)*31797|0)+16384|0)>>>15;b[B+10>>1]=(((b[z+70>>1]|0)*31606|0)+16384|0)>>>15;O=B+12|0;b[O>>1]=(((b[z+72>>1]|0)*31416|0)+16384|0)>>>15;b[B+14>>1]=(((b[z+74>>1]|0)*31228|0)+16384|0)>>>15;pa=B+16|0;b[pa>>1]=(((b[z+76>>1]|0)*31040|0)+16384|0)>>>15;ia=B+18|0;b[ia>>1]=(((b[z+78>>1]|0)*30854|0)+16384|0)>>>15;ga=u+4|0;c[ga>>2]=33554432;w=u|0;c[w>>2]=33554432;Y=0;ea=S;while(1){S=Y<<1;aa=ea<<16>>16;$=b[B+(9-Y<<1)>>1]|0;c[u+(S+2<<2)>>2]=-(($+aa<<12)+(c[u+(S<<2)>>2]|0)|0);c[u+(S+3<<2)>>2]=(c[u+((S|1)<<2)>>2]|0)-(aa-$<<12);$=Y+1|0;if(($|0)>=5){break}Y=$;ea=b[B+($<<1)>>1]|0}ea=W;Y=u+40|0;$=c[Y>>2]>>1;c[Y>>2]=$;aa=u+44|0;S=c[aa>>2]>>1;c[aa>>2]=S;aa=c[w>>2]|0;_=(aa|0)>-1?aa:-aa|0;X=c[ga>>2]|0;ga=(X|0)>-1?X:-X|0;X=(_|0)>(ga|0)?_:ga;ga=u+8|0;_=c[ga>>2]|0;ca=(_|0)>-1?_:-_|0;_=(X|0)>(ca|0)?X:ca;ca=c[u+12>>2]|0;X=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(X|0)?_:X;X=u+16|0;_=c[X>>2]|0;U=(_|0)>-1?_:-_|0;_=(ca|0)>(U|0)?ca:U;U=c[u+20>>2]|0;ca=(U|0)>-1?U:-U|0;U=(_|0)>(ca|0)?_:ca;ca=u+24|0;_=c[ca>>2]|0;da=(_|0)>-1?_:-_|0;_=(U|0)>(da|0)?U:da;da=c[u+28>>2]|0;U=(da|0)>-1?da:-da|0;da=(_|0)>(U|0)?_:U;U=u+32|0;_=c[U>>2]|0;ha=(_|0)>-1?_:-_|0;_=(da|0)>(ha|0)?da:ha;ha=c[u+36>>2]|0;da=(ha|0)>-1?ha:-ha|0;ha=(_|0)>(da|0)?_:da;da=($|0)>-1?$:-$|0;$=(ha|0)>(da|0)?ha:da;da=(S|0)>-1?S:-S|0;S=($|0)>(da|0)?$:da;da=S>>>0>65535>>>0;$=da?S>>>16:S;S=da?16:0;if(($&65280|0)==0){sa=S;ta=$}else{sa=S|8;ta=$>>>8}$=30-sa-(d[1191992+ta|0]|0)|0;ta=0;sa=aa;while(1){aa=sa<<$;S=aa;da=(aa|0)<0|0?-1:0;aa=YGb(S,da,32768,0)|0;ha=F;_=YGb(S,da,-2147450880,0)|0;da=F;S=0;if(da>>>0>S>>>0|da>>>0==S>>>0&_>>>0>-1>>>0){((ha|0)<0|0?-1:0)>>31|((ha|0)<0|0?-1:0)<<1;ua=(ha>>31|((ha|0)<0|0?-1:0)<<1)^2147483647}else{ua=aa}c[u+(ta<<2)>>2]=ua>>16;aa=ta+1|0;if((aa|0)>=12){break}ta=aa;sa=c[u+(aa<<2)>>2]|0}sa=c[w>>2]|0;w=sa<<14;ta=c[ga>>2]<<14;ga=YGb(ta,(ta|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=c[X>>2]<<14;X=YGb(ga,F,w,(w|0)<0|0?-1:0)|0;w=c[ca>>2]<<14;ca=YGb(X,F,w,(w|0)<0|0?-1:0)|0;w=c[U>>2]<<14;U=YGb(ca,F,w,(w|0)<0|0?-1:0)|0;w=c[Y>>2]<<14;Y=YGb(U,F,w,(w|0)<0|0?-1:0)|0;w=F;U=Y<<1|0>>>31;ca=YGb(U,w<<1|Y>>>31,-2147483648,0)|0;Y=F;X=0;if(Y>>>0>X>>>0|Y>>>0==X>>>0&ca>>>0>-1>>>0){((w|0)<0|0?-1:0)>>30|((w|0)<0|0?-1:0)<<2;va=(w>>30|((w|0)<0|0?-1:0)<<2)^2147483647;wa=0;xa=0;ya=1;za=sa}else{va=U;wa=0;xa=0;ya=1;za=sa}a:while(1){sa=c[u+(xa+10<<2)>>2]<<14;U=b[1419304+(ya<<1)>>1]|0;w=ba(U,c[u+(xa+8<<2)>>2]|0)|0;ca=YGb(w,(w|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0)|0;sa=b[1419304+(ya<<1<<1)>>1]|0;w=ba(sa,c[u+(xa+6<<2)>>2]|0)|0;X=YGb(ca,F,w,(w|0)<0|0?-1:0)|0;w=b[1419304+(((ya*3|0|0)%512|0)<<1)>>1]|0;ca=ba(w,c[u+(xa+4<<2)>>2]|0)|0;Y=YGb(X,F,ca,(ca|0)<0|0?-1:0)|0;ca=b[1419304+(((ya<<2|0)%512|0)<<1)>>1]|0;X=ba(ca,c[u+(xa+2<<2)>>2]|0)|0;ga=YGb(Y,F,X,(X|0)<0|0?-1:0)|0;X=b[1419304+(((ya*5|0|0)%512|0)<<1)>>1]|0;Y=ba(X,za)|0;ta=YGb(ga,F,Y,(Y|0)<0|0?-1:0)|0;Y=F;ga=ta<<1|0>>>31;ua=YGb(ga,Y<<1|ta>>>31,-2147483648,0)|0;ta=F;$=0;if(ta>>>0>$>>>0|ta>>>0==$>>>0&ua>>>0>-1>>>0){((Y|0)<0|0?-1:0)>>30|((Y|0)<0|0?-1:0)<<2;Aa=(Y>>30|((Y|0)<0|0?-1:0)<<2)^2147483647}else{Aa=ga}do{if((Aa^va|0)<0){ga=(va|0)>-1?va:-va|0;Y=((Aa|0)>-1?Aa:-Aa|0)+ga|0;ua=Y>>>0>65535>>>0;$=ua?Y>>>16:Y;ta=ua?16:0;if(($&65280|0)==0){Ba=ta;Ca=$}else{Ba=ta|8;Ca=$>>>8}$=30-Ba-(d[1191992+Ca|0]|0)|0;ta=wa+1|0;b[B+(wa<<1)>>1]=(ya<<7)+65408+((ga<<$>>9|0)/(Y<<$>>16|0)|0);if((ta|0)==10){break a}$=xa^1;Y=c[u+($+10<<2)>>2]<<14;ga=ba(c[u+($+8<<2)>>2]|0,U)|0;ua=YGb(ga,(ga|0)<0|0?-1:0,Y,(Y|0)<0|0?-1:0)|0;Y=ba(c[u+($+6<<2)>>2]|0,sa)|0;ga=YGb(ua,F,Y,(Y|0)<0|0?-1:0)|0;Y=ba(c[u+($+4<<2)>>2]|0,w)|0;ua=YGb(ga,F,Y,(Y|0)<0|0?-1:0)|0;Y=ba(c[u+($+2<<2)>>2]|0,ca)|0;ga=YGb(ua,F,Y,(Y|0)<0|0?-1:0)|0;Y=c[u+($<<2)>>2]|0;ua=ba(Y,X)|0;aa=YGb(ga,F,ua,(ua|0)<0|0?-1:0)|0;ua=F;ga=aa<<1|0>>>31;ha=YGb(ga,ua<<1|aa>>>31,-2147483648,0)|0;aa=F;_=0;if(!(aa>>>0>_>>>0|aa>>>0==_>>>0&ha>>>0>-1>>>0)){Da=ga;Ea=$;Fa=ta;Ga=Y;break}((ua|0)<0|0?-1:0)>>30|((ua|0)<0|0?-1:0)<<2;Da=(ua>>30|((ua|0)<0|0?-1:0)<<2)^2147483647;Ea=$;Fa=ta;Ga=Y}else{Da=Aa;Ea=xa;Fa=wa;Ga=za}}while(0);X=ya+1|0;if((X|0)<256){va=Da;wa=Fa;xa=Ea;ya=X;za=Ga}else{Ha=56;break}}do{if((Ha|0)==56){if((Fa|0)==10){break}UGb(B|0,W|0,20)|0}}while(0);Fa=b[qa>>1]|0;qa=b[y>>1]|0;Ga=v|0;b[Ga>>1]=1048576/((Fa<<16>>16)-(qa<<16>>16)|0)|0;za=v+18|0;b[za>>1]=1048576/((b[ia>>1]|0)-(b[pa>>1]|0)|0)|0;pa=1;ia=Fa;Fa=qa;while(1){ya=ia<<16>>16;Ea=ya-(Fa<<16>>16)|0;xa=pa+1|0;wa=b[B+(xa<<1)>>1]|0;Da=(wa<<16>>16)-ya|0;ya=((Ea|0)>(Da|0)?Da:Ea)&65535;if(ya<<16>>16>32){b[v+(pa<<1)>>1]=1048576/(ya<<16>>16|0)|0}else{b[v+(pa<<1)>>1]=32767}if((xa|0)>=9){break}ya=b[B+(pa<<1)>>1]|0;pa=xa;ia=wa;Fa=ya}Fa=M+128|0;ia=b[Ga>>1]|0;pa=ia<<16>>16>0?ia:0;ya=v+2|0;wa=b[ya>>1]|0;xa=wa<<16>>16>pa<<16>>16?wa:pa;pa=v+4|0;Ea=b[pa>>1]|0;Da=Ea<<16>>16>xa<<16>>16?Ea:xa;xa=v+6|0;va=b[xa>>1]|0;Aa=va<<16>>16>Da<<16>>16?va:Da;Da=v+8|0;u=b[Da>>1]|0;Ca=u<<16>>16>Aa<<16>>16?u:Aa;Aa=v+10|0;Ba=b[Aa>>1]|0;X=Ba<<16>>16>Ca<<16>>16?Ba:Ca;Ca=v+12|0;ca=b[Ca>>1]|0;w=ca<<16>>16>X<<16>>16?ca:X;X=v+14|0;sa=b[X>>1]|0;U=sa<<16>>16>w<<16>>16?sa:w;w=v+16|0;v=b[w>>1]|0;Y=v<<16>>16>U<<16>>16?v:U;U=b[za>>1]|0;ta=U<<16>>16>Y<<16>>16?U:Y;Y=ta<<16>>16;$=ta<<16>>16<0;ta=$?Y>>>16:Y;Y=$?16:0;if((ta&65280|0)==0){Ia=Y;Ja=ta}else{Ia=Y|8;Ja=ta>>>8}ta=14-Ia-(d[1191992+Ja|0]|0)|0;Ja=ia<<16>>16<<ta&65535;b[Ga>>1]=Ja;Ga=wa<<16>>16<<ta&65535;b[ya>>1]=Ga;ya=Ea<<16>>16<<ta&65535;b[pa>>1]=ya;pa=va<<16>>16<<ta&65535;b[xa>>1]=pa;xa=u<<16>>16<<ta&65535;b[Da>>1]=xa;Da=Ba<<16>>16<<ta&65535;b[Aa>>1]=Da;Aa=ca<<16>>16<<ta&65535;b[Ca>>1]=Aa;Ca=sa<<16>>16<<ta&65535;b[X>>1]=Ca;X=v<<16>>16<<ta&65535;b[w>>1]=X;w=U<<16>>16<<ta&65535;b[za>>1]=w;za=0;ta=qa;while(1){qa=b[1407920+(za<<1)>>1]|0;b[B+(za<<1)>>1]=(ta&65535)-qa-(((((b[ea+(za<<1)>>1]|0)-qa|0)*12288|0)+16384|0)>>>15);qa=za+1|0;if((qa|0)>=10){break}za=qa;ta=b[B+(qa<<1)>>1]|0}ta=r|0;za=Ja<<16>>16;Ja=Ga<<16>>16;Ga=r+2|0;qa=ya<<16>>16;ya=r+4|0;r=-1;U=0;while(1){v=692024+(U*6|0)|0;b[ta>>1]=((ba(b[v>>1]|0,za)|0)+16384|0)>>>15;b[Ga>>1]=((ba(b[692026+(U*6|0)>>1]|0,Ja)|0)+16384|0)>>>15;b[ya>>1]=((ba(b[692028+(U*6|0)>>1]|0,qa)|0)+16384|0)>>>15;sa=C$(y,ta,3)|0;ca=sa;sa=0>>>31|ca<<1;Ba=YGb(sa,ca>>31|((ca|0)<0|0?-1:0)<<1,-2147483648,0)|0;u=F;va=0;if(u>>>0>va>>>0|u>>>0==va>>>0&Ba>>>0>-1>>>0){((ca|0)<0|0?-1:0)>>31|((ca|0)<0|0?-1:0)<<1;Ka=(ca>>31|((ca|0)<0|0?-1:0)<<1)^2147483647}else{Ka=sa}sa=C$(v,ta,3)|0;v=sa;sa=0>>>31|v<<1;ca=YGb(sa,v>>31|((v|0)<0|0?-1:0)<<1,-2147483648,0)|0;Ba=F;va=0;if(Ba>>>0>va>>>0|Ba>>>0==va>>>0&ca>>>0>-1>>>0){((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1;La=(v>>31|((v|0)<0|0?-1:0)<<1)^2147483647}else{La=sa}sa=(Ka<<1)-La|0;if((sa|0)>(r|0)){a[Fa]=U;Ma=sa}else{Ma=r}sa=U+1|0;if((sa|0)<256){r=Ma;U=sa}else{break}}U=s|0;Ma=M+129|0;r=pa<<16>>16;pa=xa<<16>>16;xa=s+2|0;La=Da<<16>>16;Da=s+4|0;s=-1;Ka=0;while(1){ta=690488+(Ka*6|0)|0;b[U>>1]=((ba(b[ta>>1]|0,r)|0)+16384|0)>>>15;b[xa>>1]=((ba(b[690490+(Ka*6|0)>>1]|0,pa)|0)+16384|0)>>>15;b[Da>>1]=((ba(b[690492+(Ka*6|0)>>1]|0,La)|0)+16384|0)>>>15;qa=C$(ra,U,3)|0;ya=qa;qa=0>>>31|ya<<1;Ja=YGb(qa,ya>>31|((ya|0)<0|0?-1:0)<<1,-2147483648,0)|0;Ga=F;za=0;if(Ga>>>0>za>>>0|Ga>>>0==za>>>0&Ja>>>0>-1>>>0){((ya|0)<0|0?-1:0)>>31|((ya|0)<0|0?-1:0)<<1;Na=(ya>>31|((ya|0)<0|0?-1:0)<<1)^2147483647}else{Na=qa}qa=C$(ta,U,3)|0;ta=qa;qa=0>>>31|ta<<1;ya=YGb(qa,ta>>31|((ta|0)<0|0?-1:0)<<1,-2147483648,0)|0;Ja=F;za=0;if(Ja>>>0>za>>>0|Ja>>>0==za>>>0&ya>>>0>-1>>>0){((ta|0)<0|0?-1:0)>>31|((ta|0)<0|0?-1:0)<<1;Oa=(ta>>31|((ta|0)<0|0?-1:0)<<1)^2147483647}else{Oa=qa}qa=(Na<<1)-Oa|0;if((qa|0)>(s|0)){a[Ma]=Ka;Pa=qa}else{Pa=s}qa=Ka+1|0;if((qa|0)<256){s=Pa;Ka=qa}else{break}}Ka=t|0;Pa=M+130|0;s=Aa<<16>>16;Aa=Ca<<16>>16;Ca=t+2|0;Oa=X<<16>>16;X=t+4|0;Na=w<<16>>16;w=t+6|0;t=-1;U=0;while(1){ra=688440+(U<<3)|0;b[Ka>>1]=((ba(b[ra>>1]|0,s)|0)+16384|0)>>>15;b[Ca>>1]=((ba(b[688442+(U<<3)>>1]|0,Aa)|0)+16384|0)>>>15;b[X>>1]=((ba(b[688444+(U<<3)>>1]|0,Oa)|0)+16384|0)>>>15;b[w>>1]=((ba(b[688446+(U<<3)>>1]|0,Na)|0)+16384|0)>>>15;La=C$(O,Ka,4)|0;Da=La;La=0>>>31|Da<<1;pa=YGb(La,Da>>31|((Da|0)<0|0?-1:0)<<1,-2147483648,0)|0;xa=F;r=0;if(xa>>>0>r>>>0|xa>>>0==r>>>0&pa>>>0>-1>>>0){((Da|0)<0|0?-1:0)>>31|((Da|0)<0|0?-1:0)<<1;Qa=(Da>>31|((Da|0)<0|0?-1:0)<<1)^2147483647}else{Qa=La}La=C$(ra,Ka,4)|0;ra=La;La=0>>>31|ra<<1;Da=YGb(La,ra>>31|((ra|0)<0|0?-1:0)<<1,-2147483648,0)|0;pa=F;r=0;if(pa>>>0>r>>>0|pa>>>0==r>>>0&Da>>>0>-1>>>0){((ra|0)<0|0?-1:0)>>31|((ra|0)<0|0?-1:0)<<1;Ra=(ra>>31|((ra|0)<0|0?-1:0)<<1)^2147483647}else{Ra=La}La=(Qa<<1)-Ra|0;if((La|0)>(t|0)){a[Pa]=U;Sa=La}else{Sa=t}La=U+1|0;if((La|0)<256){t=Sa;U=La}else{break}}U=D+20|0;UGb(U|0,M+2286|0,120)|0;UGb(D+140|0,N|0,360)|0;UGb(P|0,N+240|0,240)|0;UGb(N|0,U|0,480)|0;P=M+1292|0;UGb(R|0,P|0,20)|0;Sa=M+1272|0;UGb(q|0,Sa|0,20)|0;UGb(q+20|0,U|0,480)|0;t=0;Ra=0;Qa=10;while(1){Ka=t<<1;O=0;do{Na=b[z+(O+t<<1)>>1]|0;w=O+Ka|0;b[C+(w<<1)>>1]=((ba(b[589952+(O<<1)>>1]|0,Na)|0)+16384|0)>>>15;b[C+(w+10<<1)>>1]=((ba(b[589972+(O<<1)>>1]|0,Na)|0)+16384|0)>>>15;O=O+1|0;}while((O|0)<10);O=Ka+10|0;Na=0;do{w=1;Oa=0;X=0;do{Aa=w-1|0;Ca=Na-w+Qa|0;s=ba(b[q+(Ca<<1)>>1]|0,b[C+(Aa+Ka<<1)>>1]|0)|0;La=s-(ba(b[D+(Ca<<1)>>1]|0,b[C+(O+Aa<<1)>>1]|0)|0)|0;X=ZGb(X,Oa,La,(La|0)<0|0?-1:0)|0;Oa=F;w=w+1|0;}while((w|0)<11);w=Na+Qa|0;Z=e[q+(w<<1)>>1]<<16;La=YGb(Z,(Z|0)<0|0?-1:0,X<<3|0>>>29,Oa<<3|X>>>29)|0;Z=F;Aa=YGb(La,Z,32768,0)|0;Ca=F;s=YGb(La,Z,-2147450880,0)|0;Z=F;La=0;if(Z>>>0>La>>>0|Z>>>0==La>>>0&s>>>0>-1>>>0){((Ca|0)<0|0?-1:0)>>31|((Ca|0)<0|0?-1:0)<<1;Ta=((Ca>>31|((Ca|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{Ta=Aa>>>16&65535}b[D+(w<<1)>>1]=Ta;Na=Na+1|0;}while((Na|0)<60);Na=Ra+1|0;if((Na|0)<4){t=t+10|0;Ra=Na;Qa=Qa+60|0}else{break}}Qa=D+480|0;UGb(P|0,Qa|0,20)|0;UGb(Sa|0,q+480|0,20)|0;UGb(N|0,U|0,480)|0;U=M+2406|0;UGb(R|0,U|0,290)|0;q=D+290|0;Sa=q;UGb(Sa|0,N|0,480)|0;P=0;Ra=0;do{t=b[D+(Ra<<1)>>1]|0;Ta=t<<16>>16;P=(t<<16>>16>-1?Ta:-Ta|0)|P;Ra=Ra+1|0;}while((Ra|0)<385);Ra=(P&65280|0)==0;Ta=(Ra?14:6)-(d[1191992+(Ra?P:P>>>8)|0]|0)|0;P=(Ta|0)>0?Ta:0;Ta=0;do{Ra=D+(Ta<<1)|0;b[Ra>>1]=b[Ra>>1]<<P>>>3;Ta=Ta+1|0;}while((Ta|0)<385);Ta=M+132|0;P=Ta;Ra=Ta;c[Ra>>2]=Iba(V,145)|0;Ta=M+136|0;c[Ta>>2]=Iba(V,265)|0;V=p+56|0;t=p|0;z=p+4|0;Na=p+8|0;O=p+12|0;Ka=p+16|0;w=p+20|0;Aa=p+24|0;Ca=p+28|0;s=p+32|0;La=p+36|0;Z=p+40|0;ra=p+44|0;Da=p+48|0;r=p+52|0;pa=145;xa=0;while(1){qa=D+(pa<<1)|0;ta=c[P+(xa>>1<<2)>>2]<<16>>16;ya=ta-3|0;za=ta+3|0;Ja=0;Ga=ya;while(1){sa=D+(pa-Ga<<1)|0;v=C$(sa,sa,60)|0;ca=Ja<<1;c[p+(ca<<2)>>2]=v;v=C$(qa,sa,60)|0;c[p+((ca|1)<<2)>>2]=v;v=Ga+1|0;if((v|0)>(za|0)){break}else{Ja=Ja+1|0;Ga=v}}Ga=C$(qa,qa,60)|0;Ja=Ga;c[V>>2]=Ja;Ga=c[t>>2]|0;za=(Ga|0)>-1?Ga:-Ga|0;v=(za|0)<0?0:za;za=c[z>>2]|0;ca=(za|0)>-1?za:-za|0;za=(v|0)>(ca|0)?v:ca;ca=c[Na>>2]|0;v=(ca|0)>-1?ca:-ca|0;ca=(za|0)>(v|0)?za:v;v=c[O>>2]|0;za=(v|0)>-1?v:-v|0;v=(ca|0)>(za|0)?ca:za;za=c[Ka>>2]|0;ca=(za|0)>-1?za:-za|0;za=(v|0)>(ca|0)?v:ca;ca=c[w>>2]|0;v=(ca|0)>-1?ca:-ca|0;ca=(za|0)>(v|0)?za:v;v=c[Aa>>2]|0;za=(v|0)>-1?v:-v|0;v=(ca|0)>(za|0)?ca:za;za=c[Ca>>2]|0;ca=(za|0)>-1?za:-za|0;za=(v|0)>(ca|0)?v:ca;ca=c[s>>2]|0;v=(ca|0)>-1?ca:-ca|0;ca=(za|0)>(v|0)?za:v;v=c[La>>2]|0;za=(v|0)>-1?v:-v|0;v=(ca|0)>(za|0)?ca:za;za=c[Z>>2]|0;ca=(za|0)>-1?za:-za|0;za=(v|0)>(ca|0)?v:ca;ca=c[ra>>2]|0;v=(ca|0)>-1?ca:-ca|0;ca=(za|0)>(v|0)?za:v;v=c[Da>>2]|0;za=(v|0)>-1?v:-v|0;v=(ca|0)>(za|0)?ca:za;za=c[r>>2]|0;ca=(za|0)>-1?za:-za|0;za=(v|0)>(ca|0)?v:ca;ca=(Ja|0)>-1?Ja:-Ja|0;Ja=(za|0)>(ca|0)?za:ca;ca=Ja>>>0>65535>>>0;za=ca?Ja>>>16:Ja;Ja=ca?16:0;if((za&65280|0)==0){Ua=Ja;Va=za}else{Ua=Ja|8;Va=za>>>8}za=30-Ua-(d[1191992+Va|0]|0)|0;Ja=0;ca=Ga;while(1){Ga=ca<<za;v=Ga;sa=(Ga|0)<0|0?-1:0;Ga=YGb(v,sa,32768,0)|0;va=F;Ba=YGb(v,sa,-2147450880,0)|0;sa=F;v=0;if(sa>>>0>v>>>0|sa>>>0==v>>>0&Ba>>>0>-1>>>0){((va|0)<0|0?-1:0)>>31|((va|0)<0|0?-1:0)<<1;Wa=(va>>31|((va|0)<0|0?-1:0)<<1)^2147483647}else{Wa=Ga}c[p+(Ja<<2)>>2]=Wa>>16;Ga=Ja+1|0;if((Ga|0)>=15){break}Ja=Ga;ca=c[p+(Ga<<2)>>2]|0}ca=E+(xa<<3)|0;c[ca>>2]=-1;Ja=E+(xa<<3)+4|0;c[Ja>>2]=0;za=c[t>>2]|0;qa=c[z>>2]|0;do{if((qa|0)<1){Xa=32767;Ya=1;Za=-1}else{Ga=((ba(qa,qa)|0)+16384|0)>>>15;if(((Ga*32767|0)-za|0)<=0){Xa=32767;Ya=1;Za=-1;break}c[ca>>2]=0;Xa=za;Ya=Ga;Za=0}}while(0);za=c[Na>>2]|0;qa=c[O>>2]|0;do{if((qa|0)<1){_a=Xa;$a=Ya;ab=Za}else{Ga=((ba(qa,qa)|0)+16384|0)>>>15;if(((ba(Ga,Xa)|0)-(ba(za,Ya)|0)|0)<=0){_a=Xa;$a=Ya;ab=Za;break}c[ca>>2]=1;_a=za;$a=Ga;ab=1}}while(0);za=c[Ka>>2]|0;qa=c[w>>2]|0;do{if((qa|0)<1){bb=_a;cb=$a;db=ab}else{Ga=((ba(qa,qa)|0)+16384|0)>>>15;if(((ba(Ga,_a)|0)-(ba(za,$a)|0)|0)<=0){bb=_a;cb=$a;db=ab;break}c[ca>>2]=2;bb=za;cb=Ga;db=2}}while(0);za=c[Aa>>2]|0;qa=c[Ca>>2]|0;do{if((qa|0)<1){eb=bb;fb=cb;gb=db}else{Ga=((ba(qa,qa)|0)+16384|0)>>>15;if(((ba(Ga,bb)|0)-(ba(za,cb)|0)|0)<=0){eb=bb;fb=cb;gb=db;break}c[ca>>2]=3;eb=za;fb=Ga;gb=3}}while(0);za=c[s>>2]|0;qa=c[La>>2]|0;do{if((qa|0)<1){hb=eb;ib=fb;jb=gb}else{Ga=((ba(qa,qa)|0)+16384|0)>>>15;if(((ba(Ga,eb)|0)-(ba(za,fb)|0)|0)<=0){hb=eb;ib=fb;jb=gb;break}c[ca>>2]=4;hb=za;ib=Ga;jb=4}}while(0);za=c[Z>>2]|0;qa=c[ra>>2]|0;do{if((qa|0)<1){kb=hb;lb=ib;mb=jb}else{Ga=((ba(qa,qa)|0)+16384|0)>>>15;if(((ba(Ga,hb)|0)-(ba(za,ib)|0)|0)<=0){kb=hb;lb=ib;mb=jb;break}c[ca>>2]=5;kb=za;lb=Ga;mb=5}}while(0);za=c[Da>>2]|0;qa=c[r>>2]|0;do{if((qa|0)<1){Ha=143}else{if(((ba(((ba(qa,qa)|0)+16384|0)>>>15,kb)|0)-(ba(za,lb)|0)|0)<=0){Ha=143;break}c[ca>>2]=6;nb=6;ob=za;Ha=121}}while(0);if((Ha|0)==143){Ha=0;if((mb|0)==-1){pb=ta}else{nb=mb;ob=kb;Ha=121}}if((Ha|0)==121){Ha=0;za=ba(c[V>>2]|0,ob)|0;qa=c[p+((nb<<1|1)<<2)>>2]|0;do{if(((za>>2)+(za>>3)|0)<(ba(qa,qa)|0)){if((qa|0)<(ob|0)){c[Ja>>2]=(((qa<<15|0)/(ob|0)|0)*10240|0)+16384>>15;break}else{c[Ja>>2]=10240;break}}}while(0);pb=nb+ya|0}c[ca>>2]=pb;Ja=xa+1|0;if((Ja|0)<4){pa=pa+60|0;xa=Ja}else{break}}UGb(R|0,U|0,290)|0;UGb(Sa|0,N|0,480)|0;UGb(U|0,Qa|0,290)|0;Qa=0;U=0;while(1){N=Qa+145|0;xa=c[E+(U<<3)+4>>2]<<1;pa=N-(c[E+(U<<3)>>2]|0)|0;pb=0;do{nb=ba(xa,b[D+(pa+pb<<1)>>1]|0)|0;ob=e[D+(pb+N<<1)>>1]<<16;p=ZGb(ob,(ob|0)<0|0?-1:0,nb,(nb|0)<0|0?-1:0)|0;nb=F;ob=YGb(p,nb,32768,0)|0;V=F;kb=YGb(p,nb,-2147450880,0)|0;nb=F;p=0;if(nb>>>0>p>>>0|nb>>>0==p>>>0&kb>>>0>-1>>>0){((V|0)<0|0?-1:0)>>31|((V|0)<0|0?-1:0)<<1;qb=((V>>31|((V|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{qb=ob>>>16&65535}b[h+(pb+Qa<<1)>>1]=qb;pb=pb+1|0;}while((pb|0)<60);pb=U+1|0;if((pb|0)<4){Qa=Qa+60|0;U=pb}else{break}}Jba(y,ea,Fa,0);Kba(A|0,y,ea);UGb(W|0,B|0,20)|0;B=J;W=I;ea=I|0;I=J|0;J=G|0;y=K;U=M+2704|0;Qa=L;qb=M+2724|0;pb=K|0;K=L|0;L=M+2744|0;N=H|0;pa=H+2|0;xa=n|0;ca=n+120|0;ya=n+240|0;ob=n+360|0;V=n+480|0;kb=M+184|0;p=kb;nb=M+4|0;mb=M+124|0;lb=m|0;r=m+8|0;Da=m+4|0;jb=m+12|0;ib=M+304|0;hb=M+354|0;ra=U;Z=qb;gb=M+2864|0;fb=M+2914|0;eb=l;La=0;s=h;h=0;while(1){TGb(B|0,0,20)|0;TGb(R|0,0,290)|0;TGb(W|0,0,120)|0;b[ea>>1]=8192;db=A+(La<<1)|0;cb=C+(La<<1<<1)|0;Lba(db,cb,I,I,ea,q,1);bb=c[E+(h<<3)+4>>2]<<1;Ca=145-(c[E+(h<<3)>>2]|0)|0;Aa=0;do{ab=ba(bb,b[D+(Ca+Aa<<1)>>1]|0)|0;$a=e[D+(Aa+145<<1)>>1]<<16;_a=ZGb($a,($a|0)<0|0?-1:0,ab,(ab|0)<0|0?-1:0)|0;ab=F;$a=YGb(_a,ab,32768,0)|0;w=F;Ka=YGb(_a,ab,-2147450880,0)|0;ab=F;_a=0;if(ab>>>0>_a>>>0|ab>>>0==_a>>>0&Ka>>>0>-1>>>0){((w|0)<0|0?-1:0)>>31|((w|0)<0|0?-1:0)<<1;rb=((w>>31|((w|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{rb=$a>>>16&65535}b[G+(Aa<<1)>>1]=rb;Aa=Aa+1|0;}while((Aa|0)<60);b[ea>>1]=0;UGb(y|0,U|0,20)|0;UGb(Qa|0,qb|0,20)|0;Lba(db,cb,pb,K,ea,q,0);UGb(R|0,L|0,290)|0;Aa=0;do{$a=ba(bb,b[D+(Ca+Aa<<1)>>1]|0)|0;w=s+(Aa<<1)|0;Ka=(e[w>>1]|0)-(e[D+(Aa+145<<1)>>1]|0)<<16;_a=YGb(Ka,(Ka|0)<0|0?-1:0,$a,($a|0)<0|0?-1:0)|0;$a=F;Ka=YGb(_a,$a,32768,0)|0;ab=F;Za=YGb(_a,$a,-2147450880,0)|0;$a=F;_a=0;if($a>>>0>_a>>>0|$a>>>0==_a>>>0&Za>>>0>-1>>>0){((ab|0)<0|0?-1:0)>>31|((ab|0)<0|0?-1:0)<<1;sb=((ab>>31|((ab|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{sb=Ka>>>16&65535}b[w>>1]=sb;Aa=Aa+1|0;}while((Aa|0)<60);Aa=h>>1;Ca=Q+132+(Aa<<2)|0;bb=c[Ca>>2]|0;w=h&1;Ka=w+3|0;ab=(w|0)!=0;do{if(ab){tb=bb}else{if((bb|0)==18){tb=19;break}tb=(bb|0)>140?140:bb}}while(0);bb=0;w=0;while(1){Za=w+tb|0;_a=Za-1|0;$a=144-Za|0;b[N>>1]=b[Q+184+($a<<1)>>1]|0;b[pa>>1]=b[Q+184+($a+1<<1)>>1]|0;Za=$a+2|0;$a=2;while(1){b[H+($a<<1)>>1]=b[Q+184+(Za+(($a-2|0)%(_a|0)|0)<<1)>>1]|0;Ya=$a+1|0;if((Ya|0)<64){$a=Ya}else{ub=0;break}}while(1){$a=0;_a=0;Za=0;do{X=ba(b[G+(ub-$a<<1)>>1]|0,b[H+($a+4<<1)>>1]|0)|0;Za=YGb(X,(X|0)<0|0?-1:0,Za,_a)|0;_a=F;$a=$a+1|0;}while(($a|0)<=(ub|0));$a=Za<<1|0>>>31;X=_a<<1|Za>>>31;Oa=YGb($a,X,32768,0)|0;Ya=F;Xa=YGb($a,X,-2147450880,0)|0;X=F;$a=0;if(X>>>0>$a>>>0|X>>>0==$a>>>0&Xa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;vb=((Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{vb=Oa>>>16&65535}b[n+480+(ub<<1)>>1]=vb;Oa=ub+1|0;if((Oa|0)<60){ub=Oa}else{wb=3;break}}while(1){Oa=b[H+(wb<<1)>>1]|0;b[n+(wb*120|0)>>1]=((Oa<<13)+16384|0)>>>15;Ya=wb+1|0;Xa=1;do{$a=(ba(b[G+(Xa<<1)>>1]|0,Oa)|0)+(b[n+(Ya*120|0)+(Xa-1<<1)>>1]<<15)|0;X=$a;O=X<<1|0>>>31;Na=(($a|0)<0|0?-1:0)<<1|X>>>31;X=YGb(O,Na,32768,0)|0;$a=F;z=YGb(O,Na,-2147450880,0)|0;Na=F;O=0;if(Na>>>0>O>>>0|Na>>>0==O>>>0&z>>>0>-1>>>0){(($a|0)<0|0?-1:0)>>31|(($a|0)<0|0?-1:0)<<1;xb=(($a>>31|(($a|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{xb=X>>>16&65535}b[n+(wb*120|0)+(Xa<<1)>>1]=xb;Xa=Xa+1|0;}while((Xa|0)<60);if((wb|0)>0){wb=wb-1|0}else{break}}Xa=C$(s,xa,60)|0;Ya=Xa<<1|0>>>31;Oa=F<<1|Xa>>>31;Xa=YGb(Ya,Oa,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;yb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{yb=Ya}c[o+(bb<<2)>>2]=yb;Ya=C$(s,ca,60)|0;Oa=Ya<<1|0>>>31;Xa=F<<1|Ya>>>31;Ya=YGb(Oa,Xa,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;zb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{zb=Oa}c[o+((bb|1)<<2)>>2]=zb;Oa=C$(s,ya,60)|0;Xa=Oa<<1|0>>>31;Ya=F<<1|Oa>>>31;Oa=YGb(Xa,Ya,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Ab=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Ab=Xa}c[o+((bb|2)<<2)>>2]=Ab;Xa=C$(s,ob,60)|0;Ya=Xa<<1|0>>>31;Oa=F<<1|Xa>>>31;Xa=YGb(Ya,Oa,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;Bb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{Bb=Ya}c[o+((bb|3)<<2)>>2]=Bb;Ya=C$(s,V,60)|0;Oa=Ya<<1|0>>>31;Xa=F<<1|Ya>>>31;Ya=YGb(Oa,Xa,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Cb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Cb=Oa}c[o+(bb+4<<2)>>2]=Cb;Oa=C$(xa,xa,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=YGb(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Db=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Db=Oa}c[o+(bb+5<<2)>>2]=Db;Oa=C$(ca,ca,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=YGb(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Eb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Eb=Oa}c[o+(bb+6<<2)>>2]=Eb;Oa=C$(ya,ya,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=YGb(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Fb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Fb=Oa}c[o+(bb+7<<2)>>2]=Fb;Oa=C$(ob,ob,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=YGb(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Gb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Gb=Oa}c[o+(bb+8<<2)>>2]=Gb;Oa=C$(V,V,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=YGb(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Hb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Hb=Oa}c[o+(bb+9<<2)>>2]=Hb;Oa=C$(ca,xa,60)|0;Xa=Oa<<2|0>>>30;Ya=F<<2|Oa>>>30;Oa=YGb(Xa,Ya,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Ib=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Ib=Xa}c[o+(bb+10<<2)>>2]=Ib;Xa=C$(ya,xa,60)|0;Ya=Xa<<2|0>>>30;Oa=F<<2|Xa>>>30;Xa=YGb(Ya,Oa,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;Jb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{Jb=Ya}c[o+(bb+11<<2)>>2]=Jb;Ya=C$(ya,ca,60)|0;Oa=Ya<<2|0>>>30;Xa=F<<2|Ya>>>30;Ya=YGb(Oa,Xa,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Kb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Kb=Oa}c[o+(bb+12<<2)>>2]=Kb;Oa=C$(ob,xa,60)|0;Xa=Oa<<2|0>>>30;Ya=F<<2|Oa>>>30;Oa=YGb(Xa,Ya,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Lb=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Lb=Xa}c[o+(bb+13<<2)>>2]=Lb;Xa=C$(ob,ca,60)|0;Ya=Xa<<2|0>>>30;Oa=F<<2|Xa>>>30;Xa=YGb(Ya,Oa,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;Mb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{Mb=Ya}c[o+(bb+14<<2)>>2]=Mb;Ya=C$(ob,ya,60)|0;Oa=Ya<<2|0>>>30;Xa=F<<2|Ya>>>30;Ya=YGb(Oa,Xa,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Nb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Nb=Oa}c[o+(bb+15<<2)>>2]=Nb;Oa=C$(V,xa,60)|0;Xa=Oa<<2|0>>>30;Ya=F<<2|Oa>>>30;Oa=YGb(Xa,Ya,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Ob=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Ob=Xa}c[o+(bb+16<<2)>>2]=Ob;Xa=C$(V,ca,60)|0;Ya=Xa<<2|0>>>30;Oa=F<<2|Xa>>>30;Xa=YGb(Ya,Oa,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;Pb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{Pb=Ya}c[o+(bb+17<<2)>>2]=Pb;Ya=C$(V,ya,60)|0;Oa=Ya<<2|0>>>30;Xa=F<<2|Ya>>>30;Ya=YGb(Oa,Xa,-2147483648,0)|0;Za=F;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Qb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Qb=Oa}c[o+(bb+18<<2)>>2]=Qb;Oa=C$(V,ob,60)|0;Xa=Oa<<2|0>>>30;Ya=F<<2|Oa>>>30;Oa=YGb(Xa,Ya,-2147483648,0)|0;_a=F;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Rb=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Rb=Xa}c[o+(bb+19<<2)>>2]=Rb;Xa=w+1|0;if((Xa|0)<(Ka|0)){bb=bb+20|0;w=Xa}else{break}}w=Ka*20|0;bb=0;Xa=0;do{Ya=c[o+(bb<<2)>>2]|0;Oa=(Ya|0)>-1?Ya:-Ya|0;Xa=(Xa|0)>(Oa|0)?Xa:Oa;bb=bb+1|0;}while((bb|0)<(w|0));bb=Xa>>>0>65535>>>0;Oa=bb?Xa>>>16:Xa;Ya=bb?16:0;if((Oa&65280|0)==0){Sb=Ya;Tb=Oa}else{Sb=Ya|8;Tb=Oa>>>8}Oa=30-Sb-(d[1191992+Tb|0]|0)|0;Ya=0;do{bb=o+(Ya<<2)|0;Za=c[bb>>2]<<Oa;_a=Za;X=(Za|0)<0|0?-1:0;Za=YGb(_a,X,32768,0)|0;$a=F;z=YGb(_a,X,-2147450880,0)|0;X=F;_a=0;if(X>>>0>_a>>>0|X>>>0==_a>>>0&z>>>0>-1>>>0){(($a|0)<0|0?-1:0)>>31|(($a|0)<0|0?-1:0)<<1;Ub=($a>>31|(($a|0)<0|0?-1:0)<<1)^2147483647}else{Ub=Za}c[bb>>2]=Ub>>16;Ya=Ya+1|0;}while((Ya|0)<(w|0));w=(tb|0)>57;Ya=tb-1|0;if(ab){Oa=1;Xa=0;bb=1842768;Za=85;$a=0;z=0;while(1){if(w){Vb=1846168;Wb=170;Ha=197}else{if((Za|0)>0){Vb=bb;Wb=Za;Ha=197}else{Xb=Oa;Yb=Xa;Zb=z;_b=bb;$b=Za}}if((Ha|0)==197){Ha=0;_a=$a*20|0;X=Oa;O=Xa;Na=0;t=0;Wa=z;while(1){Va=0;Ua=0;Ja=0;do{qa=ba(b[Vb+(Va+t<<1)>>1]|0,c[o+(Va+_a<<2)>>2]|0)|0;Ja=YGb(qa,(qa|0)<0|0?-1:0,Ja,Ua)|0;Ua=F;Va=Va+1|0;}while((Va|0)<20);Va=YGb(Ja,Ua,-2147483648,0)|0;qa=F;za=0;if(qa>>>0>za>>>0|qa>>>0==za>>>0&Va>>>0>-1>>>0){((Ua|0)<0|0?-1:0)>>31|((Ua|0)<0|0?-1:0)<<1;ac=(Ua>>31|((Ua|0)<0|0?-1:0)<<1)^2147483647}else{ac=Ja}Va=(ac|0)>(Wa|0);za=Va?$a:X;qa=Va?Na:O;ta=Va?ac:Wa;Va=Na+1|0;if((Va|0)<(Wb|0)){X=za;O=qa;Na=Va;t=t+20|0;Wa=ta}else{Xb=za;Yb=qa;Zb=ta;_b=Vb;$b=Wb;break}}}Wa=$a+1|0;if((Wa|0)<(Ka|0)){Oa=Xb;Xa=Yb;bb=_b;Za=$b;$a=Wa;z=Zb}else{bc=Xb;cc=Yb;break}}}else{z=1;$a=0;Za=1842768;bb=85;Xa=0;Oa=0;while(1){if((Xa+Ya|0)>57){dc=1846168;ec=170;Ha=203}else{if((bb|0)>0){dc=Za;ec=bb;Ha=203}else{fc=z;gc=$a;hc=Oa;ic=Za;jc=bb}}if((Ha|0)==203){Ha=0;w=Xa*20|0;Wa=z;t=$a;Na=0;O=0;X=Oa;while(1){_a=0;ta=0;qa=0;do{za=ba(b[dc+(_a+O<<1)>>1]|0,c[o+(_a+w<<2)>>2]|0)|0;qa=YGb(za,(za|0)<0|0?-1:0,qa,ta)|0;ta=F;_a=_a+1|0;}while((_a|0)<20);_a=YGb(qa,ta,-2147483648,0)|0;Ja=F;Ua=0;if(Ja>>>0>Ua>>>0|Ja>>>0==Ua>>>0&_a>>>0>-1>>>0){((ta|0)<0|0?-1:0)>>31|((ta|0)<0|0?-1:0)<<1;kc=(ta>>31|((ta|0)<0|0?-1:0)<<1)^2147483647}else{kc=qa}_a=(kc|0)>(X|0);Ua=_a?Xa:Wa;Ja=_a?Na:t;za=_a?kc:X;_a=Na+1|0;if((_a|0)<(ec|0)){Wa=Ua;t=Ja;Na=_a;O=O+20|0;X=za}else{fc=Ua;gc=Ja;hc=za;ic=dc;jc=ec;break}}}X=Xa+1|0;if((X|0)<(Ka|0)){z=fc;$a=gc;Za=ic;bb=jc;Xa=X;Oa=hc}else{bc=fc;cc=gc;break}}}c[Ca>>2]=ab?tb:bc+Ya|0;c[Q+4+(h*28|0)>>2]=ab?bc:1;c[Q+4+(h*28|0)+4>>2]=cc;Oa=P+(Aa<<2)|0;Xa=nb+(h*28|0)|0;Mba(N,p,c[Oa>>2]|0,Xa,c[mb>>2]|0);bb=0;do{Za=s+(bb<<1)|0;$a=b[Za>>1]<<14;z=0;Ka=($a|0)<0|0?-1:0;X=$a;do{$a=ba(b[G+(bb-z<<1)>>1]|0,b[H+(z<<1)>>1]|0)|0;X=ZGb(X,Ka,$a,($a|0)<0|0?-1:0)|0;Ka=F;z=z+1|0;}while((z|0)<=(bb|0));z=X<<2|0>>>30;$a=Ka<<2|X>>>30;O=YGb(z,$a,32768,0)|0;Na=F;t=YGb(z,$a,-2147450880,0)|0;$a=F;z=0;if($a>>>0>z>>>0|$a>>>0==z>>>0&t>>>0>-1>>>0){((Na|0)<0|0?-1:0)>>31|((Na|0)<0|0?-1:0)<<1;lc=((Na>>31|((Na|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{lc=O>>>16&65535}b[Za>>1]=lc;bb=bb+1|0;}while((bb|0)<60);bb=a[559728+h|0]|0;c[lb>>2]=1073741824;Nba(m,J,s,bb,60);Aa=c[Ca>>2]|0;if((Aa|0)<58){Nba(m,J,s,bb,Aa)}Aa=s;TGb(Aa|0,0,120)|0;ab=0;do{b[s+(c[m+16+(ab<<2)>>2]<<1)>>1]=c[m+40+(ab<<2)>>2];ab=ab+1|0;}while((ab|0)<(bb|0));ab=Q+4+(h*28|0)+12|0;c[ab>>2]=0;Ya=Q+4+(h*28|0)+24|0;c[Ya>>2]=0;O=c[r>>2]|0;Na=6-bb|0;t=0;z=0;$a=0;while(1){Wa=b[s+((t<<1)+O<<1)>>1]|0;if(Wa<<16>>16==0){w=(c[1421792+(Na*120|0)+(t<<2)>>2]|0)+z|0;c[Ya>>2]=w;mc=Na;nc=w;oc=$a}else{w=(Wa&65535)>>>15&65535|$a<<1;c[ab>>2]=w;Wa=Na+1|0;if((Wa|0)==6){break}else{mc=Wa;nc=z;oc=w}}w=t+1|0;if((w|0)<30){Na=mc;t=w;z=nc;$a=oc}else{break}}c[Q+4+(h*28|0)+20>>2]=c[Da>>2];c[Q+4+(h*28|0)+16>>2]=O;$a=c[jb>>2]|0;c[Q+4+(h*28|0)+8>>2]=$a;do{if(($a|0)==0){pc=c[Oa>>2]|0}else{z=c[Ca>>2]|0;UGb(eb|0,Aa|0,120)|0;if((z|0)<60){qc=z}else{pc=z;break}while(1){t=60-qc|0;if((t|0)>0){Na=0;do{ab=s+(Na+qc<<1)|0;b[ab>>1]=(b[ab>>1]|0)+(b[l+(Na<<1)>>1]|0);Na=Na+1|0;}while((Na|0)<(t|0))}t=qc+z|0;if((t|0)<60){qc=t}else{pc=z;break}}}}while(0);Mba(J,p,pc,Xa,0);VGb(kb|0,ib|0,170)|0;Ca=0;do{Oa=s+(Ca<<1)|0;$a=(b[Oa>>1]<<1)+(b[G+(Ca<<1)>>1]|0)|0;if(($a+32768|0)>>>0>65535>>>0){rc=($a>>31^32767)&65535}else{rc=$a&65535}b[Oa>>1]=rc;Ca=Ca+1|0;}while((Ca|0)<60);UGb(hb|0,Aa|0,120)|0;Lba(db,cb,ra,Z,s,q,0);VGb(L|0,gb|0,170)|0;UGb(fb|0,Sa|0,120)|0;Ca=h+1|0;if((Ca|0)<4){La=La+10|0;s=s+120|0;h=Ca}else{break}}h=r0a(f,g,24,0)|0;if((h|0)<0){sc=h;i=k;return sc|0}c[j>>2]=1;j=g+28|0;h=(c[j>>2]|0)<0?0:c[g+24>>2]|0;g=(c[mb>>2]|0)==0?30:32;f=g-8|0;s=d[Ma]|0;Ma=s<<40-g|d[Pa]<<32-g;if((f|0)>8){tc=f;uc=Ma;vc=h}else{Pa=h;x=Ma;a[Pa]=x;x=x>>8;a[Pa+1|0]=x;x=x>>8;a[Pa+2|0]=x;x=x>>8;a[Pa+3|0]=x;tc=g+24|0;uc=s>>>(f>>>0);vc=h+4|0}h=tc-8|0;f=d[Fa]|0;Fa=f<<40-tc|uc;if((h|0)>8){wc=h;xc=Fa;yc=vc}else{uc=vc;x=Fa;a[uc]=x;x=x>>8;a[uc+1|0]=x;x=x>>8;a[uc+2|0]=x;x=x>>8;a[uc+3|0]=x;wc=tc+24|0;xc=f>>>(h>>>0);yc=vc+4|0}vc=wc-8|0;h=(c[Ra>>2]|0)-18|0;Ra=h<<40-wc|xc;if((vc|0)>7){zc=vc;Ac=Ra;Bc=yc}else{xc=yc;x=Ra;a[xc]=x;x=x>>8;a[xc+1|0]=x;x=x>>8;a[xc+2|0]=x;x=x>>8;a[xc+3|0]=x;zc=wc+24|0;Ac=h>>>(vc>>>0);Bc=yc+4|0}yc=zc-7|0;vc=c[M+32>>2]|0;h=vc<<39-zc|Ac;if((yc|0)>2){Cc=yc;Dc=h;Ec=Bc}else{Ac=Bc;x=h;a[Ac]=x;x=x>>8;a[Ac+1|0]=x;x=x>>8;a[Ac+2|0]=x;x=x>>8;a[Ac+3|0]=x;Cc=zc+25|0;Dc=vc>>>(yc>>>0);Ec=Bc+4|0}Bc=Cc-2|0;yc=(c[Ta>>2]|0)-18|0;Ta=yc<<34-Cc|Dc;if((Bc|0)>7){Fc=Bc;Gc=Ta;Hc=Ec}else{Dc=Ec;x=Ta;a[Dc]=x;x=x>>8;a[Dc+1|0]=x;x=x>>8;a[Dc+2|0]=x;x=x>>8;a[Dc+3|0]=x;Fc=Cc+30|0;Gc=yc>>>(Bc>>>0);Hc=Ec+4|0}Ec=Fc-7|0;Bc=c[M+88>>2]|0;yc=Bc<<39-Fc|Gc;if((Ec|0)>2){Ic=Ec;Jc=yc;Kc=Hc}else{Gc=Hc;x=yc;a[Gc]=x;x=x>>8;a[Gc+1|0]=x;x=x>>8;a[Gc+2|0]=x;x=x>>8;a[Gc+3|0]=x;Ic=Fc+25|0;Jc=Bc>>>(Ec>>>0);Kc=Hc+4|0}Hc=Ic-2|0;Ec=((c[M+8>>2]|0)*24|0)+(c[M+24>>2]|0)|0;Bc=c[mb>>2]|0;if((Bc|0)==0){Lc=(c[M+12>>2]<<11)+Ec|0}else{Lc=Ec}Ec=Lc<<34-Ic|Jc;if((Hc|0)>12){Mc=Hc;Nc=Ec;Oc=Kc;Pc=Bc}else{Bc=Kc;x=Ec;a[Bc]=x;x=x>>8;a[Bc+1|0]=x;x=x>>8;a[Bc+2|0]=x;x=x>>8;a[Bc+3|0]=x;Mc=Ic+30|0;Nc=Lc>>>(Hc>>>0);Oc=Kc+4|0;Pc=c[mb>>2]|0}Kc=Mc-12|0;Hc=((c[M+36>>2]|0)*24|0)+(c[M+52>>2]|0)|0;if((Pc|0)==0){Qc=(c[M+40>>2]<<11)+Hc|0}else{Qc=Hc}Hc=Qc<<44-Mc|Nc;if((Kc|0)>12){Rc=Kc;Sc=Hc;Tc=Oc;Uc=Pc}else{Pc=Oc;x=Hc;a[Pc]=x;x=x>>8;a[Pc+1|0]=x;x=x>>8;a[Pc+2|0]=x;x=x>>8;a[Pc+3|0]=x;Rc=Mc+20|0;Sc=Qc>>>(Kc>>>0);Tc=Oc+4|0;Uc=c[mb>>2]|0}Oc=Rc-12|0;Kc=((c[M+64>>2]|0)*24|0)+(c[M+80>>2]|0)|0;if((Uc|0)==0){Vc=(c[M+68>>2]<<11)+Kc|0}else{Vc=Kc}Kc=Vc<<44-Rc|Sc;if((Oc|0)>12){Wc=Oc;Xc=Kc;Yc=Tc;Zc=Uc}else{Uc=Tc;x=Kc;a[Uc]=x;x=x>>8;a[Uc+1|0]=x;x=x>>8;a[Uc+2|0]=x;x=x>>8;a[Uc+3|0]=x;Wc=Rc+20|0;Xc=Vc>>>(Oc>>>0);Yc=Tc+4|0;Zc=c[mb>>2]|0}Tc=Wc-12|0;Oc=((c[M+92>>2]|0)*24|0)+(c[M+108>>2]|0)|0;if((Zc|0)==0){_c=(c[M+96>>2]<<11)+Oc|0}else{_c=Oc}Oc=_c<<44-Wc|Xc;if((Tc|0)>12){$c=Tc;ad=Oc;bd=Yc}else{Xc=Yc;x=Oc;a[Xc]=x;x=x>>8;a[Xc+1|0]=x;x=x>>8;a[Xc+2|0]=x;x=x>>8;a[Xc+3|0]=x;$c=Wc+20|0;ad=_c>>>(Tc>>>0);bd=Yc+4|0}Yc=$c-12|0;Tc=c[M+20>>2]|0;_c=Tc<<44-$c|ad;if((Yc|0)>1){cd=Yc;dd=_c;ed=bd}else{ad=bd;x=_c;a[ad]=x;x=x>>8;a[ad+1|0]=x;x=x>>8;a[ad+2|0]=x;x=x>>8;a[ad+3|0]=x;cd=$c+20|0;dd=Tc>>>(Yc>>>0);ed=bd+4|0}bd=cd-1|0;Yc=c[M+48>>2]|0;Tc=Yc<<33-cd|dd;if((bd|0)>1){fd=bd;gd=Tc;hd=ed}else{dd=ed;x=Tc;a[dd]=x;x=x>>8;a[dd+1|0]=x;x=x>>8;a[dd+2|0]=x;x=x>>8;a[dd+3|0]=x;fd=cd+31|0;gd=Yc>>>(bd>>>0);hd=ed+4|0}ed=fd-1|0;bd=c[M+76>>2]|0;Yc=bd<<33-fd|gd;if((ed|0)>1){id=ed;jd=Yc;kd=hd}else{gd=hd;x=Yc;a[gd]=x;x=x>>8;a[gd+1|0]=x;x=x>>8;a[gd+2|0]=x;x=x>>8;a[gd+3|0]=x;id=fd+31|0;jd=bd>>>(ed>>>0);kd=hd+4|0}hd=id-1|0;ed=c[M+104>>2]|0;bd=ed<<33-id|jd;if((hd|0)>1){ld=hd;md=bd;nd=kd}else{jd=kd;x=bd;a[jd]=x;x=x>>8;a[jd+1|0]=x;x=x>>8;a[jd+2|0]=x;x=x>>8;a[jd+3|0]=x;ld=id+31|0;md=ed>>>(hd>>>0);nd=kd+4|0}kd=ld-1|0;if((c[mb>>2]|0)==0){mb=ld-2|0;ld=mb>>5<<2;hd=nd+(-ld|0)|0;ed=mb&31;mb=M+28|0;id=c[mb>>2]|0;jd=M+56|0;bd=M+84|0;fd=M+112|0;gd=((c[jd>>2]>>14)*90|0)+((id>>16)*810|0)+((c[bd>>2]>>16)*9|0)+(c[fd>>2]>>14)|0;Yc=gd<<32-ed|md;if(ed>>>0>13>>>0){od=ed;pd=Yc;qd=hd;rd=id}else{id=hd;x=Yc;a[id]=x;x=x>>8;a[id+1|0]=x;x=x>>8;a[id+2|0]=x;x=x>>8;a[id+3|0]=x;od=ed|32;pd=gd>>>(ed>>>0);qd=nd+(4-ld)|0;rd=c[mb>>2]|0}mb=od-13|0;ld=rd&65535;rd=ld<<45-od|pd;if((mb|0)>16){sd=mb;td=rd;ud=qd}else{pd=qd;x=rd;a[pd]=x;x=x>>8;a[pd+1|0]=x;x=x>>8;a[pd+2|0]=x;x=x>>8;a[pd+3|0]=x;sd=od+19|0;td=ld>>>(mb>>>0);ud=qd+4|0}qd=sd-16|0;mb=c[jd>>2]&16383;jd=mb<<48-sd|td;if((qd|0)>14){vd=qd;wd=jd;xd=ud}else{td=ud;x=jd;a[td]=x;x=x>>8;a[td+1|0]=x;x=x>>8;a[td+2|0]=x;x=x>>8;a[td+3|0]=x;vd=sd+16|0;wd=mb>>>(qd>>>0);xd=ud+4|0}ud=vd-14|0;qd=c[bd>>2]&65535;bd=qd<<46-vd|wd;if((ud|0)>16){yd=ud;zd=bd;Ad=xd}else{wd=xd;x=bd;a[wd]=x;x=x>>8;a[wd+1|0]=x;x=x>>8;a[wd+2|0]=x;x=x>>8;a[wd+3|0]=x;yd=vd+18|0;zd=qd>>>(ud>>>0);Ad=xd+4|0}xd=yd-16|0;ud=c[fd>>2]&16383;fd=ud<<48-yd|zd;if((xd|0)>14){Bd=xd;Cd=fd;Dd=Ad}else{zd=Ad;x=fd;a[zd]=x;x=x>>8;a[zd+1|0]=x;x=x>>8;a[zd+2|0]=x;x=x>>8;a[zd+3|0]=x;Bd=yd+16|0;Cd=ud>>>(xd>>>0);Dd=Ad+4|0}Ad=Bd-14|0;xd=c[M+16>>2]|0;ud=xd<<46-Bd|Cd;if((Ad|0)>6){Ed=Ad;Fd=ud;Gd=Dd}else{Cd=Dd;x=ud;a[Cd]=x;x=x>>8;a[Cd+1|0]=x;x=x>>8;a[Cd+2|0]=x;x=x>>8;a[Cd+3|0]=x;Ed=Bd+18|0;Fd=xd>>>(Ad>>>0);Gd=Dd+4|0}Dd=Ed-6|0;Ad=c[M+44>>2]|0;xd=Ad<<38-Ed|Fd;if((Dd|0)>5){Hd=Dd;Id=xd;Jd=Gd}else{Fd=Gd;x=xd;a[Fd]=x;x=x>>8;a[Fd+1|0]=x;x=x>>8;a[Fd+2|0]=x;x=x>>8;a[Fd+3|0]=x;Hd=Ed+26|0;Id=Ad>>>(Dd>>>0);Jd=Gd+4|0}Gd=Hd-5|0;Dd=c[M+72>>2]|0;Ad=Dd<<37-Hd|Id;if((Gd|0)>6){Kd=Gd;Ld=Ad;Md=Jd}else{Id=Jd;x=Ad;a[Id]=x;x=x>>8;a[Id+1|0]=x;x=x>>8;a[Id+2|0]=x;x=x>>8;a[Id+3|0]=x;Kd=Hd+27|0;Ld=Dd>>>(Gd>>>0);Md=Jd+4|0}Jd=Kd-6|0;Gd=c[M+100>>2]|0;M=Gd<<38-Kd|Ld;if((Jd|0)>5){Nd=Jd;Od=M;Pd=Md}else{Ld=Md;x=M;a[Ld]=x;x=x>>8;a[Ld+1|0]=x;x=x>>8;a[Ld+2|0]=x;x=x>>8;a[Ld+3|0]=x;Nd=Kd+26|0;Od=Gd>>>(Jd>>>0);Pd=Md+4|0}Qd=Od;Rd=Nd-5|0;Sd=Pd}else{Qd=md;Rd=kd;Sd=nd}if((Rd|0)<32){nd=Qd&255;kd=Qd;Qd=Rd;Rd=Sd;while(1){a[Rd]=nd;Sd=kd>>>8;md=Qd+8|0;if((md|0)<32){nd=Sd&255;kd=Sd;Qd=md;Rd=Rd+1|0}else{break}}}c[j>>2]=24;sc=0;i=k;return sc|0}function Iba(a,c){a=a|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=c-17|0;f=a+(e<<1)|0;g=C$(f,f,120)|0;f=a+(c<<1)|0;c=18;h=e;e=32767;i=g;g=16384;j=32;k=18;while(1){l=h-1|0;m=a+(l<<1)|0;n=b[m>>1]|0;o=ba(n,n)|0;n=b[a+(h+119<<1)>>1]|0;p=o-(ba(n,n)|0)+i|0;n=C$(f,m,120)|0;m=n;a:do{if((m|0)<1){q=j;r=g;s=e;t=c}else{n=m>>>0>65535>>>0;o=n?m>>>16:m;u=n?16:0;if((o&65280|0)==0){v=u;w=o}else{v=u|8;w=o>>>8}o=30-v-(d[1191992+w|0]|0)|0;u=m<<o;n=u;x=(u|0)<0|0?-1:0;u=YGb(n,x,32768,0)|0;y=F;z=YGb(n,x,-2147450880,0)|0;x=F;n=0;if(x>>>0>n>>>0|x>>>0==n>>>0&z>>>0>-1>>>0){((y|0)<0|0?-1:0)>>31|((y|0)<0|0?-1:0)<<1;A=(y>>31|((y|0)<0|0?-1:0)<<1)^2147483647}else{A=u}u=A>>16;y=ba(u,u)|0;u=y>>>0>65535>>>0;z=u?y>>>16:y;n=u?16:0;if((z&65280|0)==0){B=n;C=z}else{B=n|8;C=z>>>8}z=30-B-(d[1191992+C|0]|0)|0;n=y<<z;y=n>>16;u=p>>>0>65535>>>0;x=u?p>>>16:p;D=u?16:0;if((x&65280|0)==0){E=D;G=x}else{E=D|8;G=x>>>8}x=30-E-(d[1191992+G|0]|0)|0;D=p<<x;u=D;H=(D|0)<0|0?-1:0;D=YGb(u,H,32768,0)|0;I=F;J=YGb(u,H,-2147450880,0)|0;H=F;u=0;if(H>>>0>u>>>0|H>>>0==u>>>0&J>>>0>-1>>>0){((I|0)<0|0?-1:0)>>31|((I|0)<0|0?-1:0)<<1;K=(I>>31|((I|0)<0|0?-1:0)<<1)^2147483647}else{K=D}D=K>>16;I=z+(o<<1)-x|0;if((y|0)<(D|0)){L=I;M=y}else{L=I-1|0;M=n>>17}if((L|0)>(j|0)){q=j;r=g;s=e;t=c;break}n=L+1|0;do{if((n|0)>=(j|0)){I=ba(M,e)|0;y=I-(ba(g>>((n|0)==(j|0)),D)|0)|0;if((y|0)<=0){q=j;r=g;s=e;t=c;break a}if((k-c|0)<18){break}if((y|0)<=(I>>2|0)){q=j;r=g;s=e;t=c;break a}}}while(0);q=L;r=M;s=D;t=k}}while(0);m=k+1|0;if((m|0)<143){c=t;h=l;e=s;i=p;g=r;j=q;k=m}else{break}}return t|0}function Jba(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((g|0)==0){h=12288;i=256;j=d[f]|0;k=f+1|0;l=f+2|0}else{g=f+2|0;a[g]=0;m=f+1|0;a[m]=0;a[f]=0;h=23552;i=512;j=0;k=m;l=g}g=b[692024+(j*6|0)>>1]|0;b[c>>1]=g;b[c+2>>1]=b[692026+((d[f]|0)*6|0)>>1]|0;b[c+4>>1]=b[692028+((d[f]|0)*6|0)>>1]|0;b[c+6>>1]=b[690488+((d[k]|0)*6|0)>>1]|0;b[c+8>>1]=b[690490+((d[k]|0)*6|0)>>1]|0;b[c+10>>1]=b[690492+((d[k]|0)*6|0)>>1]|0;b[c+12>>1]=b[688440+(d[l]<<3)>>1]|0;b[c+14>>1]=b[688442+(d[l]<<3)>>1]|0;b[c+16>>1]=b[688444+(d[l]<<3)>>1]|0;k=c+18|0;b[k>>1]=b[688446+(d[l]<<3)>>1]|0;l=0;f=g;while(1){g=b[1407920+(l<<1)>>1]|0;b[c+(l<<1)>>1]=(f&65535)+g+(((ba((b[e+(l<<1)>>1]|0)-g|0,h)|0)+16384|0)>>>15);g=l+1|0;if((g|0)>=10){break}l=g;f=b[c+(g<<1)>>1]|0}f=i-4|0;l=1;a:while(1){h=b[c>>1]|0;g=h<<16>>16>384?h:384;b[c>>1]=g;h=b[k>>1]|0;b[k>>1]=h<<16>>16>32256?32256:h;h=1;j=g;while(1){g=j<<16>>16;m=c+(h<<1)|0;n=b[m>>1]|0;o=g+i-(n<<16>>16)|0;if((o|0)>0){p=o>>1;b[c+(h-1<<1)>>1]=g-p;g=(n&65535)+p&65535;b[m>>1]=g;q=g}else{q=n}n=h+1|0;if((n|0)<10){h=n;j=q}else{r=1;break}}while(1){if((r|0)>=10){s=17;break a}if((f+(b[c+(r-1<<1)>>1]|0)-(b[c+(r<<1)>>1]|0)|0)>0){break}else{r=r+1|0}}if((l|0)>=10){break}l=l+1|0}if((s|0)==17){return}UGb(c|0,e|0,20)|0;return}function Kba(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=i;i=i+48|0;g=f|0;h=f+24|0;Lgb(a,d,e,4096,12288,8192,14,10);Lgb(a+20|0,d,e,8192,8192,8192,14,10);Lgb(a+40|0,d,e,12288,4096,8192,14,10);UGb(a+60|0,d|0,20)|0;d=g|0;e=g+4|0;j=g+8|0;k=h|0;l=h+4|0;m=h+8|0;n=0;o=a;while(1){a=0;do{p=o+(a<<1)|0;q=b[p>>1]|0;r=q>>>7&511;s=b[1419304+(r<<1)>>1]|0;t=(ba(q<<9&65024|256,(b[1419304+(r+1<<1)>>1]|0)-s|0)|0)+(s<<16)|0;s=t;r=(t|0)<0|0?-1:0;t=s<<1|0>>>31;q=YGb(t,r<<1|s>>>31,-2147483648,0)|0;s=F;u=0;if(s>>>0>u>>>0|s>>>0==u>>>0&q>>>0>-1>>>0){((r|0)<0|0?-1:0)>>30|((r|0)<0|0?-1:0)<<2;v=(r>>30|((r|0)<0|0?-1:0)<<2)^2147483647}else{v=t}t=v;r=(v|0)<0|0?-1:0;q=YGb(t,r,32768,0)|0;u=F;s=YGb(t,r,-2147450880,0)|0;r=F;t=0;if(r>>>0>t>>>0|r>>>0==t>>>0&s>>>0>-1>>>0){((u|0)<0|0?-1:0)>>31|((u|0)<0|0?-1:0)<<1;w=(u>>31|((u|0)<0|0?-1:0)<<1)^2147483647}else{w=q}b[p>>1]=-(w>>>16);a=a+1|0;}while((a|0)<10);c[d>>2]=268435456;a=b[o>>1]|0;p=b[o+4>>1]|0;q=p+a<<14;c[e>>2]=q;u=(ba(p,a)|0)+536870912|0;c[j>>2]=u;c[k>>2]=268435456;a=b[o+2>>1]|0;p=b[o+6>>1]|0;s=p+a<<14;c[l>>2]=s;t=(ba(p,a)|0)+536870912|0;c[m>>2]=t;a=2;p=q;q=u;u=s;s=t;while(1){t=a<<1;r=b[o+(t<<1)>>1]|0;x=r<<16>>16;y=r<<16>>16<0|0?-1:0;z=gHb(x,y,q,(q|0)<0|0?-1:0)|0;A=F;B=YGb(z>>>15|A<<17,A>>>15|0<<17,p,0)|0;A=a+1|0;z=g+(A<<2)|0;c[z>>2]=B;B=b[o+((t|1)<<1)>>1]|0;t=B<<16>>16;C=B<<16>>16<0|0?-1:0;D=gHb(t,C,s,(s|0)<0|0?-1:0)|0;E=F;G=YGb(D>>>15|E<<17,E>>>15|0<<17,u,0)|0;E=h+(A<<2)|0;c[E>>2]=G;G=a;D=p;H=u;I=q;J=s;while(1){K=G-1|0;L=gHb(D,(D|0)<0|0?-1:0,x,y)|0;M=F;N=YGb(L>>>15|M<<17,M>>>15|0<<17,I>>1,0)|0;M=G-2|0;L=c[g+(M<<2)>>2]|0;O=YGb(N,F,L>>1,0)|0;c[g+(G<<2)>>2]=O;O=gHb(H,(H|0)<0|0?-1:0,t,C)|0;N=F;P=YGb(O>>>15|N<<17,N>>>15|0<<17,J>>1,0)|0;N=c[h+(M<<2)>>2]|0;M=YGb(P,F,N>>1,0)|0;c[h+(G<<2)>>2]=M;if((K|0)<=1){break}G=K;D=L;H=N;I=c[g+(K<<2)>>2]|0;J=c[h+(K<<2)>>2]|0}J=c[d>>2]>>1;c[d>>2]=J;I=c[k>>2]>>1;c[k>>2]=I;c[e>>2]=(c[e>>2]|0)+((r&65535)<<16>>a)>>1;c[l>>2]=(c[l>>2]|0)+((B&65535)<<16>>a)>>1;if((A|0)>=5){Q=0;R=J;S=I;break}I=c[g+(a<<2)>>2]|0;J=c[h+(a<<2)>>2]|0;a=A;p=I;q=c[z>>2]|0;u=J;s=c[E>>2]|0}while(1){s=Q+1|0;u=c[g+(s<<2)>>2]|0;q=u+R|0;p=q;a=(q|0)<0|0?-1:0;q=c[h+(s<<2)>>2]|0;J=q-S|0;I=J;H=(J|0)<0|0?-1:0;J=YGb(I,H,p,a)|0;D=J<<3|0>>>29;G=F<<3|J>>>29;J=YGb(D,G,32768,0)|0;C=F;t=YGb(D,G,-2147450880,0)|0;G=F;D=0;if(G>>>0>D>>>0|G>>>0==D>>>0&t>>>0>-1>>>0){((C|0)<0|0?-1:0)>>31|((C|0)<0|0?-1:0)<<1;T=((C>>31|((C|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{T=J>>>16&65535}b[o+(Q<<1)>>1]=T;J=ZGb(p,a,I,H)|0;H=J<<3|0>>>29;I=F<<3|J>>>29;J=YGb(H,I,32768,0)|0;a=F;p=YGb(H,I,-2147450880,0)|0;I=F;H=0;if(I>>>0>H>>>0|I>>>0==H>>>0&p>>>0>-1>>>0){((a|0)<0|0?-1:0)>>31|((a|0)<0|0?-1:0)<<1;U=((a>>31|((a|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{U=J>>>16&65535}b[o+(9-Q<<1)>>1]=U;if((s|0)<5){Q=s;R=u;S=q}else{break}}q=n+1|0;if((q|0)<4){n=q;o=o+20|0}else{break}}i=f;return}function Lba(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+624|0;l=k|0;m=k+144|0;n=e;UGb(l|0,n|0,20)|0;e=f;UGb(h-20|0,e|0,20)|0;f=b[a>>1]|0;o=b[a+2>>1]|0;p=b[a+4>>1]|0;q=b[a+6>>1]|0;r=b[a+8>>1]|0;s=b[a+10>>1]|0;t=b[a+12>>1]|0;u=b[a+14>>1]|0;v=b[a+16>>1]|0;w=b[a+18>>1]|0;a=0;do{x=ba(b[l+(a+9<<1)>>1]|0,f<<16>>16)|0;y=ZGb(0,0,x,(x|0)<0|0?-1:0)|0;x=ba(b[l+(a+8<<1)>>1]|0,o<<16>>16)|0;z=ZGb(y,F,x,(x|0)<0|0?-1:0)|0;x=ba(b[l+(a+7<<1)>>1]|0,p<<16>>16)|0;y=ZGb(z,F,x,(x|0)<0|0?-1:0)|0;x=ba(b[l+(a+6<<1)>>1]|0,q<<16>>16)|0;z=ZGb(y,F,x,(x|0)<0|0?-1:0)|0;x=ba(b[l+(a+5<<1)>>1]|0,r<<16>>16)|0;y=ZGb(z,F,x,(x|0)<0|0?-1:0)|0;x=ba(b[l+(a+4<<1)>>1]|0,s<<16>>16)|0;z=ZGb(y,F,x,(x|0)<0|0?-1:0)|0;x=ba(b[l+(a+3<<1)>>1]|0,t<<16>>16)|0;y=ZGb(z,F,x,(x|0)<0|0?-1:0)|0;x=ba(b[l+(a+2<<1)>>1]|0,u<<16>>16)|0;z=ZGb(y,F,x,(x|0)<0|0?-1:0)|0;x=ba(b[l+(a+1<<1)>>1]|0,v<<16>>16)|0;y=ZGb(z,F,x,(x|0)<0|0?-1:0)|0;x=ba(b[l+(a<<1)>>1]|0,w<<16>>16)|0;z=ZGb(y,F,x,(x|0)<0|0?-1:0)|0;x=b[g+(a<<1)>>1]<<15;y=YGb(x,(x|0)<0|0?-1:0,z<<3|0>>>29,F<<3|z>>>29)|0;z=F;x=m+(a<<3)|0;c[x>>2]=y;c[x+4>>2]=z;x=YGb(y,z,32768,0)|0;A=F;B=YGb(y,z,-2147450880,0)|0;z=F;y=0;if(z>>>0>y>>>0|z>>>0==y>>>0&B>>>0>-1>>>0){((A|0)<0|0?-1:0)>>31|((A|0)<0|0?-1:0)<<1;C=((A>>31|((A|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{C=x>>>16&65535}b[l+(a+10<<1)>>1]=C;a=a+1|0;}while((a|0)<60);a=j;j=0;do{C=1;g=0;w=0;v=0;u=0;do{t=j-C|0;s=ba(b[l+(t+10<<1)>>1]|0,b[d+(C-1<<1)>>1]|0)|0;w=ZGb(w,g,s,(s|0)<0|0?-1:0)|0;g=F;s=ba(b[h+(t<<1)>>1]|0,b[d+(C+9<<1)>>1]|0)|0;u=YGb(s,(s|0)<0|0?-1:0,u,v)|0;v=F;C=C+1|0;}while((C|0)<11);C=m+(j<<3)|0;s=YGb(c[C>>2]|0,c[C+4>>2]|0,w<<3|0>>>29,g<<3|w>>>29)|0;C=_Gb(s|0,F|0,a|0)|0;s=YGb(C,F,u<<3|0>>>29,v<<3|u>>>29)|0;C=F;t=YGb(s,C,32768,0)|0;r=F;q=YGb(s,C,-2147450880,0)|0;C=F;s=0;if(C>>>0>s>>>0|C>>>0==s>>>0&q>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;D=((r>>31|((r|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{D=t>>>16&65535}b[h+(j<<1)>>1]=D;j=j+1|0;}while((j|0)<60);UGb(n|0,l+120|0,20)|0;UGb(e|0,h+100|0,20)|0;i=k;return}function Mba(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+128|0;j=h|0;k=(c[f>>2]|0)+e|0;l=k-1|0;m=144-k|0;b[j>>1]=b[d+(m<<1)>>1]|0;b[j+2>>1]=b[d+(m+1<<1)>>1]|0;k=m+2|0;m=2;do{b[j+(m<<1)>>1]=b[d+(k+((m-2|0)%(l|0)|0)<<1)>>1]|0;m=m+1|0;}while((m|0)<64);m=((g|0)==0&(e|0)<58?1842768:1846168)+(((c[f+4>>2]|0)*20|0)<<1)|0;f=0;do{e=C$(j+(f<<1)|0,m,5)|0;g=e;e=0>>>31|g<<1;l=YGb(e,g>>31|((g|0)<0|0?-1:0)<<1,-2147483648,0)|0;k=F;d=0;if(k>>>0>d>>>0|k>>>0==d>>>0&l>>>0>-1>>>0){((g|0)<0|0?-1:0)>>31|((g|0)<0|0?-1:0)<<1;n=(g>>31|((g|0)<0|0?-1:0)<<1)^2147483647}else{n=e}e=n;g=(n|0)<0|0?-1:0;l=e<<1|0>>>31;d=YGb(l,g<<1|e>>>31,-2147483648,0)|0;e=F;k=0;if(e>>>0>k>>>0|e>>>0==k>>>0&d>>>0>-1>>>0){((g|0)<0|0?-1:0)>>30|((g|0)<0|0?-1:0)<<2;o=(g>>30|((g|0)<0|0?-1:0)<<2)^2147483647}else{o=l}l=o;g=(o|0)<0|0?-1:0;d=YGb(l,g,32768,0)|0;k=F;e=YGb(l,g,-2147450880,0)|0;g=F;l=0;if(g>>>0>l>>>0|g>>>0==l>>>0&e>>>0>-1>>>0){((k|0)<0|0?-1:0)>>31|((k|0)<0|0?-1:0)<<1;p=((k>>31|((k|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{p=d>>>16&65535}b[a+(f<<1)>>1]=p;f=f+1|0;}while((f|0)<60);i=h;return}function Nba(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;j=i;i=i+1024|0;k=j|0;l=j+120|0;m=j+184|0;n=j+304|0;o=j+424|0;p=j+544|0;q=j+784|0;r=m;UGb(r|0,e|0,120)|0;e=l+12|0;c[e>>2]=0;if((h|0)<58){c[e>>2]=1;UGb(k|0,r|0,120)|0;r=h;while(1){s=60-r|0;if((s|0)>0){t=0;do{u=m+(t+r<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[k+(t<<1)>>1]|0);t=t+1|0;}while((t|0)<(s|0))}s=r+h|0;if((s|0)<60){r=s}else{v=0;break}}}else{v=0}do{b[n+(v<<1)>>1]=(b[m+(v<<1)>>1]|0)>>>1;v=v+1|0;}while((v|0)<60);v=n|0;r=C$(v,v,60)|0;h=r;r=0>>>31|h<<1;k=YGb(r,h>>31|((h|0)<0|0?-1:0)<<1,-2147483648,0)|0;s=F;t=0;if(s>>>0>t>>>0|s>>>0==t>>>0&k>>>0>-1>>>0){((h|0)<0|0?-1:0)>>31|((h|0)<0|0?-1:0)<<1;w=(h>>31|((h|0)<0|0?-1:0)<<1)^2147483647}else{w=r}r=w>>>0>65535>>>0;h=r?w>>>16:w;k=r?16:0;if((h&65280|0)==0){x=k;y=h}else{x=k|8;y=h>>>8}h=30-x-(d[1191992+y|0]|0)|0;y=h;x=_Gb(w|0,((w|0)<0|0?-1:0)|0,y|0)|0;w=F;k=YGb(x,w,32768,0)|0;r=F;t=YGb(x,w,-2147450880,0)|0;w=F;x=0;if(w>>>0>x>>>0|w>>>0==x>>>0&t>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;z=((r>>31|((r|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{z=k>>>16&65535}k=o|0;b[k>>1]=z;z=1;do{r=C$(n+(z<<1)|0,v,60-z|0)|0;t=r;r=0>>>31|t<<1;x=YGb(r,t>>31|((t|0)<0|0?-1:0)<<1,-2147483648,0)|0;w=F;s=0;if(w>>>0>s>>>0|w>>>0==s>>>0&x>>>0>-1>>>0){((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1;A=(t>>31|((t|0)<0|0?-1:0)<<1)^2147483647}else{A=r}r=_Gb(A|0,((A|0)<0|0?-1:0)|0,y|0)|0;t=F;x=YGb(r,t,32768,0)|0;s=F;w=YGb(r,t,-2147450880,0)|0;t=F;r=0;if(t>>>0>r>>>0|t>>>0==r>>>0&w>>>0>-1>>>0){((s|0)<0|0?-1:0)>>31|((s|0)<0|0?-1:0)<<1;B=((s>>31|((s|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{B=x>>>16&65535}b[o+(z<<1)>>1]=B;z=z+1|0;}while((z|0)<60);z=h-4|0;B=m|0;y=(z|0)<0;A=4-h|0;h=z;z=0;do{v=C$(f+(z<<1)|0,B,60-z|0)|0;x=v;v=0>>>31|x<<1;s=YGb(v,x>>31|((x|0)<0|0?-1:0)<<1,-2147483648,0)|0;w=F;r=0;if(w>>>0>r>>>0|w>>>0==r>>>0&s>>>0>-1>>>0){((x|0)<0|0?-1:0)>>31|((x|0)<0|0?-1:0)<<1;C=(x>>31|((x|0)<0|0?-1:0)<<1)^2147483647}else{C=v}v=C;x=(C|0)<0|0?-1:0;if(y){s=aHb(v|0,x|0,A|0)|0;c[p+(z<<2)>>2]=s}else{s=_Gb(v|0,x|0,h|0)|0;x=F;v=YGb(s,x,-2147483648,0)|0;r=F;w=0;if(r>>>0>w>>>0|r>>>0==w>>>0&v>>>0>-1>>>0){((x|0)<0|0?-1:0)>>31|((x|0)<0|0?-1:0)<<1;D=(x>>31|((x|0)<0|0?-1:0)<<1)^2147483647}else{D=s}c[p+(z<<2)>>2]=D}z=z+1|0;}while((z|0)<60);z=b[k>>1]|0;k=z<<16>>16;D=z<<16>>16<0|0?-1:0;z=l+4|0;h=l+16|0;A=l+40|0;y=(g|0)>1;C=n;B=(g|0)>0;s=a|0;x=a+8|0;v=a+4|0;w=a+12|0;r=0;do{t=0;u=r;while(1){E=c[p+(u<<2)>>2]|0;G=(E|0)>-1?E:-E|0;if((G|0)<(t|0)){H=t}else{c[h>>2]=u;H=G}G=u+2|0;if((G|0)<60){t=H;u=G}else{break}}u=H;t=(H|0)<0|0?-1:0;G=22;E=1073741824;I=22;while(1){J=b[1049952+(I<<1)>>1]|0;K=J<<16>>16;L=gHb(K<<1|0>>>31,(J<<16>>16<0|0?-1:0)<<1|K>>>31,k,D)|0;K=F;J=YGb(L,K,-2147483648,0)|0;M=F;N=0;if(M>>>0>N>>>0|M>>>0==N>>>0&J>>>0>-1>>>0){((K|0)<0|0?-1:0)>>31|((K|0)<0|0?-1:0)<<1;O=(K>>31|((K|0)<0|0?-1:0)<<1)^2147483647}else{O=L}L=ZGb(O,(O|0)<0|0?-1:0,u,t)|0;K=F;J=-1;N=(K|0)>(J|0)|(K|0)==(J|0)&L>>>0>-1>>>0;J=ZGb(0,0,L,K)|0;M=N?L:J;J=N?K:F;K=(E|0)<0|0?-1:0;N=(J|0)<(K|0)|(J|0)==(K|0)&M>>>0<E>>>0;P=N?I:G;K=I-1|0;if((K|0)>1){G=P;E=N?M:E;I=K}else{break}}I=P-3|0;E=1;do{G=r;do{b[n+(G<<1)>>1]=0;c[q+(G<<2)>>2]=c[p+(G<<2)>>2];G=G+2|0;}while((G|0)<60);G=I+E|0;c[z>>2]=G;t=b[1049952+(G<<1)>>1]|0;G=c[h>>2]|0;u=-t|0;K=(c[q+(G<<2)>>2]|0)<0?u:t;c[A>>2]=K;b[n+(G<<1)>>1]=1;if(y){M=1;N=G;G=K;do{K=l+16+(M<<2)|0;J=-1073741824;L=r;while(1){do{if((b[n+(L<<1)>>1]|0)==0){Q=L-N|0;R=b[o+(((Q|0)>-1?Q:-Q|0)<<1)>>1]|0;Q=R<<16>>16;S=gHb(Q<<1|0>>>31,(R<<16>>16<0|0?-1:0)<<1|Q>>>31,G,(G|0)<0|0?-1:0)|0;Q=F;R=YGb(S,Q,-2147483648,0)|0;T=F;U=0;if(T>>>0>U>>>0|T>>>0==U>>>0&R>>>0>-1>>>0){((Q|0)<0|0?-1:0)>>31|((Q|0)<0|0?-1:0)<<1;V=(Q>>31|((Q|0)<0|0?-1:0)<<1)^2147483647}else{V=S}S=q+(L<<2)|0;Q=(c[S>>2]|0)-V|0;c[S>>2]=Q;S=(Q|0)>-1?Q:-Q|0;if((S|0)<=(J|0)){W=J;break}c[K>>2]=L;W=S}else{W=J}}while(0);S=L+2|0;if((S|0)<60){J=W;L=S}else{break}}N=c[K>>2]|0;G=(c[q+(N<<2)>>2]|0)<0?u:t;c[l+40+(M<<2)>>2]=G;b[n+(N<<1)>>1]=1;M=M+1|0;}while((M|0)<(g|0))}TGb(C|0,0,120)|0;if(B){M=0;while(1){b[n+(c[l+16+(M<<2)>>2]<<1)>>1]=c[l+40+(M<<2)>>2];N=M+1|0;if((N|0)<(g|0)){M=N}else{X=59;break}}}else{X=59}while(1){M=0;N=0;G=0;do{t=b[n+(M<<1)>>1]|0;u=t<<16>>16;L=b[m+(X-M<<1)>>1]|0;J=gHb(u<<1|0>>>31,(t<<16>>16<0|0?-1:0)<<1|u>>>31,L<<16>>16,L<<16>>16<0|0?-1:0)|0;L=F;u=YGb(J,L,-2147483648,0)|0;t=F;S=0;if(t>>>0>S>>>0|t>>>0==S>>>0&u>>>0>-1>>>0){((L|0)<0|0?-1:0)>>31|((L|0)<0|0?-1:0)<<1;Y=(L>>31|((L|0)<0|0?-1:0)<<1)^2147483647}else{Y=J}J=YGb(Y,(Y|0)<0|0?-1:0,G,N)|0;L=F;u=YGb(J,L,-2147483648,0)|0;S=F;t=0;if(S>>>0>t>>>0|S>>>0==t>>>0&u>>>0>-1>>>0){((L|0)<0|0?-1:0)>>31|((L|0)<0|0?-1:0)<<1;Z=(L>>31|((L|0)<0|0?-1:0)<<1)^2147483647}else{Z=J}G=Z;N=(Z|0)<0|0?-1:0;M=M+1|0;}while((M|0)<=(X|0));b[n+(X<<1)>>1]=G>>>14|N<<18;if((X|0)>0){X=X-1|0}else{_=0;$=0;break}}while(1){M=b[f+(_<<1)>>1]|0;K=M<<16>>16;J=b[n+(_<<1)>>1]|0;L=J<<16>>16;u=J<<16>>16<0|0?-1:0;J=gHb(K<<1|0>>>31,(M<<16>>16<0|0?-1:0)<<1|K>>>31,L,u)|0;K=F;M=YGb(J,K,-2147483648,0)|0;t=F;S=0;if(t>>>0>S>>>0|t>>>0==S>>>0&M>>>0>-1>>>0){((K|0)<0|0?-1:0)>>31|((K|0)<0|0?-1:0)<<1;aa=(K>>31|((K|0)<0|0?-1:0)<<1)^2147483647}else{aa=J}J=ZGb($,($|0)<0|0?-1:0,aa,(aa|0)<0|0?-1:0)|0;K=F;M=YGb(J,K,-2147483648,0)|0;S=F;t=0;if(S>>>0>t>>>0|S>>>0==t>>>0&M>>>0>-1>>>0){((K|0)<0|0?-1:0)>>31|((K|0)<0|0?-1:0)<<1;ba=(K>>31|((K|0)<0|0?-1:0)<<1)^2147483647}else{ba=J}J=gHb(L,u,L,u)|0;u=YGb(J,F,-2147483648,0)|0;L=F;K=0;M=L>>>0>K>>>0|L>>>0==K>>>0&u>>>0>-1>>>0;u=J;J=YGb(ba,(ba|0)<0|0?-1:0,M?2147483647:u,M?0:(u|0)<0|0?-1:0)|0;u=F;M=YGb(J,u,-2147483648,0)|0;K=F;L=0;if(K>>>0>L>>>0|K>>>0==L>>>0&M>>>0>-1>>>0){((u|0)<0|0?-1:0)>>31|((u|0)<0|0?-1:0)<<1;ca=(u>>31|((u|0)<0|0?-1:0)<<1)^2147483647}else{ca=J}J=_+1|0;if((J|0)<60){_=J;$=ca}else{break}}do{if((ca|0)<(c[s>>2]|0)){c[s>>2]=ca;c[x>>2]=r;c[v>>2]=c[z>>2];c[w>>2]=c[e>>2];if(B){da=0}else{break}do{c[a+40+(da<<2)>>2]=c[l+40+(da<<2)>>2];c[a+16+(da<<2)>>2]=c[l+16+(da<<2)>>2];da=da+1|0;}while((da|0)<(g|0))}}while(0);E=E+1|0;}while((E|0)<5);r=r+1|0;}while((r|0)<2);i=j;return}function Oba(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a<<1;if(b>>>0<255>>>0){e=((d[1135648+(b|1)|0]|0)+2097151|0)>>>5&65535;f=e&-2;return f|0}do{if(b>>>0<4096>>>0){g=(d[1135648+(a>>>3&268435455)|0]|0)>>>2}else{if(b>>>0<16384>>>0){g=(d[1135648+(a>>>5&67108863)|0]|0)>>>1;break}if(b>>>0<65536>>>0){g=d[1135648+(a>>>7&16777215)|0]|0;break}else{h=a>>>15;i=(h&65280|0)==0;j=((d[1191992+(i?h&65535:a>>>23&255)|0]|0)+(i?0:8)|0)>>>1;i=b>>>((j+2|0)>>>0);h=d[1135648+(i>>>((j+8|0)>>>0))|0]|0;gHb(i,0,c[1199552+(h<<2)>>2]|0,0)|0;g=F+(h<<j)|0;break}}}while(0);e=(g-((ba(g,g)|0)>>>0>b>>>0)|0)>>>1&65535;f=e&-2;return f|0}function Pba(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[d>>2]=a;a=g<<1;if((ba(a,g)|0)>((ba(h,f)|0)>>1|0)){if((g|0)<(h|0)){i=(ba(b[562576+(e<<1)>>1]|0,(g<<15|0)/(h|0)|0)|0)>>>15&65535;b[d+4>>1]=i;j=i}else{i=b[562576+(e<<1)>>1]|0;b[d+4>>1]=i;j=i}i=j<<16>>16;e=(ba(a,i)|0)+(f<<15)|0;a=(ba((ba(i,i)|0)>>>15,h)|0)+32768|0;h=YGb(a,(a|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=F;a=YGb(h,e,-2147483648,0)|0;i=F;g=0;if(i>>>0>g>>>0|i>>>0==g>>>0&a>>>0>-1>>>0){((e|0)<0|0?-1:0)>>31|((e|0)<0|0?-1:0)<<1;k=(e>>31|((e|0)<0|0?-1:0)<<1)^2147483647}else{k=h}h=k>>16;if((h<<1|0)>(f|0)){l=((f<<14|0)/(h|0)|0)<<16}else{l=2147418112}h=Oba(l)|0;b[d+6>>1]=h;m=j;n=h<<16>>16}else{b[d+4>>1]=0;b[d+6>>1]=32767;m=0;n=32767}h=d+4|0;d=ba(n,m<<16>>16)|0;m=d>>15;if(!((m+32768|0)>>>0>65535>>>0)){o=m&65535;b[h>>1]=o;return}o=(d>>31^32767)&65535;b[h>>1]=o;return}function Qba(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+16|0;e=d|0;f=c[b+60>>2]|0;g=c[b+412>>2]|0;do{if((c[b+680>>2]|0)>-1){if((g|0)==8e3){h=8e3;break}yDb(b,16,1940576,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=d;return k|0}else{if((g|0)>0){h=g;break}yDb(0,0,1916296,(j=i,i=i+24|0,c[j>>2]=1895744,c[j+8>>2]=2352976,c[j+16>>2]=319,j)|0);i=j;Cd();return 0}}while(0);if((c[b+416>>2]|0)!=1){yDb(b,16,2332888,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=d;return k|0}j=b+72|0;g=c[j>>2]|0;if((g|0)==0){l=c[f+120>>2]|0}else{m=(((h|0)/2|0)+g|0)/(h|0)|0;c[f+120>>2]=m;l=m}m=f+120|0;if((l|0)<2){n=2}else{n=(l|0)>5?5:l}c[m>>2]=n;c[j>>2]=ba(c[b+412>>2]|0,n)|0;c[b+792>>2]=c[m>>2];n=f+4|0;j=(c[m>>2]|0)-2|0;m=2365400+(j<<4)|0;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];c[n+12>>2]=c[m+12>>2];a[f+22|0]=32;c[f+76>>2]=1;a[f+25|0]=32;c[f+80>>2]=1;a[f+28|0]=32;a[f+31|0]=32;a[f+34|0]=32;a[f+37|0]=32;a[f+40|0]=32;a[f+43|0]=32;c[f+88>>2]=544;c[f+92>>2]=34816;c[f+116>>2]=544;c[e>>2]=4096;c[e+4>>2]=2736;c[e+8>>2]=2048;c[e+12>>2]=1640;c[b+424>>2]=c[e+(j<<2)>>2];k=0;i=d;return k|0}function Rba(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=i;k=c[e+60>>2]|0;l=k;m=c[g>>2]|0;n=g+76|0;g=k+120|0;o=((ba(c[g>>2]|0,c[n>>2]|0)|0)+7|0)/8|0;p=r0a(e,f,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=j;return q|0}p=f+28|0;e=0;do{if((c[n>>2]|0)>0){r=k+108|0;s=k+116|0;t=k+4|0;u=(c[p>>2]|0)<0?0:c[f+24>>2]|0;v=32;w=0;y=m;z=0;while(1){A=c[g>>2]|0;B=((b[y>>1]|0)/4|0)-(c[r>>2]|0)|0;C=(B|0)<0?-B|0:B;D=(C&65280|0)==0;E=(D?0:8)+(d[1191992+(D?C:C>>>8)|0]|0)|0;D=(C<<7>>E&127|E<<7)-(c[s>>2]>>2)|0;E=c[t>>2]|0;C=0;while(1){F=c[E+(C<<2)>>2]|0;if((F|0)!=2147483647&(F|0)<(D|0)){C=C+1|0}else{break}}D=B>>31;E=(C^D)&255;if((A|0)==2){G=E}else{G=(C|0)==(D|0)?-1:E}E=G&255&(1<<A)+255;Vba(l,E)|0;if((v|0)>(A|0)){H=v;I=z<<A|E;J=u}else{D=u;x=fe(E>>>((A-v|0)>>>0)|z<<v|0)|0;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;H=v+32|0;I=E;J=u+4|0}K=H-A|0;e=I;E=w+1|0;if((E|0)<(c[n>>2]|0)){u=J;v=K;w=E;y=y+2|0;z=I}else{break}}if((K|0)>=32){break}z=I<<K;e=z;y=z>>>24&255;z=K;w=J;while(1){a[w]=y;v=e;e=v<<8;u=z+8|0;if((u|0)<32){y=v>>>16&255;z=u;w=w+1|0}else{break}}}}while(0);e=0;c[p>>2]=o;c[h>>2]=1;q=0;i=j;return q|0}function Sba(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=c[b+60>>2]|0;f=b+416|0;if((c[f>>2]|0)>1){DDb(b,2007056,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1163346256;i=d;return h|0}c[f>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;c[e+124>>2]=(QGb(c[c[b+12>>2]>>2]|0,2188264)|0)==0;f=c[b+792>>2]|0;c[e+120>>2]=f;j=f-2|0;if(j>>>0>3>>>0){yDb(b,16,1969144,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-22;i=d;return h|0}else{g=e+4|0;f=2365400+(j<<4)|0;c[g>>2]=c[f>>2];c[g+4>>2]=c[f+4>>2];c[g+8>>2]=c[f+8>>2];c[g+12>>2]=c[f+12>>2];a[e+22|0]=32;c[e+76>>2]=1;a[e+25|0]=32;c[e+80>>2]=1;a[e+28|0]=32;a[e+31|0]=32;a[e+34|0]=32;a[e+37|0]=32;a[e+40|0]=32;a[e+43|0]=32;c[e+88>>2]=544;c[e+92>>2]=34816;c[e+116>>2]=544;c[b+420>>2]=1;h=0;i=d;return h|0}return 0}function Tba(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[a+60>>2]|0;l=g;m=k<<3;n=g+120|0;o=(m|0)/(c[n>>2]|0)|0;c[e+76>>2]=o;p=_$a(a,e,0)|0;if((p|0)<0){q=p;i=h;return q|0}p=m>>>0>2147483639>>>0|(j|0)==0;r=p?0:j;j=p?0:m;m=j+8|0;if((o|0)==0){s=0}else{p=g+124|0;g=0;t=c[e>>2]|0;e=o;while(1){o=e-1|0;u=c[n>>2]|0;v=r+(g>>>3)|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;if((c[p>>2]|0)==0){v=(fe(w|0)|0)<<(g&7)>>>((32-u|0)>>>0);x=u+g|0;y=v;z=m>>>0>x>>>0?x:m}else{x=32-u|0;v=u+g|0;y=w>>>((g&7)>>>0)<<x>>>(x>>>0);z=m>>>0>v>>>0?v:m}b[t>>1]=Vba(l,y)|0;if((o|0)==0){s=z;break}else{g=z;t=t+2|0;e=o}}}if((j-s|0)>0){yDb(a,16,2052616,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a}c[f>>2]=1;q=k;i=h;return q|0}function Uba(b){b=b|0;var d=0,e=0;d=c[b+60>>2]|0;b=d+4|0;e=2365400+((c[d+120>>2]|0)-2<<4)|0;c[b>>2]=c[e>>2];c[b+4>>2]=c[e+4>>2];c[b+8>>2]=c[e+8>>2];c[b+12>>2]=c[e+12>>2];a[d+22|0]=32;c[d+76>>2]=1;a[d+25|0]=32;c[d+80>>2]=1;a[d+28|0]=32;a[d+31|0]=32;a[d+34|0]=32;a[d+37|0]=32;a[d+40|0]=32;a[d+43|0]=32;c[d+88>>2]=544;c[d+92>>2]=34816;c[d+116>>2]=544;return}function Vba(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;g=f>>(c[e+120>>2]|0)-1;h=e+116|0;i=c[h>>2]|0;j=(b[(c[e+8>>2]|0)+(f<<1)>>1]|0)+(i>>2)|0;if((j|0)<0){k=0}else{k=(j&127|128)<<(j>>>7&15)>>>7<<16>>16}j=e+92|0;l=c[j>>2]|0;m=l>>15;if((m|0)>9){n=23808}else{n=(((l>>>10&31|32)<<m)*3|0)>>2}m=e+104|0;o=(c[m>>2]|0)==1&(k|0)>(n|0);n=(g|0)==0?k:-k|0;p=e+108|0;q=(c[p>>2]|0)+n|0;r=e+112|0;s=(c[r>>2]|0)+n|0;if((s|0)==0){t=0}else{t=s>>31|1}if((n|0)==0){u=0}else{u=n>>31<<7|128}s=e+44|0;if(o){TGb(s|0,0,32)|0;v=c[e+76>>2]|0;w=0;x=0;y=0;z=e+80|0}else{A=c[s>>2]|0;B=c[e+76>>2]|0;C=(ba(ba(A,-t|0)|0,B)|0)>>5;if((C|0)<-256){D=-256}else{D=(C|0)>255?255:C}C=e+80|0;E=(ba(t<<7,c[C>>2]|0)|0)+D|0;D=e+48|0;F=c[D>>2]|0;G=E+F-(F>>7)|0;if((G|0)<-12288){H=-12288}else{H=(G|0)>12288?12288:G}c[D>>2]=H;D=(ba(t*192|0,B)|0)-(A>>8)+A|0;c[s>>2]=D;A=15360-H|0;G=-A|0;if((D|0)<(G|0)){I=G}else{I=(D|0)>(A|0)?A:D}c[s>>2]=I;s=ba(-(d[e+26|0]|0)>>31|1,u)|0;D=e+52|0;A=c[D>>2]|0;G=A-(A>>8)+s|0;c[D>>2]=G;D=ba(-(d[e+29|0]|0)>>31|1,u)|0;s=e+56|0;A=c[s>>2]|0;c[s>>2]=A-(A>>8)+D;D=ba(-(d[e+32|0]|0)>>31|1,u)|0;A=e+60|0;s=c[A>>2]|0;c[A>>2]=s-(s>>8)+D;D=ba(-(d[e+35|0]|0)>>31|1,u)|0;s=e+64|0;A=c[s>>2]|0;c[s>>2]=A-(A>>8)+D;D=ba(-(d[e+38|0]|0)>>31|1,u)|0;A=e+68|0;s=c[A>>2]|0;c[A>>2]=s-(s>>8)+D;D=ba(-(d[e+41|0]|0)>>31|1,u)|0;u=e+72|0;s=c[u>>2]|0;c[u>>2]=s-(s>>8)+D;v=B;w=H;x=I;y=G;z=C}c[z>>2]=v;c[e+76>>2]=(t|0)!=0?t:1;t=e+23|0;v=e+20|0;a[t]=a[v]|0;a[t+1|0]=a[v+1|0]|0;a[t+2|0]=a[v+2|0]|0;z=q>>>31&255;a[v]=z;v=z<<24>>24==0?q:-q|0;C=(v&65280|0)==0;G=(q|0)!=0;I=(d[1191992+(C?v:v>>>8)|0]|0)+((C?0:8)|G&1)|0;a[e+21|0]=I;if(G){J=v<<6>>(I&255)&255}else{J=32}a[e+22|0]=J;v=e+41|0;G=e+38|0;a[v]=a[G]|0;a[v+1|0]=a[G+1|0]|0;a[v+2|0]=a[G+2|0]|0;v=e+35|0;a[G]=a[v]|0;a[G+1|0]=a[v+1|0]|0;a[G+2|0]=a[v+2|0]|0;G=e+32|0;a[v]=a[G]|0;a[v+1|0]=a[G+1|0]|0;a[v+2|0]=a[G+2|0]|0;v=e+29|0;a[G]=a[v]|0;a[G+1|0]=a[v+1|0]|0;a[G+2|0]=a[v+2|0]|0;G=e+26|0;a[v]=a[G]|0;a[v+1|0]=a[G+1|0]|0;a[v+2|0]=a[G+2|0]|0;G=n>>>31&255;v=e+26|0;a[v]=G;C=G<<24>>24==0?n:-n|0;n=(C&65280|0)==0;G=(k|0)!=0;k=(d[1191992+(n?C:C>>>8)|0]|0)+((n?0:8)|G&1)|0;a[e+27|0]=k;if(G){K=C<<6>>(k&255)&255}else{K=32}a[e+28|0]=K;a[v]=g;g=(w|0)<-11776;c[m>>2]=g&1;m=(c[e+16>>2]|0)+f|0;v=e+96|0;K=c[v>>2]|0;k=(-K>>5)+K+(d[m]<<4)|0;c[v>>2]=k;v=e+100|0;K=c[v>>2]|0;C=(-K>>7)+K+(d[m]<<4)|0;c[v>>2]=C;v=e+84|0;do{if(o){c[v>>2]=256;L=256}else{m=c[v>>2]|0;K=(-m>>4)+m|0;c[v>>2]=K;if(!((i|0)<1536|g)){m=(k<<2)-C|0;if((((m|0)>-1?m:-m|0)|0)<(C>>3|0)){L=K;break}}m=K+32|0;c[v>>2]=m;L=m}}while(0);v=(-i>>5)+i+(b[(c[e+12>>2]|0)+(f<<1)>>1]|0)|0;if((v|0)<544){M=544}else{M=(v|0)>5120?5120:v}c[e+88>>2]=M;v=l+M+(-l>>6)|0;c[j>>2]=v;c[h>>2]=(ba(M-(v>>6)|0,(L|0)>255?64:L>>2)|0)+v>>6;c[p>>2]=0;v=0;L=0;M=y;while(1){y=M>>2;h=y>>>31&255;j=h<<24>>24==0?y:-y|0;l=(j&65280|0)==0;f=(y|0)!=0;y=((l?0:8)|f&1)+(d[1191992+(l?j:j>>>8)|0]|0)|0;if(f){f=y&255;N=j<<6>>f&255;O=f}else{N=32;O=y&255}y=(d[e+26+(v*3|0)+1|0]|0)+O|0;f=((ba(d[e+26+(v*3|0)+2|0]|0,N)|0)+48|0)>>>4;if((y|0)>19){P=f<<y-19}else{P=f>>>((19-y|0)>>>0)}Q=((h<<24>>24!=(a[e+26+(v*3|0)|0]|0)?-P|0:P)<<16>>16)+L|0;c[p>>2]=Q;h=v+1|0;if((h|0)>=6){break}v=h;L=Q;M=c[e+52+(h<<2)>>2]|0}c[r>>2]=Q>>1;r=x>>2;x=r>>>31&255;M=x<<24>>24==0?r:-r|0;L=(M&65280|0)==0;v=(r|0)!=0;r=((L?0:8)|v&1)+(d[1191992+(L?M:M>>>8)|0]|0)|0;if(v){v=r&255;R=M<<6>>v&255;S=v}else{R=32;S=r&255}r=(I&255)+S|0;S=((ba(J&255,R)|0)+48|0)>>>4;if((r|0)>19){T=S<<r-19}else{T=S>>>((19-r|0)>>>0)}r=((x<<24>>24!=z<<24>>24?-T|0:T)<<16>>16)+Q|0;c[p>>2]=r;Q=w>>2;w=Q>>>31&255;T=w<<24>>24==0?Q:-Q|0;z=(T&65280|0)==0;x=(Q|0)!=0;Q=((z?0:8)|x&1)+(d[1191992+(z?T:T>>>8)|0]|0)|0;if(x){x=Q&255;U=T<<6>>x&255;V=x}else{U=32;V=Q&255}Q=(d[e+24|0]|0)+V|0;V=((ba(d[e+25|0]|0,U)|0)+48|0)>>>4;if((Q|0)>19){W=V<<Q-19}else{W=V>>>((19-Q|0)>>>0)}c[p>>2]=((w<<24>>24!=(a[t]|0)?-W|0:W)<<16>>16)+r>>1;r=q<<2;if((r|0)<-65535){X=1;return X|0}X=(r|0)>65535?-1:r&65535;return X|0}function Wba(a){a=a|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[a+60>>2]|0;f=c[a+416>>2]|0;if((f|0)==1){c[a+420>>2]=1;c[a+424>>2]=80;c[e+2544>>2]=16384;g=e+1720|0;c[e+1820>>2]=g;b[g>>1]=2339;b[e+1722>>1]=4679;b[e+1724>>1]=7018;b[e+1726>>1]=9358;b[e+1728>>1]=11698;b[e+1730>>1]=14037;b[e+1732>>1]=16377;b[e+1734>>1]=18717;b[e+1736>>1]=21056;b[e+1738>>1]=23396;g=e+1740|0;c[e+1824>>2]=g;b[g>>1]=2339;b[e+1742>>1]=4679;b[e+1744>>1]=7018;b[e+1746>>1]=9358;b[e+1748>>1]=11698;b[e+1750>>1]=14037;b[e+1752>>1]=16377;b[e+1754>>1]=18717;b[e+1756>>1]=21056;b[e+1758>>1]=23396;g=e+1760|0;c[e+1828>>2]=g;b[g>>1]=2339;b[e+1762>>1]=4679;b[e+1764>>1]=7018;b[e+1766>>1]=9358;b[e+1768>>1]=11698;b[e+1770>>1]=14037;b[e+1772>>1]=16377;b[e+1774>>1]=18717;b[e+1776>>1]=21056;b[e+1778>>1]=23396;g=e+1780|0;c[e+1832>>2]=g;b[g>>1]=2339;b[e+1782>>1]=4679;b[e+1784>>1]=7018;b[e+1786>>1]=9358;b[e+1788>>1]=11698;b[e+1790>>1]=14037;b[e+1792>>1]=16377;b[e+1794>>1]=18717;b[e+1796>>1]=21056;b[e+1798>>1]=23396;g=e+1800|0;c[e+1836>>2]=g;b[g>>1]=2339;b[e+1802>>1]=4679;b[e+1804>>1]=7018;b[e+1806>>1]=9358;b[e+1808>>1]=11698;b[e+1810>>1]=14037;b[e+1812>>1]=16377;b[e+1814>>1]=18717;b[e+1816>>1]=21056;b[e+1818>>1]=23396;g=e+1860|0;c[e+1900>>2]=g;c[e+1904>>2]=e+1880;UGb(g|0,688416,20)|0;c[e+1712>>2]=e+1552;c[e+1716>>2]=20;b[e+2548>>1]=21845;b[e+1908>>1]=-14336;b[e+1910>>1]=-14336;b[e+1912>>1]=-14336;b[e+1914>>1]=-14336;Z3(e,a);c[e+1224>>2]=300;h=0;i=d;return h|0}else{yDb(a,16,1940504,(a=i,i=i+8|0,c[a>>2]=f,a)|0);i=a;h=-22;i=d;return h|0}return 0}function Xba(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0;k=i;i=i+408|0;l=k|0;m=k+80|0;n=k+128|0;o=k+136|0;p=k+216|0;q=k+320|0;r=k+328|0;s=c[j+24>>2]|0;t=c[j+28>>2]|0;j=c[f+60>>2]|0;c[q>>2]=0;c[g+76>>2]=80;u=_$a(f,g,0)|0;if((u|0)<0){v=u;i=k;return v|0}u=c[g>>2]|0;if((t|0)==10){b[j+2538>>1]=0;b[j+2536>>1]=2;yDb(f,48,2188240,(w=i,i=i+8|0,c[w>>2]=2110920,w)|0);i=w;y=1048048;z=0}else if((t|0)==8){yDb(f,48,2188240,(w=i,i=i+8|0,c[w>>2]=2052592,w)|0);i=w;y=1048040;z=1}else{yDb(f,16,2007024,(w=i,i=i+8|0,c[w>>2]=t,w)|0);i=w;v=-1094995529;i=k;return v|0}g=0;A=0;do{A=d[s+g|0]|A;g=g+1|0;}while((g|0)<(t|0));g=(A|0)==0;A=g&1;B=t<<3;C=B>>>0>2147483639>>>0|(s|0)==0;D=C?0:s;s=C?8:B+8|0;B=D;C=(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)>>>7;B=s>>>0>1>>>0?1:s;E=B+7|0;F=s>>>0>E>>>0?E:s;E=F+5|0;G=s>>>0>E>>>0?E:s;E=G+5|0;H=s>>>0>E>>>0?E:s;E=j+1840|0;I=j+1820|0;J=I;if(g){K=c[j+2552>>2]|0;L=c[j+1836>>2]|0;M=c[J>>2]|0;N=c[j+1824>>2]|0;O=c[j+1828>>2]|0;P=c[j+1832>>2]|0;Q=0;while(1){R=(b[E+(Q<<1)>>1]<<15)-(ba(b[1502928+(K*80|0)+(Q<<1)>>1]|0,b[M+(Q<<1)>>1]|0)|0)|0;S=R-(ba(b[1502948+(K*80|0)+(Q<<1)>>1]|0,b[N+(Q<<1)>>1]|0)|0)|0;R=S-(ba(b[1502968+(K*80|0)+(Q<<1)>>1]|0,b[O+(Q<<1)>>1]|0)|0)|0;S=R-(ba(b[1502988+(K*80|0)+(Q<<1)>>1]|0,b[P+(Q<<1)>>1]|0)|0)>>15;b[L+(Q<<1)>>1]=(ba(S,b[1502848+(K*20|0)+(Q<<1)>>1]|0)|0)>>>12;S=Q+1|0;if((S|0)<10){Q=S}else{T=L;break}}}else{L=D+(G>>>3)|0;Q=D+(F>>>3)|0;K=D+(B>>>3)|0;P=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0;K=fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0;L=fe(P|0)|0;P=K<<(G&7)>>>27;G=L<<(F&7)>>>27;F=(fe(Q|0)|0)<<(B&1)>>>25;B=j+1836|0;Q=c[B>>2]|0;L=(b[1503088+(G*20|0)>>1]|0)+(b[1503728+(F*20|0)>>1]|0)&65535;b[Q>>1]=L;b[Q+10>>1]=(b[1503098+(P*20|0)>>1]|0)+(b[1503738+(F*20|0)>>1]|0);K=(b[1503090+(G*20|0)>>1]|0)+(b[1503730+(F*20|0)>>1]|0)&65535;b[Q+2>>1]=K;b[Q+12>>1]=(b[1503100+(P*20|0)>>1]|0)+(b[1503740+(F*20|0)>>1]|0);b[Q+4>>1]=(b[1503092+(G*20|0)>>1]|0)+(b[1503732+(F*20|0)>>1]|0);b[Q+14>>1]=(b[1503102+(P*20|0)>>1]|0)+(b[1503742+(F*20|0)>>1]|0);b[Q+6>>1]=(b[1503094+(G*20|0)>>1]|0)+(b[1503734+(F*20|0)>>1]|0);b[Q+16>>1]=(b[1503104+(P*20|0)>>1]|0)+(b[1503744+(F*20|0)>>1]|0);b[Q+8>>1]=(b[1503096+(G*20|0)>>1]|0)+(b[1503736+(F*20|0)>>1]|0);b[Q+18>>1]=(b[1503106+(P*20|0)>>1]|0)+(b[1503746+(F*20|0)>>1]|0);F=1;P=L;L=K;while(1){K=P<<16>>16;G=10-(L<<16>>16)+K>>1;if((G|0)>0){b[Q+(F-1<<1)>>1]=K-G;K=G+(L&65535)&65535;b[Q+(F<<1)>>1]=K;U=K}else{U=L}K=F+1|0;if((K|0)>=10){break}F=K;P=U;L=b[Q+(K<<1)>>1]|0}L=1;U=b[Q>>1]|0;while(1){P=U<<16>>16;F=Q+(L<<1)|0;K=b[F>>1]|0;G=P+5-(K<<16>>16)>>1;if((G|0)>0){b[Q+(L-1<<1)>>1]=P-G;P=G+(K&65535)&65535;b[F>>1]=P;V=P}else{V=K}K=L+1|0;if((K|0)<10){L=K;U=V}else{break}}V=C&1;C=c[J>>2]|0;U=c[j+1824>>2]|0;L=c[j+1828>>2]|0;K=c[j+1832>>2]|0;P=0;do{F=ba(b[1502888+(V*20|0)+(P<<1)>>1]|0,b[Q+(P<<1)>>1]|0)|0;G=(ba(b[1502928+(V*80|0)+(P<<1)>>1]|0,b[C+(P<<1)>>1]|0)|0)+F|0;F=G+(ba(b[1502948+(V*80|0)+(P<<1)>>1]|0,b[U+(P<<1)>>1]|0)|0)|0;G=F+(ba(b[1502968+(V*80|0)+(P<<1)>>1]|0,b[L+(P<<1)>>1]|0)|0)|0;b[E+(P<<1)>>1]=(G+(ba(b[1502988+(V*80|0)+(P<<1)>>1]|0,b[K+(P<<1)>>1]|0)|0)|0)>>>15;P=P+1|0;}while((P|0)<10);JKa(E,321,40,25681,10);c[j+2552>>2]=V;T=c[B>>2]|0}VGb(j+1824|0,I|0,16)|0;c[J>>2]=T;T=j+1904|0;LKa(c[T>>2]|0,E,10);E=j+1900|0;PKa(m|0,m+22|0,c[T>>2]|0,c[E>>2]|0,10);J=c[E>>2]|0;c[E>>2]=c[T>>2];c[T>>2]=J;J=d[y+6|0]|0;T=32-J|0;E=d[y+5|0]|0;I=32-E|0;B=d[y+3|0]|0;V=32-B|0;P=d[y+4|0]|0;K=32-P|0;L=j+1716|0;U=f;f=j+2548|0;C=o;Q=o|0;G=j+2520|0;F=G;O=j+2522|0;N=j+2532|0;M=j+2534|0;S=j+1908|0;R=j+1712|0;W=j+2540|0;X=g^1;Y=p;Z=j+1916|0;_=p+20|0;$=(z|0)==1;aa=j+2538|0;ca=j+2536|0;da=O;ea=j+2524|0;fa=j+2526|0;ga=j+2528|0;ha=j+2530|0;ia=r|0;ja=l|0;ka=p+80|0;la=j;ma=j+2542|0;na=n|0;oa=j+1936|0;pa=j+2320|0;qa=j+2420|0;ra=j+2544|0;sa=j+2564|0;ta=p+16|0;ua=j+2556|0;va=p+96|0;wa=j+1244|0;xa=wa;ya=y+2|0;za=H;H=0;Aa=0;while(1){Ba=d[y+H|0]|0;Ca=D+(za>>>3)|0;Da=(fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(za&7)>>>((32-Ba|0)>>>0);Ca=Ba+za|0;Ba=s>>>0>Ca>>>0?Ca:s;Ca=(H|0)!=0;do{if(Ca){Ea=Aa;Fa=Ba}else{if((a[ya]|0)==0){Ea=Aa;Fa=Ba;break}Ga=$Gb(-1771476586|0,1771476585,Da>>>2&63|0)|0;Ea=(d[D+(Ba>>>3)|0]<<(Ba&7)>>>7^Ga)&1^1;Fa=((Ba|0)<(s|0))+Ba|0}}while(0);Ba=D+(Fa>>>3)|0;Ga=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Fa&7)>>>(T>>>0);Ba=J+Fa|0;Ha=s>>>0>Ba>>>0?Ba:s;Ba=D+(Ha>>>3)|0;Ia=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ha&7)>>>(I>>>0);Ba=Ha+E|0;Ha=s>>>0>Ba>>>0?Ba:s;Ba=Ia&255;Ia=D+(Ha>>>3)|0;Ja=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ha&7)>>>(V>>>0);Ia=Ha+B|0;Ha=s>>>0>Ia>>>0?Ia:s;Ia=D+(Ha>>>3)|0;Ka=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ha&7)>>>(K>>>0);Ia=Ha+P|0;Ha=s>>>0>Ia>>>0?Ia:s;do{if(g){La=(c[L>>2]|0)*3|0}else{if(!Ca){if((Ea|0)==0){La=Cgb(Da&255)|0;break}else{La=(c[L>>2]|0)*3|0;break}}Ia=(c[L>>2]|0)-5|0;if((Ia|0)<20){Ma=20}else{Ma=(Ia|0)>134?134:Ia}Ia=Da&255;if($){La=Dgb(Ia,Ma)|0;break}else{La=Egb(Ia,Ma)|0;break}}}while(0);Da=La+1|0;Ca=(Da|0)/3|0;Ia=n+(H<<2)|0;c[Ia>>2]=Ca;if((Da|0)>431){yDb(U,24,1969104,(w=i,i=i+8|0,c[w>>2]=Ca,w)|0);i=w;c[Ia>>2]=143;Na=143}else{Na=Ca}if(g){Ca=((b[f>>1]|0)*31821&65535)+13849&65535;Ia=(Ca*31821&65535)+13849&65535;b[f>>1]=Ia;Oa=(1<<J)+65535&(Ca&65535);Pa=Ia&255}else{Oa=Ga;Pa=Ba}TGb(C|0,0,80)|0;if((z|0)==1){Jgb(Q,1222064,1222032,Oa,Pa&255,1,4)}else if((z|0)==0){Jgb(Q,1221984,1222e3,Oa,Pa&255,3,3)}Ia=o+(Na<<1)|0;Ca=b[F>>1]|0;if(Ca<<16>>16<3277){Qa=3277}else{Qa=Ca<<16>>16>13017?13017:Ca}Lgb(Ia,Ia,Q,16384,Qa,0,14,40-Na|0);VGb(O|0,G|0,10)|0;Ia=b[N>>1]|0;b[M>>1]=Ia;if(g){b[F>>1]=((b[F>>1]|0)*29491|0)>>>15;Ra=0;Sa=((Ia<<16>>16)*2007|0)>>>11&65535}else{Ia=Ja&255;if($){Ca=Ka&255;b[F>>1]=(b[1506352+(Ca<<2)>>1]|0)+(b[1506416+(Ia<<2)>>1]|0);Da=(b[1506354+(Ca<<2)>>1]|0)+(b[1506418+(Ia<<2)>>1]|0)|0;Ta=(Da|0)>1024?Da>>1:512}else{Da=Ka&255;b[F>>1]=(b[1506288+(Da<<2)>>1]|0)+(b[1506384+(Ia<<2)>>1]|0);Ta=(b[1506290+(Da<<2)>>1]|0)+(b[1506386+(Ia<<2)>>1]|0)|0}Ra=Ta;Sa=Ggb(la,Ta,Q,1018156,S,687088,40,4)|0}b[N>>1]=Sa;Fgb(S,Ra,2,A);Ia=c[R>>2]|0;Da=H*40|0;wgb(Ia+(Da<<1)|0,Ia+(((La|0)/-3|0)+Da<<1)|0,1274120,6,((La|0)%3|0)<<1,10,40);Ia=(c[R>>2]|0)+(Da<<1)|0;Ca=b[W>>1]|0;if(Ca<<16>>16!=0|X){Ua=b[F>>1]|0}else{Ua=0}if(Ca<<16>>16==0|X){Va=b[N>>1]|0}else{Va=0}Lgb(Ia,Ia,Q,Ua,Va,8192,14,40);UGb(Y|0,Z|0,20)|0;Ia=m+(H*22|0)+2|0;if((x$(_,Ia,(c[R>>2]|0)+(Da<<1)|0,40,10,1,0,2048)|0)!=0){Ca=0;do{Wa=xa+(Ca<<1)|0;b[Wa>>1]=(b[Wa>>1]|0)>>>2;Ca=Ca+1|0;}while((Ca|0)<234)}if($){Ca=b[N>>1]|0;if((Ca>>1|0)>(b[M>>1]|0)){Xa=2}else{Ka=(b[aa>>1]|0)-1|0;Xa=(Ka|0)>0?Ka&65535:0}b[aa>>1]=Xa;Ka=b[F>>1]|0;if(Ka<<16>>16>14744){Ya=2}else{Ya=Ka<<16>>16>9830|0}Ja=Xa<<16>>16==0;Ba=(((b[da>>1]|0)<9830)+(Ka<<16>>16<9830)+((b[ea>>1]|0)<9830)+((b[fa>>1]|0)<9830)+((b[ga>>1]|0)<9830)+((b[ha>>1]|0)<9830)|0)>2&Ja?0:Ya;do{if(Ja){Za=(((Ba|0)>((b[ca>>1]|0)+1|0))<<31>>31)+Ba&65535}else{if(!(Ba>>>0<2>>>0)){Za=Ba&65535;break}Za=Ba+1&65535}}while(0);b[ca>>1]=Za;Ba=c[R>>2]|0;v$(ja,Q,589368+((Za<<16>>16)*80|0)|0,40);Ja=0;do{Ka=(e[Ba+(Ja+Da<<1)>>1]|0)-(((ba(b[o+(Ja<<1)>>1]|0,Ca)|0)+8192|0)>>>14)|0;b[r+(Ja<<1)>>1]=Ka+(((ba(b[l+(Ja<<1)>>1]|0,Ca)|0)+8192|0)>>>14);Ja=Ja+1|0;}while((Ja|0)<40);x$(_,Ia,ia,40,10,0,0,2048)|0}else{x$(_,Ia,(c[R>>2]|0)+(Da<<1)|0,40,10,0,0,2048)|0}UGb(Z|0,ka|0,20)|0;Ja=0;Ca=0;do{Ba=b[p+(Ja+10<<1)>>1]|0;Ka=Ba<<16>>16;Ca=(Ba<<16>>16>-1?Ka:-Ka|0)+Ca|0;Ja=Ja+1|0;}while((Ja|0)<40);Zba(la,ma,q,m+(H*22|0)|0,c[na>>2]|0,oa,pa,qa,_,40);Ja=0;Ia=0;do{Ka=b[p+(Ja+10<<1)>>1]|0;Ba=Ka<<16>>16;Ia=(Ka<<16>>16>-1?Ba:-Ba|0)+Ia|0;Ja=Ja+1|0;}while((Ja|0)<40);c[ra>>2]=($ba(Ca,Ia,_,40,c[ra>>2]&65535)|0)<<16>>16;if(g){Ja=(c[L>>2]|0)+1|0;_a=(Ja|0)>143?143:Ja}else{_a=Na}c[L>>2]=_a;x=e[sa>>1]|e[sa+2>>1]<<16;b[ta>>1]=x;b[ta+2>>1]=x>>16;ygb(u+(Da<<1)|0,ua,_,40);x=e[va>>1]|e[va+2>>1]<<16;b[sa>>1]=x;b[sa+2>>1]=x>>16;Ja=H+1|0;if((Ja|0)<2){za=Ha;H=Ja;Aa=Ea}else{break}}b[W>>1]=c[q>>2];VGb(wa|0,j+1404|0,308)|0;c[h>>2]=1;v=t;i=k;return v|0}function Yba(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)==0){e=0;return e|0}else{f=a;g=c;h=d;i=0}while(1){d=h-1|0;c=(ba(b[g>>1]|0,b[f>>1]|0)|0)+i|0;if((d|0)==0){e=c;break}else{f=f+2|0;g=g+2|0;h=d;i=c}}return e|0}function Zba(a,f,g,h,j,k,l,m,n,o){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;p=i;i=i+200|0;q=p|0;r=p+104|0;s=p+176|0;TGb(r|0,0,66)|0;t=0;while(1){u=t+1|0;b[r+(t+11<<1)>>1]=((ba(b[1048440+(t<<1)>>1]|0,b[h+(u<<1)>>1]|0)|0)+16384|0)>>>15;if((u|0)<10){t=u}else{break}}t=s+2|0;b[t>>1]=(((b[h+2>>1]|0)*22938|0)+16384|0)>>>15;b[s+4>>1]=(((b[h+4>>1]|0)*16057|0)+16384|0)>>>15;b[s+6>>1]=(((b[h+6>>1]|0)*11240|0)+16384|0)>>>15;b[s+8>>1]=(((b[h+8>>1]|0)*7868|0)+16384|0)>>>15;b[s+10>>1]=(((b[h+10>>1]|0)*5508|0)+16384|0)>>>15;b[s+12>>1]=(((b[h+12>>1]|0)*3856|0)+16384|0)>>>15;b[s+14>>1]=(((b[h+14>>1]|0)*2699|0)+16384|0)>>>15;b[s+16>>1]=(((b[h+16>>1]|0)*1889|0)+16384|0)>>>15;b[s+18>>1]=(((b[h+18>>1]|0)*1322|0)+16384|0)>>>15;b[s+20>>1]=(((b[h+20>>1]|0)*925|0)+16384|0)>>>15;h=l;UGb(n-20|0,h|0,20)|0;l=(o|0)>0;if(l){s=b[r+22>>1]|0;u=b[r+24>>1]|0;v=b[r+26>>1]|0;w=b[r+28>>1]|0;x=b[r+30>>1]|0;y=b[r+32>>1]|0;z=b[r+34>>1]|0;A=b[r+36>>1]|0;B=b[r+38>>1]|0;C=b[r+40>>1]|0;D=o;while(1){E=(ba(b[n+(D-2<<1)>>1]|0,s)|0)+2048|0;F=E+(ba(b[n+(D-3<<1)>>1]|0,u)|0)|0;E=F+(ba(b[n+(D-4<<1)>>1]|0,v)|0)|0;F=E+(ba(b[n+(D-5<<1)>>1]|0,w)|0)|0;E=F+(ba(b[n+(D-6<<1)>>1]|0,x)|0)|0;F=E+(ba(b[n+(D-7<<1)>>1]|0,y)|0)|0;E=F+(ba(b[n+(D-8<<1)>>1]|0,z)|0)|0;F=E+(ba(b[n+(D-9<<1)>>1]|0,A)|0)|0;E=F+(ba(b[n+(D-10<<1)>>1]|0,B)|0)|0;F=E+(ba(b[n+(D-11<<1)>>1]|0,C)|0)|0;E=D-1|0;b[k+(D+151<<1)>>1]=(F>>>12)+(e[n+(E<<1)>>1]|0);if((E|0)>0){D=E}else{break}}}UGb(h|0,n+(o-10<<1)|0,20)|0;h=c[g>>2]|0;D=q+20|0;if((h|0)>((_ba(a,j,k,D,o)|0)<<16>>16|0)){G=c[g>>2]|0}else{G=(_ba(a,j,k,D,o)|0)<<16>>16}c[g>>2]=G;VGb(k|0,k+(o<<1)|0,304)|0;k=r+20|0;b[k>>1]=4096;G=r+22|0;x$(G,t,G,22,10,0,0,2048)|0;g=a+1224|0;a=ze[c[g>>2]&511](k,k,20)|0;j=ze[c[g>>2]&511](k,G,20)|0;G=a>>>0>65535>>>0;k=G?a>>>16:a;g=G?16:0;if((k&65280|0)==0){H=g;I=k}else{H=g|8;I=k>>>8}k=H-14+(d[1191992+I|0]|0)|0;if((k|0)>0){J=a>>k;K=j>>k}else{J=a;K=j}if((((K|0)>-1?K:-K|0)|0)<=(J|0)&(J|0)!=0){j=0;a=0;do{k=b[r+(j+10<<1)>>1]|0;I=k<<16>>16;a=(k<<16>>16>-1?I:-I|0)+a|0;j=j+1|0;}while((j|0)<20);j=a>>2;do{if((j|0)>1024){a=33554432/(j|0)|0;if(l){L=0}else{break}do{r=q+(L+10<<1)|0;b[r>>1]=((ba(b[r>>1]|0,a)|0)+16384|0)>>>15;L=L+1|0;}while((L|0)<(o|0))}}while(0);M=((-(K<<15)|0)/(J|0)|0)<<16>>16}else{M=0}J=m+20|0;x$(J,t,D,o,10,0,0,2048)|0;UGb(m|0,m+(o<<1)|0,20)|0;D=b[f>>1]|0;if((M|0)>0){N=15;O=16384;P=M*6554|0}else{N=12;O=2048;P=M*29491|0}M=P+16384|0;P=M>>15;t=32768-((P|0)>-1?P:-P|0)|0;if((t+32768|0)>>>0>65535>>>0){Q=(t>>31^32767)&65535}else{Q=t&65535}t=(O<<15|0)/(Q<<16>>16|0)|0;Q=M>>16;M=o-1|0;P=b[m+(o+9<<1)>>1]|0;if((M|0)<=0){R=t<<1;S=b[J>>1]|0;T=S<<16>>16;U=T<<15;V=D<<16>>16;W=V<<1;X=ba(W,Q)|0;Y=X+16384|0;Z=Y+U|0;_=Z>>15;$=ba(_,R)|0;aa=$+O|0;ca=aa>>N;da=ca&65535;b[n>>1]=da;b[f>>1]=P;i=p;return}o=Q<<1;K=t<<1;t=M;M=P;while(1){L=t-1|0;q=m+(t+9<<1)|0;b[n+(t<<1)>>1]=(ba((ba(o,b[q>>1]|0)|0)+(M<<16>>16<<15|16384)>>15,K)|0)+O>>N;if((L|0)<=0){R=K;break}t=L;M=b[q>>1]|0}S=b[J>>1]|0;T=S<<16>>16;U=T<<15;V=D<<16>>16;W=V<<1;X=ba(W,Q)|0;Y=X+16384|0;Z=Y+U|0;_=Z>>15;$=ba(_,R)|0;aa=$+O|0;ca=aa>>N;da=ca&65535;b[n>>1]=da;b[f>>1]=P;i=p;return}function _ba(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;j=i;i=i+1016|0;k=j|0;l=j+384|0;m=j+960|0;n=h+152|0;o=(n|0)>0;a:do{if(o){p=0;q=0;do{r=b[f+(q<<1)>>1]|0;s=r<<16>>16;p=(r<<16>>16>-1?s:-s|0)|p;q=q+1|0;}while((q|0)<(n|0));do{if((p|0)==0){t=3}else{q=p>>>0>65535>>>0;s=q?p>>>16:p;r=q?16:0;if((s&65280|0)==0){u=r;v=s}else{u=r|8;v=s>>>8}s=((d[1191992+v|0]|0)+u<<16)-720896|0;r=s>>16;if((s|0)>0){t=r;break}if(!o){w=r;x=0;break a}s=-r|0;q=0;while(1){b[k+(q<<1)>>1]=b[f+(q<<1)>>1]<<s;y=q+1|0;if((y|0)<(n|0)){q=y}else{w=r;x=0;break a}}}}while(0);if(o){z=0}else{w=t;x=1;break}while(1){b[k+(z<<1)>>1]=b[f+(z<<1)>>1]>>t;p=z+1|0;if((p|0)<(n|0)){z=p}else{w=t;x=1;break}}}else{w=3;x=1}}while(0);t=a+1224|0;a=k+304|0;z=ze[c[t>>2]&511](a,a,h)|0;do{if((z|0)!=0){n=z>>>0>65535>>>0;o=n?z>>>16:z;u=n?16:0;if((o&65280|0)==0){A=u;B=o}else{A=u|8;B=o>>>8}o=A-14+(d[1191992+B|0]|0)|0;u=(o|0)>0?o&65535:0;o=u<<16>>16;n=e-1|0;v=e+1|0;p=0;r=n&65535;q=n;do{n=ze[c[t>>2]&511](a,k+(152-q<<1)|0,h)|0;s=(n|0)>(p|0);p=s?n:p;r=s?q&65535:r;q=q+1|0;}while((q|0)<=(v|0));v=z>>o;if((p|0)==0){break}q=r<<16>>16;s=152-q|0;n=k+(s<<1)|0;y=ze[c[t>>2]&511](n,n,h)|0;C=h+1|0;wgb(l|0,n,1216816,8,7,2,C);wgb(l+82|0,n,1216816,8,6,2,C);wgb(l+164|0,n,1216816,8,5,2,C);wgb(l+246|0,n,1216816,8,4,2,C);wgb(l+328|0,n,1216816,8,3,2,C);wgb(l+410|0,n,1216816,8,2,2,C);wgb(l+492|0,n,1216816,8,1,2,C);n=h-1|0;D=y;E=0;do{G=l+(E*82|0)+2|0;H=ze[c[t>>2]&511](G,G,n)|0;G=b[l+(E*82|0)>>1]|0;I=(ba(G,G)|0)+H|0;c[m+(E<<3)>>2]=I;G=b[l+(E*82|0)+(h<<1)>>1]|0;J=(ba(G,G)|0)+H|0;c[m+(E<<3)+4>>2]=J;H=(D|0)>(I|0)?D:I;D=(H|0)>(J|0)?H:J;E=E+1|0;}while((E|0)<7);E=D>>>0>65535>>>0;n=E?D>>>16:D;r=E?16:0;if((n&65280|0)==0){K=r;L=n}else{K=r|8;L=n>>>8}n=K+65522+(d[1191992+L|0]|0)&65535;r=n<<16>>16;if(!(n<<16>>16>-1)){break}E=n<<16>>16>u<<16>>16?n:u;J=E<<16>>16;H=p>>J&65535;I=H<<16>>16;G=H;H=y>>r&65535;M=ba(I,I)|0;I=0;N=1;O=0;while(1){P=O+1|0;Q=P&65535;R=(ze[c[t>>2]&511](l+(O*82|0)|0,a,h)|0)>>J;S=(R|0)>0?R&65535:0;R=S<<16>>16;T=ba(R,R)|0;R=c[m+(O<<3)>>2]>>r&65535;U=gHb(T,0,H<<16>>16,H<<16>>16<0|0?-1:0)|0;V=U>>>15|F<<17;U=gHb(R<<16>>16,R<<16>>16<0|0?-1:0,M,(M|0)<0|0?-1:0)|0;W=(V|0)>(U>>>15|F<<17|0);U=W?R:H;R=W?T:M;T=(ze[c[t>>2]&511](l+(O*82|0)+2|0,a,h)|0)>>J;V=(T|0)>0?T&65535:0;T=V<<16>>16;X=ba(T,T)|0;T=c[m+(O<<3)+4>>2]>>r&65535;Y=gHb(X,0,U<<16>>16,U<<16>>16<0|0?-1:0)|0;Z=Y>>>15|F<<17;Y=gHb(T<<16>>16,T<<16>>16<0|0?-1:0,R,(R|0)<0|0?-1:0)|0;_=(Z|0)>(Y>>>15|F<<17|0);$=_?V:W?S:G;aa=_?T:U;ca=_?X:R;da=_?Q:W?Q:I;ea=_?1:W?0:N;if((P|0)<7){G=$;H=aa;M=ca;I=da;N=ea;O=P}else{break}}O=_Gb(ca|0,((ca|0)<0|0?-1:0)|0,J<<1|1|0)|0;N=F;I=aa<<16>>16;M=aa<<16>>16<0|0?-1:0;H=gHb(I,M,v,(v|0)<0|0?-1:0)|0;G=_Gb(H|0,F|0,r+o|0)|0;H=F;y=(N|0)<(H|0)|(N|0)==(H|0)&O>>>0<G>>>0?0:$;if(y<<16>>16==0){break}G=ea<<16>>16;b:do{if(da<<16>>16==0){fa=f+(151-q+G<<1)|0;ga=n;ha=E;ia=aa;ja=y}else{O=da<<16>>16;wgb(g,k+(s+G<<1)|0,1216848,8,8-O|0,8,C);H=ze[c[t>>2]&511](g,a,h)|0;if((H|0)<0){ka=0;la=0}else{N=H>>>0>65535>>>0;p=N?H>>>16:H;u=N?16:0;if((p&65280|0)==0){ma=u;na=p}else{ma=u|8;na=p>>>8}p=ma-14+(d[1191992+na|0]|0)|0;u=(p|0)>0?p:0;ka=u&65535;la=H>>u&65535}u=ze[c[t>>2]&511](g,g,h)|0;H=u>>>0>65535>>>0;p=H?u>>>16:u;N=H?16:0;if((p&65280|0)==0){oa=N;pa=p}else{oa=N|8;pa=p>>>8}p=oa-14+(d[1191992+pa|0]|0)|0;N=(p|0)>0?p:0;p=u>>N&65535;u=N&65535;N=y<<16>>16;H=ba(N,N)|0;N=gHb(p<<16>>16,p<<16>>16<0|0?-1:0,H,0)|0;H=N>>>15|F<<17;N=la<<16>>16;D=gHb(ba(N,N)|0,0,I,M)|0;N=D>>>15|F<<17;D=r-(u<<16>>16)+((ka<<16>>16)-J<<1)|0;if((D|0)>0){qa=H>>D;ra=N}else{qa=H;ra=N>>-D}if((ra|0)>(qa|0)){sa=g;ta=u;ua=ka;va=p;wa=la}else{sa=l+((O-1|0)*82|0)+(G<<1)|0;ta=n;ua=E;va=aa;wa=y}O=(h|0)>0;if(x){if(O){xa=0}else{fa=sa;ga=ta;ha=ua;ia=va;ja=wa;break}while(1){p=sa+(xa<<1)|0;b[p>>1]=b[p>>1]<<w;p=xa+1|0;if((p|0)<(h|0)){xa=p}else{fa=sa;ga=ta;ha=ua;ia=va;ja=wa;break b}}}if(!O){fa=sa;ga=ta;ha=ua;ia=va;ja=wa;break}p=-w|0;u=0;while(1){D=sa+(u<<1)|0;b[D>>1]=b[D>>1]>>p;D=u+1|0;if((D|0)<(h|0)){u=D}else{fa=sa;ga=ta;ha=ua;ia=va;ja=wa;break}}}}while(0);y=_Gb(ja<<16>>16|0,(ja<<16>>16<0|0?-1:0)|0,(ha<<16>>16)-1|0)|0;E=F;n=_Gb(ia<<16>>16|0,(ia<<16>>16<0|0?-1:0)|0,ga<<16>>16|0)|0;G=F;J=YGb(n,G,y,E)|0;E=eHb(n<<15|0>>>17,G<<15|n>>>17,J,F)|0;J=F;n=0;G=(J|0)>(n|0)|(J|0)==(n|0)&E>>>0>21845>>>0?E:21845;Lgb(g,f+304|0,fa,G&65535,32768-G&65535,16384,15,h);ya=1;i=j;return ya|0}}while(0);UGb(g|0,f+304|0,h<<1)|0;ya=0;i=j;return ya|0}function $ba(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=(a|0)==0;if(!((c|0)!=0|h)){i=0;return i|0}if(h){j=0}else{h=a>>>0>65535>>>0;k=h?a>>>16:a;l=h?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=14-m-(d[1191992+n|0]|0)|0;if((k|0)<0){o=a>>-k}else{o=a<<k}a=c>>>0>65535>>>0;n=a?c>>>16:c;m=a?16:0;if((n&65280|0)==0){p=m;q=n}else{p=m|8;q=n>>>8}n=14-p-(d[1191992+q|0]|0)|0;if((n|0)<0){r=c>>-n}else{r=c<<n}do{if((o|0)<(r|0)){c=(o<<15|0)/(r|0)|0;q=n-k|0;p=q-1|0;if((p|0)<0){s=c>>1-q;break}else{s=c<<p;break}}else{p=((o-r<<14|0)/(r|0)|0)+16384|0;c=n-k|0;if((c|0)<0){s=p>>-c;break}else{s=p<<c;break}}}while(0);j=(s*410|0)+16384>>15}if((f|0)>0){t=g;u=0}else{i=g;return i|0}while(1){g=((((t<<16>>16)*32358|0)+16384|0)>>>15<<16>>16)+j|0;if((g+32768|0)>>>0>65535>>>0){v=(g>>31^32767)&65535}else{v=g&65535}g=e+(u<<1)|0;s=(ba(b[g>>1]|0,v<<16>>16)|0)+8192|0;k=s>>14;if((k+32768|0)>>>0>65535>>>0){w=(s>>31^32767)&65535}else{w=k&65535}b[g>>1]=w;g=u+1|0;if((g|0)<(f|0)){t=v;u=g}else{i=v;break}}return i|0}function aca(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+60>>2]|0;e=a+120|0;do{if((c[e>>2]|0)<=65535){f=a+124|0;if((c[f>>2]|0)>65535){break}g=ICb()|0;c[a+804>>2]=g;if((g|0)==0){h=-12;i=b;return h|0}c[g+88>>2]=1;c[g+84>>2]=1;g=d+4|0;c[g>>2]=cEb(c[297946]|0)|0;j=d+8|0;c[j>>2]=WDb(ba(c[e>>2]<<1,c[f>>2]|0)|0)|0;f=WDb(c[e>>2]|0)|0;c[d+1044>>2]=f;if((f|0)==0){h=-12;i=b;return h|0}if((c[j>>2]|0)==0){h=-12;i=b;return h|0}if((c[g>>2]|0)==0){h=-12;i=b;return h|0}g=a+140|0;if((fDb(d+20|0,c[g>>2]|0)|0)>=0){h=0;i=b;return h|0}if((c[g>>2]|0)==11){h=0;i=b;return h|0}else{yDb(0,0,2006992,(k=i,i=i+24|0,c[k>>2]=1969064,c[k+8>>2]=1940480,c[k+16>>2]=233,k)|0);i=k;Cd();return 0}}}while(0);yDb(a,16,2052536,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;h=-22;i=b;return h|0}function bca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;i=i+1024|0;j=h|0;k=b+60|0;l=c[k>>2]|0;m=b+120|0;n=b+124|0;o=((ba((c[m>>2]|0)*7|0,c[n>>2]|0)|0)/5|0)+16384|0;p=r0a(b,e,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=h;return q|0}p=e+24|0;o=c[p>>2]|0;r=e+28|0;s=o+(c[r>>2]|0)|0;do{if((c[b+140>>2]|0)==11){t=GZ(e,0,1024)|0;if((t|0)==0){q=-12;i=h;return q|0}else{u=f+4|0;UGb(t|0,c[u>>2]|0,1024)|0;v=c[u>>2]|0;break}}else{v=0}}while(0);u=c[f>>2]|0;t=c[f+32>>2]|0;w=c[k>>2]|0;k=c[n>>2]|0;n=c[m>>2]|0;m=w+16|0;do{if((c[m>>2]&1|0)==0){y=k;z=n;A=0;B=0}else{C=c[w+12>>2]|0;if(!((C|0)!=0&(v|0)==0)){y=k;z=n;A=0;B=0;break}D=c[C>>2]|0;E=c[C+32>>2]|0;C=n-1|0;F=k-1|0;G=0;while(1){if((G|0)>=(F|0)){H=F;break}if((PGb(D+(ba(G,E)|0)|0,u+(ba(G,t)|0)|0,n)|0)==0){G=G+1|0}else{H=F;break}}while(1){if((H|0)<=(G|0)){break}if((PGb(D+(ba(H,E)|0)|0,u+(ba(H,t)|0)|0,n)|0)==0){H=H-1|0}else{break}}F=H+(1-G)|0;a:do{if((C|0)>0){I=0;while(1){J=G;while(1){if((J|0)>=(H|0)){break}K=a[D+((ba(J,E)|0)+I)|0]|0;if(K<<24>>24==(a[u+((ba(J,t)|0)+I)|0]|0)){J=J+1|0}else{L=I;break a}}J=I+1|0;if((J|0)<(C|0)){I=J}else{L=J;break}}}else{L=0}}while(0);b:do{if((C|0)>(L|0)){I=C;while(1){J=G;while(1){if((J|0)>=(H|0)){break}K=a[D+((ba(J,E)|0)+I)|0]|0;if(K<<24>>24==(a[u+((ba(J,t)|0)+I)|0]|0)){J=J+1|0}else{M=I;break b}}J=I-1|0;if((J|0)>(L|0)){I=J}else{M=J;break}}}else{M=C}}while(0);C=M+(1-L)|0;yDb(b,48,2188144,(N=i,i=i+48|0,c[N>>2]=C,c[N+8>>2]=F,c[N+16>>2]=L,c[N+24>>2]=G,c[N+32>>2]=n,c[N+40>>2]=k,N)|0);i=N;y=F;z=C;A=G;B=L}}while(0);a[o]=44;L=o+1|0;x=B&65535;a[L]=x;x=x>>8;a[L+1|0]=x;L=o+3|0;x=A&65535;a[L]=x;x=x>>8;a[L+1|0]=x;L=o+5|0;x=z&65535;a[L]=x;x=x>>8;a[L+1|0]=x;L=o+7|0;x=y&65535;a[L]=x;x=x>>8;a[L+1|0]=x;L=o+9|0;k=(v|0)!=0;if(k){a[L]=-121;n=0;M=o+10|0;while(1){H=c[v+(n<<2)>>2]|0;a[M+2|0]=H;a[M+1|0]=H>>>8;a[M]=H>>>16;H=n+1|0;if(H>>>0<256>>>0){n=H;M=M+3|0}else{break}}O=o+778|0}else{a[L]=0;O=o+10|0}c:do{if((c[m>>2]&2|0)==0){P=-1;Q=41}else{if((c[w+12>>2]|0)==0|k){P=-1;Q=41;break}TGb(j|0,0,1024)|0;if((y|0)>0&(z|0)>0){o=u+((ba(A,t)|0)+B)|0;L=0;while(1){M=0;do{n=j+(d[o+M|0]<<2)|0;c[n>>2]=(c[n>>2]|0)+1;M=M+1|0;}while((M|0)<(z|0));M=L+1|0;if((M|0)<(y|0)){o=o+t|0;L=M}else{R=0;break}}}else{R=0}while(1){if(!(R>>>0<256>>>0)){S=-1;break}if((c[j+(R<<2)>>2]|0)==0){Q=37;break}else{R=R+1|0}}do{if((Q|0)==37){if((R|0)<0){S=R;break}L=GZ(e,0,1024)|0;if((L|0)==0){T=O;break c}UGb(L|0,w+20|0,1024)|0;a[L+(R<<2|3)|0]=0;P=R;Q=41;break c}}while(0);yDb(b,48,2110872,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;P=S;Q=41}}while(0);d:do{if((Q|0)==41){a[O]=8;S=O+1|0;N=w+4|0;b=w+8|0;XKa(c[N>>2]|0,c[b>>2]|0,ba(z<<1,y)|0,12,0,930);R=u+((ba(A,t)|0)+B)|0;e:do{if((P|0)>-1){j=c[w+12>>2]|0;k=c[j+32>>2]|0;if((y|0)<=0){U=0;break}m=w+1044|0;L=P&255;if((z|0)<=0){o=R;G=0;F=0;while(1){UGb(c[m>>2]|0,o|0,z)|0;M=(YKa(c[N>>2]|0,c[m>>2]|0,z)|0)+F|0;n=G+1|0;if((n|0)<(y|0)){o=o+t|0;G=n;F=M}else{U=M;break e}}}F=ba(k,A)|0;G=R;o=0;M=0;n=(c[j>>2]|0)+(F+B)|0;while(1){UGb(c[m>>2]|0,G|0,z)|0;F=0;do{if((a[n+F|0]|0)==(a[G+F|0]|0)){a[(c[m>>2]|0)+F|0]=L}F=F+1|0;}while((F|0)<(z|0));F=(YKa(c[N>>2]|0,c[m>>2]|0,z)|0)+M|0;v=o+1|0;if((v|0)<(y|0)){G=G+t|0;o=v;M=F;n=n+k|0}else{U=F;break}}}else{if((y|0)>0){V=R;W=0;X=0}else{U=0;break}while(1){k=(YKa(c[N>>2]|0,V,z)|0)+X|0;n=W+1|0;if((n|0)<(y|0)){V=V+t|0;W=n;X=k}else{U=k;break}}}}while(0);R=(ZKa(c[N>>2]|0,142)|0)+U|0;if((R|0)>0){k=s;n=c[b>>2]|0;M=R;R=S;while(1){o=(M|0)<255?M:255;a[R]=o;G=R+1|0;if((k-G|0)<(o|0)){T=G;break d}UGb(G|0,n|0,o)|0;G=R+(o+1)|0;m=M-o|0;if((m|0)>0){n=n+o|0;M=m;R=G}else{Y=G;break}}}else{Y=S}a[Y]=0;T=Y+1|0}}while(0);Y=l+12|0;l=c[Y>>2]|0;do{if((l|0)==0){s=ICb()|0;c[Y>>2]=s;if((s|0)==0){q=-12}else{Z=s;break}i=h;return q|0}else{Z=l}}while(0);KCb(Z);Z=MCb(c[Y>>2]|0,f)|0;if((Z|0)<0){q=Z;i=h;return q|0}c[r>>2]=T-(c[p>>2]|0);p=e+36|0;c[p>>2]=c[p>>2]|1;c[g>>2]=1;q=0;i=h;return q|0}function cca(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(a+804|0);$Db(b+4|0);$Db(b+8|0);JCb(b+12|0);$Db(b+1044|0);return 0}function dca(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b|0;g=b+4|0;h=c[g>>2]|0;i=e<<32-h|c[f>>2];if((h|0)>(d|0)){j=h;k=i;l=j-d|0;c[f>>2]=k;c[g>>2]=l;return}m=b+12|0;b=c[m>>2]|0;x=i;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;j=h+32|0;k=(h|0)==32?0:e>>>(h>>>0);l=j-d|0;c[f>>2]=k;c[g>>2]=l;return}function eca(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+4|0;e=b|0;if((c[d>>2]|0)>=32){c[d>>2]=32;c[e>>2]=0;return}f=b+12|0;b=c[e>>2]&255;while(1){g=c[f>>2]|0;c[f>>2]=g+1;a[g]=b;g=(c[e>>2]|0)>>>8;c[e>>2]=g;h=(c[d>>2]|0)+8|0;c[d>>2]=h;if((h|0)<32){b=g&255}else{break}}c[d>>2]=32;c[e>>2]=0;return}function fca(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b+2148>>2]=a;c[a+140>>2]=30;a=ICb()|0;c[b+4>>2]=a;if((a|0)==0){d=-12;return d|0}TKa(b+96|0);d=0;return d|0}function gca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;h=i;i=i+8|0;j=h|0;k=c[b+60>>2]|0;l=k;m=g+24|0;n=c[m>>2]|0;o=g+28|0;p=c[o>>2]|0;if(!((p|0)>-1)){yDb(0,0,1895664,(q=i,i=i+24|0,c[q>>2]=2352936,c[q+8>>2]=2332824,c[q+16>>2]=135,q)|0);i=q;Cd();return 0}r=k+84|0;c[r>>2]=n;s=k+92|0;c[s>>2]=n;t=k+88|0;c[t>>2]=n+p;p=g+8|0;n=c[p+4>>2]|0;u=k+4|0;v=c[u>>2]|0;w=v+136|0;c[w>>2]=c[p>>2];c[w+4>>2]=n;n=c[p+4>>2]|0;w=v+144|0;c[w>>2]=c[p>>2];c[w+4>>2]=n;n=g+16|0;w=c[n+4>>2]|0;p=v+152|0;c[p>>2]=c[n>>2];c[p+4>>2]=w;w=c[g+48>>2]|0;rCb(v,w,(w|0)<0|0?-1:0);do{if((c[o>>2]|0)>5){w=c[m>>2]|0;if((PGb(w,986968,6)|0)==0){c[k+2152>>2]=1;x=k+2152|0;y=k+2156|0}else{v=(PGb(w,986952,6)|0)==0;c[k+2152>>2]=v&1;w=k+2152|0;g=k+2156|0;if(v){x=w;y=g}else{z=w;A=g;B=25;break}}c[y>>2]=0;c[k+48>>2]=0;g=j|0;w=c[r>>2]|0;v=c[t>>2]|0;if((v-w|0)>>>0<13>>>0){C=-1094995529;i=h;return C|0}a[g]=a[w]|0;a[g+1|0]=a[w+1|0]|0;a[g+2|0]=a[w+2|0]|0;a[g+3|0]=a[w+3|0]|0;a[g+4|0]=a[w+4|0]|0;a[g+5|0]=a[w+5|0]|0;p=w+6|0;c[r>>2]=p;do{if((PGb(g,986968,6)|0)!=0){if((PGb(g,986952,6)|0)==0){break}else{C=-1094995529}i=h;return C|0}}while(0);c[k+32>>2]=-1;g=w+8|0;c[r>>2]=g;n=p;D=k+8|0;c[D>>2]=(d[n]|d[n+1|0]<<8)<<16>>16&65535;n=w+10|0;c[r>>2]=n;E=g;g=k+12|0;c[g>>2]=(d[E]|d[E+1|0]<<8)<<16>>16&65535;E=w+11|0;c[r>>2]=E;F=d[n]|0;c[k+36>>2]=(F>>>4&7)+1;n=F&128;G=k+16|0;c[G>>2]=n;H=k+20|0;c[H>>2]=(F&7)+1;F=w+12|0;c[r>>2]=F;I=d[E]|0;E=w+13|0;c[r>>2]=E;J=a[F]|0;if(J<<24>>24==0){K=n}else{n=c[k+2148>>2]|0;c[n+224>>2]=(J&255)+15;c[n+228>>2]=64;K=c[G>>2]|0}G=k+28|0;if((K|0)==0){c[G>>2]=-1}else{c[G>>2]=I;n=c[H>>2]|0;if((v-E|0)>>>0<3<<n>>>0){C=-1094995529;i=h;return C|0}H=1<<n;if((H|0)>0){n=k+100|0;J=0;F=E;while(1){E=F+3|0;c[r>>2]=E;c[n>>2]=(d[F]|0)<<16|(d[F+1|0]|0)<<8|(d[F+2|0]|0)|-16777216;L=J+1|0;if((L|0)<(H|0)){n=n+4|0;J=L;F=E}else{break}}M=c[G>>2]|0}else{M=I}c[k+24>>2]=c[l+100+(M<<2)>>2]}F=V$a(b,c[D>>2]|0,c[g>>2]|0)|0;if((F|0)<0){C=F;i=h;return C|0}KCb(c[u>>2]|0);F=_$a(b,c[u>>2]|0,0)|0;if((F|0)<0){C=F;i=h;return C|0}F=k+40|0;kEb(F,k+44|0,c[D>>2]|0);if((c[F>>2]|0)==0){C=-12;i=h;return C|0}else{F=c[u>>2]|0;c[F+88>>2]=1;c[F+84>>2]=1;c[y>>2]=1;N=F;O=x;break}}else{c[k+2152>>2]=0;z=k+2152|0;A=k+2156|0;B=25}}while(0);do{if((B|0)==25){if((c[A>>2]|0)==0){yDb(b,16,2188096,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}x=$$a(b,c[u>>2]|0)|0;if((x|0)<0){C=x;i=h;return C|0}else{x=c[u>>2]|0;c[x+88>>2]=2;c[x+84>>2]=0;N=x;O=z;break}}}while(0);z=c[r>>2]|0;b=c[t>>2]|0;if((b|0)==(z|0)){C=-541478725;i=h;return C|0}A=k+2148|0;x=k+32|0;y=k+52|0;M=b;b=z;a:while(1){if((M-b|0)<1){B=32;break}c[r>>2]=b+1;z=d[b]|0;yDb(c[A>>2]|0,48,2110856,(q=i,i=i+16|0,c[q>>2]=z,c[q+8>>2]=z,q)|0);i=q;if((z|0)==44){B=34;break}else if((z|0)==59){C=-541478725;B=113;break}else if((z|0)!=33){B=112;break}z=c[r>>2]|0;l=c[t>>2]|0;K=l;if((K-z|0)>>>0<2>>>0){C=-1094995529;B=113;break}j=z+1|0;c[r>>2]=j;m=a[z]|0;o=z+2|0;c[r>>2]=o;F=a[j]|0;if(m<<24>>24==-7&F<<24>>24==4){if((K-o|0)>>>0<5>>>0){C=-1094995529;B=113;break}c[r>>2]=z+3;m=d[o]|0;j=z+6|0;c[r>>2]=j;if((m&1|0)==0){P=-1}else{P=d[z+5|0]|0}c[x>>2]=P;J=m>>>2&7;c[y>>2]=J>>>0>3>>>0?0:J;J=z+7|0;c[r>>2]=J;Q=a[j]|0;R=J}else{Q=F;R=o}if(Q<<24>>24==0){S=R}else{o=Q;F=R;while(1){J=o&255;j=J+1|0;if((K-F|0)>>>0<j>>>0){C=-1094995529;B=113;break a}z=F+j|0;c[r>>2]=z;j=a[F+J|0]|0;if(j<<24>>24==0){S=z;break}else{o=j;F=z}}}if((l|0)==(S|0)){C=-541478725;B=113;break}else{M=l;b=S}}if((B|0)==32){yDb(c[A>>2]|0,48,2110856,(q=i,i=i+16|0,c[q>>2]=0,c[q+8>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}else if((B|0)==34){S=c[r>>2]|0;b=c[t>>2]|0;if((b-S|0)>>>0<9>>>0){C=-1094995529;i=h;return C|0}M=S+2|0;c[r>>2]=M;R=S;Q=(d[R]|d[R+1|0]<<8)<<16>>16&65535;R=S+4|0;c[r>>2]=R;P=M;M=(d[P]|d[P+1|0]<<8)<<16>>16&65535;P=S+6|0;c[r>>2]=P;F=R;R=(d[F]|d[F+1|0]<<8)<<16>>16;F=R&65535;o=S+8|0;c[r>>2]=o;K=P;P=(d[K]|d[K+1|0]<<8)<<16>>16;K=P&65535;D=S+9|0;c[r>>2]=D;S=d[o]|0;o=S&64;do{if((S&128|0)==0){if((c[k+16>>2]|0)!=0){T=k+100|0;break}yDb(c[A>>2]|0,16,2052480,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}else{g=(S&7)+1|0;if((b-D|0)>>>0<3<<g>>>0){C=-1094995529;i=h;return C|0}I=1<<g;g=k+1124|0;if((I|0)>0){U=g;V=0;W=D}else{T=g;break}while(1){G=W+3|0;c[r>>2]=G;c[U>>2]=(d[W]|0)<<16|(d[W+1|0]|0)<<8|(d[W+2|0]|0)|-16777216;z=V+1|0;if((z|0)<(I|0)){U=U+4|0;V=z;W=G}else{T=g;break}}}}while(0);b:do{if((c[O>>2]|0)!=0){do{if((c[x>>2]|0)==-1){if((c[k+16>>2]|0)==0){break}W=c[k+24>>2]|0;V=c[N>>2]|0;U=V+((ba((c[N+32>>2]|0)>>>2,c[N+72>>2]|0)|0)<<2)|0;if(V>>>0<U>>>0){X=V}else{break b}while(1){c[X>>2]=W;X=X+4|0;if(!(X>>>0<U>>>0)){break b}}}}while(0);U=c[k+2160>>2]|0;W=c[N>>2]|0;V=W+((ba((c[N+32>>2]|0)>>>2,c[N+72>>2]|0)|0)<<2)|0;if(W>>>0<V>>>0){Y=W}else{break}do{c[Y>>2]=U;Y=Y+4|0;}while(Y>>>0<V>>>0)}}while(0);do{if((F+Q|0)<=(c[k+8>>2]|0)){Y=K+M|0;if((Y|0)>(c[k+12>>2]|0)){break}if(R<<16>>16==0|P<<16>>16==0){yDb(c[A>>2]|0,16,1969032,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}X=k+48|0;O=c[X>>2]|0;c:do{if((O|0)==3){V=c[k+72>>2]|0;U=(c[N+32>>2]|0)>>>2;W=c[k+56>>2]|0;D=c[k+60>>2]|0;b=ba(D,U)|0;S=ba((c[k+68>>2]|0)+D|0,U)|0;D=V+(S<<2)|0;if((b|0)>=(S|0)){break}S=c[k+64>>2]<<2;g=(c[N>>2]|0)+(b<<2)|0;I=V+(b<<2)|0;while(1){UGb(g+(W<<2)|0,I+(W<<2)|0,S)|0;b=I+(U<<2)|0;if(b>>>0<D>>>0){g=g+(U<<2)|0;I=b}else{break}}}else if((O|0)==2){I=c[k+80>>2]|0;U=c[k+56>>2]|0;g=c[k+60>>2]|0;D=(c[N+32>>2]|0)>>>2;S=c[N>>2]|0;W=ba(D,g)|0;b=ba(D,(c[k+68>>2]|0)+g|0)|0;g=S+(b<<2)|0;if((W|0)>=(b|0)){break}b=S+(W<<2)|0;W=(c[k+64>>2]|0)+U|0;if((W|0)>(U|0)){Z=b}else{S=b;while(1){S=S+(D<<2)|0;if(!(S>>>0<g>>>0)){break c}}}do{S=Z+(W<<2)|0;b=Z+(U<<2)|0;do{c[b>>2]=I;b=b+4|0;}while(b>>>0<S>>>0);Z=Z+(D<<2)|0;}while(Z>>>0<g>>>0)}}while(0);O=c[y>>2]|0;c[X>>2]=O;do{if((O|0)!=0){c[k+56>>2]=Q;c[k+60>>2]=M;c[k+64>>2]=F;c[k+68>>2]=K;if((O|0)==2){if((c[x>>2]|0)>-1){c[k+80>>2]=c[k+2160>>2];break}else{c[k+80>>2]=c[k+24>>2];break}}else if((O|0)!=3){break}g=k+72|0;D=N+32|0;kEb(g,k+76|0,ba(c[N+72>>2]|0,c[D>>2]|0)|0);I=c[g>>2]|0;if((I|0)==0){C=-12;i=h;return C|0}g=c[N>>2]|0;U=(c[D>>2]|0)>>>2;D=ba(U,M)|0;W=ba(U,Y)|0;S=g+(W<<2)|0;if((D|0)>=(W|0)){break}W=F<<2;b=I+(D<<2)|0;I=g+(D<<2)|0;while(1){UGb(b+(Q<<2)|0,I+(Q<<2)|0,W)|0;D=I+(U<<2)|0;if(D>>>0<S>>>0){b=b+(U<<2)|0;I=D}else{break}}}}while(0);Y=c[r>>2]|0;O=c[t>>2]|0;if((O-Y|0)>>>0<2>>>0){C=-1094995529;i=h;return C|0}X=Y+1|0;c[r>>2]=X;I=k+96|0;U=VKa(c[I>>2]|0,d[Y]|0,X,O-X|0,0)|0;if((U|0)<0){yDb(c[A>>2]|0,16,1940456,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=U;i=h;return C|0}U=(c[N+32>>2]|0)>>>2;X=c[N>>2]|0;O=(ba(U,M)|0)+Q|0;Y=X+(O<<2)|0;b=k+40|0;S=U<<3;W=U<<1;D=U<<2;g=X+(O+U<<2)|0;d:do{if((o|0)==0){V=WKa(c[I>>2]|0,c[b>>2]|0,F)|0;if((V|0)==(F|0)){_=1;$=Y}else{aa=V;B=87;break}while(1){V=$+(F<<2)|0;l=c[b>>2]|0;G=$;z=l;while(1){j=d[z]|0;if((j|0)!=(c[x>>2]|0)){c[G>>2]=c[T+(j<<2)>>2]}j=G+4|0;if(!(j>>>0<V>>>0)){break}G=j;z=z+1|0}if((_|0)>=(K|0)){break d}z=WKa(c[I>>2]|0,l,F)|0;if((z|0)==(F|0)){_=_+1|0;$=$+(U<<2)|0}else{aa=z;B=87;break}}}else{z=Y;G=0;V=0;j=1;J=c[b>>2]|0;while(1){m=WKa(c[I>>2]|0,J,F)|0;if((m|0)!=(F|0)){aa=m;B=87;break d}m=z+(F<<2)|0;n=c[b>>2]|0;H=z;v=n;while(1){w=d[v]|0;if((w|0)!=(c[x>>2]|0)){c[H>>2]=c[T+(w<<2)>>2]}w=H+4|0;if(!(w>>>0<m>>>0)){break}H=w;v=v+1|0}do{if((V|0)==3){ca=3;da=G+2|0;ea=z+(W<<2)|0}else if((V|0)==2){v=G+4|0;H=(v|0)<(K|0);ca=H?2:3;da=H?v:1;ea=H?z+(D<<2)|0:g}else{H=G+8|0;if((H|0)<(K|0)){ca=V;da=H;ea=z+(S<<2)|0;break}H=(V|0)!=0?2:4;ca=V+1|0;da=H;ea=X+((ba(H,U)|0)+O<<2)|0}}while(0);if((j|0)<(K|0)){z=ea;G=da;V=ca;j=j+1|0;J=n}else{break}}}}while(0);do{if((B|0)==87){if((aa|0)==0){break}yDb(c[A>>2]|0,16,1916248,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}}while(0);SKa(c[I>>2]|0);c[x>>2]=-1;c[y>>2]=0;O=MCb(e,c[u>>2]|0)|0;if((O|0)<0){C=O;i=h;return C|0}c[f>>2]=1;C=(c[r>>2]|0)-(c[s>>2]|0)|0;i=h;return C|0}}while(0);yDb(c[A>>2]|0,16,2006936,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}else if((B|0)==112){C=-1094995529;i=h;return C|0}else if((B|0)==113){i=h;return C|0}return 0}function hca(a){a=a|0;var b=0;b=c[a+60>>2]|0;UKa(b+96|0);JCb(b+4|0);$Db(b+40|0);$Db(b+72|0);return 0}function ica(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;c[a+416>>2]=1;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;d=a+412|0;if((c[d>>2]|0)==0){c[d>>2]=8e3}c[a+420>>2]=1;d=c[a+48>>2]|0;if((d|0)==86046){c[a+424>>2]=320;e=a+432|0;f=c[e>>2]|0;if((f|0)==0){c[e>>2]=65;g=0;i=b;return g|0}e=f-41|0;if(e>>>0<25>>>0&((e|0)%3|0|0)==0){g=0;i=b;return g|0}yDb(a,16,1969e3,(e=i,i=i+8|0,c[e>>2]=f,e)|0);i=e;g=-1094995529;i=b;return g|0}else if((d|0)==86034){c[a+424>>2]=160;c[a+432>>2]=33;g=0;i=b;return g|0}else{g=0;i=b;return g|0}return 0}function jca(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=a+432|0;if((l|0)<(c[h>>2]|0)){yDb(a,16,2052416,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=j;return n|0}c[f+76>>2]=c[a+424>>2];o=_$a(a,f,0)|0;if((o|0)<0){n=o;i=j;return n|0}o=c[f>>2]|0;f=c[a+48>>2]|0;do{if((f|0)==86046){p=PPa(a,o,k,(65-(c[h>>2]|0)|0)/3|0)|0;if((p|0)<0){n=p}else{break}i=j;return n|0}else if((f|0)==86034){p=l<<3;q=p>>>0>2147483639>>>0|(k|0)==0;r=q?0:k;s=q?8:p+8|0;p=r;q=s>>>0>4>>>0?4:s;if(((d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24)&240|0)!=208){yDb(a,24,2006888,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}p=c[a+60>>2]|0;t=p+240|0;u=p+660|0;v=c[u>>2]|0;w=p+596|0;x=r+(q>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&4)>>>26;x=q+6|0;q=s>>>0>x>>>0?x:s;c[w+(v<<5)>>2]=(ba(y,13421568)|0)-429473792>>15<<1;y=r+(q>>>3)|0;x=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>26;y=q+6|0;q=s>>>0>y>>>0?y:s;c[w+(v<<5)+4>>2]=(ba(x,13421568)|0)-429473792>>15<<1;x=r+(q>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>27;x=q+5|0;q=s>>>0>x>>>0?x:s;c[w+(v<<5)+8>>2]=(ba(y,13421568)|0)-268414976>>15<<1;y=r+(q>>>3)|0;x=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>27;y=q+5|0;q=s>>>0>y>>>0?y:s;c[w+(v<<5)+12>>2]=(ba(x,13421568)|0)-147620864>>15<<1;x=r+(q>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>28;x=q+4|0;q=s>>>0>x>>>0?x:s;c[w+(v<<5)+16>>2]=(ba(y,19684352)|0)-161072356>>15<<1;y=r+(q>>>3)|0;x=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>28;y=q+4|0;q=s>>>0>y>>>0?y:s;c[w+(v<<5)+20>>2]=(ba(x,17895424)|0)-80513024>>15<<1;x=r+(q>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>29;x=q+3|0;q=s>>>0>x>>>0?x:s;c[w+(v<<5)+24>>2]=(ba(y,32208896)|0)-107367572>>15<<1;y=r+(q>>>3)|0;x=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>29;y=q+3|0;c[w+(v<<5)+28>>2]=(ba(x,30420992)|0)-53695680>>15<<1;x=t;v=0;w=s>>>0>y>>>0?y:s;while(1){y=r+(w>>>3)|0;q=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7);y=q>>>25;z=w+7|0;A=s>>>0>z>>>0?z:s;z=r+(A>>>3)|0;B=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(A&7)>>>30;z=A+2|0;A=s>>>0>z>>>0?z:s;z=r+(A>>>3)|0;C=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(A&7)>>>30;z=A+2|0;A=s>>>0>z>>>0?z:s;if(q>>>0<1342177280>>>0){D=40}else{D=y>>>0>120>>>0?120:y}y=e[1212384+(B<<1)>>1]|0;B=0;do{b[x+(B<<1)>>1]=((ba(b[x+(B-D<<1)>>1]|0,y)|0)+16384|0)>>>15;B=B+1|0;}while((B|0)<40);B=c[1213600+(v<<2)>>2]|0;y=r+(A>>>3)|0;q=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(A&7)>>>26;y=A+6|0;z=0;E=s>>>0>y>>>0?y:s;do{y=c[B+(z<<2)>>2]|0;F=r+(E>>>3)|0;G=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>((32-y|0)>>>0);F=y+E|0;E=s>>>0>F>>>0?F:s;F=x+((z*3|0)+C<<1)|0;b[F>>1]=(b[F>>1]|0)+(b[1212392+(q<<4)+(c[548272+(y<<5)+(G<<2)>>2]<<1)>>1]|0);z=z+1|0;}while((z|0)<13);z=v+1|0;if((z|0)<4){x=x+80|0;v=z;w=E}else{break}}w=p;UGb(p|0,p+320|0,240)|0;v=c[u>>2]|0;x=v^1;s=w+596+(x<<5)|0;r=c[s>>2]|0;z=w+596+(v<<5)|0;q=lca((r>>2)+(r>>1)+(c[z>>2]>>2)|0)|0;r=w+596+(x<<5)+4|0;C=c[r>>2]|0;B=w+596+(v<<5)+4|0;A=lca((C>>2)+(C>>1)+(c[B>>2]>>2)|0)|0;C=w+596+(x<<5)+8|0;G=c[C>>2]|0;y=w+596+(v<<5)+8|0;F=lca((G>>2)+(G>>1)+(c[y>>2]>>2)|0)|0;G=w+596+(x<<5)+12|0;H=c[G>>2]|0;I=w+596+(v<<5)+12|0;J=lca((H>>2)+(H>>1)+(c[I>>2]>>2)|0)|0;H=w+596+(x<<5)+16|0;K=c[H>>2]|0;L=w+596+(v<<5)+16|0;M=lca((K>>2)+(K>>1)+(c[L>>2]>>2)|0)|0;K=w+596+(x<<5)+20|0;N=c[K>>2]|0;O=w+596+(v<<5)+20|0;P=lca((N>>2)+(N>>1)+(c[O>>2]>>2)|0)|0;N=w+596+(x<<5)+24|0;Q=c[N>>2]|0;R=w+596+(v<<5)+24|0;S=lca((Q>>2)+(Q>>1)+(c[R>>2]>>2)|0)|0;Q=w+596+(x<<5)+28|0;T=c[Q>>2]|0;U=w+596+(v<<5)+28|0;v=lca((T>>2)+(T>>1)+(c[U>>2]>>2)|0)|0;T=p+560|0;w=p+588|0;V=p+584|0;W=p+580|0;X=p+576|0;Y=p+572|0;Z=p+568|0;_=p+564|0;$=0;aa=c[w>>2]|0;ca=c[V>>2]|0;da=c[W>>2]|0;ea=c[X>>2]|0;fa=c[Y>>2]|0;ga=c[Z>>2]|0;ha=c[_>>2]|0;ia=c[T>>2]|0;while(1){ja=(b[t+($<<1)>>1]|0)-((ba(aa,v)|0)+16384>>15)|0;ka=ja-((ba(ca,S)|0)+16384>>15)|0;la=((ba(ka,S)|0)+16384>>15)+ca|0;ma=ka-((ba(da,P)|0)+16384>>15)|0;na=((ba(ma,P)|0)+16384>>15)+da|0;ka=ma-((ba(ea,M)|0)+16384>>15)|0;oa=((ba(ka,M)|0)+16384>>15)+ea|0;ma=ka-((ba(fa,J)|0)+16384>>15)|0;pa=((ba(ma,J)|0)+16384>>15)+fa|0;ka=ma-((ba(ga,F)|0)+16384>>15)|0;qa=((ba(ka,F)|0)+16384>>15)+ga|0;ma=ka-((ba(ha,A)|0)+16384>>15)|0;ra=((ba(ma,A)|0)+16384>>15)+ha|0;sa=ma-((ba(ia,q)|0)+16384>>15)|0;ta=((ba(sa,q)|0)+16384>>15)+ia|0;b[o+($<<1)>>1]=sa;ma=$+1|0;if((ma|0)<13){$=ma;aa=la;ca=na;da=oa;ea=pa;fa=qa;ga=ra;ha=ta;ia=sa}else{break}}ia=p+592|0;ha=((ba(ja,v)|0)+16384>>15)+aa|0;c[w>>2]=la;c[ia>>2]=ha;c[V>>2]=na;c[W>>2]=oa;c[X>>2]=pa;c[Y>>2]=qa;c[Z>>2]=ra;c[_>>2]=ta;c[T>>2]=sa;ha=lca((c[z>>2]>>1)+(c[s>>2]>>1)|0)|0;ga=lca((c[B>>2]>>1)+(c[r>>2]>>1)|0)|0;fa=lca((c[y>>2]>>1)+(c[C>>2]>>1)|0)|0;ea=lca((c[I>>2]>>1)+(c[G>>2]>>1)|0)|0;da=lca((c[L>>2]>>1)+(c[H>>2]>>1)|0)|0;ca=lca((c[O>>2]>>1)+(c[K>>2]>>1)|0)|0;$=lca((c[R>>2]>>1)+(c[N>>2]>>1)|0)|0;q=lca((c[U>>2]>>1)+(c[Q>>2]>>1)|0)|0;A=13;F=la;J=na;M=oa;P=pa;S=qa;ma=ra;ka=ta;ua=sa;while(1){va=(b[t+(A<<1)>>1]|0)-((ba(F,q)|0)+16384>>15)|0;wa=va-((ba(J,$)|0)+16384>>15)|0;xa=((ba(wa,$)|0)+16384>>15)+J|0;ya=wa-((ba(M,ca)|0)+16384>>15)|0;za=((ba(ya,ca)|0)+16384>>15)+M|0;wa=ya-((ba(P,da)|0)+16384>>15)|0;Aa=((ba(wa,da)|0)+16384>>15)+P|0;ya=wa-((ba(S,ea)|0)+16384>>15)|0;Ba=((ba(ya,ea)|0)+16384>>15)+S|0;wa=ya-((ba(ma,fa)|0)+16384>>15)|0;Ca=((ba(wa,fa)|0)+16384>>15)+ma|0;ya=wa-((ba(ka,ga)|0)+16384>>15)|0;Da=((ba(ya,ga)|0)+16384>>15)+ka|0;Ea=ya-((ba(ua,ha)|0)+16384>>15)|0;Fa=((ba(Ea,ha)|0)+16384>>15)+ua|0;b[o+(A<<1)>>1]=Ea;ya=A+1|0;if((ya|0)<27){A=ya;F=xa;J=za;M=Aa;P=Ba;S=Ca;ma=Da;ka=Fa;ua=Ea}else{break}}ua=((ba(va,q)|0)+16384>>15)+F|0;c[w>>2]=xa;c[ia>>2]=ua;c[V>>2]=za;c[W>>2]=Aa;c[X>>2]=Ba;c[Y>>2]=Ca;c[Z>>2]=Da;c[_>>2]=Fa;c[T>>2]=Ea;ua=c[z>>2]|0;ka=lca((ua>>1)+(c[s>>2]>>2)+(ua>>2)|0)|0;ua=c[B>>2]|0;ma=lca((ua>>1)+(c[r>>2]>>2)+(ua>>2)|0)|0;ua=c[y>>2]|0;S=lca((ua>>1)+(c[C>>2]>>2)+(ua>>2)|0)|0;ua=c[I>>2]|0;P=lca((ua>>1)+(c[G>>2]>>2)+(ua>>2)|0)|0;ua=c[L>>2]|0;M=lca((ua>>1)+(c[H>>2]>>2)+(ua>>2)|0)|0;ua=c[O>>2]|0;J=lca((ua>>1)+(c[K>>2]>>2)+(ua>>2)|0)|0;ua=c[R>>2]|0;A=lca((ua>>1)+(c[N>>2]>>2)+(ua>>2)|0)|0;ua=c[U>>2]|0;ha=lca((ua>>1)+(c[Q>>2]>>2)+(ua>>2)|0)|0;ua=27;ga=xa;fa=za;ea=Aa;da=Ba;ca=Ca;$=Da;aa=Fa;v=Ea;while(1){Ga=(b[t+(ua<<1)>>1]|0)-((ba(ga,ha)|0)+16384>>15)|0;ya=Ga-((ba(fa,A)|0)+16384>>15)|0;Ha=((ba(ya,A)|0)+16384>>15)+fa|0;wa=ya-((ba(ea,J)|0)+16384>>15)|0;Ia=((ba(wa,J)|0)+16384>>15)+ea|0;ya=wa-((ba(da,M)|0)+16384>>15)|0;Ja=((ba(ya,M)|0)+16384>>15)+da|0;wa=ya-((ba(ca,P)|0)+16384>>15)|0;Ka=((ba(wa,P)|0)+16384>>15)+ca|0;ya=wa-((ba($,S)|0)+16384>>15)|0;La=((ba(ya,S)|0)+16384>>15)+$|0;wa=ya-((ba(aa,ma)|0)+16384>>15)|0;Ma=((ba(wa,ma)|0)+16384>>15)+aa|0;Na=wa-((ba(v,ka)|0)+16384>>15)|0;Oa=((ba(Na,ka)|0)+16384>>15)+v|0;b[o+(ua<<1)>>1]=Na;wa=ua+1|0;if((wa|0)<40){ua=wa;ga=Ha;fa=Ia;ea=Ja;da=Ka;ca=La;$=Ma;aa=Oa;v=Na}else{break}}v=((ba(Ga,ha)|0)+16384>>15)+ga|0;c[w>>2]=Ha;c[ia>>2]=v;c[V>>2]=Ia;c[W>>2]=Ja;c[X>>2]=Ka;c[Y>>2]=La;c[Z>>2]=Ma;c[_>>2]=Oa;c[T>>2]=Na;v=lca(c[z>>2]|0)|0;aa=lca(c[B>>2]|0)|0;$=lca(c[y>>2]|0)|0;ca=lca(c[I>>2]|0)|0;da=lca(c[L>>2]|0)|0;ea=lca(c[O>>2]|0)|0;fa=lca(c[R>>2]|0)|0;ua=lca(c[U>>2]|0)|0;ka=40;ma=Ha;S=Ia;P=Ja;M=Ka;J=La;A=Ma;Q=Oa;N=Na;while(1){Pa=(b[t+(ka<<1)>>1]|0)-((ba(ma,ua)|0)+16384>>15)|0;K=Pa-((ba(S,fa)|0)+16384>>15)|0;Qa=((ba(K,fa)|0)+16384>>15)+S|0;H=K-((ba(P,ea)|0)+16384>>15)|0;Ra=((ba(H,ea)|0)+16384>>15)+P|0;K=H-((ba(M,da)|0)+16384>>15)|0;Sa=((ba(K,da)|0)+16384>>15)+M|0;H=K-((ba(J,ca)|0)+16384>>15)|0;Ta=((ba(H,ca)|0)+16384>>15)+J|0;K=H-((ba(A,$)|0)+16384>>15)|0;Ua=((ba(K,$)|0)+16384>>15)+A|0;H=K-((ba(Q,aa)|0)+16384>>15)|0;Va=((ba(H,aa)|0)+16384>>15)+Q|0;Wa=H-((ba(N,v)|0)+16384>>15)|0;Xa=((ba(Wa,v)|0)+16384>>15)+N|0;b[o+(ka<<1)>>1]=Wa;H=ka+1|0;if((H|0)<160){ka=H;ma=Qa;S=Ra;P=Sa;M=Ta;J=Ua;A=Va;Q=Xa;N=Wa}else{break}}N=((ba(Pa,ua)|0)+16384>>15)+ma|0;c[w>>2]=Qa;c[ia>>2]=N;c[V>>2]=Ra;c[W>>2]=Sa;c[X>>2]=Ta;c[Y>>2]=Ua;c[Z>>2]=Va;c[_>>2]=Xa;c[T>>2]=Wa;c[u>>2]=x;N=p+664|0;Q=c[N>>2]|0;A=0;do{J=o+(A<<1)|0;M=((Q*28180|0)+16384>>15)+(b[J>>1]|0)|0;if((M+32768|0)>>>0>65535>>>0){Ya=(M>>31^32767)&65535}else{Ya=M&65535}Q=Ya<<16>>16;M=Q<<1;if((M+32768|0)>>>0>65535>>>0){Za=(Q>>30^32767)&65535}else{Za=M&65535}b[J>>1]=Za&-8;A=A+1|0;}while((A|0)<160);c[N>>2]=Q}}while(0);c[g>>2]=1;n=c[h>>2]|0;i=j;return n|0}function kca(a){a=a|0;TGb(c[a+60>>2]|0,0,668)|0;return}function lca(a){a=a|0;var b=0,c=0;b=(a|0)>-1?a:-a|0;do{if((b|0)<11059){c=b<<1}else{if((b|0)<20070){c=b+11059|0;break}else{c=(b>>2)+26112|0;break}}}while(0);return((a|0)<0?-c|0:c)|0}function mca(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[b+60>>2]|0;IOa(d);c[d+4>>2]=b;c[d+8>>2]=c[b+128>>2];c[d+12>>2]=c[b+132>>2];e=(c[b+12>>2]|0)+12|0;f=d+48|0;c[f>>2]=c[e>>2];c[d+28>>2]=1;c[d+13944>>2]=1;c[b+140>>2]=0;c[f>>2]=c[e>>2];glb();if(a[985752]|0){g=d+14696|0;h=g;c[h>>2]=0;return 0}a[985752]=1;c[1283107]=5137600;c[1283109]=662;N_(5132424,9,35,1211648,1,1,1211608,1,1,0,0,0,4)|0;c[1283101]=5137280;c[1283103]=80;N_(5132400,6,10,1211592,1,1,1211576,1,1,0,0,0,4)|0;c[1283095]=5136704;c[1283097]=144;N_(5132376,7,17,1211409,2,1,1211408,2,1,0,0,0,4)|0;c[1302727]=5134656;c[1302729]=512;N_(5210904,9,63,1211985,2,1,1211984,2,1,0,0,0,4)|0;c[302816]=5132448;c[302818]=552;e=c[302806]|0;N_(1211260,9,(c[302804]|0)+1|0,e+2|0,4,2,e,4,2,0,0,0,4)|0;if((c[302820]|0)==0){i=0}else{g=d+14696|0;h=g;c[h>>2]=0;return 0}do{c[1211280+(i<<2)>>2]=5140248+(i*2208|0);i=i+1|0;}while((i|0)<32);POa(1211216);g=d+14696|0;h=g;c[h>>2]=0;return 0}function nca(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;j=i;i=i+64|0;k=j|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;h=c[e+60>>2]|0;n=h;o=h;p=f;c[h+60>>2]=c[e+88>>2];c[h+64>>2]=c[e+92>>2];f=h+14696|0;c[f>>2]=0;q=h+14120|0;r=m<<3;s=r>>>0>2147483639>>>0|(l|0)==0;t=s?0:l;l=s?0:r;r=q;s=h+14132|0;u=l+8|0;v=h+14136|0;w=t+(l>>3)|0;x=h+14124|0;y=h+14128|0;z=h+96|0;A=h+108|0;B=h+4|0;C=h+8|0;D=h+12|0;E=h+116|0;F=h+120|0;G=h+144|0;H=h+9992|0;I=h+14692|0;J=e+128|0;K=e+132|0;L=h+13744|0;M=j+24|0;N=L;a:while(1){c[r>>2]=t;c[s>>2]=l;c[v>>2]=u;c[x>>2]=w;c[y>>2]=0;if((c[z>>2]|0)==0){if((FOa(o)|0)<0){O=-1;P=109;break}Q=c[y>>2]|0;R=c[s>>2]|0}else{Q=0;R=l}S=R-Q|0;T=0;U=Q;while(1){if((S|0)<=24){P=8;break}V=c[v>>2]|0;W=c[r>>2]|0;X=W+(U>>>3)|0;Y=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(U&7)>>>31;X=U+1|0;Z=V>>>0>X>>>0?X:V;c[y>>2]=Z;X=Y|T<<1&1048574;if((X|0)==16){_=Z;$=V;aa=W;break}else{S=S-1|0;T=X;U=Z}}if((P|0)==8){P=0;if((T|0)!=16){P=10;break}_=U;$=c[v>>2]|0;aa=c[r>>2]|0}S=aa+(_>>>3)|0;Z=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(_&7)>>>27;S=_+5|0;c[y>>2]=$>>>0>S>>>0?S:$;S=c[A>>2]|0;c[A>>2]=(Z>>>0<(S&31)>>>0?Z|32:Z)+(S&-32);S=c[B>>2]|0;c[S+104>>2]=1001;c[S+108>>2]=3e4;S=c[v>>2]|0;Z=(c[y>>2]|0)+1|0;X=(S>>>0>Z>>>0?Z:S)+1|0;Z=(S>>>0>X>>>0?X:S)+1|0;X=S>>>0>Z>>>0?Z:S;c[y>>2]=X;Z=c[r>>2]|0;W=d[Z+(X>>>3)|0]|0;V=((X|0)<(S|0))+X|0;c[y>>2]=V;Y=(128>>>((X&7)>>>0)&W|0)==0;W=Y?176:352;X=Y?144:288;ca=Y?11:22;da=Y?9:18;c[C>>2]=W;c[D>>2]=X;c[E>>2]=ca;c[F>>2]=da;c[G>>2]=ba(ca,da)|0;da=V+1|0;V=(S>>>0>da>>>0?da:S)+1|0;da=S>>>0>V>>>0?V:S;c[y>>2]=da;V=c[s>>2]|0;if((V-da|0)<1){break}else{ea=da}while(1){da=d[Z+(ea>>>3)|0]|0;ca=((ea|0)<(S|0))+ea|0;c[y>>2]=ca;if((da&128>>>((ea&7)>>>0)|0)==0){break}da=ca+8|0;ea=S>>>0>da>>>0?da:S;c[y>>2]=ea;if((V-ea|0)<1){break a}}c[H>>2]=2;c[I>>2]=0;if((W|0)==(c[J>>2]|0)){if((X|0)!=(c[K>>2]|0)){P=17}}else{P=17}if((P|0)==17){P=0;c[M>>2]=c[L>>2];c[M+4>>2]=c[L+4>>2];c[M+8>>2]=c[L+8>>2];c[M+12>>2]=c[L+12>>2];c[M+16>>2]=c[L+16>>2];c[M+20>>2]=c[L+20>>2];c[M+24>>2]=c[L+24>>2];c[M+28>>2]=c[L+28>>2];c[M+32>>2]=c[L+32>>2];c[M+36>>2]=c[L+36>>2];c[N>>2]=0;LOa(o);c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];c[L+8>>2]=c[M+8>>2];c[L+12>>2]=c[M+12>>2];c[L+16>>2]=c[M+16>>2];c[L+20>>2]=c[M+20>>2];c[L+24>>2]=c[M+24>>2];c[L+28>>2]=c[M+28>>2];c[L+32>>2]=c[M+32>>2];c[L+36>>2]=c[M+36>>2]}if((c[z>>2]|0)!=0){P=20;break}V=V$a(e,c[C>>2]|0,c[D>>2]|0)|0;if((V|0)<0){O=V;P=109;break}}if((P|0)==10){yDb(c[B>>2]|0,16,2258200,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa}else if((P|0)==20){D=c[H>>2]|0;C=h+7712|0;c[C>>2]=D;z=(D|0)==1;c[h+7708>>2]=z&1;M=c[e+856>>2]|0;do{if((M|0)>7){if((D|0)!=3){if((M|0)<=31){break}if(!((M|0)>47|z^1)){break}}L=c[y>>2]>>3;N=(L|0)==0?1:L;O=(N+10|0)>(m|0)?m:N;i=j;return O|0}}while(0);if((ROa(o,e)|0)<0){O=-1;i=j;return O|0}ePa(o);e=h+12476|0;c[e>>2]=0;z=h+12480|0;c[z>>2]=0;b:do{if((c[I>>2]|0)<(((c[F>>2]|0)==18?12:5)|0)){M=k;D=h+13712|0;N=h+9960|0;L=h+14672|0;K=q;J=h+14676|0;ea=h+124|0;G=h+12496|0;E=h+12500|0;A=h+12504|0;$=h+12508|0;_=h+12512|0;aa=h+12516|0;Q=h+12544|0;R=h+12548|0;l=h+12552|0;w=h+14680|0;x=h+12488|0;u=h+14684|0;t=h+14688|0;V=h+11736|0;S=h+11740|0;Z=h+9160|0;U=h+11744|0;T=h+11748|0;da=h+180|0;ca=h+14340|0;Y=h+10096|0;c:while(1){d:do{if((c[f>>2]|0)==0){ga=c[y>>2]|0;ha=(c[r>>2]|0)+(ga>>>3)|0;if(((fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)&-131072>>>((ga&7)>>>0)|0)==0){if((rca(n)|0)>-1){break}}c[q>>2]=c[D>>2];c[q+4>>2]=c[D+4>>2];c[q+8>>2]=c[D+8>>2];c[q+12>>2]=c[D+12>>2];c[q+16>>2]=c[D+16>>2];ga=c[y>>2]|0;ha=-ga&7;if((ha|0)==0){ia=ga}else{ja=c[v>>2]|0;ka=ha+ga|0;ga=ja>>>0>ka>>>0?ka:ja;c[y>>2]=ga;ia=ga}ga=(c[s>>2]|0)-ia|0;if((ga|0)>25){la=ga;ma=ia}else{break b}while(1){ga=(c[r>>2]|0)+(ma>>>3)|0;if(((fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)&-131072>>>((ma&7)>>>0)|0)==0){c[M>>2]=c[q>>2];c[M+4>>2]=c[q+4>>2];c[M+8>>2]=c[q+8>>2];c[M+12>>2]=c[q+12>>2];c[M+16>>2]=c[q+16>>2];if((rca(n)|0)>-1){break d}c[q>>2]=c[M>>2];c[q+4>>2]=c[M+4>>2];c[q+8>>2]=c[M+8>>2];c[q+12>>2]=c[M+12>>2];c[q+16>>2]=c[M+16>>2];na=c[y>>2]|0}else{na=ma}ga=c[v>>2]|0;ja=na+8|0;ma=ga>>>0>ja>>>0?ja:ga;c[y>>2]=ma;la=la-8|0;if((la|0)<=25){break b}}}else{if(!((rca(n)|0)>-1)){break b}}}while(0);cPa(o,c[N>>2]|0);ga=c[L>>2]|0;e:do{if((ga|0)<34){ja=ga;f:while(1){ka=c[1283107]|0;ha=c[v>>2]|0;oa=c[r>>2]|0;pa=c[y>>2]|0;while(1){qa=oa+(pa>>>3)|0;ra=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(pa&7)>>>23;qa=b[ka+(ra<<2)>>1]|0;sa=b[ka+(ra<<2)+2>>1]|0;ra=sa<<16>>16;if(sa<<16>>16<0){sa=pa+9|0;ta=ha>>>0>sa>>>0?sa:ha;sa=oa+(ta>>>3)|0;ua=((fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ta&7)>>>((ra+32|0)>>>0))+qa|0;va=b[ka+(ua<<2)+2>>1]|0;wa=b[ka+(ua<<2)>>1]|0;xa=ta}else{va=ra;wa=qa;xa=pa}qa=va+xa|0;ya=ha>>>0>qa>>>0?qa:ha;c[y>>2]=ya;c[J>>2]=wa;if((wa|0)==33){pa=ya}else if((wa|0)==34){P=45;break f}else{break}}if((wa|0)<0){P=47;break}pa=wa+1|0;c[J>>2]=pa;ha=pa+ja|0;c[L>>2]=ha;if((ha|0)>33){P=101;break}ha=(c[I>>2]|0)-1|0;pa=wa+ja|0;ka=(((ha|0)%2|0)*11|0)+((pa|0)%11|0)|0;c[e>>2]=ka;oa=((pa|0)/11|0)+(((ha|0)/2|0)*3|0)|0;c[z>>2]=oa;ha=(ba(c[ea>>2]|0,oa)|0)+ka|0;$Oa(o);za=c[B>>2]|0;ka=8>>>((c[za+800>>2]|0)>>>0);c[G>>2]=(c[G>>2]|0)+2;c[E>>2]=(c[E>>2]|0)+2;c[A>>2]=(c[A>>2]|0)+2;c[$>>2]=(c[$>>2]|0)+2;c[_>>2]=(c[_>>2]|0)+1;c[aa>>2]=(c[aa>>2]|0)+1;c[Q>>2]=(c[Q>>2]|0)+(ka<<1);c[R>>2]=(c[R>>2]|0)+ka;c[l>>2]=(c[l>>2]|0)+ka;ka=c[1283101]|0;oa=c[y>>2]|0;pa=c[v>>2]|0;qa=c[r>>2]|0;ra=qa+(oa>>>3)|0;ta=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(oa&7)>>>26;ra=b[ka+(ta<<2)>>1]|0;ua=b[ka+(ta<<2)+2>>1]|0;ta=ua<<16>>16;if(ua<<16>>16<0){ua=oa+6|0;sa=pa>>>0>ua>>>0?ua:pa;ua=qa+(sa>>>3)|0;Aa=((fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(sa&7)>>>((ta+32|0)>>>0))+ra|0;Ba=b[ka+(Aa<<2)+2>>1]|0;Ca=b[ka+(Aa<<2)>>1]|0;Da=sa}else{Ba=ta;Ca=ra;Da=oa}oa=Ba+Da|0;ra=pa>>>0>oa>>>0?oa:pa;c[y>>2]=ra;c[w>>2]=Ca;if((Ca|0)<0){P=53;break}if(!(Ca>>>0<10>>>0)){break c}oa=c[1211536+(Ca<<2)>>2]|0;c[w>>2]=oa;if((oa&65536|0)==0){Ea=oa}else{oa=qa+(ra>>>3)|0;qa=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ra&7)>>>27;oa=ra+5|0;c[y>>2]=pa>>>0>oa>>>0?oa:pa;cPa(o,qa);Ea=c[w>>2]|0}c[x>>2]=Ea&1;if((Ea&8|0)==0){c[u>>2]=0;c[t>>2]=0;Fa=Ea}else{qa=c[L>>2]|0;do{if((qa|0)==1|(qa|0)==12|(qa|0)==23){P=62}else{if((c[J>>2]|0)!=1){P=62;break}Ga=c[u>>2]|0}}while(0);if((P|0)==62){P=0;c[u>>2]=0;c[t>>2]=0;Ga=0}c[u>>2]=qca(K,Ga)|0;c[t>>2]=qca(K,c[t>>2]|0)|0;Fa=c[w>>2]|0}if((Fa&131072|0)==0){Ha=63}else{qa=c[1302727]|0;pa=c[y>>2]|0;oa=c[v>>2]|0;ra=c[r>>2]|0;ta=ra+(pa>>>3)|0;sa=(fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(pa&7)>>>23;ta=b[qa+(sa<<2)>>1]|0;Aa=b[qa+(sa<<2)+2>>1]|0;sa=Aa<<16>>16;if(Aa<<16>>16<0){Aa=pa+9|0;ka=oa>>>0>Aa>>>0?Aa:oa;Aa=ra+(ka>>>3)|0;ra=((fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(ka&7)>>>((sa+32|0)>>>0))+ta|0;Ia=b[qa+(ra<<2)+2>>1]|0;Ja=b[qa+(ra<<2)>>1]|0;Ka=ka}else{Ia=sa;Ja=ta;Ka=pa}pa=Ia+Ka|0;c[y>>2]=oa>>>0>pa>>>0?pa:oa;Ha=Ja+1|0}if((c[x>>2]|0)==0){c[V>>2]=1;c[S>>2]=0;c[(c[Z>>2]|0)+(ha<<2)>>2]=12296;c[U>>2]=c[u>>2]<<1;c[T>>2]=c[t>>2]<<1}else{c[(c[Z>>2]|0)+(ha<<2)>>2]=1}do{if((c[x>>2]|0)==0){if((c[w>>2]&131072|0)!=0){P=75;break}TGb(da|0,-1|0,24)|0}else{P=75}}while(0);if((P|0)==75){P=0;me[c[Y>>2]&511](c[ca>>2]|0);ha=0;oa=Ha;while(1){pa=c[ca>>2]|0;ta=pa+(ha<<7)|0;sa=oa&32;do{if((c[x>>2]|0)==0){if((sa|0)==0){La=0;P=85;break}ka=c[r>>2]|0;ra=c[y>>2]|0;qa=ka+(ra>>>3)|0;Aa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ra&7)>>>30;if((Aa&2|0)==0){Ma=0;Na=ra;Oa=ka;P=83;break}qa=c[v>>2]|0;ua=ra+2|0;ra=qa>>>0>ua>>>0?ua:qa;c[y>>2]=ra;b[ta>>1]=(Aa<<1&2^2)+65535;Ma=1;Na=ra;Oa=ka;P=83}else{ka=c[y>>2]|0;ra=c[v>>2]|0;Aa=c[r>>2]|0;qa=Aa+(ka>>>3)|0;Pa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ka&7)>>>24;qa=ka+8|0;ka=ra>>>0>qa>>>0?qa:ra;c[y>>2]=ka;if((Pa&127|0)==0){P=78;break f}b[ta>>1]=(Pa|0)==255?128:Pa&65535;Ma=1;Na=ka;Oa=Aa;P=83}}while(0);do{if((P|0)==83){P=0;if((sa|0)==0){La=Ma;P=85;break}ta=c[302816]|0;Aa=c[v>>2]|0;ka=Ma;ra=Na;g:while(1){qa=Oa+(ra>>>3)|0;ua=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ra&7)>>>23;qa=b[ta+(ua<<2)>>1]|0;Qa=b[ta+(ua<<2)+2>>1]|0;ua=Qa<<16>>16;if(Qa<<16>>16<0){Qa=ra+9|0;Ra=Aa>>>0>Qa>>>0?Qa:Aa;Qa=Oa+(Ra>>>3)|0;Sa=((fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Ra&7)>>>((ua+32|0)>>>0))+qa|0;Ta=b[ta+(Sa<<2)+2>>1]|0;Ua=b[ta+(Sa<<2)>>1]|0;Va=Ra}else{Ta=ua;Ua=qa;Va=ra}qa=Ta+Va|0;ua=Aa>>>0>qa>>>0?qa:Aa;c[y>>2]=ua;if((Ua|0)<0){P=89;break f}do{if((Ua|0)==(c[302804]|0)){qa=Oa+(ua>>>3)|0;Ra=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ua&7)>>>26;qa=ua+6|0;Sa=Aa>>>0>qa>>>0?qa:Aa;c[y>>2]=Sa;qa=Oa+(Sa>>>3)|0;Qa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Sa&7)>>24;qa=Sa+8|0;Sa=Aa>>>0>qa>>>0?qa:Aa;c[y>>2]=Sa;Wa=Qa&65535;Xa=Ra;Ya=Sa}else{if((Ua|0)==0){break g}Sa=a[(c[302807]|0)+Ua|0]|0;Ra=a[(c[302808]|0)+Ua|0]|0;Qa=d[Oa+(ua>>>3)|0]|0;qa=((ua|0)<(Aa|0))+ua|0;c[y>>2]=qa;Za=Ra<<24>>24;if((Qa&128>>>((ua&7)>>>0)|0)==0){Wa=Za;Xa=Sa;Ya=qa;break}Wa=-Za&65535;Xa=Sa;Ya=qa}}while(0);ua=Xa+ka|0;if((ua|0)>63){P=96;break f}b[pa+(ha<<7)+(d[n+368+ua|0]<<1)>>1]=Wa;ka=ua+1|0;ra=Ya}c[n+180+(ha<<2)>>2]=ka-1}}while(0);if((P|0)==85){P=0;c[n+180+(ha<<2)>>2]=La-1}pa=ha+1|0;if((pa|0)<6){ha=pa;oa=oa<<1}else{break}}}YOa(o,c[ca>>2]|0);oa=c[L>>2]|0;pca(n,oa-(c[J>>2]|0)|0,oa-1|0);oa=c[L>>2]|0;if((oa|0)<34){ja=oa}else{break e}}do{if((P|0)==45){P=0;c[f>>2]=1;P=100}else if((P|0)==47){P=0;if(((c[s>>2]|0)-ya|0)<8){P=100;break}oa=c[z>>2]|0;yDb(c[B>>2]|0,16,1916224,(fa=i,i=i+16|0,c[fa>>2]=c[e>>2],c[fa+8>>2]=oa,fa)|0);i=fa;P=101}else if((P|0)==53){P=0;yDb(za,16,1895640,(fa=i,i=i+8|0,c[fa>>2]=Ca,fa)|0);i=fa;P=101}else if((P|0)==78){P=0;oa=c[e>>2]|0;ha=c[z>>2]|0;yDb(c[B>>2]|0,16,2332800,(fa=i,i=i+24|0,c[fa>>2]=Pa,c[fa+8>>2]=oa,c[fa+16>>2]=ha,fa)|0);i=fa;P=101}else if((P|0)==89){P=0;ha=c[z>>2]|0;yDb(c[B>>2]|0,16,2308416,(fa=i,i=i+16|0,c[fa>>2]=c[e>>2],c[fa+8>>2]=ha,fa)|0);i=fa;P=101}else if((P|0)==96){P=0;ha=c[z>>2]|0;yDb(c[B>>2]|0,16,2289808,(fa=i,i=i+16|0,c[fa>>2]=c[e>>2],c[fa+8>>2]=ha,fa)|0);i=fa;P=101}}while(0);if((P|0)==100){P=0;pca(n,ja,33);break}else if((P|0)==101){P=0;ha=(ba(c[ea>>2]|0,c[z>>2]|0)|0)+(c[e>>2]|0)|0;yDb(c[B>>2]|0,16,1940432,(fa=i,i=i+8|0,c[fa>>2]=ha,fa)|0);i=fa;break}}}while(0);if((c[I>>2]|0)>=(((c[F>>2]|0)==18?12:5)|0)){break b}}yDb(0,0,2110776,(fa=i,i=i+24|0,c[fa>>2]=2352864,c[fa+8>>2]=2006864,c[fa+16>>2]=386,fa)|0);i=fa;Cd();return 0}}while(0);SOa(o);F=c[C>>2]|0;C=h+9856|0;h=c[C>>2]|0;if((F|0)!=(c[h+88>>2]|0)){yDb(0,0,2110776,(fa=i,i=i+24|0,c[fa>>2]=2052344,c[fa+8>>2]=2006864,c[fa+16>>2]=636,fa)|0);i=fa;Cd();return 0}if((F|0)!=(c[H>>2]|0)){yDb(0,0,2110776,(fa=i,i=i+24|0,c[fa>>2]=1968952,c[fa+8>>2]=2006864,c[fa+16>>2]=637,fa)|0);i=fa;Cd();return 0}H=MCb(p,h|0)|0;if((H|0)<0){O=H;i=j;return O|0}VOa(o,c[C>>2]|0,p);c[g>>2]=1;g=c[y>>2]>>3;y=(g|0)==0?1:g;O=(y+10|0)>(m|0)?m:y;i=j;return O|0}else if((P|0)==109){i=j;return O|0}yDb(c[B>>2]|0,16,2188016,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;O=-1;i=j;return O|0}function oca(a){a=a|0;LOa(c[a+60>>2]|0);return 0}function pca(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=a|0;c[a+12488>>2]=0;if((b|0)>=(d|0)){return}f=a+14692|0;g=a+12476|0;h=a+12480|0;i=a+124|0;j=a+4|0;k=a+12496|0;l=a+12500|0;m=a+12504|0;n=a+12508|0;o=a+12512|0;p=a+12516|0;q=a+12544|0;r=a+12548|0;s=a+12552|0;t=a+11736|0;u=a+11740|0;v=a+9160|0;w=a+11744|0;x=a+11748|0;y=a+9924|0;z=a+14680|0;A=a+14340|0;B=a+180|0;a=b;do{b=(c[f>>2]|0)-1|0;C=(((b|0)%2|0)*11|0)+((a|0)%11|0)|0;c[g>>2]=C;D=(((b|0)/2|0)*3|0)+((a|0)/11|0)|0;c[h>>2]=D;b=ba(c[i>>2]|0,D)|0;$Oa(e);D=8>>>((c[(c[j>>2]|0)+800>>2]|0)>>>0);c[k>>2]=(c[k>>2]|0)+2;c[l>>2]=(c[l>>2]|0)+2;c[m>>2]=(c[m>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+1;c[p>>2]=(c[p>>2]|0)+1;c[q>>2]=(c[q>>2]|0)+(D<<1);c[r>>2]=(c[r>>2]|0)+D;c[s>>2]=(c[s>>2]|0)+D;TGb(B|0,-1|0,24)|0;c[t>>2]=1;c[u>>2]=0;c[(c[v>>2]|0)+(b+C<<2)>>2]=14344;c[w>>2]=0;c[x>>2]=0;c[y>>2]=1;c[z>>2]=c[z>>2]&-8388609;YOa(e,c[A>>2]|0);a=a+1|0;}while((a|0)<(d|0));return}function qca(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c[1283095]|0;g=a+8|0;h=c[g>>2]|0;i=c[a+16>>2]|0;j=c[a>>2]|0;a=j+(h>>>3)|0;k=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(h&7)>>>25;a=b[f+(k<<2)>>1]|0;l=b[f+(k<<2)+2>>1]|0;k=l<<16>>16;if(l<<16>>16<0){l=h+7|0;m=i>>>0>l>>>0?l:i;l=j+(m>>>3)|0;n=((fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>((k+32|0)>>>0))+a|0;o=b[f+(n<<2)+2>>1]|0;p=b[f+(n<<2)>>1]|0;q=m}else{o=k;p=a;q=h}h=o+q|0;q=i>>>0>h>>>0?h:i;c[g>>2]=q;if((p|0)<0){r=e;return r|0}h=c[642984+(p<<2)>>2]|0;if((p|0)==0){s=h}else{p=d[j+(q>>>3)|0]|0;c[g>>2]=((q|0)<(i|0))+q;s=(p&128>>>((q&7)>>>0)|0)==0?-h|0:h}h=s+e|0;if(!((h|0)<-15)){return((h|0)>15?h-32|0:h)|0}r=h+32|0;return r|0}function rca(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;e=a+14696|0;do{if((c[e>>2]|0)==0){f=c[a+14120>>2]|0;g=a+14128|0;h=c[g>>2]|0;j=f+(h>>>3)|0;if(((fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)&-131072>>>((h&7)>>>0)|0)==0){j=c[a+14136>>2]|0;k=h+16|0;h=j>>>0>k>>>0?k:j;c[g>>2]=h;l=h;m=j;n=f;break}else{o=-1;i=b;return o|0}}else{l=c[a+14128>>2]|0;m=c[a+14136>>2]|0;n=c[a+14120>>2]|0}}while(0);c[e>>2]=0;e=a+14128|0;f=n+(l>>>3)|0;j=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7)>>>28;f=l+4|0;l=m>>>0>f>>>0?f:m;c[e>>2]=l;c[a+14692>>2]=j;f=n+(l>>>3)|0;h=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7)>>>27;f=l+5|0;l=m>>>0>f>>>0?f:m;c[e>>2]=l;c[a+9960>>2]=h;do{if((c[a+120>>2]|0)==18){if((j-1|0)>>>0>11>>>0){o=-1}else{break}i=b;return o|0}else{if((j|0)==1|(j|0)==3|(j|0)==5){break}else{o=-1}i=b;return o|0}}while(0);j=c[a+14132>>2]|0;if((j-l|0)<1){o=-1094995529;i=b;return o|0}else{p=l}while(1){l=d[n+(p>>>3)|0]|0;f=((p|0)<(m|0))+p|0;c[e>>2]=f;if((l&128>>>((p&7)>>>0)|0)==0){break}l=f+8|0;f=m>>>0>l>>>0?l:m;c[e>>2]=f;if((j-f|0)<1){o=-1094995529;q=14;break}else{p=f}}if((q|0)==14){i=b;return o|0}do{if((h|0)==0){q=a+4|0;yDb(c[q>>2]|0,16,2273840,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;if((c[(c[q>>2]|0)+696>>2]&131074|0)==0){break}else{o=-1}i=b;return o|0}}while(0);c[a+14672>>2]=0;c[a+14676>>2]=0;o=0;i=b;return o|0}function sca(a,b){a=a|0;b=b|0;if((a|0)==176&(b|0)==144){return 0}else{return((a|0)==352&(b|0)==288?1:-1)|0}return 0}function tca(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=b+784|0;K_(d);e=b+796|0;f=c[e>>2]|0;c[b+14280>>2]=f;g=d|0;d=c[g>>2]|0;h=b+788|0;i=c[h>>2]|0;if((i|0)>20){j=i-20|0;k=d<<20|16;l=f}else{m=f;x=fe(16>>>((20-i|0)>>>0)|d<<i|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=(c[e>>2]|0)+4|0;c[e>>2]=m;j=i+12|0;k=16;l=m}c[g>>2]=k;c[h>>2]=j;m=c[b+108>>2]|0;i=gHb(m,(m|0)<0|0?-1:0,3e4,0)|0;m=c[b+4>>2]|0;d=c[m+104>>2]|0;f=gHb(i,F,d,(d|0)<0|0?-1:0)|0;d=F;i=c[m+108>>2]|0;m=gHb(i,(i|0)<0|0?-1:0,1001,0)|0;i=eHb(f,d,m,F)|0;m=i&31;if((j|0)>5){n=j-5|0;o=k<<5|m;p=l}else{i=l;x=fe(m>>>((5-j|0)>>>0)|k<<j|0)|0;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;i=(c[e>>2]|0)+4|0;c[e>>2]=i;n=j+27|0;o=m;p=i}c[g>>2]=o;c[h>>2]=n;if((n|0)>1){q=n-1|0;r=o<<1;s=p}else{i=p;x=fe(o<<n|0)|0;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;i=(c[e>>2]|0)+4|0;c[e>>2]=i;q=n+31|0;r=0;s=i}c[g>>2]=r;c[h>>2]=q;if((q|0)>1){t=q-1|0;u=r<<1;v=s}else{i=s;x=fe(r<<q|0)|0;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;i=(c[e>>2]|0)+4|0;c[e>>2]=i;t=q+31|0;u=0;v=i}c[g>>2]=u;c[h>>2]=t;if((t|0)>1){w=t-1|0;y=u<<1;z=v}else{i=v;x=fe(u<<t|0)|0;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;i=(c[e>>2]|0)+4|0;c[e>>2]=i;w=t+31|0;y=0;z=i}c[g>>2]=y;c[h>>2]=w;i=c[b+8>>2]|0;t=c[b+12>>2]|0;if((i|0)==176&(t|0)==144){A=0}else{A=(i|0)==352&(t|0)==288?1:-1}if((w|0)>1){B=w-1|0;C=y<<1|A;D=z}else{t=z;x=fe(A>>>((1-w|0)>>>0)|y<<w|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[e>>2]|0)+4|0;c[e>>2]=t;B=w+31|0;C=A;D=t}c[g>>2]=C;c[h>>2]=B;if((B|0)>1){E=B-1|0;G=C<<1;H=D}else{t=D;x=fe(C<<B|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[e>>2]|0)+4|0;c[e>>2]=t;E=B+31|0;G=0;H=t}c[g>>2]=G;c[h>>2]=E;if((E|0)>1){I=E-1|0;J=G<<1;K=H}else{t=H;x=fe(G<<E|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[e>>2]|0)+4|0;c[e>>2]=t;I=E+31|0;J=0;K=t}c[g>>2]=J;c[h>>2]=I;if((I|0)>1){L=I-1|0;M=J<<1;c[g>>2]=M;c[h>>2]=L;N=(A|0)==0;O=b+14692|0;P=N<<31>>31;c[O>>2]=P;Q=b+12484|0;c[Q>>2]=0;return}else{t=K;x=fe(J<<I|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[e>>2]=(c[e>>2]|0)+4;L=I+31|0;M=0;c[g>>2]=M;c[h>>2]=L;N=(A|0)==0;O=b+14692|0;P=N<<31>>31;c[O>>2]=P;Q=b+12484|0;c[Q>>2]=0;return}}function uca(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;d=b+12476|0;e=b+12480|0;f=(ba(c[b+116>>2]|0,c[e>>2]|0)|0)+(c[d>>2]|0)|0;g=(f|0)%11|0;if((g|0)==0){if(((f|0)%33|0|0)==0){h=b+14692|0;i=((c[b+8>>2]|0)==176&(c[b+12>>2]|0)==144?2:1)+(c[h>>2]|0)|0;c[h>>2]=i;j=b+784|0;k=c[j>>2]|0;l=b+788|0;m=c[l>>2]|0;if((m|0)>16){n=m-16|0;o=k<<16|1;p=i}else{i=fe(1>>>((16-m|0)>>>0)|k<<m|0)|0;k=b+796|0;q=c[k>>2]|0;x=i;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;n=m+16|0;o=1;p=c[h>>2]|0}c[j>>2]=o;c[l>>2]=n;if((n|0)>4){r=n-4|0;s=o<<4|p}else{h=fe(p>>>((4-n|0)>>>0)|o<<n|0)|0;o=b+796|0;m=c[o>>2]|0;x=h;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;r=n+28|0;s=p}c[j>>2]=s;c[l>>2]=r;p=c[b+9960>>2]|0;if((r|0)>5){t=r-5|0;u=p|s<<5}else{n=fe(p>>>((5-r|0)>>>0)|s<<r|0)|0;s=b+796|0;o=c[s>>2]|0;x=n;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;t=r+27|0;u=p}c[j>>2]=u;c[l>>2]=t;if((t|0)>1){v=t-1|0;w=u<<1}else{p=fe(u<<t|0)|0;u=b+796|0;r=c[u>>2]|0;x=p;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=t+31|0;w=0}c[j>>2]=w;c[l>>2]=v;c[b+12484>>2]=0;v=b+11824|0;c[v>>2]=0;l=b+11828|0;c[l>>2]=0;y=v;z=l}else{y=b+11824|0;z=b+11828|0}c[y>>2]=0;c[z>>2]=0}z=c[b+8>>2]|0;y=c[b+12>>2]|0;if((z|0)==176&(y|0)==144){return}if(!((z|0)==352&(y|0)==288)){return}c[d>>2]=g+((((f|0)/33|0|0)%2|0)*11|0);c[e>>2]=(((f|0)/11|0|0)%3|0)+(((f|0)/66|0)*3|0);$Oa(b);f=8>>>((c[(c[b+4>>2]|0)+800>>2]|0)>>>0);e=b+12496|0;c[e>>2]=(c[e>>2]|0)+2;e=b+12500|0;c[e>>2]=(c[e>>2]|0)+2;e=b+12504|0;c[e>>2]=(c[e>>2]|0)+2;e=b+12508|0;c[e>>2]=(c[e>>2]|0)+2;e=b+12512|0;c[e>>2]=(c[e>>2]|0)+1;e=b+12516|0;c[e>>2]=(c[e>>2]|0)+1;e=b+12544|0;c[e>>2]=(c[e>>2]|0)+(f<<1);e=b+12548|0;c[e>>2]=(c[e>>2]|0)+f;e=b+12552|0;c[e>>2]=(c[e>>2]|0)+f;return}function vca(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;j=f;k=f+14680|0;c[k>>2]=0;l=f+12488|0;m=c[l>>2]|0;do{if((m|0)==0){n=(c[f+180>>2]>>31)+32&-32;o=(c[f+184>>2]|0)>-1?n|16:n;n=(c[f+188>>2]|0)>-1?o|8:o;o=(c[f+192>>2]|0)>-1?n|4:n;n=((c[f+196>>2]|0)>-1?o|2:o)|(c[f+200>>2]|0)>>>31^1;o=i|h;if((c[f+9984>>2]|o|n|0)!=0){p=n;q=o;break}o=f+13692|0;c[o>>2]=(c[o>>2]|0)+1;o=f+12484|0;c[o>>2]=(c[o>>2]|0)+1;c[f+11824>>2]=0;c[f+11828>>2]=0;return}else{p=63;q=0}}while(0);o=f+12484|0;n=c[o>>2]|0;r=d[1211648+n|0]|0;s=d[1211608+n|0]|0;n=f+784|0;t=c[n>>2]|0;u=f+788|0;v=c[u>>2]|0;if((v|0)>(r|0)){w=v-r|0;y=t<<r|s;z=m}else{m=fe(s>>>((r-v|0)>>>0)|t<<v|0)|0;t=f+796|0;A=c[t>>2]|0;x=m;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;w=32-r+v|0;y=s;z=c[l>>2]|0}c[n>>2]=y;c[u>>2]=w;c[o>>2]=0;do{if((z|0)==0){o=c[k>>2]|0;s=o+1|0;c[k>>2]=s;v=c[f+13836>>2]|0;do{if((q|0)==0){if((v|0)==0){B=s;break}r=o+4|0;c[k>>2]=r;C=r;D=12}else{r=o+4|0;c[k>>2]=r;if((v|0)==0){B=r}else{C=r;D=12}}}while(0);if((D|0)==12){v=C+3|0;c[k>>2]=v;B=v}if((p|0)==0){if((c[f+9984>>2]|0)==0){break}}c[k>>2]=B+1}}while(0);B=f+9984|0;C=c[k>>2]|0;if((c[B>>2]|0)==0){E=C}else{q=C+1|0;c[k>>2]=q;E=q}q=d[1211592+E|0]|0;C=d[1211576+E|0]|0;if((w|0)>(q|0)){F=w-q|0;G=y<<q|C;H=E}else{E=fe(C>>>((q-w|0)>>>0)|y<<w|0)|0;y=f+796|0;z=c[y>>2]|0;x=E;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;F=32-q+w|0;G=C;H=c[k>>2]|0}c[n>>2]=G;c[u>>2]=F;C=c[1211536+(H<<2)>>2]|0;c[k>>2]=C;if((C&65536|0)==0){I=C;J=G;K=F}else{F=f+9960|0;cPa(f,(c[B>>2]|0)+(c[F>>2]|0)|0);B=c[F>>2]|0;F=c[n>>2]|0;G=c[u>>2]|0;if((G|0)>5){L=G-5|0;M=F<<5|B}else{C=fe(B>>>((5-G|0)>>>0)|F<<G|0)|0;F=f+796|0;H=c[F>>2]|0;x=C;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[F>>2]=(c[F>>2]|0)+4;L=G+27|0;M=B}c[n>>2]=M;c[u>>2]=L;I=c[k>>2]|0;J=M;K=L}do{if((I&8|0)==0){N=J;O=K}else{L=h>>1;M=f+11824|0;B=c[M>>2]|0;G=L-B|0;F=i>>1;H=f+11828|0;C=c[H>>2]|0;w=F-C|0;c[M>>2]=L;c[H>>2]=F;do{if((L|0)==(B|0)){H=d[1211409]|0;M=d[1211408]|0;if((K|0)>(H|0)){P=K-H|0;Q=J<<H|M;break}else{q=fe(M>>>((H-K|0)>>>0)|J<<K|0)|0;y=f+796|0;z=c[y>>2]|0;x=q;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;P=32-H+K|0;Q=M;break}}else{M=(G|0)>15?G-32|0:G;H=(M|0)<-16?M+32|0:M;M=H>>>31;y=(H|0)<0?-H|0:H;H=d[1211409+(y<<1)|0]|0;z=d[1211408+(y<<1)|0]|0;if((K|0)>(H|0)){R=K-H|0;S=J<<H|z}else{y=fe(z>>>((H-K|0)>>>0)|J<<K|0)|0;q=f+796|0;E=c[q>>2]|0;x=y;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;R=32-H+K|0;S=z}c[n>>2]=S;c[u>>2]=R;if((R|0)>1){P=R-1|0;Q=S<<1|M;break}else{z=fe(M>>>((1-R|0)>>>0)|S<<R|0)|0;H=f+796|0;q=c[H>>2]|0;x=z;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;P=R+31|0;Q=M;break}}}while(0);c[n>>2]=Q;c[u>>2]=P;if((F|0)==(C|0)){G=d[1211409]|0;B=d[1211408]|0;if((P|0)>(G|0)){T=P-G|0;U=Q<<G|B}else{L=fe(B>>>((G-P|0)>>>0)|Q<<P|0)|0;M=f+796|0;H=c[M>>2]|0;x=L;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[M>>2]=(c[M>>2]|0)+4;T=32-G+P|0;U=B}c[n>>2]=U;c[u>>2]=T;N=U;O=T;break}B=(w|0)>15?w-32|0:w;G=(B|0)<-16?B+32|0:B;B=G>>>31;M=(G|0)<0?-G|0:G;G=d[1211409+(M<<1)|0]|0;H=d[1211408+(M<<1)|0]|0;if((P|0)>(G|0)){V=P-G|0;W=Q<<G|H}else{M=fe(H>>>((G-P|0)>>>0)|Q<<P|0)|0;L=f+796|0;q=c[L>>2]|0;x=M;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[L>>2]=(c[L>>2]|0)+4;V=32-G+P|0;W=H}c[n>>2]=W;c[u>>2]=V;if((V|0)>1){X=V-1|0;Y=W<<1|B}else{H=fe(B>>>((1-V|0)>>>0)|W<<V|0)|0;G=f+796|0;L=c[G>>2]|0;x=H;a[L]=x;x=x>>8;a[L+1|0]=x;x=x>>8;a[L+2|0]=x;x=x>>8;a[L+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;X=V+31|0;Y=B}c[n>>2]=Y;c[u>>2]=X;N=Y;O=X}}while(0);if((c[k>>2]&131072|0)==0){Z=O;_=N}else{X=p-1|0;p=d[1211985+(X<<1)|0]|0;Y=d[1211984+(X<<1)|0]|0;if((O|0)>(p|0)){$=O-p|0;aa=N<<p|Y}else{X=fe(Y>>>((p-O|0)>>>0)|N<<O|0)|0;N=f+796|0;V=c[N>>2]|0;x=X;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;$=32-p+O|0;aa=Y}c[n>>2]=aa;c[u>>2]=$;Z=$;_=aa}aa=f+796|0;$=f+784|0;Y=0;O=Z;Z=_;while(1){_=g+(Y<<7)|0;p=b[_>>1]|0;N=p<<16>>16;a:do{if((c[l>>2]|0)==0){if(!((p<<16>>16|0)==1|(p<<16>>16|0)==(-1|0))){ba=0;ca=O;da=Z;break}if(!((c[j+180+(Y<<2)>>2]|0)>-1)){ba=0;ca=O;da=Z;break}V=p<<16>>16>0?2:3;if((O|0)>2){ea=O-2|0;fa=Z<<2|V}else{X=fe(V>>>((2-O|0)>>>0)|Z<<O|0)|0;W=c[aa>>2]|0;x=X;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;c[aa>>2]=(c[aa>>2]|0)+4;ea=O+30|0;fa=V}c[n>>2]=fa;c[u>>2]=ea;ba=1;ca=ea;da=fa}else{do{if(p<<16>>16>254){ga=254;ha=254;D=58}else{if(p<<16>>16<1){ga=1;ha=1;D=58;break}if(!(p<<16>>16==128)){ia=N;ja=Z;ka=O;la=f+788|0;break}if((O|0)>8){ma=O-8|0;na=Z<<8|255}else{V=fe(255>>>((8-O|0)>>>0)|Z<<O|0)|0;W=c[aa>>2]|0;x=V;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;c[aa>>2]=(c[aa>>2]|0)+4;ma=O+24|0;na=255}c[$>>2]=na;c[u>>2]=ma;ba=1;ca=ma;da=na;break a}}while(0);if((D|0)==58){D=0;b[_>>1]=ha;W=f+788|0;ia=ga;ja=c[$>>2]|0;ka=c[W>>2]|0;la=W}if((ka|0)>8){oa=ka-8|0;pa=ja<<8|ia}else{W=fe(ia>>>((8-ka|0)>>>0)|ja<<ka|0)|0;V=f+796|0;X=c[V>>2]|0;x=W;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;c[V>>2]=(c[V>>2]|0)+4;oa=ka+24|0;pa=ia}c[$>>2]=pa;c[la>>2]=oa;ba=1;ca=oa;da=pa}}while(0);_=c[j+180+(Y<<2)>>2]|0;if((ba|0)>(_|0)){qa=ca;ra=da}else{N=ba-1|0;p=ba;w=ca;C=da;while(1){F=b[g+(Y<<7)+(d[j+368+p|0]<<1)>>1]|0;V=F<<16>>16;do{if(F<<16>>16==0){sa=N;ta=w;ua=C}else{X=p-N-1|0;W=(F&65535)>>>15&65535;P=F<<16>>16<0?-V|0:V;Q=d[(c[302809]|0)+X|0]|0;T=c[302804]|0;do{if((Q|0)<(T|0)){if((a[(c[302811]|0)+X|0]|0)<(P|0)){va=T;break}va=P-1+Q|0}else{va=T}}while(0);T=va+((X|0)==0&(P|0)<16&1)|0;Q=c[302806]|0;U=e[Q+(T<<2)+2>>1]|0;R=e[Q+(T<<2)>>1]|0;if((w|0)>(U|0)){wa=w-U|0;xa=C<<U|R}else{Q=fe(R>>>((U-w|0)>>>0)|C<<w|0)|0;S=c[aa>>2]|0;x=Q;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;c[aa>>2]=(c[aa>>2]|0)+4;wa=32-U+w|0;xa=R}c[n>>2]=xa;c[u>>2]=wa;if((T|0)!=(c[302804]|0)){if((wa|0)>1){ya=wa-1|0;za=xa<<1|W}else{T=fe(W>>>((1-wa|0)>>>0)|xa<<wa|0)|0;R=c[aa>>2]|0;x=T;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[aa>>2]=(c[aa>>2]|0)+4;ya=wa+31|0;za=W}c[n>>2]=za;c[u>>2]=ya;sa=p;ta=ya;ua=za;break}if((wa|0)>6){Aa=wa-6|0;Ba=xa<<6|X}else{R=fe(X>>>((6-wa|0)>>>0)|xa<<wa|0)|0;T=c[aa>>2]|0;x=R;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[aa>>2]=(c[aa>>2]|0)+4;Aa=wa+26|0;Ba=X}c[n>>2]=Ba;c[u>>2]=Aa;T=V&255;if((Aa|0)>8){Ca=Aa-8|0;Da=Ba<<8|T}else{R=fe(T>>>((8-Aa|0)>>>0)|Ba<<Aa|0)|0;U=c[aa>>2]|0;x=R;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;c[aa>>2]=(c[aa>>2]|0)+4;Ca=Aa+24|0;Da=T}c[n>>2]=Da;c[u>>2]=Ca;sa=p;ta=Ca;ua=Da}}while(0);V=p+1|0;if((V|0)>(_|0)){qa=ta;ra=ua;break}else{N=sa;p=V;w=ta;C=ua}}}if((_|0)>-1){C=c[302806]|0;w=e[C+2>>1]|0;p=e[C>>1]|0;if((qa|0)>(w|0)){Ea=qa-w|0;Fa=ra<<w|p}else{C=fe(p>>>((w-qa|0)>>>0)|ra<<qa|0)|0;N=c[aa>>2]|0;x=C;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[aa>>2]=(c[aa>>2]|0)+4;Ea=32-w+qa|0;Fa=p}c[n>>2]=Fa;c[u>>2]=Ea;Ga=Ea;Ha=Fa}else{Ga=qa;Ha=ra}p=Y+1|0;if((p|0)<6){Y=p;O=Ga;Z=Ha}else{break}}if((c[k>>2]&8|0)!=0){return}c[f+11824>>2]=0;c[f+11828>>2]=0;return}function wca(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;glb();c[f+13080>>2]=-127;c[f+13084>>2]=127;c[f+9892>>2]=1179688;c[f+9888>>2]=1179688;c[f+13088>>2]=20;g=-64;while(1){if((g|0)==0){g=1;continue}h=g+64|0;i=(g|0)<0?-g|0:g;j=i-1|0;k=c[302809]|0;l=c[302804]|0;m=0;do{n=h+(m<<7)|0;o=2799320+n|0;a[o]=100;p=k+m|0;q=d[p]|0;do{if((q|0)<(l|0)){if((a[(c[302811]|0)+m|0]|0)<(i|0)){r=6;break}s=q+j|0;t=c[302806]|0;u=(e[t+(s<<2)+2>>1]|0)+1|0;if(!((s|0)!=(l|0)&u>>>0<100>>>0)){v=100;w=t;break}a[o]=u;v=u&255;w=t}else{r=6}}while(0);if((r|0)==6){r=0;v=100;w=c[302806]|0}q=w+(l<<2)+2|0;t=b[q>>1]|0;if((t&65535)>>>0<v>>>0){a[o]=t}t=n+2807512|0;a[t]=100;u=d[p]|0;do{if((u|0)<(l|0)){if((a[(c[302811]|0)+m|0]|0)<(i|0)){x=100;break}s=u+j|0;y=(e[w+(s<<2)+2>>1]|0)+3|0;if(!((s|0)!=(l|0)&y>>>0<100>>>0)){x=100;break}a[t]=y;x=y&255}else{x=100}}while(0);u=(e[q>>1]|0)+2|0;if(u>>>0<x>>>0){a[t]=u}m=m+1|0;}while((m|0)<64);g=g+1|0;if((g|0)>=64){break}}c[f+13100>>2]=2799320;c[f+13092>>2]=2799320;c[f+13104>>2]=2807512;c[f+13096>>2]=2807512;return}function xca(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=ba(c[d+124>>2]|0,c[d+12480>>2]|0)|0;f=e+(c[d+12476>>2]|0)|0;e=c[d+128>>2]|0;g=c[d+12496>>2]|0;a[(c[d+9168>>2]|0)+f|0]=c[d+9924>>2];h=d+11740|0;i=c[h>>2]|0;if((i|0)!=1){do{if((c[d+12488>>2]|0)==0){j=c[d+11744>>2]|0;if((i|0)==0){k=c[d+11748>>2]&65535;l=j&65535;break}else{m=c[d+11752>>2]|0;n=m+j|0;o=c[d+11748>>2]|0;p=c[d+11756>>2]|0;q=c[d+11660>>2]|0;b[q+(f<<2)>>1]=j;b[q+(f<<2)+2>>1]=o;q=c[d+11668>>2]|0;b[q+(f<<2)>>1]=m;b[q+(f<<2)+2>>1]=p;q=c[d+11808>>2]&255;m=f<<2;j=d+9180|0;a[(c[j>>2]|0)+(m|1)|0]=q;a[(c[j>>2]|0)+m|0]=q;q=c[d+11812>>2]&255;a[(c[j>>2]|0)+(m|3)|0]=q;a[(c[j>>2]|0)+(m|2)|0]=q;k=p+o&65535;l=(n>>>1|n&1)&65535;break}}else{k=0;l=0}}while(0);i=c[d+9148>>2]|0;b[i+(g<<2)>>1]=l;b[i+(g<<2)+2>>1]=k;n=g+1|0;b[i+(n<<2)>>1]=l;b[i+(n<<2)+2>>1]=k;o=g+e|0;b[i+(o<<2)>>1]=l;b[i+(o<<2)+2>>1]=k;o=n+e|0;b[i+(o<<2)>>1]=l;b[i+(o<<2)+2>>1]=k}if((c[d+56>>2]|0)==0){return}if((c[h>>2]|0)==1){c[(c[d+9160>>2]|0)+(f<<2)>>2]=12352;return}h=(c[d+9160>>2]|0)+(f<<2)|0;if((c[d+12488>>2]|0)==0){c[h>>2]=12296;return}else{c[h>>2]=1;return}}function yca(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[a+12476>>2]|0;if((d|0)<4){g=a+9876|0;h=a+128|0;i=c[a+12480>>2]<<1|d>>>1&1;j=f<<1|d&1}else{g=a+9876+(d-3<<2)|0;h=a+124|0;i=c[a+12480>>2]|0;j=f}k=c[g>>2]|0;g=c[h>>2]|0;h=ba(g,i)|0;l=b[k+(j-1+h<<1)>>1]|0;m=b[k+((ba(g,i-1|0)|0)+j<<1)>>1]|0;do{if((c[a+14084>>2]|0)==0|(d|0)==3){n=m;o=l}else{i=(d|0)==2?m:1024;if((d|0)==1){n=i;o=l;break}n=i;o=(f|0)==(c[a+13704>>2]|0)?1024:l}}while(0);l=(o|0)!=1024;if((n|0)==1024|l^1){p=l?o:n;q=h+j|0;r=k+(q<<1)|0;c[e>>2]=r;return p|0}else{p=n+o>>1;q=h+j|0;r=k+(q<<1)|0;c[e>>2]=r;return p|0}return 0}function zca(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[b+148>>2]|0;f=c[b+152>>2]|0;g=b+12480|0;h=c[g>>2]|0;i=b+124|0;j=ba(c[i>>2]|0,h)|0;k=b+12476|0;l=j+(c[k>>2]|0)|0;j=c[b+12544>>2]|0;m=c[b+12548>>2]|0;n=c[b+12552>>2]|0;o=b+9160|0;if((c[(c[o>>2]|0)+(l<<2)>>2]&2048|0)==0){p=c[b+9960>>2]|0;q=b+11552|0;r=e<<3;Xe[c[q>>2]&4095](j+r|0,e,p);Xe[c[q>>2]&4095](j+(r+8)|0,e,p);s=p;t=c[g>>2]|0}else{s=0;t=h}do{if((t|0)!=0){h=l-(c[i>>2]|0)|0;if((c[(c[o>>2]|0)+(h<<2)>>2]&2048|0)==0){u=a[(c[b+9136>>2]|0)+h|0]|0}else{u=0}h=(s|0)==0?u:s;if((h|0)!=0){p=d[(c[b+9896>>2]|0)+h|0]|0;r=b+11552|0;Xe[c[r>>2]&4095](j,e,h);Xe[c[r>>2]&4095](j+8|0,e,h);Xe[c[r>>2]&4095](m,f,p);Xe[c[r>>2]&4095](n,f,p)}p=(u|0)!=0;if(p){Xe[c[b+11548>>2]&4095](j+(8-(e<<3))|0,e,u)}if((c[k>>2]|0)==0){break}if(p){v=u}else{p=l-1-(c[i>>2]|0)|0;if((c[(c[o>>2]|0)+(p<<2)>>2]&2048|0)!=0){break}r=a[(c[b+9136>>2]|0)+p|0]|0;if(r<<24>>24==0){break}else{v=r<<24>>24}}r=d[(c[b+9896>>2]|0)+v|0]|0;p=b+11548|0;Xe[c[p>>2]&4095](j+(-(e<<3)|0)|0,e,v);h=-(f<<3)|0;Xe[c[p>>2]&4095](m+h|0,f,r);Xe[c[p>>2]&4095](n+h|0,f,r)}}while(0);v=(s|0)!=0;do{if(v){i=b+11548|0;Xe[c[i>>2]&4095](j+8|0,e,s);if(((c[g>>2]|0)+1|0)!=(c[b+120>>2]|0)){break}Xe[c[i>>2]&4095](j+((e<<3)+8)|0,e,s)}}while(0);if((c[k>>2]|0)==0){return}do{if(v){w=s}else{k=l-1|0;if((c[(c[o>>2]|0)+(k<<2)>>2]&2048|0)!=0){return}i=a[(c[b+9136>>2]|0)+k|0]|0;if(!(i<<24>>24==0)){w=i<<24>>24;break}return}}while(0);o=b+11548|0;Xe[c[o>>2]&4095](j,e,w);if(((c[g>>2]|0)+1|0)!=(c[b+120>>2]|0)){return}g=d[(c[b+9896>>2]|0)+w|0]|0;Xe[c[o>>2]&4095](j+(e<<3)|0,e,w);Xe[c[o>>2]&4095](m,f,g);Xe[c[o>>2]&4095](n,f,g);return}function Aca(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=c[a+12476>>2]|0;if((f|0)<4){h=g<<1|f&1;i=a+9912|0;j=a+9876|0;k=a+168|0;l=a+128|0;m=(c[a+12480>>2]<<1)+(f>>1)|0}else{n=f-3|0;h=g;i=a+9912+(n<<2)|0;j=a+9876+(n<<2)|0;k=a+172|0;l=a+124|0;m=c[a+12480>>2]|0}n=c[i>>2]|0;i=c[j>>2]|0;j=c[k>>2]|0;k=c[l>>2]|0;l=ba(k,m)|0;o=l+h|0;p=o<<4;q=b[i+(h-1+l<<1)>>1]|0;l=b[i+((ba(k,m-1|0)|0)+h<<1)>>1]|0;do{if((c[a+14084>>2]|0)==0|(f|0)==3){r=l;s=q}else{h=(f|0)==2?l:1024;if((f|0)==1){r=h;s=q;break}r=h;s=(g|0)==(c[a+13704>>2]|0)?1024:q}}while(0);do{if((c[a+176>>2]|0)==0){q=(s|0)!=1024;if((r|0)==1024|q^1){t=q?s:r;break}else{t=r+s>>1;break}}else{if((c[a+13820>>2]|0)==0){if((r|0)==1024){t=1024;break}q=(-(k<<4)|8)+p|0;g=e+(d[a+11185|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|1)<<1)>>1]|0);g=e+(d[a+11186|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|2)<<1)>>1]|0);g=e+(d[a+11187|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|3)<<1)>>1]|0);g=e+(d[a+11188|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|4)<<1)>>1]|0);g=e+(d[a+11189|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|5)<<1)>>1]|0);g=e+(d[a+11190|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|6)<<1)>>1]|0);g=e+(d[a+11191|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|7)<<1)>>1]|0);t=r;break}else{if((s|0)==1024){t=1024;break}q=e+(d[a+11192|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-15<<1)>>1]|0);q=e+(d[a+11200|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-14<<1)>>1]|0);q=e+(d[a+11208|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-13<<1)>>1]|0);q=e+(d[a+11216|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-12<<1)>>1]|0);q=e+(d[a+11224|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-11<<1)>>1]|0);q=e+(d[a+11232|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-10<<1)>>1]|0);q=e+(d[a+11240|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-9<<1)>>1]|0);t=s;break}}}while(0);s=(ba(b[e>>1]|0,j)|0)+t&65535;t=s<<16>>16<0?0:s|1;b[e>>1]=t;b[i+(o<<1)>>1]=t;b[n+((p|1)<<1)>>1]=b[e+(d[a+11192|0]<<1)>>1]|0;b[n+((p|2)<<1)>>1]=b[e+(d[a+11200|0]<<1)>>1]|0;b[n+((p|3)<<1)>>1]=b[e+(d[a+11208|0]<<1)>>1]|0;b[n+((p|4)<<1)>>1]=b[e+(d[a+11216|0]<<1)>>1]|0;b[n+((p|5)<<1)>>1]=b[e+(d[a+11224|0]<<1)>>1]|0;b[n+((p|6)<<1)>>1]=b[e+(d[a+11232|0]<<1)>>1]|0;b[n+((p|7)<<1)>>1]=b[e+(d[a+11240|0]<<1)>>1]|0;b[n+((p|9)<<1)>>1]=b[e+(d[a+11185|0]<<1)>>1]|0;b[n+((p|10)<<1)>>1]=b[e+(d[a+11186|0]<<1)>>1]|0;b[n+((p|11)<<1)>>1]=b[e+(d[a+11187|0]<<1)>>1]|0;b[n+((p|12)<<1)>>1]=b[e+(d[a+11188|0]<<1)>>1]|0;b[n+((p|13)<<1)>>1]=b[e+(d[a+11189|0]<<1)>>1]|0;b[n+((p|14)<<1)>>1]=b[e+(d[a+11190|0]<<1)>>1]|0;b[n+((p|15)<<1)>>1]=b[e+(d[a+11191|0]<<1)>>1]|0;return}function Bca(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[a+128>>2]|0;i=c[a+9148+(e<<2)>>2]|0;e=c[a+12496+(d<<2)>>2]|0;j=e-1|0;k=i+(j<<2)|0;if(!((c[a+14084>>2]|0)!=0&(d|0)<3)){l=e-h|0;m=(c[1210376+(d<<2)>>2]|0)-h+e|0;n=b[k>>1]|0;o=n<<16>>16;p=b[i+(l<<2)>>1]|0;q=p<<16>>16;r=b[i+(m<<2)>>1]|0;s=r<<16>>16;do{if(n<<16>>16>p<<16>>16){if(!(r<<16>>16>p<<16>>16)){t=q;break}t=(s|0)>(o|0)?o:s}else{if(!(p<<16>>16>r<<16>>16)){t=q;break}t=(s|0)>(o|0)?s:o}}while(0);c[f>>2]=t;t=b[i+(j<<2)+2>>1]|0;o=t<<16>>16;s=b[i+(l<<2)+2>>1]|0;l=s<<16>>16;q=b[i+(m<<2)+2>>1]|0;m=q<<16>>16;do{if(t<<16>>16>s<<16>>16){if(!(q<<16>>16>s<<16>>16)){u=l;break}u=(m|0)>(o|0)?o:m}else{if(!(s<<16>>16>q<<16>>16)){u=l;break}u=(m|0)>(o|0)?m:o}}while(0);c[g>>2]=u;v=i+(e<<2)|0;return v|0}if((d|0)==0){u=c[a+12476>>2]|0;o=c[a+13704>>2]|0;if((u|0)==(o|0)){c[g>>2]=0;c[f>>2]=0;v=i+(e<<2)|0;return v|0}do{if((u+1|0)==(o|0)){if((c[a+32>>2]|0)==0){break}m=2-h+e|0;l=i+(m<<2)|0;if((u|0)==0){c[f>>2]=b[l>>1]|0;c[g>>2]=b[i+(m<<2)+2>>1]|0;v=i+(e<<2)|0;return v|0}q=b[k>>1]|0;s=q<<16>>16;t=b[l>>1]|0;l=t<<16>>16;do{if(q<<16>>16>0){if(!(t<<16>>16>0)){w=0;break}w=(l|0)>(s|0)?s:l}else{if(!(t<<16>>16<0)){w=0;break}w=(l|0)>(s|0)?l:s}}while(0);c[f>>2]=w;s=b[i+(j<<2)+2>>1]|0;l=s<<16>>16;t=b[i+(m<<2)+2>>1]|0;q=t<<16>>16;do{if(s<<16>>16>0){if(!(t<<16>>16>0)){x=0;break}x=(q|0)>(l|0)?l:q}else{if(!(t<<16>>16<0)){x=0;break}x=(q|0)>(l|0)?q:l}}while(0);c[g>>2]=x;v=i+(e<<2)|0;return v|0}}while(0);c[f>>2]=b[k>>1]|0;c[g>>2]=b[i+(j<<2)+2>>1]|0;v=i+(e<<2)|0;return v|0}else if((d|0)==1){do{if(((c[a+12476>>2]|0)+1|0)==(c[a+13704>>2]|0)){if((c[a+32>>2]|0)==0){break}x=1-h+e|0;w=b[k>>1]|0;u=w<<16>>16;o=b[i+(x<<2)>>1]|0;l=o<<16>>16;do{if(w<<16>>16>0){if(!(o<<16>>16>0)){y=0;break}y=(l|0)>(u|0)?u:l}else{if(!(o<<16>>16<0)){y=0;break}y=(l|0)>(u|0)?l:u}}while(0);c[f>>2]=y;u=b[i+(j<<2)+2>>1]|0;l=u<<16>>16;o=b[i+(x<<2)+2>>1]|0;w=o<<16>>16;do{if(u<<16>>16>0){if(!(o<<16>>16>0)){z=0;break}z=(w|0)>(l|0)?l:w}else{if(!(o<<16>>16<0)){z=0;break}z=(w|0)>(l|0)?w:l}}while(0);c[g>>2]=z;v=i+(e<<2)|0;return v|0}}while(0);c[f>>2]=b[k>>1]|0;c[g>>2]=b[i+(j<<2)+2>>1]|0;v=i+(e<<2)|0;return v|0}else{z=e-h|0;y=(c[1210376+(d<<2)>>2]|0)-h+e|0;if((c[a+12476>>2]|0)==(c[a+13704>>2]|0)){b[i+(j<<2)+2>>1]=0;b[k>>1]=0;A=0}else{A=b[k>>1]|0}k=A<<16>>16;a=b[i+(z<<2)>>1]|0;h=a<<16>>16;d=b[i+(y<<2)>>1]|0;l=d<<16>>16;do{if(A<<16>>16>a<<16>>16){if(!(d<<16>>16>a<<16>>16)){B=h;break}B=(l|0)>(k|0)?k:l}else{if(!(a<<16>>16>d<<16>>16)){B=h;break}B=(l|0)>(k|0)?l:k}}while(0);c[f>>2]=B;B=b[i+(j<<2)+2>>1]|0;j=B<<16>>16;f=b[i+(z<<2)+2>>1]|0;z=f<<16>>16;k=b[i+(y<<2)+2>>1]|0;y=k<<16>>16;do{if(B<<16>>16>f<<16>>16){if(!(k<<16>>16>f<<16>>16)){C=z;break}C=(y|0)>(j|0)?j:y}else{if(!(f<<16>>16>k<<16>>16)){C=z;break}C=(y|0)>(j|0)?y:j}}while(0);c[g>>2]=C;v=i+(e<<2)|0;return v|0}return 0}function Cca(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)<401){d=1;return d|0}d=(b|0)<801?2:4;return d|0}function Dca(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=a+20|0;g=c[f>>2]|0;h=a+16|0;a=c[h>>2]|0;a:do{if((g|0)==0){i=a;j=0;while(1){if((j|0)>=(e|0)){k=i;l=0;break a}m=d[b+j|0]|0|i<<8;n=j+1|0;if((i&16777212|0)==128){o=m;p=n;q=1;r=4;break}else{i=m;j=n}}}else{o=a;p=0;q=g;r=4}}while(0);b:do{if((r|0)==4){if((p|0)<(e|0)){s=p;t=o}else{k=o;l=q;break}while(1){if((t&16777212|0)==128){break}g=d[b+s|0]|0|t<<8;a=s+1|0;if((a|0)<(e|0)){s=a;t=g}else{k=g;l=q;break b}}c[f>>2]=0;c[h>>2]=-1;u=s-3|0;return u|0}}while(0);c[f>>2]=l;c[h>>2]=k;u=-100;return u|0}function Eca(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;i=i+16|0;j=b|0;k=b+8|0;c[j>>2]=g;c[k>>2]=h;l=c[a>>2]|0;m=l;do{if((c[a+176>>2]&1|0)==0){n=l+20|0;o=c[n>>2]|0;p=l+16|0;q=c[p>>2]|0;a:do{if((o|0)==0){r=q;s=0;while(1){if((s|0)>=(h|0)){t=r;u=0;v=9;break a}w=d[g+s|0]|0|r<<8;x=s+1|0;if((r&16777212|0)==128){y=w;z=x;A=1;v=5;break}else{r=w;s=x}}}else{y=q;z=0;A=o;v=5}}while(0);b:do{if((v|0)==5){if((z|0)<(h|0)){B=z;C=y}else{t=y;u=A;v=9;break}while(1){if((C&16777212|0)==128){break}o=d[g+B|0]|0|C<<8;q=B+1|0;if((q|0)<(h|0)){B=q;C=o}else{t=o;u=A;v=9;break b}}c[n>>2]=0;c[p>>2]=-1;D=B-3|0}}while(0);if((v|0)==9){c[n>>2]=u;c[p>>2]=t;D=-100}if((WRa(m,D,j,k)|0)>=0){E=D;F=c[j>>2]|0;G=c[k>>2]|0;break}c[e>>2]=0;c[f>>2]=0;H=c[k>>2]|0;i=b;return H|0}else{E=h;F=g;G=h}}while(0);c[e>>2]=F;c[f>>2]=G;H=E;i=b;return H|0}function Fca(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=c[b+60>>2]|0;f=e;c[e+4>>2]=b;c[e+28>>2]=2;c[e+8>>2]=c[b+128>>2];c[e+12>>2]=c[b+132>>2];c[e+84>>2]=c[b+676>>2];IOa(f);c[e+13920>>2]=5;c[e+14348>>2]=736;c[e+13944>>2]=1;g=b+12|0;h=c[g>>2]|0;a:do{if((c[h+12>>2]|0)==168){c[b+140>>2]=0;c[e+10048>>2]=1;j=168;k=10}else{c[b+140>>2]=Oe[c[b+152>>2]&1023](b,c[h+24>>2]|0)|0;l=c[(c[g>>2]|0)+12>>2]|0;m=e+10048|0;c[m>>2]=1;switch(l|0){case 22:{c[e+44>>2]=1;n=22;break a;break};case 13:case 21:{n=l;break a;break};case 19:{c[e+32>>2]=1;c[e+14092>>2]=5;n=19;break a;break};case 71:case 72:case 153:case 152:case 168:{j=l;k=10;break a;break};case 16:{c[e+32>>2]=1;c[e+14092>>2]=2;n=16;break a;break};case 17:{c[e+32>>2]=1;c[e+14092>>2]=3;n=17;break a;break};case 5:case 20:{c[m>>2]=0;c[b+400>>2]=2;n=l;break a;break};case 15:{c[e+32>>2]=1;c[e+14092>>2]=1;n=15;break a;break};case 18:{c[e+32>>2]=1;c[e+14092>>2]=4;n=18;break a;break};default:{yDb(b,16,2287608,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;o=-38;i=d;return o|0}}}}while(0);if((k|0)==10){c[e+32>>2]=1;c[e+14092>>2]=6;c[b+400>>2]=1;n=j}c[e+48>>2]=n;c[b+712>>2]=R0a(b)|0;do{if((c[b+56>>2]|0)==859189868){if((c[b+100>>2]|0)!=56){break}if((a[c[b+96>>2]|0]|0)!=1){break}c[e+13812>>2]=1}}while(0);b=c[(c[g>>2]|0)+12>>2]|0;do{if(!((b|0)==5|(b|0)==20|(b|0)==13)){g=FOa(f)|0;if((g|0)<0){o=g}else{break}i=d;return o|0}}while(0);Jca(e+11548|0);gIa();o=0;i=d;return o|0}function Gca(a){a=a|0;LOa(c[a+60>>2]|0);return 0}function Hca(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;g=i;i=i+40|0;h=g|0;j=g+8|0;k=g+16|0;l=c[f+24>>2]|0;c[h>>2]=l;c[j>>2]=c[f+28>>2];f=b+60|0;m=c[f>>2]|0;n=m;o=d;p=c[b+88>>2]|0;q=m+60|0;c[q>>2]=p;c[m+64>>2]=c[b+92>>2];r=c[j>>2]|0;if((r|0)==0){if((c[m+13944>>2]|0)!=0){s=0;i=g;return s|0}t=m+9852|0;u=c[t>>2]|0;if((u|0)==0){s=0;i=g;return s|0}v=MCb(o,u|0)|0;if((v|0)<0){s=v;i=g;return s|0}c[t>>2]=0;c[e>>2]=1;s=0;i=g;return s|0}t=m+48|0;do{if((p&65536|0)!=0){v=c[t>>2]|0;if((v|0)==5){w=Dca(m+13744|0,l,r)|0}else if((v|0)==13){w=XMa(m+13744|0,l,r)|0}else if((v|0)==20){w=Dca(m+13744|0,l,r)|0}else{yDb(c[m+4>>2]|0,16,2187920,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;s=-38;i=g;return s|0}if((WRa(m+13744|0,w,h,j)|0)>=0){break}s=c[j>>2]|0;i=g;return s|0}}while(0);w=m+14012|0;r=m+14020|0;l=m+14120|0;p=l;v=m+14132|0;u=m+14136|0;y=m+14124|0;z=m+14128|0;A=m+96|0;B=m+9856|0;C=m+156|0;D=m+14092|0;E=m+8|0;F=b+128|0;G=m+12|0;H=b+132|0;I=m+4|0;J=m+13944|0;K=b+176|0;L=b+48|0;M=l;l=m+108|0;N=k|0;O=k+12|0;P=k+16|0;Q=k+4|0;R=k+8|0;S=m+44|0;T=m+14016|0;while(1){U=c[r>>2]|0;a:do{if((c[w>>2]|0)==0){V=25}else{if((U|0)==0){V=26;break}W=(c[j>>2]|0)-3|0;if((W|0)<=0){V=27;break}X=c[h>>2]|0;Y=0;b:while(1){Z=Y+1|0;do{if((a[X+Y|0]|0)==0){if((a[X+Z|0]|0)!=0){break}if((a[X+(Y+2)|0]|0)==1){break b}}}while(0);if((Z|0)<(W|0)){Y=Z}else{V=25;break a}}if(!((a[X+(Y+3)|0]|0)==-80)){V=25;break}yDb(c[I>>2]|0,24,2110704,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;c[r>>2]=0;V=26}}while(0);if((V|0)==25){V=0;if((U|0)==0){V=26}else{V=27}}do{if((V|0)==26){V=0;_=c[j>>2]|0;V=30}else if((V|0)==27){V=0;if((c[w>>2]|0)==0){W=c[j>>2]|0;if((W|0)>=20){_=W;V=30;break}}W=c[T>>2]|0;$=U>>>0>268435455>>>0?-8:U<<3;aa=$>>>0>2147483639>>>0|(W|0)==0;ca=aa?0:W;W=aa?0:$;c[p>>2]=ca;c[v>>2]=W;c[u>>2]=W+8;da=aa?-1094995529:0;ea=ca+(W>>3)|0}}while(0);if((V|0)==30){V=0;U=c[h>>2]|0;W=_>>>0>268435455>>>0?-8:_<<3;ca=W>>>0>2147483639>>>0|(U|0)==0;aa=ca?0:U;U=ca?0:W;c[p>>2]=aa;c[v>>2]=U;c[u>>2]=U+8;da=ca?-1094995529:0;ea=aa+(U>>3)|0}c[y>>2]=ea;c[z>>2]=0;c[r>>2]=0;if((da|0)<0){s=da;V=161;break}if((c[A>>2]|0)==0){U=FOa(n)|0;if((U|0)<0){s=U;V=161;break}}U=c[B>>2]|0;if((U|0)==0){V=36}else{if((c[U>>2]|0)!=0){V=36}}if((V|0)==36){V=0;U=QOa(n,0)|0;if((U|0)<0){s=U;V=161;break}c[B>>2]=(c[C>>2]|0)+(U*2224|0)}U=c[D>>2]|0;do{if((U|0)==0){if((c[L>>2]|0)==13){aa=c[I>>2]|0;ca=c[aa+100>>2]|0;do{if((ca|0)!=0){if((c[l>>2]|0)!=0){break}W=c[aa+96>>2]|0;$=ca>>>0>268435455>>>0?-8:ca<<3;fa=$>>>0>2147483639>>>0|(W|0)==0;ga=fa?0:W;W=fa?0:$;c[N>>2]=ga;c[O>>2]=W;c[P>>2]=W+8;c[Q>>2]=ga+(W>>3);c[R>>2]=0;if(fa){break}dNa(c[f>>2]|0,k)|0}}while(0);ha=dNa(c[f>>2]|0,M)|0;break}else{if((c[t>>2]|0)==21){ha=DHa(n)|0;break}if((c[S>>2]|0)==0){ha=rIa(n)|0;break}else{ha=eba(n)|0;break}}}else if((U|0)==5){ha=Vcb(n)|0}else{ha=VPa(n)|0}}while(0);U=(ha|0)<0;ca=(ha|0)==100;do{if(U|ca){if((c[E>>2]|0)==(c[F>>2]|0)){if((c[G>>2]|0)==(c[H>>2]|0)){break}}yDb(c[I>>2]|0,24,2052224,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;c[E>>2]=c[F>>2];c[G>>2]=c[H>>2]}}while(0);if(ca){V=57;break}if(U){V=63;break}c[K>>2]=(c[J>>2]|0)==0;if((c[L>>2]|0)!=13){V=66;break}if((cNa(b)|0)!=1){V=66;break}}if((V|0)==57){K=c[j>>2]|0;S=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=K;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=K;i=g;return s|0}if((c[q>>2]&65536|0)==0){M=(S|0)==0?1:S;s=(M+10|0)>(K|0)?K:M;i=g;return s|0}else{M=S-(c[m+13752>>2]|0)|0;s=(M|0)<0?0:M;i=g;return s|0}}else if((V|0)==63){yDb(c[I>>2]|0,16,2006832,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;s=ha;i=g;return s|0}else if((V|0)==66){ha=c[E>>2]|0;E=c[G>>2]|0;do{if((ha|0)==(c[F>>2]|0)){if((E|0)!=(c[H>>2]|0)){V=69;break}if((c[m+14420>>2]|0)!=0){V=69}}else{V=69}}while(0);do{if((V|0)==69){c[m+14420>>2]=0;H=V$a(b,ha,E)|0;if((H|0)<0){s=H;i=g;return s|0}H=GOa(n)|0;if((H|0)==0){break}else{s=H}i=g;return s|0}}while(0);E=c[t>>2]|0;if((E|0)==5|(E|0)==20|(E|0)==21){c[m+13784>>2]=Cca(n)|0}E=m+9992|0;t=c[E>>2]|0;c[m+7712>>2]=t;ha=(t|0)==1;c[m+7708>>2]=ha&1;H=m+9848|0;do{if((c[H>>2]|0)==0){if((t|0)!=3){if((c[m+10008>>2]|0)==0){break}}F=c[j>>2]|0;G=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=F;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=F;i=g;return s|0}if((c[q>>2]&65536|0)==0){x=(G|0)==0?1:G;s=(x+10|0)>(F|0)?F:x;i=g;return s|0}else{x=G-(c[m+13752>>2]|0)|0;s=(x|0)<0?0:x;i=g;return s|0}}}while(0);x=c[b+856>>2]|0;do{if((x|0)>7){if((t|0)!=3){if((x|0)<=31){break}if(!((x|0)>47|ha^1)){break}}G=c[j>>2]|0;F=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=G;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=G;i=g;return s|0}if((c[q>>2]&65536|0)==0){M=(F|0)==0?1:F;s=(M+10|0)>(G|0)?G:M;i=g;return s|0}else{M=F-(c[m+13752>>2]|0)|0;s=(M|0)<0?0:M;i=g;return s|0}}}while(0);ha=m+13736|0;do{if((c[ha>>2]|0)!=0){if((t|0)!=3){c[ha>>2]=0;break}x=c[j>>2]|0;M=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=x;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=x;i=g;return s|0}if((c[q>>2]&65536|0)==0){F=(M|0)==0?1:M;s=(F+10|0)>(x|0)?x:F;i=g;return s|0}else{F=M-(c[m+13752>>2]|0)|0;s=(F|0)<0?0:F;i=g;return s|0}}}while(0);if((c[m+12472>>2]|0)==0|(t|0)==3){c[m+12452>>2]=m+10680;c[m+12456>>2]=m+10808}else{c[m+12452>>2]=m+10936;c[m+12456>>2]=m+10808}t=ROa(n,b)|0;if((t|0)<0){s=t;i=g;return s|0}ha=b+712|0;do{if((c[w>>2]|0)==0){if((c[ha>>2]|0)!=0){break}X0a(b)}}while(0);F=c[ha>>2]|0;do{if((F|0)==0){ia=t}else{M=c[p>>2]|0;x=ze[c[F+24>>2]&511](b,M,(c[y>>2]|0)-M|0)|0;if((x|0)<0){s=x}else{ia=x;break}i=g;return s|0}}while(0);ePa(n);do{if((c[D>>2]|0)==5){y=Wcb(n)|0;if((y|0)<0){s=y;i=g;return s|0}else{if((y|0)==1){ja=1;ka=0;break}else{la=y;V=110;break}}}else{la=ia;V=110}}while(0);do{if((V|0)==110){ia=m+12476|0;c[ia>>2]=0;y=m+12480|0;c[y>>2]=0;F=Ica(n)|0;p=m+14080|0;t=c[y>>2]|0;x=m+120|0;c:do{if((t|0)<(c[x>>2]|0)){M=m+116|0;G=m+14460|0;S=m+32|0;K=F;f=t;while(1){do{if((c[D>>2]|0)==0){k=c[ia>>2]|0;if((iIa(n)|0)<0){ma=K;break c}R=c[M>>2]|0;Q=(ba(R,f)|0)+k|0;k=ba(c[y>>2]|0,R)|0;if((Q|0)>=(k+(c[ia>>2]|0)|0)){break}c[G>>2]=1}else{k=c[p>>2]|0;if((k|0)==0){ma=K;break c}if((c[ia>>2]|0)!=0){ma=K;break c}if(((f|0)%(k|0)|0|0)!=0){ma=K;break c}if(((c[v>>2]|0)-(c[z>>2]|0)|0)<0){ma=K;break c}}}while(0);do{if((c[D>>2]|0)<4){if((c[S>>2]|0)==0){break}TMa(n)}}while(0);Z=(Ica(n)|0)<0;k=Z?-1094995529:K;Z=c[y>>2]|0;if((Z|0)<(c[x>>2]|0)){K=k;f=Z}else{ma=k;break}}}else{ma=F}}while(0);F=c[D>>2]|0;if(!((F|0)!=0&(F|0)<4)){ja=la;ka=ma;break}if((c[E>>2]|0)!=1){ja=la;ka=ma;break}if((WPa(n,c[j>>2]|0)|0)>=0){ja=la;ka=ma;break}a[(c[m+14464>>2]|0)+((c[m+144>>2]|0)-1)|0]=14;ja=la;ka=ma}}while(0);Mkb(m+14424|0);ma=c[ha>>2]|0;do{if((ma|0)==0){na=ja}else{la=re[c[ma+32>>2]&4095](b)|0;if((la|0)<0){s=la}else{na=la;break}i=g;return s|0}}while(0);SOa(n);if((c[L>>2]|0)==13){fNa(b,c[h>>2]|0,c[j>>2]|0)|0}do{if((c[w>>2]|0)==0){if((c[ha>>2]|0)==0){break}X0a(b)}}while(0);do{if((c[E>>2]|0)==3){V=137}else{if((c[J>>2]|0)!=0){V=137;break}ha=c[H>>2]|0;if((ha|0)==0){oa=na;break}h=MCb(o,ha|0)|0;if((h|0)<0){s=h;i=g;return s|0}else{VOa(n,c[H>>2]|0,o);WOa(n,o,c[H>>2]|0,0)|0;pa=h;V=142;break}}}while(0);do{if((V|0)==137){na=MCb(o,c[B>>2]|0)|0;if((na|0)<0){s=na;i=g;return s|0}else{VOa(n,c[B>>2]|0,o);WOa(n,o,c[B>>2]|0,0)|0;pa=na;V=142;break}}}while(0);do{if((V|0)==142){if((c[H>>2]|0)==0){if((c[J>>2]|0)==0){oa=pa;break}}do{if((c[d+80>>2]|0)==0){B=c[m+88>>2]|0;if(!((B|0)==1448035655|(B|0)==1481590087)){break}SCb(o)|0;B=d+68|0;n=d+72|0;na=c[B>>2]|0;E=c[n>>2]|0;h=c[d+32>>2]|0;ha=E>>1;do{if((ha|0)>0){L=E-1|0;ma=d;if((na|0)>0){qa=0}else{ra=na;sa=E;break}do{ja=ba(L-qa|0,h)|0;la=ba(qa,h)|0;D=0;do{v=c[ma>>2]|0;F=v+(D+ja)|0;x=a[F]|0;y=D+la|0;a[F]=a[v+y|0]|0;a[(c[ma>>2]|0)+y|0]=x;D=D+1|0;}while((D|0)<(na|0));qa=qa+1|0;}while((qa|0)<(ha|0));ra=c[B>>2]|0;sa=c[n>>2]|0}else{ra=na;sa=E}}while(0);E=-ra>>1;na=-E|0;ha=-sa>>1;h=c[d+36>>2]|0;ma=-ha>>1;do{if((ma|0)>0){L=~ha;D=d+4|0;if((E|0)<0){ta=0}else{ua=ra;va=sa;break}do{la=ba(L-ta|0,h)|0;ja=ba(ta,h)|0;x=0;do{y=c[D>>2]|0;v=y+(x+la)|0;F=a[v]|0;ia=x+ja|0;a[v]=a[y+ia|0]|0;a[(c[D>>2]|0)+ia|0]=F;x=x+1|0;}while((x|0)<(na|0));ta=ta+1|0;}while((ta|0)<(ma|0));ua=c[B>>2]|0;va=c[n>>2]|0}else{ua=ra;va=sa}}while(0);n=-ua>>1;B=-n|0;ma=-va>>1;na=c[d+40>>2]|0;h=-ma>>1;if((h|0)<=0){break}E=~ma;ma=d+8|0;if((n|0)<0){wa=0}else{break}do{n=ba(E-wa|0,na)|0;ha=ba(wa,na)|0;D=0;do{L=c[ma>>2]|0;x=L+(D+n)|0;ja=a[x]|0;la=D+ha|0;a[x]=a[L+la|0]|0;a[(c[ma>>2]|0)+la|0]=ja;D=D+1|0;}while((D|0)<(B|0));wa=wa+1|0;}while((wa|0)<(h|0))}}while(0);c[e>>2]=1;oa=pa}}while(0);do{if((ka|0)<0){if((c[b+696>>2]&8|0)==0){break}else{s=oa}i=g;return s|0}}while(0);oa=c[j>>2]|0;j=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=oa;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=oa;i=g;return s|0}if((c[q>>2]&65536|0)==0){q=(j|0)==0?1:j;s=(q+10|0)>(oa|0)?oa:q;i=g;return s|0}else{q=j-(c[m+13752>>2]|0)|0;s=(q|0)<0?0:q;i=g;return s|0}}else if((V|0)==161){i=g;return s|0}return 0}function Ica(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;b=i;e=a+13940|0;f=(c[e>>2]|0)!=0?18:127;g=a+4|0;h=16>>>((c[(c[g>>2]|0)+800>>2]|0)>>>0);j=a+14120|0;k=a+13712|0;l=j;c[k>>2]=c[l>>2];c[k+4>>2]=c[l+4>>2];c[k+8>>2]=c[l+8>>2];c[k+12>>2]=c[l+12>>2];c[k+16>>2]=c[l+16>>2];l=a+14084|0;c[l>>2]=1;k=a+12476|0;m=a+13704|0;c[m>>2]=c[k>>2];n=a+12480|0;o=a+13708|0;c[o>>2]=c[n>>2];p=a+9960|0;cPa(a,c[p>>2]|0);q=c[g>>2]|0;r=c[q+712>>2]|0;if((r|0)!=0){s=(c[j>>2]|0)+((c[a+14128>>2]|0)/8|0)|0;t=ze[c[r+28>>2]&511](q,s,(c[a+14124>>2]|0)-s|0)|0;c[n>>2]=c[a+120>>2];u=t;i=b;return u|0}if((c[e>>2]|0)!=0){e=c[p>>2]|0;do{if((c[a+48>>2]|0)==13){p=bNa(c[q+60>>2]|0)|0;if((p|0)<0){u=p}else{break}i=b;return u|0}}while(0);c[l>>2]=1;c[k>>2]=c[m>>2];c[n>>2]=c[o>>2];cPa(a,e)}e=c[n>>2]|0;q=a+120|0;a:do{if((e|0)<(c[q>>2]|0)){p=a+14092|0;t=a+116|0;s=a+12496|0;r=a+12500|0;v=a+12504|0;w=a+12508|0;x=a+12512|0;y=a+12516|0;z=a+12544|0;A=a+12548|0;B=a+12552|0;C=a+11736|0;D=a+11740|0;E=a+14348|0;F=a+14340|0;G=a+9992|0;H=a+13836|0;I=a+14080|0;J=a+9868|0;K=a+9864|0;L=a+9860|0;M=e;b:while(1){N=c[p>>2]|0;do{if((N|0)!=0){O=c[o>>2]|0;if(((c[I>>2]|0)+O|0)==(M|0)){P=11;break b}if((N|0)!=1){break}c[J>>2]=128;c[K>>2]=128;c[L>>2]=128}}while(0);$Oa(a);N=c[k>>2]|0;if((N|0)<(c[t>>2]|0)){Q=N;do{N=8>>>((c[(c[g>>2]|0)+800>>2]|0)>>>0);c[s>>2]=(c[s>>2]|0)+2;c[r>>2]=(c[r>>2]|0)+2;c[v>>2]=(c[v>>2]|0)+2;c[w>>2]=(c[w>>2]|0)+2;c[x>>2]=(c[x>>2]|0)+1;c[y>>2]=(c[y>>2]|0)+1;c[z>>2]=(c[z>>2]|0)+(N<<1);c[A>>2]=(c[A>>2]|0)+N;c[B>>2]=(c[B>>2]|0)+N;do{if((c[m>>2]|0)==(Q|0)){if(((c[o>>2]|0)+1|0)!=(c[n>>2]|0)){break}c[l>>2]=0}}while(0);c[C>>2]=1;c[D>>2]=0;R=Oe[c[E>>2]&1023](a,c[F>>2]|0)|0;if((c[G>>2]|0)!=3){xca(a)}if((R|0)<0){break b}YOa(a,c[F>>2]|0);if((c[H>>2]|0)!=0){zca(a)}Q=(c[k>>2]|0)+1|0;c[k>>2]=Q;}while((Q|0)<(c[t>>2]|0))}_Oa(a,ba(c[n>>2]|0,h)|0,h);dPa(a);c[k>>2]=0;Q=(c[n>>2]|0)+1|0;c[n>>2]=Q;if((Q|0)<(c[q>>2]|0)){M=Q}else{S=Q;break a}}if((P|0)==11){Lkb(a+14424|0,c[m>>2]|0,O,(c[k>>2]|0)-1|0,M,112);u=0;i=b;return u|0}G=(ba(c[a+124>>2]|0,c[n>>2]|0)|0)+(c[k>>2]|0)|0;if(!((R|0)==-2)){E=c[g>>2]|0;if((R|0)==-3){yDb(E,16,2332768,(T=i,i=i+8|0,c[T>>2]=G,T)|0);i=T;Lkb(a+14424|0,c[m>>2]|0,c[o>>2]|0,(c[k>>2]|0)+1|0,c[n>>2]|0,f&112);u=-1094995529;i=b;return u|0}else{yDb(E,16,2308392,(T=i,i=i+8|0,c[T>>2]=G,T)|0);i=T;Lkb(a+14424|0,c[m>>2]|0,c[o>>2]|0,c[k>>2]|0,c[n>>2]|0,f&14);u=-1094995529;i=b;return u|0}}YOa(a,c[F>>2]|0);if((c[H>>2]|0)!=0){zca(a)}Lkb(a+14424|0,c[m>>2]|0,c[o>>2]|0,c[k>>2]|0,c[n>>2]|0,f&112);G=a+14008|0;c[G>>2]=(c[G>>2]|0)-1;G=(c[k>>2]|0)+1|0;c[k>>2]=G;if((G|0)<(c[t>>2]|0)){u=0;i=b;return u|0}c[k>>2]=0;_Oa(a,ba(c[n>>2]|0,h)|0,h);dPa(a);c[n>>2]=(c[n>>2]|0)+1;u=0;i=b;return u|0}else{S=e}}while(0);e=c[a+84>>2]|0;c:do{if((c[a+48>>2]|0)==13){if((e&1|0)==0){break}h=c[a+14128>>2]|0;do{if(((c[a+14132>>2]|0)-h|0)>47){R=(c[j>>2]|0)+(h>>>3)|0;if(((fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(h&7)&-256|0)!=4198400){break}if((c[a+13936>>2]|0)!=0){break}R=a+14008|0;c[R>>2]=(c[R>>2]|0)+32}}while(0);h=c[a+14128>>2]|0;t=c[a+14132>>2]|0;H=t-h|0;if(!(H>>>0<137>>>0)){break}if((c[a+13936>>2]|0)!=0){break}if((t|0)==(h|0)){t=a+14008|0;c[t>>2]=(c[t>>2]|0)+16;break}if((H|0)==1){break}t=(c[j>>2]|0)+(h>>>3)|0;F=h&7;M=((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<F>>>24|127>>>((F^7)>>>0)|0)==127;if(M&(H|0)<9){F=a+14008|0;c[F>>2]=(c[F>>2]|0)-1;break}do{if(M){if(!((h&8|0)==0&(H|0)<17)){break}F=a+14008|0;c[F>>2]=(c[F>>2]|0)+4;break c}}while(0);H=a+14008|0;c[H>>2]=(c[H>>2]|0)+1}}while(0);H=a+84|0;d:do{if((e&1|0)==0){U=e}else{do{if((c[a+14008>>2]|0)>-2){if((c[a+13936>>2]|0)!=0){break}h=e|16;c[H>>2]=h;U=h;break d}}while(0);h=e&-17;c[H>>2]=h;U=h}}while(0);do{if((c[a+14092>>2]|0)==0){H=U&16;if((H|0)!=0){e=c[a+14128>>2]|0;V=7;W=(c[a+14132>>2]|0)-e|0;X=e;Y=H;break}H=c[g>>2]|0;e=c[a+14128>>2]|0;h=(c[a+14132>>2]|0)-e|0;M=(c[j>>2]|0)+(e>>>3)|0;F=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(e&7)>>>8;e=c[a+14008>>2]|0;yDb(H,16,2258128,(T=i,i=i+24|0,c[T>>2]=h,c[T+8>>2]=F,c[T+16>>2]=e,T)|0);i=T;Lkb(a+14424|0,c[m>>2]|0,c[o>>2]|0,c[k>>2]|0,c[n>>2]|0,f&112);u=-1094995529;i=b;return u|0}else{e=c[a+14128>>2]|0;V=(c[a+9992>>2]|0)==1?24:7;W=(c[a+14132>>2]|0)-e|0;X=e;Y=U&16}}while(0);U=(Y|0)==0;do{if(U){P=62}else{if((c[a+13740>>2]&262148|0)==0){P=62;break}Z=V+48|0}}while(0);if((P|0)==62){Z=U?V:V|1073741824}if((W|0)>(Z|0)){Z=c[g>>2]|0;V=(c[j>>2]|0)+(X>>>3)|0;j=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(X&7)>>>8;yDb(Z,16,2289752,(T=i,i=i+16|0,c[T>>2]=W,c[T+8>>2]=j,T)|0);i=T;u=0;i=b;return u|0}if((W|0)<0){yDb(c[g>>2]|0,16,2273816,(T=i,i=i+8|0,c[T>>2]=-W,T)|0);i=T;u=0;i=b;return u|0}else{Lkb(a+14424|0,c[m>>2]|0,c[o>>2]|0,(c[k>>2]|0)-1|0,S,112);u=0;i=b;return u|0}return 0}function Jca(a){a=a|0;c[a>>2]=1428;c[a+4>>2]=278;return}function Kca(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d[1210688+e|0]|0;e=f*-2|0;g=-f|0;h=f<<1;i=0;do{j=ba(i,c)|0;k=b+(j-2)|0;l=d[k]|0;m=b+(j-1)|0;n=d[m]|0;o=b+j|0;p=d[o]|0;q=b+(j+1)|0;j=d[q]|0;r=l-j|0;s=(r+(p-n<<2)|0)/8|0;do{if((s|0)<(e|0)){t=0}else{if((s|0)<(g|0)){t=e-s|0;break}if((s|0)<(f|0)){t=s;break}t=(s|0)<(h|0)?h-s|0:0}}while(0);s=t+n|0;u=p-t|0;if((s&256|0)==0){v=s&255}else{v=(s>>31^255)&255}if((u&256|0)==0){w=u&255}else{w=(u>>31^255)&255}a[m]=v;a[o]=w;u=((t|0)>-1?t:-t|0)>>1;s=(r|0)/4|0;x=-u|0;if((s|0)<(x|0)){y=x}else{y=(s|0)>(u|0)?u:s}a[k]=l-y;a[q]=y+j;i=i+1|0;}while((i|0)<8);return}function Lca(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=d[1210688+e|0]|0;e=c<<1;g=f*-2|0;h=-f|0;i=f<<1;j=0;do{k=b+(j-e)|0;l=d[k]|0;m=b+(j-c)|0;n=d[m]|0;o=b+j|0;p=d[o]|0;q=b+(j+c)|0;r=d[q]|0;s=l-r|0;t=(s+(p-n<<2)|0)/8|0;do{if((t|0)<(g|0)){u=0}else{if((t|0)<(h|0)){u=g-t|0;break}if((t|0)<(f|0)){u=t;break}u=(t|0)<(i|0)?i-t|0:0}}while(0);t=u+n|0;v=p-u|0;if((t&256|0)==0){w=t&255}else{w=(t>>31^255)&255}if((v&256|0)==0){x=v&255}else{x=(v>>31^255)&255}a[m]=w;a[o]=x;v=((u|0)>-1?u:-u|0)>>1;t=(s|0)/4|0;y=-v|0;if((t|0)<(y|0)){z=y}else{z=(t|0)>(v|0)?v:t}a[k]=l-z;a[q]=z+r;j=j+1|0;}while((j|0)<8);return}function Mca(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;if((b|0)==0){d=0;return d|0}d=c[b+6788>>2]|0;return d|0}function Nca(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+32|0;g=f|0;h=c[a>>2]|0;j=a+199440|0;k=(c[j>>2]|0)==0?0:j;j=d[(bFb(c[h+140>>2]|0)|0)+6|0]|0;l=c[a+177100>>2]|0;do{if((l|0)==3){m=(c[h+124>>2]|0)-b|0;n=b;o=(m|0)<(e|0)?m:e}else{m=e<<1;p=b<<1;q=(c[h+124>>2]|0)-p|0;r=(m|0)>(q|0)?q:m;if((c[a+177104>>2]|0)==0){n=p;o=r;break}if((c[h+288>>2]&2|0)!=0){n=p;o=r;break}i=f;return}}while(0);b=h+148|0;if((c[b>>2]|0)==0){i=f;return}e=a+2528|0;do{if((c[a+2616>>2]|0)==3){s=e}else{if((c[a+4808>>2]|0)!=0){s=e;break}if((c[h+288>>2]&1|0)!=0){s=e;break}if((k|0)==0){i=f;return}else{s=k|0;break}}}while(0);k=g|0;c[k>>2]=ba(c[s+32>>2]|0,n)|0;e=ba(c[s+36>>2]|0,n>>j)|0;c[g+8>>2]=e;c[g+4>>2]=e;TGb(g+12|0,0,20)|0;Se[c[b>>2]&511](h,s,k,n,l,o);i=f;return}function Oca(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;a:do{if((c[b+5164>>2]&32768|0)==0){e=b+4900|0;f=a[e]|0;g=a[1208448+f|0]|0;do{if((249>>>(f>>>0)&1|0)==0){if((253>>>(f>>>0)&1|0)!=0){a[e]=g}h=b+4901|0;j=a[h]|0;k=a[1208448+j|0]|0;if((249>>>(j>>>0)&1|0)!=0){l=k;break}if((253>>>(j>>>0)&1|0)!=0){a[h]=k}k=b+4902|0;h=a[k]|0;j=a[1208448+h|0]|0;if((249>>>(h>>>0)&1|0)!=0){l=j;break}if((253>>>(h>>>0)&1|0)!=0){a[k]=j}j=b+4903|0;k=a[j]|0;h=a[1208448+k|0]|0;if((249>>>(k>>>0)&1|0)!=0){l=h;break}if((253>>>(k>>>0)&1|0)==0){break a}a[j]=h;break a}else{l=g}}while(0);g=c[b+427376>>2]|0;e=c[b+427380>>2]|0;yDb(c[b>>2]|0,16,2286256,(m=i,i=i+24|0,c[m>>2]=l<<24>>24,c[m+8>>2]=g,c[m+16>>2]=e,m)|0);i=m;n=-1094995529;i=d;return n|0}}while(0);l=c[b+5172>>2]|0;if((l&34952|0)==34952){n=0;i=d;return n|0}do{if((l&32768|0)==0){e=b+4900|0;g=a[e]|0;f=a[1208464+g|0]|0;if((370>>>(g>>>0)&1|0)!=0){o=f;break}if((886>>>(g>>>0)&1|0)==0){p=13;break}a[e]=f;p=13}else{p=13}}while(0);b:do{if((p|0)==13){do{if((l&8192|0)==0){f=b+4908|0;e=a[f]|0;g=a[1208464+e|0]|0;if((370>>>(e>>>0)&1|0)!=0){o=g;break b}if((886>>>(e>>>0)&1|0)==0){break}a[f]=g}}while(0);do{if((l&128|0)==0){g=b+4916|0;f=a[g]|0;e=a[1208464+f|0]|0;if((370>>>(f>>>0)&1|0)!=0){o=e;break b}if((886>>>(f>>>0)&1|0)==0){break}a[g]=e}}while(0);if((l&32|0)!=0){n=0;i=d;return n|0}e=b+4924|0;g=a[e]|0;f=a[1208464+g|0]|0;if((370>>>(g>>>0)&1|0)!=0){o=f;break}if((886>>>(g>>>0)&1|0)==0){n=0;i=d;return n|0}a[e]=f;n=0;i=d;return n|0}}while(0);l=c[b+427376>>2]|0;p=c[b+427380>>2]|0;yDb(c[b>>2]|0,16,2324616,(m=i,i=i+24|0,c[m>>2]=o<<24>>24,c[m+8>>2]=l,c[m+16>>2]=p,m)|0);i=m;n=-1094995529;i=d;return n|0}function Pca(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;if(d>>>0>3>>>0){g=c[b+427380>>2]|0;yDb(c[b>>2]|0,16,2187856,(h=i,i=i+16|0,c[h>>2]=c[b+427376>>2],c[h+8>>2]=g,h)|0);i=h;j=-1094995529;i=f;return j|0}do{if((c[b+5164>>2]&32768|0)==0){if(!((d-2|0)>>>0<2>>>0)){k=a[1208432+d|0]|0;break}g=c[b+427380>>2]|0;yDb(c[b>>2]|0,16,2110544,(h=i,i=i+16|0,c[h>>2]=c[b+427376>>2],c[h+8>>2]=g,h)|0);i=h;j=-1094995529;i=f;return j|0}else{k=d}}while(0);d=c[b+5172>>2]|0;g=d&32896;if((g|0)==32896){j=k;i=f;return j|0}if(!((e|0)==0|(g|0)==0)){j=8-(d>>>15&1)+(((k|0)==4)<<1)|0;i=f;return j|0}if(!((k|0)==3|(k|0)==1)){j=a[1208440+k|0]|0;i=f;return j|0}k=c[b+427380>>2]|0;yDb(c[b>>2]|0,16,2052112,(h=i,i=i+16|0,c[h>>2]=c[b+427376>>2],c[h+8>>2]=k,h)|0);i=h;j=-1094995529;i=f;return j|0}function Qca(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;c[b+427432>>2]=(d[e]|0)>>>5;i=a[e]&31;c[b+427436>>2]=i;j=e+1|0;k=h-1|0;a:do{if((k|0)>1){h=0;b:while(1){do{if((a[e+(h+1)|0]|0)==0){if((h|0)>0){l=(((a[e+h|0]|0)==0)<<31>>31)+h|0}else{l=h}m=l+2|0;if((m|0)>=(k|0)){n=l;break}if((a[e+m|0]|0)!=0){n=l;break}o=a[e+(l+3)|0]|0;if((o&255)>>>0<4>>>0){break b}else{n=l}}else{n=h}}while(0);m=n+2|0;if((n+3|0)<(k|0)){h=m}else{p=m;q=k;break a}}p=l;q=o<<24>>24==3?k:l}else{p=0;q=k}}while(0);k=(i|0)==4|0;i=b+427440+(k<<2)|0;O$a(i,b+427448+(k<<2)|0,q+262144|0);k=c[i>>2]|0;if((k|0)==0){r=0;return r|0}if((p|0)>=(q-1|0)){c[f>>2]=q;c[g>>2]=q+1;if((c[(c[b>>2]|0)+92>>2]&1|0)!=0){r=j;return r|0}UGb(k|0,j|0,q)|0;r=k;return r|0}UGb(k|0,j|0,p)|0;j=p+2|0;c:do{if((j|0)<(q|0)){b=p;i=p;l=j;while(1){o=b+3|0;n=a[e+o|0]|0;h=a[e+(b+1)|0]|0;do{if((n&255)>>>0>3>>>0){a[k+i|0]=h;a[k+(i+1)|0]=a[e+(b+2)|0]|0;s=i+2|0;t=l;u=24}else{if(!(h<<24>>24==0)){s=i;t=b;u=24;break}if((a[e+(b+2)|0]|0)!=0){s=i;t=b;u=24;break}if(!(n<<24>>24==3)){v=i;w=b;break c}a[k+i|0]=0;a[k+(i+1)|0]=0;x=i+2|0;y=o}}while(0);if((u|0)==24){u=0;o=t+1|0;a[k+s|0]=a[e+o|0]|0;x=s+1|0;y=o}o=y+2|0;if((o|0)<(q|0)){b=y;i=x;l=o}else{z=y;A=x;u=15;break}}}else{z=p;A=p;u=15}}while(0);do{if((u|0)==15){if((z|0)>=(q|0)){v=A;w=z;break}p=q+A|0;x=z;y=A;while(1){s=x+1|0;a[k+y|0]=a[e+s|0]|0;if((s|0)<(q|0)){x=s;y=y+1|0}else{break}}v=p-z|0;w=q}}while(0);TGb(k+v|0,0,16)|0;c[f>>2]=v;c[g>>2]=w+1;r=k;return r|0}function Rca(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;d=a+427404|0;e=c[d>>2]|0;f=a+427396|0;g=ba((c[f>>2]|0)+1|0,e)|0;h=a|0;j=c[(c[h>>2]|0)+808>>2]|0;k=ba((j|0)>1?j:1,e<<1)|0;e=k<<3;j=cEb(e)|0;c[a+4928>>2]=j;a:do{if((j|0)!=0|(e|0)==0){l=g*48|0;m=cEb(l)|0;c[a+5304>>2]=m;if(!((m|0)!=0|(l|0)==0)){yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}l=cEb((c[d>>2]|0)+g<<1)|0;m=a+428632|0;c[m>>2]=l;do{if((l|0)==0){if(((c[d>>2]|0)+g&2147483647|0)==0){break}yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break a}}while(0);l=g<<1;o=cEb(l)|0;c[a+426560>>2]=o;if(!((o|0)!=0|(l|0)==0)){yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}l=cEb(g)|0;c[a+426576>>2]=l;o=(g|0)==0;if(!((l|0)!=0|o)){yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}l=k<<4;p=cEb(l)|0;c[a+426584>>2]=p;q=(l|0)==0;if(!((p|0)!=0|q)){yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}p=cEb(l)|0;c[a+426588>>2]=p;if(!((p|0)!=0|q)){yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}q=g<<2;p=cEb(q)|0;c[a+426752>>2]=p;l=(q|0)==0;if(!((p|0)!=0|l)){yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}p=cEb(g)|0;c[a+199432>>2]=p;if(!((p|0)!=0|o)){yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}TGb(c[m>>2]|0,-1|0,(c[d>>2]|0)+g<<1|0)|0;c[a+177072>>2]=(c[m>>2]|0)+((c[d>>2]<<1|1)<<1);o=cEb(q)|0;p=a+6100|0;c[p>>2]=o;if(!((o|0)!=0|l)){yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}o=cEb(q)|0;q=o;c[a+6104>>2]=q;if(!((o|0)!=0|l)){yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}l=c[f>>2]|0;if((l|0)>0){o=a+427400|0;r=a+6108|0;s=0;t=c[o>>2]|0;u=l;while(1){if((t|0)>0){l=c[p>>2]|0;v=0;do{w=(ba(c[d>>2]|0,s)|0)+v|0;c[l+(w<<2)>>2]=(ba(c[r>>2]|0,s)|0)+v<<2;c[q+(w<<2)>>2]=((w|0)%(c[d>>2]<<1|0)|0)<<3;v=v+1|0;x=c[o>>2]|0;}while((v|0)<(x|0));y=x;z=c[f>>2]|0}else{y=t;z=u}v=s+1|0;if((v|0)<(z|0)){s=v;t=y;u=z}else{break}}}if((c[a+177020>>2]|0)==0){Sca(a)}u=a+2520|0;if((c[u>>2]|0)!=0){A=0;i=b;return A|0}t=cEb(80064)|0;s=t;c[u>>2]=s;if((t|0)==0){A=-12;i=b;return A|0}else{B=0;C=s}while(1){KCb(C+(B*2224|0)|0);s=B+1|0;if((s|0)>=36){break}B=s;C=c[u>>2]|0}KCb(a+2528|0);A=0;i=b;return A|0}else{yDb(c[h>>2]|0,16,2006760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}}while(0);Tca(a,1);A=-12;i=b;return A|0}function Sca(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=a+7308|0;e=((c[b>>2]|0)*6|0)+4|0;a:do{if((e|0)>0){f=0;do{g=a+177020+(f<<2)|0;c[g>>2]=a+8060+(f*5632|0);h=a+7396+(f<<4)|0;i=0;while(1){if((i|0)>=(f|0)){j=0;k=4;break}if((PGb(a+7396+(i<<4)|0,h,16)|0)==0){k=8;break}else{i=i+1|0}}if((k|0)==4){while(1){k=0;h=(d[1360440+j|0]|0)+2|0;l=d[549136+j|0]|0;m=0;do{n=m>>2;c[a+8060+(f*5632|0)+(j<<6)+((m<<2&12|n)<<2)>>2]=(ba(d[a+7396+(f<<4)+m|0]|0,d[(n&1)+(m&1)+(1381480+(l*3|0))|0]|0)|0)<<h;m=m+1|0;}while((m|0)<16);m=j+1|0;if((m|0)<(e|0)){j=m;k=4}else{break}}}else if((k|0)==8){k=0;c[g>>2]=a+8060+(i*5632|0)}f=f+1|0;}while((f|0)<6)}else{c[a+177020>>2]=a+8060;f=a+177024|0;c[f>>2]=a+13692;m=a+7412|0;h=0;while(1){if((h|0)>=1){break}if((PGb(a+7396+(h<<4)|0,m,16)|0)==0){k=13;break}else{h=h+1|0}}if((k|0)==13){c[f>>2]=a+8060+(h*5632|0)}m=a+177028|0;c[m>>2]=a+19324;l=a+7428|0;n=0;while(1){if((n|0)>=2){break}if((PGb(a+7396+(n<<4)|0,l,16)|0)==0){k=17;break}else{n=n+1|0}}if((k|0)==17){c[m>>2]=a+8060+(n*5632|0)}l=a+177032|0;c[l>>2]=a+24956;h=a+7444|0;f=0;while(1){if((f|0)>=3){break}if((PGb(a+7396+(f<<4)|0,h,16)|0)==0){k=21;break}else{f=f+1|0}}if((k|0)==21){c[l>>2]=a+8060+(f*5632|0)}h=a+177036|0;c[h>>2]=a+30588;n=a+7460|0;m=0;while(1){if((m|0)>=4){break}if((PGb(a+7396+(m<<4)|0,n,16)|0)==0){k=25;break}else{m=m+1|0}}if((k|0)==25){c[h>>2]=a+8060+(m*5632|0)}n=a+177040|0;c[n>>2]=a+36220;f=a+7476|0;l=0;while(1){if((l|0)>=5){break a}if((PGb(a+7396+(l<<4)|0,f,16)|0)==0){break}else{l=l+1|0}}c[n>>2]=a+8060+(l*5632|0)}}while(0);TGb(a+177044|0,0,24)|0;j=a+7392|0;if((c[j>>2]|0)!=0){e=((c[b>>2]|0)*6|0)+4|0;b=(e|0)>0;f=0;do{m=a+177044+(f<<2)|0;c[m>>2]=a+41852+(f*22528|0);h=a+7492+(f<<6)|0;o=0;while(1){if((o|0)>=(f|0)){k=36;break}if((PGb(a+7492+(o<<6)|0,h,64)|0)==0){k=35;break}else{o=o+1|0}}do{if((k|0)==35){k=0;c[m>>2]=a+41852+(o*22528|0)}else if((k|0)==36){k=0;if(b){p=0}else{break}do{h=d[1360440+p|0]|0;l=d[549136+p|0]|0;n=0;do{c[a+41852+(f*22528|0)+(p<<8)+((n<<3&56|n>>3)<<2)>>2]=(ba(d[a+7492+(f<<6)+n|0]|0,d[(d[1381424+(n>>>1&12|n&3)|0]|0)+(1381440+(l*6|0))|0]|0)|0)<<h;n=n+1|0;}while((n|0)<64);p=p+1|0;}while((p|0)<(e|0))}}while(0);f=f+1|0;}while((f|0)<6)}if((c[a+6140>>2]|0)==0){return}f=c[a+177020>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177024>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177028>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177032>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177036>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177040>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;if((c[j>>2]|0)==0){return}j=c[a+177044>>2]|0;f=0;do{c[j+(f<<2)>>2]=64;f=f+1|0;}while((f|0)<64);f=c[a+177048>>2]|0;j=0;do{c[f+(j<<2)>>2]=64;j=j+1|0;}while((j|0)<64);j=c[a+177052>>2]|0;f=0;do{c[j+(f<<2)>>2]=64;f=f+1|0;}while((f|0)<64);f=c[a+177056>>2]|0;j=0;do{c[f+(j<<2)>>2]=64;j=j+1|0;}while((j|0)<64);j=c[a+177060>>2]|0;f=0;do{c[j+(f<<2)>>2]=64;f=f+1|0;}while((f|0)<64);f=c[a+177064>>2]|0;a=0;do{c[f+(a<<2)>>2]=64;a=a+1|0;}while((a|0)<64);return}function Tca(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;$Db(a+4928|0);$Db(a+426576|0);$Db(a+426560|0);$Db(a+426584|0);$Db(a+426588|0);$Db(a+426752|0);$Db(a+5304|0);$Db(a+428632|0);c[a+177072>>2]=0;$Db(a+199432|0);$Db(a+6100|0);$Db(a+6104|0);bBb(a+572692|0);bBb(a+572696|0);bBb(a+572700|0);bBb(a+572704|0);d=(b|0)!=0;b=a+2520|0;e=c[b>>2]|0;f=(e|0)==0;do{if(d){if(f){c[a+2524>>2]=0;g=0;h=11;break}else{i=0;j=e}while(1){ida(a,j+(i*2224|0)|0);k=i+1|0;if((k|0)>=36){break}i=k;j=c[b>>2]|0}$Db(b);h=10}else{if(f){c[a+2524>>2]=0;l=0;h=16;break}else{k=0;while(1){c[e+(k*2224|0)+2188>>2]=1;m=k+1|0;if((m|0)<36){k=m}else{h=10;break}}}}}while(0);if((h|0)==10){c[a+2524>>2]=0;if(d){g=0;h=11}else{l=0;h=16}}if((h|0)==11){a:while(1){h=0;d=a+572248+(g<<2)|0;e=c[d>>2]|0;do{if((e|0)!=0){$Db(e+5180|0);$Db(e+5176|0);$Db(e+572636|0);$Db(e+572684|0);$Db(e+572688|0);$Db(e+768|0);$Db(e+2360|0);$Db(e+2392|0);$Db(e+2396|0);$Db(e+2416|0);$Db(e+2412|0);$Db(e+427444|0);$Db(e+427440|0);c[e+427448>>2]=0;c[e+427452>>2]=0;if((g|0)==0){g=g+1|0;h=11;continue a}else{$Db(d);break}}}while(0);d=g+1|0;if((d|0)<32){g=d;h=11}else{break}}return}else if((h|0)==16){b:while(1){h=0;g=a+572248+(l<<2)|0;d=c[g>>2]|0;do{if((d|0)!=0){$Db(d+5180|0);$Db(d+5176|0);$Db(d+572636|0);$Db(d+572684|0);$Db(d+572688|0);$Db(d+768|0);$Db(d+2360|0);$Db(d+2392|0);$Db(d+2396|0);$Db(d+2416|0);$Db(d+2412|0);if((l|0)==0){l=l+1|0;h=16;continue b}else{$Db(g);break}}}while(0);g=l+1|0;if((g|0)<32){l=g;h=16}else{break}}return}}function Uca(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=c[b>>2]|0;if((e|0)==0|(f|0)<1){j=-1;i=g;return j|0}k=b+427456|0;do{if((a[e]|0)==1){c[k>>2]=1;if((f|0)<7){yDb(h,16,1968896,(l=i,i=i+8|0,c[l>>2]=f,l)|0);i=l;j=-1094995529;i=g;return j|0}m=b+427460|0;c[m>>2]=2;n=a[e+5|0]&31;o=e+6|0;a:do{if((n|0)==0){p=o}else{q=e+f|0;r=0;s=o;while(1){t=s;u=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)+2|0;if((u|0)>(q-s|0)){j=-1094995529;v=20;break}w=Vca(b,s,u,1)|0;if((w|0)<0){break}t=s+u|0;u=r+1|0;if((u|0)<(n|0)){r=u;s=t}else{p=t;break a}}if((v|0)==20){i=g;return j|0}yDb(h,16,1940360,(l=i,i=i+8|0,c[l>>2]=r,l)|0);i=l;j=w;i=g;return j|0}}while(0);n=a[p]|0;o=n&255;b:do{if(!(n<<24>>24==0)){s=e+f|0;q=0;t=p+1|0;while(1){u=t;x=((de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)+2|0;if((x|0)>(s-t|0)){j=-1094995529;v=20;break}y=Vca(b,t,x,1)|0;if((y|0)<0){break}u=q+1|0;if((u|0)<(o|0)){q=u;t=t+x|0}else{break b}}if((v|0)==20){i=g;return j|0}yDb(h,16,1916144,(l=i,i=i+8|0,c[l>>2]=q,l)|0);i=l;j=y;i=g;return j|0}}while(0);c[m>>2]=(a[e+4|0]&3)+1}else{c[k>>2]=0;o=Vca(b,e,f,1)|0;if((o|0)<0){j=o}else{break}i=g;return j|0}}while(0);j=f;i=g;return j|0}function Vca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=b|0;m=c[l>>2]|0;n=m+816|0;o=c[n>>2]&1^1;p=b+427436|0;c[p>>2]=0;q=b+572384|0;r=c[q>>2]|0;if((r|0)==0){c[q>>2]=1;s=1}else{s=r}r=b+572380|0;c[r>>2]=s;s=m+92|0;if((c[s>>2]&32768|0)==0){c[b+572376>>2]=0;if((c[b+177104>>2]|0)==0){c[b+2524>>2]=0}mea(b)}q=b+427460|0;a:do{if((c[q>>2]|0)==4){do{if((f|0)>8){t=e;if((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)!=16777216){break}t=e+5|0;if(!((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)>>>0>f>>>0)){break}c[b+427456>>2]=0;break a}}while(0);if((f|0)<=3){break}t=e;u=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;if(u>>>0<2>>>0|u>>>0>f>>>0){break}c[b+427456>>2]=1}}while(0);u=b+427456|0;t=b+4820|0;v=m+856|0;w=b+427432|0;x=(g|0)==0;g=m;y=b+428676|0;z=b+428672|0;A=b+428660|0;B=b+428664|0;C=b+571360|0;D=b+571364|0;E=b+571368|0;F=b+571372|0;G=b+571376|0;H=b+571380|0;I=b+571384|0;J=b+571388|0;K=b+571392|0;L=b+571396|0;M=b+571400|0;N=b+571404|0;O=b+571408|0;P=b+571412|0;Q=b+571416|0;R=b+571420|0;S=b+572444|0;T=b+428656|0;U=b+572476|0;V=b+6144|0;W=b+572448|0;X=b+2524|0;Y=b+572480|0;Z=m+88|0;_=b+572376|0;$=m+712|0;aa=b+4800|0;ba=b+1088|0;ca=b+1100|0;da=b+1104|0;ea=b+1092|0;fa=b+1096|0;ga=b+8056|0;ha=b+199428|0;ia=b+199424|0;ja=b+199420|0;ka=o;o=0;la=0;ma=0;na=0;b:while(1){oa=(ka|0)==0;pa=na;qa=ma;ra=la;sa=0;ta=o;ua=(c[u>>2]|0)!=0?0:f;va=0;wa=0;c:while(1){if((wa|0)<(ua|0)){xa=wa+3|0;d:do{if((xa|0)<(ua|0)){ya=wa;za=xa;while(1){Aa=ya+1|0;do{if((a[e+ya|0]|0)==0){if((a[e+Aa|0]|0)!=0){break}if((a[e+(ya+2)|0]|0)==1){Ba=za;Ca=1;break d}}}while(0);Da=ya+4|0;if((Da|0)<(ua|0)){ya=Aa;za=Da}else{Ba=Da;Ca=0;break}}}else{Ba=xa;Ca=0}}while(0);if((Ba|0)>=(f|0)){Ea=f;break}if(Ca){Fa=0;Ga=ua;Ha=Ba}else{pa=pa;qa=qa;ra=ra;sa=sa;ta=ta;ua=ua;va=va;wa=Ba;continue}}else{xa=c[q>>2]|0;if((wa|0)>=(f-xa|0)){Ea=wa;break}if((xa|0)<=0){Ia=0;Ja=wa;Ka=25;break}za=(xa|0)>1?xa:1;ya=wa;Da=0;La=0;while(1){Ma=d[e+ya|0]|La<<8;Na=Da+1|0;if((Na|0)<(xa|0)){ya=ya+1|0;Da=Na;La=Ma}else{break}}La=wa+za|0;if((Ma|0)<1){Ia=Ma;Ja=La;Ka=25;break}if((Ma|0)>(f-La|0)){Ia=Ma;Ja=La;Ka=25;break}Fa=Ma;Ga=Ma+La|0;Ha=La}La=c[b+572248+(va<<2)>>2]|0;Da=e+Ha|0;ya=Qca(La,Da,k,j,Ga-Ha|0)|0;xa=c[k>>2]|0;if((ya|0)==0|(xa|0)<0){Oa=-1;Pa=Ha;break b}Na=c[j>>2]|0;Qa=Na+Ha|0;Ra=c[t>>2]|0;do{if((Ra&1|0)==0){Sa=Ra}else{Ta=Qa+3|0;if((Ta|0)>=(Ga|0)){Sa=Ra;break}if((a[e+Qa|0]|0)!=0){Sa=Ra;break}if((a[e+(Qa+1)|0]|0)!=0){Sa=Ra;break}if((a[e+(Qa+2)|0]|0)!=1){Sa=Ra;break}if(!((a[e+Ta|0]|0)==-32)){Sa=Ra;break}Ta=Ra|16384;c[t>>2]=Ta;Sa=Ta}}while(0);e:do{if((Sa&16384|0)==0&(xa|0)>0){Ra=xa;while(1){za=Ra-1|0;if((a[ya+za|0]|0)!=0){Ua=Ra;break e}c[k>>2]=za;if((za|0)>0){Ra=za}else{Ua=za;break}}}else{Ua=xa}}while(0);if((Ua|0)==0){Va=0}else{xa=Ua<<3;Ra=d[ya+(Ua-1)|0]|0;do{if((Ra&1|0)==0){if((Ra&2|0)!=0){Wa=2;break}if((Ra&4|0)!=0){Wa=3;break}if((Ra&8|0)!=0){Wa=4;break}if((Ra&16|0)!=0){Wa=5;break}if((Ra&32|0)!=0){Wa=6;break}if((Ra&64|0)!=0){Wa=7;break}Wa=Ra>>>4&8}else{Wa=1}}while(0);Va=xa-Wa|0}Ra=c[l>>2]|0;if((c[Ra+688>>2]&256|0)!=0){za=c[La+427432>>2]|0;yDb(Ra,48,2036592,(Xa=i,i=i+48|0,c[Xa>>2]=c[La+427436>>2],c[Xa+8>>2]=za,c[Xa+16>>2]=Ha,c[Xa+24>>2]=f,c[Xa+32>>2]=Ua,c[Xa+40>>2]=ka,Xa)|0);i=Xa}do{if((c[u>>2]|0)!=0){if(!((Fa|0)!=(Na|0)&(Fa|0)!=0)){break}yDb(c[l>>2]|0,48,2032968,(Xa=i,i=i+16|0,c[Xa>>2]=Na,c[Xa+8>>2]=Fa,Xa)|0);i=Xa}}while(0);xa=sa+1|0;if(oa){za=c[La+427436>>2]|0;switch(za|0){case 2:case 5:case 1:{break};case 7:case 8:{pa=pa;qa=qa;ra=ra;sa=xa;ta=xa;ua=Ga;va=va;wa=Qa;continue c;break};default:{pa=pa;qa=qa;ra=ra;sa=xa;ta=ta;ua=Ga;va=va;wa=Qa;continue c}}Ra=Va>>>0>2147483639>>>0;Ta=Ra?0:ya;Ya=Ra?0:Va;c[La+1088>>2]=Ta;c[La+1100>>2]=Ya;c[La+1104>>2]=Ya+8;c[La+1092>>2]=Ta+(Ya+7>>3);Ya=La+1096|0;c[Ya>>2]=0;Ra=Ta;Ta=fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0;if(Ta>>>0>134217727>>>0){Ra=Ta>>>23;c[Ya>>2]=d[1213744+Ra|0]|0;Za=d[1108392+Ra|0]|0}else{Ra=Ta>>>0>65535>>>0;_a=Ra?Ta>>>16:Ta;$a=Ra?16:0;if((_a&65280|0)==0){ab=$a;bb=_a}else{ab=$a|8;bb=_a>>>8}_a=(d[1191992+bb|0]|0)+ab<<1;c[Ya>>2]=63-_a;Za=(Ta>>>((_a-31|0)>>>0))-1|0}_a=(qa|0)==0;Ta=(qa|0)==(za|0)&(((Za|0)==0|_a)^1);pa=pa;qa=_a?Ta?qa:za:qa;ra=ra;sa=xa;ta=Ta?ta:xa;ua=Ga;va=va;wa=Qa;continue}do{if((qa|0)==0){Ta=c[La+427436>>2]|0;if(!((Ta|0)==2|(Ta|0)==5|(Ta|0)==1)){cb=0;break}cb=Ta}else{cb=qa}}while(0);do{if((c[v>>2]|0)>7){if((c[w>>2]|0)!=0){break}if((c[p>>2]|0)!=6){pa=pa;qa=cb;ra=ra;sa=xa;ta=ta;ua=Ga;va=va;wa=Qa;continue c}}}while(0);Ta=(ta|0)<(xa|0);za=Va>>>0>2147483639>>>0;_a=za?0:ya;Ya=za?0:Va;za=Ya+8|0;$a=_a+(Ya+7>>3)|0;Ra=(xa|0)>=(ta|0)|0;db=(Fa|0)==0;eb=Ga-1-Qa+Na|0;fb=(eb|0)>268435454;gb=e+(Qa+1-Na)|0;hb=eb<<3;eb=hb>>>0>2147483639>>>0|(gb|0)==0;ib=eb?0:gb;gb=eb?0:hb;hb=gb+8|0;eb=ib+(gb>>3)|0;jb=(Ga-Qa+Na|0)==(Fa|0);kb=La;lb=pa;mb=ra;nb=va;while(1){if(!((c[n>>2]&1|0)!=0&Ta)){c[ga>>2]=-1}ob=kb+427436|0;pb=c[ob>>2]|0;f:do{if(x){Ka=81}else{switch(pb|0){case 5:case 1:case 2:case 3:case 4:{yDb(c[l>>2]|0,24,2028720,(Xa=i,i=i+8|0,c[Xa>>2]=pb,Xa)|0);i=Xa;break};case 19:{break};default:{Ka=81;break f}}c[ob>>2]=267448321;qb=0;rb=lb;sb=mb;tb=nb;ub=kb+427436|0}}while(0);g:do{if((Ka|0)==81){Ka=0;ob=kb+427436|0;do{if((pb|0)==3){vb=kb+421136|0;c[vb>>2]=_a;c[kb+421148>>2]=Ya;c[kb+421152>>2]=za;c[kb+421140>>2]=$a;c[kb+421144>>2]=0;c[kb+421176>>2]=vb;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==4){vb=kb+421156|0;c[vb>>2]=_a;c[kb+421168>>2]=Ya;c[kb+421172>>2]=za;c[kb+421160>>2]=$a;c[kb+421164>>2]=0;c[kb+421180>>2]=vb;yDb(c[l>>2]|0,16,2017952,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==2){wb=c[l>>2]|0;if((c[wb+88>>2]&32768|0)!=0){Ka=117;break b}c[kb+1088>>2]=_a;c[kb+1100>>2]=Ya;c[kb+1104>>2]=za;c[kb+1092>>2]=$a;c[kb+1096>>2]=0;c[kb+421180>>2]=0;c[kb+421176>>2]=0;vb=mda(kb,b)|0;if((vb|0)<0){c[aa>>2]=0;qb=vb;rb=lb;sb=mb;tb=nb;ub=ob;break g}else{c[kb+4800>>2]=1;qb=vb;rb=lb;sb=mb;tb=nb;ub=ob;break g}}else if((pb|0)==6){c[ba>>2]=_a;c[ca>>2]=Ya;c[da>>2]=za;c[ea>>2]=$a;c[fa>>2]=0;nea(b)|0;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==7){c[ba>>2]=_a;c[ca>>2]=Ya;c[da>>2]=za;c[ea>>2]=$a;c[fa>>2]=0;if((aea(b)|0)>=0){qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}if((c[u>>2]|0)!=0&db){qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}yDb(c[l>>2]|0,48,2013784,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;if(!((c[u>>2]|0)==0|jb)){Ka=127;break b}if(fb){qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}c[ba>>2]=ib;c[ca>>2]=gb;c[da>>2]=hb;c[ea>>2]=eb;c[fa>>2]=0;aea(b)|0;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==9|(pb|0)==10|(pb|0)==11|(pb|0)==12|(pb|0)==13|(pb|0)==19|(pb|0)==267448321){qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==8){c[ba>>2]=_a;c[ca>>2]=Ya;c[da>>2]=za;c[ea>>2]=$a;c[fa>>2]=0;cea(b,Va)|0;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==1){xb=mb}else if((pb|0)==5){if((c[p>>2]|0)!=5){Ka=83;break b}if((mb|0)!=0){xb=1;break}iea(b);c[y>>2]=0;c[z>>2]=0;c[A>>2]=65536;c[B>>2]=0;c[C>>2]=-2147483648;c[D>>2]=-2147483648;c[E>>2]=-2147483648;c[F>>2]=-2147483648;c[G>>2]=-2147483648;c[H>>2]=-2147483648;c[I>>2]=-2147483648;c[J>>2]=-2147483648;c[K>>2]=-2147483648;c[L>>2]=-2147483648;c[M>>2]=-2147483648;c[N>>2]=-2147483648;c[O>>2]=-2147483648;c[P>>2]=-2147483648;c[Q>>2]=-2147483648;c[R>>2]=-2147483648;xb=1}else{yDb(g,48,1999288,(Xa=i,i=i+16|0,c[Xa>>2]=pb,c[Xa+8>>2]=Va,Xa)|0);i=Xa;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}}while(0);Aa=kb+1088|0;c[Aa>>2]=_a;c[kb+1100>>2]=Ya;c[kb+1104>>2]=za;c[kb+1092>>2]=$a;c[kb+1096>>2]=0;c[kb+421180>>2]=Aa;c[kb+421176>>2]=Aa;c[kb+4800>>2]=0;Aa=mda(kb,b)|0;if((Aa|0)!=0){qb=Aa;rb=lb;sb=xb;tb=nb;ub=ob;break}Aa=c[S>>2]|0;do{if((Aa|0)>-1){vb=c[T>>2]|0;if((vb|0)==(Aa|0)){if((c[kb+177080>>2]|0)!=1){Ka=90}}else{Ka=90}if((Ka|0)==90){Ka=0;c[W>>2]=1}yb=c[U>>2]|0;if((yb|0)<0){zb=c[V>>2]|0}else{Ab=c[V>>2]|0;if(((1<<Ab)-1&yb-vb|0)>(Aa|0)){zb=Ab}else{break}}c[U>>2]=(1<<zb)-1&Aa+vb;if((c[W>>2]|0)!=0){break}c[U>>2]=vb}}while(0);Aa=c[X>>2]|0;vb=Aa+84|0;c[vb>>2]=c[vb>>2]|(c[ob>>2]|0)==5;if((c[ob>>2]|0)==5){Ka=98}else{if((c[U>>2]|0)==(c[T>>2]|0)){Ka=98}else{Ka=99}}do{if((Ka|0)==98){Ka=0;c[U>>2]=-1;c[Aa+2200>>2]=1;if((c[ob>>2]|0)!=5){Ka=99;break}vb=c[Y>>2]|1;c[Y>>2]=vb;Bb=vb}}while(0);if((Ka|0)==99){Ka=0;Bb=c[Y>>2]|0}vb=-((c[s>>2]|0)>>>22&1)&3|Bb;c[Y>>2]=vb;Ab=-((c[Z>>2]|0)>>>3&1)&3|vb;c[Y>>2]=Ab;vb=Aa+2200|0;c[vb>>2]=Ab|c[vb>>2];do{if((c[_>>2]|0)==1){if((c[s>>2]&32768|0)==0){kda(b,Ra)}vb=c[l>>2]|0;Ab=c[vb+712>>2]|0;if((Ab|0)==0){Cb=lb;break}yb=ze[c[Ab+24>>2]&511](vb,0,0)|0;if((yb|0)<0){Db=yb;Ka=145;break b}else{Cb=yb}}else{Cb=lb}}while(0);if((c[kb+428688>>2]|0)!=0){qb=0;rb=Cb;sb=xb;tb=nb;ub=ob;break}Aa=c[v>>2]|0;do{if((Aa|0)>=8){if((c[kb+427432>>2]|0)==0){qb=0;rb=Cb;sb=xb;tb=nb;ub=ob;break g}if((Aa|0)<16){break}yb=c[kb+177080>>2]|0;if((yb|0)==3){qb=0;rb=Cb;sb=xb;tb=nb;ub=ob;break g}if((Aa|0)<32){break}if(!((yb|0)==1&(Aa|0)<48)){qb=0;rb=Cb;sb=xb;tb=nb;ub=ob;break g}}}while(0);Aa=c[$>>2]|0;if((Aa|0)==0){qb=0;rb=Cb;sb=xb;tb=nb+1|0;ub=ob;break}else{yb=ze[c[Aa+28>>2]&511](m,Da,Na)|0;if((yb|0)<0){Db=yb;Ka=145;break b}else{qb=0;rb=yb;sb=xb;tb=nb;ub=ob;break}}}}while(0);if((tb|0)==(c[r>>2]|0)){nda(b,tb);Eb=0}else{Eb=tb}if((qb|0)<0){break}if((qb|0)!=1){pa=rb;qa=cb;ra=sb;sa=xa;ta=ta;ua=Ga;va=Eb;wa=Qa;continue c}c[p>>2]=c[ub>>2];c[w>>2]=c[kb+427432>>2];kb=b;lb=rb;mb=sb;nb=Eb}yDb(c[l>>2]|0,16,1995072,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;c[ha>>2]=0;c[ia>>2]=0;c[ja>>2]=0;pa=rb;qa=cb;ra=sb;sa=xa;ta=ta;ua=Ga;va=Eb;wa=Qa}if((Ka|0)==25){Ka=0;yDb(c[l>>2]|0,16,2039944,(Xa=i,i=i+8|0,c[Xa>>2]=Ia,Xa)|0);i=Xa;Ea=Ja}wa=ka+1|0;if((wa|0)<2){ka=wa;o=ta;la=ra;ma=qa;na=pa}else{Ka=139;break}}do{if((Ka|0)==83){yDb(c[l>>2]|0,16,2025104,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;Oa=-1;Pa=Qa}else if((Ka|0)==117){yDb(wb,16,2021696,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;Db=-38;i=h;return Db|0}else if((Ka|0)==127){yDb(0,0,1895544,(Xa=i,i=i+24|0,c[Xa>>2]=2009736,c[Xa+8>>2]=2332720,c[Xa+16>>2]=5089,Xa)|0);i=Xa;Cd();return 0}else if((Ka|0)==139){if((va|0)==0){Oa=pa;Pa=Ea;break}nda(b,va);Oa=pa;Pa=Ea}else if((Ka|0)==145){i=h;return Db|0}}while(0);Ka=c[b+2524>>2]|0;do{if((Ka|0)!=0){if((c[b+4796>>2]|0)!=0){break}Y0a(Ka+1496|0,2147483647,(c[b+177100>>2]|0)==2|0)}}while(0);Db=(Oa|0)<0?Oa:Pa;i=h;return Db|0}function Wca(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+60>>2]|0;e=d;f=d;c[f>>2]=a;c[d+427468>>2]=8;c[d+427472>>2]=1;g=a+796|0;c[g>>2]=8;c[d+572632>>2]=1;Gea(d+12|0,8,1);if((c[d+7312>>2]|0)!=0){yDb(0,0,1895544,(h=i,i=i+24|0,c[h>>2]=2352824,c[h+8>>2]=2332720,c[h+16>>2]=1585,h)|0);i=h;Cd();return 0}pea(d+148|0,0);Soa(d+180|0,8);cia(d+4932|0,c[(c[f>>2]|0)+48>>2]|0,8,1);c[d+428628>>2]=-1;c[d+6120>>2]=-1;Z3(d+1108|0,c[f>>2]|0);T3a(d+4|0,8);TGb(d+7396|0,16,224)|0;c[d+177100>>2]=3;c[d+572384>>2]=1;c[d+4820>>2]=c[a+676>>2];c[d+4816>>2]=c[a+88>>2];if((c[a+176>>2]|0)==0){c[d+4808>>2]=1}c[a+400>>2]=1;Qda();Vhb();c[d+4752>>2]=0;c[g>>2]=8;c[d+7308>>2]=8;c[d+572248>>2]=e;g=d+571432|0;c[g>>2]=-2147483648;h=d+571428|0;c[h>>2]=-2147483648;j=d+571360|0;c[j>>2]=-2147483648;c[d+571364>>2]=-2147483648;c[d+571368>>2]=-2147483648;c[d+571372>>2]=-2147483648;c[d+571376>>2]=-2147483648;c[d+571380>>2]=-2147483648;c[d+571384>>2]=-2147483648;c[d+571388>>2]=-2147483648;c[d+571392>>2]=-2147483648;c[d+571396>>2]=-2147483648;c[d+571400>>2]=-2147483648;c[d+571404>>2]=-2147483648;c[d+571408>>2]=-2147483648;c[d+571412>>2]=-2147483648;c[d+571416>>2]=-2147483648;c[d+571420>>2]=-2147483648;k=d+428660|0;c[k>>2]=65536;l=d+428676|0;c[l>>2]=-1;c[d+427372>>2]=-1;c[d+572456>>2]=-1;mea(e);if((c[a+48>>2]|0)==28){m=a+112|0;do{if((c[m>>2]|0)==1){n=c[f>>2]|0;o=n+108|0;p=c[o>>2]|0;if((p|0)<1073741823){c[o>>2]=p<<1;break}else{p=n+104|0;c[p>>2]=(c[p>>2]|0)/2|0;break}}}while(0);c[m>>2]=2}m=c[a+100>>2]|0;do{if((m|0)>0){p=c[a+96>>2]|0;if((p|0)==0){break}n=Uca(e,p,m)|0;if((n|0)>=0){break}Tca(e,1);p=0;while(1){$Db(e+427476+(p<<2)|0);o=p+1|0;if((o|0)<32){p=o}else{q=0;break}}while(1){$Db(e+427604+(q<<2)|0);p=q+1|0;if((p|0)<256){q=p}else{r=n;break}}i=b;return r|0}}while(0);do{if((c[d+6784>>2]|0)!=0){q=(c[f>>2]|0)+176|0;m=c[d+6788>>2]|0;if((c[q>>2]|0)>=(m|0)){break}c[q>>2]=m;c[d+4808>>2]=0}}while(0);c[(c[a+64>>2]|0)+4>>2]=1;c[g>>2]=-2147483648;c[h>>2]=-2147483648;c[d+572412>>2]=1;iea(e);c[d+428672>>2]=0;c[k>>2]=65536;c[d+428664>>2]=0;c[j>>2]=-2147483648;c[d+571364>>2]=-2147483648;c[d+571368>>2]=-2147483648;c[d+571372>>2]=-2147483648;c[d+571376>>2]=-2147483648;c[d+571380>>2]=-2147483648;c[d+571384>>2]=-2147483648;c[d+571388>>2]=-2147483648;c[d+571392>>2]=-2147483648;c[d+571396>>2]=-2147483648;c[d+571400>>2]=-2147483648;c[d+571404>>2]=-2147483648;c[d+571408>>2]=-2147483648;c[d+571412>>2]=-2147483648;c[d+571416>>2]=-2147483648;c[d+571420>>2]=-2147483648;c[l>>2]=-1;l=d+2524|0;j=c[l>>2]|0;if((j|0)!=0){c[j+2192>>2]=0;k=c[d+571288>>2]|0;a:do{if((k|0)==0){s=0}else{h=1;g=0;a=k;f=j;while(1){if((a|0)==(f|0)){t=g}else{c[e+571288+(g<<2)>>2]=a;t=g+1|0}m=c[e+571288+(h<<2)>>2]|0;if((m|0)==0){s=t;break a}h=h+1|0;g=t;a=m;f=c[l>>2]|0}}}while(0);c[e+571288+(s<<2)>>2]=0}c[d+177104>>2]=0;TGb(d+199440|0,0,213504)|0;TGb(d+428696|0,0,142336)|0;mea(e);c[d+572476>>2]=-1;c[d+572480>>2]=0;c[d+199428>>2]=0;c[d+572376>>2]=0;c[d+572232>>2]=1;r=0;i=b;return r|0}function Xca(a){a=a|0;var b=0,c=0,d=0;Tca(a,1);b=0;while(1){$Db(a+427476+(b<<2)|0);c=b+1|0;if((c|0)<32){b=c}else{d=0;break}}do{$Db(a+427604+(d<<2)|0);d=d+1|0;}while((d|0)<256);return}function Yca(a){a=a|0;var b=0;do{if((c[a+427416>>2]|0)==0){if((c[(c[a+4064>>2]|0)+(c[a+427412>>2]<<2)>>2]&4|0)!=0){b=1;break}b=(c[a+4792>>2]|0)==0}else{b=1}}while(0);if((c[a+6136>>2]|0)==3){do{if(!b){if((c[a+4752>>2]|0)!=0){break}_ca(a);return}}while(0);Zca(a);return}if(b){$ca(a);return}if((c[a+4752>>2]|0)==0){bda(a);return}else{ada(a);return}}



function TZa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;e=i;i=i+8|0;f=e|0;g=c[b+60>>2]|0;h=g;j=g+572928|0;c[j>>2]=cEb(2224)|0;k=g+572936|0;c[k>>2]=cEb(2224)|0;l=cEb(2224)|0;c[g+572932>>2]=l;a:do{if((l|0)==0){m=-12}else{if((c[k>>2]|0)==0){m=-12;break}if((c[j>>2]|0)==0){m=-12;break}n=Wca(b)|0;if((n|0)<0){m=n;break}n=b+88|0;BFa(g+572720|0,c[n>>2]|0);c[g+4816>>2]=c[n>>2];c[g+427416>>2]=1;c[g+6136>>2]=1;c[g+177100>>2]=3;c[b+140>>2]=c[c[(c[b+12>>2]|0)+24>>2]>>2];c[g+4760>>2]=4;c[g+4756>>2]=4;c[g+4788>>2]=1;c[g+4784>>2]=1;n=g+572940|0;c[n>>2]=1;o=g+572944|0;c[o>>2]=1;p=g+572948|0;c[p>>2]=0;q=c[b+96>>2]|0;r=c[b+100>>2]|0;s=q+r|0;b:do{if((q|0)!=0&(r|0)>8){t=q;u=0;while(1){if((PGb(t,2191392,4)|0)==0){break}if((u+9|0)<(r|0)){t=t+1|0;u=u+1|0}else{break b}}u=t+4|0;v=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;if(v>>>0>(s-8-t|0)>>>0){m=-1094995529;break a}u=t+8|0;w=v<<3;x=w>>>0>2147483639>>>0|(u|0)==0;y=x?0:u;u=x?0:w;w=u+8|0;x=y;z=w>>>0>3>>>0?3:w;switch((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>5&7|0){case 1:{c[b+120>>2]=128;c[b+124>>2]=96;A=z;break};case 3:{c[b+120>>2]=352;c[b+124>>2]=288;A=z;break};case 0:{c[b+120>>2]=160;c[b+124>>2]=120;A=z;break};case 2:{c[b+120>>2]=176;c[b+124>>2]=144;A=z;break};case 7:{x=y+(z>>>3)|0;B=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&3)>>>20;x=z+12|0;C=w>>>0>x>>>0?x:w;c[b+120>>2]=B;B=y+(C>>>3)|0;x=C+12|0;c[b+124>>2]=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>20;A=w>>>0>x>>>0?x:w;break};case 6:{c[b+120>>2]=320;c[b+124>>2]=240;A=z;break};case 4:{c[b+120>>2]=704;c[b+124>>2]=576;A=z;break};case 5:{c[b+120>>2]=240;c[b+124>>2]=180;A=z;break};default:{A=z}}z=((A|0)<(w|0))+A|0;c[n>>2]=(d[y+(A>>>3)|0]|0)<<(A&7)>>>7&1;c[o>>2]=(d[y+(z>>>3)|0]|0)<<(z&7)>>>7&1;x=z+1+((z|0)<(w|0))|0;z=(w>>>0>x>>>0?x:w)+1|0;x=(w>>>0>z>>>0?z:w)+1|0;z=(w>>>0>x>>>0?x:w)+1|0;x=w>>>0>z>>>0?z:w;z=(d[y+(x>>>3)|0]|0)<<(x&7)>>>7&1;c[g+4808>>2]=z;C=x+1+((x|0)<(w|0))|0;x=w>>>0>C>>>0?C:w;if((u-x|0)<1){m=-1094995529;break a}else{D=x}while(1){E=((D|0)<(w|0))+D|0;if(((d[y+(D>>>3)|0]|0)&128>>>((D&7)>>>0)|0)==0){break}x=E+8|0;C=w>>>0>x>>>0?x:w;if((u-C|0)<1){m=-1094995529;break a}else{D=C}}u=((E|0)<(w|0))+E|0;c[p>>2]=(d[y+(E>>>3)|0]|0)<<(E&7)>>>7&1;c[b+176>>2]=z^1;if((c[p>>2]|0)==0){break}C=y+(u>>>3)|0;x=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(u&7);if((x&-1434451968|0)==0){C=1;B=u;F=x;while(1){G=F>>>24;H=a[1201432+G|0]|0;I=H&255;J=((H&255)>>>0>8>>>0?8:I)+B|0;K=w>>>0>J>>>0;L=K?J:w;if(!(H<<24>>24==9)){M=25;break}H=d[1201688+G|0]|0|C<<4;if(!(H>>>0<134217728>>>0)){N=H;break}J=y+(L>>>3)|0;O=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7);if(K){C=H;B=L;F=O}else{N=H;break}}if((M|0)==25){N=d[1201688+G|0]|0|C<<(I-1>>1)}P=N-1|0;Q=L}else{F=x>>>24;B=(d[1201432+F|0]|0)+u|0;P=d[1200920+F|0]|0;Q=w>>>0>B>>>0?B:w}B=y+(Q>>>3)|0;F=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(Q&7);if((F&-1434451968|0)==0){B=1;z=Q;H=F;while(1){R=H>>>24;O=a[1201432+R|0]|0;S=O&255;K=((O&255)>>>0>8>>>0?8:S)+z|0;J=w>>>0>K>>>0;T=J?K:w;if(!(O<<24>>24==9)){M=32;break}O=d[1201688+R|0]|0|B<<4;if(!(O>>>0<134217728>>>0)){U=O;break}K=y+(T>>>3)|0;V=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(T&7);if(J){B=O;z=T;H=V}else{U=O;break}}if((M|0)==32){U=d[1201688+R|0]|0|B<<(S-1>>1)}W=U-1|0;X=T}else{H=F>>>24;z=(d[1201432+H|0]|0)+Q|0;W=d[1200920+H|0]|0;X=w>>>0>z>>>0?z:w}z=y+(X>>>3)|0;H=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(X&7);if((H&-1434451968|0)==0){z=1;u=X;x=H;while(1){Y=x>>>24;C=a[1201432+Y|0]|0;Z=C&255;O=((C&255)>>>0>8>>>0?8:Z)+u|0;V=w>>>0>O>>>0;_=V?O:w;if(!(C<<24>>24==9)){M=39;break}C=d[1201688+Y|0]|0|z<<4;if(!(C>>>0<134217728>>>0)){$=C;break}O=y+(_>>>3)|0;J=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(_&7);if(V){z=C;u=_;x=J}else{$=C;break}}if((M|0)==39){$=d[1201688+Y|0]|0|z<<(Z-1>>1)}aa=$-1|0;ca=_}else{x=H>>>24;u=(d[1201432+x|0]|0)+X|0;aa=d[1200920+x|0]|0;ca=w>>>0>u>>>0?u:w}u=y+(ca>>>3)|0;x=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(ca&7)>>>24;u=ca+8|0;F=w>>>0>u>>>0?u:w;u=y+(F>>>3)|0;B=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(F&7)>>>30;u=F+2|0;F=w>>>0>u>>>0?u:w;u=y+(F>>>3)|0;C=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(F&7);if((C&-1434451968|0)==0){u=1;J=F;V=C;while(1){da=V>>>24;O=a[1201432+da|0]|0;ea=O&255;K=((O&255)>>>0>8>>>0?8:ea)+J|0;fa=w>>>0>K>>>0;ga=fa?K:w;if(!(O<<24>>24==9)){M=46;break}O=d[1201688+da|0]|0|u<<4;if(!(O>>>0<134217728>>>0)){ha=O;break}K=y+(ga>>>3)|0;ia=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(ga&7);if(fa){u=O;J=ga;V=ia}else{ha=O;break}}if((M|0)==46){ha=d[1201688+da|0]|0|u<<(ea-1>>1)}ja=ha-1|0;ka=ga}else{V=C>>>24;J=(d[1201432+V|0]|0)+F|0;ja=d[1200920+V|0]|0;ka=w>>>0>J>>>0?J:w}J=ba(P<<2,W)|0;c[f>>2]=J;V=ka+7>>3;if((W|0)==0){m=-1;break a}y=P;H=0<<2|y>>>30;z=0;if(H>>>0>z>>>0|H>>>0==z>>>0&(y<<2|0>>>30)>>>0>(4294967295/(W>>>0)|0)>>>0){m=-1;break a}y=WDb(J)|0;J=b;yDb(J,48,2174760,(la=i,i=i+16|0,c[la>>2]=P,c[la+8>>2]=W,la)|0);i=la;yDb(J,48,2164520,(la=i,i=i+40|0,c[la>>2]=aa,c[la+8>>2]=x,c[la+16>>2]=B,c[la+24>>2]=ja,c[la+32>>2]=V,la)|0);i=la;if((Zb(y|0,f|0,t+(V+8)|0,v-V|0)|0)==0){V=(Xob(y,c[f>>2]|0,0)|0)&65535;z=V<<16|V;c[g+572956>>2]=z;yDb(J,48,2150976,(la=i,i=i+8|0,c[la>>2]=z,la)|0);i=la;ZDb(y);break}else{yDb(J,16,2157752,(la=i,i=i+1|0,i=i+7&-8,c[la>>2]=0,la)|0);i=la;ZDb(y);m=-1;break a}}}while(0);p=c[b+120>>2]|0;c[g+4768>>2]=p;o=c[b+124>>2]|0;c[g+4772>>2]=o;n=(p+15|0)/16|0;c[g+427400>>2]=n;p=(o+15|0)/16|0;c[g+427396>>2]=p;c[g+427404>>2]=n+1;c[g+427408>>2]=ba(p,n)|0;c[g+6108>>2]=n<<2;c[g+572976>>2]=n<<4;c[g+572980>>2]=p<<4;p=Rca(h)|0;if((p|0)<0){yDb(b,16,2143912,(la=i,i=i+1|0,i=i+7&-8,c[la>>2]=0,la)|0);i=la;m=p;break}else{ma=0;i=e;return ma|0}}}while(0);VZa(b)|0;ma=m;i=e;return ma|0}function UZa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0;h=i;j=c[b+60>>2]|0;k=j;l=j;m=c[g+28>>2]|0;if((m|0)==0){n=c[j+572932>>2]|0;if((c[n>>2]|0)==0){o=0;i=h;return o|0}if((c[j+4808>>2]|0)!=0){o=0;i=h;return o|0}p=j+572984|0;if((c[p>>2]|0)!=0){o=0;i=h;return o|0}q=MCb(e,n|0)|0;if((q|0)<0){o=q;i=h;return o|0}c[p>>2]=1;c[f>>2]=1;o=0;i=h;return o|0}p=j+427412|0;c[p>>2]=0;q=j+427380|0;c[q>>2]=0;n=j+427376|0;c[n>>2]=0;do{if((c[j+572956>>2]|0)==0){r=g+24|0}else{s=j+572960|0;t=s;O$a(s,j+572964|0,m);s=c[t>>2]|0;if((s|0)==0){o=-12;i=h;return o|0}else{UGb(s|0,c[g+24>>2]|0,m)|0;r=t;break}}}while(0);g=c[r>>2]|0;r=j+1088|0;t=m<<3;s=t>>>0>2147483639>>>0|(g|0)==0;u=s?0:g;g=s?0:t;s=r;c[s>>2]=u;v=j+1100|0;c[v>>2]=g;w=j+1104|0;c[w>>2]=g+8;c[j+1092>>2]=u+(g>>3);g=j+1096|0;c[g>>2]=0;if((WZa(b)|0)!=0){o=-1;i=h;return o|0}u=c[j+177076>>2]|0;y=j+572392|0;c[y>>2]=u;if((u|0)!=3){u=j+572936|0;z=c[u>>2]|0;A=j+572932|0;c[u>>2]=c[A>>2];c[A>>2]=z}z=j+572928|0;KCb(c[z>>2]|0);A=c[z>>2]|0;c[A+88>>2]=c[y>>2];c[A+84>>2]=(c[y>>2]|0)==1;u=XZa(b,A)|0;if((u|0)<0){o=u;i=h;return o|0}c[j+2524>>2]=c[z>>2];u=j+2528|0;A=u;KCb(A);B=c[z>>2]|0;UGb(u|0,B|0,2224)|0;u=MCb(A,B|0)|0;if((u|0)<0){o=u;i=h;return o|0}B=j+4776|0;A=j+5716|0;C=0;do{D=(d[473144+C|0]|0)-12|0;E=D<<2&28;F=D>>3;c[A+(C<<2)>>2]=E+(ba(c[B>>2]<<2,F)|0);c[A+(C+48<<2)>>2]=E+(ba(c[B>>2]<<3,F)|0);C=C+1|0;}while((C|0)<16);C=j+4780|0;B=0;do{F=(d[473144+B|0]|0)-12|0;E=F<<2&28;D=F>>3;F=E+(ba(c[C>>2]<<2,D)|0)|0;c[A+(B+32<<2)>>2]=F;c[A+(B+16<<2)>>2]=F;F=E+(ba(c[C>>2]<<3,D)|0)|0;c[A+(B+80<<2)>>2]=F;c[A+(B+64<<2)>>2]=F;B=B+1|0;}while((B|0)<16);B=c[y>>2]|0;do{if((B|0)==1){G=u}else{A=j+572936|0;do{if((c[c[A>>2]>>2]|0)==0){yDb(b,16,2181320,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;KCb(c[A>>2]|0);C=XZa(b,c[A>>2]|0)|0;if((C|0)<0){o=C;i=h;return o|0}else{F=c[A>>2]|0;D=b+124|0;TGb(c[F>>2]|0,0,ba(c[F+32>>2]|0,c[D>>2]|0)|0)|0;F=c[A>>2]|0;TGb(c[F+4>>2]|0,-128|0,ba(c[F+36>>2]|0,(c[D>>2]|0)/2|0)|0)|0;F=c[A>>2]|0;TGb(c[F+8>>2]|0,-128|0,ba(c[F+40>>2]|0,(c[D>>2]|0)/2|0)|0)|0;I=C;J=c[y>>2]|0;break}}else{I=u;J=B}}while(0);if((J|0)!=3){G=I;break}A=j+572932|0;if((c[c[A>>2]>>2]|0)!=0){G=I;break}yDb(b,16,2181320,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;KCb(c[A>>2]|0);C=XZa(b,c[A>>2]|0)|0;if((C|0)<0){o=C;i=h;return o|0}else{D=c[A>>2]|0;F=b+124|0;TGb(c[D>>2]|0,0,ba(c[D+32>>2]|0,c[F>>2]|0)|0)|0;D=c[A>>2]|0;TGb(c[D+4>>2]|0,-128|0,ba(c[D+36>>2]|0,(c[F>>2]|0)/2|0)|0)|0;D=c[A>>2]|0;TGb(c[D+8>>2]|0,-128|0,ba(c[D+40>>2]|0,(c[F>>2]|0)/2|0)|0)|0;G=C;break}}}while(0);if((c[b+688>>2]&1|0)!=0){I=c[j>>2]|0;J=(mGb(c[y>>2]|0)|0)<<24>>24;B=c[j+572940>>2]|0;u=c[j+572944>>2]|0;C=c[j+572968>>2]|0;F=c[j+4792>>2]|0;D=c[j+177068>>2]|0;yDb(I,48,2104224,(H=i,i=i+48|0,c[H>>2]=J,c[H+8>>2]=B,c[H+16>>2]=u,c[H+24>>2]=C,c[H+32>>2]=F,c[H+40>>2]=D,H)|0);i=H}D=c[b+856>>2]|0;do{if((D|0)>7){F=c[y>>2]|0;if((F|0)==3){o=0;i=h;return o|0}if((D|0)<=31){break}if((F|0)!=1|(D|0)>47){o=0}else{break}i=h;return o|0}}while(0);D=j+572972|0;F=(c[y>>2]|0)==3;do{if((c[D>>2]|0)==0){if(!F){K=41;break}C=(c[j+177068>>2]|0)-(c[j+428676>>2]|0)|0;u=(C|0)<0?C+256|0:C;c[j+428668>>2]=u;if((u|0)!=0){if((u|0)<(c[j+428672>>2]|0)){break}}yDb(c[j>>2]|0,16,2047784,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;o=-1;i=h;return o|0}else{if(F){o=0;i=h;return o|0}else{c[D>>2]=0;K=41;break}}}while(0);do{if((K|0)==41){D=j+428656|0;F=c[D>>2]|0;c[j+428676>>2]=F;u=c[j+177068>>2]|0;c[D>>2]=u;D=u-F|0;F=j+428672|0;c[F>>2]=D;if((D|0)>=0){break}c[F>>2]=D+256}}while(0);TGb(j+5643|0,1,5)|0;a[j+5648|0]=-2;TGb(j+5651|0,1,5)|0;a[j+5656|0]=-2;TGb(j+5659|0,1,5)|0;a[j+5664|0]=-2;TGb(j+5667|0,1,5)|0;TGb(j+5683|0,1,5)|0;a[j+5688|0]=-2;TGb(j+5691|0,1,5)|0;a[j+5696|0]=-2;TGb(j+5699|0,1,5)|0;a[j+5704|0]=-2;TGb(j+5707|0,1,5)|0;c[q>>2]=0;D=j+427396|0;F=c[D>>2]|0;a:do{if((F|0)>0){u=j+427400|0;C=j+572936|0;B=j+177100|0;J=j+4808|0;I=j+427404|0;A=j+6108|0;E=j+5164|0;L=j+5172|0;M=j+5168|0;N=j+572932|0;O=j+4052|0;P=j+4056|0;Q=j+4928|0;R=j+6104|0;S=j+5192|0;T=j+4792|0;U=j+424272|0;V=U;W=r;X=j+426564|0;Y=j+4064|0;Z=j+4832|0;_=j+572968|0;$=j+572944|0;aa=j+572940|0;ca=j+4836|0;da=j;ea=j+4888|0;fa=j+4899|0;ga=j+4907|0;ha=j+4915|0;ia=j+4923|0;ja=j+4892|0;ka=j+4893|0;la=j+4894|0;ma=j+4895|0;na=j+4924|0;oa=j+4919|0;pa=j+4911|0;qa=j+4903|0;ra=j+4900|0;sa=j+4908|0;ta=j+4916|0;ua=j+572952|0;va=0;b:while(1){c[n>>2]=0;if((c[u>>2]|0)>0){wa=0;xa=va;while(1){c[p>>2]=(ba(c[I>>2]|0,xa)|0)+wa;ya=c[g>>2]|0;do{if((ya+7|0)<(c[v>>2]|0)){za=ya}else{Aa=ya&7;if((Aa|0)!=0){Ba=(c[s>>2]|0)+(ya>>>3)|0;if(((fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<Aa>>>((32-(-ya&7)|0)>>>0)|0)!=0){za=ya;break}}Aa=c[ua>>2]|0;Ba=c[w>>2]|0;c[g>>2]=Ba>>>0>Aa>>>0?Aa:Ba;c[v>>2]=t;if((WZa(b)|0)!=0){o=-1;K=212;break b}za=c[g>>2]|0}}while(0);ya=c[w>>2]|0;Ba=c[s>>2]|0;Aa=Ba+(za>>>3)|0;Ca=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(za&7);if((Ca&-1434451968|0)==0){Aa=1;Da=za;Ea=Ca;while(1){Fa=Ea>>>24;Ga=a[1201432+Fa|0]|0;Ha=Ga&255;Ia=((Ga&255)>>>0>8>>>0?8:Ha)+Da|0;Ja=ya>>>0>Ia>>>0;Ka=Ja?Ia:ya;if(!(Ga<<24>>24==9)){K=53;break}Ga=d[1201688+Fa|0]|Aa<<4;if(!(Ga>>>0<134217728>>>0)){La=Ga;break}Ia=Ba+(Ka>>>3)|0;Ma=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ka&7);if(Ja){Aa=Ga;Da=Ka;Ea=Ma}else{La=Ga;break}}if((K|0)==53){K=0;La=d[1201688+Fa|0]|Aa<<(Ha-1>>1)}c[g>>2]=Ka;Na=La-1|0;Oa=Ka}else{Ea=Ca>>>24;Da=(d[1201432+Ea|0]|0)+za|0;Ga=ya>>>0>Da>>>0?Da:ya;c[g>>2]=Ga;Na=d[1200920+Ea|0]|0;Oa=Ga}Ga=c[y>>2]|0;if((Ga|0)==3){Pa=Na>>>0>3>>>0?Na+4|0:Na}else if((Ga|0)==1){Pa=Na+8|0}else{Pa=Na}if(Pa>>>0>33>>>0){break b}Ea=c[p>>2]|0;Da=c[n>>2]|0;Ma=c[q>>2]|0;Ja=(ba(Ma<<2,c[A>>2]|0)|0)+(Da<<2)|0;c[E>>2]=(Ma|0)==0?13311:65535;c[L>>2]=(Da|0)==0?24415:65535;c[M>>2]=65535;Ia=(Pa|0)==0;c:do{if(Ia){do{if((Ga|0)!=2){Qa=c[(c[(c[N>>2]|0)+1536>>2]|0)+(Ea<<2)>>2]|0;if((Qa|0)==-1){break}Ra=Qa>>>0>6>>>0?6:Qa;if((ZZa(k,Ra,4,0,0)|0)<0){break b}if((ZZa(k,Ra,4,1,1)|0)<0){break b}else{Sa=8;Ta=0;K=132;break c}}}while(0);YZa(k,Da<<4,Ma<<4,16,16,0,0,0,0,0,0);Ra=c[y>>2]|0;if((Ra|0)!=3){Ua=2048;Va=0;Wa=Ra;K=128;break}YZa(k,c[n>>2]<<4,c[q>>2]<<4,16,16,0,0,0,0,1,1);Xa=2048;Ya=0;K=127}else{if(!(Pa>>>0<8>>>0)){Ra=(Pa|0)==8;if(!((Pa|0)==33|(Pa|0)==8)){Qa=Pa-8|0;Za=d[918506+(Qa<<2)|0]|0;_a=Pca(l,Za>>>1^1^-(Za&1)&3,0)|0;c[ca>>2]=_a;if((_a|0)<0){yDb(c[da>>2]|0,16,2350392,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;if((c[ca>>2]|0)==0){break}else{break b}}else{Xa=2;Ya=d[918507+(Qa<<2)|0]|0;K=127;break}}TGb(ea|0,-1|0,40)|0;if(Ra){do{if((Da|0)>0){Qa=(c[R>>2]|0)+(Ea-1<<2)|0;_a=c[Q>>2]|0;Za=a[_a+((c[Qa>>2]|0)+6)|0]|0;a[fa]=Za;a[ga]=a[_a+((c[Qa>>2]|0)+5)|0]|0;a[ha]=a[_a+((c[Qa>>2]|0)+4)|0]|0;a[ia]=a[_a+((c[Qa>>2]|0)+3)|0]|0;if(!(Za<<24>>24==-1)){break}c[L>>2]=24415}}while(0);do{if((Ma|0)>0){Za=(c[R>>2]|0)+(Ea-(c[I>>2]|0)<<2)|0;Qa=c[Q>>2]|0;_a=a[Qa+(c[Za>>2]|0)|0]|0;a[ja]=_a;a[ka]=a[Qa+((c[Za>>2]|0)+1)|0]|0;a[la]=a[Qa+((c[Za>>2]|0)+2)|0]|0;a[ma]=a[Qa+((c[Za>>2]|0)+3)|0]|0;if(!(_a<<24>>24==-1)){$a=0;break}c[E>>2]=13311;$a=0}else{$a=0}}while(0);while(1){if(($a|0)>=16){break}_a=c[g>>2]|0;Za=c[w>>2]|0;Qa=c[s>>2]|0;ab=Qa+(_a>>>3)|0;bb=(fe(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(_a&7);if((bb&-1434451968|0)==0){ab=1;cb=_a;db=bb;while(1){eb=db>>>24;fb=a[1201432+eb|0]|0;gb=fb&255;hb=((fb&255)>>>0>8>>>0?8:gb)+cb|0;ib=Za>>>0>hb>>>0;jb=ib?hb:Za;if(!(fb<<24>>24==9)){K=112;break}fb=d[1201688+eb|0]|ab<<4;if(!(fb>>>0<134217728>>>0)){kb=fb;break}hb=Qa+(jb>>>3)|0;lb=(fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(jb&7);if(ib){ab=fb;cb=jb;db=lb}else{kb=fb;break}}if((K|0)==112){K=0;kb=d[1201688+eb|0]|ab<<(gb-1>>1)}c[g>>2]=jb;mb=kb-1|0}else{db=bb>>>24;cb=(d[1201432+db|0]|0)+_a|0;c[g>>2]=Za>>>0>cb>>>0?cb:Za;mb=d[1200920+db|0]|0}if(mb>>>0>24>>>0){K=117;break b}db=d[473144+$a|0]|0;cb=a[(d[405104+(mb<<1)|0]|0)+(404920+(((a[db-8+(k+4888)|0]|0)+1|0)*30|0)+(((a[db-1+(k+4888)|0]|0)+1|0)*5|0))|0]|0;a[k+4888+db|0]=cb;Qa=a[(d[405105+(mb<<1)|0]|0)+(404920+(((a[db-7+(k+4888)|0]|0)+1|0)*30|0)+(((cb<<24>>24)+1|0)*5|0))|0]|0;a[db+1+(k+4888)|0]=Qa;if(cb<<24>>24==-1|Qa<<24>>24==-1){K=119;break b}else{$a=$a+2|0}}nb=c[p>>2]|0;ob=c[na>>2]|0}else{x=33686018;a[ra]=x;x=x>>8;a[ra+1|0]=x;x=x>>8;a[ra+2|0]=x;x=x>>8;a[ra+3|0]=x;x=33686018;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;x=33686018;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;x=33686018;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;nb=Ea;ob=33686018}Qa=c[Q>>2]|0;cb=c[(c[R>>2]|0)+(nb<<2)>>2]|0;c[Qa+cb>>2]=ob;a[Qa+(cb+4)|0]=a[oa]|0;a[Qa+(cb+5)|0]=a[pa]|0;a[Qa+(cb+6)|0]=a[qa]|0;if(Ra){Oca(l)|0;c[E>>2]=(c[q>>2]|0)==0?13311:65535;pb=(c[n>>2]|0)==0?24415:65535}else{x=185273099;a[ra]=x;x=x>>8;a[ra+1|0]=x;x=x>>8;a[ra+2|0]=x;x=x>>8;a[ra+3|0]=x;x=185273099;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;x=185273099;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;x=185273099;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[E>>2]=13311;pb=24415}c[L>>2]=pb;Xa=1;Ya=0;K=127;break}cb=c[$>>2]|0;Qa=c[aa>>2]|0;if((cb|0)==0){qb=Oa;K=71}else{db=d[Ba+(Oa>>>3)|0]<<(Oa&7);fb=((Oa|0)<(ya|0))+Oa|0;c[g>>2]=fb;if((Qa|0)==(db>>>7&1^1|0)){rb=3}else{qb=fb;K=71}}do{if((K|0)==71){K=0;if((Qa|0)!=0){fb=d[Ba+(qb>>>3)|0]<<(qb&7);c[g>>2]=((qb|0)<(ya|0))+qb;if((cb|0)==(fb>>>7&1^1|0)){rb=2;break}}rb=1}}while(0);cb=Ea-1|0;Qa=Ja-1|0;Ra=Ja+4|0;fb=0;db=Ga;while(1){if((fb|0)>=2){sb=db;break}do{if((c[n>>2]|0)>0){if((a[(c[Q>>2]|0)+((c[(c[R>>2]|0)+(cb<<2)>>2]|0)+6)|0]|0)==-1){K=77;break}lb=k+4052+(fb<<2)|0;c[k+5312+(fb*160|0)+44>>2]=c[(c[lb>>2]|0)+(Qa<<2)>>2];ib=c[A>>2]|0;c[k+5312+(fb*160|0)+76>>2]=c[(c[lb>>2]|0)+(ib+Qa<<2)>>2];c[k+5312+(fb*160|0)+108>>2]=c[(c[lb>>2]|0)+((ib<<1)+Qa<<2)>>2];c[k+5312+(fb*160|0)+140>>2]=c[(c[lb>>2]|0)+((ib*3|0)+Qa<<2)>>2]}else{K=77}}while(0);if((K|0)==77){K=0;c[k+5312+(fb*160|0)+44>>2]=0;c[k+5312+(fb*160|0)+76>>2]=0;c[k+5312+(fb*160|0)+108>>2]=0;c[k+5312+(fb*160|0)+140>>2]=0}do{if((c[q>>2]|0)>0){Za=k+4052+(fb<<2)|0;UGb(k+5312+(fb*160|0)+16|0,(c[Za>>2]|0)+(Ja-(c[A>>2]|0)<<2)|0,16)|0;_a=c[R>>2]|0;TGb(k+5632+(fb*40|0)+4|0,((a[(c[Q>>2]|0)+(c[_a+(Ea-(c[I>>2]|0)<<2)>>2]|0)|0]|0)==-1?-2:1)|0,4)|0;if((c[n>>2]|0)<((c[u>>2]|0)-1|0)){c[k+5312+(fb*160|0)+32>>2]=c[(c[Za>>2]|0)+(Ra-(c[A>>2]|0)<<2)>>2];bb=Ea-(c[I>>2]|0)|0;ab=c[Q>>2]|0;if((a[ab+((c[_a+(bb+1<<2)>>2]|0)+6)|0]|0)==-1){tb=-2}else{tb=(a[ab+(c[_a+(bb<<2)>>2]|0)|0]|0)==-1?-2:1}a[k+5632+(fb*40|0)+8|0]=tb}else{a[k+5632+(fb*40|0)+8|0]=-2}if((c[n>>2]|0)>0){c[k+5312+(fb*160|0)+12>>2]=c[(c[Za>>2]|0)+(Qa-(c[A>>2]|0)<<2)>>2];a[k+5632+(fb*40|0)+3|0]=(a[(c[Q>>2]|0)+((c[(c[R>>2]|0)+(cb-(c[I>>2]|0)<<2)>>2]|0)+3)|0]|0)==-1?-2:1;break}else{a[k+5632+(fb*40|0)+3|0]=-2;break}}else{Za=k+5632+(fb*40|0)+3|0;bb=Za|0;x=-16843010;a[bb]=x;x=x>>8;a[bb+1|0]=x;x=x>>8;a[bb+2|0]=x;x=x>>8;a[bb+3|0]=x;bb=Za+4|0;x=-16843010;a[bb]=x;x=x>>8;a[bb+1|0]=x;x=x>>8;a[bb+2|0]=x;x=x>>8;a[bb+3|0]=x}}while(0);bb=c[y>>2]|0;if((bb|0)==3){fb=fb+1|0;db=3}else{sb=bb;break}}if((sb|0)==2){if((ZZa(k,Pa-1|0,rb,0,0)|0)<0){break b}else{Sa=8;Ta=0;K=132;break}}do{if((Pa|0)==2){TGb((c[O>>2]|0)+(Ja<<2)|0,0,16)|0;TGb((c[O>>2]|0)+((c[A>>2]|0)+Ja<<2)|0,0,16)|0;TGb((c[O>>2]|0)+((c[A>>2]<<1)+Ja<<2)|0,0,16)|0;TGb((c[O>>2]|0)+(((c[A>>2]|0)*3|0)+Ja<<2)|0,0,16)|0}else{if((ZZa(k,0,rb,0,0)|0)<0){break b}if((Pa|0)!=1){break}TGb((c[P>>2]|0)+(Ja<<2)|0,0,16)|0;TGb((c[P>>2]|0)+((c[A>>2]|0)+Ja<<2)|0,0,16)|0;TGb((c[P>>2]|0)+((c[A>>2]<<1)+Ja<<2)|0,0,16)|0;TGb((c[P>>2]|0)+(((c[A>>2]|0)*3|0)+Ja<<2)|0,0,16)|0;Sa=8;Ta=0;K=132;break c}}while(0);if((ZZa(k,0,rb,1,(Pa|0)==3|0)|0)<0){break b}else{Sa=8;Ta=0;K=132}}}while(0);if((K|0)==127){K=0;Ua=Xa;Va=Ya;Wa=c[y>>2]|0;K=128}if((K|0)==128){K=0;do{if((Wa|0)!=1){TGb((c[O>>2]|0)+(Ja<<2)|0,0,16)|0;TGb((c[O>>2]|0)+((c[A>>2]|0)+Ja<<2)|0,0,16)|0;TGb((c[O>>2]|0)+((c[A>>2]<<1)+Ja<<2)|0,0,16)|0;TGb((c[O>>2]|0)+(((c[A>>2]|0)*3|0)+Ja<<2)|0,0,16)|0;if((c[y>>2]|0)!=3){break}TGb((c[P>>2]|0)+(Ja<<2)|0,0,16)|0;TGb((c[P>>2]|0)+((c[A>>2]|0)+Ja<<2)|0,0,16)|0;TGb((c[P>>2]|0)+((c[A>>2]<<1)+Ja<<2)|0,0,16)|0;TGb((c[P>>2]|0)+(((c[A>>2]|0)*3|0)+Ja<<2)|0,0,16)|0}}while(0);Ja=Ua&1;if((Ja|0)==0){Sa=Ua;Ta=Va;K=132}else{ub=Ua;vb=Va;wb=Ja;K=133}}if((K|0)==132){K=0;Ja=(c[Q>>2]|0)+(c[(c[R>>2]|0)+(Ea<<2)>>2]|0)|0;Ga=Ja|0;x=33686018;a[Ga]=x;x=x>>8;a[Ga+1|0]=x;x=x>>8;a[Ga+2|0]=x;x=x>>8;a[Ga+3|0]=x;Ga=Ja+4|0;x=33686018;a[Ga]=x;x=x>>8;a[Ga+1|0]=x;x=x>>8;a[Ga+2|0]=x;x=x>>8;a[Ga+3|0]=x;ub=Sa;vb=Ta;wb=0;K=133}do{if((K|0)==133){K=0;Ga=(ub&2048|0)!=0;if(Ga){if((c[y>>2]|0)==3){K=135}}else{K=135}if((K|0)==135){K=0;TGb(S|0,0,112)|0}Ja=ub&2;ya=(Ja|0)!=0;do{if(ya){xb=vb;K=151}else{if(Ga){Ba=c[y>>2]|0;if((Ba|0)==3){K=139}else{yb=vb;zb=Ba}}else{K=139}if((K|0)==139){K=0;Ba=c[g>>2]|0;Ma=c[w>>2]|0;Da=c[s>>2]|0;Ca=Da+(Ba>>>3)|0;Aa=(fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(Ba&7);if((Aa&-1434451968|0)==0){Ca=1;db=Ba;fb=Aa;while(1){Ab=fb>>>24;cb=a[1201432+Ab|0]|0;Bb=cb&255;Qa=((cb&255)>>>0>8>>>0?8:Bb)+db|0;Ra=Ma>>>0>Qa>>>0;Cb=Ra?Qa:Ma;if(!(cb<<24>>24==9)){K=142;break}cb=d[1201688+Ab|0]|Ca<<4;if(!(cb>>>0<134217728>>>0)){Db=cb;break}Qa=Da+(Cb>>>3)|0;bb=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Cb&7);if(Ra){Ca=cb;db=Cb;fb=bb}else{Db=cb;break}}if((K|0)==142){K=0;Db=d[1201688+Ab|0]|Ca<<(Bb-1>>1)}c[g>>2]=Cb;Eb=Db-1|0}else{fb=Aa>>>24;db=(d[1201432+fb|0]|0)+Ba|0;c[g>>2]=Ma>>>0>db>>>0?db:Ma;Eb=d[1200920+fb|0]|0}if(Eb>>>0>47>>>0){K=147;break b}yb=d[((ub&3|0)==0?986504:986392)+Eb|0]|0;zb=c[y>>2]|0}if((zb|0)==1){Fb=yb;break}if((c[_>>2]|0)==0|(yb|0)==0){Fb=yb}else{xb=yb;K=151}}}while(0);if((K|0)==151){K=0;Ga=c[g>>2]|0;fb=c[w>>2]|0;db=c[s>>2]|0;Da=db+(Ga>>>3)|0;cb=(fe(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Ga&7);do{if((cb&-1434451968|0)==0){Da=Ga+8|0;bb=fb>>>0>Da>>>0?Da:fb;Da=db+(bb>>>3)|0;Ra=(fe(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(bb&7)>>>8|cb;Da=Ra|1;if((Ra&-1431655766|0)==0){Gb=-2147483648;break}if((Da|0)>-1){Ra=Da;Qa=31;while(1){Za=Qa-1|0;_a=(Ra>>>30|Ra<<2)-(Ra<<Qa>>>(Za>>>0))|0;if((_a|0)>-1){Ra=_a;Qa=Za}else{Hb=_a;Ib=Za;break}}}else{Hb=Da;Ib=31}Qa=bb+55-(Ib<<1)|0;c[g>>2]=fb>>>0>Qa>>>0?Qa:fb;Gb=((Hb<<Ib>>>(Ib>>>0))-1^-(Hb&1))+1>>1}else{Qa=cb>>>24;Ra=(d[1201432+Qa|0]|0)+Ga|0;c[g>>2]=fb>>>0>Ra>>>0?Ra:fb;Gb=a[1201176+Qa|0]|0}}while(0);Jb=(c[T>>2]|0)+Gb|0;c[T>>2]=Jb;if(Jb>>>0>31>>>0){K=158;break b}else{Fb=xb}}if(ya){TGb(U|0,0,32)|0;if((_Za(W,V,0,1)|0)!=0){K=161;break b}}d:do{if((Fb|0)==0){Kb=0}else{fb=Ja>>>1;Ga=(c[T>>2]|0)<24?wb+1|0:1;cb=0;do{e:do{if((1<<cb&Fb|0)!=0){db=cb<<2;Qa=db&8|cb<<1&2;Ra=0;while(1){if((Ra|0)>=4){break e}if(ya){Lb=Qa|Ra&1|Ra<<1&4}else{Lb=Ra+db|0}a[(d[473144+Lb|0]|0)+(k+5184)|0]=1;if((_Za(W,k+421200+(Lb<<4<<1)|0,fb,Ga)|0)==0){Ra=Ra+1|0}else{K=171;break b}}}}while(0);cb=cb+1|0;}while((cb|0)<4);if((Fb&48|0)==0){Kb=Fb;break}else{Mb=1}while(1){if((Mb|0)>=3){break}if((_Za(W,k+421200+(Mb<<8<<1)|0,0,3)|0)==0){Mb=Mb+1|0}else{K=176;break b}}if((Fb&32|0)==0){Kb=Fb;break}else{Nb=0}while(1){if((Nb|0)>=4){Ob=0;break}cb=Nb+16|0;a[(d[473144+cb|0]|0)+(k+5184)|0]=1;if((_Za(W,k+421200+(cb<<4<<1)|0,1,1)|0)==0){Nb=Nb+1|0}else{K=180;break b}}while(1){if((Ob|0)>=4){Kb=Fb;break d}cb=Ob+32|0;a[(d[473144+cb|0]|0)+(k+5184)|0]=1;if((_Za(W,k+421200+(cb<<4<<1)|0,1,1)|0)==0){Ob=Ob+1|0}else{K=180;break b}}}}while(0);c[X>>2]=Kb;c[(c[Y>>2]|0)+(Ea<<2)>>2]=ub;if((ub&3|0)==0){break}c[Z>>2]=Pca(l,0,1)|0}}while(0);if(Ia){if((c[X>>2]|0)!=0){K=189}}else{K=189}if((K|0)==189){K=0;Yca(l)}Ea=c[y>>2]|0;do{if((Ea|0)!=3){if((c[J>>2]|0)!=0){break}ya=(ba(c[I>>2]|0,c[q>>2]|0)|0)+(c[n>>2]|0)|0;c[(c[Y>>2]|0)+(ya<<2)>>2]=(Ea|0)==2&Pa>>>0<8>>>0?Pa-1|0:-1}}while(0);Ea=(c[n>>2]|0)+1|0;c[n>>2]=Ea;Ia=c[q>>2]|0;if((Ea|0)<(c[u>>2]|0)){wa=Ea;xa=Ia}else{Pb=Ia;break}}}else{Pb=va}xa=c[C>>2]|0;ZOa(b,c[z>>2]|0,(c[xa>>2]|0)==0?0:xa,Pb<<4,16,c[B>>2]|0,0,c[J>>2]|0);xa=(c[q>>2]|0)+1|0;c[q>>2]=xa;wa=c[D>>2]|0;if((xa|0)<(wa|0)){va=xa}else{Qb=xa;Rb=wa;break a}}if((K|0)==117){yDb(c[da>>2]|0,16,1913160,(H=i,i=i+8|0,c[H>>2]=mb,H)|0);i=H}else if((K|0)==119){yDb(c[da>>2]|0,16,1892688,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==147){yDb(c[da>>2]|0,16,2330088,(H=i,i=i+8|0,c[H>>2]=Eb,H)|0);i=H}else if((K|0)==158){yDb(c[da>>2]|0,16,2305584,(H=i,i=i+8|0,c[H>>2]=Jb,H)|0);i=H}else if((K|0)==161){yDb(c[da>>2]|0,16,2287704,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==171){yDb(c[da>>2]|0,16,2271616,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==176){yDb(c[da>>2]|0,16,2256240,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==180){yDb(c[da>>2]|0,16,2241848,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==212){i=h;return o|0}va=c[q>>2]|0;yDb(c[da>>2]|0,16,2002144,(H=i,i=i+16|0,c[H>>2]=c[n>>2],c[H+8>>2]=va,H)|0);i=H;o=-1;i=h;return o|0}else{Qb=0;Rb=F}}while(0);F=t-(c[g>>2]|0)|0;g=c[n>>2]|0;if((Qb|0)==(Rb|0)){if((g|0)!=(c[j+427400>>2]|0)){K=197}}else{K=197}if((K|0)==197){yDb(b,32,1964888,(H=i,i=i+32|0,c[H>>2]=c[b+428>>2],c[H+8>>2]=Qb,c[H+16>>2]=g,c[H+24>>2]=F,H)|0);i=H}if((F|0)<0){yDb(b,16,1936784,(H=i,i=i+16|0,c[H>>2]=c[b+428>>2],c[H+8>>2]=F,H)|0);i=H;o=-1;i=h;return o|0}do{if((c[y>>2]|0)==3){K=202}else{if((c[j+4808>>2]|0)!=0){K=202;break}H=c[j+572936>>2]|0;if((c[H>>2]|0)==0){Sb=G;break}Sb=MCb(e,H|0)|0}}while(0);if((K|0)==202){Sb=MCb(e,c[z>>2]|0)|0}if((Sb|0)<0){o=Sb;i=h;return o|0}if((c[c[j+572936>>2]>>2]|0)==0){if((c[j+4808>>2]|0)!=0){K=208}}else{K=208}if((K|0)==208){c[f>>2]=1}if((c[y>>2]|0)==3){KCb(c[z>>2]|0);o=m;i=h;return o|0}else{y=j+572932|0;j=c[y>>2]|0;c[y>>2]=c[z>>2];c[z>>2]=j;o=m;i=h;return o|0}return 0}function VZa(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;a=b+572928|0;d=c[a>>2]|0;XAb(d+1516|0);XAb(d+1548|0);XAb(d+1520|0);XAb(d+1552|0);XAb(d+1532|0);KCb(d|0);d=b+572932|0;e=c[d>>2]|0;XAb(e+1516|0);XAb(e+1548|0);XAb(e+1520|0);XAb(e+1552|0);XAb(e+1532|0);KCb(e|0);e=b+572936|0;f=c[e>>2]|0;XAb(f+1516|0);XAb(f+1548|0);XAb(f+1520|0);XAb(f+1552|0);XAb(f+1532|0);KCb(f|0);$Db(a);$Db(d);$Db(e);KCb(b+2528|0);Xca(b);$Db(b+572960|0);c[b+572964>>2]=0;$Db(b+572684|0);return 0}function WZa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;f=c[b+60>>2]|0;g=c[f+427412>>2]|0;h=f+1096|0;j=c[h>>2]|0;k=f+1104|0;l=c[k>>2]|0;m=f+1088|0;n=c[m>>2]|0;o=n+(j>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(j&7);o=p>>>24;q=j+8|0;j=l>>>0>q>>>0?q:l;c[h>>2]=j;q=o&159;if((q-1|0)>>>0>1>>>0|(o&96|0)==0){yDb(b,16,2217744,(r=i,i=i+8|0,c[r>>2]=o,r)|0);i=r;s=-1;i=e;return s|0}o=p>>>29&3;p=o<<3;t=n+(j>>>3)|0;u=j+p+((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(j&7)>>>((32-p|0)>>>0)<<3)|0;c[f+572952>>2]=u;p=f+1100|0;if((u|0)>(c[p>>2]|0)){yDb(b,16,2208432,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1;i=e;return s|0}b=o-1|0;c[p>>2]=u-(b<<3);u=j+8|0;j=l>>>0>u>>>0?u:l;c[h>>2]=j;l=c[f+572956>>2]|0;if((l|0)!=0){u=n+((j>>3)+1)|0;x=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24)^l;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x}if((o|0)!=0){o=c[m>>2]|0;VGb(o+(c[h>>2]>>3)|0,o+(c[p>>2]>>3)|0,b|0)|0}b=c[h>>2]|0;o=c[k>>2]|0;k=o-b|0;if((b|0)<0){v=-b|0}else{v=(k|0)<0?k:0}k=v+b|0;c[h>>2]=k;b=c[m>>2]|0;m=b+(k>>>3)|0;v=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(k&7);if((v&-1434451968|0)==0){m=1;u=k;l=v;while(1){w=l>>>24;j=a[1201432+w|0]|0;y=j&255;n=((j&255)>>>0>8>>>0?8:y)+u|0;t=o>>>0>n>>>0;z=t?n:o;if(!(j<<24>>24==9)){A=15;break}j=d[1201688+w|0]|0|m<<4;if(!(j>>>0<134217728>>>0)){B=j;break}n=b+(z>>>3)|0;C=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(z&7);if(t){m=j;u=z;l=C}else{B=j;break}}if((A|0)==15){B=d[1201688+w|0]|0|m<<(y-1>>1)}c[h>>2]=z;D=B-1|0;E=z}else{z=v>>>24;v=(d[1201432+z|0]|0)+k|0;k=o>>>0>v>>>0?v:o;c[h>>2]=k;D=d[1200920+z|0]|0;E=k}if(D>>>0>2>>>0){yDb(c[f>>2]|0,16,2199976,(r=i,i=i+8|0,c[r>>2]=D,r)|0);i=r;s=-1;i=e;return s|0}c[f+177076>>2]=d[986360+D|0]|0;if((q|0)==2){q=c[f+427408>>2]|0;if((q|0)<64){F=6}else{D=q-1|0;q=D>>>0>65535>>>0;r=q?D>>>16:D;D=q?16:0;if((r&65280|0)==0){G=D;H=r}else{G=D|8;H=r>>>8}F=G+1+(d[1191992+H|0]|0)|0}H=b+(E>>>3)|0;G=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(E&7)>>>((32-F|0)>>>0);H=E+F|0;F=o>>>0>H>>>0?H:o;c[h>>2]=F;H=ba(c[f+427400>>2]|0,c[f+427380>>2]|0)|0;c[f+427392>>2]=G-(c[f+427376>>2]|0)-H;I=F}else{F=E+1|0;E=o>>>0>F>>>0?F:o;c[h>>2]=E;c[f+427392>>2]=0;I=E}E=b+(I>>>3)|0;F=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(I&7)>>>24;E=I+8|0;I=o>>>0>E>>>0?E:o;c[h>>2]=I;c[f+177068>>2]=F;F=b+(I>>>3)|0;E=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>27;F=I+5|0;I=o>>>0>F>>>0?F:o;c[h>>2]=I;c[f+4792>>2]=E;c[f+572968>>2]=(d[b+(I>>>3)|0]|0)<<(I&7)>>>7&1;E=((I|0)<(o|0))+I+1|0;I=o>>>0>E>>>0?E:o;c[h>>2]=I;if((c[f+572948>>2]|0)==0){J=I}else{E=I+1|0;I=o>>>0>E>>>0?E:o;c[h>>2]=I;J=I}I=J+1|0;J=(o>>>0>I>>>0?I:o)+2|0;I=o>>>0>J>>>0?J:o;c[h>>2]=I;J=c[p>>2]|0;if((J-I|0)<1){s=-1094995529;i=e;return s|0}else{K=I}while(1){I=d[b+(K>>>3)|0]|0;p=((K|0)<(o|0))+K|0;c[h>>2]=p;if((I&128>>>((K&7)>>>0)|0)==0){break}I=p+8|0;p=o>>>0>I>>>0?I:o;c[h>>2]=p;if((J-p|0)<1){s=-1094995529;A=38;break}else{K=p}}if((A|0)==38){i=e;return s|0}A=f+427376|0;if((c[A>>2]|0)>0){K=f+4928|0;J=f+6104|0;h=(c[K>>2]|0)+((c[(c[J>>2]|0)+(g-1<<2)>>2]|0)+3)|0;x=-1;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=c[A>>2]|0;TGb((c[K>>2]|0)+(c[(c[J>>2]|0)+(g-h<<2)>>2]|0)|0,-1|0,h<<3|0)|0}if((c[f+427380>>2]|0)<=0){s=0;i=e;return s|0}h=f+4928|0;J=f+427404|0;K=f+6104|0;TGb((c[h>>2]|0)+(c[(c[K>>2]|0)+(g-(c[J>>2]|0)<<2)>>2]|0)|0,-1|0,(c[f+427400>>2]|0)-(c[A>>2]|0)<<3|0)|0;if((c[A>>2]|0)<=0){s=0;i=e;return s|0}a[(c[h>>2]|0)+((c[(c[K>>2]|0)+(g-1-(c[J>>2]|0)<<2)>>2]|0)+3)|0]=-1;s=0;i=e;return s|0}function XZa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[a+60>>2]|0;e=d+427404|0;f=c[e>>2]|0;g=c[d+427396>>2]|0;h=ba(g<<4,c[d+427400>>2]<<2|1)|0;i=b+1516|0;a:do{if((c[i>>2]|0)==0){j=VAb(f+1+(ba(g+1|0,f)|0)<<2)|0;k=b+1532|0;c[k>>2]=j;if((j|0)==0){l=-12;return l|0}c[b+1536>>2]=(c[j+4>>2]|0)+((c[e>>2]<<1|1)<<2);j=h+16|0;m=ba(f<<2,g)|0;c[i>>2]=VAb(j)|0;n=VAb(m)|0;o=b+1548|0;c[o>>2]=n;p=c[i>>2]|0;do{if(!((p|0)==0|(n|0)==0)){c[b+1524>>2]=(c[p+4>>2]|0)+16;c[b+1556>>2]=c[n+4>>2];q=b+1520|0;c[q>>2]=VAb(j)|0;r=VAb(m)|0;c[b+1552>>2]=r;s=c[q>>2]|0;if((s|0)==0|(r|0)==0){break}c[b+1528>>2]=(c[s+4>>2]|0)+16;c[b+1560>>2]=c[r+4>>2];t=5;break a}}while(0);u=-12;v=b|0;w=o;x=k}else{t=5}}while(0);do{if((t|0)==5){g=(c[d+572392>>2]|0)!=3|0;c[b+2192>>2]=g;f=b|0;h=_$a(a,f,g)|0;if((h|0)<0){u=h;v=f;w=b+1548|0;x=b+1532|0;break}f=d+572684|0;h=b+32|0;do{if((c[f>>2]|0)==0){g=cEb((c[h>>2]|0)*17|0)|0;c[f>>2]=g;if((g|0)==0){l=-12}else{break}return l|0}}while(0);c[d+4776>>2]=c[h>>2];c[d+4780>>2]=c[b+36>>2];l=0;return l|0}}while(0);XAb(i);XAb(w);XAb(b+1520|0);XAb(b+1552|0);XAb(x);KCb(v);l=u;return l|0}function YZa(a,b,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;m=c[((k|0)==0?a+572936|0:a+572932|0)>>2]|0;k=2-(e>>3)|0;n=g+b|0;g=h+d|0;h=c[a+572976>>2]|0;do{if((n|0)<0){if((n|0)<-16){o=-16;p=7}else{p=6}}else{if(!((n|0)>=(h+~e|0)|(g|0)<0)){q=c[a+572980>>2]|0;if((g|0)<(q+~f|0)){r=0;s=n;t=g;u=q;break}}p=6}}while(0);if((p|0)==6){q=h-e+15|0;o=(n|0)>(q|0)?q:n;p=7}do{if((p|0)==7){n=c[a+572980>>2]|0;q=n-f+15|0;if((g|0)<-16){r=1;s=o;t=-16;u=n;break}r=1;s=o;t=(g|0)>(q|0)?q:g;u=n}}while(0);g=a+4776|0;o=c[g>>2]|0;p=(c[a+2528>>2]|0)+((ba(o,d)|0)+b)|0;n=(c[m>>2]|0)+((ba(o,t)|0)+s)|0;if(r){q=a+572684|0;Ne[c[a+4>>2]&127](c[q>>2]|0,n,o,o,e+1|0,f+1|0,s,t,h,u);v=c[q>>2]|0}else{v=n}n=(j|0)!=0;j=(l|0)!=0;if(n){le[c[(j?a+1688|0:a+1644|0)+(i<<2)>>2]&1023](p,v,c[g>>2]|0,e,f)}else{cf[c[(j?a+572784|0:a+572720|0)+(k<<4)+(i<<2)>>2]&1023](p,v,c[g>>2]|0,f)}if((c[a+4816>>2]&8192|0)!=0){return}g=((s|0)<(b|0))+s>>1;s=((t|0)<(d|0))+t>>1;t=e>>1;e=f>>1;f=b>>1;b=d>>1;d=a+4780|0;v=a+4|0;p=a+572684|0;l=t+1|0;q=e+1|0;u=a+572976|0;h=a+572980|0;o=(j?a+1688|0:a+1644|0)+(i<<2)|0;w=(j?a+572784|0:a+572720|0)+(k+1<<4)+(i<<2)|0;i=c[d>>2]|0;k=(c[a+2532>>2]|0)+((ba(i,b)|0)+f)|0;j=(c[m+4>>2]|0)+((ba(i,s)|0)+g)|0;if(r){Ne[c[v>>2]&127](c[p>>2]|0,j,i,i,l,q,g,s,c[u>>2]>>1,c[h>>2]>>1);r=c[p>>2]|0;if(n){le[c[o>>2]&1023](k,r,c[d>>2]|0,t,e);x=c[d>>2]|0;y=(c[a+2536>>2]|0)+((ba(x,b)|0)+f)|0;z=(c[m+8>>2]|0)+((ba(x,s)|0)+g)|0;Ne[c[v>>2]&127](c[p>>2]|0,z,x,x,l,q,g,s,c[u>>2]>>1,c[h>>2]>>1);le[c[o>>2]&1023](y,c[p>>2]|0,c[d>>2]|0,t,e);return}else{cf[c[w>>2]&1023](k,r,c[d>>2]|0,e);r=c[d>>2]|0;y=(c[a+2536>>2]|0)+((ba(r,b)|0)+f)|0;x=(c[m+8>>2]|0)+((ba(r,s)|0)+g)|0;Ne[c[v>>2]&127](c[p>>2]|0,x,r,r,l,q,g,s,c[u>>2]>>1,c[h>>2]>>1);cf[c[w>>2]&1023](y,c[p>>2]|0,c[d>>2]|0,e);return}}else{if(n){le[c[o>>2]&1023](k,j,i,t,e);n=c[d>>2]|0;p=(c[a+2536>>2]|0)+((ba(n,b)|0)+f)|0;y=(c[m+8>>2]|0)+((ba(n,s)|0)+g)|0;le[c[o>>2]&1023](p,y,n,t,e);return}else{cf[c[w>>2]&1023](k,j,i,e);i=c[d>>2]|0;d=(c[a+2536>>2]|0)+((ba(i,b)|0)+f)|0;f=(c[m+8>>2]|0)+((ba(i,s)|0)+g)|0;cf[c[w>>2]&1023](d,f,i,e);return}}}function ZZa(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;k=i;if((f&5|0)==4){l=4}else{l=16>>>((f&1)>>>0)}m=16>>>((((f+1|0)>>>0)/3|0)>>>0);f=(g|0)==4;n=f?-96:0;o=(((c[e+572976>>2]|0)-l|0)*6|0)-n|0;p=(((c[e+572980>>2]|0)-m|0)*6|0)-n|0;q=e+427376|0;r=e+427380|0;s=e+6108|0;t=(g|0)!=4;u=l>>2;v=e+177088|0;w=e+5632+(h*40|0)+11|0;x=e+2524|0;y=e+5312+(h*160|0)+40|0;z=y|0;A=y;y=e+177092|0;B=e+4872|0;C=e+4852|0;D=e+427404|0;E=12288<<(h<<1);F=e+6100|0;G=e+5312+(h*160|0)+42|0;H=(m|0)==8;I=(l|0)==8;J=(l|0)==4|(m|0)==4;K=e+4052+(h<<2)|0;L=m>>2;M=u<<2;N=(L|0)==1;O=(L|0)==2;L=e+1096|0;P=e+1104|0;Q=e+1088|0;R=e+572932|0;S=(h|0)==0;T=e+428668|0;U=e+428672|0;V=0;a:while(1){W=V>>2;X=V>>>1&2|V&8;Y=H&(V|0)<8;Z=0;do{_=c[q>>2]|0;$=Z>>2;aa=c[r>>2]|0;ca=c[s>>2]|0;da=(_<<2)+$+(ba((aa<<2)+W|0,ca)|0)|0;ea=(_<<4)+Z|0;_=(aa<<4)+V|0;fa=X|$&1|Z>>>1&4;do{if(t){$=a[473144+fa|0]|0;ga=$&255;ha=ga-8|0;ia=a[e+5632+(h*40|0)+ha|0]|0;ja=ga-1|0;ka=a[e+5632+(h*40|0)+ja|0]|0;la=e+5312+(h*160|0)+(ja<<2)|0;ma=e+5312+(h*160|0)+(ha<<2)|0;na=ha+u|0;oa=a[e+5632+(h*40|0)+na|0]|0;pa=oa<<24>>24;qa=oa<<24>>24==-2;do{if((c[v>>2]|0)!=0&qa&($&255)>>>0>19>>>0&(ga&7|0)==4){if((a[w]|0)==-2){ra=15;break}oa=c[x>>2]|0;sa=c[oa+1536>>2]|0;c[A>>2]=0;ta=(c[B>>2]&128|0)==0;if((c[y>>2]|0)==0){if(ta){ra=15;break}ua=c[D>>2]|0;va=ua+(c[C>>2]|0)|0;wa=(aa<<1&2)+(ga>>>5)|0;if((c[sa+((ba(wa>>>2,ua)|0)+va<<2)>>2]&E|0)==0){xa=-1;ya=z;break}ua=(c[(c[F>>2]|0)+(va<<2)>>2]|0)+3+(ba(ca,wa)|0)|0;za=c[oa+1524+(h<<2)>>2]|0;b[z>>1]=b[za+(ua<<2)>>1]|0;b[G>>1]=b[za+(ua<<2)+2>>1]<<1;xa=a[(c[oa+1556+(h<<2)>>2]|0)+((wa&2147483646)+(va<<2|1))|0]>>1;ya=z;break}else{if(!ta){ra=15;break}ta=c[e+4852+((($&255)>>>0>35>>>0)<<2)>>2]|0;va=ga>>>2;if((c[sa+(ta<<2)>>2]&E|0)==0){xa=-1;ya=z;break}sa=(c[(c[F>>2]|0)+(ta<<2)>>2]|0)+3+(ba(ca,va&3)|0)|0;wa=c[oa+1524+(h<<2)>>2]|0;b[z>>1]=b[wa+(sa<<2)>>1]|0;b[G>>1]=(b[wa+(sa<<2)+2>>1]|0)/2|0;xa=a[(c[oa+1556+(h<<2)>>2]|0)+(va&2|ta<<2|1)|0]<<1;ya=z;break}}else{ra=15}}while(0);do{if((ra|0)==15){ra=0;if(qa){$=ga-9|0;xa=a[e+5632+(h*40|0)+$|0]|0;ya=e+5312+(h*160|0)+($<<2)|0;break}else{xa=pa;ya=e+5312+(h*160|0)+(na<<2)|0;break}}}while(0);na=ia<<24>>24==1;pa=ka<<24>>24==1;ga=(pa&1)+(na&1)+((xa|0)==1)|0;if((ga|0)>1){qa=b[la>>1]|0;$=qa<<16>>16;ta=b[ma>>1]|0;va=ta<<16>>16;oa=b[ya>>1]|0;sa=oa<<16>>16;do{if(qa<<16>>16>ta<<16>>16){if(!(oa<<16>>16>ta<<16>>16)){Aa=va;break}Aa=(sa|0)>($|0)?$:sa}else{if(!(ta<<16>>16>oa<<16>>16)){Aa=va;break}Aa=(sa|0)>($|0)?sa:$}}while(0);$=b[e+5312+(h*160|0)+(ja<<2)+2>>1]|0;sa=$<<16>>16;va=b[e+5312+(h*160|0)+(ha<<2)+2>>1]|0;oa=va<<16>>16;ta=b[ya+2>>1]|0;qa=ta<<16>>16;if($<<16>>16>va<<16>>16){if(!(ta<<16>>16>va<<16>>16)){Ba=oa;Ca=Aa;break}Ba=(qa|0)>(sa|0)?sa:qa;Ca=Aa;break}else{if(!(va<<16>>16>ta<<16>>16)){Ba=oa;Ca=Aa;break}Ba=(qa|0)>(sa|0)?qa:sa;Ca=Aa;break}}if((ga|0)==1){if(pa){Ba=b[e+5312+(h*160|0)+(ja<<2)+2>>1]|0;Ca=b[la>>1]|0;break}if(na){Ba=b[e+5312+(h*160|0)+(ha<<2)+2>>1]|0;Ca=b[ma>>1]|0;break}else{Ba=b[ya+2>>1]|0;Ca=b[ya>>1]|0;break}}sa=b[la>>1]|0;qa=sa<<16>>16;if(!((xa|0)!=-2|ia<<24>>24!=-2|ka<<24>>24==-2)){Ba=b[e+5312+(h*160|0)+(ja<<2)+2>>1]|0;Ca=qa;break}oa=b[ma>>1]|0;ta=oa<<16>>16;va=b[ya>>1]|0;$=va<<16>>16;do{if(sa<<16>>16>oa<<16>>16){if(!(va<<16>>16>oa<<16>>16)){Da=ta;break}Da=($|0)>(qa|0)?qa:$}else{if(!(oa<<16>>16>va<<16>>16)){Da=ta;break}Da=($|0)>(qa|0)?$:qa}}while(0);qa=b[e+5312+(h*160|0)+(ja<<2)+2>>1]|0;$=qa<<16>>16;ta=b[e+5312+(h*160|0)+(ha<<2)+2>>1]|0;va=ta<<16>>16;oa=b[ya+2>>1]|0;sa=oa<<16>>16;if(qa<<16>>16>ta<<16>>16){if(!(oa<<16>>16>ta<<16>>16)){Ba=va;Ca=Da;break}Ba=(sa|0)>($|0)?$:sa;Ca=Da;break}else{if(!(ta<<16>>16>oa<<16>>16)){Ba=va;Ca=Da;break}Ba=(sa|0)>($|0)?sa:$;Ca=Da;break}}else{$=c[(c[R>>2]|0)+1524>>2]|0;sa=b[$+(da<<2)>>1]<<1;va=b[$+(da<<2)+2>>1]<<1;$=c[T>>2]|0;if(S){oa=ba(sa,$)|0;ta=c[U>>2]|0;Ba=((ba(va,$)|0)/(ta|0)|0)+1>>1;Ca=((oa|0)/(ta|0)|0)+1>>1;break}else{ta=c[U>>2]|0;oa=$-ta|0;Ba=((ba(oa,va)|0)/(ta|0)|0)+1>>1;Ca=((ba(oa,sa)|0)/(ta|0)|0)+1>>1;break}}}while(0);ca=ea*6|0;aa=n-ca|0;ta=o-ca|0;if((Ca|0)<(aa|0)){Ea=aa}else{Ea=(Ca|0)>(ta|0)?ta:Ca}ta=_*6|0;aa=n-ta|0;ca=p-ta|0;if((Ba|0)<(aa|0)){Fa=aa}else{Fa=(Ba|0)>(ca|0)?ca:Ba}do{if(f){Ga=0;Ha=0;ra=71}else{ca=c[L>>2]|0;aa=c[P>>2]|0;ta=c[Q>>2]|0;sa=ta+(ca>>>3)|0;oa=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ca&7);do{if((oa&-1434451968|0)==0){sa=ca+8|0;va=aa>>>0>sa>>>0?sa:aa;sa=ta+(va>>>3)|0;$=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(va&7)>>>8|oa;sa=$|1;if(($&-1431655766|0)==0){Ia=-2147483648;Ja=ca;break}if((sa|0)>-1){$=sa;qa=31;while(1){ma=qa-1|0;ka=($>>>30|$<<2)-($<<qa>>>(ma>>>0))|0;if((ka|0)>-1){$=ka;qa=ma}else{Ka=ka;La=ma;break}}}else{Ka=sa;La=31}qa=va+55-(La<<1)|0;$=aa>>>0>qa>>>0?qa:aa;c[L>>2]=$;Ia=((Ka<<La>>>(La>>>0))-1^-(Ka&1))+1>>1;Ja=$}else{$=oa>>>24;qa=(d[1201432+$|0]|0)+ca|0;ma=aa>>>0>qa>>>0?qa:aa;c[L>>2]=ma;Ia=a[1201176+$|0]|0;Ja=ma}}while(0);ca=ta+(Ja>>>3)|0;oa=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(Ja&7);if((oa&-1434451968|0)==0){ca=Ja+8|0;ha=aa>>>0>ca>>>0?ca:aa;ca=ta+(ha>>>3)|0;ja=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(ha&7)>>>8|oa;ca=ja|1;if((ja&-1431655766|0)==0){break a}if((ca|0)>-1){ja=ca;ma=31;while(1){$=ma-1|0;qa=(ja>>>30|ja<<2)-(ja<<ma>>>($>>>0))|0;if((qa|0)>-1){ja=qa;ma=$}else{Ma=qa;Na=$;break}}}else{Ma=ca;Na=31}ma=ha+55-(Na<<1)|0;c[L>>2]=aa>>>0>ma>>>0?ma:aa;Oa=((Ma<<Na>>>(Na>>>0))-1^-(Ma&1))+1>>1}else{ma=oa>>>24;ja=(d[1201432+ma|0]|0)+Ja|0;c[L>>2]=aa>>>0>ja>>>0?ja:aa;Oa=a[1201176+ma|0]|0}if((Ia|0)==-2147483648){break a}if((g|0)==4|(g|0)==2){Ga=Ia;Ha=Oa;ra=71;break}else if((g|0)==3){ma=Oa+(Ea+1>>1)|0;ja=Ia+(Fa+1>>1)|0;ta=(((ma+12288|0)>>>0)/3|0)-4096|0;$=(((ja+12288|0)>>>0)/3|0)-4096|0;YZa(e,ea,_,l,m,ta,$,(ta*-3|0)+ma+(($*-3|0)+ja<<2)|0,1,h,j);Pa=ja<<1;Qa=ma<<1;break}else{ma=Oa-4096+(((Ea+24579|0)>>>0)/6|0)|0;ja=Ia-4096+(((Fa+24579|0)>>>0)/6|0)|0;YZa(e,ea,_,l,m,ma,ja,0,0,h,j);Pa=ja*6|0;Qa=ma*6|0;break}}}while(0);if((ra|0)==71){ra=0;ma=Ha-4096+(((Ea+12289|0)>>>0)/3|0)|0;ja=Ga-4096+(((Fa+12289|0)>>>0)/3|0)|0;YZa(e,ea,_,l,m,ma>>1,ja>>1,ja<<1&2|ma&1,0,h,j);Pa=ja*3|0;Qa=ma*3|0}ma=Pa<<16|Qa&65535;do{if(t){do{if(Y){ja=d[473144+fa|0]|0;c[e+5312+(h*160|0)+(ja+8<<2)>>2]=ma;if(!(I&(Z|0)<8)){break}c[e+5312+(h*160|0)+(ja+9<<2)>>2]=ma}}while(0);if(I&(Z|0)<8){c[e+5312+(h*160|0)+((d[473144+fa|0]|0)+1<<2)>>2]=ma}if(!J){break}c[e+5312+(h*160|0)+(d[473144+fa|0]<<2)>>2]=ma}}while(0);fa=c[K>>2]|0;_=fa+(da<<2)|0;ea=_;aa=c[s>>2]|0;oa=aa<<2;do{if((M|0)==4){c[_>>2]=ma;if(N){break}c[ea+oa>>2]=ma;if(O){break}c[fa+(da<<2)+(oa<<1)>>2]=ma;c[fa+(da<<2)+((aa*6|0)<<1)>>2]=ma}else if((M|0)==16){c[_>>2]=ma;c[fa+(da<<2)+4>>2]=ma;c[fa+(da<<2)+8>>2]=ma;c[fa+(da<<2)+12>>2]=ma;c[ea+oa>>2]=ma;c[ea+(oa+4)>>2]=ma;c[ea+(oa+8)>>2]=ma;c[ea+(oa+12)>>2]=ma;if(O){break}ha=aa<<3;c[ea+ha>>2]=ma;c[ea+(ha|4)>>2]=ma;c[ea+(ha+8)>>2]=ma;c[ea+(ha+12)>>2]=ma;ha=aa*12|0;c[ea+ha>>2]=ma;c[ea+(ha+4)>>2]=ma;c[ea+(ha+8)>>2]=ma;c[ea+(ha+12)>>2]=ma}else if((M|0)==8){c[_>>2]=ma;c[fa+(da<<2)+4>>2]=ma;if(N){break}c[ea+oa>>2]=ma;c[ea+(oa+4)>>2]=ma;if(O){break}ha=aa<<3;c[ea+ha>>2]=ma;c[ea+(ha|4)>>2]=ma;ha=aa*12|0;c[ea+ha>>2]=ma;c[ea+(ha+4)>>2]=ma}}while(0);Z=Z+l|0;}while((Z|0)<16);Z=V+m|0;if((Z|0)<16){V=Z}else{Ra=0;ra=92;break}}if((ra|0)==92){i=k;return Ra|0}yDb(c[e>>2]|0,16,2229512,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;Ra=-1;i=k;return Ra|0}function _Za(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=(h*3|0)>>2;j=c[405288+(h<<2)>>2]|0;k=e+8|0;l=e+16|0;m=e|0;e=(h|0)==3;n=(i|0)==0;o=(h|0)==2;h=g;g=16>>>(i>>>0);a:while(1){if((h|0)>=16){p=0;q=31;break}r=c[l>>2]|0;s=c[m>>2]|0;t=h;u=c[k>>2]|0;while(1){v=s+(u>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(u&7);if((w&-1434451968|0)==0){v=1;x=u;y=w;while(1){z=y>>>24;A=a[1201432+z|0]|0;B=A&255;C=((A&255)>>>0>8>>>0?8:B)+x|0;D=r>>>0>C>>>0;E=D?C:r;if(!(A<<24>>24==9)){q=7;break}A=d[1201688+z|0]|0|v<<4;if(!(A>>>0<134217728>>>0)){F=A;break}C=s+(E>>>3)|0;G=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7);if(D){v=A;x=E;y=G}else{F=A;break}}if((q|0)==7){q=0;F=d[1201688+z|0]|0|v<<(B-1>>1)}c[k>>2]=E;H=F-1|0;I=E}else{y=w>>>24;x=(d[1201432+y|0]|0)+u|0;A=r>>>0>x>>>0?x:r;c[k>>2]=A;H=d[1200920+y|0]|0;I=A}if((H|0)==0){break}if((H|0)<0){p=-1;q=31;break a}A=(H&1)-1|0;y=H+1|0;x=y>>>1;do{if(e){if(y>>>0<6>>>0){J=0;K=x;break}if(y>>>0<8>>>0){J=1;K=1;break}G=x&3;J=G;K=((x+9|0)>>>2)-G|0}else{if(y>>>0<32>>>0){J=d[405304+(i<<5)+(x<<1)|0]|0;K=d[405304+(i<<5)+(x<<1)+1|0]|0;break}if(n){G=x&15;D=y>>>5;do{if((G|0)==0){L=4}else{if(G>>>0<3>>>0){L=2;break}L=G>>>0<10>>>0|0}}while(0);J=G;K=L+D|0;break}else{C=x&7;M=y>>>4;do{if((C|0)==0){N=8}else{if(C>>>0<2>>>0){N=2;break}N=(C>>>0>4>>>0)<<31>>31}}while(0);J=C;K=N+M|0;break}}}while(0);y=J+t|0;if((y|0)>=(g|0)){p=-1;q=31;break a}b[f+((d[j+y|0]|0)<<1)>>1]=(K^A)-A;t=y+1|0;u=I}if(o){h=g;g=g+8|0}else{p=0;q=31;break}}if((q|0)==31){return p|0}return 0}function $Za(a){a=a|0;c[a>>2]=2;return}function a_a(a,b,d,e,f,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0.0,U=0.0;k=c[d>>2]|0;Xe[c[a+44>>2]&4095](a,b+(k<<2)|0,i);i=c[d>>2]|0;a=512-i|0;l=k-497|0;m=k-512|0;n=k-481|0;o=k+15|0;p=k+31|0;if((a|0)>0){q=0;r=0}else{s=0;t=0;while(1){u=e+(s<<2)|0;v=s+16|0;w=e+(v<<2)|0;x=l+t|0;y=m+v|0;z=n+t|0;A=0;B=+g[u>>2];C=+g[w>>2];D=0.0;E=0.0;do{F=A+s|0;B=B+ +g[f+(F<<2)>>2]*(-0.0- +g[b+(x+A<<2)>>2]);C=C+ +g[f+(F+16<<2)>>2]*+g[b+(m+F<<2)>>2];D=D+ +g[f+(F+32<<2)>>2]*+g[b+(y+A<<2)>>2];E=E+ +g[f+(F+48<<2)>>2]*+g[b+(z+A<<2)>>2];A=A+64|0;}while((A|0)<512);g[h+(s<<2)>>2]=B*j;g[h+(v<<2)>>2]=C*j;g[u>>2]=D;g[w>>2]=E;A=s+1|0;z=~s;if((A|0)<16){s=A;t=z}else{break}}G=i+480|0;H=G&511;c[d>>2]=H;return}while(1){t=e+(q<<2)|0;s=q+16|0;z=e+(s<<2)|0;A=o+r|0;y=s+k|0;x=p+r|0;F=0;I=+g[t>>2];J=+g[z>>2];K=0.0;L=0.0;do{M=F+q|0;I=I+ +g[f+(M<<2)>>2]*(-0.0- +g[b+(A+F<<2)>>2]);J=J+ +g[f+(M+16<<2)>>2]*+g[b+(M+k<<2)>>2];K=K+ +g[f+(M+32<<2)>>2]*+g[b+(y+F<<2)>>2];L=L+ +g[f+(M+48<<2)>>2]*+g[b+(x+F<<2)>>2];F=F+64|0;}while((F|0)<(a|0));if((F|0)<512){x=l+r|0;y=m+s|0;A=n+r|0;w=F;E=I;D=J;C=K;B=L;while(1){u=w+q|0;N=E+ +g[f+(u<<2)>>2]*(-0.0- +g[b+(x+w<<2)>>2]);O=D+ +g[f+(u+16<<2)>>2]*+g[b+(m+u<<2)>>2];P=C+ +g[f+(u+32<<2)>>2]*+g[b+(y+w<<2)>>2];Q=B+ +g[f+(u+48<<2)>>2]*+g[b+(A+w<<2)>>2];u=w+64|0;if((u|0)<512){w=u;E=N;D=O;C=P;B=Q}else{R=N;S=O;T=P;U=Q;break}}}else{R=I;S=J;T=K;U=L}g[h+(q<<2)>>2]=R*j;g[h+(s<<2)>>2]=S*j;g[t>>2]=T;g[z>>2]=U;w=q+1|0;A=~q;if((w|0)<16){q=w;r=A}else{break}}G=i+480|0;H=G&511;c[d>>2]=H;return}function b_a(a,b){a=a|0;b=b|0;var c=0,e=0,f=0;if(b>>>0<4>>>0){c=-1094995529;return c|0}e=b-3|0;f=(d[a+(b-2)|0]|0)<<8|(d[a+e|0]|0)<<16|(d[a+(b-1)|0]|0);b=(f|0)==(uBb(tBb(12)|0,13501623,a,e)|0);c=b?0:-1094995529;return c|0}function c_a(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=a+8|0;g=c[f>>2]|0;h=a+16|0;i=c[h>>2]|0;j=c[a>>2]|0;a=j+(g>>>3)|0;k=g+6|0;c[b+4>>2]=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>((g&7)>>>0)&63;g=(i>>>0>k>>>0?k:i)+4|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=j+(k>>>3)|0;a=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0)&15;g=k+4|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=j+(k>>>3)|0;l=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0)&65535;g=k+16|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=j+(k>>>3)|0;m=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0);g=k+16|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=j+(k>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0)&7;g=k+3|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=b+48|0;c[g>>2]=m<<16|l;c[g+4>>2]=n;n=j+(k>>>3)|0;g=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((k&7)>>>0)&7;n=k+3|0;c[f>>2]=i>>>0>n>>>0?n:i;c[b+8>>2]=g;g=c[f>>2]|0;i=c[h>>2]|0;n=j+(g>>>3)|0;k=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((g&7)>>>0)&262143;n=g+18|0;c[f>>2]=i>>>0>n>>>0?n:i;i=b+12|0;c[i>>2]=k+6e3;k=c[f>>2]|0;n=c[h>>2]|0;g=j+(k>>>3)|0;l=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0)&31;g=k+5|0;c[f>>2]=n>>>0>g>>>0?g:n;c[b+20>>2]=l+8;l=c[f>>2]|0;n=c[h>>2]|0;g=j+(l>>>3)|0;k=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((l&7)>>>0)&15;g=l+4|0;c[f>>2]=n>>>0>g>>>0?g:n;n=b+16|0;c[n>>2]=k+1;k=c[f>>2]|0;g=d[j+(k>>>3)|0]|0;l=c[h>>2]|0;h=((k|0)<(l|0))+k|0;c[f>>2]=h;do{if((g&1<<(k&7)|0)==0){o=0;p=0}else{m=h+5|0;q=l>>>0>m>>>0?m:l;c[f>>2]=q;m=d[j+(q>>>3)|0]|0;r=((q|0)<(l|0))+q|0;c[f>>2]=r;if((1<<(q&7)&m|0)==0){o=0;p=0;break}if((c[n>>2]|0)>0){s=0;t=0;u=0;v=r}else{o=0;p=0;break}while(1){r=j+(v>>>3)|0;m=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((v&7)>>>0)&63;r=v+6|0;q=l>>>0>r>>>0?r:l;c[f>>2]=q;if(m>>>0<19>>>0){r=189824+(m<<3)|0;w=c[r+4>>2]|t;x=c[r>>2]|u}else{w=t;x=u}r=s+1|0;if((r|0)<(c[n>>2]|0)){s=r;t=w;u=x;v=q}else{o=w;p=x;break}}}}while(0);x=b+40|0;c[x>>2]=p;c[x+4>>2]=o;o=c[i>>2]|0;do{if(a>>>0<4>>>0){y=16384;z=(ba(e[1047200+(a<<1)>>1]|0,o)|0)>>5}else{if(a>>>0<10>>>0){y=o>>2;z=e[1047200+(a<<1)>>1]|0;break}else{A=-1094995529;B=b+28|0;c[B>>2]=A;return}}}while(0);A=(z|0)<1|(z|0)>(y|0)?-1094995529:z;B=b+28|0;c[B>>2]=A;return}function d_a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;h=b+8|0;j=c[h>>2]|0;k=b+16|0;l=c[k>>2]|0;m=b|0;n=c[m>>2]|0;o=n+(j>>>3)|0;p=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((j&7)>>>0)&65535;o=j+16|0;j=l>>>0>o>>>0?o:l;c[h>>2]=j;if((p|0)!=41215){yDb(a,f+16|0,2216984,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;q=-1094995529;i=g;return q|0}f=n+(j>>>3)|0;a=(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)>>>((j&7)>>>0)&7;f=j+3|0;c[h>>2]=l>>>0>f>>>0?f:l;l=e|0;c[l>>2]=a;a=c[h>>2]|0;f=c[k>>2]|0;j=n+(a>>>3)|0;p=(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)>>>((a&7)>>>0)&2097151;j=a+21|0;c[h>>2]=f>>>0>j>>>0?j:f;c[e+24>>2]=p;p=c[l>>2]|0;if((p&1|0)==0){c[e+32>>2]=0;r=p}else{p=c[h>>2]|0;f=c[k>>2]|0;j=n+(p>>>3)|0;n=(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)>>>((p&7)>>>0)&16383;j=p+14|0;c[h>>2]=f>>>0>j>>>0?j:f;c[e+32>>2]=n+1;n=c[k>>2]|0;f=(c[h>>2]|0)+2|0;c[h>>2]=n>>>0>f>>>0?f:n;r=c[l>>2]|0}do{if((r&2|0)!=0){c_a(b,e);n=c[h>>2]|0;f=c[k>>2]|0;j=(c[m>>2]|0)+(n>>>3)|0;p=n+6|0;a=f>>>0>p>>>0?p:f;if(((d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24)&63<<(n&7)|0)==0){s=a}else{n=a+25|0;s=f>>>0>n>>>0?n:f}c[h>>2]=s;n=-s&7;if((n|0)==0){break}a=n+s|0;c[h>>2]=f>>>0>a>>>0?a:f}}while(0);if((c[l>>2]&4|0)!=0){q=-1094995529;i=g;return q|0}l=c[k>>2]|0;k=(c[h>>2]|0)+24|0;c[h>>2]=l>>>0>k>>>0?k:l;q=0;i=g;return q|0}function e_a(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+168|0;k=j|0;l=j+8|0;m=j+16|0;n=j+96|0;o=j+104|0;p=j+112|0;c[k>>2]=g;c[l>>2]=h;q=c[b>>2]|0;r=q;s=(h|0)!=0?37:8;if((c[b+176>>2]&1|0)!=0){t=h>>>0>2147483639>>>0|(g|0)==0;u=t?0:g;g=t?0:h;c[m>>2]=u;c[m+12>>2]=g;c[m+16>>2]=g+8;c[m+4>>2]=u+(g+7>>3);c[m+8>>2]=0;if((d_a(d,m,j+40|0,127)|0)==0){g=c[q+72>>2]|0;if((g|0)==0){v=c[q+68>>2]|0}else{v=g}c[b+304>>2]=v}c[e>>2]=c[k>>2];v=c[l>>2]|0;c[f>>2]=v;w=v;i=j;return w|0}v=q+96|0;g=q+4|0;u=q;t=m|0;x=m+12|0;y=m+16|0;z=m+4|0;A=m+8|0;B=q+20|0;C=q+40|0;D=C;E=q+72|0;F=q+68|0;G=b+304|0;H=C;C=b+224|0;b=0;I=h;a:while(1){h=c[v>>2]|0;do{if((I|0)==0){J=c[g>>2]|0;if((h+s|0)>(J|0)){K=b;L=-100;break a}else{M=b;N=h;O=J;P=0}}else{J=c[g>>2]|0;if((h+37|0)<=(J|0)){M=b;N=h;O=J;P=I;break}c[n>>2]=(I|0)<74?I:74;c[o>>2]=c[k>>2];if(!((WRa(r,-100,o,n)|0)==-1)){w=-12;Q=33;break a}J=c[n>>2]|0;c[k>>2]=(c[k>>2]|0)+J;R=(c[l>>2]|0)-J|0;c[l>>2]=R;M=J+b|0;N=c[v>>2]|0;O=c[g>>2]|0;P=R}}while(0);if((N+s|0)>(O|0)){b=M;I=P;continue}else{S=N;T=O}do{h=c[u>>2]|0;R=h+S|0;do{if((a[R]|0)==-1){if(!((a[h+(S+1)|0]|0)==-96)){break}J=T-S<<3;U=J>>>0>2147483639>>>0;V=U?0:R;W=U?0:J;c[t>>2]=V;c[x>>2]=W;c[y>>2]=W+8;c[z>>2]=V+(W>>3);c[A>>2]=0;if((d_a(d,m,(c[B>>2]|0)==0?D:p,127)|0)!=0){break}if((b_a((c[u>>2]|0)+(c[v>>2]|0)|0,(c[A>>2]|0)/8|0)|0)!=0){break}if((c[B>>2]|0)!=0){Q=23;break a}c[B>>2]=1;W=c[E>>2]|0;if((W|0)==0){X=c[F>>2]|0}else{X=W}c[G>>2]=X;c[C>>2]=(c[H>>2]|0)>>>1&1}}while(0);S=(c[v>>2]|0)+1|0;c[v>>2]=S;T=c[g>>2]|0;}while((S+s|0)<=(T|0));b=M;I=c[l>>2]|0}if((Q|0)==23){c[B>>2]=0;B=(c[v>>2]|0)-(c[g>>2]|0)|0;c[v>>2]=0;K=M;L=B}else if((Q|0)==33){i=j;return w|0}if((K|0)==0){Q=27}else{if((c[l>>2]|0)==0&(L|0)==-100){Y=0}else{Q=27}}do{if((Q|0)==27){if((WRa(r,L,k,l)|0)<0){Y=c[l>>2]|0;break}if((L|0)==-100){Z=-100}else{B=K+L|0;c[q+24>>2]=(B|0)>0?0:-B|0;Z=B}c[e>>2]=c[k>>2];c[f>>2]=c[l>>2];w=Z;i=j;return w|0}}while(0);c[e>>2]=0;c[f>>2]=0;w=Y+K|0;i=j;return w|0}function f_a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a+60|0;e=c[d>>2]|0;Z3(e+4|0,a);c[e>>2]=a;e=a+796|0;c[e>>2]=c[a+792>>2];f=c[d>>2]|0;d=a+412|0;g=c[d>>2]|0;h=3-((g|0)/11025|0)|0;c[f+1324>>2]=((g+511>>9)+3&-4)<<((h|0)<0?0:h);c[f+1968>>2]=((c[d>>2]|0)+511>>9<<1)+6&-8;d=c[e>>2]|0;if((d|0)==24){c[a+420>>2]=7;j=0;i=b;return j|0}else if((d|0)==16){c[a+420>>2]=6;j=0;i=b;return j|0}else if((d|0)==8){c[a+420>>2]=5;j=0;i=b;return j|0}else{yDb(a,16,2350336,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;j=-1094995529;i=b;return j|0}return 0}function g_a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;j=i;i=i+16|0;k=j|0;l=e+60|0;m=c[l>>2]|0;n=m;c[k>>2]=f;c[k+4>>2]=0;c[k+8>>2]=0;o=m+1304|0;p=h+28|0;q=c[p>>2]|0;if((q|0)<8){r=-1094995529;i=j;return r|0}s=h+24|0;h=c[s>>2]|0;t=q>>>0>268435455>>>0?-8:q<<3;q=t>>>0>2147483639>>>0|(h|0)==0;u=q?0:h;h=q?0:t;t=o;c[t>>2]=u;v=m+1316|0;c[v>>2]=h;w=m+1320|0;c[w>>2]=h+8;c[m+1308>>2]=u+(h>>3);h=m+1312|0;c[h>>2]=0;if(q){r=q?-1094995529:0;i=j;return r|0}q=d_a(e,o,m+1248|0,0)|0;if((q|0)<0){r=q;i=j;return r|0}q=e+696|0;do{if((c[q>>2]&131073|0)==0){x=0}else{o=(c[h>>2]|0)/8|0;if((b_a(c[s>>2]|0,o)|0)==0){x=o;break}yDb(e,16,2181280,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;if((c[q>>2]&8|0)==0){x=o;break}else{r=-1094995529}i=j;return r|0}}while(0);o=m+1252|0;u=c[o>>2]|0;if(!((u|0)==2|(u|0)==4)){yDb(e,16,2104176,(y=i,i=i+8|0,c[y>>2]=u,y)|0);i=y;r=-1163346256;i=j;return r|0}z=c[m+1256>>2]|0;if((z|0)!=0){yDb(e,16,2047720,(y=i,i=i+8|0,c[y>>2]=z,y)|0);i=y;r=-1094995529;i=j;return r|0}z=c[m+1264>>2]|0;do{if((u|0)==2){if((z|0)<=2){break}yDb(e,16,2002088,(y=i,i=i+8|0,c[y>>2]=z,y)|0);i=y;r=-1094995529;i=j;return r|0}else{if((z|0)<=6){break}yDb(e,16,1964816,(y=i,i=i+8|0,c[y>>2]=z,y)|0);i=y;r=-1094995529;i=j;return r|0}}while(0);z=m+1264|0;u=m+1276|0;if((c[u>>2]|0)<1){yDb(e,16,1936704,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;r=-1094995529;i=j;return r|0}A=c[m+1268>>2]|0;B=e+796|0;c[B>>2]=A;if((A|0)==24){c[e+420>>2]=7}else if((A|0)==8){c[e+420>>2]=5}else if((A|0)==16){c[e+420>>2]=6}else{yDb(e,16,2350336,(y=i,i=i+8|0,c[y>>2]=A,y)|0);i=y;r=-1094995529;i=j;return r|0}A=c[m+1260>>2]|0;C=e+412|0;if((A|0)!=(c[C>>2]|0)){c[C>>2]=A;D=c[l>>2]|0;l=3-((A|0)/11025|0)|0;c[D+1324>>2]=((A+511>>9)+3&-4)<<((l|0)<0?0:l);c[D+1968>>2]=((c[C>>2]|0)+511>>9<<1)+6&-8}C=m+1288|0;D=c[C>>2]|0;l=c[C+4>>2]|0;if(!((D|0)==0&(l|0)==0)){C=e+448|0;c[C>>2]=D;c[C+4>>2]=l}l=e+416|0;c[l>>2]=c[z>>2];z=c[m+1280>>2]|0;if((z|0)==0){E=c[u>>2]|0}else{E=z}z=m+1328|0;c[z>>2]=E;c[f+76>>2]=E;E=W0a(e,k,0)|0;if((E|0)<0){r=E;i=j;return r|0}X0a(e);E=c[l>>2]|0;do{if((c[B>>2]|0)<17){k=m+1332|0;kEb(k,m+1336|0,DFb(0,E,c[z>>2]|0,7,0)|0);u=c[k>>2]|0;if((u|0)==0){r=-12;i=j;return r|0}k=EFb(m+1340|0,0,u,c[l>>2]|0,c[z>>2]|0,7,0)|0;if((k|0)<0){r=k}else{break}i=j;return r|0}else{if((E|0)<=0){break}k=f+64|0;u=m+1340|0;C=0;do{c[u+(C<<2)>>2]=c[(c[k>>2]|0)+(C<<2)>>2];C=C+1|0;}while((C|0)<(E|0))}}while(0);E=c[z>>2]|0;a:do{if((E|0)<16){C=c[l>>2]|0;if((C|0)<=0){break}k=m+1340|0;u=0;D=E;A=C;while(1){C=c[k+(u<<2)>>2]|0;if((D|0)>0){F=c[t>>2]|0;G=0;do{H=c[B>>2]|0;I=c[h>>2]|0;J=c[w>>2]|0;K=F+(I>>>3)|0;L=32-H|0;M=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((I&7)>>>0)<<L>>L;L=I+H|0;c[h>>2]=J>>>0>L>>>0?L:J;c[C+(G<<2)>>2]=M;G=G+1|0;N=c[z>>2]|0;}while((G|0)<(N|0));O=N;P=c[l>>2]|0}else{O=D;P=A}G=u+1|0;if((G|0)<(P|0)){u=G;D=O;A=P}else{break}}}else{A=c[o>>2]|0;b:do{if((A|0)==4){D=c[h>>2]|0;u=c[t>>2]|0;k=d[u+(D>>>3)|0]|0;G=c[w>>2]|0;C=((D|0)<(G|0))+D|0;c[h>>2]=C;c:do{if((k&1<<(D&7)|0)==0){F=c[l>>2]|0;if((F|0)<=0){break a}M=m+1973|0;J=0;while(1){a[M+(J<<2)|0]=0;a[M+(J<<2)+2|0]=J;L=J+1|0;if((L|0)<(F|0)){J=L}else{Q=F;break}}}else{F=u+(C>>>3)|0;J=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((C&7)>>>0)&15;F=C+4|0;M=G>>>0>F>>>0?F:G;c[h>>2]=M;F=J+1|0;if((F|0)>(c[l>>2]|0)){r=-1094995529;i=j;return r|0}J=m+1973|0;L=0;H=0;I=M;M=G;K=u;d:while(1){R=K+(I>>>3)|0;S=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((I&7)>>>0)&15;R=I+4|0;T=M>>>0>R>>>0?R:M;c[h>>2]=T;if((S|0)>=(c[l>>2]|0)){r=-1094995529;U=115;break}R=1<<S;if((R&L|0)!=0){r=-1094995529;U=115;break}V=(d[K+(T>>>3)|0]|0)>>>((T&7)>>>0);c[h>>2]=((T|0)<(M|0))+T;T=V&1;a[J+(H<<2)|0]=T;do{if(T<<24>>24==0){W=L}else{V=c[h>>2]|0;X=c[w>>2]|0;Y=(c[t>>2]|0)+(V>>>3)|0;Z=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((V&7)>>>0);Y=V+2|0;c[h>>2]=X>>>0>Y>>>0?Y:X;X=J+(H<<2)+1|0;a[X]=Z&3;Z=c[h>>2]|0;Y=c[w>>2]|0;V=(c[t>>2]|0)+(Z>>>3)|0;_=(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((Z&7)>>>0);V=Z+4|0;c[h>>2]=Y>>>0>V>>>0?V:Y;Y=_&15;a[J+(H<<2)+3|0]=Y;_=Y&255;if((a[X]|0)!=1){if((1<<_&L|0)==0){r=-1094995529;U=115;break d}else{W=L;break}}if((S|0)==(_|0)){r=-1094995529;U=115;break d}X=1<<_;if((X&L|0)!=0){r=-1094995529;U=115;break d}W=X|L}}while(0);a[J+(H<<2)+2|0]=S;T=H+1|0;if((T|0)>=(F|0)){Q=F;break c}L=W|R;H=T;I=c[h>>2]|0;M=c[w>>2]|0;K=c[t>>2]|0}if((U|0)==115){i=j;return r|0}}}while(0);if((Q|0)<=0){break}u=m+1973|0;G=m+1972|0;C=0;e:while(1){D=u+(C<<2)|0;do{if((a[D]|0)!=0){if((a[u+(C<<2)+1|0]|0)!=1){break}k=i_a(n,a[u+(C<<2)+3|0]|0)|0;if((k|0)!=0){r=k;U=115;break e}}}while(0);k=u+(C<<2)+2|0;K=i_a(n,a[k]|0)|0;if((K|0)!=0){r=K;U=115;break}if((a[D]|0)!=0){a[G]=a[679208+(a[u+(C<<2)+1|0]|0)|0]|0;K=j_a(n,a[u+(C<<2)+3|0]|0,a[k]|0,(c[z>>2]|0)-1|0)|0;if((K|0)!=0){r=K;U=115;break}}C=C+1|0;if((C|0)>=(Q|0)){break b}}if((U|0)==115){i=j;return r|0}}else if((A|0)==2){C=0;while(1){$=c[l>>2]|0;if((C|0)>=($|0)){break}u=i_a(n,C)|0;if((u|0)!=0){r=u;U=115;break}C=C+1|0}if((U|0)==115){i=j;return r|0}if(($|0)!=2){break}C=c[h>>2]|0;u=c[w>>2]|0;G=c[t>>2]|0;K=G+(C>>>3)|0;k=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((C&7)>>>0)&1;K=C+1|0;C=u>>>0>K>>>0?K:u;c[h>>2]=C;K=k+1|0;c[m+1948>>2]=K;if(K>>>0>1>>>0){K=G+(C>>>3)|0;k=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((C&7)>>>0);K=C+6|0;M=u>>>0>K>>>0?K:u;c[h>>2]=M;b[m+1954>>1]=k&63;aa=M}else{aa=C}C=G+(aa>>>3)|0;G=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((aa&7)>>>0);C=aa+3|0;c[h>>2]=u>>>0>C>>>0?C:u;a[m+1972|0]=G&7;G=j_a(n,0,1,(c[z>>2]|0)-1|0)|0;if((G|0)==0){break}else{r=G}i=j;return r|0}}while(0);if((c[l>>2]|0)<=0){break}A=m+1340|0;G=0;do{u=c[A+(G<<2)>>2]|0;C=a[m+(G+1404)|0]|0;if(!(C<<24>>24==0)){k_a(u,C<<24>>24,c[z>>2]|0)}C=m+(G+1420)|0;M=a[C]|0;f:do{if(M<<24>>24>0){if((c[z>>2]|0)>0){ba=0;ca=M}else{break}while(1){k=u+(ba<<2)|0;c[k>>2]=c[k>>2]<<(ca<<24>>24);k=ba+1|0;if((k|0)>=(c[z>>2]|0)){break f}ba=k;ca=a[C]|0}}}while(0);G=G+1|0;}while((G|0)<(c[l>>2]|0))}}while(0);ca=c[h>>2]|0;ba=-ca&7;n=c[w>>2]|0;if((ba|0)==0){da=ca}else{w=ba+ca|0;ca=n>>>0>w>>>0?w:n;c[h>>2]=ca;da=ca}ca=da+24|0;da=n>>>0>ca>>>0?ca:n;c[h>>2]=da;n=(c[v>>2]|0)-da|0;do{if((n|0)<0){yDb(e,48,1913096,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}else{if((n|0)<=0){break}yDb(e,48,1892664,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}}while(0);do{if((c[q>>2]&131073|0)!=0){if((b_a((c[s>>2]|0)+x|0,((c[h>>2]|0)/8|0)-x|0)|0)==0){break}yDb(e,16,2181280,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;if((c[q>>2]&8|0)==0){break}else{r=-1094995529}i=j;return r|0}}while(0);q=c[e+420>>2]|0;do{if((q|0)==6){e=c[l>>2]|0;if((e|0)<=0){break}y=c[f+64>>2]|0;x=m+1340|0;h=c[z>>2]|0;if((h|0)>0){ea=0}else{break}do{s=c[y+(ea<<2)>>2]|0;n=c[x+(ea<<2)>>2]|0;da=0;do{b[s+(da<<1)>>1]=c[n+(da<<2)>>2];da=da+1|0;}while((da|0)<(h|0));ea=ea+1|0;}while((ea|0)<(e|0))}else if((q|0)==7){e=c[l>>2]|0;if((e|0)<=0){break}h=c[f+64>>2]|0;x=0;y=c[z>>2]|0;da=e;while(1){e=c[h+(x<<2)>>2]|0;if((y|0)>0){n=0;do{s=e+(n<<2)|0;c[s>>2]=c[s>>2]<<8;n=n+1|0;fa=c[z>>2]|0;}while((n|0)<(fa|0));ga=fa;ha=c[l>>2]|0}else{ga=y;ha=da}n=x+1|0;if((n|0)<(ha|0)){x=n;y=ga;da=ha}else{break}}}else if((q|0)==5){da=c[l>>2]|0;if((da|0)<=0){break}y=f+64|0;x=m+1340|0;h=0;n=c[z>>2]|0;e=da;while(1){da=c[(c[y>>2]|0)+(h<<2)>>2]|0;s=c[x+(h<<2)>>2]|0;if((n|0)>0){v=0;do{a[da+v|0]=(c[s+(v<<2)>>2]|0)+128;v=v+1|0;ia=c[z>>2]|0;}while((v|0)<(ia|0));ja=ia;ka=c[l>>2]|0}else{ja=n;ka=e}v=h+1|0;if((v|0)<(ka|0)){h=v;n=ja;e=ka}else{break}}}}while(0);c[g>>2]=1;r=c[p>>2]|0;i=j;return r|0}function h_a(a){a=a|0;$Db((c[a+60>>2]|0)+1332|0);return 0}function i_a(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;h=i;i=i+1024|0;j=h|0;k=c[f>>2]|0;l=c[f+1340+(g<<2)>>2]|0;m=(c[f+1328>>2]|0)-1|0;n=f+1312|0;o=c[n>>2]|0;p=f+1304|0;q=c[p>>2]|0;r=d[q+(o>>>3)|0]|0;s=f+1320|0;t=c[s>>2]|0;u=((o|0)<(t|0))+o|0;c[n>>2]=u;if((r&1<<(o&7)|0)==0){v=0}else{o=q+(u>>>3)|0;q=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((u&7)>>>0)&15;o=u+4|0;c[n>>2]=t>>>0>o>>>0?o:t;v=q+1&255}a[f+1420+g|0]=v;q=v<<24>>24;v=c[k+796>>2]|0;if((q|0)>=(v|0)){w=-1094995529;i=h;return w|0}k=v-q|0;q=c[n>>2]|0;v=c[s>>2]|0;t=c[p>>2]|0;o=t+(q>>>3)|0;u=32-k|0;r=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((q&7)>>>0)<<u>>u;u=q+k|0;c[n>>2]=v>>>0>u>>>0?u:v;v=l+4|0;c[l>>2]=r;r=c[n>>2]|0;l=c[s>>2]|0;u=t+(r>>>3)|0;t=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((r&7)>>>0);u=r+2|0;c[n>>2]=l>>>0>u>>>0?u:l;a[f+1404+g|0]=t&3;t=c[n>>2]|0;g=c[s>>2]|0;l=c[p>>2]|0;u=l+(t>>>3)|0;r=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((t&7)>>>0)&7;u=t+3|0;t=g>>>0>u>>>0?u:g;c[n>>2]=t;u=r+1|0;k=f+1948|0;c[k>>2]=u;q=m&65535;do{if(u>>>0>1>>>0){if(((c[f+1316>>2]|0)-t|0)<((u*6|0)-6|0)){w=-1094995529;i=h;return w|0}a:do{if((r|0)==0){x=m;y=0}else{o=f+1968|0;z=m;A=0;B=0;C=t;D=g;E=l;while(1){F=E+(C>>>3)|0;G=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((C&7)>>>0)&63;F=C+6|0;c[n>>2]=D>>>0>F>>>0?F:D;F=(ba(G-B|0,c[o>>2]|0)|0)&65535;b[f+1952+(A<<1)>>1]=F;if(F<<16>>16<1){w=-1094995529;break}H=z-(F<<16>>16)|0;F=A+1|0;if((F|0)>=((c[k>>2]|0)-1|0)){x=H;y=F;break a}z=H;A=F;B=G;C=c[n>>2]|0;D=c[s>>2]|0;E=c[p>>2]|0}i=h;return w|0}}while(0);if((x|0)<1){w=-1094995529}else{I=y;J=x&65535;break}i=h;return w|0}else{I=0;J=q}}while(0);b[f+1952+(I<<1)>>1]=J;if((c[k>>2]|0)<=0){w=0;i=h;return w|0}J=f+1436|0;I=f+1438|0;q=f+1440|0;x=f+1442|0;y=j|0;l=f+1228|0;g=f+2176|0;t=f+2688|0;m=0;r=v;v=0;b:while(1){u=f+1952+(m<<1)|0;E=b[u>>1]|0;D=E<<16>>16;C=c[n>>2]|0;B=c[p>>2]|0;A=d[B+(C>>>3)|0]|0;z=c[s>>2]|0;o=((C|0)<(z|0))+C|0;c[n>>2]=o;c:do{if((A&1<<(C&7)|0)==0){G=l_a(f,r,D)|0;if((G|0)<0){w=G;K=71;break b}}else{G=B+(o>>>3)|0;F=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((o&7)>>>0)&15;G=o+4|0;H=z>>>0>G>>>0?G:z;c[n>>2]=H;G=e[562248+(F<<1)>>1]|0;do{if((v|0)>0){L=d[B+(H>>>3)|0]|0;M=((H|0)<(z|0))+H|0;c[n>>2]=M;if((L&1<<(H&7)|0)==0){N=M;K=19;break}if((G|0)>(v|0)){w=-1094995529;K=71;break b}if(E<<16>>16<0){w=-1094995529;K=71;break b}else{O=r+(-G<<2)|0;P=G+D|0}}else{N=H;K=19}}while(0);do{if((K|0)==19){K=0;if((G|0)>(D|0)){w=-1094995529;K=71;break b}H=B+(N>>>3)|0;M=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((N&7)>>>0)&3;H=N+2|0;c[n>>2]=z>>>0>H>>>0?H:z;if((M|0)==3){w=-1094995529;K=71;break b}H=l_a(f,r,G)|0;if((H|0)<0){w=H;K=71;break b}if((M|0)==0){O=r;P=D;break}k_a(r,M,G);O=r;P=D}}while(0);M=c[n>>2]|0;H=c[p>>2]|0;L=d[H+(M>>>3)|0]|0;Q=c[s>>2]|0;R=((M|0)<(Q|0))+M|0;c[n>>2]=R;if((L&1<<(M&7)|0)==0){S=0;T=R}else{M=H+(R>>>3)|0;L=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((R&7)>>>0)&15;M=R+4|0;R=Q>>>0>M>>>0?M:Q;c[n>>2]=R;S=L+1|0;T=R}R=(d[H+(T>>>3)|0]|0)>>>((T&7)>>>0);L=((T|0)<(Q|0))+T|0;c[n>>2]=L;M=R&1;R=M|6;U=d[H+(L>>>3)|0]|0;V=((L|0)<(Q|0))+L|0;c[n>>2]=V;if((1<<(L&7)&U|0)==0){W=10;X=V}else{U=H+(V>>>3)|0;L=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((V&7)>>>0)&7;U=V+3|0;V=Q>>>0>U>>>0?U:Q;c[n>>2]=V;U=9-L|0;if(U>>>0<3>>>0){w=-1094995529;K=71;break b}else{W=U;X=V}}V=H+(X>>>3)|0;U=(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((X&7)>>>0)<<22>>22;V=X+10|0;L=Q>>>0>V>>>0?V:Q;c[n>>2]=L;V=U&65535;b[J>>1]=V;U=H+(L>>>3)|0;Y=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((L&7)>>>0)<<22>>22;U=L+10|0;L=Q>>>0>U>>>0?U:Q;c[n>>2]=L;b[I>>1]=Y;Y=H+(L>>>3)|0;U=32-R|0;Z=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((L&7)>>>0)<<U>>U;Y=L+R|0;L=Q>>>0>Y>>>0?Y:Q;c[n>>2]=L;Y=4-M|0;b[q>>1]=Z<<Y;Z=H+(L>>>3)|0;M=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>((L&7)>>>0)<<U>>U;U=L+R|0;L=Q>>>0>U>>>0?U:Q;c[n>>2]=L;b[x>>1]=M<<Y;if((F|0)==15|(F|0)==0){_=V}else{V=(d[H+(L>>>3)|0]|0)>>>((L&7)>>>0);M=((L|0)<(Q|0))+L|0;c[n>>2]=M;L=R-(V&1)|0;V=0;R=4;U=M;M=Q;Q=H;while(1){if((R&3|0)==0){H=Q+(U>>>3)|0;Z=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((U&7)>>>0)&3;H=U+2|0;$=M>>>0>H>>>0?H:M;c[n>>2]=$;aa=L-Z|0;ca=$}else{aa=V;ca=U}$=Q+(ca>>>3)|0;Z=32-aa|0;H=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((ca&7)>>>0)<<Z>>Z;Z=aa+ca|0;c[n>>2]=M>>>0>Z>>>0?Z:M;b[f+1436+(R<<1)>>1]=H<<Y;H=R+1|0;if((H|0)>=(G|0)){break}V=aa;R=H;U=c[n>>2]|0;M=c[s>>2]|0;Q=c[p>>2]|0}_=b[J>>1]|0}Q=_<<16>>16<<6;c[y>>2]=Q;d:do{if((F|0)==15){da=1}else{M=1;U=Q;R=Q;while(1){V=M+1|0;Y=(V|0)/2|0;L=b[f+1436+(M<<1)>>1]|0;H=R+((ba(U,L)|0)+256>>9)|0;c[j+(M-1<<2)>>2]=((ba(R,L)|0)+256>>9)+U;c[y>>2]=H;if((V|0)>3){H=y;Z=1;$=j+(M-2<<2)|0;while(1){ea=H+4|0;fa=c[$>>2]|0;ga=Z+1|0;ha=c[ea>>2]|0;ia=ha+((ba(fa,L)|0)+256>>9)|0;c[$>>2]=((ba(ha,L)|0)+256>>9)+fa;c[ea>>2]=ia;if((ga|0)<(Y|0)){H=ea;Z=ga;$=$-4|0}else{break}}}$=L<<6;c[j+(M<<2)>>2]=$;if((V|0)>=(G|0)){da=0;break d}M=V;U=$;R=c[y>>2]|0}}}while(0);Q=15-W|0;F=1<<32-Q;R=1<<Q-1;U=G>>>1;if((U|0)!=0){M=0;$=G;do{$=$-1|0;b[f+2176+($<<1)>>1]=F-((c[j+(M<<2)>>2]|0)+R>>Q);b[f+2176+(M<<1)>>1]=F-((c[j+($<<2)>>2]|0)+R>>Q);M=M+1|0;}while((M|0)<(U|0))}U=P-G|0;M=l_a(f,O+(G<<2)|0,U)|0;if((M|0)<0){w=M;K=71;break b}if(da){ja=O}else{M=G>>>0>1>>>0;Q=0;R=O;while(1){b[f+2688+(Q<<1)>>1]=c[R>>2]>>S;$=Q+1|0;if(($|0)<(G|0)){Q=$;R=R+4|0}else{break}}ja=O+((M?G:1)<<2)|0}R=544-G|0;if((U|0)<=0){break}Q=1<<W-1;$=G&65520;F=($|0)==0;Z=f+2688+(R<<1)|0;H=G<<1;Y=G-545|0;ga=$>>>0<G>>>0;ea=U;ia=ja;while(1){fa=(R|0)>(ea|0)?ea:R;if((fa|0)>0){ha=~ea;ka=(Y|0)<(ha|0)?ha:Y;e:do{if(F){ha=0;la=ia;while(1){if(da){ma=Q}else{na=0;oa=Q;while(1){pa=na+ha|0;qa=ba(b[f+2176+((na|3)<<1)>>1]|0,b[f+2688+(pa+3<<1)>>1]|0)|0;ra=ba(b[f+2176+((na|2)<<1)>>1]|0,b[f+2688+(pa+2<<1)>>1]|0)|0;sa=ba(b[f+2176+((na|1)<<1)>>1]|0,b[f+2688+(pa+1<<1)>>1]|0)|0;ta=qa+oa+ra+sa+(ba(b[f+2176+(na<<1)>>1]|0,b[f+2688+(pa<<1)>>1]|0)|0)|0;pa=na+4|0;if((pa|0)<(G|0)){na=pa;oa=ta}else{ma=ta;break}}}oa=ma>>W;if((oa|0)<-8192){ua=-8192}else{ua=(oa|0)>8191?8191:oa}oa=(ua<<S)-(c[la>>2]|0)|0;c[la>>2]=oa;b[f+2688+(ha+G<<1)>>1]=oa>>S;oa=ha+1|0;if((oa|0)<(fa|0)){ha=oa;la=la+4|0}else{break}}}else{if(ga){va=0;wa=ia}else{la=0;ha=ia;while(1){V=(ze[c[l>>2]&511](f+2688+(la<<1)|0,g,$)|0)+Q>>W;if((V|0)<-8192){xa=-8192}else{xa=(V|0)>8191?8191:V}V=(xa<<S)-(c[ha>>2]|0)|0;c[ha>>2]=V;b[f+2688+(la+G<<1)>>1]=V>>S;V=la+1|0;if((V|0)<(fa|0)){la=V;ha=ha+4|0}else{break e}}}while(1){ha=$;la=(ze[c[l>>2]&511](f+2688+(va<<1)|0,g,$)|0)+Q|0;do{V=ha+va|0;L=ba(b[f+2176+((ha|3)<<1)>>1]|0,b[f+2688+(V+3<<1)>>1]|0)|0;oa=ba(b[f+2176+((ha|2)<<1)>>1]|0,b[f+2688+(V+2<<1)>>1]|0)|0;na=ba(b[f+2176+((ha|1)<<1)>>1]|0,b[f+2688+(V+1<<1)>>1]|0)|0;la=L+la+oa+na+(ba(b[f+2176+(ha<<1)>>1]|0,b[f+2688+(V<<1)>>1]|0)|0)|0;ha=ha+4|0;}while((ha|0)<(G|0));ha=la>>W;if((ha|0)<-8192){ya=-8192}else{ya=(ha|0)>8191?8191:ha}ha=(ya<<S)-(c[wa>>2]|0)|0;c[wa>>2]=ha;b[f+2688+(va+G<<1)>>1]=ha>>S;ha=va+1|0;if((ha|0)<(fa|0)){va=ha;wa=wa+4|0}else{break}}}}while(0);za=ia+(~ka<<2)|0}else{za=ia}ha=ea-fa|0;if((ha|0)<=0){break c}UGb(t|0,Z|0,H)|0;ea=ha;ia=za}}}while(0);D=b[u>>1]|0;z=m+1|0;if((z|0)<(c[k>>2]|0)){m=z;r=r+(D<<2)|0;v=D}else{w=0;K=71;break}}if((K|0)==71){i=h;return w|0}return 0}function j_a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=e+1304|0;j=c[e+1340+(f<<2)>>2]|0;f=j+4|0;k=c[e+1340+(g<<2)>>2]|0;g=k+4|0;switch(a[e+1972|0]|0){case 7:{l=f;m=g;break};case 5:{n=f;o=g;p=9;break};case 6:{l=g;m=f;break};case 2:{if((h|0)>0){q=0}else{r=0;return r|0}while(1){s=q+1|0;t=j+(s<<2)|0;c[t>>2]=(c[k+(s<<2)>>2]|0)-(c[t>>2]|0);if((s|0)<(h|0)){q=s}else{r=0;break}}return r|0};case 4:{n=g;o=f;p=9;break};case 3:{if((h|0)>0){u=0}else{r=0;return r|0}while(1){f=u+1|0;g=j+(f<<2)|0;q=k+(f<<2)|0;s=c[q>>2]|0;t=(c[g>>2]|0)-(s>>1)|0;c[g>>2]=t;c[q>>2]=t+s;if((f|0)<(h|0)){u=f}else{r=0;break}}return r|0};case 1:{if((h|0)>0){v=0}else{r=0;return r|0}while(1){u=v+1|0;f=k+(u<<2)|0;c[f>>2]=(c[f>>2]|0)+(c[j+(u<<2)>>2]|0);if((u|0)<(h|0)){v=u}else{r=0;break}}return r|0};default:{r=0;return r|0}}if((p|0)==9){p=e+1312|0;v=c[p>>2]|0;j=c[i>>2]|0;k=d[j+(v>>>3)|0]|0;u=c[e+1320>>2]|0;f=((v|0)<(u|0))+v|0;c[p>>2]=f;if((k&1<<(v&7)|0)==0){w=0;x=f}else{v=j+(f>>>3)|0;k=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((f&7)>>>0)&15;v=f+4|0;f=u>>>0>v>>>0?v:u;c[p>>2]=f;w=k+1|0;x=f}f=j+(x>>>3)|0;j=(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)>>>((x&7)>>>0)<<22>>22;f=x+10|0;c[p>>2]=u>>>0>f>>>0?f:u;if((h|0)>0){y=0}else{r=0;return r|0}while(1){u=n+(y<<2)|0;c[u>>2]=((ba(c[o+(y<<2)>>2]>>w,j)|0)+128>>8<<w)-(c[u>>2]|0);u=y+1|0;if((u|0)<(h|0)){y=u}else{r=0;break}}return r|0}if((h|0)<256){r=-1094995529;return r|0}y=e+1312|0;w=c[y>>2]|0;j=i|0;i=c[j>>2]|0;o=d[i+(w>>>3)|0]|0;n=e+1320|0;u=c[n>>2]|0;f=((w|0)<(u|0))+w|0;c[y>>2]=f;if((o&1<<(w&7)|0)==0){z=0;A=f}else{w=i+(f>>>3)|0;o=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((f&7)>>>0)&15;w=f+4|0;f=u>>>0>w>>>0?w:u;c[y>>2]=f;z=o+1|0;A=f}f=(d[i+(A>>>3)|0]|0)>>>((A&7)>>>0);o=((A|0)<(u|0))+A|0;c[y>>2]=o;A=8<<(f&1);f=o&7;w=d[i+(o>>>3)|0]|0;p=((o|0)<(u|0))+o|0;c[y>>2]=p;o=p&7;x=d[i+(p>>>3)|0]|0;c[y>>2]=((p|0)<(u|0))+p;p=(A|0)>0;if(p){u=0;i=0;while(1){k=c[y>>2]|0;v=c[n>>2]|0;s=c[j>>2]|0;if((i&3|0)==0){t=s+(k>>>3)|0;q=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>((k&7)>>>0)&7;t=k+3|0;g=v>>>0>t>>>0?t:v;c[y>>2]=g;B=14-q|0;C=g}else{B=u;C=k}k=s+(C>>>3)|0;s=32-B|0;g=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((C&7)>>>0)<<s>>s;s=C+B|0;c[y>>2]=v>>>0>s>>>0?s:v;b[e+2176+(i<<1)>>1]=g;g=i+1|0;if((g|0)<(A|0)){u=B;i=g}else{break}}}i=(A|0)/2|0;B=h+1-A|0;if((1<<f&w|0)!=0&(A|0)>1){w=0;do{f=l+(w<<2)|0;c[f>>2]=(c[m+(w<<2)>>2]|0)+(c[f>>2]|0);w=w+1|0;}while((w|0)<(i|0))}do{if((1<<o&x|0)!=0){w=i+B|0;if((w|0)<(h|0)){D=w}else{break}do{w=l+(D<<2)|0;c[w>>2]=(c[m+(D<<2)>>2]|0)+(c[w>>2]|0);D=D+1|0;}while((D|0)<(h|0))}}while(0);if(p){p=0;h=m;while(1){b[e+2688+(p<<1)>>1]=c[h>>2]>>z;D=p+1|0;if((D|0)<(A|0)){p=D;h=h+4|0}else{break}}E=m+(A<<2)|0}else{E=m}m=544-A|0;if((B|0)<=0){r=0;return r|0}h=e+2688|0;p=A<<1;D=(A|0)==16;x=e+1228|0;o=e+2176|0;w=e+2190|0;f=e+2188|0;u=e+2186|0;y=e+2184|0;C=e+2182|0;j=e+2180|0;n=e+2178|0;g=A-545|0;v=B;B=E;E=l+(i<<2)|0;while(1){i=(v|0)>(m|0)?m:v;l=(i|0)>0;do{if(l){s=~v;k=(g|0)<(s|0)?s:g;s=0;q=B;while(1){b[e+2688+(s+A<<1)>>1]=c[q>>2]>>z;t=s+1|0;if((t|0)<(i|0)){s=t;q=q+4|0}else{break}}q=B+(~k<<2)|0;if(!l){F=E;G=q;break}s=~v;t=(g|0)<(s|0)?s:g;s=0;H=E;while(1){if(D){I=ze[c[x>>2]&511](e+2688+(s<<1)|0,o,16)|0}else{J=ba(b[w>>1]|0,b[e+2688+(s+7<<1)>>1]|0)|0;K=(ba(b[f>>1]|0,b[e+2688+(s+6<<1)>>1]|0)|0)+J|0;J=K+(ba(b[u>>1]|0,b[e+2688+(s+5<<1)>>1]|0)|0)|0;K=J+(ba(b[y>>1]|0,b[e+2688+(s+4<<1)>>1]|0)|0)|0;J=K+(ba(b[C>>1]|0,b[e+2688+(s+3<<1)>>1]|0)|0)|0;K=J+(ba(b[j>>1]|0,b[e+2688+(s+2<<1)>>1]|0)|0)|0;J=K+(ba(b[n>>1]|0,b[e+2688+(s+1<<1)>>1]|0)|0)|0;I=J+(ba(b[o>>1]|0,b[e+2688+(s<<1)>>1]|0)|0)|0}J=I+512>>10;if((J|0)<-8192){L=-8192}else{L=(J|0)>8191?8191:J}c[H>>2]=(L<<z)-(c[H>>2]|0);J=s+1|0;if((J|0)<(i|0)){s=J;H=H+4|0}else{break}}F=E+(~t<<2)|0;G=q}else{F=E;G=B}}while(0);UGb(h|0,e+2688+(i<<1)|0,p)|0;l=v-i|0;if((l|0)>0){v=l;B=G;E=F}else{r=0;break}}return r|0}function k_a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((d|0)<2){return}if((b|0)==3){e=a+4|0;f=c[e>>2]|0;g=(c[a>>2]|0)+f|0;c[e>>2]=g;if((d|0)<=2){return}e=c[a+8>>2]|0;h=e+f|0;f=d-3|0;if((f|0)<=0){return}i=0;j=a+12|0;k=e;e=h;l=h+g|0;while(1){g=(c[j>>2]|0)+k|0;h=g+e|0;m=h+l|0;c[j>>2]=m;n=i+1|0;if((n|0)<(f|0)){i=n;j=j+4|0;k=g;e=h;l=m}else{break}}return}else if((b|0)==1){l=a+4|0;e=c[a>>2]|0;k=d-1|0;j=k>>1;if((j|0)>0){i=j<<1|1;f=e;m=0;h=l;while(1){g=(c[h>>2]|0)+f|0;c[h>>2]=g;n=h+4|0;o=(c[n>>2]|0)+g|0;c[n>>2]=o;n=m+1|0;if((n|0)<(j|0)){f=o;m=n;h=h+8|0}else{break}}p=o;q=a+(i<<2)|0}else{p=e;q=l}if((k&1|0)==0){return}c[q>>2]=(c[q>>2]|0)+p;return}else if((b|0)==2){b=a+4|0;p=c[b>>2]|0;q=(c[a>>2]|0)+p|0;c[b>>2]=q;if((d|0)<=2){return}b=a+8|0;k=d-2>>1;if((k|0)>0){l=(k<<1)+2|0;e=q;i=p;o=0;h=a;m=b;while(1){f=(c[m>>2]|0)+i|0;j=f+e|0;c[m>>2]=j;n=h+12|0;r=(c[n>>2]|0)+f|0;s=r+j|0;c[n>>2]=s;n=o+1|0;if((n|0)<(k|0)){e=s;i=r;o=n;h=m;m=m+8|0}else{break}}t=s;u=r;v=a+(l<<2)|0}else{t=q;u=p;v=b}if((d&1|0)==0){return}c[v>>2]=u+t+(c[v>>2]|0);return}else{return}}function l_a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[b+1328>>2]|0)<(f|0)){g=-1094995529;return g|0}h=b+1312|0;i=c[h>>2]|0;j=b+1304|0;k=c[j>>2]|0;l=d[k+(i>>>3)|0]|0;m=b+1320|0;n=c[m>>2]|0;o=((i|0)<(n|0))+i|0;c[h>>2]=o;a:do{if((l&1<<(i&7)|0)==0){p=k+(o>>>3)|0;q=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((o&7)>>>0);p=o+6|0;c[h>>2]=n>>>0>p>>>0?p:n;p=m_a(b,q&63,e,f)|0;if((p|0)<0){g=p}else{break}return g|0}else{p=b+1324|0;q=c[p>>2]|0;r=(f|0)/(q|0)|0;s=f-(ba(r,q)|0)|0;t=(s|0)<((q|0)/2|0|0);u=(t&1^1)+r|0;r=(t?q:0)+s|0;if((u-2|0)>>>0>126>>>0){g=-1094995529;return g|0}s=k+(o>>>3)|0;q=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((o&7)>>>0)&63;s=o+6|0;c[h>>2]=n>>>0>s>>>0?s:n;a[b+2037|0]=q;b:do{if((u|0)>1){s=1;t=q;while(1){v=0;while(1){if((v|0)>=6){break}w=c[h>>2]|0;x=d[(c[j>>2]|0)+(w>>>3)|0]|0;c[h>>2]=((w|0)<(c[m>>2]|0))+w;if((x&1<<(w&7)|0)==0){v=v+1|0}else{break}}switch(v|0){case 2:{y=t+1|0;break};case 1:{y=t-1|0;break};case 5:case 4:case 3:{w=c[h>>2]|0;x=(d[(c[j>>2]|0)+(w>>>3)|0]|0)>>>((w&7)>>>0);c[h>>2]=((w|0)<(c[m>>2]|0))+w;w=x&1;y=w+t+(v-1^-w)|0;break};case 6:{w=c[h>>2]|0;x=c[m>>2]|0;z=(c[j>>2]|0)+(w>>>3)|0;A=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((w&7)>>>0)&63;z=w+6|0;c[h>>2]=x>>>0>z>>>0?z:x;y=A;break};default:{y=t}}a[b+2037+s|0]=y;A=s+1|0;if((A|0)<(u|0)){s=A;t=y}else{break b}}}}while(0);if((u|0)<=0){break}q=u-1|0;t=0;s=e;while(1){A=a[b+2037+t|0]|0;x=0;z=t;while(1){if((z|0)<(q|0)){B=c[p>>2]|0}else{B=r}C=B+x|0;w=z+1|0;if((w|0)==(u|0)){D=u;break}if((a[b+2037+w|0]|0)==A<<24>>24){x=C;z=w}else{D=w;break}}z=m_a(b,A,s,C)|0;if((z|0)<0){g=z;break}if((D|0)>=(u|0)){break a}t=D;s=s+(C<<2)|0}return g|0}}while(0);g=0;return g|0}function m_a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;if(b<<24>>24==0){TGb(e|0,0,f<<2|0)|0;g=0;return g|0}if((b&255)>>>0>50>>>0){g=-1094995529;return g|0}h=b<<24>>24;b=h-1|0;i=c[1848+(b*20|0)>>2]|0;j=c[1852+(b*20|0)>>2]|0;k=c[1856+(b*20|0)>>2]|0;l=c[1860+(b*20|0)>>2]|0;m=c[1864+(b*20|0)>>2]|0;if((f|0)<=0){g=0;return g|0}b=(h-49|0)>>>0>1>>>0;h=a+1312|0;n=a+1320|0;o=32-i|0;p=1<<i;q=i-16|0;r=48-i|0;s=c[a+1304>>2]|0;a=0;a:while(1){t=c[h>>2]|0;u=c[n>>2]|0;v=s+(t>>>3)|0;w=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((t&7)>>>0);if(b){v=t+i|0;x=u>>>0>v>>>0?v:u;c[h>>2]=x;y=w<<o>>>(o>>>0);z=x}else{x=t+16|0;t=u>>>0>x>>>0?x:u;c[h>>2]=t;x=s+(t>>>3)|0;v=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((t&7)>>>0)<<r>>>(r>>>0);x=q+t|0;t=u>>>0>x>>>0?x:u;c[h>>2]=t;y=v<<16|w&65535;z=t}b:do{if((y|0)<(j|0)){A=y}else{t=d[s+(z>>>3)|0]|0;w=((z|0)<(u|0))+z|0;c[h>>2]=w;if((t&1<<(z&7)|0)==0){A=y;break}t=y|p;if((t|0)<(l|0)){A=t-j|0;break}else{B=0;C=w}while(1){if((B|0)>=9){D=14;break}w=d[s+(C>>>3)|0]|0;v=((C|0)<(u|0))+C|0;c[h>>2]=v;if((w&1<<(C&7)|0)==0){B=B+1|0;C=v}else{break}}do{if((D|0)==14){D=0;if((B|0)!=9){break}v=s+(C>>>3)|0;w=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((C&7)>>>0)&7;v=C+3|0;x=u>>>0>v>>>0?v:u;c[h>>2]=x;do{if((w|0)==7){v=s+(x>>>3)|0;E=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((x&7)>>>0)&31;v=x+5|0;F=u>>>0>v>>>0?v:u;c[h>>2]=F;v=E+7|0;if(v>>>0>29>>>0){g=-1094995529;D=26;break a}G=s+(F>>>3)|0;H=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((F&7)>>>0);if(v>>>0<26>>>0){I=F;J=v;K=H;D=19;break}v=F+16|0;F=u>>>0>v>>>0?v:u;c[h>>2]=F;v=s+(F>>>3)|0;G=41-E|0;L=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((F&7)>>>0)<<G>>>(G>>>0);G=E-9+F|0;c[h>>2]=u>>>0>G>>>0?G:u;M=L<<16|H&65535;D=21}else if((w|0)==0){N=t}else{H=s+(x>>>3)|0;I=x;J=w;K=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((x&7)>>>0);D=19}}while(0);if((D|0)==19){D=0;x=32-J|0;w=I+J|0;c[h>>2]=u>>>0>w>>>0?w:u;M=K<<x>>>(x>>>0);D=21}if((D|0)==21){D=0;N=(ba(M+1|0,k)|0)+t|0}A=N+m|0;break b}}while(0);A=t-j+(ba(B,k)|0)|0}}while(0);c[e+(a<<2)>>2]=A>>1^-(A&1);u=a+1|0;if((u|0)<(f|0)){a=u}else{g=0;D=26;break}}if((D|0)==26){return g|0}return 0}function n_a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;j=i;i=i+8|0;k=j|0;l=c[e+60>>2]|0;m=f;n=c[h+24>>2]|0;o=h+28|0;h=c[o>>2]|0;if(!((h|0)>-1)){yDb(0,0,2330048,(p=i,i=i+24|0,c[p>>2]=2305568,c[p+8>>2]=2287680,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}q=l;c[q>>2]=n;c[l+8>>2]=n;r=n+h|0;s=l+4|0;c[s>>2]=r;l=r;if((h|0)<1){t=0;u=n}else{h=n+1|0;c[q>>2]=h;t=d[n]|0;u=h}if((l-u|0)<1){v=0;w=u}else{h=u+1|0;c[q>>2]=h;v=d[u]|0;w=h}if((l-w|0)<1){x=0;y=w}else{h=w+1|0;c[q>>2]=h;x=d[w]|0;y=h}if((l-y|0)<2){z=0;A=y}else{h=y+2|0;c[q>>2]=h;w=y;z=(d[w]|d[w+1|0]<<8)<<16>>16&65535;A=h}if((l-A|0)<2){B=0;C=A}else{h=A+2|0;c[q>>2]=h;w=A;B=(d[w]|d[w+1|0]<<8)<<16>>16&65535;C=h}if((l-C|0)<1){D=0;E=C}else{h=C+1|0;c[q>>2]=h;D=d[C]|0;E=h}h=l-E|0;C=h>>>0>4>>>0?4:h;h=E+C|0;c[q>>2]=h;if((l-h|0)<2){F=0;G=h}else{w=E+(C+2)|0;c[q>>2]=w;C=h;F=(d[C]|d[C+1|0]<<8)<<16>>16&65535;G=w}if((l-G|0)<2){H=0;I=G}else{w=G+2|0;c[q>>2]=w;C=G;H=(d[C]|d[C+1|0]<<8)<<16>>16&65535;I=w}if((l-I|0)<1){J=0;K=I}else{w=I+1|0;c[q>>2]=w;J=d[I]|0;K=w}w=l-K|0;if(!(w>>>0>t>>>0)){yDb(e,16,2181248,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}if((w|0)<1){M=0;N=K}else{w=K+1|0;c[q>>2]=w;M=d[K]|0;N=w}do{if((v|0)==0){if((B|z|D|0)==0){O=z;P=B;Q=D;R=r;S=N;break}yDb(e,24,2104120,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;O=0;P=0;Q=0;R=c[s>>2]|0;S=c[q>>2]|0}else{O=z;P=B;Q=D;R=r;S=N}}while(0);N=R-S|0;c[q>>2]=S+(N>>>0>t>>>0?t:N);switch(J|0){case 15:case 16:{c[e+140>>2]=46;break};case 24:{c[e+140>>2]=3;break};case 8:{c[e+140>>2]=(x&247|0)==3?8:11;break};case 32:{c[e+140>>2]=30;break};default:{yDb(e,16,2047688,(p=i,i=i+8|0,c[p>>2]=J,p)|0);i=p;L=-1094995529;i=j;return L|0}}N=(P|0)!=0;do{if(N){if((O+P|0)<=256){break}yDb(e,16,2002040,(p=i,i=i+16|0,c[p>>2]=P,c[p+8>>2]=O,p)|0);i=p;L=-1094995529;i=j;return L|0}}while(0);t=V$a(e,F,H)|0;if((t|0)<0){L=t;i=j;return L|0}t=_$a(e,m,0)|0;if((t|0)<0){L=t;i=j;return L|0}c[f+88>>2]=1;t=f;m=c[t>>2]|0;S=f+32|0;R=c[S>>2]|0;if((M&32|0)==0){T=m+(ba(R,H-1|0)|0)|0;U=-R|0}else{T=m;U=R}if((M&64|0)==0){V=(M&128|0)!=0?4:1}else{V=2}do{if(N){if((Q|0)==32){W=4}else if((Q|0)==16|(Q|0)==15){W=2}else if((Q|0)==24){W=3}else{yDb(e,16,1964768,(p=i,i=i+8|0,c[p>>2]=Q,p)|0);i=p;L=-1094995529;i=j;return L|0}R=ba(W,P)|0;if((c[e+140>>2]|0)!=11){m=c[q>>2]|0;r=(c[s>>2]|0)-m|0;c[q>>2]=m+(r>>>0>R>>>0?R:r);break}r=(c[f+4>>2]|0)+(O<<2)|0;m=c[q>>2]|0;if(((c[s>>2]|0)-m|0)>>>0<R>>>0){yDb(e,16,1936664,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}do{if((W|0)==2){if((P|0)>0){X=r;Y=0;Z=m}else{break}while(1){R=Z+2|0;c[q>>2]=R;D=Z;B=(d[D]|d[D+1|0]<<8)<<16>>16&65535;D=B<<9&16252928|B<<6&63488|B<<3&248;c[X>>2]=D|D>>>5&460551|-16777216;D=Y+1|0;if((D|0)<(P|0)){X=X+4|0;Y=D;Z=R}else{break}}}else if((W|0)==3){if((P|0)>0){_=r;$=0;aa=m}else{break}while(1){R=aa+3|0;c[q>>2]=R;c[_>>2]=(d[aa+2|0]|0)<<16|(d[aa+1|0]|0)<<8|(d[aa]|0)|-16777216;D=$+1|0;if((D|0)<(P|0)){_=_+4|0;$=D;aa=R}else{break}}}else if((W|0)==4){if((P|0)>0){ca=r;da=0;ea=m}else{break}while(1){R=ea+4|0;c[q>>2]=R;D=ea;c[ca>>2]=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24;D=da+1|0;if((D|0)<(P|0)){ca=ca+4|0;da=D;ea=R}else{break}}}}while(0);c[f+304>>2]=1}}while(0);a:do{if((x&247|0)==0){TGb(c[t>>2]|0,0,ba(c[S>>2]|0,H)|0)|0}else{if((x&8|0)==0){f=ba((J+1|0)>>>3,F)|0;ea=c[q>>2]|0;da=c[s>>2]|0;if((da-ea|0)>>>0<(ba(f,H)|0)>>>0){yDb(e,16,1913056,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}ca=ba(V,U)|0;P=V-1|0;W=T;aa=0;$=ea;ea=da;while(1){da=ea-$|0;_=da>>>0>f>>>0?f:da;UGb(W|0,$|0,_)|0;da=(c[q>>2]|0)+_|0;c[q>>2]=da;_=aa+V|0;if((_|0)<(H|0)){fa=W+ca|0;ga=_}else{Z=_+1&P;if(!((Z|0)!=0&(Z|0)<(H|0))){break a}fa=T+(ba(Z,U)|0)|0;ga=Z}if((fa|0)==0){break a}W=fa;aa=ga;$=da;ea=c[s>>2]|0}}ea=k|0;$=(J+1|0)>>>3;if((T|0)==0){break}aa=ba(V,U)|0;W=V-1|0;P=~F;ca=0;f=0;da=T;Z=T;b:while(1){_=c[q>>2]|0;Y=c[s>>2]|0;if((Y|0)==(_|0)){ha=67;break}X=_+1|0;c[q>>2]=X;O=d[_]|0;Q=(O&127)+1|0;c:do{if((O&128|0)==0){N=Z;m=da;r=Q;R=f;D=ca;B=X;z=Y;while(1){v=F-R|0;w=(r|0)>(v|0)?v:r;v=ba(w,$)|0;K=z-B|0;l=K>>>0>v>>>0?v:K;UGb(N|0,B|0,l)|0;K=(c[q>>2]|0)+l|0;c[q>>2]=K;l=r-w|0;I=N+v|0;v=w+R|0;do{if((v|0)==(F|0)){w=D+V|0;if((w|0)<(H|0)){C=m+aa|0;ia=C;ja=C;ka=0;la=w;break}C=w+1&W;if(!((C|0)!=0&(C|0)<(H|0))){ma=l;break b}w=T+(ba(C,U)|0)|0;ia=w;ja=w;ka=0;la=C}else{ia=I;ja=m;ka=v;la=D}}while(0);if(!((ia|0)!=0&(l|0)>0)){na=ia;oa=ja;pa=l;qa=ka;ra=la;break c}N=ia;m=ja;r=l;R=ka;D=la;B=K;z=c[s>>2]|0}}else{z=Y-X|0;B=z>>>0>$>>>0?$:z;UGb(ea|0,X|0,B)|0;c[q>>2]=_+(B+1);B=Z;z=da;D=Q;R=f;r=ca;while(1){m=F-R|0;N=(D|0)>(m|0)?m:D;m=~D;v=R+P|0;I=~((v|0)<(m|0)?m:v);v=N;m=B;while(1){UGb(m|0,ea|0,$)|0;C=v-1|0;if((C|0)==0){break}else{v=C;m=m+$|0}}m=D-N|0;v=N+R|0;K=B+(ba($,I)|0)|0;do{if((v|0)==(F|0)){l=r+V|0;if((l|0)<(H|0)){C=z+aa|0;sa=C;ta=C;ua=0;va=l;break}C=l+1&W;if(!((C|0)!=0&(C|0)<(H|0))){ma=m;break b}l=T+(ba(C,U)|0)|0;sa=l;ta=l;ua=0;va=C}else{sa=K;ta=z;ua=v;va=r}}while(0);if((sa|0)!=0&(m|0)>0){B=sa;z=ta;D=m;R=ua;r=va}else{na=sa;oa=ta;pa=m;qa=ua;ra=va;break}}}}while(0);if((na|0)==0){ma=pa;break}else{ca=ra;f=qa;da=oa;Z=na}}if((ha|0)==67){yDb(e,16,1892624,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}if((ma|0)==0){break}yDb(e,16,2350304,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}}while(0);if(!((M&16|0)==0|(H|0)==0)){M=F>>>1;p=(M|0)==0;e=F-1|0;ma=F*3|0;F=0;do{ha=ba(c[S>>2]|0,F)|0;na=c[t>>2]|0;oa=na+ha|0;if(!p){qa=oa;ra=ha-3|0;pa=ha-2|0;va=ha+1|0;ua=ha-1|0;ta=ha+2|0;sa=oa;oa=e+ha|0;if((J|0)==32){U=0;T=0;while(1){V=qa+(e+T<<2)|0;q=c[V>>2]|0;s=qa+(U<<2)|0;c[V>>2]=c[s>>2];c[s>>2]=q;q=U+1|0;s=~U;if((q|0)<(M|0)){U=q;T=s}else{break}}}else if((J|0)==24){T=0;do{U=T*3|0;qa=ma-U|0;s=na+(ra+qa)|0;q=a[s]|0;V=na+(U+ha)|0;a[s]=a[V]|0;a[V]=q;q=na+(pa+qa)|0;V=a[q]|0;s=na+(va+U)|0;a[q]=a[s]|0;a[s]=V;V=na+(ua+qa)|0;qa=a[V]|0;s=na+(ta+U)|0;a[V]=a[s]|0;a[s]=qa;T=T+1|0;}while((T|0)<(M|0))}else{T=0;ta=0;while(1){if((J|0)==8){ua=na+(oa+ta)|0;va=a[ua]|0;pa=na+(T+ha)|0;a[ua]=a[pa]|0;a[pa]=va}else if((J|0)==16){va=sa+(e+ta<<1)|0;pa=b[va>>1]|0;ua=sa+(T<<1)|0;b[va>>1]=b[ua>>1]|0;b[ua>>1]=pa}pa=T+1|0;ua=~T;if((pa|0)<(M|0)){T=pa;ta=ua}else{break}}}}F=F+1|0;}while((F|0)<(H|0))}c[g>>2]=1;L=c[o>>2]|0;i=j;return L|0}function o_a(a){a=a|0;c[a+140>>2]=56;c[a+796>>2]=14;return 0}function p_a(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;h=c[f+24>>2]|0;j=a+120|0;k=f+28|0;f=a+124|0;l=(c[j>>2]|0)+3&65532;if((c[k>>2]|0)<(ba(c[f>>2]<<2,l)|0)){yDb(a,16,2181208,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=g;return n|0}m=_$a(a,d,0)|0;if((m|0)<0){n=m;i=g;return n|0}c[d+84>>2]=1;c[d+88>>2]=1;m=c[f>>2]|0;do{if((m|0)>0){f=c[j>>2]>>1;a=c[d+32>>2]>>1;o=c[d+36>>2]>>1;p=c[d+40>>2]>>1;q=l<<1;if((f|0)>0){r=c[d>>2]|0;s=c[d+4>>2]|0;t=c[d+8>>2]|0;u=h;v=0}else{break}while(1){w=0;do{x=w<<2;y=b[u+(x<<1)>>1]|0;b[s+(w<<1)>>1]=y<<2|(y&65535)>>>14;y=b[u+((x|1)<<1)>>1]|0;z=w<<1;b[r+(z<<1)>>1]=y<<2|(y&65535)>>>14;y=b[u+((x|2)<<1)>>1]|0;b[t+(w<<1)>>1]=y<<2|(y&65535)>>>14;y=b[u+((x|3)<<1)>>1]|0;b[r+((z|1)<<1)>>1]=y<<2|(y&65535)>>>14;w=w+1|0;}while((w|0)<(f|0));w=v+1|0;if((w|0)<(m|0)){r=r+(a<<1)|0;s=s+(o<<1)|0;t=t+(p<<1)|0;u=u+(q<<1)|0;v=w}else{break}}}}while(0);c[e>>2]=1;n=c[k>>2]|0;i=g;return n|0}function q_a(a){a=a|0;var b=0,d=0;b=ICb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+84>>2]=1;c[b+88>>2]=1;d=0;return d|0}function r_a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=i;j=b+120|0;k=c[j>>2]|0;do{if((k|0)<=65535){l=b+124|0;m=c[l>>2]|0;if((m|0)>65535){break}n=b+140|0;o=QZ(c[n>>2]|0,k,m)|0;m=o+45|0;p=r0a(b,e,m,(m|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=h;return q|0}p=e+24|0;TGb(c[p>>2]|0,0,12)|0;m=(c[p>>2]|0)+12|0;x=c[j>>2]&65535;a[m]=x;x=x>>8;a[m+1|0]=x;m=(c[p>>2]|0)+14|0;x=c[l>>2]&65535;a[m]=x;x=x>>8;a[m+1|0]=x;a[(c[p>>2]|0)+17|0]=(c[n>>2]|0)==30?40:32;m=c[p>>2]|0;r=m+18|0;s=b+792|0;c[s>>2]=$Eb(bFb(c[n>>2]|0)|0)|0;t=c[n>>2]|0;switch(t|0){case 8:{a[(c[p>>2]|0)+2|0]=3;c[s>>2]=40;a[(c[p>>2]|0)+16|0]=8;u=r;break};case 46:{a[(c[p>>2]|0)+2|0]=2;a[(c[p>>2]|0)+16|0]=16;c[s>>2]=16;u=r;break};case 3:{a[(c[p>>2]|0)+2|0]=2;a[(c[p>>2]|0)+16|0]=24;u=r;break};case 30:{a[(c[p>>2]|0)+2|0]=2;a[(c[p>>2]|0)+16|0]=32;u=r;break};case 11:{r=f+4|0;s=0;while(1){if((s|0)>=256){v=24;break}n=(c[r>>2]|0)+(s<<2)|0;if(((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24)&-16777216|0)==-16777216){s=s+1|0}else{v=32;break}}a[(c[p>>2]|0)+1|0]=1;a[(c[p>>2]|0)+2|0]=1;a[(c[p>>2]|0)+6|0]=1;a[(c[p>>2]|0)+7|0]=v;a[(c[p>>2]|0)+16|0]=8;if((v|0)==32){s=0;do{n=s<<2;w=(c[p>>2]|0)+(n+18)|0;x=c[(c[r>>2]|0)+n>>2]|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;s=s+1|0;}while((s|0)<256)}else{s=0;do{w=s<<2;n=s*3|0;a[(c[p>>2]|0)+(n+18)|0]=c[(c[r>>2]|0)+w>>2];a[(c[p>>2]|0)+(n+19)|0]=(c[(c[r>>2]|0)+w>>2]|0)>>>8;a[(c[p>>2]|0)+(n+20)|0]=(c[(c[r>>2]|0)+w>>2]|0)>>>16;s=s+1|0;}while((s|0)<256)}u=m+(v<<5|18)|0;break};default:{s=ZEb(t)|0;yDb(b,16,2104080,(y=i,i=i+8|0,c[y>>2]=s,y)|0);i=y;q=-22;i=h;return q|0}}s=(d[(c[p>>2]|0)+16|0]|0)>>>3;a:do{if((c[b+568>>2]|0)==2){z=25}else{r=c[j>>2]|0;w=c[l>>2]|0;if((w|0)>0){n=f|0;A=f+32|0;B=o;C=0;D=u;while(1){E=lnb(D,B,(c[n>>2]|0)+(ba(c[A>>2]|0,C)|0)|0,s,r,127,0,-1,0)|0;if((E|0)==-1){z=25;break a}F=D+E|0;G=C+1|0;if((G|0)<(w|0)){B=B-E|0;C=G;D=F}else{H=F;break}}}else{H=u}D=H-u|0;if(!((D|0)>-1)){z=25;break}C=(c[p>>2]|0)+2|0;a[C]=a[C]|8;I=D}}while(0);if((z|0)==25){o=c[l>>2]|0;t=ba(c[j>>2]|0,s)|0;if((o|0)>0){m=f+32|0;D=0;C=u;B=c[f>>2]|0;while(1){UGb(C|0,B|0,t)|0;w=D+1|0;if((w|0)<(o|0)){D=w;C=C+t|0;B=B+(c[m>>2]|0)|0}else{break}}J=u+(ba(t,o)|0)|0}else{J=u}I=J-u|0}UGb(u+I|0,2047656,26)|0;c[e+28>>2]=u+(I+26)-(c[p>>2]|0);m=e+36|0;c[m>>2]=c[m>>2]|1;c[g>>2]=1;q=0;i=h;return q|0}}while(0);yDb(b,16,2181176,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;q=-22;i=h;return q|0}function s_a(a){a=a|0;JCb(a+804|0);return 0}function t_a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1040|0;h=g|0;j=g+1024|0;k=g+1032|0;l=d;m=c[f+24>>2]|0;n=c[b+60>>2]|0;o=f+8|0;p=c[o>>2]|0;q=c[o+4>>2]|0;o=b+104|0;c[j>>2]=1;c[j+4>>2]=100;b=KDb(p,q,o,j)|0;j=b;b=c[f+48>>2]|0;if((b|0)==-1){r=-1}else{c[k>>2]=1;c[k+4>>2]=100;q=KDb(b,(b|0)<0|0?-1:0,o,k)|0;r=q}IAb(h,0,-1);q=f+28|0;do{if((m|0)!=0){f=c[q>>2]|0;if((f|0)<=0){break}if((a[m]|0)==0){break}thb(h,m,f,c[n+4>>2]|0,c[n+8>>2]|0);if((c[h+4>>2]|0)>>>0<(c[h+8>>2]|0)>>>0){shb(l,c[h>>2]|0,j,r,0)|0;break}QAb(h,0)|0;s=-12;i=g;return s|0}}while(0);c[e>>2]=(c[d+12>>2]|0)!=0;QAb(h,0)|0;s=c[q>>2]|0;i=g;return s|0}function u_a(a){a=a|0;c[(c[a+60>>2]|0)+4>>2]=2305512;return qhb(a)|0}function v_a(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;a=ICb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function w_a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;h=i;i=i+64|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=(c[b+60>>2]|0)+4|0;m=$$a(b,c[g>>2]|0)|0;if((m|0)<0){n=m;i=h;return n|0}m=k+l|0;b=k+1|0;o=d[k]|0;if((o&1|0)==0){p=b}else{q=c[g>>2]|0;r=c[q+4>>2]|0;if((m-b|0)<768){n=-1094995529;i=h;return n|0}else{s=0;t=b}while(1){b=a[t]|0;u=a[t+1|0]|0;v=a[t+2|0]|0;c[r+(s<<2)>>2]=((b<<2|(b&255)>>>4)&255)<<16|((u<<2|(u&255)>>>4)&255)<<8|(v<<2|(v&255)>>>4)&255|-16777216;v=s+1|0;if((v|0)<256){s=v;t=t+3|0}else{break}}c[q+304>>2]=1;p=k+769|0}a:do{if((o&2|0)!=0){k=m;if((k-p|0)<128){n=-1094995529;i=h;return n|0}q=(p|0)==0?8:1032;t=j;s=j|0;r=j;v=j+8|0;u=j+16|0;b=j+24|0;w=j+32|0;y=j+40|0;z=j+48|0;A=j+56|0;B=0;C=0;D=p+128|0;b:while(1){E=D;F=0;G=B;while(1){if((F|0)>=256){break}H=c[g>>2]|0;I=(ba(c[H+32>>2]|0,C)|0)+F|0;J=c[H>>2]|0;H=J+I|0;K=p+(G>>>3)|0;L=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((G&7)>>>0)&3;K=G+2|0;M=q>>>0>K>>>0?K:q;c:do{if((L|0)==1){if((k-E|0)<1){n=-1094995529;N=31;break b}K=E+1|0;O=a[E]|0;P=O&255;if((P&128|0)!=0){Q=P&3;if((Q|0)==1){R=y_a(K,m,t)|0;S=H;T=c[s+4>>2]|0;U=S|0;x=c[s>>2]|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=S+4|0;x=T;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=c[(c[g>>2]|0)+32>>2]|0;T=J+(U+I)|0;S=c[v+4>>2]|0;V=T|0;x=c[v>>2]|0;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=T+4|0;x=S;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=(c[(c[g>>2]|0)+32>>2]|0)+U|0;U=J+(V+I)|0;S=c[u+4>>2]|0;T=U|0;x=c[u>>2]|0;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;T=U+4|0;x=S;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;T=(c[(c[g>>2]|0)+32>>2]|0)+V|0;V=J+(T+I)|0;S=c[b+4>>2]|0;U=V|0;x=c[b>>2]|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=V+4|0;x=S;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=(c[(c[g>>2]|0)+32>>2]|0)+T|0;T=J+(U+I)|0;S=c[w+4>>2]|0;V=T|0;x=c[w>>2]|0;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=T+4|0;x=S;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=(c[(c[g>>2]|0)+32>>2]|0)+U+I|0;U=J+V|0;S=c[y+4>>2]|0;T=U|0;x=c[y>>2]|0;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;T=U+4|0;x=S;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;T=V+(c[(c[g>>2]|0)+32>>2]|0)|0;V=J+T|0;S=c[z+4>>2]|0;U=V|0;x=c[z>>2]|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=V+4|0;x=S;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=J+((c[(c[g>>2]|0)+32>>2]|0)+T)|0;T=c[A+4>>2]|0;S=U|0;x=c[A>>2]|0;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;S=U+4|0;x=T;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;W=R;break}else if((Q|0)!=2){W=K;break}Q=y_a(K,m,t)|0;R=H;S=0;while(1){T=S<<3;a[R]=a[r+T|0]|0;a[R+(c[(c[g>>2]|0)+32>>2]|0)|0]=a[r+(T|1)|0]|0;a[R+(c[(c[g>>2]|0)+32>>2]<<1)|0]=a[r+(T|2)|0]|0;a[R+((c[(c[g>>2]|0)+32>>2]|0)*3|0)|0]=a[r+(T|3)|0]|0;a[R+(c[(c[g>>2]|0)+32>>2]<<2)|0]=a[r+(T|4)|0]|0;a[R+((c[(c[g>>2]|0)+32>>2]|0)*5|0)|0]=a[r+(T|5)|0]|0;a[R+((c[(c[g>>2]|0)+32>>2]|0)*6|0)|0]=a[r+(T|6)|0]|0;a[R+((c[(c[g>>2]|0)+32>>2]|0)*7|0)|0]=a[r+(T|7)|0]|0;T=S+1|0;if((T|0)<8){R=R+1|0;S=T}else{W=Q;break c}}}if(O<<24>>24==0){n=-1094995529;N=31;break b}Q=d[1191992+(P-1)|0]|0;S=Q+1|0;R=S<<3;if((k-K|0)<(R+P|0)){n=-1094995529;N=31;break b}T=P+1|0;U=E+T|0;V=S<<6;X=V>>>0>2147483639>>>0|(U|0)==0;Y=X?0:U;U=X?8:V|8;V=31-Q|0;Q=0;X=H;Z=0;while(1){_=Y+(Q>>>3)|0;$=Q+S|0;aa=U>>>0>$>>>0?$:U;a[X]=a[E+(((d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((Q&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;_=Y+(aa>>>3)|0;$=aa+S|0;ca=U>>>0>$>>>0?$:U;a[X+1|0]=a[E+(((d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((aa&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;aa=Y+(ca>>>3)|0;_=ca+S|0;$=U>>>0>_>>>0?_:U;a[X+2|0]=a[E+(((d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((ca&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;ca=Y+($>>>3)|0;aa=$+S|0;_=U>>>0>aa>>>0?aa:U;a[X+3|0]=a[E+(((d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)>>>(($&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;$=Y+(_>>>3)|0;ca=_+S|0;aa=U>>>0>ca>>>0?ca:U;a[X+4|0]=a[E+(((d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((_&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;_=Y+(aa>>>3)|0;$=aa+S|0;ca=U>>>0>$>>>0?$:U;a[X+5|0]=a[E+(((d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((aa&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;aa=Y+(ca>>>3)|0;_=ca+S|0;$=U>>>0>_>>>0?_:U;a[X+6|0]=a[E+(((d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((ca&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;ca=Y+($>>>3)|0;aa=$+S|0;a[X+7|0]=a[E+(((d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)>>>(($&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;$=Z+1|0;if(($|0)<8){Q=U>>>0>aa>>>0?aa:U;X=X+(c[(c[g>>2]|0)+32>>2]|0)|0;Z=$}else{break}}W=E+(R+T)|0}else if((L|0)==2){if((k-E|0)<64){n=-1094995529;N=31;break b}Z=E;X=H;U=Z|0;Q=Z+4|0;Z=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=X|0;x=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=X+4|0;x=Z;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=c[(c[g>>2]|0)+32>>2]|0;Z=E+8|0;X=J+(Q+I)|0;U=Z|0;V=Z+4|0;Z=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;V=X|0;x=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=X+4|0;x=Z;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=(c[(c[g>>2]|0)+32>>2]|0)+Q|0;Q=E+16|0;Z=J+(V+I)|0;X=Q|0;U=Q+4|0;Q=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;U=Z|0;x=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=Z+4|0;x=Q;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=(c[(c[g>>2]|0)+32>>2]|0)+V|0;V=E+24|0;Q=J+(U+I)|0;Z=V|0;X=V+4|0;V=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;X=Q|0;x=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=Q+4|0;x=V;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=(c[(c[g>>2]|0)+32>>2]|0)+U|0;U=E+32|0;V=J+(X+I)|0;Q=U|0;Z=U+4|0;U=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;Z=V|0;x=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;Z=V+4|0;x=U;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;Z=(c[(c[g>>2]|0)+32>>2]|0)+X+I|0;X=E+40|0;U=J+Z|0;V=X|0;Q=X+4|0;X=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=U|0;x=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=U+4|0;x=X;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=Z+(c[(c[g>>2]|0)+32>>2]|0)|0;Z=E+48|0;X=J+Q|0;U=Z|0;V=Z+4|0;Z=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;V=X|0;x=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=X+4|0;x=Z;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=E+56|0;Z=J+((c[(c[g>>2]|0)+32>>2]|0)+Q)|0;Q=V|0;X=V+4|0;V=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;X=Z|0;x=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=Z+4|0;x=V;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;W=E+64|0}else if((L|0)==3){X=E;while(1){if((k-X|0)<2){n=-1094995529;N=31;break b}V=d[X]|0;Z=ba(V>>>3&7,c[(c[g>>2]|0)+32>>2]|0)|0;Q=X+2|0;a[J+(Z+(V&7|I))|0]=a[X+1|0]|0;if((V&128|0)==0){X=Q}else{W=Q;break}}}else{W=E}}while(0);if((W|0)==0){n=-1094995529;N=31;break b}else{E=W;F=F+8|0;G=M}}F=C+8|0;if((F|0)<128){B=G;C=F;D=E}else{break a}}if((N|0)==31){i=h;return n|0}}}while(0);N=MCb(e,c[g>>2]|0)|0;if((N|0)<0){n=N;i=h;return n|0}c[f>>2]=1;n=l;i=h;return n|0}function x_a(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function y_a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+256|0;h=g|0;j=e;e=j-b<<3;k=e>>>0>2147483639>>>0|(b|0)==0;l=k?0:b;m=k?0:e;e=m+8|0;k=0;n=0;o=0;do{if((m-k|0)<4){p=0;q=11;break}r=l+(k>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((k&7)>>>0)<<28;r=s>>28;t=k+4|0;k=e>>>0>t>>>0?t:e;c[h+(n<<2)>>2]=r;o=((s|0)>-268435456?r:-r|0)+o|0;n=n+1|0;}while((n|0)<64&(o|0)<64);if((q|0)==11){i=g;return p|0}o=b+((k+7|0)/8|0)|0;k=f;f=64;b=0;while(1){n=c[h+(b<<2)>>2]|0;if((n|0)<0){e=-n|0;if((j-o|0)<1){p=0;q=11;break}TGb(k|0,a[o]|0,((f|0)<(e|0)?f:e)|0)|0;u=e;v=o+1|0}else{if((j-o|0)<(n|0)){p=0;q=11;break}UGb(k|0,o|0,(n|0)>(f|0)?f:n)|0;u=n;v=o+n|0}n=f-u|0;e=b+1|0;if((e|0)<64&(n|0)>0){o=v;k=k+u|0;f=n;b=e}else{p=v;q=11;break}}if((q|0)==11){i=g;return p|0}return 0}function z_a(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+16>>2]=0;c[b+20>>2]=0;c[b>>2]=a;TKa(b+1120|0);Rkb();return 0}function A_a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0.0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0;j=i;i=i+176|0;k=j|0;l=j+56|0;m=j+64|0;n=j+72|0;o=j+80|0;p=j+88|0;q=j+96|0;r=j+104|0;s=j+112|0;t=j+128|0;u=j+136|0;v=j+144|0;w=j+160|0;y=c[b+60>>2]|0;z=y;A=e;B=s|0;c[B>>2]=A;c[s+4>>2]=0;c[s+8>>2]=0;C=y+4|0;D=C;E=g+24|0;F=c[E>>2]|0;G=g+28|0;g=c[G>>2]|0;if(!((g|0)>-1)){yDb(0,0,1973520,(H=i,i=i+24|0,c[H>>2]=1970736,c[H+8>>2]=1961872,c[H+16>>2]=135,H)|0);i=H;Cd();return 0}I=C;c[I>>2]=F;C=y+12|0;c[C>>2]=F;J=y+8|0;c[J>>2]=F+g;g=P_a(D,u,t)|0;if((g|0)!=0){yDb(b,16,2181144,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=g;i=j;return K|0}g=c[t>>2]|0;do{if(!(g>>>0>4294967280>>>0)){if((c[G>>2]|0)>>>0<(g+14|0)>>>0){break}F=y+1060|0;c[F>>2]=c[u>>2];L=y+24|0;c[L>>2]=1;M=y+28|0;c[M>>2]=1;N=y+1068|0;c[N>>2]=0;O=y+1064|0;c[O>>2]=1;P=y+1084|0;c[P>>2]=0;Q=y+1132|0;R=c[Q>>2]|0;S=y+1136|0;T=S;if((R|0)>0){U=0;V=R;while(1){R=(c[T>>2]|0)+(U*20|0)+16|0;if((c[R>>2]|0)==0){W=V}else{$Db(R);W=c[Q>>2]|0}R=U+1|0;if((R|0)<(W|0)){U=R;V=W}else{break}}}$Db(S);c[Q>>2]=0;V=y+1116|0;c[V>>2]=0;U=y+1104|0;c[U>>2]=0;R=c[t>>2]|0;X=c[C>>2]|0;Y=(c[J>>2]|0)-X|0;if((R|0)<0){Z=0}else{Z=(Y|0)<(R|0)?Y:R}c[I>>2]=X+Z;X=F_a(D,c[u>>2]|0)|0;if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<(X*12|0)>>>0){K=-1094995529;i=j;return K|0}R=r;Y=y;_=y+16|0;$=y+20|0;aa=y+1080|0;ca=y+1076|0;da=y+1092|0;ea=y+1112|0;fa=y+1088|0;ga=y+1100|0;ha=y+1108|0;ia=y+1096|0;ja=y+1056|0;ka=y+1072|0;la=m;ma=l;na=0;while(1){if((na|0)>=(X|0)){break}a:do{if((Q_a(D,c[F>>2]|0,n,o,p,q)|0)<0){oa=211}else{pa=(c[I>>2]|0)-(c[C>>2]|0)|0;do{if((c[p>>2]|0)==1){qa=c[o>>2]|0;if((qa|0)==2){ra=0;break}else if((qa|0)==1|(qa|0)==3|(qa|0)==4){ra=I_a(D,qa,c[F>>2]|0)|0;break}else{ra=-1;break}}else{ra=0}}while(0);qa=c[n>>2]|0;if((qa|0)==279){sa=c[p>>2]|0;if((sa|0)==1){c[U>>2]=0;c[ha>>2]=ra;c[fa>>2]=1;ta=0}else{c[U>>2]=pa;ta=pa}c[fa>>2]=sa;c[ia>>2]=c[o>>2];if((ta|0)<=((c[J>>2]|0)-(c[C>>2]|0)|0)){oa=211;break}yDb(c[Y>>2]|0,16,2119720,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ua=-1094995529;break}else if((qa|0)==306){if((C_a(c[p>>2]|0,c[o>>2]|0,2032216,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==271){if((C_a(c[p>>2]|0,c[o>>2]|0,2017392,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==284){c[ka>>2]=(ra|0)==2;oa=211;break}else if((qa|0)==320){sa=c[p>>2]|0;if(sa>>>0>770>>>0){ua=-1094995529;break}va=d[180128+(c[o>>2]|0)|0]|0;if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<(ba(va*3|0,(sa>>>0)/3|0)|0)>>>0){ua=-1094995529;break}wa=(va<<3)-8|0;do{if(sa>>>0>2>>>0){va=0;do{xa=z+32+(va<<2)|0;c[xa>>2]=-16777216;ya=(I_a(D,c[o>>2]|0,c[F>>2]|0)|0)>>>(wa>>>0)<<16;c[xa>>2]=ya|c[xa>>2];va=va+1|0;za=c[p>>2]|0;}while(va>>>0<((za>>>0)/3|0)>>>0);if(za>>>0>2>>>0){Aa=0}else{break}do{va=(I_a(D,c[o>>2]|0,c[F>>2]|0)|0)>>>(wa>>>0)<<8;xa=z+32+(Aa<<2)|0;c[xa>>2]=va|c[xa>>2];Aa=Aa+1|0;Ba=c[p>>2]|0;}while(Aa>>>0<((Ba>>>0)/3|0)>>>0);if(Ba>>>0>2>>>0){Ca=0}else{break}do{xa=(I_a(D,c[o>>2]|0,c[F>>2]|0)|0)>>>(wa>>>0);va=z+32+(Ca<<2)|0;c[va>>2]=xa|c[va>>2];Ca=Ca+1|0;}while(Ca>>>0<(((c[p>>2]|0)>>>0)/3|0)>>>0)}}while(0);c[ja>>2]=1;oa=211;break}else if((qa|0)==325|(qa|0)==323|(qa|0)==324|(qa|0)==322){yDb(c[Y>>2]|0,16,2113752,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ua=-1163346256;break}else if((qa|0)==317){c[aa>>2]=ra;oa=211;break}else if((qa|0)==262){if((ra|0)==0){c[N>>2]=1;oa=211;break}else if((ra|0)==1){c[N>>2]=0;oa=211;break}else if((ra|0)==2|(ra|0)==3){oa=211;break}else{yDb(c[Y>>2]|0,16,2099424,(H=i,i=i+8|0,c[H>>2]=ra,H)|0);i=H;ua=-1094995529;break}}else if((qa|0)==292){if((c[O>>2]|0)!=3){oa=211;break}c[ca>>2]=ra;oa=211;break}else if((qa|0)==272){if((C_a(c[p>>2]|0,c[o>>2]|0,2013448,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==285){if((C_a(c[p>>2]|0,c[o>>2]|0,2009216,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==34737){wa=(c[I>>2]|0)-(c[C>>2]|0)|0;if((c[Q>>2]|0)>0){Da=0}else{oa=211;break}b:while(1){sa=c[T>>2]|0;c:do{if((c[sa+(Da*20|0)+4>>2]|0)==34737){va=c[sa+(Da*20|0)+8>>2]|0;do{if((va|0)!=0){xa=c[sa+(Da*20|0)+12>>2]|0;if((xa+va|0)>>>0>(c[p>>2]|0)>>>0){break}ya=xa+wa|0;xa=c[C>>2]|0;Ea=c[J>>2]|0;Fa=Ea-xa|0;if((ya|0)<0){Ga=0}else{Ga=(Fa|0)<(ya|0)?Fa:ya}ya=xa+Ga|0;c[I>>2]=ya;if((Ea-ya|0)>>>0<va>>>0){ua=-1094995529;break a}ya=WDb(va)|0;if((ya|0)==0){break b}Ea=c[T>>2]|0;xa=Ea+(Da*20|0)+8|0;Fa=c[xa>>2]|0;Ha=c[I>>2]|0;UGb(ya|0,Ha|0,Fa)|0;c[I>>2]=Ha+Fa;a[ya+((c[xa>>2]|0)-1)|0]=0;c[Ea+(Da*20|0)+16>>2]=ya;break c}}while(0);yDb(c[Y>>2]|0,24,2055144,(H=i,i=i+8|0,c[H>>2]=c[sa+(Da*20|0)>>2],H)|0);i=H}}while(0);sa=Da+1|0;if((sa|0)<(c[Q>>2]|0)){Da=sa}else{oa=211;break a}}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ua=-12;break}else if((qa|0)==259){c[O>>2]=ra;c[aa>>2]=0;if((ra|0)==6|(ra|0)==7){EDb(c[Y>>2]|0,2138368,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ua=-1163346256;break}else if((ra|0)==1|(ra|0)==32773|(ra|0)==5|(ra|0)==2|(ra|0)==32946|(ra|0)==8){oa=211;break}else if((ra|0)==3|(ra|0)==4){c[ca>>2]=0;oa=211;break}else{yDb(c[Y>>2]|0,16,2131808,(H=i,i=i+8|0,c[H>>2]=ra,H)|0);i=H;ua=-1094995529;break}}else if((qa|0)==34736){wa=c[p>>2]|0;if(wa>>>0>268435454>>>0){ua=-1094995529;break}sa=wa<<3;if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<sa>>>0){ua=-1094995529;break}wa=WDb(sa)|0;c[r>>2]=wa;if((wa|0)==0){yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}if((c[p>>2]|0)!=0){wa=0;do{Ia=+H_a(D,c[F>>2]|0);h[(c[r>>2]|0)+(wa<<3)>>3]=Ia;wa=wa+1|0;}while(wa>>>0<(c[p>>2]|0)>>>0)}d:do{if((c[Q>>2]|0)>0){wa=0;e:while(1){sa=c[T>>2]|0;f:do{if((c[sa+(wa*20|0)+4>>2]|0)==34736){va=c[sa+(wa*20|0)+8>>2]|0;do{if((va|0)!=0){ya=c[sa+(wa*20|0)+12>>2]|0;if((ya+va|0)>>>0>(c[p>>2]|0)>>>0){break}Ea=c[r>>2]|0;if(va>>>0>82595523>>>0){break e}Ja=WDb(va*26|0|1)|0;if((Ja|0)==0){break e}a[Ja]=0;if((va|0)>0){xa=Ja;Fa=0;while(1){Ha=Lb(xa|0,26,1983632,(H=i,i=i+16|0,h[H>>3]=+h[Ea+(Fa+ya<<3)>>3],c[H+8>>2]=2044120,H)|0)|0;i=H;if(Ha>>>0>25>>>0){oa=169;break e}Ka=Fa+1|0;if((Ka|0)<(va|0)){xa=xa+Ha|0;Fa=Ka}else{break}}}a[Ja+((SGb(Ja|0)|0)-2)|0]=0;c[(c[T>>2]|0)+(wa*20|0)+16>>2]=Ja;break f}}while(0);yDb(c[Y>>2]|0,24,2055144,(H=i,i=i+8|0,c[H>>2]=c[sa+(wa*20|0)>>2],H)|0);i=H}}while(0);wa=wa+1|0;if((wa|0)>=(c[Q>>2]|0)){break d}}if((oa|0)==169){oa=0;ZDb(Ja)}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;$Db(R);ua=-12;break a}}while(0);$Db(R);oa=211;break}else if((qa|0)==258){wa=c[p>>2]|0;c[M>>2]=wa;if(wa>>>0>4>>>0){yDb(c[Y>>2]|0,16,2157696,(H=i,i=i+16|0,c[H>>2]=c[L>>2],c[H+8>>2]=wa,H)|0);i=H;ua=-1094995529;break}if((wa|0)==1){c[L>>2]=ra;oa=211;break}sa=c[o>>2]|0;if(!((sa|0)==1|(sa|0)==3|(sa|0)==4)){c[L>>2]=-1;oa=211;break}c[L>>2]=0;if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<(ba(d[180128+sa|0]|0,wa)|0)>>>0){ua=-1094995529;break}if((wa|0)==0){oa=211;break}wa=I_a(D,sa,c[F>>2]|0)|0;c[L>>2]=(c[L>>2]|0)+wa;if((c[p>>2]|0)>>>0>1>>>0){La=1}else{oa=211;break}while(1){wa=La+1|0;sa=I_a(D,c[o>>2]|0,c[F>>2]|0)|0;c[L>>2]=(c[L>>2]|0)+sa;if(wa>>>0<(c[p>>2]|0)>>>0){La=wa}else{oa=211;break}}}else if((qa|0)==277){if((c[p>>2]|0)!=1){yDb(c[Y>>2]|0,16,2150912,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ua=-1094995529;break}if(ra>>>0>4>>>0){yDb(c[Y>>2]|0,16,2143872,(H=i,i=i+8|0,c[H>>2]=ra,H)|0);i=H;ua=-1094995529;break}if((c[M>>2]|0)==1){c[L>>2]=ba(c[L>>2]|0,ra)|0}c[M>>2]=ra;oa=211;break}else if((qa|0)==34735){if((C_a(1,c[o>>2]|0,2072776,0,z,A)|0)<0){yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}if((C_a(2,c[o>>2]|0,2068112,2063744,z,A)|0)<0){yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}wa=F_a(D,c[F>>2]|0)|0;c[Q>>2]=wa;sa=((c[p>>2]|0)>>>2)-1|0;if(wa>>>0>sa>>>0){c[Q>>2]=sa;yDb(c[Y>>2]|0,24,2059936,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;Ma=c[Q>>2]|0}else{Ma=wa}if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<Ma<<3>>>0){c[Q>>2]=0;ua=-1;break}wa=cEb(Ma*20|0)|0;c[T>>2]=wa;if((wa|0)==0){yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[Q>>2]=0;oa=211;break}if((c[Q>>2]|0)>0){Na=0}else{oa=211;break}while(1){wa=F_a(D,c[F>>2]|0)|0;c[(c[T>>2]|0)+(Na*20|0)>>2]=wa;wa=F_a(D,c[F>>2]|0)|0;c[(c[T>>2]|0)+(Na*20|0)+4>>2]=wa;wa=F_a(D,c[F>>2]|0)|0;sa=c[T>>2]|0;c[sa+(Na*20|0)+8>>2]=wa;if((c[sa+(Na*20|0)+4>>2]|0)==0){wa=c[sa+(Na*20|0)>>2]|0;sa=F_a(D,c[F>>2]|0)|0;g:do{if((sa|0)==0){Oa=eEb(1980872)|0}else if((sa|0)==32767){Oa=eEb(1978072)|0}else{h:do{switch(wa|0){case 3074:{c[l>>2]=sa;va=wc(ma|0,1111056,298,8,764)|0;if((va|0)==0){Pa=0}else{Pa=c[va+4>>2]|0}va=eEb(Pa)|0;if((va|0)!=0){Oa=va;break g}break};case 2048:{do{if((sa|0)>4200){va=sa-4201|0;if(!(va>>>0<133>>>0)){break}Oa=eEb(c[1122496+(va<<2)>>2]|0)|0;break g}else{if((sa|0)<=4e3){break h}}}while(0);va=sa-4001|0;if(!(va>>>0<35>>>0)){break h}Oa=eEb(c[1122352+(va<<2)>>2]|0)|0;break g;break};case 2052:case 3076:case 4099:{if((sa|0)<=9e3){break h}va=sa-9001|0;if(!(va>>>0<15>>>0)){break h}Oa=eEb(c[1121528+(va<<2)>>2]|0)|0;break g;break};case 2054:case 2060:{if((sa|0)<=9100){break h}va=sa-9101|0;if(!(va>>>0<8>>>0)){break h}Oa=eEb(c[1123520+(va<<2)>>2]|0)|0;break g;break};case 2051:{if((sa|0)<=8900){break h}va=sa-8901|0;if(!(va>>>0<11>>>0)){break h}Oa=eEb(c[1121456+(va<<2)>>2]|0)|0;break g;break};case 3072:{c[m>>2]=sa;va=wc(la|0,1113632,978,8,764)|0;if((va|0)==0){Qa=0}else{Qa=c[va+4>>2]|0}va=eEb(Qa)|0;if((va|0)!=0){Oa=va;break g}break};case 1024:{if((sa|0)<=0){break h}va=sa-1|0;if(!(va>>>0<3>>>0)){break h}Oa=eEb(c[1121600+(va<<2)>>2]|0)|0;break g;break};case 2050:{do{if((sa|0)>6200){va=sa-6201|0;if(!(va>>>0<120>>>0)){break}Oa=eEb(c[1121872+(va<<2)>>2]|0)|0;break g}else{if((sa|0)<=6e3){break h}}}while(0);va=sa-6001|0;if(!(va>>>0<35>>>0)){break h}Oa=eEb(c[1121728+(va<<2)>>2]|0)|0;break g;break};case 2056:{if((sa|0)<=7e3){break h}va=sa-7001|0;if(!(va>>>0<35>>>0)){break h}Oa=eEb(c[1123136+(va<<2)>>2]|0)|0;break g;break};case 1025:{if((sa|0)<=0){break h}va=sa-1|0;if(!(va>>>0<2>>>0)){break h}Oa=eEb(c[1121592+(va<<2)>>2]|0)|0;break g;break};case 3075:{if((sa|0)<=0){break h}va=sa-1|0;if(!(va>>>0<27>>>0)){break h}Oa=eEb(c[1123384+(va<<2)>>2]|0)|0;break g;break};case 4096:{if((sa|0)<=5e3){break h}va=sa-5001|0;if(va>>>0<32>>>0){Oa=eEb(c[1110928+(va<<2)>>2]|0)|0;break g}if((sa|0)<=5100){break h}va=sa-5101|0;if(!(va>>>0<6>>>0)){break h}Oa=eEb(c[1121504+(va<<2)>>2]|0)|0;break g;break};default:{}}}while(0);va=WDb(14)|0;if((va|0)==0){Oa=0;break}Lb(va|0,14,1975536,(H=i,i=i+8|0,c[H>>2]=sa,H)|0)|0;i=H;Oa=va}}while(0);c[(c[T>>2]|0)+(Na*20|0)+16>>2]=Oa}else{sa=F_a(D,c[F>>2]|0)|0;c[(c[T>>2]|0)+(Na*20|0)+12>>2]=sa}sa=Na+1|0;if((sa|0)<(c[Q>>2]|0)){Na=sa}else{oa=211;break}}}else if((qa|0)==257){c[$>>2]=ra;oa=211;break}else if((qa|0)==269){if((C_a(c[p>>2]|0,c[o>>2]|0,2028216,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==297){if((C_a(c[p>>2]|0,c[o>>2]|0,1998712,1994720,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==273){sa=c[p>>2]|0;if((sa|0)==1){c[V>>2]=0;c[ea>>2]=ra;c[fa>>2]=1;c[da>>2]=c[$>>2];Ra=0}else{c[V>>2]=pa;c[fa>>2]=sa;Ra=pa}c[ga>>2]=c[o>>2];if((Ra|0)<=((c[J>>2]|0)-(c[C>>2]|0)|0)){oa=211;break}yDb(c[Y>>2]|0,16,2119720,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ua=-1094995529;break}else if((qa|0)==33920){if((C_a(c[p>>2]|0,c[o>>2]|0,2083192,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==33550){if((C_a(c[p>>2]|0,c[o>>2]|0,2087752,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==316){if((C_a(c[p>>2]|0,c[o>>2]|0,2024576,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==305){if((C_a(c[p>>2]|0,c[o>>2]|0,1991432,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==33432){if((C_a(c[p>>2]|0,c[o>>2]|0,2036096,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==270){if((C_a(c[p>>2]|0,c[o>>2]|0,2021328,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==293){if((c[O>>2]|0)!=4){oa=211;break}c[ca>>2]=ra;oa=211;break}else if((qa|0)==278){if((c[o>>2]|0)==4&(ra|0)==-1){Sa=c[$>>2]|0}else{Sa=ra}if((Sa|0)==0){yDb(c[Y>>2]|0,16,2125464,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ua=-1094995529;break}else{c[da>>2]=Sa;oa=211;break}}else if((qa|0)==33922){if((C_a(c[p>>2]|0,c[o>>2]|0,2077520,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==256){c[_>>2]=ra;oa=211;break}else if((qa|0)==315){if((C_a(c[p>>2]|0,c[o>>2]|0,2039208,0,z,A)|0)>=0){oa=211;break}yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==266){if((ra|0)==0|ra>>>0>2>>>0){yDb(c[Y>>2]|0,16,2093096,(H=i,i=i+8|0,c[H>>2]=ra,H)|0);i=H;Ta=1}else{Ta=ra}c[P>>2]=Ta-1;oa=211;break}else{sa=c[Y>>2]|0;if((c[sa+696>>2]&8|0)==0){oa=211;break}yDb(sa,16,1987976,(H=i,i=i+16|0,c[H>>2]=qa,c[H+8>>2]=qa,H)|0);i=H;ua=-1094995529;break}}}while(0);if((oa|0)==211){oa=0;sa=c[q>>2]|0;wa=c[C>>2]|0;va=(c[J>>2]|0)-wa|0;if((sa|0)<0){Ua=0}else{Ua=(va|0)<(sa|0)?va:sa}c[I>>2]=wa+Ua;ua=0}if((ua|0)<0){K=ua;oa=474;break}else{na=na+1|0}}if((oa|0)==474){i=j;return K|0}i:do{if((c[Q>>2]|0)>0){na=b;la=0;j:while(1){ma=c[T>>2]|0;R=c[ma+(la*20|0)>>2]|0;X=(R|0)>4095;do{if(X){S=R-4096|0;if(!(S>>>0<4>>>0)){oa=219;break}Va=1110896+(S<<3)|0;oa=227}else{if((R|0)>3071){oa=219;break}if((R|0)>2047){oa=222;break}if((R|0)>1023){oa=225}else{oa=228}}}while(0);do{if((oa|0)==219){oa=0;qa=R-3072|0;if(!(qa>>>0<24>>>0)){oa=222;break}Va=1113440+(qa<<3)|0;oa=227}}while(0);do{if((oa|0)==222){oa=0;qa=R-2048|0;if(!(qa>>>0<14>>>0)){oa=225;break}Va=1121616+(qa<<3)|0;oa=227}}while(0);do{if((oa|0)==225){oa=0;qa=R-1024|0;if(!(qa>>>0<3>>>0)){oa=228;break}Va=1123496+(qa<<3)|0;oa=227}}while(0);do{if((oa|0)==227){oa=0;Wa=c[Va>>2]|0;if((Wa|0)==0){oa=228;break}do{if(X){qa=R-4096|0;if(!(qa>>>0<4>>>0)){oa=233;break}Xa=c[1110900+(qa<<3)>>2]|0}else{if((R|0)>3071){oa=233;break}if((R|0)>2047){oa=236;break}if((R|0)>1023){oa=239}else{Xa=-1094995529}}}while(0);do{if((oa|0)==233){oa=0;qa=R-3072|0;if(!(qa>>>0<24>>>0)){oa=236;break}Xa=c[1113444+(qa<<3)>>2]|0}}while(0);do{if((oa|0)==236){oa=0;qa=R-2048|0;if(!(qa>>>0<14>>>0)){oa=239;break}Xa=c[1121620+(qa<<3)>>2]|0}}while(0);do{if((oa|0)==239){oa=0;qa=R-1024|0;if(!(qa>>>0<3>>>0)){Xa=-1094995529;break}Xa=c[1123500+(qa<<3)>>2]|0}}while(0);if((Xa|0)==(c[ma+(la*20|0)+4>>2]|0)){qa=FCb(A)|0;Ya=CBb(qa,Wa,c[(c[T>>2]|0)+(la*20|0)+16>>2]|0,0)|0;if((Ya|0)<0){break j}else{break}}else{yDb(na,24,2001984,(H=i,i=i+8|0,c[H>>2]=R,H)|0);i=H;break}}}while(0);if((oa|0)==228){oa=0;yDb(na,24,2047608,(H=i,i=i+8|0,c[H>>2]=R,H)|0);i=H}la=la+1|0;if((la|0)>=(c[Q>>2]|0)){break i}}yDb(na,16,1964712,(H=i,i=i+8|0,c[H>>2]=Wa,H)|0);i=H;K=Ya;i=j;return K|0}}while(0);do{if((c[V>>2]|0)==0){if((c[ea>>2]|0)!=0){break}yDb(b,16,1936616,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=-1094995529;i=j;return K|0}}while(0);Q=c[L>>2]|0;T=c[M>>2]|0;k:do{switch((Q*10|0)+((c[ka>>2]|0)*1e3|0)+T|0){case 1483:{la=c[Y>>2]|0;c[la+140>>2]=(c[F>>2]|0)!=0?88:87;Za=la;break};case 1644:{la=c[Y>>2]|0;c[la+140>>2]=(c[F>>2]|0)!=0?319:318;Za=la;break};case 483:{la=c[Y>>2]|0;c[la+140>>2]=(c[F>>2]|0)!=0?42:41;Za=la;break};case 644:{la=c[Y>>2]|0;c[la+140>>2]=(c[F>>2]|0)!=0?292:291;Za=la;break};case 1243:{la=c[Y>>2]|0;c[la+140>>2]=82;Za=la;break};case 1324:{la=c[Y>>2]|0;c[la+140>>2]=317;Za=la;break};case 21:case 41:case 81:{oa=252;break};case 243:{la=c[Y>>2]|0;c[la+140>>2]=2;Za=la;break};case 161:{la=c[Y>>2]|0;c[la+140>>2]=(c[F>>2]|0)!=0?32:31;Za=la;break};case 162:{la=c[Y>>2]|0;c[la+140>>2]=66;Za=la;break};case 324:{la=c[Y>>2]|0;c[la+140>>2]=28;Za=la;break};case 11:{if((c[ja>>2]|0)!=0){oa=252;break k}la=c[Y>>2]|0;c[la+140>>2]=10;Za=la;break};default:{yDb(c[Y>>2]|0,16,2164464,(H=i,i=i+16|0,c[H>>2]=Q,c[H+8>>2]=T,H)|0);i=H;K=-1094995529;i=j;return K|0}}}while(0);if((oa|0)==252){T=c[Y>>2]|0;c[T+140>>2]=11;Za=T}T=c[_>>2]|0;Q=c[$>>2]|0;if((T|0)==(c[Za+120>>2]|0)){if((Q|0)==(c[Za+124>>2]|0)){_a=Za}else{oa=266}}else{oa=266}do{if((oa|0)==266){la=V$a(Za,T,Q)|0;if((la|0)<0){K=la;i=j;return K|0}else{_a=c[Y>>2]|0;break}}}while(0);Q=W0a(_a,s,0)|0;if((Q|0)<0){K=Q;i=j;return K|0}do{if((c[(c[Y>>2]|0)+140>>2]|0)==11){Q=c[(c[B>>2]|0)+4>>2]|0;if((c[ja>>2]|0)!=0){UGb(Q|0,y+32|0,1024)|0;break}T=Q;Q=1<<c[L>>2];if((Q|0)>0){$a=0;ab=Q}else{break}do{c[T+($a<<2)>>2]=(($a*255|0|0)/(ab-1|0)|0)*65793|0|-16777216;$a=$a+1|0;ab=1<<c[L>>2];}while(($a|0)<(ab|0))}}while(0);do{if((c[fa>>2]|0)==1){if((c[ha>>2]|0)!=0){break}yDb(b,24,1913e3,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[ha>>2]=(c[G>>2]|0)-(c[ea>>2]|0)}}while(0);fa=c[U>>2]|0;do{if((fa|0)!=0){ja=c[G>>2]|0;if(!(fa>>>0<ja>>>0)){K=-1094995529;i=j;return K|0}T=c[E>>2]|0;na=T+fa|0;if((ja-fa|0)>-1){c[v>>2]=na;c[v+8>>2]=na;c[v+4>>2]=T+ja;break}else{yDb(0,0,1973520,(H=i,i=i+24|0,c[H>>2]=1970736,c[H+8>>2]=1961872,c[H+16>>2]=135,H)|0);i=H;Cd();return 0}}}while(0);fa=c[V>>2]|0;do{if((fa|0)!=0){ja=c[G>>2]|0;if(!(fa>>>0<ja>>>0)){K=-1094995529;i=j;return K|0}T=c[E>>2]|0;na=T+fa|0;if((ja-fa|0)>-1){c[w>>2]=na;c[w+8>>2]=na;c[w+4>>2]=T+ja;break}else{yDb(0,0,1973520,(H=i,i=i+24|0,c[H>>2]=1970736,c[H+8>>2]=1961872,c[H+16>>2]=135,H)|0);i=H;Cd();return 0}}}while(0);fa=c[da>>2]|0;if((fa|0)<1){yDb(b,16,1892592,(H=i,i=i+8|0,c[H>>2]=fa,H)|0);i=H;K=-1094995529;i=j;return K|0}if((c[ka>>2]|0)==0){bb=1;oa=291}else{fa=c[M>>2]|0;if((fa|0)>0){bb=fa;oa=291}else{cb=fa;oa=471}}do{if((oa|0)==291){fa=e+32|0;ja=e;T=y+1120|0;na=k;Q=k|0;la=k+4|0;ma=k+12|0;X=k+16|0;qa=k+20|0;pa=y+1124|0;S=pa;wa=y+1128|0;sa=b+696|0;va=0;l:while(1){Fa=fa+(va<<2)|0;xa=c[Fa>>2]|0;ya=ja+(va<<2)|0;m:do{if((c[$>>2]|0)>0){Ea=c[ya>>2]|0;Ka=0;n:while(1){if((c[U>>2]|0)==0){db=c[ha>>2]|0}else{db=I_a(v,c[ia>>2]|0,c[F>>2]|0)|0}if((c[V>>2]|0)==0){eb=c[ea>>2]|0}else{eb=I_a(w,c[ga>>2]|0,c[F>>2]|0)|0}Ha=c[G>>2]|0;if(eb>>>0>Ha>>>0|db>>>0>(Ha-eb|0)>>>0){oa=301;break l}Ha=c[E>>2]|0;fb=Ha+eb|0;gb=c[da>>2]|0;hb=(c[$>>2]|0)-Ka|0;ib=(gb|0)>(hb|0)?hb:gb;gb=((ba(c[L>>2]|0,c[_>>2]|0)|0)+7|0)>>>3;if((c[ka>>2]|0)==0){jb=gb}else{jb=(gb>>>0)/((c[M>>2]|0)>>>0)|0}if((db|0)<1){kb=-1094995529;break}gb=c[O>>2]|0;if((gb|0)==5){do{if((c[P>>2]|0)==0){lb=fb;oa=340}else{O$a(pa,wa,db);hb=c[S>>2]|0;if((hb|0)==0){kb=-12;break n}if((db|0)<=0){mb=hb;break}a[hb]=a[1148864+(d[fb]|0)|0]|0;if((db|0)>1){hb=1;do{a[(c[S>>2]|0)+hb|0]=a[1148864+(d[Ha+(hb+eb)|0]|0)|0]|0;hb=hb+1|0;}while((hb|0)<(db|0))}lb=c[S>>2]|0;oa=340}}while(0);do{if((oa|0)==340){oa=0;if((db|0)<=1){mb=lb;break}if((a[lb]|0)!=0){mb=lb;break}if((a[lb+1|0]&1)==0){mb=lb;break}yDb(c[Y>>2]|0,16,233e4,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;mb=lb}}while(0);nb=VKa(c[T>>2]|0,8,mb,db,1)|0;if((nb|0)<0){oa=346;break}ob=mb;pb=c[O>>2]|0;oa=347}else if((gb|0)==32946|(gb|0)==8){qb=ba(jb,ib)|0;rb=WDb(qb)|0;if((rb|0)==0){kb=-12;break}do{if((c[P>>2]|0)==0){sb=fb}else{O$a(pa,wa,db);hb=c[S>>2]|0;if((hb|0)==0){oa=312;break n}if((db|0)<=0){sb=hb;break}a[hb]=a[1148864+(d[fb]|0)|0]|0;if((db|0)>1){hb=1;do{a[(c[S>>2]|0)+hb|0]=a[1148864+(d[Ha+(hb+eb)|0]|0)|0]|0;hb=hb+1|0;}while((hb|0)<(db|0))}sb=c[S>>2]|0}}while(0);TGb(na|0,0,56)|0;c[Q>>2]=sb;c[la>>2]=db;c[ma>>2]=rb;c[X>>2]=qb;tb=Qd(k|0,2191384,56)|0;if((tb|0)!=0){oa=315;break}Ha=$c(k|0,2)|0;he(k|0)|0;hb=(Ha|0)==1?0:Ha;if((hb|0)!=0){ub=c[qa>>2]|0;vb=hb;oa=319;break}o:do{if((ib|0)>0){hb=(jb|0)>0;Ha=rb;wb=Ea;xb=1;while(1){yb=c[L>>2]|0;do{if(yb>>>0<8>>>0){if((c[(c[Y>>2]|0)+140>>2]|0)!=11){oa=330;break}if((yb|0)==4){if(hb){zb=jb}else{break}do{zb=zb-1|0;Ab=a[Ha+zb|0]|0;Bb=zb<<1;a[wb+(Bb|1)|0]=Ab&15;a[wb+Bb|0]=(Ab&255)>>>4;}while((zb|0)>0)}else if((yb|0)==2){if(hb){Cb=jb}else{break}do{Cb=Cb-1|0;Ab=a[Ha+Cb|0]|0;Bb=Cb<<2;a[wb+(Bb|3)|0]=Ab&3;a[wb+(Bb|2)|0]=(Ab&255)>>>2&3;a[wb+(Bb|1)|0]=(Ab&255)>>>4&3;a[wb+Bb|0]=(Ab&255)>>>6;}while((Cb|0)>0)}else if((yb|0)==1){if(hb){Db=jb}else{break}do{Db=Db-1|0;Ab=a[Ha+Db|0]|0;Bb=Db<<3;a[wb+(Bb|7)|0]=Ab&1;a[wb+(Bb|6)|0]=(Ab&255)>>>1&1;a[wb+(Bb|5)|0]=(Ab&255)>>>2&1;a[wb+(Bb|4)|0]=(Ab&255)>>>3&1;a[wb+(Bb|3)|0]=(Ab&255)>>>4&1;a[wb+(Bb|2)|0]=(Ab&255)>>>5&1;a[wb+(Bb|1)|0]=(Ab&255)>>>6&1;a[wb+Bb|0]=(Ab&255)>>>7;}while((Db|0)>0)}else{UGb(wb|0,Ha|0,jb)|0;break}}else{oa=330}}while(0);if((oa|0)==330){oa=0;UGb(wb|0,Ha|0,jb)|0}if((xb|0)>=(ib|0)){break o}Ha=Ha+jb|0;wb=wb+xa|0;xb=xb+1|0}}}while(0);ZDb(rb)}else{ob=fb;pb=gb;oa=347}do{if((oa|0)==347){oa=0;if((pb-2|0)>>>0<3>>>0){Eb=WDb(db+16|0)|0;if((Eb|0)==0){oa=351;break n}xb=c[ca>>2]|0;if((xb&2|0)!=0){oa=353;break n}do{if((c[P>>2]|0)==0){UGb(Eb|0,ob|0,db)|0}else{if((db|0)>0){Fb=0}else{break}do{a[Eb+Fb|0]=a[1148864+(d[ob+Fb|0]|0)|0]|0;Fb=Fb+1|0;}while((Fb|0)<(db|0))}}while(0);TGb(Eb+db|0,0,16)|0;wb=Skb(c[Y>>2]|0,Eb,db,Ea,ib,xa,c[O>>2]|0,xb)|0;Ha=c[L>>2]|0;p:do{if(Ha>>>0<8>>>0){if(!((c[(c[Y>>2]|0)+140>>2]|0)==11&(ib|0)>0)){break}hb=(jb|0)>0;yb=Ea;Ab=1;Bb=Ha;while(1){do{if((Bb|0)==4){if(hb){Gb=jb}else{break}do{Gb=Gb-1|0;Hb=yb+Gb|0;Ib=Gb<<1;a[yb+(Ib|1)|0]=a[Hb]&15;a[yb+Ib|0]=(d[Hb]|0)>>>4;}while((Gb|0)>0)}else if((Bb|0)==2){if(hb){Jb=jb}else{break}do{Jb=Jb-1|0;Hb=yb+Jb|0;Ib=Jb<<2;a[yb+(Ib|3)|0]=a[Hb]&3;a[yb+(Ib|2)|0]=(d[Hb]|0)>>>2&3;a[yb+(Ib|1)|0]=(d[Hb]|0)>>>4&3;a[yb+Ib|0]=(d[Hb]|0)>>>6;}while((Jb|0)>0)}else if((Bb|0)==1){if(hb){Kb=jb}else{break}do{Kb=Kb-1|0;Hb=yb+Kb|0;Ib=Kb<<3;a[yb+(Ib|7)|0]=a[Hb]&1;a[yb+(Ib|6)|0]=(d[Hb]|0)>>>1&1;a[yb+(Ib|5)|0]=(d[Hb]|0)>>>2&1;a[yb+(Ib|4)|0]=(d[Hb]|0)>>>3&1;a[yb+(Ib|3)|0]=(d[Hb]|0)>>>4&1;a[yb+(Ib|2)|0]=(d[Hb]|0)>>>5&1;a[yb+(Ib|1)|0]=(d[Hb]|0)>>>6&1;a[yb+Ib|0]=(d[Hb]|0)>>>7;}while((Kb|0)>0)}}while(0);if((Ab|0)>=(ib|0)){break p}yb=yb+xa|0;Ab=Ab+1|0;Bb=c[L>>2]|0}}}while(0);ZDb(Eb);if((wb|0)<0){kb=wb;break n}else{break}}if((ib|0)<=0){break}Ha=ob;xb=ob+db|0;Bb=(jb|0)>0;Ab=Bb^1;yb=ob;hb=Ea;Hb=0;while(1){Ib=yb;if((Ib-Ha|0)>(db|0)){oa=371;break n}Mb=c[O>>2]|0;do{if((Mb|0)==5){Nb=WKa(c[T>>2]|0,hb,jb)|0;if((Nb|0)<(jb|0)){oa=422;break n}Ob=c[L>>2]|0;if(!(Ob>>>0<8>>>0)){Pb=yb;break}if((c[(c[Y>>2]|0)+140>>2]|0)!=11){Pb=yb;break}if((Ob|0)==4){if(Bb){Qb=jb}else{Pb=yb;break}while(1){Rb=Qb-1|0;Sb=hb+Rb|0;Tb=Rb<<1;a[hb+(Tb|1)|0]=a[Sb]&15;a[hb+Tb|0]=(d[Sb]|0)>>>4;if((Rb|0)>0){Qb=Rb}else{Pb=yb;break}}}else if((Ob|0)==2){if(Bb){Ub=jb}else{Pb=yb;break}while(1){Rb=Ub-1|0;Sb=hb+Rb|0;Tb=Rb<<2;a[hb+(Tb|3)|0]=a[Sb]&3;a[hb+(Tb|2)|0]=(d[Sb]|0)>>>2&3;a[hb+(Tb|1)|0]=(d[Sb]|0)>>>4&3;a[hb+Tb|0]=(d[Sb]|0)>>>6;if((Rb|0)>0){Ub=Rb}else{Pb=yb;break}}}else if((Ob|0)==1){if(Bb){Vb=jb}else{Pb=yb;break}while(1){Rb=Vb-1|0;Sb=hb+Rb|0;Tb=Rb<<3;a[hb+(Tb|7)|0]=a[Sb]&1;a[hb+(Tb|6)|0]=(d[Sb]|0)>>>1&1;a[hb+(Tb|5)|0]=(d[Sb]|0)>>>2&1;a[hb+(Tb|4)|0]=(d[Sb]|0)>>>3&1;a[hb+(Tb|3)|0]=(d[Sb]|0)>>>4&1;a[hb+(Tb|2)|0]=(d[Sb]|0)>>>5&1;a[hb+(Tb|1)|0]=(d[Sb]|0)>>>6&1;a[hb+Tb|0]=(d[Sb]|0)>>>7;if((Rb|0)>0){Vb=Rb}else{Pb=yb;break}}}else{Pb=yb;break}}else if((Mb|0)==32773){if(Bb){Wb=yb;Xb=0}else{Pb=yb;break}while(1){if((xb-Wb|0)<2){oa=388;break n}Ob=Wb+1|0;Rb=a[Wb]|0;if((c[P>>2]|0)==0){Yb=Rb}else{Yb=a[1148864+(Rb&255)|0]|0}Rb=Yb<<24>>24;do{if(Yb<<24>>24>-1){Sb=Rb+1|0;Tb=Sb+Xb|0;if((Tb|0)>(jb|0)){oa=394;break n}if((xb-Ob|0)<(Sb|0)){oa=394;break n}Zb=c[L>>2]&-((c[(c[Y>>2]|0)+140>>2]|0)==11|0);do{if((Zb|0)==4){if((Sb|0)>0){_b=Rb}else{break}while(1){$b=Wb+(_b+1)|0;ac=_b+Xb<<1;a[hb+(ac|1)|0]=a[$b]&15;a[hb+ac|0]=(d[$b]|0)>>>4;if((_b|0)>0){_b=_b-1|0}else{break}}}else if((Zb|0)==2){if((Sb|0)>0){bc=Rb}else{break}while(1){$b=Wb+(bc+1)|0;ac=bc+Xb<<2;a[hb+(ac|3)|0]=a[$b]&3;a[hb+(ac|2)|0]=(d[$b]|0)>>>2&3;a[hb+(ac|1)|0]=(d[$b]|0)>>>4&3;a[hb+ac|0]=(d[$b]|0)>>>6;if((bc|0)>0){bc=bc-1|0}else{break}}}else if((Zb|0)==1){if((Sb|0)>0){cc=Rb}else{break}while(1){$b=Wb+(cc+1)|0;ac=cc+Xb<<3;a[hb+(ac|7)|0]=a[$b]&1;a[hb+(ac|6)|0]=(d[$b]|0)>>>1&1;a[hb+(ac|5)|0]=(d[$b]|0)>>>2&1;a[hb+(ac|4)|0]=(d[$b]|0)>>>3&1;a[hb+(ac|3)|0]=(d[$b]|0)>>>4&1;a[hb+(ac|2)|0]=(d[$b]|0)>>>5&1;a[hb+(ac|1)|0]=(d[$b]|0)>>>6&1;a[hb+ac|0]=(d[$b]|0)>>>7;if((cc|0)>0){cc=cc-1|0}else{break}}}else{UGb(hb+Xb|0,Ob|0,Sb)|0}}while(0);dc=Tb;ec=Wb+(Rb+2)|0}else{if(Yb<<24>>24==-128){dc=Xb;ec=Ob;break}Sb=1-Rb|0;Zb=Sb+Xb|0;if((Zb|0)>(jb|0)){oa=407;break n}$b=Wb+2|0;ac=a[Ob]|0;fc=c[L>>2]&-((c[(c[Y>>2]|0)+140>>2]|0)==11|0);if((fc|0)==4){if((Sb|0)<=0){dc=Zb;ec=$b;break}gc=ac&15;hc=(ac&255)>>>4;ic=Sb;while(1){jc=ic-1|0;kc=jc+Xb<<1;a[hb+(kc|1)|0]=gc;a[hb+kc|0]=hc;if((jc|0)>0){ic=jc}else{dc=Zb;ec=$b;break}}}else if((fc|0)==2){if((Sb|0)<=0){dc=Zb;ec=$b;break}ic=ac&3;hc=(ac&255)>>>2&3;gc=(ac&255)>>>4&3;Tb=(ac&255)>>>6;jc=Sb;while(1){kc=jc-1|0;lc=kc+Xb<<2;a[hb+(lc|3)|0]=ic;a[hb+(lc|2)|0]=hc;a[hb+(lc|1)|0]=gc;a[hb+lc|0]=Tb;if((kc|0)>0){jc=kc}else{dc=Zb;ec=$b;break}}}else if((fc|0)==1){if((Sb|0)<=0){dc=Zb;ec=$b;break}jc=ac&1;Tb=(ac&255)>>>1&1;gc=(ac&255)>>>2&1;hc=(ac&255)>>>3&1;ic=(ac&255)>>>4&1;kc=(ac&255)>>>5&1;lc=(ac&255)>>>6&1;mc=(ac&255)>>>7;nc=Sb;while(1){oc=nc-1|0;pc=oc+Xb<<3;a[hb+(pc|7)|0]=jc;a[hb+(pc|6)|0]=Tb;a[hb+(pc|5)|0]=gc;a[hb+(pc|4)|0]=hc;a[hb+(pc|3)|0]=ic;a[hb+(pc|2)|0]=kc;a[hb+(pc|1)|0]=lc;a[hb+pc|0]=mc;if((oc|0)>0){nc=oc}else{dc=Zb;ec=$b;break}}}else{TGb(hb+Xb|0,ac|0,Sb|0)|0;dc=Zb;ec=$b;break}}}while(0);if((dc|0)<(jb|0)){Wb=ec;Xb=dc}else{break}}if((c[P>>2]|0)==0|Ab){Pb=ec;break}else{qc=0}while(1){Ob=hb+qc|0;a[Ob]=a[1148864+(d[Ob]|0)|0]|0;Ob=qc+1|0;if((Ob|0)<(jb|0)){qc=Ob}else{Pb=ec;break}}}else if((Mb|0)==1){if((xb-Ib|0)<(jb|0)){kb=-1094995529;break n}do{if((c[P>>2]|0)==0){Ob=c[L>>2]&-((c[(c[Y>>2]|0)+140>>2]|0)==11|0);if((Ob|0)==4){if(Bb){rc=jb}else{break}do{rc=rc-1|0;Rb=yb+rc|0;nc=rc<<1;a[hb+(nc|1)|0]=a[Rb]&15;a[hb+nc|0]=(d[Rb]|0)>>>4;}while((rc|0)>0)}else if((Ob|0)==2){if(Bb){sc=jb}else{break}do{sc=sc-1|0;Rb=yb+sc|0;nc=sc<<2;a[hb+(nc|3)|0]=a[Rb]&3;a[hb+(nc|2)|0]=(d[Rb]|0)>>>2&3;a[hb+(nc|1)|0]=(d[Rb]|0)>>>4&3;a[hb+nc|0]=(d[Rb]|0)>>>6;}while((sc|0)>0)}else if((Ob|0)==1){if(Bb){tc=jb}else{break}do{tc=tc-1|0;Rb=yb+tc|0;nc=tc<<3;a[hb+(nc|7)|0]=a[Rb]&1;a[hb+(nc|6)|0]=(d[Rb]|0)>>>1&1;a[hb+(nc|5)|0]=(d[Rb]|0)>>>2&1;a[hb+(nc|4)|0]=(d[Rb]|0)>>>3&1;a[hb+(nc|3)|0]=(d[Rb]|0)>>>4&1;a[hb+(nc|2)|0]=(d[Rb]|0)>>>5&1;a[hb+(nc|1)|0]=(d[Rb]|0)>>>6&1;a[hb+nc|0]=(d[Rb]|0)>>>7;}while((tc|0)>0)}else{UGb(hb|0,yb|0,jb)|0;break}}else{if(Bb){uc=0}else{break}do{a[hb+uc|0]=a[1148864+(d[yb+uc|0]|0)|0]|0;uc=uc+1|0;}while((uc|0)<(jb|0))}}while(0);Pb=yb+jb|0}else{Pb=yb}}while(0);Ib=Hb+1|0;if((Ib|0)<(ib|0)){yb=Pb;hb=hb+xa|0;Hb=Ib}else{break}}}}while(0);ib=c[da>>2]|0;gb=ib+Ka|0;if((gb|0)>=(c[$>>2]|0)){break m}Ea=Ea+(ba(ib,xa)|0)|0;Ka=gb}if((oa|0)==312){oa=0;ZDb(rb);kb=-12}else if((oa|0)==315){oa=0;yDb(0,16,2174704,(H=i,i=i+8|0,c[H>>2]=tb,H)|0);i=H;ub=qb;vb=tb;oa=319}else if((oa|0)==346){oa=0;yDb(c[Y>>2]|0,16,2305480,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=nb}else if((oa|0)==351){oa=0;yDb(c[Y>>2]|0,16,2217672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-12}else if((oa|0)==353){oa=0;DDb(c[Y>>2]|0,2208408,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ZDb(Eb);kb=-1163346256}else if((oa|0)==371){oa=0;yDb(c[Y>>2]|0,16,2287632,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-1094995529}else if((oa|0)==388){oa=0;yDb(c[Y>>2]|0,16,2271560,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-1094995529}else if((oa|0)==394){oa=0;yDb(c[Y>>2]|0,16,2256176,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-1094995529}else if((oa|0)==407){oa=0;yDb(c[Y>>2]|0,16,2241816,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-1094995529}else if((oa|0)==422){oa=0;yDb(c[Y>>2]|0,16,2229472,(H=i,i=i+16|0,c[H>>2]=Nb,c[H+8>>2]=jb,H)|0);i=H;kb=-1094995529}if((oa|0)==319){oa=0;yDb(c[Y>>2]|0,16,2199920,(H=i,i=i+24|0,c[H>>2]=ub,c[H+8>>2]=qb,c[H+16>>2]=vb,H)|0);i=H;ZDb(rb);kb=-1313558101}if((c[sa>>2]&8|0)!=0){K=kb;oa=474;break l}}}while(0);q:do{if((c[aa>>2]|0)==2){R=c[ya>>2]|0;Ka=(c[L>>2]|0)>>>3;if((c[ka>>2]|0)==0){vc=Ka}else{Ea=(Ka>>>0)/((c[M>>2]|0)>>>0)|0;vc=Ea>>>0>1>>>0?Ea:1}Ea=ba(c[_>>2]|0,vc)|0;switch(c[(c[Y>>2]|0)+140>>2]|0){case 42:case 292:case 88:case 319:{Ka=c[$>>2]|0;if((Ka|0)<=0){break q}gb=vc>>>0<Ea>>>0;ib=R;fb=0;Hb=Ka;while(1){if(gb){Ka=vc;do{hb=ib+Ka|0;yb=ib+(Ka-vc)|0;x=((d[yb]|d[yb+1|0]<<8)<<16>>16)+((d[hb]|d[hb+1|0]<<8)<<16>>16)&65535;a[hb]=x;x=x>>8;a[hb+1|0]=x;Ka=Ka+2|0;}while(Ka>>>0<Ea>>>0);xc=c[$>>2]|0}else{xc=Hb}Ka=fb+1|0;if((Ka|0)<(xc|0)){ib=ib+xa|0;fb=Ka;Hb=xc}else{break}}break};case 41:case 291:case 87:case 318:{Hb=c[$>>2]|0;if((Hb|0)<=0){break q}if(vc>>>0<Ea>>>0){yc=R;zc=0}else{fb=0;while(1){fb=fb+1|0;if((fb|0)>=(Hb|0)){break q}}}while(1){Hb=vc;do{fb=yc+Hb|0;ib=de((d[fb]|d[fb+1|0]<<8)<<16>>16|0)|0;gb=yc+(Hb-vc)|0;x=de((de((d[gb]|d[gb+1|0]<<8)<<16>>16|0)|0)+ib&65535|0)|0;a[fb]=x;x=x>>8;a[fb+1|0]=x;Hb=Hb+2|0;}while(Hb>>>0<Ea>>>0);Hb=zc+1|0;if((Hb|0)<(c[$>>2]|0)){yc=yc+xa|0;zc=Hb}else{break}}break};default:{Hb=c[$>>2]|0;if((Hb|0)<=0){break q}fb=vc>>>0<Ea>>>0;ib=R;gb=0;Ka=Hb;while(1){if(fb){Hb=vc;do{hb=ib+Hb|0;a[hb]=(a[hb]|0)+(a[ib+(Hb-vc)|0]|0);Hb=Hb+1|0;}while(Hb>>>0<Ea>>>0);Ac=c[$>>2]|0}else{Ac=Ka}Hb=gb+1|0;if((Hb|0)<(Ac|0)){ib=ib+xa|0;gb=Hb;Ka=Ac}else{break}}}}}}while(0);do{if((c[N>>2]|0)!=0){xa=c[$>>2]|0;if((xa|0)<=0){break}Ka=c[ya>>2]|0;gb=0;ib=c[Fa>>2]|0;Ea=xa;while(1){if((ib|0)>0){xa=0;do{if((c[(c[Y>>2]|0)+140>>2]|0)==11){Bc=(1<<c[L>>2])-1|0}else{Bc=255}fb=Ka+xa|0;a[fb]=Bc-(d[fb]|0);xa=xa+1|0;Cc=c[Fa>>2]|0;}while((xa|0)<(Cc|0));Dc=Cc;Ec=c[$>>2]|0}else{Dc=ib;Ec=Ea}xa=gb+1|0;if((xa|0)<(Ec|0)){Ka=Ka+Dc|0;gb=xa;ib=Dc;Ea=Ec}else{break}}}}while(0);Fa=va+1|0;if((Fa|0)<(bb|0)){va=Fa}else{oa=469;break}}if((oa|0)==301){yDb(b,16,2350240,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=-1094995529;i=j;return K|0}else if((oa|0)==469){if((c[ka>>2]|0)==0){break}cb=c[M>>2]|0;oa=471;break}else if((oa|0)==474){i=j;return K|0}}}while(0);do{if((oa|0)==471){if(!(cb>>>0>2>>>0)){break}M=e+8|0;ka=c[M>>2]|0;$=e;c[M>>2]=c[$>>2];M=e+40|0;L=c[M>>2]|0;Y=e+32|0;c[M>>2]=c[Y>>2];M=e+4|0;N=c[M>>2]|0;c[M>>2]=ka;c[$>>2]=N;N=e+36|0;$=c[N>>2]|0;c[N>>2]=L;c[Y>>2]=$}}while(0);c[f>>2]=1;K=c[G>>2]|0;i=j;return K|0}}while(0);yDb(b,16,2104016,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=-1094995529;i=j;return K|0}function B_a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+60>>2]|0;a=b+1132|0;d=c[a>>2]|0;e=b+1136|0;f=e;if((d|0)>0){g=0;h=d;while(1){d=(c[f>>2]|0)+(g*20|0)+16|0;if((c[d>>2]|0)==0){i=h}else{$Db(d);i=c[a>>2]|0}d=g+1|0;if((d|0)<(i|0)){g=d;h=i}else{break}}}$Db(e);c[a>>2]=0;UKa(b+1120|0);$Db(b+1124|0);return 0}function C_a(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;if((b|0)==2){h=c[f+1060>>2]|0;i=O_a(a,d,f+4|0,h,FCb(g)|0)|0;return i|0}else if((b|0)==3){h=c[f+1060>>2]|0;i=M_a(a,d,e,f+4|0,h,FCb(g)|0)|0;return i|0}else if((b|0)==12){b=c[f+1060>>2]|0;i=L_a(a,d,e,f+4|0,b,FCb(g)|0)|0;return i|0}else{i=-1094995529;return i|0}return 0}function D_a(a,b){a=a|0;b=b|0;return(c[a>>2]|0)-(c[b>>2]|0)|0}function E_a(a){a=a|0;var b=0,c=0,d=0,f=0;b=0;while(1){if(!(b>>>0<3>>>0)){c=0;d=4;break}f=b+1|0;if((e[917592+(b<<1)>>1]|0|0)==(a|0)){c=f;d=4;break}else{b=f}}if((d|0)==4){return c|0}return 0}function F_a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a|0;f=c[e>>2]|0;g=((c[a+4>>2]|0)-f|0)<2;if((b|0)==0){if(g){h=0;return h|0}c[e>>2]=f+2;b=f;h=(de((d[b]|d[b+1|0]<<8)<<16>>16|0)|0)&65535;return h|0}else{if(g){h=0;return h|0}c[e>>2]=f+2;e=f;h=(d[e]|d[e+1|0]<<8)<<16>>16&65535;return h|0}return 0}function G_a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a|0;f=c[e>>2]|0;g=((c[a+4>>2]|0)-f|0)<4;if((b|0)==0){if(g){h=0;return h|0}c[e>>2]=f+4;b=f;h=fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;return h|0}else{if(g){h=0;return h|0}c[e>>2]=f+4;e=f;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;return h|0}return 0}function H_a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,i=0,j=0,l=0.0,m=0;e=a|0;f=c[e>>2]|0;g=((c[a+4>>2]|0)-f|0)<8;if((b|0)==0){if(g){i=0;j=0;l=(c[k>>2]=j,c[k+4>>2]=i,+h[k>>3]);return+l}c[e>>2]=f+8;b=f;a=b|0;m=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=b+4|0;b=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=fe(m|0)|0;i=a|0;j=fe(b|0)|0;l=(c[k>>2]=j,c[k+4>>2]=i,+h[k>>3]);return+l}else{if(g){i=0;j=0;l=(c[k>>2]=j,c[k+4>>2]=i,+h[k>>3]);return+l}c[e>>2]=f+8;e=f;f=e|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;i=e;j=g;l=(c[k>>2]=j,c[k+4>>2]=i,+h[k>>3]);return+l}return 0.0}function I_a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((b|0)==3){f=a|0;g=c[f>>2]|0;h=((c[a+4>>2]|0)-g|0)<2;if((e|0)==0){if(h){i=0;return i|0}c[f>>2]=g+2;j=g;i=(de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535;return i|0}else{if(h){i=0;return i|0}c[f>>2]=g+2;f=g;i=(d[f]|d[f+1|0]<<8)<<16>>16&65535;return i|0}}else if((b|0)==4){f=a|0;g=c[f>>2]|0;h=((c[a+4>>2]|0)-g|0)<4;if((e|0)==0){if(h){i=0;return i|0}c[f>>2]=g+4;e=g;i=fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;return i|0}else{if(h){i=0;return i|0}c[f>>2]=g+4;f=g;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;return i|0}}else if((b|0)==1){b=a|0;f=c[b>>2]|0;if(((c[a+4>>2]|0)-f|0)<1){i=0;return i|0}c[b>>2]=f+1;i=d[f]|0;return i|0}else{i=-1;return i|0}return 0}function J_a(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=i;i=i+1032|0;k=j|0;l=j+1024|0;if(a>>>0>268435454>>>0|(a|0)<1){m=-1094995529;i=j;return m|0}n=f|0;o=f+4|0;if(((c[o>>2]|0)-(c[n>>2]|0)|0)>>>0<a<<3>>>0){m=-1094995529;i=j;return m|0}IAb(k,a*10|0,-1);if((a|0)>0){f=(e|0)==0;p=(a|0)>4?1892584:9203104;if((g|0)==0){g=0;do{q=c[n>>2]|0;r=c[o>>2]|0;if((r-q|0)<4){s=0;t=q}else{u=q+4|0;c[n>>2]=u;v=q;s=fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;t=u}if((r-t|0)<4){w=0}else{c[n>>2]=t+4;r=t;w=fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0}r=(g|0)!=0;if(f){x=(g&3|0)==0|r^1?p:1912992}else{x=r?e:9203104}KAb(k,2215688,(y=i,i=i+24|0,c[y>>2]=x,c[y+8>>2]=s,c[y+16>>2]=w,y)|0);i=y;g=g+1|0;}while((g|0)<(a|0))}else{g=0;do{w=c[n>>2]|0;s=c[o>>2]|0;if((s-w|0)<4){z=0;A=w}else{x=w+4|0;c[n>>2]=x;t=w;z=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;A=x}if((s-A|0)<4){B=0}else{c[n>>2]=A+4;s=A;B=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0}s=(g|0)!=0;if(f){C=(g&3|0)==0|s^1?p:1912992}else{C=s?e:9203104}KAb(k,2215688,(y=i,i=i+24|0,c[y>>2]=C,c[y+8>>2]=z,c[y+16>>2]=B,y)|0);i=y;g=g+1|0;}while((g|0)<(a|0))}}a=QAb(k,l)|0;if((a|0)!=0){m=a;i=j;return m|0}a=c[l>>2]|0;if((a|0)==0){m=-12;i=j;return m|0}CBb(h,b,a,8)|0;m=0;i=j;return m|0}function K_a(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;i=i+1032|0;k=j|0;l=j+1024|0;if(a>>>0>536870910>>>0|(a|0)<1){m=-1094995529;i=j;return m|0}n=f|0;o=f+4|0;if(((c[o>>2]|0)-(c[n>>2]|0)|0)>>>0<a<<2>>>0){m=-1094995529;i=j;return m|0}IAb(k,a*10|0,-1);if((a|0)>0){f=(a|0)>8?1892584:9203104;p=(g|0)==0;if((e|0)==0){g=0;do{q=(g&7|0)==0|(g|0)==0?f:1912992;r=c[n>>2]|0;s=((c[o>>2]|0)-r|0)<4;do{if(p){if(s){t=0;break}c[n>>2]=r+4;u=r;t=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0}else{if(s){t=0;break}c[n>>2]=r+4;u=r;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0}}while(0);KAb(k,2314816,(v=i,i=i+16|0,c[v>>2]=q,c[v+8>>2]=t,v)|0);i=v;g=g+1|0;}while((g|0)<(a|0))}else{g=0;do{t=(g|0)!=0?e:9203104;f=c[n>>2]|0;r=((c[o>>2]|0)-f|0)<4;do{if(p){if(r){w=0;break}c[n>>2]=f+4;s=f;w=fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0}else{if(r){w=0;break}c[n>>2]=f+4;s=f;w=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0}}while(0);KAb(k,2314816,(v=i,i=i+16|0,c[v>>2]=t,c[v+8>>2]=w,v)|0);i=v;g=g+1|0;}while((g|0)<(a|0))}}a=QAb(k,l)|0;if((a|0)!=0){m=a;i=j;return m|0}a=c[l>>2]|0;if((a|0)==0){m=-12;i=j;return m|0}CBb(h,b,a,8)|0;m=0;i=j;return m|0}function L_a(a,b,e,f,g,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0;l=i;i=i+1032|0;m=l|0;n=l+1024|0;if(a>>>0>268435454>>>0|(a|0)<1){o=-1094995529;i=l;return o|0}p=f|0;q=f+4|0;if(((c[q>>2]|0)-(c[p>>2]|0)|0)>>>0<a<<3>>>0){o=-1094995529;i=l;return o|0}IAb(m,a*10|0,a*100|0);if((a|0)>0){f=(e|0)==0;r=(a|0)>4?1892584:9203104;s=(g|0)==0;g=0;do{t=(g|0)!=0;if(f){u=(g&3|0)==0|t^1?r:1912992}else{u=t?e:9203104}t=c[p>>2]|0;v=((c[q>>2]|0)-t|0)<8;do{if(s){if(v){w=0;x=0;break}c[p>>2]=t+8;y=t;z=y|0;A=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=y+4|0;y=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=fe(A|0)|0;w=z|0;x=fe(y|0)|0}else{if(v){w=0;x=0;break}c[p>>2]=t+8;y=t;z=y|0;A=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=y+4|0;y=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;w=y;x=A}}while(0);B=(c[k>>2]=x,c[k+4>>2]=w,+h[k>>3]);KAb(m,2180736,(t=i,i=i+16|0,c[t>>2]=u,h[t+8>>3]=B,t)|0);i=t;g=g+1|0;}while((g|0)<(a|0))}a=QAb(m,n)|0;if((a|0)!=0){o=a;i=l;return o|0}a=c[n>>2]|0;if((a|0)==0){o=-12;i=l;return o|0}CBb(j,b,a,8)|0;o=0;i=l;return o|0}function M_a(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;i=i+1032|0;k=j|0;l=j+1024|0;if(a>>>0>1073741822>>>0|(a|0)<1){m=-1094995529;i=j;return m|0}n=f|0;o=f+4|0;if(((c[o>>2]|0)-(c[n>>2]|0)|0)>>>0<a<<1>>>0){m=-1094995529;i=j;return m|0}IAb(k,a*10|0,-1);if((a|0)>0){f=(e|0)==0;p=(a|0)>8?1892584:9203104;q=(g|0)==0;g=0;do{r=(g|0)!=0;if(f){s=(g&7|0)==0|r^1?p:1912992}else{s=r?e:9203104}r=c[n>>2]|0;t=((c[o>>2]|0)-r|0)<2;do{if(q){if(t){u=0;break}c[n>>2]=r+2;v=r;u=(de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535}else{if(t){u=0;break}c[n>>2]=r+2;v=r;u=(d[v]|d[v+1|0]<<8)<<16>>16&65535}}while(0);KAb(k,2104e3,(r=i,i=i+16|0,c[r>>2]=s,c[r+8>>2]=u,r)|0);i=r;g=g+1|0;}while((g|0)<(a|0))}a=QAb(k,l)|0;if((a|0)!=0){m=a;i=j;return m|0}a=c[l>>2]|0;if((a|0)==0){m=-12;i=j;return m|0}CBb(h,b,a,8)|0;m=0;i=j;return m|0}function N_a(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1032|0;j=g|0;k=g+1024|0;if(a>>>0>2147483646>>>0|(a|0)<0){l=-1094995529;i=g;return l|0}m=f|0;n=f+4|0;if(((c[n>>2]|0)-(c[m>>2]|0)|0)>>>0<a>>>0){l=-1094995529;i=g;return l|0}IAb(j,a*10|0,-1);if((a|0)>0){f=(e|0)==0;o=(a|0)>16?1892584:9203104;p=0;do{q=(p|0)!=0;if(f){r=(p&15|0)==0|q^1?o:1912992}else{r=q?e:9203104}q=c[m>>2]|0;if(((c[n>>2]|0)-q|0)<1){s=0}else{c[m>>2]=q+1;s=d[q]|0}KAb(j,2047568,(q=i,i=i+16|0,c[q>>2]=r,c[q+8>>2]=s,q)|0);i=q;p=p+1|0;}while((p|0)<(a|0))}a=QAb(j,k)|0;if((a|0)!=0){l=a;i=g;return l|0}a=c[k>>2]|0;if((a|0)==0){l=-12;i=g;return l|0}CBb(h,b,a,8)|0;l=0;i=g;return l|0}function O_a(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;f=e|0;if(((c[e+4>>2]|0)-(c[f>>2]|0)|0)>>>0<b>>>0|(b|0)<0){h=-1094995529;return h|0}e=WDb(b+1|0)|0;if((e|0)==0){h=-12;return h|0}i=c[f>>2]|0;UGb(e|0,i|0,b)|0;c[f>>2]=i+b;a[e+b|0]=0;CBb(g,d,e,8)|0;h=0;return h|0}function P_a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a|0;g=c[f>>2]|0;h=a+4|0;if(((c[h>>2]|0)-g|0)>>>0<8>>>0){i=-1094995529;return i|0}c[f>>2]=g+2;a=g;g=(d[a]|d[a+1|0]<<8)<<16>>16;c[b>>2]=g&65535;do{if(g<<16>>16==18761){j=1}else{if(g<<16>>16==19789){j=0;break}else{i=-1094995529}return i|0}}while(0);c[b>>2]=j;b=(j|0)==0;j=c[f>>2]|0;g=c[h>>2]|0;h=(g-j|0)<2;do{if(b){if(h){i=-1094995529;return i|0}else{a=j+2|0;c[f>>2]=a;k=j;l=de((d[k]|d[k+1|0]<<8)<<16>>16|0)|0;m=a;break}}else{if(h){i=-1094995529;return i|0}else{a=j+2|0;c[f>>2]=a;k=j;l=(d[k]|d[k+1|0]<<8)<<16>>16;m=a;break}}}while(0);if(!(l<<16>>16==42)){i=-1094995529;return i|0}l=(g-m|0)<4;do{if(b){if(l){n=0;break}c[f>>2]=m+4;g=m;n=fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0}else{if(l){n=0;break}c[f>>2]=m+4;g=m;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0}}while(0);c[e>>2]=n;i=0;return i|0}function Q_a(a,b,f,g,h,i){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=(b|0)==0;b=a|0;k=c[b>>2]|0;l=c[a+4>>2]|0;m=(l-k|0)<2;do{if(j){if(m){n=0;o=k}else{p=k+2|0;c[b>>2]=p;q=k;n=(de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;o=p}c[f>>2]=n;if((l-o|0)<2){r=0;s=o}else{p=o+2|0;c[b>>2]=p;q=o;r=(de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;s=p}c[g>>2]=r;if((l-s|0)<4){t=0;u=s;break}p=s+4|0;c[b>>2]=p;q=s;t=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;u=p}else{if(m){v=0;w=k}else{p=k+2|0;c[b>>2]=p;q=k;v=(d[q]|d[q+1|0]<<8)<<16>>16&65535;w=p}c[f>>2]=v;if((l-w|0)<2){x=0;y=w}else{p=w+2|0;c[b>>2]=p;q=w;x=(d[q]|d[q+1|0]<<8)<<16>>16&65535;y=p}c[g>>2]=x;if((l-y|0)<4){t=0;u=y;break}p=y+4|0;c[b>>2]=p;q=y;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;u=p}}while(0);c[h>>2]=t;t=c[f>>2]|0;f=0;while(1){if(!(f>>>0<3>>>0)){z=0;break}y=f+1|0;if((e[917592+(f<<1)>>1]|0|0)==(t|0)){z=y;break}else{f=y}}f=c[g>>2]|0;t=c[a+8>>2]|0;a=u;y=t;c[i>>2]=a+4-y;if(!(f>>>0<14>>>0&(f|0)!=0)){A=-1094995529;return A|0}do{if((z|0)==0){f=c[h>>2]|0;if(f>>>0>4>>>0){break}i=c[g>>2]|0;if((ba(d[180112+i|0]|0,f)|0)>>>0<5>>>0|(i|0)==2){A=0}else{break}return A|0}}while(0);g=(l-a|0)<4;do{if(j){if(g){B=26;break}c[b>>2]=u+4;a=u;C=fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0;B=27}else{if(g){B=26;break}c[b>>2]=u+4;a=u;C=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;B=27}}while(0);if((B|0)==26){D=0;B=28}else if((B|0)==27){if((C|0)<0){E=0}else{D=C;B=28}}if((B|0)==28){B=l-y|0;E=(B|0)<(D|0)?B:D}c[b>>2]=t+E;A=0;return A|0}function R_a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=ICb()|0;c[a+804>>2]=d;if((d|0)==0){e=-12;return e|0}c[d+88>>2]=1;c[d+84>>2]=1;c[b+4>>2]=a;e=0;return e|0}function S_a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;k=i;i=i+1704|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+32|0;q=k+40|0;r=k+48|0;s=k+56|0;t=k+64|0;u=k+72|0;v=k+80|0;w=k+88|0;y=k+96|0;z=k+104|0;A=k+112|0;B=k+120|0;C=k+1656|0;D=f+140|0;E=bFb(c[D>>2]|0)|0;G=c[f+60>>2]|0;H=G;c[w>>2]=c[G+472>>2];c[w+4>>2]=1;I=f+120|0;J=G+8|0;c[J>>2]=c[I>>2];K=f+124|0;L=G+12|0;c[L>>2]=c[K>>2];M=G+464|0;N=M;b[N>>1]=1;O=G+466|0;b[O>>1]=1;P=$Eb(E)|0;Q=G+16|0;c[Q>>2]=P;R=f+792|0;c[R>>2]=P;P=G+24|0;c[P>>2]=d[E+4|0]|0;S=c[D>>2]|0;switch(S|0){case 32:case 10:{T=0;U=6;break};case 11:{c[G+28>>2]=3;V=0;W=0;break};case 42:case 2:{X=0;U=3;break};case 9:{c[G+28>>2]=0;V=0;W=0;break};case 292:case 28:{X=1;U=3;break};case 0:case 4:case 33:case 5:case 6:case 7:{eFb(S,z,A)|0;c[G+28>>2]=6;b[N>>1]=1<<c[z>>2];b[O>>1]=1<<c[A>>2];V=0;W=1;break};case 66:{U=5;break};case 8:{c[R>>2]=40;U=5;break};default:{yDb(c[G+4>>2]|0,16,2180304,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;Z=-1;i=k;return Z|0}}if((U|0)==3){c[G+28>>2]=2;V=X;W=0}else if((U|0)==5){T=(S|0)==66|0;U=6}if((U|0)==6){c[G+28>>2]=1;V=T;W=0}T=c[P>>2]|0;if((T|0)>0){S=0;do{b[y+(S<<1)>>1]=((e[E+8+(S<<1)>>1]|0)>>>11&15)+1;S=S+1|0;}while((S|0)<(T|0))}T=G+20|0;S=c[T>>2]|0;if((S|0)==32946|(S|0)==8|(S|0)==5){S=c[L>>2]|0;c[G+60>>2]=S;_=S;$=S;aa=c[Q>>2]|0}else{S=c[Q>>2]|0;E=8192/((((ba(S,c[J>>2]|0)|0)>>>3)+1|0)>>>0)|0;X=E>>>0>1>>>0?E:1;c[G+60>>2]=X;_=X;$=c[L>>2]|0;aa=S}S=G+60|0;X=e[O>>1]|0;E=ba(((_-1|0)/(X|0)|0)+1|0,X)|0;c[S>>2]=E;X=(($-1|0)/(E|0)|0)+1|0;E=r0a(f,g,(ba((ba(c[I>>2]<<1,aa)|0)+4|0,c[K>>2]|0)|0)+16384|0,0)|0;if((E|0)<0){Z=E;i=k;return Z|0}K=g+24|0;aa=c[K>>2]|0;c[v>>2]=aa;I=G+456|0;c[I>>2]=aa;$=G+452|0;c[$>>2]=v;_=g+28|0;R=c[_>>2]|0;A=G+460|0;c[A>>2]=R;z=(R|0)<0|0?-1:0;ca=c[v>>2]|0;da=ca-aa|0;ea=YGb(da,(da|0)<0|0?-1:0,8,0)|0;da=F;a:do{if(z>>>0<da>>>0|z>>>0==da>>>0&R>>>0<ea>>>0){c[v>>2]=aa+(R+1);yDb(c[G+4>>2]|0,16,2350072,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=E}else{ga=ca;x=18761;a[ga]=x;x=x>>8;a[ga+1|0]=x;ga=(c[v>>2]|0)+2|0;c[v>>2]=ga;ha=ga;x=42;a[ha]=x;x=x>>8;a[ha+1|0]=x;ha=(c[v>>2]|0)+2|0;c[v>>2]=ha;ga=ha;x=0;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;ha=G+36|0;ia=ha;ja=X<<2;P$a(ha,G+40|0,ja);ha=G+44|0;ka=ha;P$a(ha,G+48|0,ja);if((c[ia>>2]|0)==0){fa=-12;break}if((c[ka>>2]|0)==0){fa=-12;break}ja=e[N>>1]|0;ha=((ba(ba(ba(c[Q>>2]|0,ja)|0,(((c[J>>2]|0)-1|0)/(ja|0)|0)+1|0)|0,e[O>>1]|0)|0)+7|0)>>>3;ja=(W|0)!=0;do{if(ja){la=G+52|0;O$a(la,G+56|0,ha);if((c[la>>2]|0)!=0){break}yDb(c[G+4>>2]|0,16,2103688,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=-12;break a}}while(0);la=c[T>>2]|0;do{if((la|0)==32946|(la|0)==8){ma=WDb(ba(c[S>>2]|0,ha)|0)|0;if((ma|0)==0){fa=-12;break a}na=c[v>>2]|0;c[c[ka>>2]>>2]=na-(c[K>>2]|0);b:do{if((c[S>>2]|0)>0){oa=G+52|0;pa=h|0;qa=h+32|0;if(ja){ra=0;sa=0}else{ta=0;ua=0;while(1){va=ma+(ba(ua,ha)|0)|0;UGb(va|0,(c[pa>>2]|0)+(ba(c[qa>>2]|0,ua)|0)|0,ha)|0;va=ta+ha|0;wa=ua+1|0;if((wa|0)<(c[S>>2]|0)){ta=va;ua=wa}else{xa=va;ya=na;break b}}}do{U_a(H,h,c[oa>>2]|0,sa);UGb(ma+ra|0,c[oa>>2]|0,ha)|0;ra=ra+ha|0;sa=sa+(e[O>>1]|0)|0;}while((sa|0)<(c[S>>2]|0));xa=ra;ya=c[v>>2]|0}else{xa=0;ya=na}}while(0);na=V_a(H,ma,ya,xa,c[T>>2]|0)|0;ZDb(ma);if((na|0)<0){yDb(c[G+4>>2]|0,16,2047360,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=na;break a}else{oa=(c[v>>2]|0)+na|0;c[v>>2]=oa;c[c[ia>>2]>>2]=oa-(c[K>>2]|0)-(c[c[ka>>2]>>2]|0);za=na;break}}else if((la|0)==5){na=WDb(c[297946]|0)|0;c[G+468>>2]=na;if((na|0)==0){fa=-12;break a}else{U=35}}else{U=35}}while(0);do{if((U|0)==35){c:do{if((c[L>>2]|0)>0){la=G+468|0;na=G+52|0;oa=h|0;ua=h+32|0;d:do{if(ja){ta=0;while(1){qa=c[S>>2]|0;if((c[(c[ia>>2]|0)+(((ta|0)/(qa|0)|0)<<2)>>2]|0)==0){if((c[T>>2]|0)==5){XKa(c[la>>2]|0,c[v>>2]|0,(c[A>>2]|0)-(c[c[$>>2]>>2]|0)+(c[I>>2]|0)|0,12,1,1948);Aa=c[S>>2]|0}else{Aa=qa}c[(c[ka>>2]|0)+(((ta|0)/(Aa|0)|0)<<2)>>2]=(c[v>>2]|0)-(c[K>>2]|0)}U_a(H,h,c[na>>2]|0,ta);qa=V_a(H,c[na>>2]|0,c[v>>2]|0,ha,c[T>>2]|0)|0;pa=e[O>>1]|0;va=ta-1+pa|0;if((qa|0)<0){Ba=qa;break d}wa=(c[ia>>2]|0)+(((va|0)/(c[S>>2]|0)|0)<<2)|0;c[wa>>2]=(c[wa>>2]|0)+qa;c[v>>2]=(c[v>>2]|0)+qa;do{if((c[T>>2]|0)==5){if((va|0)!=((c[L>>2]|0)-1|0)){wa=c[S>>2]|0;if(((va|0)%(wa|0)|0|0)!=(wa-1|0)){Ca=qa;break}}wa=ZKa(c[la>>2]|0,22)|0;Da=(c[ia>>2]|0)+(((va|0)/(c[S>>2]|0)|0)<<2)|0;c[Da>>2]=(c[Da>>2]|0)+wa;c[v>>2]=(c[v>>2]|0)+wa;Ca=wa}else{Ca=qa}}while(0);qa=ta+pa|0;if((qa|0)<(c[L>>2]|0)){ta=qa}else{Ea=Ca;break c}}}else{ta=0;while(1){qa=c[S>>2]|0;if((c[(c[ia>>2]|0)+(((ta|0)/(qa|0)|0)<<2)>>2]|0)==0){if((c[T>>2]|0)==5){XKa(c[la>>2]|0,c[v>>2]|0,(c[A>>2]|0)-(c[c[$>>2]>>2]|0)+(c[I>>2]|0)|0,12,1,1948);Fa=c[S>>2]|0}else{Fa=qa}c[(c[ka>>2]|0)+(((ta|0)/(Fa|0)|0)<<2)>>2]=(c[v>>2]|0)-(c[K>>2]|0)}qa=(c[oa>>2]|0)+(ba(c[ua>>2]|0,ta)|0)|0;va=V_a(H,qa,c[v>>2]|0,ha,c[T>>2]|0)|0;if((va|0)<0){Ba=va;break d}qa=(c[ia>>2]|0)+(((ta|0)/(c[S>>2]|0)|0)<<2)|0;c[qa>>2]=(c[qa>>2]|0)+va;c[v>>2]=(c[v>>2]|0)+va;do{if((c[T>>2]|0)==5){if((ta|0)!=((c[L>>2]|0)-1|0)){qa=c[S>>2]|0;if(((ta|0)%(qa|0)|0|0)!=(qa-1|0)){Ga=va;break}}qa=ZKa(c[la>>2]|0,22)|0;wa=(c[ia>>2]|0)+(((ta|0)/(c[S>>2]|0)|0)<<2)|0;c[wa>>2]=(c[wa>>2]|0)+qa;c[v>>2]=(c[v>>2]|0)+qa;Ga=qa}else{Ga=va}}while(0);va=ta+1|0;if((va|0)<(c[L>>2]|0)){ta=va}else{Ea=Ga;break c}}}}while(0);yDb(c[G+4>>2]|0,16,2047360,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=Ba;break a}else{Ea=E}}while(0);if((c[T>>2]|0)!=5){za=Ea;break}ZDb(c[G+468>>2]|0);za=Ea}}while(0);ha=G+448|0;c[ha>>2]=0;c[t>>2]=0;Y_a(H,254,4,1,t);c[s>>2]=c[J>>2];Y_a(H,256,4,1,s);c[r>>2]=c[L>>2];Y_a(H,257,4,1,r);ma=c[P>>2]|0;if((ma|0)!=0){Y_a(H,258,3,ma,y)}b[q>>1]=c[T>>2];Y_a(H,259,3,1,q);b[p>>1]=c[G+28>>2];Y_a(H,262,3,1,p);Y_a(H,273,4,X,c[ka>>2]|0);ma=c[P>>2]|0;if((ma|0)!=0){b[o>>1]=ma;Y_a(H,277,3,1,o)}c[n>>2]=c[S>>2];Y_a(H,278,4,1,n);Y_a(H,279,4,X,c[ia>>2]|0);ma=w;Y_a(H,282,5,1,ma);Y_a(H,283,5,1,ma);b[m>>1]=2;Y_a(H,296,3,1,m);if((c[f+88>>2]&8388608|0)==0){Y_a(H,305,2,14,2001664)}if((c[D>>2]|0)==11){ma=c[h+4>>2]|0;la=0;do{ua=c[ma+(la<<2)>>2]|0;b[B+(la<<1)>>1]=(ua>>>16&255)*257|0;b[B+(la+256<<1)>>1]=(ua>>>8&255)*257|0;b[B+(la+512<<1)>>1]=(ua&255)*257|0;la=la+1|0;}while((la|0)<256);Y_a(H,320,3,768,B)}if((V|0)!=0){b[l>>1]=2;Y_a(H,338,3,1,l)}if(ja){la=C;UGb(la|0,1342968,48)|0;Y_a(H,530,3,2,M);if((c[f+400>>2]|0)==3){b[u>>1]=2;Y_a(H,531,3,1,u)}Y_a(H,532,5,6,la)}x=(c[v>>2]|0)-(c[K>>2]|0)|0;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;la=c[ha>>2]|0;ma=(la*12|0)+6|0;ia=c[A>>2]|0;ka=(ia|0)<0|0?-1:0;ua=c[$>>2]|0;oa=c[I>>2]|0;na=(c[ua>>2]|0)-oa|0;ta=YGb(na,(na|0)<0|0?-1:0,ma,(ma|0)<0|0?-1:0)|0;ma=F;if(ka>>>0<ma>>>0|ka>>>0==ma>>>0&ia>>>0<ta>>>0){c[ua>>2]=oa+(ia+1);yDb(c[G+4>>2]|0,16,2350072,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=-22;break}else{ia=c[v>>2]|0;x=la&65535;a[ia]=x;x=x>>8;a[ia+1|0]=x;ia=(c[v>>2]|0)+2|0;c[v>>2]=ia;la=(c[ha>>2]|0)*12|0;UGb(ia|0,G+64|0,la)|0;ia=(c[v>>2]|0)+la|0;c[v>>2]=ia;la=ia;x=0;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;la=(c[v>>2]|0)+4|0;c[v>>2]=la;c[_>>2]=la-(c[K>>2]|0);la=g+36|0;c[la>>2]=c[la>>2]|1;c[j>>2]=1;fa=za;break}}}while(0);Z=(fa|0)<0?fa:0;i=k;return Z|0}function T_a(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(a+804|0);$Db(b+36|0);$Db(b+44|0);$Db(b+52|0);return 0}function U_a(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=d+8|0;j=c[i>>2]|0;k=d+464|0;l=e[k>>1]|0;m=((j-1|0)/(l|0)|0)+1|0;n=d+466|0;o=b[n>>1]|0;p=o&65535;q=(h|0)/(p|0)|0;r=f+32|0;s=ba(c[f+36>>2]|0,q)|0;t=(c[f+4>>2]|0)+s|0;s=ba(c[f+40>>2]|0,q)|0;q=(c[f+8>>2]|0)+s|0;do{if(((j|0)%(l|0)|0|0)==0){if(((c[d+12>>2]|0)%(p|0)|0|0)!=0){break}if((m|0)<=0){return}s=r|0;u=f|0;v=0;w=g;x=t;y=q;z=o;while(1){if(z<<16>>16==0){A=w}else{B=0;C=w;D=b[k>>1]|0;E=z;while(1){if(D<<16>>16==0){F=C;G=0;H=E}else{I=B+h|0;J=0;K=C;L=D&65535;while(1){M=(ba(L,v)|0)+J+(ba(c[s>>2]|0,I)|0)|0;N=K+1|0;a[K]=a[(c[u>>2]|0)+M|0]|0;M=J+1|0;O=b[k>>1]|0;P=O&65535;if((M|0)<(P|0)){J=M;K=N;L=P}else{break}}F=N;G=O;H=b[n>>1]|0}L=B+1|0;if((L|0)<(H&65535|0)){B=L;C=F;D=G;E=H}else{A=F;break}}}a[A]=a[x]|0;a[A+1|0]=a[y]|0;E=v+1|0;if((E|0)>=(m|0)){break}v=E;w=A+2|0;x=x+1|0;y=y+1|0;z=b[n>>1]|0}return}}while(0);if((m|0)<=0){return}A=d+12|0;d=r|0;r=f|0;f=0;F=g;g=t;t=q;q=o;while(1){if(q<<16>>16==0){Q=F}else{o=0;H=F;G=b[k>>1]|0;O=q;while(1){if(G<<16>>16==0){R=H;S=0;T=O}else{N=o+h|0;p=0;l=H;j=G&65535;while(1){z=(c[A>>2]|0)-1|0;y=ba((N|0)>(z|0)?z:N,c[d>>2]|0)|0;z=(ba(j,f)|0)+p|0;x=(c[i>>2]|0)-1|0;U=l+1|0;a[l]=a[(c[r>>2]|0)+(((z|0)>(x|0)?x:z)+y)|0]|0;y=p+1|0;V=b[k>>1]|0;z=V&65535;if((y|0)<(z|0)){p=y;l=U;j=z}else{break}}R=U;S=V;T=b[n>>1]|0}j=o+1|0;if((j|0)<(T&65535|0)){o=j;H=R;G=S;O=T}else{Q=R;break}}}a[Q]=a[g]|0;a[Q+1|0]=a[t]|0;O=f+1|0;if((O|0)>=(m|0)){break}f=O;F=Q+2|0;g=g+1|0;t=t+1|0;q=b[n>>1]|0}return}function V_a(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+8|0;h=g|0;if((f|0)==32773){j=lnb(d,(c[a+460>>2]|0)-(c[c[a+452>>2]>>2]|0)+(c[a+456>>2]|0)|0,b,1,e,2,255,-1,0)|0;i=g;return j|0}else if((f|0)==32946|(f|0)==8){c[h>>2]=(c[a+460>>2]|0)-(c[c[a+452>>2]>>2]|0)+(c[a+456>>2]|0);if((Xd(d|0,h|0,b|0,e|0)|0)==0){j=c[h>>2]|0;i=g;return j|0}else{yDb(c[a+4>>2]|0,16,1892408,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;j=-1;i=g;return j|0}}else if((f|0)==5){j=YKa(c[a+468>>2]|0,b,e)|0;i=g;return j|0}else if((f|0)==1){f=c[a+460>>2]|0;h=(f|0)<0|0?-1:0;l=c[a+452>>2]|0;m=c[a+456>>2]|0;n=(c[l>>2]|0)-m|0;o=YGb(n,(n|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;n=F;if(h>>>0<n>>>0|h>>>0==n>>>0&f>>>0<o>>>0){c[l>>2]=m+(f+1);yDb(c[a+4>>2]|0,16,2350072,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;j=-1;i=g;return j|0}else{UGb(d|0,b|0,e)|0;j=e;i=g;return j|0}}else{j=-1;i=g;return j|0}return 0}function W_a(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b|0;g=c[f>>2]|0;h=b+4|0;i=c[h>>2]|0;if((i|0)>(d|0)){j=i-d|0;k=g<<d|e;c[f>>2]=k;c[h>>2]=j;return}else{l=fe(e>>>((d-i|0)>>>0)|g<<i|0)|0;g=b+12|0;b=c[g>>2]|0;x=l;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;j=32-d+i|0;k=e;c[f>>2]=k;c[h>>2]=j;return}}function X_a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=b+4|0;e=c[d>>2]|0;f=b|0;if((e|0)>=32){g=f;c[d>>2]=32;c[g>>2]=0;return}h=c[f>>2]<<e;c[f>>2]=h;f=b|0;e=b+12|0;b=h>>>24&255;while(1){h=c[e>>2]|0;c[e>>2]=h+1;a[h]=b;h=c[f>>2]|0;c[f>>2]=h<<8;i=(c[d>>2]|0)+8|0;c[d>>2]=i;if((i|0)<32){b=h>>>16&255}else{g=f;break}}c[d>>2]=32;c[g>>2]=0;return}function Y_a(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;k=b+448|0;l=c[k>>2]|0;m=l*12|0;if((l|0)>=32){yDb(0,0,1964512,(n=i,i=i+24|0,c[n>>2]=1936456,c[n+8>>2]=1912864,c[n+16>>2]=131,n)|0);i=n;Cd()}l=b+64+m|0;x=e&65535;a[l]=x;x=x>>8;a[l+1|0]=x;l=m|2;m=b+64+l|0;x=f&65535;a[m]=x;x=x>>8;a[m+1|0]=x;m=l+2+(b+64)|0;x=g;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+6+(b+64)|0;l=g;e=(g|0)<0|0?-1:0;o=gHb(d[180096+f|0]|0,0,l,e)|0;p=F;q=0;if((p|0)<(q|0)|(p|0)==(q|0)&o>>>0<5>>>0){o=ba(d[180080+f|0]|0,g)|0;if((o|0)>0){r=0;s=m}else{t=c[k>>2]|0;u=t+1|0;c[k>>2]=u;i=j;return}while(1){a[s]=a[h+r|0]|0;q=r+1|0;if((q|0)<(o|0)){r=q;s=s+1|0}else{break}}t=c[k>>2]|0;u=t+1|0;c[k>>2]=u;i=j;return}s=b+452|0;r=b+456|0;o=m;x=(c[c[s>>2]>>2]|0)-(c[r>>2]|0)|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=a[180080+f|0]|0;f=gHb(o&255,0,l,e)|0;e=c[b+460>>2]|0;l=(e|0)<0|0?-1:0;m=c[s>>2]|0;q=c[r>>2]|0;r=(c[m>>2]|0)-q|0;p=YGb(r,(r|0)<0|0?-1:0,f,F)|0;f=F;if(l>>>0<f>>>0|l>>>0==f>>>0&e>>>0<p>>>0){c[m>>2]=q+(e+1);yDb(c[b+4>>2]|0,16,2350072,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;v=c[s>>2]|0}else{v=m}m=ba(o&255,g)|0;if((m|0)>0){w=0}else{t=c[k>>2]|0;u=t+1|0;c[k>>2]=u;i=j;return}do{g=a[h+w|0]|0;o=c[v>>2]|0;c[v>>2]=o+1;a[o]=g;w=w+1|0;}while((w|0)<(m|0));t=c[k>>2]|0;u=t+1|0;c[k>>2]=u;i=j;return}function Z_a(a){a=a|0;c[a+140>>2]=11;return 0}function __a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=c[f+24>>2]|0;j=c[a+120>>2]>>3;k=c[a+124>>2]>>3;l=_$a(a,b,0)|0;if((l|0)<0){m=l;i=g;return m|0}l=f+28|0;if((c[l>>2]|0)>>>0<(ba(j<<1,k)|0)>>>0){yDb(a,16,2180256,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;c[e>>2]=0;m=-1094995529;i=g;return m|0}c[b+88>>2]=1;c[b+84>>2]=1;a=c[b>>2]|0;c[b+304>>2]=1;f=b+4|0;UGb(c[f>>2]|0,1244144,64)|0;TGb((c[f>>2]|0)+64|0,0,960)|0;do{if((k|0)!=0){f=b+32|0;if((j|0)==0){break}n=j<<1;o=0;p=a;q=h;while(1){r=0;s=q;while(1){t=d[s+1|0]|0;F$(p+(r<<3)|0,c[f>>2]|0,1744336,8,d[s]|0,t&15,t>>>4);t=r+1|0;if(!(t>>>0<j>>>0)){break}r=t;s=s+2|0}s=o+1|0;if(s>>>0<k>>>0){o=s;p=p+(c[f>>2]<<3)|0;q=q+n|0}else{break}}}}while(0);c[e>>2]=1;m=c[l>>2]|0;i=g;return m|0}function $_a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=b;c[d>>2]=a;a=ICb()|0;c[b+4>>2]=a;if((a|0)==0){e=-12;return e|0}a=b+16524|0;kEb(a,b+16528|0,c[(c[d>>2]|0)+120>>2]<<2);e=(c[a>>2]|0)==0?-12:0;return e|0}function a$a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0;k=i;i=i+128|0;l=k|0;m=c[j+24>>2]|0;n=c[j+28>>2]|0;j=c[f+60>>2]|0;o=j;p=j+8|0;c[p>>2]=m;q=j+12|0;c[q>>2]=n;r=l|0;TGb(r|0,0,128)|0;s=a[m]|0;if((s&255)>>>0<16>>>0){yDb(c[j>>2]|0,16,2047328,(t=i,i=i+8|0,c[t>>2]=s&255,t)|0);i=t;u=-1094995529;i=k;return u|0}v=s<<3&120|(s&255)>>>5;s=v&255;if((s+1|0)>(n|0)){yDb(c[j>>2]|0,16,2001632,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=k;return u|0}do{if((v&255)>>>0>1>>>0){w=1;x=a[m+1|0]|0;while(1){y=w+1|0;z=a[m+y|0]|0;a[l+(w-1)|0]=z^x;if((y|0)<(s|0)){w=y;x=z}else{break}}x=a[r]|0;w=a[l+1|0]|0;z=a[l+2|0]|0;y=l+3|0;A=(d[y]|d[y+1|0]<<8)<<16>>16;y=l+5|0;B=a[l+10|0]|0;C=(d[y]|d[y+1|0]<<8)<<16>>16&65535;y=d[l+11|0]|0;if(!((d[l+9|0]|0)>>>0>1>>>0)){D=B;E=C;F=A;G=z;H=w;I=x;J=14;break}if((B&255)>>>0>3>>>0){yDb(c[j>>2]|0,16,1964480,(t=i,i=i+8|0,c[t>>2]=B&255,t)|0);i=t;u=-1094995529;i=k;return u|0}K=j+32|0;if(!((B-2&255)>>>0<2>>>0)){c[K>>2]=16;L=x;M=w;N=z;O=A;P=C;Q=B;R=16;break}S=(y&8|0)==0?y|16:y;c[K>>2]=S;if((S&32|0)==0){L=x;M=w;N=z;O=A;P=C;Q=B;R=S;break}DDb(c[j>>2]|0,1936432,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1163346256;i=k;return u|0}else{D=0;E=0;F=0;G=0;H=0;I=0;J=14}}while(0);if((J|0)==14){c[j+32>>2]=16;L=I;M=H;N=G;O=F;P=E;Q=D;R=16}D=j+32|0;E=j+44|0;c[E>>2]=P;F=j+48|0;c[F>>2]=O&65535;do{if((Q&255)>>>0<2>>>0){if(!(P>>>0<213>>>0&(O&65535)>>>0>175>>>0)){break}c[D>>2]=R|4;DDb(c[j>>2]|0,1912840,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}}while(0);R=L&255;if((L&255)>>>0>16>>>0){yDb(c[j>>2]|0,16,1892376,(t=i,i=i+8|0,c[t>>2]=R,t)|0);i=t;u=-1094995529;i=k;return u|0}L=M&255;O=j+16516|0;P=c[O>>2]|0;if((L|0)==(P|0)){if(!((N&255|0)==(c[j+16520>>2]|0)|(M&255)>>>0>3>>>0)){J=24}}else{if(!((M&255)>>>0>3>>>0)){J=24}}if((J|0)==24){M=j+16452|0;UGb(M|0,c[904+(L<<2)>>2]|0,16)|0;UGb(j+16468|0,c[1501552+(L<<2)>>2]|0,16)|0;UGb(j+16484|0,c[1312584+(L<<2)>>2]|0,16)|0;UGb(j+16500|0,c[1312640+(L<<2)>>2]|0,16)|0;G=M;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16454|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16456|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16458|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16460|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16462|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16464|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16466|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0}do{if((R&1|0)==0|Q<<24>>24==0){G=N&255;if(N<<24>>24!=0&(N&255)>>>0<4>>>0){T=c[194216+(G-1<<2)>>2]|0;break}yDb(c[j>>2]|0,16,2350040,(t=i,i=i+8|0,c[t>>2]=G,t)|0);i=t;u=-1094995529;i=k;return u|0}else{T=591800}}while(0);Q=87040>>>(R>>>0)&1;G=(Q|0)==0;M=(Q<<4^16)+30|0;H=c[E>>2]>>Q;c[E>>2]=H;I=j;l=c[I>>2]|0;do{if((H|0)==(c[l+120>>2]|0)){if((c[F>>2]|0)!=(c[l+124>>2]|0)){J=32;break}if((M|0)==(c[l+140>>2]|0)){U=l;V=H;W=P}else{J=32}}else{J=32}}while(0);do{if((J|0)==32){KCb(c[j+4>>2]|0);P=c[I>>2]|0;c[P+224>>2]=1<<Q;c[P+228>>2]=1;P=c[I>>2]|0;c[P+140>>2]=M;H=V$a(P,c[E>>2]|0,c[F>>2]|0)|0;if((H|0)<0){u=H;i=k;return u|0}H=j+16524|0;kEb(H,j+16528|0,c[(c[I>>2]|0)+120>>2]<<2);if((c[H>>2]|0)==0){u=-12;i=k;return u|0}else{H=c[I>>2]|0;U=H;V=c[H+120>>2]|0;W=c[O>>2]|0;break}}}while(0);F=j+20|0;c[F>>2]=(V>>2-Q)+7>>3;if((L|0)==(W|0)){if((N&255|0)!=(c[j+16520>>2]|0)){J=37}}else{J=37}a:do{if((J|0)==37){if(!G){W=0;Q=T;while(1){V=(d[Q]|0)>>>1;E=Q+1|0;if((V|0)==0){X=0;Y=E}else{M=0;H=E;while(1){E=d[H]|0;P=E>>>4;l=E&15;E=M+W|0;c[o+52+(E<<2)>>2]=((b[o+16452+(l<<1)>>1]|0)*65792|0)+(b[o+16452+(P<<1)>>1]|0)<<1;c[o+4148+(E<<2)>>2]=(e[o+16468+(P<<1)>>1]<<16)+(b[o+16468+(l<<1)>>1]|0)<<1;c[o+8244+(E<<2)>>2]=((b[o+16484+(l<<1)>>1]|0)*65792|0)+(b[o+16484+(P<<1)>>1]|0)<<1;c[o+12340+(E<<2)>>2]=(e[o+16500+(P<<1)>>1]<<16)+(b[o+16500+(l<<1)>>1]|0)<<1;l=M+1|0;if((l|0)<(V|0)){M=l;H=H+1|0}else{break}}H=V>>>0>1>>>0?V:1;X=H;Y=Q+(H+1)|0}H=W-1+X|0;M=o+52+(H<<2)|0;c[M>>2]=c[M>>2]|1;M=o+4148+(H<<2)|0;c[M>>2]=c[M>>2]|1;M=o+8244+(H<<2)|0;c[M>>2]=c[M>>2]|1;M=o+12340+(H<<2)|0;c[M>>2]=c[M>>2]|1;M=W+4|0;if((M|0)<1024){W=M;Q=Y}else{break a}}}if((c[U+140>>2]|0)==46){Q=0;W=T;while(1){M=(d[W]|0)>>>1;H=W+1|0;if((M|0)==0){Z=0;_=H}else{l=0;P=H;while(1){H=d[P]|0;E=H>>>4;r=H&15;H=l+Q|0;c[o+52+(H<<2)>>2]=(ba(b[o+16452+(r<<1)>>1]|0,69271552)|0)+((b[o+16452+(E<<1)>>1]|0)*1057|0)<<1;c[o+4148+(H<<2)>>2]=((b[o+16468+(E<<1)>>1]<<10)+(b[o+16468+(r<<1)>>1]|0)|0)*131074|0;r=l+1|0;if((r|0)<(M|0)){l=r;P=P+1|0}else{break}}P=M>>>0>1>>>0?M:1;Z=P;_=W+(P+1)|0}P=Q-1+Z|0;l=o+52+(P<<2)|0;c[l>>2]=c[l>>2]|1;l=o+4148+(P<<2)|0;c[l>>2]=c[l>>2]|1;l=Q+4|0;if((l|0)<1024){Q=l;W=_}else{break}}}else{W=0;Q=T;while(1){l=(d[Q]|0)>>>1;P=Q+1|0;if((l|0)==0){$=0;aa=P}else{V=0;r=P;while(1){P=d[r]|0;E=P>>>4;H=P&15;P=V+W|0;c[o+52+(P<<2)>>2]=(ba(b[o+16452+(H<<1)>>1]|0,138477568)|0)+((b[o+16452+(E<<1)>>1]|0)*2113|0)<<1;c[o+4148+(P<<2)>>2]=((b[o+16468+(E<<1)>>1]<<11)+(b[o+16468+(H<<1)>>1]|0)|0)*131074|0;H=V+1|0;if((H|0)<(l|0)){V=H;r=r+1|0}else{break}}r=l>>>0>1>>>0?l:1;$=r;aa=Q+(r+1)|0}r=W-1+$|0;V=o+52+(r<<2)|0;c[V>>2]=c[V>>2]|1;V=o+4148+(r<<2)|0;c[V>>2]=c[V>>2]|1;V=W+4|0;if((V|0)<1024){W=V;Q=aa}else{break}}}}}while(0);aa=c[p>>2]|0;p=aa+s|0;$=j+16|0;c[$>>2]=p;T=c[D>>2]|0;_=T&16;if((_|0)==0){Z=c[I>>2]|0;U=aa+((ba(c[Z+124>>2]>>2,c[F>>2]|0)|0)+s)|0;c[j+24>>2]=U;ca=U;da=Z}else{c[j+24>>2]=p;ca=p;da=c[I>>2]|0}p=j+28|0;c[p>>2]=aa-ca+(c[q>>2]|0);c[O>>2]=L;O=N&255;c[j+16520>>2]=O;N=j+16436|0;c[N>>2]=R;q=c[1420852+(R<<4)>>2]|0;ca=j+16444|0;c[ca>>2]=q;aa=c[1420856+(R<<4)>>2]|0;c[j+16448>>2]=aa;Z=c[1420860+(R<<4)>>2]|0;U=j+16440|0;c[U>>2]=Z;if((c[da+688>>2]&1|0)!=0){yDb(da,32,2329864,(t=i,i=i+80|0,c[t>>2]=L,c[t+8>>2]=O,c[t+16>>2]=R,c[t+24>>2]=q,c[t+32>>2]=aa,c[t+40>>2]=Z,c[t+48>>2]=(_|0)!=0?2305384:9203568,c[t+56>>2]=(T&8|0)!=0?2271416:9203568,c[t+64>>2]=(T&32|0)!=0?2256016:9203568,c[t+72>>2]=(T&4|0)!=0?2241680:9203568,t)|0);i=t}T=j+4|0;_=$$a(f,c[T>>2]|0)|0;if((_|0)<0){u=_;i=k;return u|0}_=c[N>>2]|0;b:do{if((87040>>>(_>>>0)&1|0)==0){if((87550>>>(_>>>0)&1|0)==0){break}N=c[c[T>>2]>>2]|0;f=c[D>>2]&16;Z=c[$>>2]|0;aa=j+16524|0;TGb(c[aa>>2]|0,0,c[(c[I>>2]|0)+120>>2]<<2|0)|0;q=c[I>>2]|0;if((c[p>>2]|0)<1){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}R=q+124|0;if((c[R>>2]|0)<=0){break}O=c[j+24>>2]|0;L=(f|0)!=0;f=q+120|0;da=N;N=0;s=Z;Z=1;Y=d[O]<<2;X=O;G=O;Q=O;W=O;V=O;r=O;c:while(1){M=c[f>>2]|0;if((M|0)>0){H=N&3;E=M;M=0;P=c[aa>>2]|0;m=da;v=a[s]|0;S=1;B=1;C=Z;A=Y;z=X;w=G;x=Q;K=W;y=V;ea=r;while(1){do{if(L){J=345}else{if((v&S)<<24>>24==0){J=345;break}fa=P+4|0;c[P>>2]=c[m>>2];ga=c[m+4>>2]|0;ha=ga-(c[fa>>2]|0)|0;c[fa>>2]=ga;ia=ha;ja=P+8|0;ka=m+8|0;la=C;ma=A;na=z;oa=w;pa=x;qa=K;ra=y;sa=ea;J=608}}while(0);if((J|0)==345){J=0;do{if((H|0)==2){ha=c[U>>2]|0;if((ha|0)==0){ga=c[o+4148+(A<<2)>>2]|0;fa=(ga>>>1)+M|0;do{if((ga&1|0)==0){if((A|0)>1022){J=489;break c}ta=A+1|0;ua=C;va=fa;wa=z;xa=w;ya=x;za=K;Aa=y;Ba=ea}else{Ca=c[p>>2]|0;if((C|0)>=(Ca|0)){J=479;break c}Da=C+1|0;Ea=a[O+C|0]|0;if(!(Ea<<24>>24==0)){ta=(Ea&255)<<2;ua=Da;va=fa;wa=O;xa=O;ya=O;za=O;Aa=O;Ba=O;break}if((Da|0)>=(Ca|0)){J=482;break c}Ea=C+2|0;Fa=d[O+Da|0]<<2;Da=c[o+4148+(Fa<<2)>>2]|0;Ga=((Da>>>1)*5|0)+fa|0;if((Da&1|0)==0){ta=Fa|1;ua=Ea;va=Ga;wa=O;xa=O;ya=O;za=O;Aa=O;Ba=O;break}if((Ea|0)>=(Ca|0)){J=485;break c}ta=d[O+Ea|0]<<2;ua=C+3|0;va=Ga;wa=O;xa=O;ya=O;za=O;Aa=O;Ba=O}}while(0);fa=c[o+52+(ta<<2)>>2]|0;ga=(fa>>>1)+va|0;do{if((fa&1|0)==0){if((ta|0)>1022){J=503;break c}Ha=ta+1|0;Ia=ua;Ja=ga;Ka=wa;La=xa;Ma=ya;Na=za;Oa=Aa;Pa=Ba}else{Ga=c[p>>2]|0;if((ua|0)>=(Ga|0)){J=493;break c}Ea=ua+1|0;Ca=a[O+ua|0]|0;if(!(Ca<<24>>24==0)){Ha=(Ca&255)<<2;Ia=Ea;Ja=ga;Ka=O;La=O;Ma=O;Na=O;Oa=O;Pa=O;break}if((Ea|0)>=(Ga|0)){J=496;break c}Ca=ua+2|0;Fa=d[O+Ea|0]<<2;Ea=c[o+52+(Fa<<2)>>2]|0;Da=((Ea>>>1)*5|0)+ga|0;if((Ea&1|0)==0){Ha=Fa|1;Ia=Ca;Ja=Da;Ka=O;La=O;Ma=O;Na=O;Oa=O;Pa=O;break}if((Ca|0)>=(Ga|0)){J=499;break c}Ha=d[O+Ca|0]<<2;Ia=ua+3|0;Ja=Da;Ka=O;La=O;Ma=O;Na=O;Oa=O;Pa=O}}while(0);ga=(c[P>>2]|0)+Ja|0;c[m>>2]=ga;fa=m+4|0;Da=P+4|0;c[P>>2]=ga;ga=c[o+4148+(Ha<<2)>>2]|0;Ca=(ga>>>1)+Ja|0;do{if((ga&1|0)==0){if((Ha|0)>1022){J=517;break c}Qa=Ha+1|0;Ra=Ia;Sa=Ca;Ta=Ka;Ua=La;Va=Ma;Wa=Na;Xa=Oa;Ya=Pa}else{Ga=c[p>>2]|0;if((Ia|0)>=(Ga|0)){J=507;break c}Fa=Ia+1|0;Ea=a[O+Ia|0]|0;if(!(Ea<<24>>24==0)){Qa=(Ea&255)<<2;Ra=Fa;Sa=Ca;Ta=O;Ua=O;Va=O;Wa=O;Xa=O;Ya=O;break}if((Fa|0)>=(Ga|0)){J=510;break c}Ea=Ia+2|0;Za=d[O+Fa|0]<<2;Fa=c[o+4148+(Za<<2)>>2]|0;_a=((Fa>>>1)*5|0)+Ca|0;if((Fa&1|0)==0){Qa=Za|1;Ra=Ea;Sa=_a;Ta=O;Ua=O;Va=O;Wa=O;Xa=O;Ya=O;break}if((Ea|0)>=(Ga|0)){J=513;break c}Qa=d[O+Ea|0]<<2;Ra=Ia+3|0;Sa=_a;Ta=O;Ua=O;Va=O;Wa=O;Xa=O;Ya=O}}while(0);Ca=c[o+52+(Qa<<2)>>2]|0;ga=(Ca>>>1)+Sa|0;do{if((Ca&1|0)==0){if((Qa|0)>1022){J=531;break c}$a=Qa+1|0;ab=Ra;bb=ga;cb=Ta;db=Ua;eb=Va;fb=Wa;gb=Xa;hb=Ya}else{_a=c[p>>2]|0;if((Ra|0)>=(_a|0)){J=521;break c}Ea=Ra+1|0;Ga=a[O+Ra|0]|0;if(!(Ga<<24>>24==0)){$a=(Ga&255)<<2;ab=Ea;bb=ga;cb=O;db=O;eb=O;fb=O;gb=O;hb=O;break}if((Ea|0)>=(_a|0)){J=524;break c}Ga=Ra+2|0;Za=d[O+Ea|0]<<2;Ea=c[o+52+(Za<<2)>>2]|0;Fa=((Ea>>>1)*5|0)+ga|0;if((Ea&1|0)==0){$a=Za|1;ab=Ga;bb=Fa;cb=O;db=O;eb=O;fb=O;gb=O;hb=O;break}if((Ga|0)>=(_a|0)){J=527;break c}$a=d[O+Ga|0]<<2;ab=Ra+3|0;bb=Fa;cb=O;db=O;eb=O;fb=O;gb=O;hb=O}}while(0);ga=(c[Da>>2]|0)+bb|0;c[fa>>2]=ga;c[Da>>2]=ga;ib=$a;jb=ab;kb=m+8|0;lb=P+8|0;mb=bb;nb=cb;ob=db;pb=eb;qb=fb;rb=gb;sb=hb;break}else if((ha|0)==2){ga=c[o+4148+(A<<2)>>2]|0;Ca=(ga>>>1)+M|0;do{if((ga&1|0)==0){if((A|0)>1022){J=546;break c}tb=A+1|0;ub=C;vb=Ca;wb=z;xb=w;yb=x;zb=K;Ab=y;Bb=ea}else{Fa=c[p>>2]|0;if((C|0)>=(Fa|0)){J=536;break c}Ga=C+1|0;_a=a[O+C|0]|0;if(!(_a<<24>>24==0)){tb=(_a&255)<<2;ub=Ga;vb=Ca;wb=O;xb=O;yb=O;zb=O;Ab=O;Bb=O;break}if((Ga|0)>=(Fa|0)){J=539;break c}_a=C+2|0;Za=d[O+Ga|0]<<2;Ga=c[o+4148+(Za<<2)>>2]|0;Ea=((Ga>>>1)*5|0)+Ca|0;if((Ga&1|0)==0){tb=Za|1;ub=_a;vb=Ea;wb=O;xb=O;yb=O;zb=O;Ab=O;Bb=O;break}if((_a|0)>=(Fa|0)){J=542;break c}tb=d[O+_a|0]<<2;ub=C+3|0;vb=Ea;wb=O;xb=O;yb=O;zb=O;Ab=O;Bb=O}}while(0);Ca=c[o+52+(tb<<2)>>2]|0;ga=(Ca>>>1)+vb|0;do{if((Ca&1|0)==0){if((tb|0)>1022){J=560;break c}Cb=tb+1|0;Db=ub;Eb=ga;Fb=wb;Gb=xb;Hb=yb;Ib=zb;Jb=Ab;Kb=Bb}else{ha=c[p>>2]|0;if((ub|0)>=(ha|0)){J=550;break c}Da=ub+1|0;fa=a[O+ub|0]|0;if(!(fa<<24>>24==0)){Cb=(fa&255)<<2;Db=Da;Eb=ga;Fb=O;Gb=O;Hb=O;Ib=O;Jb=O;Kb=O;break}if((Da|0)>=(ha|0)){J=553;break c}fa=ub+2|0;Ea=d[O+Da|0]<<2;Da=c[o+52+(Ea<<2)>>2]|0;_a=((Da>>>1)*5|0)+ga|0;if((Da&1|0)==0){Cb=Ea|1;Db=fa;Eb=_a;Fb=O;Gb=O;Hb=O;Ib=O;Jb=O;Kb=O;break}if((fa|0)>=(ha|0)){J=556;break c}Cb=d[O+fa|0]<<2;Db=ub+3|0;Eb=_a;Fb=O;Gb=O;Hb=O;Ib=O;Jb=O;Kb=O}}while(0);ga=(c[P>>2]|0)+Eb|0;c[m>>2]=ga;Ca=m+4|0;_a=P+4|0;c[P>>2]=ga;ga=c[o+52+(Cb<<2)>>2]|0;fa=(ga>>>1)+Eb|0;do{if((ga&1|0)==0){if((Cb|0)>1022){J=574;break c}Lb=Cb+1|0;Mb=Db;Nb=fa;Ob=Fb;Pb=Gb;Qb=Hb;Rb=Ib;Sb=Jb;Tb=Kb}else{ha=c[p>>2]|0;if((Db|0)>=(ha|0)){J=564;break c}Ea=Db+1|0;Da=a[O+Db|0]|0;if(!(Da<<24>>24==0)){Lb=(Da&255)<<2;Mb=Ea;Nb=fa;Ob=O;Pb=O;Qb=O;Rb=O;Sb=O;Tb=O;break}if((Ea|0)>=(ha|0)){J=567;break c}Da=Db+2|0;Fa=d[O+Ea|0]<<2;Ea=c[o+52+(Fa<<2)>>2]|0;Za=((Ea>>>1)*5|0)+fa|0;if((Ea&1|0)==0){Lb=Fa|1;Mb=Da;Nb=Za;Ob=O;Pb=O;Qb=O;Rb=O;Sb=O;Tb=O;break}if((Da|0)>=(ha|0)){J=570;break c}Lb=d[O+Da|0]<<2;Mb=Db+3|0;Nb=Za;Ob=O;Pb=O;Qb=O;Rb=O;Sb=O;Tb=O}}while(0);fa=(c[_a>>2]|0)+Nb|0;c[Ca>>2]=fa;c[_a>>2]=fa;ib=Lb;jb=Mb;kb=m+8|0;lb=P+8|0;mb=Nb;nb=Ob;ob=Pb;pb=Qb;qb=Rb;rb=Sb;sb=Tb;break}else{fa=c[o+52+(A<<2)>>2]|0;ga=(fa>>>1)+M|0;do{if((fa&1|0)==0){if((A|0)>1022){J=589;break c}Ub=A+1|0;Vb=C;Wb=ga;Xb=z;Yb=w;Zb=x;_b=K;$b=y;ac=ea}else{Za=c[p>>2]|0;if((C|0)>=(Za|0)){J=579;break c}Da=C+1|0;ha=a[O+C|0]|0;if(!(ha<<24>>24==0)){Ub=(ha&255)<<2;Vb=Da;Wb=ga;Xb=O;Yb=O;Zb=O;_b=O;$b=O;ac=O;break}if((Da|0)>=(Za|0)){J=582;break c}ha=C+2|0;Fa=d[O+Da|0]<<2;Da=c[o+52+(Fa<<2)>>2]|0;Ea=((Da>>>1)*5|0)+ga|0;if((Da&1|0)==0){Ub=Fa|1;Vb=ha;Wb=Ea;Xb=O;Yb=O;Zb=O;_b=O;$b=O;ac=O;break}if((ha|0)>=(Za|0)){J=585;break c}Ub=d[O+ha|0]<<2;Vb=C+3|0;Wb=Ea;Xb=O;Yb=O;Zb=O;_b=O;$b=O;ac=O}}while(0);ga=(c[P>>2]|0)+Wb|0;c[m>>2]=ga;fa=m+4|0;_a=P+4|0;c[P>>2]=ga;ga=c[o+52+(Ub<<2)>>2]|0;Ca=(ga>>>1)+Wb|0;do{if((ga&1|0)==0){if((Ub|0)>1022){J=603;break c}bc=Ub+1|0;cc=Vb;dc=Ca;ec=Xb;fc=Yb;gc=Zb;hc=_b;ic=$b;jc=ac}else{Ea=c[p>>2]|0;if((Vb|0)>=(Ea|0)){J=593;break c}ha=Vb+1|0;Za=a[O+Vb|0]|0;if(!(Za<<24>>24==0)){bc=(Za&255)<<2;cc=ha;dc=Ca;ec=O;fc=O;gc=O;hc=O;ic=O;jc=O;break}if((ha|0)>=(Ea|0)){J=596;break c}Za=Vb+2|0;Fa=d[O+ha|0]<<2;ha=c[o+52+(Fa<<2)>>2]|0;Da=((ha>>>1)*5|0)+Ca|0;if((ha&1|0)==0){bc=Fa|1;cc=Za;dc=Da;ec=O;fc=O;gc=O;hc=O;ic=O;jc=O;break}if((Za|0)>=(Ea|0)){J=599;break c}bc=d[O+Za|0]<<2;cc=Vb+3|0;dc=Da;ec=O;fc=O;gc=O;hc=O;ic=O;jc=O}}while(0);Ca=(c[_a>>2]|0)+dc|0;c[fa>>2]=Ca;c[_a>>2]=Ca;ib=bc;jb=cc;kb=m+8|0;lb=P+8|0;mb=dc;nb=ec;ob=fc;pb=gc;qb=hc;rb=ic;sb=jc;break}}else if((H|0)==1|(H|0)==3){Ca=c[o+52+(A<<2)>>2]|0;ga=(Ca>>>1)+M|0;do{if((Ca&1|0)==0){if((A|0)>1022){J=459;break c}kc=A+1|0;lc=C;mc=ga;nc=z;oc=w;pc=x;qc=K;rc=y;sc=ea}else{Da=c[p>>2]|0;if((C|0)>=(Da|0)){J=449;break c}Za=C+1|0;Ea=a[O+C|0]|0;if(!(Ea<<24>>24==0)){kc=(Ea&255)<<2;lc=Za;mc=ga;nc=O;oc=O;pc=O;qc=O;rc=O;sc=O;break}if((Za|0)>=(Da|0)){J=452;break c}Ea=C+2|0;Fa=d[O+Za|0]<<2;Za=c[o+52+(Fa<<2)>>2]|0;ha=((Za>>>1)*5|0)+ga|0;if((Za&1|0)==0){kc=Fa|1;lc=Ea;mc=ha;nc=O;oc=O;pc=O;qc=O;rc=O;sc=O;break}if((Ea|0)>=(Da|0)){J=455;break c}kc=d[O+Ea|0]<<2;lc=C+3|0;mc=ha;nc=O;oc=O;pc=O;qc=O;rc=O;sc=O}}while(0);ga=(c[P>>2]|0)+mc|0;c[m>>2]=ga;Ca=m+4|0;_a=P+4|0;c[P>>2]=ga;ga=c[o+52+(kc<<2)>>2]|0;fa=(ga>>>1)+mc|0;do{if((ga&1|0)==0){if((kc|0)>1022){J=473;break c}tc=kc+1|0;uc=lc;vc=fa;wc=nc;xc=oc;yc=pc;zc=qc;Ac=rc}else{ha=c[p>>2]|0;if((lc|0)>=(ha|0)){J=463;break c}Ea=lc+1|0;Da=a[sc+lc|0]|0;if(!(Da<<24>>24==0)){tc=(Da&255)<<2;uc=Ea;vc=fa;wc=sc;xc=sc;yc=sc;zc=sc;Ac=sc;break}if((Ea|0)>=(ha|0)){J=466;break c}Da=lc+2|0;Fa=d[sc+Ea|0]<<2;Ea=c[o+52+(Fa<<2)>>2]|0;Za=((Ea>>>1)*5|0)+fa|0;if((Ea&1|0)==0){tc=Fa|1;uc=Da;vc=Za;wc=sc;xc=sc;yc=sc;zc=sc;Ac=sc;break}if((Da|0)>=(ha|0)){J=469;break c}tc=d[sc+Da|0]<<2;uc=lc+3|0;vc=Za;wc=sc;xc=sc;yc=sc;zc=sc;Ac=sc}}while(0);fa=(c[_a>>2]|0)+vc|0;c[Ca>>2]=fa;c[_a>>2]=fa;ib=tc;jb=uc;kb=m+8|0;lb=P+8|0;mb=vc;nb=wc;ob=xc;pb=yc;qb=zc;rb=Ac;sb=sc}else if((H|0)==0){fa=c[o+4148+(A<<2)>>2]|0;ga=(fa>>>1)+M|0;Za=(fa&1|0)!=0;if((c[ca>>2]|0)!=2){do{if(Za){fa=c[p>>2]|0;if((C|0)>=(fa|0)){J=406;break c}Da=C+1|0;ha=a[K+C|0]|0;if(!(ha<<24>>24==0)){Bc=(ha&255)<<2;Cc=Da;Dc=ga;Ec=K;Fc=K;Gc=K;break}if((Da|0)>=(fa|0)){J=409;break c}ha=C+2|0;Fa=d[K+Da|0]<<2;Da=c[o+4148+(Fa<<2)>>2]|0;Ea=((Da>>>1)*5|0)+ga|0;if((Da&1|0)==0){Bc=Fa|1;Cc=ha;Dc=Ea;Ec=K;Fc=K;Gc=K;break}if((ha|0)>=(fa|0)){J=412;break c}Bc=d[K+ha|0]<<2;Cc=C+3|0;Dc=Ea;Ec=K;Fc=K;Gc=K}else{if((A|0)>1022){J=416;break c}Bc=A+1|0;Cc=C;Dc=ga;Ec=z;Fc=w;Gc=x}}while(0);_a=c[o+52+(Bc<<2)>>2]|0;Ca=(_a>>>1)+Dc|0;do{if((_a&1|0)==0){if((Bc|0)>1022){J=430;break c}Hc=Bc+1|0;Ic=Cc;Jc=Ca;Kc=Ec;Lc=Fc;Mc=Gc;Nc=K}else{Ea=c[p>>2]|0;if((Cc|0)>=(Ea|0)){J=420;break c}ha=Cc+1|0;fa=a[y+Cc|0]|0;if(!(fa<<24>>24==0)){Hc=(fa&255)<<2;Ic=ha;Jc=Ca;Kc=y;Lc=y;Mc=y;Nc=y;break}if((ha|0)>=(Ea|0)){J=423;break c}fa=Cc+2|0;Fa=d[y+ha|0]<<2;ha=c[o+52+(Fa<<2)>>2]|0;Da=((ha>>>1)*5|0)+Ca|0;if((ha&1|0)==0){Hc=Fa|1;Ic=fa;Jc=Da;Kc=y;Lc=y;Mc=y;Nc=y;break}if((fa|0)>=(Ea|0)){J=426;break c}Hc=d[y+fa|0]<<2;Ic=Cc+3|0;Jc=Da;Kc=y;Lc=y;Mc=y;Nc=y}}while(0);Ca=(c[P>>2]|0)+Jc|0;c[m>>2]=Ca;_a=m+4|0;Da=P+4|0;c[P>>2]=Ca;Ca=c[o+52+(Hc<<2)>>2]|0;fa=(Ca>>>1)+Jc|0;do{if((Ca&1|0)==0){if((Hc|0)>1022){J=444;break c}Oc=Hc+1|0;Pc=Ic;Qc=fa;Rc=Kc;Sc=Lc;Tc=Mc}else{Ea=c[p>>2]|0;if((Ic|0)>=(Ea|0)){J=434;break c}Fa=Ic+1|0;ha=a[Nc+Ic|0]|0;if(!(ha<<24>>24==0)){Oc=(ha&255)<<2;Pc=Fa;Qc=fa;Rc=Nc;Sc=Nc;Tc=Nc;break}if((Fa|0)>=(Ea|0)){J=437;break c}ha=Ic+2|0;Ga=d[Nc+Fa|0]<<2;Fa=c[o+52+(Ga<<2)>>2]|0;Uc=((Fa>>>1)*5|0)+fa|0;if((Fa&1|0)==0){Oc=Ga|1;Pc=ha;Qc=Uc;Rc=Nc;Sc=Nc;Tc=Nc;break}if((ha|0)>=(Ea|0)){J=440;break c}Oc=d[Nc+ha|0]<<2;Pc=Ic+3|0;Qc=Uc;Rc=Nc;Sc=Nc;Tc=Nc}}while(0);fa=(c[Da>>2]|0)+Qc|0;c[_a>>2]=fa;c[Da>>2]=fa;ib=Oc;jb=Pc;kb=m+8|0;lb=P+8|0;mb=Qc;nb=Rc;ob=Sc;pb=Tc;qb=Nc;rb=y;sb=ea;break}do{if(Za){fa=c[p>>2]|0;if((C|0)>=(fa|0)){J=349;break c}Ca=C+1|0;Uc=a[z+C|0]|0;if(!(Uc<<24>>24==0)){Vc=(Uc&255)<<2;Wc=Ca;Xc=ga;break}if((Ca|0)>=(fa|0)){J=352;break c}Uc=C+2|0;ha=d[z+Ca|0]<<2;Ca=c[o+4148+(ha<<2)>>2]|0;Ea=((Ca>>>1)*5|0)+ga|0;if((Ca&1|0)==0){Vc=ha|1;Wc=Uc;Xc=Ea;break}if((Uc|0)>=(fa|0)){J=355;break c}Vc=d[z+Uc|0]<<2;Wc=C+3|0;Xc=Ea}else{if((A|0)>1022){J=359;break c}Vc=A+1|0;Wc=C;Xc=ga}}while(0);ga=c[o+52+(Vc<<2)>>2]|0;Za=(ga>>>1)+Xc|0;do{if((ga&1|0)==0){if((Vc|0)>1022){J=373;break c}Yc=Vc+1|0;Zc=Wc;_c=Za;$c=z;ad=w}else{Da=c[p>>2]|0;if((Wc|0)>=(Da|0)){J=363;break c}_a=Wc+1|0;Ea=a[x+Wc|0]|0;if(!(Ea<<24>>24==0)){Yc=(Ea&255)<<2;Zc=_a;_c=Za;$c=x;ad=x;break}if((_a|0)>=(Da|0)){J=366;break c}Ea=Wc+2|0;Uc=d[x+_a|0]<<2;_a=c[o+52+(Uc<<2)>>2]|0;fa=((_a>>>1)*5|0)+Za|0;if((_a&1|0)==0){Yc=Uc|1;Zc=Ea;_c=fa;$c=x;ad=x;break}if((Ea|0)>=(Da|0)){J=369;break c}Yc=d[x+Ea|0]<<2;Zc=Wc+3|0;_c=fa;$c=x;ad=x}}while(0);Za=(c[P>>2]|0)+_c|0;c[m>>2]=Za;ga=m+4|0;fa=P+4|0;c[P>>2]=Za;Za=c[o+4148+(Yc<<2)>>2]|0;Ea=(Za>>>1)+_c|0;do{if((Za&1|0)==0){if((Yc|0)>1022){J=387;break c}bd=Yc+1|0;cd=Zc;dd=Ea;ed=$c}else{Da=c[p>>2]|0;if((Zc|0)>=(Da|0)){J=377;break c}Uc=Zc+1|0;_a=a[ad+Zc|0]|0;if(!(_a<<24>>24==0)){bd=(_a&255)<<2;cd=Uc;dd=Ea;ed=ad;break}if((Uc|0)>=(Da|0)){J=380;break c}_a=Zc+2|0;ha=d[ad+Uc|0]<<2;Uc=c[o+4148+(ha<<2)>>2]|0;Ca=((Uc>>>1)*5|0)+Ea|0;if((Uc&1|0)==0){bd=ha|1;cd=_a;dd=Ca;ed=ad;break}if((_a|0)>=(Da|0)){J=383;break c}bd=d[ad+_a|0]<<2;cd=Zc+3|0;dd=Ca;ed=ad}}while(0);Ea=c[o+52+(bd<<2)>>2]|0;Za=(Ea>>>1)+dd|0;do{if((Ea&1|0)==0){if((bd|0)>1022){J=401;break c}fd=bd+1|0;gd=cd;hd=Za}else{Ca=c[p>>2]|0;if((cd|0)>=(Ca|0)){J=391;break c}_a=cd+1|0;Da=a[ed+cd|0]|0;if(!(Da<<24>>24==0)){fd=(Da&255)<<2;gd=_a;hd=Za;break}if((_a|0)>=(Ca|0)){J=394;break c}Da=cd+2|0;ha=d[ed+_a|0]<<2;_a=c[o+52+(ha<<2)>>2]|0;Uc=((_a>>>1)*5|0)+Za|0;if((_a&1|0)==0){fd=ha|1;gd=Da;hd=Uc;break}if((Da|0)>=(Ca|0)){J=397;break c}fd=d[ed+Da|0]<<2;gd=cd+3|0;hd=Uc}}while(0);Za=(c[fa>>2]|0)+hd|0;c[ga>>2]=Za;c[fa>>2]=Za;ib=fd;jb=gd;kb=m+8|0;lb=P+8|0;mb=hd;nb=ed;ob=ad;pb=x;qb=K;rb=y;sb=ea}else{ib=A;jb=C;kb=m;lb=P;mb=M;nb=z;ob=w;pb=x;qb=K;rb=y;sb=ea}}while(0);if(L){id=B;jd=S;kd=v;ld=mb;md=lb;nd=kb;od=jb;pd=ib;qd=nb;rd=ob;sd=pb;td=qb;ud=rb;vd=sb}else{ia=mb;ja=lb;ka=kb;la=jb;ma=ib;na=nb;oa=ob;pa=pb;qa=qb;ra=rb;sa=sb;J=608}}do{if((J|0)==608){J=0;Za=S<<1;if(!(Za<<24>>24==0)){id=B;jd=Za;kd=v;ld=ia;md=ja;nd=ka;od=la;pd=ma;qd=na;rd=oa;sd=pa;td=qa;ud=ra;vd=sa;break}id=B+1|0;jd=1;kd=a[s+B|0]|0;ld=ia;md=ja;nd=ka;od=la;pd=ma;qd=na;rd=oa;sd=pa;td=qa;ud=ra;vd=sa}}while(0);Za=E-4|0;if((Za|0)>0){E=Za;M=ld;P=md;m=nd;v=kd;S=jd;B=id;C=od;A=pd;z=qd;w=rd;x=sd;K=td;y=ud;ea=vd}else{wd=od;xd=pd;yd=qd;zd=rd;Ad=sd;Bd=td;Cd=ud;Dd=vd;break}}}else{wd=Z;xd=Y;yd=X;zd=G;Ad=Q;Bd=W;Cd=V;Dd=r}ea=N+1|0;if((ea&3|0)==0){Ed=s+(c[F>>2]|0)|0}else{Ed=s}if((ea|0)>=(c[R>>2]|0)){break b}da=da+(c[(c[T>>2]|0)+32>>2]|0)|0;N=ea;s=Ed;Z=wd;Y=xd;X=yd;G=zd;Q=Ad;W=Bd;V=Cd;r=Dd}if((J|0)==349){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==352){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==355){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==359){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==363){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==366){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==369){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==373){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==377){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==380){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==383){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==387){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==391){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==394){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==397){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==401){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==406){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==409){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==412){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==416){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==420){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==423){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==426){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==430){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==434){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==437){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==440){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==444){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==449){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==452){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==455){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==459){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==463){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==466){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==469){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==473){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==479){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==482){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==485){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==489){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==493){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==496){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==499){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==503){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==507){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==510){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==513){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==517){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==521){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==524){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==527){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==531){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==536){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==539){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==542){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==546){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==550){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==553){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==556){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==560){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==564){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==567){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==570){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==574){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==579){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==582){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==585){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==589){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==593){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==596){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==599){yDb(q,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==603){yDb(q,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}}else{r=c[c[T>>2]>>2]|0;V=c[D>>2]&16;W=c[$>>2]|0;Q=j+16524|0;TGb(c[Q>>2]|0,0,c[(c[I>>2]|0)+120>>2]<<2|0)|0;G=c[I>>2]|0;if((c[p>>2]|0)<1){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}X=G+124|0;if((c[X>>2]|0)<=0){break}Y=c[j+24>>2]|0;Z=(V|0)!=0;V=G+120|0;s=r;r=0;N=W;W=1;da=d[Y]<<2;R=Y;L=Y;O=Y;aa=Y;f=Y;ea=Y;d:while(1){y=c[V>>2]|0;if((y|0)>0){K=r&3;x=y;y=0;w=c[Q>>2]|0;z=s;A=a[N]|0;C=1;B=1;S=W;v=da;m=R;P=L;M=O;E=aa;H=f;l=ea;while(1){do{if(Z){J=66}else{if((A&C)<<24>>24==0){J=66;break}Za=w+4|0;c[w>>2]=c[z>>2];Ea=c[z+4>>2]|0;Uc=Ea-(c[Za>>2]|0)|0;c[Za>>2]=Ea;Fd=Uc;Gd=w+8|0;Hd=z+8|0;Id=S;Jd=v;Kd=m;Ld=P;Md=M;Nd=E;Od=H;Pd=l;J=329}}while(0);if((J|0)==66){J=0;do{if((K|0)==2){Uc=c[U>>2]|0;if((Uc|0)==0){Ea=c[o+4148+(v<<2)>>2]|0;Za=(Ea>>>1)+y|0;do{if((Ea&1|0)==0){if((v|0)>1022){J=210;break d}Qd=v+1|0;Rd=S;Sd=Za;Td=m;Ud=P;Vd=M;Wd=E;Xd=H;Yd=l}else{Da=c[p>>2]|0;if((S|0)>=(Da|0)){J=200;break d}Ca=S+1|0;ha=a[Y+S|0]|0;if(!(ha<<24>>24==0)){Qd=(ha&255)<<2;Rd=Ca;Sd=Za;Td=Y;Ud=Y;Vd=Y;Wd=Y;Xd=Y;Yd=Y;break}if((Ca|0)>=(Da|0)){J=203;break d}ha=S+2|0;_a=d[Y+Ca|0]<<2;Ca=c[o+12340+(_a<<2)>>2]|0;Ga=(Ca>>>1)+Za|0;if((Ca&1|0)==0){Qd=_a|1;Rd=ha;Sd=Ga;Td=Y;Ud=Y;Vd=Y;Wd=Y;Xd=Y;Yd=Y;break}if((ha|0)>=(Da|0)){J=206;break d}Qd=d[Y+ha|0]<<2;Rd=S+3|0;Sd=Ga;Td=Y;Ud=Y;Vd=Y;Wd=Y;Xd=Y;Yd=Y}}while(0);Za=c[o+52+(Qd<<2)>>2]|0;Ea=(Za>>>1)+Sd|0;do{if((Za&1|0)==0){if((Qd|0)>1022){J=224;break d}Zd=Qd+1|0;_d=Rd;$d=Ea;ae=Td;be=Ud;ce=Vd;de=Wd;ee=Xd;fe=Yd}else{fa=c[p>>2]|0;if((Rd|0)>=(fa|0)){J=214;break d}ga=Rd+1|0;Ga=a[Y+Rd|0]|0;if(!(Ga<<24>>24==0)){Zd=(Ga&255)<<2;_d=ga;$d=Ea;ae=Y;be=Y;ce=Y;de=Y;ee=Y;fe=Y;break}if((ga|0)>=(fa|0)){J=217;break d}Ga=Rd+2|0;ha=d[Y+ga|0]<<2;ga=c[o+8244+(ha<<2)>>2]|0;Da=(ga>>>1)+Ea|0;if((ga&1|0)==0){Zd=ha|1;_d=Ga;$d=Da;ae=Y;be=Y;ce=Y;de=Y;ee=Y;fe=Y;break}if((Ga|0)>=(fa|0)){J=220;break d}Zd=d[Y+Ga|0]<<2;_d=Rd+3|0;$d=Da;ae=Y;be=Y;ce=Y;de=Y;ee=Y;fe=Y}}while(0);Ea=(c[w>>2]|0)+$d|0;c[z>>2]=Ea;Za=z+4|0;Da=w+4|0;c[w>>2]=Ea;Ea=c[o+4148+(Zd<<2)>>2]|0;Ga=(Ea>>>1)+$d|0;do{if((Ea&1|0)==0){if((Zd|0)>1022){J=238;break d}ge=Zd+1|0;he=_d;ie=Ga;je=ae;ke=be;le=ce;me=de;ne=ee;oe=fe}else{fa=c[p>>2]|0;if((_d|0)>=(fa|0)){J=228;break d}ha=_d+1|0;ga=a[Y+_d|0]|0;if(!(ga<<24>>24==0)){ge=(ga&255)<<2;he=ha;ie=Ga;je=Y;ke=Y;le=Y;me=Y;ne=Y;oe=Y;break}if((ha|0)>=(fa|0)){J=231;break d}ga=_d+2|0;_a=d[Y+ha|0]<<2;ha=c[o+12340+(_a<<2)>>2]|0;Ca=(ha>>>1)+Ga|0;if((ha&1|0)==0){ge=_a|1;he=ga;ie=Ca;je=Y;ke=Y;le=Y;me=Y;ne=Y;oe=Y;break}if((ga|0)>=(fa|0)){J=234;break d}ge=d[Y+ga|0]<<2;he=_d+3|0;ie=Ca;je=Y;ke=Y;le=Y;me=Y;ne=Y;oe=Y}}while(0);Ga=c[o+52+(ge<<2)>>2]|0;Ea=(Ga>>>1)+ie|0;do{if((Ga&1|0)==0){if((ge|0)>1022){J=252;break d}pe=ge+1|0;qe=he;re=Ea;se=je;te=ke;ue=le;ve=me;we=ne;xe=oe}else{Ca=c[p>>2]|0;if((he|0)>=(Ca|0)){J=242;break d}ga=he+1|0;fa=a[Y+he|0]|0;if(!(fa<<24>>24==0)){pe=(fa&255)<<2;qe=ga;re=Ea;se=Y;te=Y;ue=Y;ve=Y;we=Y;xe=Y;break}if((ga|0)>=(Ca|0)){J=245;break d}fa=he+2|0;_a=d[Y+ga|0]<<2;ga=c[o+8244+(_a<<2)>>2]|0;ha=(ga>>>1)+Ea|0;if((ga&1|0)==0){pe=_a|1;qe=fa;re=ha;se=Y;te=Y;ue=Y;ve=Y;we=Y;xe=Y;break}if((fa|0)>=(Ca|0)){J=248;break d}pe=d[Y+fa|0]<<2;qe=he+3|0;re=ha;se=Y;te=Y;ue=Y;ve=Y;we=Y;xe=Y}}while(0);Ea=(c[Da>>2]|0)+re|0;c[Za>>2]=Ea;c[Da>>2]=Ea;ye=pe;ze=qe;Ae=z+8|0;Be=w+8|0;Ce=re;De=se;Ee=te;Fe=ue;Ge=ve;He=we;Ie=xe;break}else if((Uc|0)==2){Ea=c[o+4148+(v<<2)>>2]|0;Ga=(Ea>>>1)+y|0;do{if((Ea&1|0)==0){if((v|0)>1022){J=267;break d}Je=v+1|0;Ke=S;Le=Ga;Me=m;Ne=P;Oe=M;Pe=E;Qe=H;Re=l}else{ha=c[p>>2]|0;if((S|0)>=(ha|0)){J=257;break d}fa=S+1|0;Ca=a[Y+S|0]|0;if(!(Ca<<24>>24==0)){Je=(Ca&255)<<2;Ke=fa;Le=Ga;Me=Y;Ne=Y;Oe=Y;Pe=Y;Qe=Y;Re=Y;break}if((fa|0)>=(ha|0)){J=260;break d}Ca=S+2|0;_a=d[Y+fa|0]<<2;fa=c[o+12340+(_a<<2)>>2]|0;ga=(fa>>>1)+Ga|0;if((fa&1|0)==0){Je=_a|1;Ke=Ca;Le=ga;Me=Y;Ne=Y;Oe=Y;Pe=Y;Qe=Y;Re=Y;break}if((Ca|0)>=(ha|0)){J=263;break d}Je=d[Y+Ca|0]<<2;Ke=S+3|0;Le=ga;Me=Y;Ne=Y;Oe=Y;Pe=Y;Qe=Y;Re=Y}}while(0);Ga=c[o+52+(Je<<2)>>2]|0;Ea=(Ga>>>1)+Le|0;do{if((Ga&1|0)==0){if((Je|0)>1022){J=281;break d}Se=Je+1|0;Te=Ke;Ue=Ea;Ve=Me;We=Ne;Xe=Oe;Ye=Pe;Ze=Qe;_e=Re}else{Uc=c[p>>2]|0;if((Ke|0)>=(Uc|0)){J=271;break d}Da=Ke+1|0;Za=a[Y+Ke|0]|0;if(!(Za<<24>>24==0)){Se=(Za&255)<<2;Te=Da;Ue=Ea;Ve=Y;We=Y;Xe=Y;Ye=Y;Ze=Y;_e=Y;break}if((Da|0)>=(Uc|0)){J=274;break d}Za=Ke+2|0;ga=d[Y+Da|0]<<2;Da=c[o+8244+(ga<<2)>>2]|0;Ca=(Da>>>1)+Ea|0;if((Da&1|0)==0){Se=ga|1;Te=Za;Ue=Ca;Ve=Y;We=Y;Xe=Y;Ye=Y;Ze=Y;_e=Y;break}if((Za|0)>=(Uc|0)){J=277;break d}Se=d[Y+Za|0]<<2;Te=Ke+3|0;Ue=Ca;Ve=Y;We=Y;Xe=Y;Ye=Y;Ze=Y;_e=Y}}while(0);Ea=(c[w>>2]|0)+Ue|0;c[z>>2]=Ea;Ga=z+4|0;Ca=w+4|0;c[w>>2]=Ea;Ea=c[o+52+(Se<<2)>>2]|0;Za=(Ea>>>1)+Ue|0;do{if((Ea&1|0)==0){if((Se|0)>1022){J=295;break d}$e=Se+1|0;af=Te;bf=Za;cf=Ve;df=We;ef=Xe;ff=Ye;gf=Ze;hf=_e}else{Uc=c[p>>2]|0;if((Te|0)>=(Uc|0)){J=285;break d}ga=Te+1|0;Da=a[Y+Te|0]|0;if(!(Da<<24>>24==0)){$e=(Da&255)<<2;af=ga;bf=Za;cf=Y;df=Y;ef=Y;ff=Y;gf=Y;hf=Y;break}if((ga|0)>=(Uc|0)){J=288;break d}Da=Te+2|0;ha=d[Y+ga|0]<<2;ga=c[o+8244+(ha<<2)>>2]|0;_a=(ga>>>1)+Za|0;if((ga&1|0)==0){$e=ha|1;af=Da;bf=_a;cf=Y;df=Y;ef=Y;ff=Y;gf=Y;hf=Y;break}if((Da|0)>=(Uc|0)){J=291;break d}$e=d[Y+Da|0]<<2;af=Te+3|0;bf=_a;cf=Y;df=Y;ef=Y;ff=Y;gf=Y;hf=Y}}while(0);Za=(c[Ca>>2]|0)+bf|0;c[Ga>>2]=Za;c[Ca>>2]=Za;ye=$e;ze=af;Ae=z+8|0;Be=w+8|0;Ce=bf;De=cf;Ee=df;Fe=ef;Ge=ff;He=gf;Ie=hf;break}else{Za=c[o+52+(v<<2)>>2]|0;Ea=(Za>>>1)+y|0;do{if((Za&1|0)==0){if((v|0)>1022){J=310;break d}jf=v+1|0;kf=S;lf=Ea;mf=m;nf=P;of=M;pf=E;qf=H;rf=l}else{_a=c[p>>2]|0;if((S|0)>=(_a|0)){J=300;break d}Da=S+1|0;Uc=a[Y+S|0]|0;if(!(Uc<<24>>24==0)){jf=(Uc&255)<<2;kf=Da;lf=Ea;mf=Y;nf=Y;of=Y;pf=Y;qf=Y;rf=Y;break}if((Da|0)>=(_a|0)){J=303;break d}Uc=S+2|0;ha=d[Y+Da|0]<<2;Da=c[o+8244+(ha<<2)>>2]|0;ga=(Da>>>1)+Ea|0;if((Da&1|0)==0){jf=ha|1;kf=Uc;lf=ga;mf=Y;nf=Y;of=Y;pf=Y;qf=Y;rf=Y;break}if((Uc|0)>=(_a|0)){J=306;break d}jf=d[Y+Uc|0]<<2;kf=S+3|0;lf=ga;mf=Y;nf=Y;of=Y;pf=Y;qf=Y;rf=Y}}while(0);Ea=(c[w>>2]|0)+lf|0;c[z>>2]=Ea;Za=z+4|0;Ca=w+4|0;c[w>>2]=Ea;Ea=c[o+52+(jf<<2)>>2]|0;Ga=(Ea>>>1)+lf|0;do{if((Ea&1|0)==0){if((jf|0)>1022){J=324;break d}sf=jf+1|0;tf=kf;uf=Ga;vf=mf;wf=nf;xf=of;yf=pf;zf=qf;Af=rf}else{ga=c[p>>2]|0;if((kf|0)>=(ga|0)){J=314;break d}Uc=kf+1|0;_a=a[Y+kf|0]|0;if(!(_a<<24>>24==0)){sf=(_a&255)<<2;tf=Uc;uf=Ga;vf=Y;wf=Y;xf=Y;yf=Y;zf=Y;Af=Y;break}if((Uc|0)>=(ga|0)){J=317;break d}_a=kf+2|0;ha=d[Y+Uc|0]<<2;Uc=c[o+8244+(ha<<2)>>2]|0;Da=(Uc>>>1)+Ga|0;if((Uc&1|0)==0){sf=ha|1;tf=_a;uf=Da;vf=Y;wf=Y;xf=Y;yf=Y;zf=Y;Af=Y;break}if((_a|0)>=(ga|0)){J=320;break d}sf=d[Y+_a|0]<<2;tf=kf+3|0;uf=Da;vf=Y;wf=Y;xf=Y;yf=Y;zf=Y;Af=Y}}while(0);Ga=(c[Ca>>2]|0)+uf|0;c[Za>>2]=Ga;c[Ca>>2]=Ga;ye=sf;ze=tf;Ae=z+8|0;Be=w+8|0;Ce=uf;De=vf;Ee=wf;Fe=xf;Ge=yf;He=zf;Ie=Af;break}}else if((K|0)==1|(K|0)==3){Ga=c[o+52+(v<<2)>>2]|0;Ea=(Ga>>>1)+y|0;do{if((Ga&1|0)==0){if((v|0)>1022){J=180;break d}Bf=v+1|0;Cf=S;Df=Ea;Ef=m;Ff=P;Gf=M;Hf=E;If=H;Jf=l}else{Da=c[p>>2]|0;if((S|0)>=(Da|0)){J=170;break d}_a=S+1|0;ga=a[Y+S|0]|0;if(!(ga<<24>>24==0)){Bf=(ga&255)<<2;Cf=_a;Df=Ea;Ef=Y;Ff=Y;Gf=Y;Hf=Y;If=Y;Jf=Y;break}if((_a|0)>=(Da|0)){J=173;break d}ga=S+2|0;ha=d[Y+_a|0]<<2;_a=c[o+8244+(ha<<2)>>2]|0;Uc=(_a>>>1)+Ea|0;if((_a&1|0)==0){Bf=ha|1;Cf=ga;Df=Uc;Ef=Y;Ff=Y;Gf=Y;Hf=Y;If=Y;Jf=Y;break}if((ga|0)>=(Da|0)){J=176;break d}Bf=d[Y+ga|0]<<2;Cf=S+3|0;Df=Uc;Ef=Y;Ff=Y;Gf=Y;Hf=Y;If=Y;Jf=Y}}while(0);Ea=(c[w>>2]|0)+Df|0;c[z>>2]=Ea;Ga=z+4|0;Ca=w+4|0;c[w>>2]=Ea;Ea=c[o+52+(Bf<<2)>>2]|0;Za=(Ea>>>1)+Df|0;do{if((Ea&1|0)==0){if((Bf|0)>1022){J=194;break d}Kf=Bf+1|0;Lf=Cf;Mf=Za;Nf=Ef;Of=Ff;Pf=Gf;Qf=Hf;Rf=If}else{Uc=c[p>>2]|0;if((Cf|0)>=(Uc|0)){J=184;break d}ga=Cf+1|0;Da=a[Jf+Cf|0]|0;if(!(Da<<24>>24==0)){Kf=(Da&255)<<2;Lf=ga;Mf=Za;Nf=Jf;Of=Jf;Pf=Jf;Qf=Jf;Rf=Jf;break}if((ga|0)>=(Uc|0)){J=187;break d}Da=Cf+2|0;ha=d[Jf+ga|0]<<2;ga=c[o+8244+(ha<<2)>>2]|0;_a=(ga>>>1)+Za|0;if((ga&1|0)==0){Kf=ha|1;Lf=Da;Mf=_a;Nf=Jf;Of=Jf;Pf=Jf;Qf=Jf;Rf=Jf;break}if((Da|0)>=(Uc|0)){J=190;break d}Kf=d[Jf+Da|0]<<2;Lf=Cf+3|0;Mf=_a;Nf=Jf;Of=Jf;Pf=Jf;Qf=Jf;Rf=Jf}}while(0);Za=(c[Ca>>2]|0)+Mf|0;c[Ga>>2]=Za;c[Ca>>2]=Za;ye=Kf;ze=Lf;Ae=z+8|0;Be=w+8|0;Ce=Mf;De=Nf;Ee=Of;Fe=Pf;Ge=Qf;He=Rf;Ie=Jf}else if((K|0)==0){Za=c[o+4148+(v<<2)>>2]|0;Ea=(Za>>>1)+y|0;_a=(Za&1|0)!=0;if((c[ca>>2]|0)!=2){do{if(_a){Za=c[p>>2]|0;if((S|0)>=(Za|0)){J=127;break d}Da=S+1|0;Uc=a[E+S|0]|0;if(!(Uc<<24>>24==0)){Sf=(Uc&255)<<2;Tf=Da;Uf=Ea;Vf=E;Wf=E;Xf=E;break}if((Da|0)>=(Za|0)){J=130;break d}Uc=S+2|0;ha=d[E+Da|0]<<2;Da=c[o+12340+(ha<<2)>>2]|0;ga=(Da>>>1)+Ea|0;if((Da&1|0)==0){Sf=ha|1;Tf=Uc;Uf=ga;Vf=E;Wf=E;Xf=E;break}if((Uc|0)>=(Za|0)){J=133;break d}Sf=d[E+Uc|0]<<2;Tf=S+3|0;Uf=ga;Vf=E;Wf=E;Xf=E}else{if((v|0)>1022){J=137;break d}Sf=v+1|0;Tf=S;Uf=Ea;Vf=m;Wf=P;Xf=M}}while(0);Ca=c[o+52+(Sf<<2)>>2]|0;Ga=(Ca>>>1)+Uf|0;do{if((Ca&1|0)==0){if((Sf|0)>1022){J=151;break d}Yf=Sf+1|0;Zf=Tf;_f=Ga;$f=Vf;ag=Wf;bg=Xf;cg=E}else{ga=c[p>>2]|0;if((Tf|0)>=(ga|0)){J=141;break d}Uc=Tf+1|0;Za=a[H+Tf|0]|0;if(!(Za<<24>>24==0)){Yf=(Za&255)<<2;Zf=Uc;_f=Ga;$f=H;ag=H;bg=H;cg=H;break}if((Uc|0)>=(ga|0)){J=144;break d}Za=Tf+2|0;ha=d[H+Uc|0]<<2;Uc=c[o+8244+(ha<<2)>>2]|0;Da=(Uc>>>1)+Ga|0;if((Uc&1|0)==0){Yf=ha|1;Zf=Za;_f=Da;$f=H;ag=H;bg=H;cg=H;break}if((Za|0)>=(ga|0)){J=147;break d}Yf=d[H+Za|0]<<2;Zf=Tf+3|0;_f=Da;$f=H;ag=H;bg=H;cg=H}}while(0);Ga=(c[w>>2]|0)+_f|0;c[z>>2]=Ga;Ca=z+4|0;Da=w+4|0;c[w>>2]=Ga;Ga=c[o+52+(Yf<<2)>>2]|0;Za=(Ga>>>1)+_f|0;do{if((Ga&1|0)==0){if((Yf|0)>1022){J=165;break d}dg=Yf+1|0;eg=Zf;fg=Za;gg=$f;hg=ag;ig=bg}else{ga=c[p>>2]|0;if((Zf|0)>=(ga|0)){J=155;break d}ha=Zf+1|0;Uc=a[cg+Zf|0]|0;if(!(Uc<<24>>24==0)){dg=(Uc&255)<<2;eg=ha;fg=Za;gg=cg;hg=cg;ig=cg;break}if((ha|0)>=(ga|0)){J=158;break d}Uc=Zf+2|0;fa=d[cg+ha|0]<<2;ha=c[o+8244+(fa<<2)>>2]|0;Fa=(ha>>>1)+Za|0;if((ha&1|0)==0){dg=fa|1;eg=Uc;fg=Fa;gg=cg;hg=cg;ig=cg;break}if((Uc|0)>=(ga|0)){J=161;break d}dg=d[cg+Uc|0]<<2;eg=Zf+3|0;fg=Fa;gg=cg;hg=cg;ig=cg}}while(0);Za=(c[Da>>2]|0)+fg|0;c[Ca>>2]=Za;c[Da>>2]=Za;ye=dg;ze=eg;Ae=z+8|0;Be=w+8|0;Ce=fg;De=gg;Ee=hg;Fe=ig;Ge=cg;He=H;Ie=l;break}do{if(_a){Za=c[p>>2]|0;if((S|0)>=(Za|0)){J=70;break d}Ga=S+1|0;Fa=a[m+S|0]|0;if(!(Fa<<24>>24==0)){jg=(Fa&255)<<2;kg=Ga;lg=Ea;break}if((Ga|0)>=(Za|0)){J=73;break d}Fa=S+2|0;Uc=d[m+Ga|0]<<2;Ga=c[o+12340+(Uc<<2)>>2]|0;ga=(Ga>>>1)+Ea|0;if((Ga&1|0)==0){jg=Uc|1;kg=Fa;lg=ga;break}if((Fa|0)>=(Za|0)){J=76;break d}jg=d[m+Fa|0]<<2;kg=S+3|0;lg=ga}else{if((v|0)>1022){J=80;break d}jg=v+1|0;kg=S;lg=Ea}}while(0);Ea=c[o+52+(jg<<2)>>2]|0;_a=(Ea>>>1)+lg|0;do{if((Ea&1|0)==0){if((jg|0)>1022){J=94;break d}mg=jg+1|0;ng=kg;og=_a;pg=m;qg=P}else{Da=c[p>>2]|0;if((kg|0)>=(Da|0)){J=84;break d}Ca=kg+1|0;ga=a[M+kg|0]|0;if(!(ga<<24>>24==0)){mg=(ga&255)<<2;ng=Ca;og=_a;pg=M;qg=M;break}if((Ca|0)>=(Da|0)){J=87;break d}ga=kg+2|0;Fa=d[M+Ca|0]<<2;Ca=c[o+8244+(Fa<<2)>>2]|0;Za=(Ca>>>1)+_a|0;if((Ca&1|0)==0){mg=Fa|1;ng=ga;og=Za;pg=M;qg=M;break}if((ga|0)>=(Da|0)){J=90;break d}mg=d[M+ga|0]<<2;ng=kg+3|0;og=Za;pg=M;qg=M}}while(0);_a=(c[w>>2]|0)+og|0;c[z>>2]=_a;Ea=z+4|0;Za=w+4|0;c[w>>2]=_a;_a=c[o+4148+(mg<<2)>>2]|0;ga=(_a>>>1)+og|0;do{if((_a&1|0)==0){if((mg|0)>1022){J=108;break d}rg=mg+1|0;sg=ng;tg=ga;ug=pg}else{Da=c[p>>2]|0;if((ng|0)>=(Da|0)){J=98;break d}Fa=ng+1|0;Ca=a[qg+ng|0]|0;if(!(Ca<<24>>24==0)){rg=(Ca&255)<<2;sg=Fa;tg=ga;ug=qg;break}if((Fa|0)>=(Da|0)){J=101;break d}Ca=ng+2|0;Uc=d[qg+Fa|0]<<2;Fa=c[o+12340+(Uc<<2)>>2]|0;Ga=(Fa>>>1)+ga|0;if((Fa&1|0)==0){rg=Uc|1;sg=Ca;tg=Ga;ug=qg;break}if((Ca|0)>=(Da|0)){J=104;break d}rg=d[qg+Ca|0]<<2;sg=ng+3|0;tg=Ga;ug=qg}}while(0);ga=c[o+52+(rg<<2)>>2]|0;_a=(ga>>>1)+tg|0;do{if((ga&1|0)==0){if((rg|0)>1022){J=122;break d}vg=rg+1|0;wg=sg;xg=_a}else{Ga=c[p>>2]|0;if((sg|0)>=(Ga|0)){J=112;break d}Ca=sg+1|0;Da=a[ug+sg|0]|0;if(!(Da<<24>>24==0)){vg=(Da&255)<<2;wg=Ca;xg=_a;break}if((Ca|0)>=(Ga|0)){J=115;break d}Da=sg+2|0;Uc=d[ug+Ca|0]<<2;Ca=c[o+8244+(Uc<<2)>>2]|0;Fa=(Ca>>>1)+_a|0;if((Ca&1|0)==0){vg=Uc|1;wg=Da;xg=Fa;break}if((Da|0)>=(Ga|0)){J=118;break d}vg=d[ug+Da|0]<<2;wg=sg+3|0;xg=Fa}}while(0);_a=(c[Za>>2]|0)+xg|0;c[Ea>>2]=_a;c[Za>>2]=_a;ye=vg;ze=wg;Ae=z+8|0;Be=w+8|0;Ce=xg;De=ug;Ee=qg;Fe=M;Ge=E;He=H;Ie=l}else{ye=v;ze=S;Ae=z;Be=w;Ce=y;De=m;Ee=P;Fe=M;Ge=E;He=H;Ie=l}}while(0);if(Z){yg=B;zg=C;Ag=A;Bg=Ce;Cg=Be;Dg=Ae;Eg=ze;Fg=ye;Gg=De;Hg=Ee;Ig=Fe;Jg=Ge;Kg=He;Lg=Ie}else{Fd=Ce;Gd=Be;Hd=Ae;Id=ze;Jd=ye;Kd=De;Ld=Ee;Md=Fe;Nd=Ge;Od=He;Pd=Ie;J=329}}do{if((J|0)==329){J=0;_a=C<<1;if(!(_a<<24>>24==0)){yg=B;zg=_a;Ag=A;Bg=Fd;Cg=Gd;Dg=Hd;Eg=Id;Fg=Jd;Gg=Kd;Hg=Ld;Ig=Md;Jg=Nd;Kg=Od;Lg=Pd;break}yg=B+1|0;zg=1;Ag=a[N+B|0]|0;Bg=Fd;Cg=Gd;Dg=Hd;Eg=Id;Fg=Jd;Gg=Kd;Hg=Ld;Ig=Md;Jg=Nd;Kg=Od;Lg=Pd}}while(0);_a=x-2|0;if((_a|0)>0){x=_a;y=Bg;w=Cg;z=Dg;A=Ag;C=zg;B=yg;S=Eg;v=Fg;m=Gg;P=Hg;M=Ig;E=Jg;H=Kg;l=Lg}else{Mg=Eg;Ng=Fg;Og=Gg;Pg=Hg;Qg=Ig;Rg=Jg;Sg=Kg;Tg=Lg;break}}}else{Mg=W;Ng=da;Og=R;Pg=L;Qg=O;Rg=aa;Sg=f;Tg=ea}l=r+1|0;if((l&3|0)==0){Ug=N+(c[F>>2]|0)|0}else{Ug=N}if((l|0)>=(c[X>>2]|0)){break b}s=s+(c[(c[T>>2]|0)+32>>2]|0)|0;r=l;N=Ug;W=Mg;da=Ng;R=Og;L=Pg;O=Qg;aa=Rg;f=Sg;ea=Tg}if((J|0)==70){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==73){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==76){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==80){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==84){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==87){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==90){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==94){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==98){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==101){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==104){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==108){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==112){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==115){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==118){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==122){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==127){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==130){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==133){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==137){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==141){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==144){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==147){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==151){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==155){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==158){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==161){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==165){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==170){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==173){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==176){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==180){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==184){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==187){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==190){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==194){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==200){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==203){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==206){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==210){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==214){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==217){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==220){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==224){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==228){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==231){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==234){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==238){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==242){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==245){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==248){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==252){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==257){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==260){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==263){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==267){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==271){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==274){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==277){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==281){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==285){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==288){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==291){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==295){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==300){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==303){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==306){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==310){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==314){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==317){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==320){yDb(G,32,2180208,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==324){yDb(G,16,2103664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}}}while(0);t=MCb(g,c[T>>2]|0)|0;if((t|0)<0){u=t;i=k;return u|0}c[h>>2]=1;u=n;i=k;return u|0}function b$a(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);$Db(b+16524|0);return 0}function c$a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;d=c[a+60>>2]|0;e=c[a+120>>2]|0;f=c[a+124>>2]|0;do{if((e&3|0)==0){if((f&3|0)!=0){break}c[d>>2]=a;c[a+140>>2]=3;g=ICb()|0;h=d+4|0;c[h>>2]=g;if((g|0)==0){j=-12;i=b;return j|0}Z3(d+28|0,a);g=e>>2;if(g>>>0<134217727>>>0){k=g<<4;g=d+3188|0;l=g;c[l>>2]=WDb(k)|0;m=WDb(k)|0;n=g;o=l}else{l=d+3188|0;g=l;c[g>>2]=0;m=0;n=l;o=g}g=d+3192|0;l=g;c[l>>2]=m;c[d+1280>>2]=0;c[d+1308>>2]=0;c[d+1284>>2]=0;c[d+1312>>2]=0;c[d+1288>>2]=0;c[d+1316>>2]=0;c[d+1292>>2]=0;c[d+1320>>2]=0;c[d+1296>>2]=0;c[d+1324>>2]=0;c[d+1300>>2]=0;c[d+1328>>2]=0;c[d+1304>>2]=0;c[d+1332>>2]=0;k=e+8|0;p=ba(f+8|0,k)|0;q=d+3196|0;r=q;c[r>>2]=dEb(p,4)|0;s=d+3208|0;t=s;c[t>>2]=dEb(p,4)|0;p=d+3244|0;c[p>>2]=k;k=e+9>>1;u=ba(f+9>>1,k)|0;v=d+3200|0;w=v;c[w>>2]=dEb(u,4)|0;x=d+3204|0;y=x;c[y>>2]=dEb(u,4)|0;z=d+3212|0;A=z;c[A>>2]=dEb(u,4)|0;B=dEb(u,4)|0;u=B;C=d+3216|0;c[C>>2]=u;c[d+3248>>2]=k;c[d+3252>>2]=0;D=c[r>>2]|0;do{if((D|0)!=0){r=c[t>>2]|0;if((r|0)==0){break}E=c[w>>2]|0;if((E|0)==0){break}F=c[y>>2]|0;if((F|0)==0){break}G=c[A>>2]|0;if((G|0)==0|(B|0)==0){break}if((c[o>>2]|0)==0){break}if((c[l>>2]|0)==0){break}H=(c[p>>2]<<2)+4|0;c[d+3220>>2]=D+(H<<2);c[d+3232>>2]=r+(H<<2);H=(k<<1)+2|0;c[d+3224>>2]=E+(H<<2);c[d+3236>>2]=G+(H<<2);c[d+3228>>2]=F+(H<<2);c[d+3240>>2]=u+(H<<2);j=0;i=b;return j|0}}while(0);$Db(q);$Db(s);$Db(v);$Db(z);$Db(x);$Db(C);$Db(n);$Db(g);JCb(h);j=-12;i=b;return j|0}}while(0);yDb(a,16,2150808,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-22;i=b;return j|0}function d$a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0;j=i;i=i+136|0;k=j|0;l=j+64|0;m=j+104|0;n=c[e+60>>2]|0;o=n;p=c[h+24>>2]|0;q=c[h+28>>2]|0;h=q&-4;r=n+4|0;s=c[r>>2]|0;t=n+1272|0;u=t;O$a(t,n+1276|0,h);if((c[u>>2]|0)==0){yDb(e,16,2180064,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-12;i=j;return w|0}t=$$a(e,s)|0;if((t|0)<0){w=t;i=j;return w|0}Xe[c[n+1124>>2]&4095](c[u>>2]|0,p,q>>2);q=c[u>>2]|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;if((p|0)==257){x=n}else if((p|0)==256){q=n;DDb(c[q>>2]|0,2164408,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;x=q}else{yDb(c[n>>2]|0,16,2157568,(v=i,i=i+8|0,c[v>>2]=p,v)|0);i=v;w=-1094995529;i=j;return w|0}p=n+8|0;q=n+20|0;t=n+24|0;y=n+12|0;z=n+16|0;A=l|0;B=l+4|0;C=l+8|0;D=l+12|0;E=l+16|0;F=l+20|0;G=l+24|0;H=l+28|0;I=l+32|0;J=m+24|0;K=m+4|0;L=m|0;M=m+20|0;N=m+28|0;m=0;O=40;a:while(1){if((O|0)>=(h|0)){P=10;break}Q=c[u>>2]|0;R=Q+O|0;S=186272+(m<<2)|0;T=c[S>>2]|0;U=h-O|0;if((U|0)<4){P=12;break}V=Q+h|0;W=R;X=Q+(O+4)|0;Y=R;R=d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0;Y=fe(R|0)|0;Z=(Y<<2)+4|0;if((R|0)==0){_=4}else{if(Y>>>0>536870909>>>0|(Z|0)>(U|0)){P=15;break}do{if((U-4|0)<4){$=X;aa=0}else{Y=Q+(O+8)|0;R=X;ca=fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0;if((ca&1|0)==0){$=Y;aa=ca;break}if((U-8|0)<4){$=Y;aa=ca;break}R=Q+(O+12)|0;da=Y;Y=d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0;da=fe(Y|0)|0;if((Y|0)==128){if((U-12|0)<4){$=R;aa=ca;break}Y=R;ea=fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0;fa=Q+(O+16)|0}else{ea=da;fa=R}if((ea|0)<=0){$=fa;aa=ca;break}R=fa;da=R-W|0;if((Z|0)<=(da|0)){ga=-1094995529;ha=T;break a}Y=Q+(da+O)|0;ia=Z-da<<3;da=ia>>>0>2147483639>>>0|(Y|0)==0;ja=da?0:Y;Y=da?0:ia;c[p>>2]=ja;c[q>>2]=Y;ia=Y+8|0;c[t>>2]=ia;c[y>>2]=ja+(Y>>3);c[z>>2]=0;Y=ja;da=fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0;ka=da>>>23;Y=ia>>>0>9>>>0?9:ia;c[z>>2]=Y;la=ja+(Y>>>3)|0;ma=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(Y&1);na=ma>>>27;la=Y+5|0;Y=ia>>>0>la>>>0?la:ia;c[z>>2]=Y;if((ka-1|0)>>>0>63>>>0){P=44;break a}la=na-1|0;if(la>>>0>31>>>0){P=44;break a}if((ka|0)==0){oa=0;P=38}else{pa=1<<la;la=1<<na;qa=32-na|0;ra=na-16|0;sa=48-na|0;ta=da>>>0>16777215>>>0;do{if((na|0)==0){TGb(n+((T<<8)+1364)|0,0,(ta?ka<<2:4)|0)|0;ua=ta?ka:1}else{if(ma>>>0<3489660928>>>0){da=0;va=Y;wa=ia;xa=ja;while(1){ya=xa+(va>>>3)|0;za=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(va&7)>>>(qa>>>0);ya=va+na|0;c[z>>2]=wa>>>0>ya>>>0?ya:wa;if((za&pa|0)==0){c[o+1364+(T<<8)+(da<<2)>>2]=za}else{c[o+1364+(T<<8)+(da<<2)>>2]=za-la}za=da+1|0;if((za|0)>=(ka|0)){break}da=za;va=c[z>>2]|0;wa=c[t>>2]|0;xa=c[p>>2]|0}ua=ta?ka:1;break}else{xa=0;wa=Y;va=ia;da=ja;while(1){za=da+(wa>>>3)|0;ya=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(wa&7)>>>16;za=wa+16|0;Aa=va>>>0>za>>>0?za:va;c[z>>2]=Aa;za=da+(Aa>>>3)|0;Ba=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Aa&7)>>>(sa>>>0);za=Aa+ra|0;c[z>>2]=va>>>0>za>>>0?za:va;za=Ba|ya<<ra;if((za&pa|0)==0){c[o+1364+(T<<8)+(xa<<2)>>2]=za}else{c[o+1364+(T<<8)+(xa<<2)>>2]=za-la}za=xa+1|0;if((za|0)>=(ka|0)){break}xa=za;wa=c[z>>2]|0;va=c[t>>2]|0;da=c[p>>2]|0}ua=ta?ka:1;break}}}while(0);if((ua|0)<64){oa=ua;P=38}}if((P|0)==38){P=0;ta=oa<<2;TGb(n+((T<<8)+1364+ta)|0,0,256-ta|0)|0}ta=(c[z>>2]|0)+31>>5<<2;la=V-R|0;$=fa+(la>>>0>ta>>>0?ta:la)|0;aa=ca}}while(0);do{if((V-$|0)<4){Ca=$;P=49}else{U=$+4|0;X=$;if((d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)!=128){Ca=U;P=49;break}X=V-U|0;Da=$+(X>>>0>8>>>0?12:X+4|0)|0}}while(0);if((P|0)==49){P=0;X=V-Ca|0;Da=Ca+(X>>>0>4>>>0?4:X)|0}X=Da;U=X-W|0;if((Z|0)<=(U|0)){ga=-1094995529;ha=T;break}la=Q+(U+O)|0;ta=Z-U<<3;U=ta>>>0>2147483639>>>0|(la|0)==0;pa=U?0:la;la=U?0:ta;c[p>>2]=pa;c[q>>2]=la;ta=la+8|0;c[t>>2]=ta;c[y>>2]=pa+(la>>3);c[z>>2]=0;la=pa;Ea=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>3&31;la=ta>>>0>5>>>0?5:ta;c[z>>2]=la;c[A>>2]=Ea;U=pa+(la>>>3)|0;ra=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(la&5);Fa=ra>>>27;U=la+5|0;la=ta>>>0>U>>>0?U:ta;c[z>>2]=la;c[B>>2]=Fa;U=pa+(la>>>3)|0;sa=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(la&7)>>>27;U=la+5|0;la=ta>>>0>U>>>0?U:ta;c[z>>2]=la;c[C>>2]=sa;sa=pa+(la>>>3)|0;Ga=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(la&7)>>>15;sa=la+17|0;c[z>>2]=ta>>>0>sa>>>0?sa:ta;c[D>>2]=Ga;c[E>>2]=0;if((Ea-1|0)>>>0>31>>>0|ra>>>0>3489660927>>>0){P=52;break}if((Ga-1|0)>>>0>65535>>>0){P=54;break}if((Fa|0)==0){c[B>>2]=1}ra=(Ga+1|0)>>>1;c[F>>2]=ra;ta=dEb(ra,4)|0;c[G>>2]=ta;sa=dEb(ra,4)|0;c[H>>2]=sa;la=dEb(ra,4)|0;c[I>>2]=la;do{if((ta|0)==0){Ha=-12}else{if((sa|0)==0|(la|0)==0){Ha=-12;break}ra=g$a(o,0,0,l)|0;pa=c[E>>2]|0;U=c[F>>2]|0;if((pa|0)!=(U|0)){yDb(c[x>>2]|0,16,2255976,(v=i,i=i+16|0,c[v>>2]=pa,c[v+8>>2]=U,v)|0);i=v;Ha=-1094995529;break}if(!((ra|0)>-1)){Ha=ra;break}ra=N_(L,c[B>>2]|0,pa,c[I>>2]|0,4,4,c[H>>2]|0,4,4,0,0,0,0)|0;if((ra|0)<0){yDb(c[x>>2]|0,16,2241656,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;Ha=ra;break}c[M>>2]=c[B>>2];pa=c[F>>2]|0;c[N>>2]=pa;if(!(pa>>>0<536870911>>>0)){c[J>>2]=0;Ha=-12;break}U=WDb(pa<<2)|0;pa=U;c[J>>2]=pa;if((U|0)==0){Ha=-12;break}U=c[N>>2]|0;if((U|0)<=0){Ha=ra;break}ja=c[G>>2]|0;ia=0;while(1){c[pa+(ia<<2)>>2]=c[ja+(ia<<2)>>2];Y=ia+1|0;if((Y|0)<(U|0)){ia=Y}else{Ha=ra;break}}}}while(0);ZDb(c[G>>2]|0);ZDb(c[H>>2]|0);ZDb(c[I>>2]|0);if((Ha|0)<0){ga=Ha;ha=T;break}la=(c[z>>2]|0)+31>>5<<2;sa=V-X|0;ta=sa>>>0>la>>>0?la:sa;sa=Da+ta|0;Ia=aa>>1;if(Ia>>>0>16777215>>>0){P=72;break}Ja=o+1280+(T<<2)|0;Ka=bEb(Ja,Ia,4)|0;La=o+1308+(T<<2)|0;if((Ka|0)<0){P=75;break}c[La>>2]=Ia;b:do{if((V-sa|0)<4){P=77}else{la=sa;if((fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<=0){P=77;break}la=Da+(ta+4)-W|0;if((Z|0)<=(la|0)){ga=-1094995529;ha=T;break a}ra=Q+(la+O)|0;ia=Z-la<<3;la=ia>>>0>2147483639>>>0|(ra|0)==0;U=la?0:ra;ra=la?0:ia;c[p>>2]=U;c[q>>2]=ra;c[t>>2]=ra+8;c[y>>2]=U+(ra>>3);c[z>>2]=0;ra=(m|0)!=6;Ma=0;while(1){if((Ma|0)>=(Ia|0)){break b}ia=c[z>>2]|0;if(((c[q>>2]|0)-ia|0)<1){P=86;break a}la=c[K>>2]|0;ja=c[M>>2]|0;pa=c[J>>2]|0;ca=c[t>>2]|0;R=U+(ia>>>3)|0;Y=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(ia&7)>>>((32-ja|0)>>>0);ja=b[la+(Y<<2)>>1]|0;R=(b[la+(Y<<2)+2>>1]|0)+ia|0;c[z>>2]=ca>>>0>R>>>0?R:ca;if(ja<<16>>16<0){P=88;break a}ca=c[pa+(ja<<16>>16<<2)>>2]|0;c[(c[Ja>>2]|0)+(Ma<<2)>>2]=ca;if(ra&(ca|0)>63){Na=ca;P=91;break a}if((ca|0)<0){Na=ca;P=91;break a}else{Ma=Ma+1|0}}}}while(0);c:do{if((P|0)==77){P=0;if((Ia|0)<=0){break}Q=c[J>>2]|0;W=c[Ja>>2]|0;if((m|0)==6){ta=0;while(1){c[W+(ta<<2)>>2]=c[Q>>2];ta=ta+1|0;if((ta|0)>=(Ia|0)){break c}}}else{Oa=0}while(1){Pa=c[Q>>2]|0;c[W+(Oa<<2)>>2]=Pa;if((Pa|0)>63){P=92;break a}ta=Oa+1|0;if((ta|0)<(Ia|0)){Oa=ta}else{break}}}}while(0);ZDb(c[J>>2]|0);if((c[K>>2]|0)!=0){Q_(L)}if((Z|0)<0){ga=Z;ha=T;break}else{_=Z}}W=m+1|0;if((W|0)<7){m=W;O=_+O|0}else{P=99;break}}do{if((P|0)==10){yDb(e,16,2103632,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=j;return w|0}else if((P|0)==12){yDb(c[x>>2]|0,16,1892344,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==15){yDb(c[x>>2]|0,16,2350016,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==44){yDb(c[x>>2]|0,16,2208288,(v=i,i=i+16|0,c[v>>2]=ka,c[v+8>>2]=na,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==52){yDb(c[x>>2]|0,16,2287424,(v=i,i=i+16|0,c[v>>2]=Ea,c[v+8>>2]=Fa,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==54){yDb(c[x>>2]|0,16,2271368,(v=i,i=i+8|0,c[v>>2]=Ga,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==72){yDb(c[x>>2]|0,16,2329832,(v=i,i=i+8|0,c[v>>2]=Ia,v)|0);i=v;ZDb(c[J>>2]|0);if((c[K>>2]|0)==0){ga=-1094995529;ha=T;break}Q_(L);ga=-1094995529;ha=T}else if((P|0)==75){c[La>>2]=0;ga=Ka;ha=T}else if((P|0)==86){yDb(c[x>>2]|0,16,2329832,(v=i,i=i+8|0,c[v>>2]=Ia,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==88){c[(c[Ja>>2]|0)+(Ma<<2)>>2]=-1;Na=-1;P=91}else if((P|0)==92){yDb(c[x>>2]|0,16,2305336,(v=i,i=i+24|0,c[v>>2]=Pa,c[v+8>>2]=T,c[v+16>>2]=Oa,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==99){O=c[x>>2]|0;_=c[O+120>>2]|0;m=c[O+124>>2]|0;z=m>>2;t=n+1336|0;M=t;TGb(t|0,0,28)|0;t=_>>2;q=_>>1;y=n+1332|0;p=c[y>>2]|0;Da=ba(z,t)|0;do{if((p|0)<(Da|0)){yDb(O,16,2047296,(v=i,i=i+16|0,c[v>>2]=p,c[v+8>>2]=Da,v)|0);i=v;Qa=-1094995529}else{aa=n+3188|0;Ha=t<<4;TGb(c[aa>>2]|0,0,Ha|0)|0;I=n+3192|0;TGb(c[I>>2]|0,0,Ha|0)|0;if((z|0)>0){Ha=n+3156|0;H=(t|0)>0;G=n+1360|0;N=n+1304|0;F=k;B=n+3244|0;E=n+3248|0;l=n+3252|0;D=n+3232|0;C=n+3220|0;A=n+3240|0;Ca=n+3228|0;$=n+3236|0;fa=n+3224|0;oa=n+1340|0;ua=n+1312|0;ea=n+1284|0;u=k|0;W=k+12|0;Q=k+8|0;ta=k+4|0;sa=n+3172|0;V=n+3176|0;X=n+3180|0;ra=n+3184|0;U=n+1344|0;ca=n+1316|0;ja=n+1288|0;pa=n+1348|0;R=n+1320|0;ia=n+1292|0;Y=k+32|0;la=k+40|0;qa=Ha;ma=n+3160|0;da=n+3164|0;va=n+3168|0;wa=n+1352|0;xa=n+1324|0;za=n+1296|0;ya=n+1356|0;Ba=n+1328|0;Aa=n+1300|0;Ra=n+1308|0;Sa=n+1280|0;Ta=k+16|0;Ua=k+20|0;Va=k+24|0;Wa=k+28|0;Xa=1;Ya=0;while(1){TGb(Ha|0,0,32)|0;if(H){Za=Ya<<2;_a=Ya<<1;$a=_a|1;ab=-4-Za|0;bb=Za|3;cb=Xa;db=0;while(1){eb=c[G>>2]|0;fb=c[y>>2]|0;d:do{if((eb|0)<(fb|0)){c[G>>2]=eb+1;gb=c[(c[N>>2]|0)+(eb<<2)>>2]|0;switch(gb|0){case 4:{hb=c[B>>2]|0;ib=c[E>>2]|0;jb=(c[l>>2]|0)==0;kb=c[(jb?C:D)>>2]|0;lb=c[(jb?Ca:A)>>2]|0;mb=db<<1;nb=(ba(ib,_a)|0)+mb|0;ob=c[(jb?fa:$)>>2]|0;pb=c[aa>>2]|0;qb=c[I>>2]|0;rb=c[(jb?D:C)>>2]|0;sb=(c[(jb?A:Ca)>>2]|0)+(nb<<2)|0;tb=(c[(jb?$:fa)>>2]|0)+(nb<<2)|0;jb=ob+(nb<<2)|0;ub=lb+(nb<<2)|0;nb=0;while(1){vb=c[tb>>2]|0;wb=c[wa>>2]|0;xb=c[xa>>2]|0;do{if((wb|0)<(xb|0)){yb=(c[za>>2]|0)+(wb<<2)|0;zb=c[yb>>2]|0;if((zb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=zb,v)|0);i=v;Ab=0;break}else{c[wa>>2]=wb+1;Ab=c[o+2388+(c[yb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=wb,c[v+16>>2]=xb,v)|0);i=v;Ab=0}}while(0);c[jb>>2]=Ab+vb;xb=c[sb>>2]|0;wb=c[wa>>2]|0;yb=c[xa>>2]|0;do{if((wb|0)<(yb|0)){zb=(c[za>>2]|0)+(wb<<2)|0;Bb=c[zb>>2]|0;if((Bb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=Bb,v)|0);i=v;Cb=0;break}else{c[wa>>2]=wb+1;Cb=c[o+2388+(c[zb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=wb,c[v+16>>2]=yb,v)|0);i=v;Cb=0}}while(0);c[ub>>2]=Cb+xb;yb=c[tb+4>>2]|0;wb=c[wa>>2]|0;vb=c[xa>>2]|0;do{if((wb|0)<(vb|0)){zb=(c[za>>2]|0)+(wb<<2)|0;Bb=c[zb>>2]|0;if((Bb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=Bb,v)|0);i=v;Db=0;break}else{c[wa>>2]=wb+1;Db=c[o+2388+(c[zb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=wb,c[v+16>>2]=vb,v)|0);i=v;Db=0}}while(0);c[jb+4>>2]=Db+yb;vb=c[sb+4>>2]|0;wb=c[wa>>2]|0;xb=c[xa>>2]|0;do{if((wb|0)<(xb|0)){zb=(c[za>>2]|0)+(wb<<2)|0;Bb=c[zb>>2]|0;if((Bb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=Bb,v)|0);i=v;Eb=0;break}else{c[wa>>2]=wb+1;Eb=c[o+2388+(c[zb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=wb,c[v+16>>2]=xb,v)|0);i=v;Eb=0}}while(0);c[ub+4>>2]=Eb+vb;xb=nb+1|0;if((xb|0)<2){sb=sb+(ib<<2)|0;tb=tb+(ib<<2)|0;jb=jb+(ib<<2)|0;ub=ub+(ib<<2)|0;nb=xb}else{break}}nb=db<<2;ub=(ba(hb,Za)|0)+nb|0;jb=(ba(ib,$a)|0)+mb|0;tb=ib<<1;sb=-tb|1;xb=sb+ib+jb|0;wb=ob+(xb<<2)|0;yb=qb+((nb|1)<<2)|0;c[sa>>2]=(c[wb>>2]|0)-(c[yb>>2]|0);zb=jb+tb+sb|0;sb=ob+(zb<<2)|0;c[V>>2]=(c[sb>>2]|0)-(c[wb>>2]|0);c[qb+(nb<<2)>>2]=c[ob+(jb<<2)>>2];c[yb>>2]=c[sb>>2];sb=lb+(xb<<2)|0;xb=nb|3;yb=qb+(xb<<2)|0;c[X>>2]=(c[sb>>2]|0)-(c[yb>>2]|0);wb=lb+(zb<<2)|0;c[ra>>2]=(c[wb>>2]|0)-(c[sb>>2]|0);c[qb+((nb|2)<<2)>>2]=c[lb+(jb<<2)>>2];c[yb>>2]=c[wb>>2];wb=rb+((ub|3)<<2)|0;yb=pb+(xb<<2)|0;c[qa>>2]=(c[wb>>2]|0)-(c[yb>>2]|0);xb=rb+(hb+3+ub<<2)|0;c[ma>>2]=(c[xb>>2]|0)-(c[wb>>2]|0);wb=rb+((hb<<1)+3+ub<<2)|0;c[da>>2]=(c[wb>>2]|0)-(c[xb>>2]|0);c[va>>2]=(c[rb+((hb*3|0)+3+ub<<2)>>2]|0)-(c[wb>>2]|0);wb=kb+(ub<<2)|0;xb=rb+(ub<<2)|0;ub=0;while(1){jb=c[yb>>2]|0;sb=0;do{zb=c[xb+(sb<<2)>>2]|0;tb=c[wa>>2]|0;Bb=c[xa>>2]|0;do{if((tb|0)<(Bb|0)){Fb=(c[za>>2]|0)+(tb<<2)|0;Gb=c[Fb>>2]|0;if((Gb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=Gb,v)|0);i=v;Hb=0;break}else{c[wa>>2]=tb+1;Hb=c[o+2388+(c[Fb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=tb,c[v+16>>2]=Bb,v)|0);i=v;Hb=0}}while(0);Bb=Hb+zb|0;c[wb+(sb<<2)>>2]=Bb;c[pb+(sb+nb<<2)>>2]=Bb;sb=sb+1|0;}while((sb|0)<4);c[o+3156+(ub<<2)>>2]=(c[yb>>2]|0)-jb;sb=ub+1|0;if((sb|0)<4){wb=wb+(hb<<2)|0;xb=xb+(hb<<2)|0;ub=sb}else{Ib=0;break}}break};case 0:{P=109;break d;break};case 1:{ub=c[B>>2]|0;hb=c[E>>2]|0;xb=(c[l>>2]|0)==0;wb=db<<2;yb=(c[(xb?C:D)>>2]|0)+((ba(ub,Za)|0)+wb<<2)|0;nb=c[(xb?Ca:A)>>2]|0;pb=(ba(hb,_a)|0)+(db<<1)|0;rb=nb+(pb<<2)|0;kb=c[(xb?fa:$)>>2]|0;xb=kb+(pb<<2)|0;lb=(c[aa>>2]|0)+(wb<<2)|0;qb=c[I>>2]|0;ob=qb+(wb<<2)|0;ib=c[oa>>2]|0;mb=c[ua>>2]|0;do{if((ib|0)<(mb|0)){sb=(c[ea>>2]|0)+(ib<<2)|0;vb=c[sb>>2]|0;if((vb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=vb,v)|0);i=v;Jb=0;break}else{c[oa>>2]=ib+1;Jb=c[o+1620+(c[sb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=1,c[v+8>>2]=ib,c[v+16>>2]=mb,v)|0);i=v;Jb=0}}while(0);c[u>>2]=Jb;c[W>>2]=0;c[Q>>2]=0;c[ta>>2]=0;mb=(db|0)>0;if(mb){Kb=c[qb+(wb-3<<2)>>2]|0}else{Kb=0}ib=c[sa>>2]|0;sb=c[V>>2]|0;vb=sb+ib|0;Bb=vb>>1;tb=qb+((wb|1)<<2)|0;Fb=Kb-ib-sb+(c[tb>>2]|0)>>1;c[V>>2]=vb-Bb;c[sa>>2]=Bb;c[ob>>2]=Fb;Fb=(c[sa>>2]|0)+Jb|0;c[sa>>2]=Fb;Bb=(c[ob>>2]|0)+Fb|0;c[ob>>2]=Bb;c[xb>>2]=Bb;Bb=(c[tb>>2]|0)+(c[sa>>2]|0)|0;c[tb>>2]=Bb;Fb=pb|1;c[kb+(Fb<<2)>>2]=Bb;Bb=pb+hb|0;vb=(c[ob>>2]|0)+(c[V>>2]|0)|0;c[ob>>2]=vb;c[kb+(Bb<<2)>>2]=vb;vb=(c[tb>>2]|0)+(c[V>>2]|0)|0;c[tb>>2]=vb;tb=hb+1+pb|0;c[kb+(tb<<2)>>2]=vb;vb=c[oa>>2]|0;sb=c[ua>>2]|0;do{if((vb|0)<(sb|0)){ib=(c[ea>>2]|0)+(vb<<2)|0;Gb=c[ib>>2]|0;if((Gb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=Gb,v)|0);i=v;Lb=0;break}else{c[oa>>2]=vb+1;Lb=c[o+1620+(c[ib>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=1,c[v+8>>2]=vb,c[v+16>>2]=sb,v)|0);i=v;Lb=0}}while(0);c[u>>2]=Lb;c[W>>2]=0;c[Q>>2]=0;c[ta>>2]=0;sb=wb|2;vb=qb+(sb<<2)|0;if(mb){Mb=c[qb+(sb-3<<2)>>2]|0}else{Mb=0}sb=c[X>>2]|0;kb=c[ra>>2]|0;pb=kb+sb|0;hb=pb>>1;ob=qb+((wb|3)<<2)|0;xb=Mb-sb-kb+(c[ob>>2]|0)>>1;c[ra>>2]=pb-hb;c[X>>2]=hb;c[vb>>2]=xb;xb=(c[X>>2]|0)+Lb|0;c[X>>2]=xb;hb=(c[vb>>2]|0)+xb|0;c[vb>>2]=hb;c[rb>>2]=hb;hb=(c[ob>>2]|0)+(c[X>>2]|0)|0;c[ob>>2]=hb;c[nb+(Fb<<2)>>2]=hb;hb=(c[vb>>2]|0)+(c[ra>>2]|0)|0;c[vb>>2]=hb;c[nb+(Bb<<2)>>2]=hb;hb=(c[ob>>2]|0)+(c[ra>>2]|0)|0;c[ob>>2]=hb;c[nb+(tb<<2)>>2]=hb;hb=0;do{ob=c[U>>2]|0;vb=c[ca>>2]|0;do{if((ob|0)<(vb|0)){xb=(c[ja>>2]|0)+(ob<<2)|0;pb=c[xb>>2]|0;if((pb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=pb,v)|0);i=v;Nb=0;break}else{c[U>>2]=ob+1;Nb=c[o+1876+(c[xb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=2,c[v+8>>2]=ob,c[v+16>>2]=vb,v)|0);i=v;Nb=0}}while(0);c[k+(hb<<2)>>2]=Nb;hb=hb+1|0;}while((hb|0)<16);f$a(o,yb,ub,u,lb);Ib=cb;break d;break};case 2:{hb=c[B>>2]|0;tb=c[E>>2]|0;nb=(c[l>>2]|0)==0;Bb=db<<2;Fb=(c[(nb?C:D)>>2]|0)+((ba(hb,Za)|0)+Bb<<2)|0;rb=c[(nb?Ca:A)>>2]|0;wb=(ba(tb,_a)|0)+(db<<1)|0;qb=rb+(wb<<2)|0;mb=c[(nb?fa:$)>>2]|0;nb=mb+(wb<<2)|0;vb=c[aa>>2]|0;ob=vb+(Bb<<2)|0;jb=c[I>>2]|0;xb=jb+(Bb<<2)|0;pb=c[oa>>2]|0;kb=c[ua>>2]|0;do{if((pb|0)<(kb|0)){sb=(c[ea>>2]|0)+(pb<<2)|0;ib=c[sb>>2]|0;if((ib|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=ib,v)|0);i=v;Ob=0;break}else{c[oa>>2]=pb+1;Ob=c[o+1620+(c[sb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=1,c[v+8>>2]=pb,c[v+16>>2]=kb,v)|0);i=v;Ob=0}}while(0);c[u>>2]=Ob;c[W>>2]=0;c[Q>>2]=0;c[ta>>2]=0;kb=(db|0)>0;if(kb){Pb=c[jb+(Bb-3<<2)>>2]|0}else{Pb=0}pb=c[sa>>2]|0;lb=c[V>>2]|0;ub=lb+pb|0;yb=ub>>1;sb=Bb|1;ib=jb+(sb<<2)|0;Gb=Pb-pb-lb+(c[ib>>2]|0)>>1;c[V>>2]=ub-yb;c[sa>>2]=yb;c[xb>>2]=Gb;Gb=(c[sa>>2]|0)+Ob|0;c[sa>>2]=Gb;yb=(c[xb>>2]|0)+Gb|0;c[xb>>2]=yb;c[nb>>2]=yb;yb=(c[ib>>2]|0)+(c[sa>>2]|0)|0;c[ib>>2]=yb;Gb=wb|1;c[mb+(Gb<<2)>>2]=yb;yb=wb+tb|0;ub=(c[xb>>2]|0)+(c[V>>2]|0)|0;c[xb>>2]=ub;c[mb+(yb<<2)>>2]=ub;ub=(c[ib>>2]|0)+(c[V>>2]|0)|0;c[ib>>2]=ub;ib=tb+1+wb|0;c[mb+(ib<<2)>>2]=ub;ub=c[oa>>2]|0;lb=c[ua>>2]|0;do{if((ub|0)<(lb|0)){pb=(c[ea>>2]|0)+(ub<<2)|0;Qb=c[pb>>2]|0;if((Qb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=Qb,v)|0);i=v;Rb=0;break}else{c[oa>>2]=ub+1;Rb=c[o+1620+(c[pb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=1,c[v+8>>2]=ub,c[v+16>>2]=lb,v)|0);i=v;Rb=0}}while(0);c[u>>2]=Rb;c[W>>2]=0;c[Q>>2]=0;c[ta>>2]=0;lb=Bb|2;ub=jb+(lb<<2)|0;if(kb){Sb=c[jb+(lb-3<<2)>>2]|0}else{Sb=0}mb=c[X>>2]|0;wb=c[ra>>2]|0;tb=wb+mb|0;xb=tb>>1;nb=Bb|3;pb=jb+(nb<<2)|0;Qb=Sb-mb-wb+(c[pb>>2]|0)>>1;c[ra>>2]=tb-xb;c[X>>2]=xb;c[ub>>2]=Qb;Qb=(c[X>>2]|0)+Rb|0;c[X>>2]=Qb;xb=(c[ub>>2]|0)+Qb|0;c[ub>>2]=xb;c[qb>>2]=xb;xb=(c[pb>>2]|0)+(c[X>>2]|0)|0;c[pb>>2]=xb;c[rb+(Gb<<2)>>2]=xb;xb=(c[ub>>2]|0)+(c[ra>>2]|0)|0;c[ub>>2]=xb;c[rb+(yb<<2)>>2]=xb;xb=(c[pb>>2]|0)+(c[ra>>2]|0)|0;c[pb>>2]=xb;c[rb+(ib<<2)>>2]=xb;TGb(F|0,0,64)|0;xb=c[pa>>2]|0;pb=c[R>>2]|0;do{if((xb|0)<(pb|0)){ub=(c[ia>>2]|0)+(xb<<2)|0;Qb=c[ub>>2]|0;if((Qb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=Qb,v)|0);i=v;Tb=0;break}else{c[pa>>2]=xb+1;Tb=c[o+2132+(c[ub>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=3,c[v+8>>2]=xb,c[v+16>>2]=pb,v)|0);i=v;Tb=0}}while(0);c[u>>2]=Tb;pb=c[pa>>2]|0;xb=c[R>>2]|0;do{if((pb|0)<(xb|0)){ib=(c[ia>>2]|0)+(pb<<2)|0;rb=c[ib>>2]|0;if((rb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=rb,v)|0);i=v;Ub=0;break}else{c[pa>>2]=pb+1;Ub=c[o+2132+(c[ib>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=3,c[v+8>>2]=pb,c[v+16>>2]=xb,v)|0);i=v;Ub=0}}while(0);c[Q>>2]=Ub;xb=c[pa>>2]|0;pb=c[R>>2]|0;do{if((xb|0)<(pb|0)){ib=(c[ia>>2]|0)+(xb<<2)|0;rb=c[ib>>2]|0;if((rb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=rb,v)|0);i=v;Vb=0;break}else{c[pa>>2]=xb+1;Vb=c[o+2132+(c[ib>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=3,c[v+8>>2]=xb,c[v+16>>2]=pb,v)|0);i=v;Vb=0}}while(0);c[Y>>2]=Vb;pb=c[pa>>2]|0;xb=c[R>>2]|0;do{if((pb|0)<(xb|0)){ib=(c[ia>>2]|0)+(pb<<2)|0;rb=c[ib>>2]|0;if((rb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=rb,v)|0);i=v;Wb=0;break}else{c[pa>>2]=pb+1;Wb=c[o+2132+(c[ib>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=3,c[v+8>>2]=pb,c[v+16>>2]=xb,v)|0);i=v;Wb=0}}while(0);c[la>>2]=Wb;if(kb){xb=c[vb+(sb<<2)>>2]|0;Xb=(c[vb+(Bb-1<<2)>>2]|0)-(c[qa>>2]|0)-(c[ma>>2]|0)-(c[da>>2]|0)-(c[va>>2]|0)+xb|0;Yb=xb}else{xb=c[vb+(sb<<2)>>2]|0;Xb=xb-(c[qa>>2]|0)-(c[ma>>2]|0)-(c[da>>2]|0)-(c[va>>2]|0)|0;Yb=xb}c[ob>>2]=Xb>>1;c[vb+(lb<<2)>>2]=(c[vb+(nb<<2)>>2]|0)+Yb>>1;xb=(c[ma>>2]|0)+(c[qa>>2]|0)|0;pb=xb>>1;c[qa>>2]=pb;c[ma>>2]=xb-pb;pb=(c[va>>2]|0)+(c[da>>2]|0)|0;xb=pb>>1;c[da>>2]=xb;c[va>>2]=pb-xb;f$a(o,Fb,hb,u,ob);Ib=cb;break d;break};case 3:{xb=c[B>>2]|0;pb=c[E>>2]|0;ib=(c[l>>2]|0)==0;rb=db<<2;yb=(c[(ib?C:D)>>2]|0)+((ba(xb,Za)|0)+rb<<2)|0;Gb=c[(ib?Ca:A)>>2]|0;qb=(ba(pb,_a)|0)+(db<<1)|0;jb=c[(ib?fa:$)>>2]|0;ib=c[aa>>2]|0;ub=ib+(rb<<2)|0;Qb=c[I>>2]|0;tb=Qb+(rb<<2)|0;wb=(db|0)>0;TGb(F|0,0,16)|0;if(wb){Zb=c[Qb+(rb-3<<2)>>2]|0}else{Zb=0}mb=c[sa>>2]|0;_b=c[V>>2]|0;$b=_b+mb|0;ac=$b>>1;bc=rb|1;cc=Qb+(bc<<2)|0;dc=Zb-mb-_b+(c[cc>>2]|0)>>1;c[V>>2]=$b-ac;c[sa>>2]=ac;c[tb>>2]=dc;ac=dc+(c[sa>>2]|0)|0;c[tb>>2]=ac;c[jb+(qb<<2)>>2]=ac;ac=(c[cc>>2]|0)+(c[sa>>2]|0)|0;c[cc>>2]=ac;dc=qb|1;c[jb+(dc<<2)>>2]=ac;ac=qb+pb|0;$b=(c[tb>>2]|0)+(c[V>>2]|0)|0;c[tb>>2]=$b;c[jb+(ac<<2)>>2]=$b;$b=(c[cc>>2]|0)+(c[V>>2]|0)|0;c[cc>>2]=$b;cc=pb+1+qb|0;c[jb+(cc<<2)>>2]=$b;$b=rb|2;jb=Qb+($b<<2)|0;TGb(F|0,0,16)|0;if(wb){ec=c[Qb+($b-3<<2)>>2]|0}else{ec=0}pb=c[X>>2]|0;tb=c[ra>>2]|0;_b=tb+pb|0;mb=_b>>1;fc=rb|3;gc=Qb+(fc<<2)|0;Qb=ec-pb-tb+(c[gc>>2]|0)>>1;c[ra>>2]=_b-mb;c[X>>2]=mb;c[jb>>2]=Qb;mb=Qb+(c[X>>2]|0)|0;c[jb>>2]=mb;c[Gb+(qb<<2)>>2]=mb;mb=(c[gc>>2]|0)+(c[X>>2]|0)|0;c[gc>>2]=mb;c[Gb+(dc<<2)>>2]=mb;mb=(c[jb>>2]|0)+(c[ra>>2]|0)|0;c[jb>>2]=mb;c[Gb+(ac<<2)>>2]=mb;mb=(c[gc>>2]|0)+(c[ra>>2]|0)|0;c[gc>>2]=mb;c[Gb+(cc<<2)>>2]=mb;TGb(F|0,0,64)|0;mb=(c[ma>>2]|0)+(c[qa>>2]|0)+(c[da>>2]|0)+(c[va>>2]|0)|0;if(wb){hc=(c[ib+(rb-1<<2)>>2]|0)-mb|0}else{hc=0}rb=c[ib+(fc<<2)>>2]|0;fc=rb-hc|0;wb=fc>>2;c[ub>>2]=wb+hc;c[ib+(bc<<2)>>2]=(fc>>1)+hc;c[ib+($b<<2)>>2]=rb-wb;wb=mb>>2;c[qa>>2]=wb;rb=hc+(mb>>1)|0;c[ma>>2]=rb-(hc+wb);c[da>>2]=mb-wb+hc-rb;c[va>>2]=wb;f$a(o,yb,xb,u,ub);Ib=cb;break d;break};case 5:{ub=c[B>>2]|0;xb=c[E>>2]|0;yb=(c[l>>2]|0)==0;wb=c[(yb?C:D)>>2]|0;rb=db<<2;mb=(ba(ub,Za)|0)+rb|0;$b=c[(yb?Ca:A)>>2]|0;ib=db<<1;fc=(ba(xb,_a)|0)+ib|0;bc=c[(yb?fa:$)>>2]|0;cc=c[aa>>2]|0;Gb=c[I>>2]|0;gc=c[(yb?D:C)>>2]|0;ac=c[(yb?A:Ca)>>2]|0;jb=c[(yb?$:fa)>>2]|0;yb=(ba(xb,$a)|0)+ib|0;c[bc+(fc<<2)>>2]=c[jb+(fc<<2)>>2];c[$b+(fc<<2)>>2]=c[ac+(fc<<2)>>2];ib=fc|1;c[bc+(ib<<2)>>2]=c[jb+(ib<<2)>>2];c[$b+(ib<<2)>>2]=c[ac+(ib<<2)>>2];ib=fc+xb|0;c[bc+(ib<<2)>>2]=c[jb+(ib<<2)>>2];c[$b+(ib<<2)>>2]=c[ac+(ib<<2)>>2];fc=ib+1|0;c[bc+(fc<<2)>>2]=c[jb+(fc<<2)>>2];c[$b+(fc<<2)>>2]=c[ac+(fc<<2)>>2];fc=gc+(mb<<2)|0;ac=xb<<1;jb=-ac|1;ib=jb+xb+yb|0;xb=bc+(ib<<2)|0;dc=rb|1;qb=Gb+(dc<<2)|0;c[sa>>2]=(c[xb>>2]|0)-(c[qb>>2]|0);Qb=yb+ac+jb|0;jb=bc+(Qb<<2)|0;c[V>>2]=(c[jb>>2]|0)-(c[xb>>2]|0);c[Gb+(rb<<2)>>2]=c[bc+(yb<<2)>>2];c[qb>>2]=c[jb>>2];jb=$b+(ib<<2)|0;ib=rb|2;qb=rb|3;bc=Gb+(qb<<2)|0;c[X>>2]=(c[jb>>2]|0)-(c[bc>>2]|0);xb=$b+(Qb<<2)|0;c[ra>>2]=(c[xb>>2]|0)-(c[jb>>2]|0);c[Gb+(ib<<2)>>2]=c[$b+(yb<<2)>>2];c[bc>>2]=c[xb>>2];xb=mb|3;bc=gc+(xb<<2)|0;yb=cc+(qb<<2)|0;c[qa>>2]=(c[bc>>2]|0)-(c[yb>>2]|0);qb=gc+(ub+3+mb<<2)|0;c[ma>>2]=(c[qb>>2]|0)-(c[bc>>2]|0);$b=gc+((ub<<1)+3+mb<<2)|0;c[da>>2]=(c[$b>>2]|0)-(c[qb>>2]|0);c[va>>2]=(c[gc+((ub*3|0)+3+mb<<2)>>2]|0)-(c[$b>>2]|0);c[wb+(mb<<2)>>2]=c[fc>>2];$b=cc+(rb<<2)|0;c[$b>>2]=c[fc>>2];fc=mb|1;rb=gc+(fc<<2)|0;c[wb+(fc<<2)>>2]=c[rb>>2];fc=cc+(dc<<2)|0;c[fc>>2]=c[rb>>2];rb=mb|2;dc=gc+(rb<<2)|0;c[wb+(rb<<2)>>2]=c[dc>>2];rb=cc+(ib<<2)|0;c[rb>>2]=c[dc>>2];c[wb+(xb<<2)>>2]=c[bc>>2];c[yb>>2]=c[bc>>2];bc=mb+ub|0;mb=gc+(bc<<2)|0;c[wb+(bc<<2)>>2]=c[mb>>2];c[$b>>2]=c[mb>>2];mb=bc+1|0;xb=gc+(mb<<2)|0;c[wb+(mb<<2)>>2]=c[xb>>2];c[fc>>2]=c[xb>>2];xb=bc+2|0;mb=gc+(xb<<2)|0;c[wb+(xb<<2)>>2]=c[mb>>2];c[rb>>2]=c[mb>>2];mb=bc+3|0;xb=gc+(mb<<2)|0;c[wb+(mb<<2)>>2]=c[xb>>2];c[yb>>2]=c[xb>>2];xb=bc+ub|0;bc=gc+(xb<<2)|0;c[wb+(xb<<2)>>2]=c[bc>>2];c[$b>>2]=c[bc>>2];bc=xb+1|0;mb=gc+(bc<<2)|0;c[wb+(bc<<2)>>2]=c[mb>>2];c[fc>>2]=c[mb>>2];mb=xb+2|0;bc=gc+(mb<<2)|0;c[wb+(mb<<2)>>2]=c[bc>>2];c[rb>>2]=c[bc>>2];bc=xb+3|0;mb=gc+(bc<<2)|0;c[wb+(bc<<2)>>2]=c[mb>>2];c[yb>>2]=c[mb>>2];mb=xb+ub|0;ub=gc+(mb<<2)|0;c[wb+(mb<<2)>>2]=c[ub>>2];c[$b>>2]=c[ub>>2];ub=mb+1|0;$b=gc+(ub<<2)|0;c[wb+(ub<<2)>>2]=c[$b>>2];c[fc>>2]=c[$b>>2];$b=mb+2|0;fc=gc+($b<<2)|0;c[wb+($b<<2)>>2]=c[fc>>2];c[rb>>2]=c[fc>>2];fc=mb+3|0;mb=gc+(fc<<2)|0;c[wb+(fc<<2)>>2]=c[mb>>2];c[yb>>2]=c[mb>>2];Ib=0;break d;break};case 6:{mb=c[B>>2]|0;yb=c[E>>2]|0;fc=(c[l>>2]|0)==0;wb=c[(fc?C:D)>>2]|0;gc=db<<2;rb=(ba(mb,Za)|0)+gc|0;$b=wb+(rb<<2)|0;ub=c[(fc?Ca:A)>>2]|0;xb=db<<1;bc=(ba(yb,_a)|0)+xb|0;dc=ub+(bc<<2)|0;ib=c[(fc?fa:$)>>2]|0;cc=ib+(bc<<2)|0;qb=c[aa>>2]|0;Gb=c[I>>2]|0;jb=Gb+(gc<<2)|0;Qb=c[(fc?D:C)>>2]|0;ac=c[(fc?A:Ca)>>2]|0;_b=c[(fc?$:fa)>>2]|0;fc=c[ya>>2]|0;tb=c[Ba>>2]|0;do{if((fc|0)<(tb|0)){pb=(c[Aa>>2]|0)+(fc<<2)|0;ic=c[pb>>2]|0;if((ic|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=ic,v)|0);i=v;jc=0;break}else{c[ya>>2]=fc+1;jc=c[o+2644+(c[pb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=5,c[v+8>>2]=fc,c[v+16>>2]=tb,v)|0);i=v;jc=0}}while(0);tb=c[ya>>2]|0;fc=c[Ba>>2]|0;do{if((tb|0)<(fc|0)){ob=(c[Aa>>2]|0)+(tb<<2)|0;hb=c[ob>>2]|0;if((hb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=hb,v)|0);i=v;kc=0;break}else{c[ya>>2]=tb+1;kc=c[o+2644+(c[ob>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=5,c[v+8>>2]=tb,c[v+16>>2]=fc,v)|0);i=v;kc=0}}while(0);fc=-4-gc|0;tb=c[x>>2]|0;ob=c[tb+120>>2]|0;hb=ob-gc|0;if((jc|0)<(fc|0)){lc=fc}else{lc=(jc|0)>(hb|0)?hb:jc}hb=c[tb+124>>2]|0;fc=hb-Za|0;if((kc|0)<(ab|0)){mc=ab}else{mc=(kc|0)>(fc|0)?fc:kc}fc=lc+gc|0;do{if((fc|0)>=0){Fb=mc+Za|0;if((Fb|0)<0){break}if((fc+4|0)>(ob|0)){break}if((Fb+4|0)>(hb|0)){break}Fb=lc+rb+(ba(mc,mb)|0)|0;nb=(lc>>1)+bc+(ba(mc>>1,yb)|0)|0;vb=(ba(yb,$a)|0)+xb|0;c[cc>>2]=c[_b+(nb<<2)>>2];c[dc>>2]=c[ac+(nb<<2)>>2];lb=nb+1|0;sb=bc|1;c[ib+(sb<<2)>>2]=c[_b+(lb<<2)>>2];c[ub+(sb<<2)>>2]=c[ac+(lb<<2)>>2];lb=bc+yb|0;sb=nb+yb|0;c[ib+(lb<<2)>>2]=c[_b+(sb<<2)>>2];c[ub+(lb<<2)>>2]=c[ac+(sb<<2)>>2];nb=sb+1|0;sb=lb+1|0;c[ib+(sb<<2)>>2]=c[_b+(nb<<2)>>2];c[ub+(sb<<2)>>2]=c[ac+(nb<<2)>>2];nb=yb<<1;sb=-nb|1;lb=sb+yb+vb|0;Bb=ib+(lb<<2)|0;kb=gc|1;pb=Gb+(kb<<2)|0;c[sa>>2]=(c[Bb>>2]|0)-(c[pb>>2]|0);ic=vb+nb+sb|0;sb=ib+(ic<<2)|0;c[V>>2]=(c[sb>>2]|0)-(c[Bb>>2]|0);c[jb>>2]=c[ib+(vb<<2)>>2];c[pb>>2]=c[sb>>2];sb=ub+(lb<<2)|0;lb=gc|2;pb=gc|3;Bb=Gb+(pb<<2)|0;c[X>>2]=(c[sb>>2]|0)-(c[Bb>>2]|0);nb=ub+(ic<<2)|0;c[ra>>2]=(c[nb>>2]|0)-(c[sb>>2]|0);c[Gb+(lb<<2)>>2]=c[ub+(vb<<2)>>2];c[Bb>>2]=c[nb>>2];nb=(ba(mb,bb)|0)+gc|0;c[$b>>2]=c[Qb+(Fb<<2)>>2];c[wb+((rb|1)<<2)>>2]=c[Qb+(Fb+1<<2)>>2];c[wb+((rb|2)<<2)>>2]=c[Qb+(Fb+2<<2)>>2];c[wb+((rb|3)<<2)>>2]=c[Qb+(Fb+3<<2)>>2];Bb=rb+mb|0;vb=Fb+mb|0;c[wb+(Bb<<2)>>2]=c[Qb+(vb<<2)>>2];c[wb+(Bb+1<<2)>>2]=c[Qb+(vb+1<<2)>>2];c[wb+(Bb+2<<2)>>2]=c[Qb+(vb+2<<2)>>2];c[wb+(Bb+3<<2)>>2]=c[Qb+(vb+3<<2)>>2];Fb=Bb+mb|0;Bb=vb+mb|0;c[wb+(Fb<<2)>>2]=c[Qb+(Bb<<2)>>2];c[wb+(Fb+1<<2)>>2]=c[Qb+(Bb+1<<2)>>2];c[wb+(Fb+2<<2)>>2]=c[Qb+(Bb+2<<2)>>2];c[wb+(Fb+3<<2)>>2]=c[Qb+(Bb+3<<2)>>2];vb=Fb+mb|0;Fb=Bb+mb|0;c[wb+(vb<<2)>>2]=c[Qb+(Fb<<2)>>2];c[wb+(vb+1<<2)>>2]=c[Qb+(Fb+1<<2)>>2];c[wb+(vb+2<<2)>>2]=c[Qb+(Fb+2<<2)>>2];c[wb+(vb+3<<2)>>2]=c[Qb+(Fb+3<<2)>>2];Fb=mb<<2;vb=-Fb|3;Bb=wb+(vb+mb+nb<<2)|0;sb=qb+(pb<<2)|0;c[qa>>2]=(c[Bb>>2]|0)-(c[sb>>2]|0);pb=mb<<1;ic=wb+(nb+pb+vb<<2)|0;c[ma>>2]=(c[ic>>2]|0)-(c[Bb>>2]|0);Bb=mb+3|0;vb=wb+(Bb+pb-Fb+nb<<2)|0;c[da>>2]=(c[vb>>2]|0)-(c[ic>>2]|0);ic=mb*3|0;c[va>>2]=(c[wb+(Bb+ic-Fb+nb<<2)>>2]|0)-(c[vb>>2]|0);vb=ic-Fb|0;c[qb+(gc<<2)>>2]=c[wb+(vb+mb+nb<<2)>>2];c[qb+(kb<<2)>>2]=c[wb+(mb+1+vb+nb<<2)>>2];c[qb+(lb<<2)>>2]=c[wb+(mb+2+vb+nb<<2)>>2];c[sb>>2]=c[wb+(vb+Bb+nb<<2)>>2];Ib=0;break d}}while(0);yDb(tb,16,1964456,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;Ib=0;break d;break};default:{yDb(c[x>>2]|0,16,2001600,(v=i,i=i+8|0,c[v>>2]=gb,v)|0);i=v;Ib=cb;break d}}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=6,c[v+8>>2]=eb,c[v+16>>2]=fb,v)|0);i=v;P=109}}while(0);if((P|0)==109){P=0;fb=c[B>>2]|0;eb=c[E>>2]|0;wb=(c[l>>2]|0)==0;mb=c[(wb?C:D)>>2]|0;qb=c[(wb?Ca:A)>>2]|0;gc=c[(wb?fa:$)>>2]|0;wb=c[aa>>2]|0;Qb=c[I>>2]|0;rb=0;do{$b=c[M>>2]|0;ub=c[Ra>>2]|0;do{if(($b|0)<(ub|0)){Gb=(c[Sa>>2]|0)+($b<<2)|0;ib=c[Gb>>2]|0;if((ib|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=ib,v)|0);i=v;nc=0;break}else{c[M>>2]=$b+1;nc=c[o+1364+(c[Gb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=0,c[v+8>>2]=$b,c[v+16>>2]=ub,v)|0);i=v;nc=0}}while(0);c[k+(rb<<2)>>2]=nc;ub=c[M>>2]|0;$b=c[Ra>>2]|0;do{if((ub|0)<($b|0)){gb=(c[Sa>>2]|0)+(ub<<2)|0;tb=c[gb>>2]|0;if((tb|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=tb,v)|0);i=v;oc=0;break}else{c[M>>2]=ub+1;oc=c[o+1364+(c[gb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=0,c[v+8>>2]=ub,c[v+16>>2]=$b,v)|0);i=v;oc=0}}while(0);c[k+(rb+4<<2)>>2]=oc;rb=rb+1|0;}while((rb|0)<4);rb=db<<2;$b=(ba(eb,_a)|0)+(db<<1)|0;ub=Qb+(rb<<2)|0;gb=(c[sa>>2]|0)+(c[u>>2]|0)|0;c[sa>>2]=gb;tb=(c[ub>>2]|0)+gb|0;c[ub>>2]=tb;c[gc+($b<<2)>>2]=tb;tb=(c[sa>>2]|0)+(c[ta>>2]|0)|0;c[sa>>2]=tb;gb=Qb+((rb|1)<<2)|0;Gb=(c[gb>>2]|0)+tb|0;c[gb>>2]=Gb;tb=$b|1;c[gc+(tb<<2)>>2]=Gb;Gb=$b+eb|0;ib=(c[V>>2]|0)+(c[Q>>2]|0)|0;c[V>>2]=ib;jb=(c[ub>>2]|0)+ib|0;c[ub>>2]=jb;c[gc+(Gb<<2)>>2]=jb;jb=(c[V>>2]|0)+(c[W>>2]|0)|0;c[V>>2]=jb;ub=(c[gb>>2]|0)+jb|0;c[gb>>2]=ub;gb=eb+1+$b|0;c[gc+(gb<<2)>>2]=ub;ub=Qb+((rb|2)<<2)|0;jb=(c[X>>2]|0)+(c[Ta>>2]|0)|0;c[X>>2]=jb;ib=(c[ub>>2]|0)+jb|0;c[ub>>2]=ib;c[qb+($b<<2)>>2]=ib;ib=(c[X>>2]|0)+(c[Ua>>2]|0)|0;c[X>>2]=ib;$b=Qb+((rb|3)<<2)|0;jb=(c[$b>>2]|0)+ib|0;c[$b>>2]=jb;c[qb+(tb<<2)>>2]=jb;jb=(c[ra>>2]|0)+(c[Va>>2]|0)|0;c[ra>>2]=jb;tb=(c[ub>>2]|0)+jb|0;c[ub>>2]=tb;c[qb+(Gb<<2)>>2]=tb;tb=(c[ra>>2]|0)+(c[Wa>>2]|0)|0;c[ra>>2]=tb;Gb=(c[$b>>2]|0)+tb|0;c[$b>>2]=Gb;c[qb+(gb<<2)>>2]=Gb;Gb=0;do{gb=c[U>>2]|0;$b=c[ca>>2]|0;do{if((gb|0)<($b|0)){tb=(c[ja>>2]|0)+(gb<<2)|0;ub=c[tb>>2]|0;if((ub|0)>63){yDb(c[x>>2]|0,16,1912816,(v=i,i=i+8|0,c[v>>2]=ub,v)|0);i=v;pc=0;break}else{c[U>>2]=gb+1;pc=c[o+1876+(c[tb>>2]<<2)>>2]|0;break}}else{yDb(c[x>>2]|0,16,1936376,(v=i,i=i+24|0,c[v>>2]=2,c[v+8>>2]=gb,c[v+16>>2]=$b,v)|0);i=v;pc=0}}while(0);c[k+(Gb<<2)>>2]=pc;Gb=Gb+1|0;}while((Gb|0)<16);f$a(o,mb+((ba(fb,Za)|0)+rb<<2)|0,fb,u,wb+(rb<<2)|0);Ib=cb}Gb=db+1|0;if((Gb|0)<(t|0)){cb=Ib;db=Gb}else{qc=Ib;break}}}else{qc=Xa}db=Ya+1|0;if((db|0)<(z|0)){Xa=qc;Ya=db}else{rc=qc;sc=l;break}}}else{rc=1;sc=n+3252|0}l=(c[sc>>2]|0)==0;if((m|0)<=0){Qa=rc;break}Ya=(_|0)>0;Xa=_-1|0;u=_+1|0;U=_+2|0;ja=_+3|0;ca=n+3244|0;ra=s+32|0;Wa=m-1|0;Va=q-1|0;X=q+1|0;Ua=n+3248|0;Ta=c[(l?n+3220|0:n+3232|0)>>2]|0;V=c[(l?n+3224|0:n+3236|0)>>2]|0;W=c[(l?n+3228|0:n+3240|0)>>2]|0;l=c[s>>2]|0;Q=0;while(1){if(Ya){sa=0;do{ta=c[Ta+(sa<<2)>>2]|0;Sa=sa>>1;Ra=c[V+(Sa<<2)>>2]|0;I=(c[W+(Sa<<2)>>2]|0)+ta|0;if(I>>>0>255>>>0){tc=-I>>31&255}else{tc=I&255}I=sa*3|0;a[l+I|0]=tc;if(ta>>>0>255>>>0){uc=-ta>>31&255}else{uc=ta&255}a[l+(I+1)|0]=uc;Sa=Ra+ta|0;if(Sa>>>0>255>>>0){vc=-Sa>>31&255}else{vc=Sa&255}a[l+(I+2)|0]=vc;sa=sa+1|0;}while((sa|0)<(_|0))}sa=c[Ta>>2]|0;c[Ta-4>>2]=sa;c[Ta-8>>2]=sa;c[Ta-12>>2]=sa;I=Ta-16|0;c[I>>2]=sa;sa=c[Ta+(Xa<<2)>>2]|0;c[Ta+(_<<2)>>2]=sa;c[Ta+(u<<2)>>2]=sa;c[Ta+(U<<2)>>2]=sa;c[Ta+(ja<<2)>>2]=sa;do{if((Q|0)==0){sa=c[ca>>2]|0;Sa=I;UGb(Ta+(-4-sa<<2)|0,Sa|0,sa)|0;sa=c[ca>>2]|0;UGb(Ta+(-4-(sa<<1)<<2)|0,Sa|0,sa)|0;sa=c[ca>>2]|0;UGb(Ta+((sa*-3|0)-4<<2)|0,Sa|0,sa)|0;sa=c[ca>>2]|0;UGb(Ta+(-4-(sa<<2)<<2)|0,Sa|0,sa)|0;wc=W;xc=V;yc=Ta+(c[ca>>2]<<2)|0}else{sa=(Q|0)==(Wa|0);if(sa){Sa=c[ca>>2]|0;ta=I;UGb(Ta+(Sa-4<<2)|0,ta|0,Sa)|0;Sa=c[ca>>2]|0;UGb(Ta+((Sa<<1)-4<<2)|0,ta|0,Sa)|0;Sa=c[ca>>2]|0;UGb(Ta+((Sa*3|0)-4<<2)|0,ta|0,Sa)|0;Sa=c[ca>>2]|0;UGb(Ta+((Sa<<2)-4<<2)|0,ta|0,Sa)|0}Sa=Ta+(c[ca>>2]<<2)|0;if((Q&1|0)==0){wc=W;xc=V;yc=Sa;break}ta=c[V>>2]|0;c[V-4>>2]=ta;Ra=V-8|0;c[Ra>>2]=ta;ta=c[W>>2]|0;c[W-4>>2]=ta;aa=W-8|0;c[aa>>2]=ta;ta=c[V+(Va<<2)>>2]|0;c[V+(q<<2)>>2]=ta;c[V+(X<<2)>>2]=ta;ta=c[W+(Va<<2)>>2]|0;c[W+(q<<2)>>2]=ta;c[W+(X<<2)>>2]=ta;do{if((Q|0)==1){ta=c[Ua>>2]|0;$=Ra;UGb(V+(-2-ta<<2)|0,$|0,ta)|0;ta=c[Ua>>2]|0;fa=aa;UGb(W+(-2-ta<<2)|0,fa|0,ta)|0;ta=c[Ua>>2]|0;UGb(V+(-2-(ta<<1)<<2)|0,$|0,ta)|0;ta=c[Ua>>2]|0;UGb(W+(-2-(ta<<1)<<2)|0,fa|0,ta)|0}else{if(!sa){break}ta=c[Ua>>2]|0;fa=Ra;UGb(V+(ta-2<<2)|0,fa|0,ta)|0;ta=c[Ua>>2]|0;$=aa;UGb(W+(ta-2<<2)|0,$|0,ta)|0;ta=c[Ua>>2]|0;UGb(V+((ta<<1)-2<<2)|0,fa|0,ta)|0;ta=c[Ua>>2]|0;UGb(W+((ta<<1)-2<<2)|0,$|0,ta)|0}}while(0);aa=c[Ua>>2]|0;wc=W+(aa<<2)|0;xc=V+(aa<<2)|0;yc=Sa}}while(0);I=Q+1|0;if((I|0)<(m|0)){Ta=yc;V=xc;W=wc;l=l+(c[ra>>2]|0)|0;Q=I}else{Qa=rc;break}}}}while(0);c[s+84>>2]=Qa;c[s+88>>2]=(Qa|0)==0?2:1;m=n+3252|0;c[m>>2]=(c[m>>2]|0)==0;c[g>>2]=1;m=MCb(f,c[r>>2]|0)|0;w=(m|0)<0?m:h;i=j;return w|0}}while(0);if((P|0)==91){yDb(c[x>>2]|0,16,2305336,(v=i,i=i+24|0,c[v>>2]=Na,c[v+8>>2]=T,c[v+16>>2]=Ma,v)|0);i=v;ga=-1094995529;ha=c[S>>2]|0}TGb(c[n+1280+(ha<<2)>>2]|0,0,c[n+1308+(ha<<2)>>2]<<2|0)|0;w=ga;i=j;return w|0}function e$a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;ZDb(c[b+3188>>2]|0);ZDb(c[b+3192>>2]|0);ZDb(c[b+1280>>2]|0);ZDb(c[b+1284>>2]|0);ZDb(c[b+1288>>2]|0);ZDb(c[b+1292>>2]|0);ZDb(c[b+1296>>2]|0);ZDb(c[b+1300>>2]|0);ZDb(c[b+1304>>2]|0);if((c[b+3220>>2]|0)==0){d=b+1272|0;$Db(d);e=b+1276|0;f=e;c[f>>2]=0;g=b+4|0;h=g;JCb(h);return 0}ZDb(c[b+3196>>2]|0);ZDb(c[b+3200>>2]|0);ZDb(c[b+3204>>2]|0);ZDb(c[b+3208>>2]|0);ZDb(c[b+3212>>2]|0);ZDb(c[b+3216>>2]|0);d=b+1272|0;$Db(d);e=b+1276|0;f=e;c[f>>2]=0;g=b+4|0;h=g;JCb(h);return 0}function f$a(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=b;b=0;while(1){h=a+3156+(b<<2)|0;i=b<<2;j=(c[e+(i<<2)>>2]|0)+(c[h>>2]|0)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}c[g>>2]=l&255;k=(c[e+((i|1)<<2)>>2]|0)+j|0;j=f+4|0;m=(c[j>>2]|0)+k|0;c[j>>2]=m;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}c[g+4>>2]=n&255;m=(c[e+((i|2)<<2)>>2]|0)+k|0;k=f+8|0;j=(c[k>>2]|0)+m|0;c[k>>2]=j;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}c[g+8>>2]=o&255;j=(c[e+((i|3)<<2)>>2]|0)+m|0;m=f+12|0;i=(c[m>>2]|0)+j|0;c[m>>2]=i;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}c[g+12>>2]=p&255;c[h>>2]=j;j=b+1|0;if((j|0)<4){g=g+(d<<2)|0;b=j}else{break}}return}function g$a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=c[f+4>>2]|0;if((h|0)<(e|0)){yDb(c[a>>2]|0,16,2229336,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;k=-1094995529;i=g;return k|0}h=a+16|0;l=c[h>>2]|0;m=c[a+8>>2]|0;n=d[m+(l>>>3)|0]|0;o=c[a+24>>2]|0;p=((l|0)<(o|0))+l|0;c[h>>2]=p;if((n&128>>>((l&7)>>>0)|0)!=0){l=b<<1;n=e+1|0;q=g$a(a,l,n,f)|0;if((q|0)<0){k=q;i=g;return k|0}else{q=g$a(a,l|1,n,f)|0;i=g;return((q|0)<0?q:0)|0}}q=(e|0)==0?1:e;e=f+16|0;if((c[e>>2]|0)>=(c[f+20>>2]|0)){yDb(c[a>>2]|0,48,2217568,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=g;return k|0}j=c[f>>2]|0;do{if((j|0)==0){r=0}else{a=m+(p>>>3)|0;n=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(p&7);if((j|0)<26){a=j+p|0;c[h>>2]=o>>>0>a>>>0?a:o;r=n>>>((32-j|0)>>>0);break}else{a=p+16|0;l=o>>>0>a>>>0?a:o;c[h>>2]=l;a=j-16|0;s=m+(l>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(l&7)>>>((48-j|0)>>>0);s=l+a|0;c[h>>2]=o>>>0>s>>>0?s:o;r=t|n>>>16<<a;break}}}while(0);c[(c[f+24>>2]|0)+(c[e>>2]<<2)>>2]=r;c[(c[f+28>>2]|0)+(c[e>>2]<<2)>>2]=b;c[(c[f+32>>2]|0)+(c[e>>2]<<2)>>2]=q;c[e>>2]=(c[e>>2]|0)+1;k=0;i=g;return k|0}function h$a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+416>>2]|0;if((d|0)==1){e=c[a+60>>2]|0;f=a+448|0;c[f>>2]=4;c[f+4>>2]=0;c[a+420>>2]=1;Z3(e,a);g=0;i=b;return g|0}else{DDb(a,2103600,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;g=-1163346256;i=b;return g|0}return 0}function i$a(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0;h=i;i=i+448|0;j=h|0;k=h+416|0;l=h+432|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[a+60>>2]|0;o=g;p=(n|0)/32|0;if(!((n+31|0)>>>0>62>>>0)){yDb(a,16,218e4,(q=i,i=i+8|0,c[q>>2]=n,q)|0);i=q;r=-1;i=h;return r|0}c[e+76>>2]=p*240|0;q=_$a(a,e,0)|0;if((q|0)<0){r=q;i=h;return r|0}q=c[e>>2]|0;TGb(q|0,0,p*480|0|0)|0;if((n|0)>31){e=g+1096|0;a=g+1248|0;s=a;t=(a|0)==0?8:264;a=g+1294|0;u=g+1292|0;v=t>>>0>9>>>0?9:t;w=g+1290|0;x=(v>>>3)+(o+1248)|0;y=v&1;z=v|4;v=t>>>0>z>>>0?z:t;z=g+1288|0;A=(v>>>3)+(o+1248)|0;B=v&5;C=v+4|0;v=t>>>0>C>>>0?C:t;C=g+1286|0;D=(v>>>3)+(o+1248)|0;E=v&7;F=v+4|0;v=t>>>0>F>>>0?F:t;F=g+1284|0;G=(v>>>3)+(o+1248)|0;H=v&7;I=v+5|0;v=t>>>0>I>>>0?I:t;I=g+1282|0;J=(v>>>3)+(o+1248)|0;K=v&7;L=v+5|0;v=t>>>0>L>>>0?L:t;L=g+1280|0;M=(v>>>3)+(o+1248)|0;N=v&7;O=((v|0)<(t|0))+v|0;v=g+1368|0;P=(O>>>3)+(o+1248)|0;Q=O&7;R=O+4|0;O=t>>>0>R>>>0?R:t;R=g+1296|0;S=(O>>>3)+(o+1248)|0;T=O&7;U=O+7|0;O=t>>>0>U>>>0?U:t;U=g+1316|0;V=(O>>>3)+(o+1248)|0;W=O&7;X=O+7|0;O=t>>>0>X>>>0?X:t;X=g+1312|0;Y=(O>>>3)+(o+1248)|0;Z=O&7;_=O+7|0;O=t>>>0>_>>>0?_:t;_=g+1308|0;$=(O>>>3)+(o+1248)|0;aa=O&7;ca=O+7|0;O=t>>>0>ca>>>0?ca:t;ca=g+1304|0;da=(O>>>3)+(o+1248)|0;ea=O&7;fa=O+4|0;O=t>>>0>fa>>>0?fa:t;fa=g+1300|0;ga=(O>>>3)+(o+1248)|0;ha=O&7;ia=O+14|0;O=t>>>0>ia>>>0?ia:t;ia=g+1356|0;ja=(O>>>3)+(o+1248)|0;ka=O&7;la=O+14|0;O=t>>>0>la>>>0?la:t;la=g+1352|0;ma=(O>>>3)+(o+1248)|0;na=O&7;oa=O+4|0;O=t>>>0>oa>>>0?oa:t;oa=(O>>>3)+(o+1248)|0;pa=O&7;qa=O+14|0;O=t>>>0>qa>>>0?qa:t;qa=g+1364|0;ra=(O>>>3)+(o+1248)|0;sa=O&7;ta=O+14|0;O=t>>>0>ta>>>0?ta:t;ta=g+1360|0;ua=(O>>>3)+(o+1248)|0;va=O&7;wa=((O|0)<(t|0))+O|0;O=(wa>>>3)+(o+1248)|0;xa=wa&7;ya=wa+16|0;wa=t>>>0>ya>>>0?ya:t;ya=(wa>>>3)+(o+1248)|0;za=wa&7;Aa=wa+11|0;wa=t>>>0>Aa>>>0?Aa:t;Aa=g+1336|0;Ba=(wa>>>3)+(o+1248)|0;Ca=wa&7;Da=wa+4|0;wa=t>>>0>Da>>>0?Da:t;Da=g+1320|0;Ea=(wa>>>3)+(o+1248)|0;Fa=wa&7;Ga=((wa|0)<(t|0))+wa|0;wa=(Ga>>>3)+(o+1248)|0;Ha=Ga&7;Ia=Ga+16|0;Ga=t>>>0>Ia>>>0?Ia:t;Ia=(Ga>>>3)+(o+1248)|0;Ja=Ga&7;Ka=Ga+11|0;Ga=t>>>0>Ka>>>0?Ka:t;Ka=g+1340|0;La=(Ga>>>3)+(o+1248)|0;Ma=Ga&7;Na=Ga+4|0;Ga=t>>>0>Na>>>0?Na:t;Na=g+1324|0;Oa=(Ga>>>3)+(o+1248)|0;Pa=Ga&7;Qa=((Ga|0)<(t|0))+Ga|0;Ga=(Qa>>>3)+(o+1248)|0;Ra=Qa&7;Sa=Qa+16|0;Qa=t>>>0>Sa>>>0?Sa:t;Sa=(Qa>>>3)+(o+1248)|0;Ta=Qa&7;Ua=Qa+11|0;Qa=t>>>0>Ua>>>0?Ua:t;Ua=g+1344|0;Va=(Qa>>>3)+(o+1248)|0;Wa=Qa&7;Xa=Qa+4|0;Qa=t>>>0>Xa>>>0?Xa:t;Xa=g+1328|0;Ya=(Qa>>>3)+(o+1248)|0;Za=Qa&7;_a=((Qa|0)<(t|0))+Qa|0;Qa=(_a>>>3)+(o+1248)|0;$a=_a&7;ab=_a+16|0;_a=t>>>0>ab>>>0?ab:t;ab=(_a>>>3)+(o+1248)|0;bb=_a&7;cb=_a+11|0;_a=t>>>0>cb>>>0?cb:t;t=g+1348|0;cb=(_a>>>3)+(o+1248)|0;db=_a&7;_a=g+1332|0;eb=l;fb=g+2036|0;gb=fb;hb=g+2038|0;ib=g+2040|0;jb=g+2042|0;kb=g+2044|0;lb=g+2046|0;mb=g+2048|0;nb=g+2050|0;ob=g+2052|0;pb=g+1956|0;qb=g+2176|0;rb=g+2192|0;sb=g+1960|0;tb=g+2178|0;ub=g+2194|0;vb=g+1964|0;wb=g+2180|0;xb=g+2196|0;yb=g+1968|0;zb=g+2182|0;Ab=g+2198|0;Bb=g+1972|0;Cb=g+2184|0;Db=g+2200|0;Eb=g+1976|0;Fb=g+2186|0;Gb=g+2202|0;Hb=g+1980|0;Ib=g+2188|0;Jb=g+2204|0;Kb=g+1984|0;Lb=g+2190|0;Mb=g+2206|0;Nb=g+2208|0;Ob=g+2224|0;Pb=g+2210|0;Qb=g+2226|0;Rb=g+2212|0;Sb=g+2228|0;Tb=g+2214|0;Ub=g+2230|0;Vb=g+2216|0;Wb=g+2232|0;Xb=g+2218|0;Yb=g+2234|0;Zb=g+2220|0;_b=g+2236|0;$b=g+2222|0;ac=g+2238|0;bc=g+2056|0;cc=k+12|0;dc=k+10|0;ec=k+8|0;fc=k+6|0;gc=k+4|0;hc=k+2|0;ic=k|0;k=g+1372|0;jc=g+1612|0;kc=g+1988|0;lc=g+2e3|0;mc=g+1990|0;nc=g+1992|0;oc=g+1994|0;pc=g+1996|0;qc=g+1998|0;rc=g+2002|0;sc=g+2004|0;tc=g+2016|0;uc=g+2006|0;vc=g+2008|0;wc=g+2010|0;xc=g+2012|0;yc=g+2014|0;zc=g+2018|0;Ac=g+2020|0;Bc=g+2022|0;Cc=g+2024|0;Dc=g+2026|0;Ec=g+2028|0;Fc=g+2030|0;Gc=g+2032|0;Hc=g+2034|0;g=0;Ic=q;q=m;while(1){Xe[c[e>>2]&4095](s,q,8);m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;b[a>>1]=b[182040+((m>>>5&7)<<1)>>1]|0;b[u>>1]=b[182056+((m>>>2&7)<<1)>>1]|0;b[w>>1]=b[182072+(((fe(m|0)|0)>>>23&7)<<1)>>1]|0;b[z>>1]=b[182088+((fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<y>>>28<<1)>>1]|0;b[C>>1]=b[182120+((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<B>>>28<<1)>>1]|0;b[F>>1]=b[182152+((fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<E>>>28<<1)>>1]|0;b[I>>1]=b[182184+((fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<H>>>27<<1)>>1]|0;b[L>>1]=b[182248+((fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<K>>>27<<1)>>1]|0;c[v>>2]=d[M]<<N>>>7&1;m=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<Q>>>28<<4;c[R>>2]=m;c[U>>2]=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<T>>>25;c[X>>2]=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<W>>>25;c[_>>2]=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<Z>>>25;c[ca>>2]=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<aa>>>25;Jc=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<ea>>>28;c[fa>>2]=Jc;c[ia>>2]=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<ha>>>18;c[la>>2]=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<ka>>>18;c[fa>>2]=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<na>>>28<<4|Jc;c[qa>>2]=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<pa>>>18;c[ta>>2]=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<sa>>>18;Jc=d[ua]<<va>>>7&1|m;c[R>>2]=Jc;m=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<xa>>>16;c[Aa>>2]=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<za>>>21|m<<11;c[Da>>2]=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<Ca>>>28;m=d[Ea]<<Fa>>>7<<1&2|Jc;c[R>>2]=m;Jc=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<Ha>>>16;c[Ka>>2]=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<Ja>>>21|Jc<<11;c[Na>>2]=(fe(d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0)|0)<<Ma>>>28;Jc=d[Oa]<<Pa>>>7<<2&4|m;c[R>>2]=Jc;m=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<Ra>>>16;c[Ua>>2]=(fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<Ta>>>21|m<<11;c[Xa>>2]=(fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<Wa>>>28;c[R>>2]=d[Ya]<<Za>>>7<<3&8|Jc;Jc=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<$a>>>16;c[t>>2]=(fe(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<bb>>>21|Jc<<11;c[_a>>2]=(fe(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<db>>>28;Jc=0;do{if((Jc|0)>0){UGb(eb|0,fb|0,Jc<<1)|0;m=Jc-1|0;Kc=o+1280+(Jc<<1)|0;Lc=0;while(1){Mc=ba(b[Kc>>1]|0,b[l+(m-Lc<<1)>>1]|0)|0;Nc=o+2036+(Lc<<1)|0;b[Nc>>1]=(Mc+16384+(b[Nc>>1]<<15)|0)>>>15;Nc=Lc+1|0;if((Nc|0)<(Jc|0)){Lc=Nc}else{Oc=Kc;break}}}else{Oc=o+1280+(Jc<<1)|0}b[o+2036+(Jc<<1)>>1]=(8-(b[Oc>>1]|0)|0)>>>3;Jc=Jc+1|0;}while((Jc|0)<8);Jc=q+32|0;Kc=((b[gb>>1]|0)*32571|0)>>>15&65535;b[gb>>1]=Kc;Lc=((b[hb>>1]|0)*32376|0)>>>15&65535;b[hb>>1]=Lc;m=((b[ib>>1]|0)*32182|0)>>>15&65535;b[ib>>1]=m;Nc=((b[jb>>1]|0)*31989|0)>>>15&65535;b[jb>>1]=Nc;Mc=((b[kb>>1]|0)*31797|0)>>>15&65535;b[kb>>1]=Mc;Pc=((b[lb>>1]|0)*31606|0)>>>15&65535;b[lb>>1]=Pc;Qc=((b[mb>>1]|0)*31416|0)>>>15&65535;b[mb>>1]=Qc;Rc=((b[nb>>1]|0)*31228|0)>>>15&65535;b[nb>>1]=Rc;c[ob>>2]=b[L>>1]|0;if((c[v>>2]|0)==0){Sc=c[pb>>2]&65535;b[qb>>1]=Sc;b[rb>>1]=Sc;Sc=c[sb>>2]&65535;b[tb>>1]=Sc;b[ub>>1]=Sc;Sc=c[vb>>2]&65535;b[wb>>1]=Sc;b[xb>>1]=Sc;Sc=c[yb>>2]&65535;b[zb>>1]=Sc;b[Ab>>1]=Sc;Sc=c[Bb>>2]&65535;b[Cb>>1]=Sc;b[Db>>1]=Sc;Sc=c[Eb>>2]&65535;b[Fb>>1]=Sc;b[Gb>>1]=Sc;Sc=c[Hb>>2]&65535;b[Ib>>1]=Sc;b[Jb>>1]=Sc;Sc=c[Kb>>2]&65535;b[Lb>>1]=Sc;b[Mb>>1]=Sc;Tc=Kc;Uc=Lc;Vc=m;Wc=Nc;Xc=Mc;Yc=Pc;Zc=Qc;_c=Rc}else{Rc=0;do{Qc=b[o+2036+(Rc<<1)>>1]|0;Pc=o+1956+(Rc<<2)|0;b[o+2176+(Rc<<1)>>1]=(((c[Pc>>2]|0)*10923|0)+16384+(Qc*21846|0)|0)>>>15;b[o+2176+(Rc+8<<1)>>1]=((Qc*10923|0)+16384+((c[Pc>>2]|0)*21846|0)|0)>>>15;Rc=Rc+1|0;}while((Rc|0)<8);Tc=b[gb>>1]|0;Uc=b[hb>>1]|0;Vc=b[ib>>1]|0;Wc=b[jb>>1]|0;Xc=b[kb>>1]|0;Yc=b[lb>>1]|0;Zc=b[mb>>1]|0;_c=b[nb>>1]|0}b[Nb>>1]=Tc;b[Ob>>1]=Tc;b[Pb>>1]=Uc;b[Qb>>1]=Uc;b[Rb>>1]=Vc;b[Sb>>1]=Vc;b[Tb>>1]=Wc;b[Ub>>1]=Wc;b[Vb>>1]=Xc;b[Wb>>1]=Xc;b[Xb>>1]=Yc;b[Yb>>1]=Yc;b[Zb>>1]=Zc;b[_b>>1]=Zc;b[$b>>1]=_c;b[ac>>1]=_c;Rc=0;Pc=Ic;while(1){Qc=c[o+1304+(Rc<<2)>>2]|0;if((Qc|0)==127){TGb(bc|0,0,120)|0}else{Mc=0;do{b[j+(Mc<<1)>>1]=c[o+1372+(Mc<<2)>>2];Mc=Mc+1|0;}while((Mc|0)<146);Mc=((Qc|0)/25|0)+18+(c[o+1296+(Rc>>1<<2)>>2]|0)|0;if((Mc|0)<0){$c=0}else{$c=(Mc|0)>145?145:Mc}Mc=((Qc|0)%25|0)<<1;Nc=b[181936+(Mc<<1)>>1]|0;m=b[181936+((Mc|1)<<1)>>1]|0;Mc=0;Lc=j+(145-$c<<1)|0;do{Kc=ba(b[Lc>>1]|0,Nc)|0;Lc=Lc+2|0;Sc=(Kc+8192+(ba(b[Lc>>1]|0,m)|0)|0)>>>14&65535;b[o+2056+(Mc<<1)>>1]=Sc;b[j+(Mc+146<<1)>>1]=Sc;Mc=Mc+1|0;}while((Mc|0)<60)}TGb(Pc|0,0,120)|0;Mc=o+1352+(Rc<<2)|0;m=c[o+1320+(Rc<<2)>>2]<<2;Lc=c[Mc>>2]|0;b[cc>>1]=b[181808+((Lc&3|m)<<1)>>1]|0;b[dc>>1]=b[181808+((Lc>>>2&3|m)<<1)>>1]|0;b[ec>>1]=b[181808+((Lc>>>4&3|m)<<1)>>1]|0;b[fc>>1]=b[181808+((Lc>>>6&3|m)<<1)>>1]|0;b[gc>>1]=b[181808+((Lc>>>8&3|m)<<1)>>1]|0;b[hc>>1]=b[181808+((Lc>>>10&3|m)<<1)>>1]|0;b[ic>>1]=b[181808+((Lc>>>12&3|m)<<1)>>1]|0;c[Mc>>2]=Lc>>14;Lc=c[o+1336+(Rc<<2)>>2]|0;Mc=0;m=3;Nc=181628;Qc=ic;Sc=Lc>>15;while(1){Kc=b[Nc>>1]|0;if((Sc|0)<(Kc|0)){b[Pc+(Mc<<1)>>1]=b[Qc>>1]|0;ad=Sc;bd=Qc+2|0;cd=Nc+62|0;dd=m-1|0}else{ad=Sc-Kc|0;bd=Qc;cd=Nc+2|0;dd=m}Kc=Mc+1|0;if((Kc|0)<30&(dd|0)>0){Mc=Kc;m=dd;Nc=cd;Qc=bd;Sc=ad}else{break}}Sc=30;Qc=4;Nc=181568;m=bd;Mc=Lc&32767;while(1){Kc=b[Nc>>1]|0;if((Mc|0)<(Kc|0)){b[Pc+(Sc<<1)>>1]=b[m>>1]|0;ed=Mc;fd=m+2|0;gd=Nc+62|0;hd=Qc-1|0}else{ed=Mc-Kc|0;fd=m;gd=Nc+2|0;hd=Qc}Kc=Sc+1|0;if((Kc|0)<60&(hd|0)>0){Sc=Kc;Qc=hd;Nc=gd;m=fd;Mc=ed}else{break}}VGb(k|0,jc|0,344)|0;Mc=0;do{m=Pc+(Mc<<1)|0;Nc=b[m>>1]|0;Qc=o+2056+(Mc<<1)|0;Sc=b[Qc>>1]|0;c[o+1372+(Mc+86<<2)>>2]=Sc+(Nc<<16>>16)-(Sc>>3);b[m>>1]=(b[Qc>>1]|0)+Nc;Mc=Mc+1|0;}while((Mc|0)<60);Mc=Rc<<3;Nc=o+2176+(Mc<<1)|0;Qc=o+2176+((Mc|1)<<1)|0;m=o+2176+((Mc|2)<<1)|0;Sc=o+2176+((Mc|3)<<1)|0;Lc=o+2176+((Mc|4)<<1)|0;Kc=o+2176+((Mc|5)<<1)|0;id=o+2176+((Mc|6)<<1)|0;jd=o+2176+((Mc|7)<<1)|0;Mc=0;kd=b[kc>>1]|0;ld=b[mc>>1]|0;md=b[nc>>1]|0;nd=b[oc>>1]|0;od=b[pc>>1]|0;pd=b[qc>>1]|0;qd=b[lc>>1]|0;rd=b[rc>>1]|0;do{sd=ba(b[Nc>>1]|0,kd<<16>>16)|0;td=ba(b[Qc>>1]|0,ld<<16>>16)|0;ud=ba(b[m>>1]|0,md<<16>>16)|0;vd=ba(b[Sc>>1]|0,nd<<16>>16)|0;wd=ba(b[Lc>>1]|0,od<<16>>16)|0;xd=ba(b[Kc>>1]|0,pd<<16>>16)|0;yd=ba(b[id>>1]|0,qd<<16>>16)|0;zd=ba(b[jd>>1]|0,rd<<16>>16)|0;Ad=Pc+(Mc<<1)|0;Bd=sd+2048+td+ud+vd+wd+xd+yd+zd+(b[Ad>>1]<<12)>>12;if((Bd|0)<-32766){Cd=-32766}else{Cd=(Bd|0)>32766?32766:Bd&65535}b[Ad>>1]=Cd;rd=b[lc>>1]|0;b[rc>>1]=rd;qd=b[qc>>1]|0;b[lc>>1]=qd;pd=b[pc>>1]|0;b[qc>>1]=pd;od=b[oc>>1]|0;b[pc>>1]=od;nd=b[nc>>1]|0;b[oc>>1]=nd;md=b[mc>>1]|0;b[nc>>1]=md;ld=b[kc>>1]|0;b[mc>>1]=ld;kd=b[Ad>>1]|0;b[kc>>1]=kd;Mc=Mc+1|0;}while((Mc|0)<60);Mc=((b[Nc>>1]|0)*18022|0)>>15;kd=((b[Qc>>1]|0)*9912|0)>>15;ld=((b[m>>1]|0)*5452|0)>>15;md=((b[Sc>>1]|0)*2998|0)>>15;nd=((b[Lc>>1]|0)*1649|0)>>15;od=((b[Kc>>1]|0)*907|0)>>15;pd=((b[id>>1]|0)*499|0)>>15;qd=((b[jd>>1]|0)*274|0)>>15;rd=0;do{Ad=b[sc>>1]|0;Bd=b[uc>>1]|0;zd=ba(Bd<<16>>16,kd)|0;yd=b[vc>>1]|0;xd=ba(yd<<16>>16,ld)|0;wd=b[wc>>1]|0;vd=ba(wd<<16>>16,md)|0;ud=b[xc>>1]|0;td=ba(ud<<16>>16,nd)|0;sd=b[yc>>1]|0;Dd=ba(sd<<16>>16,od)|0;Ed=b[tc>>1]|0;Fd=ba(Ed<<16>>16,pd)|0;Gd=ba(b[zc>>1]|0,qd)|0;b[zc>>1]=Ed;b[tc>>1]=sd;b[yc>>1]=ud;b[xc>>1]=wd;b[wc>>1]=yd;b[vc>>1]=Bd;b[uc>>1]=Ad;Bd=ba(Ad<<16>>16,Mc)|0;Ad=Pc+(rd<<1)|0;b[sc>>1]=b[Ad>>1]|0;b[Ad>>1]=((b[Ad>>1]<<12)-(zd+Bd+xd+vd+td+Dd+Fd+Gd)|0)>>>12;rd=rd+1|0;}while((rd|0)<60);rd=((b[Nc>>1]|0)*24576|0)>>15;Mc=((b[Qc>>1]|0)*18432|0)>>15;qd=((b[m>>1]|0)*13824|0)>>15;pd=((b[Sc>>1]|0)*10368|0)>>15;od=((b[Lc>>1]|0)*7776|0)>>15;nd=((b[Kc>>1]|0)*5832|0)>>15;md=((b[id>>1]|0)*4374|0)>>15;ld=((b[jd>>1]|0)*3281|0)>>15;kd=c[ob>>2]|0;Gd=kd-(kd>>2)|0;kd=0;do{Fd=Pc+(kd<<1)|0;Dd=b[Fd>>1]<<12;td=b[Ac>>1]|0;vd=td<<16>>16;xd=ba(vd,rd)|0;Bd=b[Bc>>1]|0;zd=ba(Bd<<16>>16,Mc)|0;Ad=b[Cc>>1]|0;yd=ba(Ad<<16>>16,qd)|0;wd=b[Dc>>1]|0;ud=ba(wd<<16>>16,pd)|0;sd=b[Ec>>1]|0;Ed=ba(sd<<16>>16,od)|0;Hd=b[Fc>>1]|0;Id=ba(Hd<<16>>16,nd)|0;Jd=b[Gc>>1]|0;Kd=ba(Jd<<16>>16,md)|0;Ld=ba(b[Hc>>1]|0,ld)|0;b[Hc>>1]=Jd;b[Gc>>1]=Hd;b[Fc>>1]=sd;b[Ec>>1]=wd;b[Dc>>1]=Ad;b[Cc>>1]=Bd;b[Bc>>1]=td;td=xd+Dd+zd+yd+ud+Ed+Id+Kd+Ld|0;Ld=td+2048>>12;if((Ld|0)<-32766){Md=-32766}else{Md=(Ld|0)>32766?32766:Ld&65535}b[Ac>>1]=Md;Ld=((ba(Gd,vd)|0)>>4)+td|0;td=Ld+2048-(Ld>>3)>>12;if((td|0)<-32766){Nd=-32766}else{Nd=(td|0)>32766?32766:td&65535}b[Fd>>1]=Nd;kd=kd+1|0;}while((kd|0)<60);kd=Rc+1|0;if((kd|0)<4){Rc=kd;Pc=Pc+120|0}else{break}}c[pb>>2]=b[gb>>1]|0;c[sb>>2]=b[hb>>1]|0;c[vb>>2]=b[ib>>1]|0;c[yb>>2]=b[jb>>1]|0;c[Bb>>2]=b[kb>>1]|0;c[Eb>>2]=b[lb>>1]|0;c[Hb>>2]=b[mb>>1]|0;c[Kb>>2]=b[nb>>1]|0;Pc=g+1|0;if((Pc|0)<(p|0)){g=Pc;Ic=Ic+480|0;q=Jc}else{break}}}c[f>>2]=1;r=n;i=h;return r|0}function j$a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;e=a+124|0;c[d+32>>2]=c[e>>2];f=d+36|0;g=f;TGb(f|0,0,56)|0;f=c[a+792>>2]|0;if((f|0)==24){c[a+140>>2]=3}else if((f|0)==32){c[a+140>>2]=30}else if((f|0)==16){c[a+140>>2]=46}else if((f|0)==8){c[a+140>>2]=11}else{yDb(a,16,1936336,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;j=-1163346256;i=b;return j|0}c[d+8>>2]=f;k=c[a+120>>2]|0;l=(k*3|0)+2+((ba(k,f)|0)+7>>3)|0;f=(ba(l,c[e>>2]|0)|0)+2|0;c[d+12>>2]=f;do{if((f|0)!=0){e=WDb(f)|0;c[d+16>>2]=e;if((e|0)!=0){break}yDb(a,16,1912776,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-12;i=b;return j|0}}while(0);c[d+68>>2]=0;c[d+72>>2]=0;c[d+76>>2]=0;f=Qd(g|0,1892336,56)|0;if((f|0)==0){c[d+4>>2]=ICb()|0;j=0;i=b;return j|0}else{yDb(a,16,2349992,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;j=-1313558101;i=b;return j|0}return 0}function k$a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=c[e+24>>2]|0;h=c[e+28>>2]|0;j=c[a+60>>2]|0;k=c[j+4>>2]|0;l=$$a(a,k)|0;if((l|0)<0){m=l;i=f;return m|0}l=j+36|0;n=l;o=bc(n|0)|0;if((o|0)!=0){yDb(a,16,2179968,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;m=-1313558101;i=f;return m|0}c[l>>2]=g;c[j+40>>2]=h;g=j+16|0;c[j+48>>2]=c[g>>2];l=j+12|0;o=j+52|0;c[o>>2]=c[l>>2];q=$c(n|0,4)|0;if((q|0)==0|(q|0)==1){r=6}else if((q|0)!=(-3|0)){yDb(a,16,2103576,(p=i,i=i+8|0,c[p>>2]=q,p)|0);i=p;m=-1313558101;i=f;return m|0}do{if((r|0)==6){q=j+20|0;n=c[g>>2]|0;s=(c[l>>2]|0)-(c[o>>2]|0)|0;if((s|0)>-1){c[q>>2]=n;c[j+28>>2]=n;c[j+24>>2]=n+s;kQa(a,k,c[j+8>>2]|0,q)|0;break}else{yDb(0,0,2047264,(p=i,i=i+24|0,c[p>>2]=2001584,c[p+8>>2]=1964432,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}}}while(0);if((c[(c[j>>2]|0)+140>>2]|0)==11){p=HZ(e,0,0)|0;if((p|0)==0){t=j+92|0}else{c[k+304>>2]=1;e=j+92|0;UGb(e|0,p|0,1024)|0;t=e}UGb(c[k+4>>2]|0,t|0,1024)|0}t=MCb(b,k)|0;if((t|0)<0){m=t;i=f;return m|0}c[d>>2]=1;m=h;i=f;return m|0}function l$a(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+16|0);JCb(b+4|0);he(b+36|0)|0;return 0}function m$a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a+60|0;e=c[d>>2]|0;f=e;c[e>>2]=a;c[a+140>>2]=5;g=N_(e+72|0,9,47,181296,1,1,181200,2,2,181104,2,2,2)|0;a:do{if((g|0)==0){h=0;while(1){if((h|0)>=13){break a}j=N_(f+92+(h*20|0)|0,9,16,180896+(h<<4)|0,1,1,180480+(h<<5)|0,2,2,180464,1,1,2)|0;if((j|0)!=0){k=4;break}l=N_(f+352+(h*20|0)|0,9,c[181400+(h<<2)>>2]|0,c[181512+(h<<2)>>2]|0,1,1,c[181456+(h<<2)>>2]|0,2,2,c[181344+(h<<2)>>2]|0,2,2,2)|0;if((l|0)==0){h=h+1|0}else{k=6;break}}if((k|0)==4){p$a(f);m=j;k=7;break}else if((k|0)==6){p$a(f);m=l;k=7;break}}else{m=g;k=7}}while(0);do{if((k|0)==7){if((m|0)>=0){break}yDb(a,16,2271344,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=m;i=b;return o|0}}while(0);m=(c[a+120>>2]|0)+15>>4;c[e+8>>2]=m;k=(c[a+124>>2]|0)+7>>3;c[e+12>>2]=k;g=WDb(ba(k,m)|0)|0;c[e+16>>2]=g;if((g|0)==0){yDb(a,16,2255936,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p$a(f);o=-12;i=b;return o|0}f=ICb()|0;c[e+4>>2]=f;if((f|0)!=0){o=0;i=b;return o|0}f=c[d>>2]|0;JCb(f+4|0);$Db(f+16|0);p$a(f);o=-12;i=b;return o|0}function n$a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;k=i;i=i+64|0;l=k|0;m=c[j+24>>2]|0;n=c[j+28>>2]|0;j=c[f+60>>2]|0;o=j;p=j+8|0;q=j+12|0;r=ba(c[q>>2]|0,c[p>>2]|0)|0;if(!((n|0)>-1)){yDb(0,0,2329800,(s=i,i=i+24|0,c[s>>2]=2305320,c[s+8>>2]=2287400,c[s+16>>2]=135,s)|0);i=s;Cd();return 0}t=m+n|0;u=m;do{if((n|0)<1){v=m;w=0}else{x=a[m]|0;y=x&255;if(!((x&255)>>>0>1>>>0)){v=m+1|0;w=y;break}yDb(f,16,2179928,(s=i,i=i+8|0,c[s>>2]=y,s)|0);i=s;z=-1094995529;i=k;return z|0}}while(0);y=j+4|0;x=$$a(f,c[y>>2]|0)|0;if((x|0)<0){z=x;i=k;return z|0}if((w|0)==0){c[h>>2]=1;w=MCb(g,c[y>>2]|0)|0;z=(w|0)<0?w:n;i=k;return z|0}w=t-v|0;if(w>>>0<4>>>0){yDb(f,16,2103552,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;z=-1094995529;i=k;return z|0}if((w|0)<1){A=0;B=v}else{A=d[v]|0;B=v+1|0}c[j+20>>2]=A;if((t-B|0)<1){C=0;D=B}else{C=d[B]|0;D=B+1|0}c[j+24>>2]=C;B=A-2|0;if(B>>>0>12>>>0|C>>>0<2>>>0|C>>>0>14>>>0){yDb(f,16,2047232,(s=i,i=i+16|0,c[s>>2]=A,c[s+8>>2]=C,s)|0);i=s;z=-1094995529;i=k;return z|0}c[j+28>>2]=e[180384+(B*6|0)>>1]|0;A=C-2|0;c[j+40>>2]=e[180384+(A*6|0)>>1]|0;c[j+32>>2]=e[180386+(B*6|0)>>1]|0;c[j+44>>2]=e[180386+(A*6|0)>>1]|0;c[j+36>>2]=e[180388+(B*6|0)>>1]|0;c[j+48>>2]=e[180388+(A*6|0)>>1]|0;A=t-D|0;B=A>>>0>1>>>0?1:A;A=D+B|0;a:do{if((t-A|0)<4){E=A;F=0}else{C=D+(B+4)|0;v=A;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;if(w>>>0>(t-C|0)>>>0){yDb(f,16,2001544,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;z=-1094995529;i=k;return z|0}if((w|0)==0){E=C;F=0;break}v=j+16|0;x=C;C=0;G=0;while(1){if((t-x|0)<1){H=0;I=x}else{H=d[x]|0;I=x+1|0}J=H&63;K=J+G|0;if((K|0)>(r|0)){break}TGb((c[v>>2]|0)+G|0,H>>>6&255|0,J|0)|0;J=C+1|0;if(J>>>0<w>>>0){x=I;C=J;G=K}else{E=I;F=K;break a}}yDb(f,16,1964392,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;z=-1094995529;i=k;return z|0}}while(0);if((F|0)<(r|0)){yDb(f,16,1936296,(s=i,i=i+16|0,c[s>>2]=F,c[s+8>>2]=r,s)|0);i=s;z=-1094995529;i=k;return z|0}r=c[q>>2]|0;b:do{if((r|0)>0){F=j+16|0;I=j+52|0;H=j+64|0;A=j+68|0;B=j+56|0;D=j+60|0;G=j+612|0;C=j+616|0;x=j+76|0;w=E;v=0;K=r;c:while(1){J=t-w|0;do{if((J|0)<1){L=w;M=37}else{N=a[w]|0;if((N&1)==0){if((J|0)<4){L=w;M=37;break}O=w;P=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>1;Q=w+4|0}else{P=(N&255)-1|0;Q=w+1|0}if((P|0)==0){L=Q;M=37}else{R=Q;S=P}}}while(0);d:do{if((M|0)==37){M=0;J=c[p>>2]|0;N=ba(J,v)|0;O=0;while(1){if((O|0)>=(J|0)){R=L;S=0;break d}if(((a[(c[F>>2]|0)+(O+N)|0]|0)-1&255)>>>0<2>>>0){M=40;break c}else{O=O+1|0}}}}while(0);O=R;T=t-O|0;if(T>>>0<S>>>0){M=42;break}N=m+(O-u)|0;O=S>>>0>268435455>>>0?-8:S<<3;J=O>>>0>2147483639>>>0|(N|0)==0;U=J?0:N;N=J?0:O;c[I>>2]=U;c[H>>2]=N;c[A>>2]=N+8;c[B>>2]=U+(N>>3);c[D>>2]=0;if(J){M=80;break}J=c[p>>2]|0;if((J|0)>0){N=v<<3;U=0;O=J;while(1){J=(ba(O,v)|0)+U|0;V=a[(c[F>>2]|0)+J|0]|0;if((V<<24>>24|0)==3|(V<<24>>24|0)==0){W=O}else{J=U<<4;X=(V&255)-1|0;V=o+20+(X<<2)|0;Y=0;do{Z=c[y>>2]|0;_=c[Z+32+(Y<<2)>>2]|0;$=(ba(N,_)|0)+J|0;aa=(c[V>>2]|0)-2|0;ca=c[Z+(Y<<2)>>2]|0;Z=ca+$|0;da=c[D>>2]|0;ea=c[I>>2]|0;fa=d[ea+(da>>>3)|0]|0;ga=c[A>>2]|0;ha=((da|0)<(ga|0))+da|0;c[D>>2]=ha;do{if((fa&1<<(da&7)|0)==0){ia=o+92+(aa*20|0)+4|0;ja=o+352+(aa*20|0)+4|0;ka=_<<2;la=Z;ma=0;na=0;while(1){oa=ma;pa=0;do{do{if((pa|na|0)==0){qa=c[D>>2]|0;ra=c[A>>2]|0;sa=c[I>>2]|0;ta=sa+(qa>>>3)|0;ua=(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)>>>((qa&7)>>>0)&255;ta=qa+8|0;qa=ra>>>0>ta>>>0?ta:ra;c[D>>2]=qa;va=ua;wa=qa;xa=ra;ya=sa}else{sa=c[x>>2]|0;ra=c[D>>2]|0;qa=c[A>>2]|0;ua=c[I>>2]|0;ta=ua+(ra>>>3)|0;za=(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)>>>((ra&7)>>>0)&511;ta=b[sa+(za<<2)>>1]|0;Aa=b[sa+(za<<2)+2>>1]|0;za=Aa<<16>>16;if(Aa<<16>>16<0){Aa=ra+9|0;Ba=qa>>>0>Aa>>>0?Aa:qa;Aa=ua+(Ba>>>3)|0;Ca=za+32|0;Da=((d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)>>>((Ba&7)>>>0)<<Ca>>>(Ca>>>0))+ta|0;Ea=b[sa+(Da<<2)+2>>1]|0;Fa=b[sa+(Da<<2)>>1]|0;Ga=Ba}else{Ea=za;Fa=ta;Ga=ra}ra=Ea+Ga|0;ta=qa>>>0>ra>>>0?ra:qa;c[D>>2]=ta;if((Fa|0)==(-1|0)){M=80;break c}else if((Fa|0)!=256){va=Fa;wa=ta;xa=qa;ya=ua;break}ra=ua+(ta>>>3)|0;za=(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)>>>((ta&7)>>>0)&255;ra=ta+8|0;ta=qa>>>0>ra>>>0?ra:qa;c[D>>2]=ta;va=za;wa=ta;xa=qa;ya=ua}}while(0);oa=va+oa&255;c[G>>2]=oa;ua=c[ia>>2]|0;qa=ya+(wa>>>3)|0;ta=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((wa&7)>>>0)&511;qa=b[ua+(ta<<2)>>1]|0;za=qa<<16>>16;ra=(b[ua+(ta<<2)+2>>1]|0)+wa|0;ta=xa>>>0>ra>>>0?ra:xa;c[D>>2]=ta;if(qa<<16>>16==-1){M=80;break c}TGb(C|0,0,60)|0;e:do{if(qa<<16>>16>0){ra=1;ua=1;Ba=ta;Da=xa;sa=ya;while(1){Ca=c[ja>>2]|0;Aa=sa+(Ba>>>3)|0;Ha=(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)>>>((Ba&7)>>>0)&511;Aa=b[Ca+(Ha<<2)>>1]|0;Ia=b[Ca+(Ha<<2)+2>>1]|0;Ha=Ia<<16>>16;if(Ia<<16>>16<0){Ia=Ba+9|0;Ja=Da>>>0>Ia>>>0?Ia:Da;Ia=sa+(Ja>>>3)|0;Ka=Ha+32|0;La=((d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)>>>((Ja&7)>>>0)<<Ka>>>(Ka>>>0))+Aa|0;Ma=b[Ca+(La<<2)+2>>1]|0;Na=b[Ca+(La<<2)>>1]|0;Oa=Ja}else{Ma=Ha;Na=Aa;Oa=Ba}Aa=Ma+Oa|0;Ha=Da>>>0>Aa>>>0?Aa:Da;c[D>>2]=Ha;if((Na|0)==4096){Aa=sa+(Ha>>>3)|0;Ja=(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)>>>((Ha&7)>>>0)&4095;Aa=Ha+12|0;c[D>>2]=Da>>>0>Aa>>>0?Aa:Da;Pa=Ja}else if((Na|0)==(-1|0)){M=80;break c}else{Pa=Na}Ja=(Pa&15)+ra|0;if((Ja|0)>15){M=80;break c}c[o+612+(d[180368+Ja|0]<<2)>>2]=Pa>>>4<<24>>24;if((ua|0)>=(za|0)){Qa=0;break e}ra=Ja+1|0;ua=ua+1|0;Ba=c[D>>2]|0;Da=c[A>>2]|0;sa=c[I>>2]|0}}else{Qa=0}}while(0);do{za=Qa&1;ta=c[o+28+(X*12|0)+(za<<2)>>2]|0;qa=(ba(ta,c[o+612+(Qa<<2)>>2]|0)|0)+128>>8;sa=Qa+4|0;Da=c[o+28+(X*12|0)+(za+1<<2)>>2]|0;za=(ba(Da,c[o+612+(sa<<2)>>2]|0)|0)+128>>8;Ba=Qa+8|0;ua=(ba(c[o+612+(Ba<<2)>>2]|0,ta)|0)+128>>8;ta=Qa+12|0;ra=(ba(c[o+612+(ta<<2)>>2]|0,Da)|0)+128>>8;Da=ra<<1;c[l+(Qa<<2)>>2]=((za+qa+ua|0)*5|0)+Da;Ja=qa-ua|0;Aa=za<<1;c[l+(sa<<2)>>2]=((Ja-ra|0)*5|0)+Aa;c[l+(Ba<<2)>>2]=((Ja+ra|0)*5|0)-Aa;c[l+(ta<<2)>>2]=((qa-za+ua|0)*5|0)-Da;Qa=Qa+1|0;}while((Qa|0)<4);Da=0;ua=la+(pa<<2)|0;while(1){za=Da<<2;qa=l+(za<<2)|0;ta=l+((za|1)<<2)|0;Aa=l+((za|2)<<2)|0;ra=l+((za|3)<<2)|0;a[ua]=((c[ra>>2]<<1)+32+(((c[ta>>2]|0)+(c[qa>>2]|0)+(c[Aa>>2]|0)|0)*5|0)|0)>>>6;a[ua+1|0]=((c[ta>>2]<<1)+32+(((c[qa>>2]|0)-(c[Aa>>2]|0)-(c[ra>>2]|0)|0)*5|0)|0)>>>6;a[ua+2|0]=(32-(c[ta>>2]<<1)+(((c[qa>>2]|0)-(c[Aa>>2]|0)+(c[ra>>2]|0)|0)*5|0)|0)>>>6;a[ua+3|0]=(32-(c[ra>>2]<<1)+(((c[qa>>2]|0)-(c[ta>>2]|0)+(c[Aa>>2]|0)|0)*5|0)|0)>>>6;Aa=Da+1|0;if((Aa|0)<4){Da=Aa;ua=ua+_|0}else{break}}pa=pa+1|0;}while((pa|0)<4);pa=na+1|0;if((pa|0)<2){la=la+ka|0;ma=oa;na=pa}else{break}}}else{na=d[ea+(ha>>>3)|0]|0;ma=((ha|0)<(ga|0))+ha|0;c[D>>2]=ma;if((na&1<<(ha&7)|0)!=0){na=ea+(ma>>>3)|0;ka=(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)>>>((ma&7)>>>0);na=ma+8|0;c[D>>2]=ga>>>0>na>>>0?na:ga;na=ka&255;TGb(Z|0,na|0,16)|0;ka=$+_|0;TGb(ca+ka|0,na|0,16)|0;la=_<<1;TGb(ca+($+la)|0,na|0,16)|0;ja=la+_|0;TGb(ca+($+ja)|0,na|0,16)|0;la=ja+_|0;TGb(ca+(la+$)|0,na|0,16)|0;ja=la+_|0;TGb(ca+(ja+$)|0,na|0,16)|0;la=ja+_|0;TGb(ca+(la+$)|0,na|0,16)|0;TGb(ca+(la+ka)|0,na|0,16)|0;break}if(((c[H>>2]|0)-ma|0)<1024){M=80;break c}else{Ra=Z;Sa=0}while(1){ma=0;do{na=c[D>>2]|0;ka=c[A>>2]|0;la=(c[I>>2]|0)+(na>>>3)|0;ja=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((na&7)>>>0);la=na+8|0;c[D>>2]=ka>>>0>la>>>0?la:ka;a[Ra+ma|0]=ja;ma=ma+1|0;}while((ma|0)<16);ma=Sa+1|0;if((ma|0)<8){Ra=Ra+_|0;Sa=ma}else{break}}}}while(0);Y=Y+1|0;}while((Y|0)<3);W=c[p>>2]|0}Y=U+1|0;if((Y|0)<(W|0)){U=Y;O=W}else{break}}Ta=c[q>>2]|0}else{Ta=K}O=v+1|0;if((O|0)<(Ta|0)){w=R+(T>>>0>S>>>0?S:T)|0;v=O;K=Ta}else{break b}}if((M|0)==40){yDb(f,16,1912744,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;z=-1094995529;i=k;return z|0}else if((M|0)==42){yDb(f,16,1892304,(s=i,i=i+16|0,c[s>>2]=S,c[s+8>>2]=T,s)|0);i=s;z=-1094995529;i=k;return z|0}else if((M|0)==80){yDb(f,16,2349960,(s=i,i=i+8|0,c[s>>2]=v,s)|0);i=s;z=-1094995529;i=k;return z|0}}}while(0);c[h>>2]=1;h=MCb(g,c[y>>2]|0)|0;z=(h|0)<0?h:n;i=k;return z|0}function o$a(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);$Db(b+16|0);p$a(b);return 0}function p$a(a){a=a|0;Q_(a+72|0);Q_(a+92|0);Q_(a+352|0);Q_(a+112|0);Q_(a+372|0);Q_(a+132|0);Q_(a+392|0);Q_(a+152|0);Q_(a+412|0);Q_(a+172|0);Q_(a+432|0);Q_(a+192|0);Q_(a+452|0);Q_(a+212|0);Q_(a+472|0);Q_(a+232|0);Q_(a+492|0);Q_(a+252|0);Q_(a+512|0);Q_(a+272|0);Q_(a+532|0);Q_(a+292|0);Q_(a+552|0);Q_(a+312|0);Q_(a+572|0);Q_(a+332|0);Q_(a+592|0);return}function q$a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;e=i;f=b+60|0;g=c[f>>2]|0;c[g+4>>2]=b;h=b+100|0;if((c[h>>2]|0)<22){j=-1094995529;i=e;return j|0}c[g+8>>2]=tBb(4)|0;k=c[b+96>>2]|0;l=c[h>>2]|0;h=l>>>0>268435455>>>0?-8:l<<3;l=h>>>0>2147483639>>>0|(k|0)==0;m=l?0:k;k=l?8:h+8|0;h=m;l=m+(k>>>0>16>>>0?2:k>>>3)|0;if(((d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)<<16|(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24)&65535|0)!=826365012){yDb(b,16,2287368,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}h=(k|0)<32?k:32;l=m+(h>>>3)|0;o=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)&65535;l=h+16|0;h=k>>>0>l>>>0?l:k;l=g+12|0;c[l>>2]=o;if(o>>>0>2>>>0){yDb(b,16,2047208,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}if((o|0)==2){o=c[g+48>>2]|0;if((o|0)==0){yDb(b,16,2001472,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-22;i=e;return j|0}p=SGb(o|0)|0;q=o+p|0;if((p|0)>0){p=-1;r=-1;s=o;do{o=(0<<24|0>>>8)^r;t=((d[s]|0)<<24|0>>>8)^p;u=(t>>31|((t|0)<0|0?-1:0)<<1)&-1444268397^(o<<1|0>>>31);v=(((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1)&1123082731^(t<<1|o>>>31);o=(v>>31|((v|0)<0|0?-1:0)<<1)&-1444268397^(u<<1|0>>>31);t=(((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1)&1123082731^(v<<1|u>>>31);u=(t>>31|((t|0)<0|0?-1:0)<<1)&-1444268397^(o<<1|0>>>31);v=(((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1)&1123082731^(t<<1|o>>>31);o=(v>>31|((v|0)<0|0?-1:0)<<1)&-1444268397^(u<<1|0>>>31);t=(((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1)&1123082731^(v<<1|u>>>31);u=(t>>31|((t|0)<0|0?-1:0)<<1)&-1444268397^(o<<1|0>>>31);v=(((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1)&1123082731^(t<<1|o>>>31);o=(v>>31|((v|0)<0|0?-1:0)<<1)&-1444268397^(u<<1|0>>>31);t=(((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1)&1123082731^(v<<1|u>>>31);u=(t>>31|((t|0)<0|0?-1:0)<<1)&-1444268397^(o<<1|0>>>31);v=(((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1)&1123082731^(t<<1|o>>>31);r=(v>>31|((v|0)<0|0?-1:0)<<1)&-1444268397^(u<<1|0>>>31);p=(((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1)&1123082731^(v<<1|u>>>31);s=s+1|0;}while(s>>>0<q>>>0);w=~p;y=~r}else{w=0;y=0}r=g+40|0;p=r|0;x=y;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=w;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x}p=m+(h>>>3)|0;w=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((h&7)>>>0)&65535;p=h+16|0;h=k>>>0>p>>>0?p:k;p=g+16|0;c[p>>2]=w;r=b+416|0;c[r>>2]=w;w=(c[p>>2]|0)-2|0;if(w>>>0<7>>>0){y=180312+(w<<3)|0;w=c[y+4>>2]|0;q=b+448|0;c[q>>2]=c[y>>2];c[q+4>>2]=w}w=m+(h>>>3)|0;q=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((h&7)>>>0)&65535;w=h+16|0;h=k>>>0>w>>>0?w:k;c[b+796>>2]=q;w=g+20|0;c[w>>2]=(q+7|0)>>>3;q=m+(h>>>3)|0;y=h+16|0;s=k>>>0>y>>>0?y:k;y=m+(s>>>3)|0;u=s+16|0;v=k>>>0>u>>>0?u:k;u=b+412|0;c[u>>2]=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((s&7)>>>0)<<16|(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((h&7)>>>0)&65535;h=m+(v>>>3)|0;q=v+16|0;s=k>>>0>q>>>0?q:k;k=m+(s>>>3)|0;m=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((s&7)>>>0)<<16|(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>((v&7)>>>0)&65535;v=g+24|0;c[v>>2]=m;if((c[p>>2]|0)==0){yDb(b,16,1964360,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}h=c[u>>2]|0;if((h|0)==0){yDb(b,16,1936272,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}s=c[w>>2]|0;if((s|0)==1){c[b+420>>2]=0}else if((s|0)==3){c[b+420>>2]=2}else if((s|0)==2){c[b+420>>2]=1}else{yDb(b,16,1912704,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}if(h>>>0>8388607>>>0){yDb(b,16,1892280,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-22;i=e;return j|0}s=(h<<8|0)/245|0;h=g+28|0;c[h>>2]=s;w=(m>>>0)%(s>>>0)|0;k=g+32|0;c[k>>2]=w;q=b;y=c[r>>2]|0;o=c[b+792>>2]|0;t=c[u>>2]|0;u=c[b+432>>2]|0;yDb(q,48,2349904,(n=i,i=i+40|0,c[n>>2]=c[l>>2],c[n+8>>2]=y,c[n+16>>2]=o,c[n+24>>2]=t,c[n+32>>2]=u,n)|0);i=n;u=c[h>>2]|0;t=c[k>>2]|0;yDb(q,48,2329744,(n=i,i=i+32|0,c[n>>2]=c[v>>2],c[n+8>>2]=u,c[n+16>>2]=t,c[n+24>>2]=((m>>>0)/(s>>>0)|0)+((w|0)!=0),n)|0);i=n;if(!((c[h>>2]|0)>>>0<(4294967295/(c[p>>2]<<2>>>0)|0)>>>0)){yDb(q,16,2305296,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}v$a(g+56|0);g=c[f>>2]|0;do{if((c[g+20>>2]|0)<3){f=cEb(ba(c[g+28>>2]<<2,c[g+16>>2]|0)|0)|0;c[g+36>>2]=f;if((f|0)==0){j=-12}else{break}i=e;return j|0}else{c[g+36>>2]=0}}while(0);f=WDb((c[r>>2]|0)*224|0)|0;c[g+52>>2]=f;if((f|0)!=0){j=0;i=e;return j|0}$Db(g+36|0);j=-12;i=e;return j|0}function r$a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;j=i;i=i+16|0;k=j|0;c[k>>2]=f;c[k+4>>2]=0;c[k+8>>2]=0;l=h+24|0;m=c[l>>2]|0;n=h+28|0;h=c[n>>2]|0;o=c[e+60>>2]|0;p=c[o+28>>2]|0;q=e+696|0;do{if((c[q>>2]&1|0)==0){r=m;s=h}else{if((h|0)<4){t=-1094995529;i=j;return t|0}u=h-4|0;v=m+u|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;if((w|0)==(~(uBb(c[o+8>>2]|0,-1,m,u)|0)|0)){r=m;s=h;break}yDb(c[o+4>>2]|0,16,2179912,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;if((c[q>>2]&8|0)==0){r=c[l>>2]|0;s=c[n>>2]|0;break}else{t=-1094995529;i=j;return t|0}}}while(0);n=s>>>0>268435455>>>0?-8:s<<3;s=n>>>0>2147483639>>>0|(r|0)==0;l=s?0:r;r=s?0:n;n=r+8|0;if(s){t=s?-1094995529:0;i=j;return t|0}s=f+76|0;c[s>>2]=p;q=W0a(e,k,0)|0;if((q|0)<0){t=q;i=j;return t|0}q=o+20|0;if((c[q>>2]|0)==3){c[o+36>>2]=c[f>>2]}k=o+16|0;e=c[k>>2]|0;if((e|0)>0){m=o+52|0;u=o+12|0;w=0;while(1){v=c[m>>2]|0;c[v+(w*224|0)>>2]=0;u$a(v+(w*224|0)+4|0,d[1109480+((c[q>>2]|0)-1)|0]|0);if((c[u>>2]|0)==2){c[v+(w*224|0)+16>>2]=a[o+40|0]|0;c[v+(w*224|0)+20>>2]=a[o+41|0]|0;c[v+(w*224|0)+24>>2]=a[o+42|0]|0;c[v+(w*224|0)+28>>2]=a[o+43|0]|0;c[v+(w*224|0)+32>>2]=a[o+44|0]|0;c[v+(w*224|0)+36>>2]=a[o+45|0]|0;c[v+(w*224|0)+40>>2]=a[o+46|0]|0;c[v+(w*224|0)+44>>2]=a[o+47|0]|0}t$a((c[m>>2]|0)+(w*224|0)+208|0,10,10);v=w+1|0;x=c[k>>2]|0;if((v|0)<(x|0)){w=v}else{y=x;break}}}else{y=e}e=o+36|0;a:do{if((ba(y,p)|0)>0){w=o+52|0;m=c[277328]|0;u=o+56|0;x=o+32|0;v=r-32|0;z=0;A=c[e>>2]|0;B=0;C=0;b:while(1){D=c[w>>2]|0;E=D+(B*224|0)|0;G=D+(B*224|0)+208|0;H=r-z|0;I=0;J=z;while(1){if((I|0)>=(H|0)){K=J;break}L=((J|0)<(n|0))+J|0;if((d[l+(J>>>3)|0]&1<<(J&7)|0)==0){K=L;break}else{I=I+1|0;J=L}}if((I|0)==0){M=G|0;N=0;O=0}else{M=D+(B*224|0)+212|0;N=1;O=I-1|0}J=c[M>>2]|0;if((r-K|0)>>>0<J>>>0){break a}if((J|0)==0){P=O;Q=K}else{if(J>>>0>25>>>0){break a}H=l+(K>>>3)|0;L=32-J|0;R=J+K|0;P=((d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((K&7)>>>0)<<L>>>(L>>>0))+(O<<J)|0;Q=n>>>0>R>>>0?R:n}if((N|0)==1){R=D+(B*224|0)+220|0;J=c[R>>2]|0;L=P-(J>>>4)+J|0;c[R>>2]=L;R=D+(B*224|0)+212|0;J=c[R>>2]|0;do{if((J|0)==0){S=32}else{if(!(L>>>0<(c[m+(J<<2)>>2]|0)>>>0)){S=32;break}c[R>>2]=J-1}}while(0);do{if((S|0)==32){S=0;I=J+1|0;if(!(L>>>0>(c[m+(I<<2)>>2]|0)>>>0)){break}c[R>>2]=I}}while(0);R=c[G>>2]|0;T=(c[1109320+(R<<2)>>2]|0)+P|0;U=R}else{T=P;U=c[G>>2]|0}R=D+(B*224|0)+216|0;L=c[R>>2]|0;J=T-(L>>>4)+L|0;c[R>>2]=J;R=G|0;do{if((U|0)==0){S=38}else{if(!(J>>>0<(c[m+(U<<2)>>2]|0)>>>0)){S=38;break}c[R>>2]=U-1}}while(0);do{if((S|0)==38){S=0;G=U+1|0;if(!(J>>>0>(c[m+(G<<2)>>2]|0)>>>0)){break}c[R>>2]=G}}while(0);c[A>>2]=((T&1)-1^T>>1)+1;Ke[c[u>>2]&1023](D+(B*224|0)+16|0,D+(B*224|0)+80|0,D+(B*224|0)+144|0,D+(B*224|0)+12|0,A,c[D+(B*224|0)+4>>2]|0,c[D+(B*224|0)+8>>2]|0);R=c[q>>2]|0;if((R|0)==1){J=c[E>>2]|0;G=gHb(J,(J|0)<0|0?-1:0,15,0)|0;J=(G>>>4|F<<28)+(c[A>>2]|0)|0;c[A>>2]=J;V=J}else if((R|0)==2|(R|0)==3){J=c[E>>2]|0;G=gHb(J,(J|0)<0|0?-1:0,31,0)|0;J=(G>>>5|F<<27)+(c[A>>2]|0)|0;c[A>>2]=J;V=J}else if((R|0)==4){R=(c[A>>2]|0)+(c[E>>2]|0)|0;c[A>>2]=R;V=R}else{V=c[A>>2]|0}c[E>>2]=V;R=c[k>>2]|0;do{if((B|0)<(R-1|0)){W=C;X=B+1|0;Y=R}else{c:do{if((R|0)>1){J=A-4|0;G=c[J>>2]|0;c[A>>2]=(c[A>>2]|0)+((G|0)/2|0);L=c[k>>2]|0;if((-L|0)<-1){Z=J;_=G}else{$=L;break}while(1){c[Z>>2]=(c[Z+4>>2]|0)-_;L=Z-4|0;G=c[k>>2]|0;if(!(L>>>0>(A+(-G<<2)|0)>>>0)){$=G;break c}Z=L;_=c[L>>2]|0}}else{$=R}}while(0);aa=C+1|0;if((aa|0)!=(c[x>>2]|0)){W=aa;X=0;Y=$;break}if((v-Q|0)>>>0<8>>>0){break b}else{W=aa;X=0;Y=$}}}while(0);R=A+4|0;if(R>>>0<((c[e>>2]|0)+((ba(Y,p)|0)<<2)|0)>>>0){z=Q;A=R;B=X;C=W}else{ca=p;da=Q;S=55;break a}}c[s>>2]=aa;ca=aa;da=Q;S=55}else{ca=p;da=0;S=55}}while(0);do{if((S|0)==55){p=-da&7;if((p|0)==0){ea=da}else{Q=p+da|0;ea=n>>>0>Q>>>0?Q:n}if((r-ea|0)<32){break}Q=c[q>>2]|0;do{if((Q|0)==1){if((ba(c[k>>2]|0,ca)|0)<=0){break}p=c[e>>2]|0;aa=c[f>>2]|0;while(1){a[aa]=(c[p>>2]|0)+128;s=p+4|0;if(s>>>0<((c[e>>2]|0)+((ba(c[k>>2]|0,ca)|0)<<2)|0)>>>0){p=s;aa=aa+1|0}else{break}}}else if((Q|0)==2){aa=ba(c[k>>2]|0,ca)|0;if((aa|0)<=0){break}p=c[e>>2]|0;s=p+(aa<<2)|0;aa=p;p=c[f>>2]|0;while(1){b[p>>1]=c[aa>>2];W=aa+4|0;if(W>>>0<s>>>0){aa=W;p=p+2|0}else{break}}}else if((Q|0)==3){if((ba(c[k>>2]|0,ca)|0)>0){p=0;aa=c[f>>2]|0;while(1){c[aa>>2]=c[aa>>2]<<8;s=p+1|0;if((s|0)<(ba(c[k>>2]|0,ca)|0)){p=s;aa=aa+4|0}else{break}}}c[e>>2]=0}}while(0);c[g>>2]=1;t=h;i=j;return t|0}}while(0);if((c[q>>2]|0)!=3){t=-1094995529;i=j;return t|0}c[e>>2]=0;t=-1094995529;i=j;return t|0}function s$a(a){a=a|0;var b=0;b=c[a+60>>2]|0;a=b+36|0;if((c[b+20>>2]|0)<3){ZDb(c[a>>2]|0)}c[a>>2]=0;$Db(b+52|0);return 0}function t$a(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=b;c[a+4>>2]=d;c[a+8>>2]=c[1109320+(b+4<<2)>>2];c[a+12>>2]=c[1109320+(d+4<<2)>>2];return}function u$a(a,b){a=a|0;b=b|0;TGb(a|0,0,204)|0;c[a>>2]=b;c[a+4>>2]=c[1109320+(b-1<<2)>>2];return}function v$a(a){a=a|0;c[a>>2]=244;return}function w$a(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=c[e>>2]|0;do{if((i|0)<0){j=(c[a>>2]|0)-(c[b>>2]|0)|0;c[a>>2]=j;k=b+4|0;l=a+4|0;m=(c[l>>2]|0)-(c[k>>2]|0)|0;c[l>>2]=m;l=b+8|0;n=a+8|0;o=(c[n>>2]|0)-(c[l>>2]|0)|0;c[n>>2]=o;n=b+12|0;p=a+12|0;q=(c[p>>2]|0)-(c[n>>2]|0)|0;c[p>>2]=q;p=b+16|0;r=a+16|0;s=(c[r>>2]|0)-(c[p>>2]|0)|0;c[r>>2]=s;r=b+20|0;t=a+20|0;u=(c[t>>2]|0)-(c[r>>2]|0)|0;c[t>>2]=u;t=b+24|0;v=a+24|0;w=(c[v>>2]|0)-(c[t>>2]|0)|0;c[v>>2]=w;v=b+28|0;x=a+28|0;y=(c[x>>2]|0)-(c[v>>2]|0)|0;c[x>>2]=y;z=j;A=m;B=o;C=q;D=s;E=u;F=w;G=y;H=k;I=l;J=n;K=p;L=r;M=t;N=v}else{if((i|0)>0){v=(c[a>>2]|0)+(c[b>>2]|0)|0;c[a>>2]=v;t=b+4|0;r=a+4|0;p=(c[r>>2]|0)+(c[t>>2]|0)|0;c[r>>2]=p;r=b+8|0;n=a+8|0;l=(c[n>>2]|0)+(c[r>>2]|0)|0;c[n>>2]=l;n=b+12|0;k=a+12|0;y=(c[k>>2]|0)+(c[n>>2]|0)|0;c[k>>2]=y;k=b+16|0;w=a+16|0;u=(c[w>>2]|0)+(c[k>>2]|0)|0;c[w>>2]=u;w=b+20|0;s=a+20|0;q=(c[s>>2]|0)+(c[w>>2]|0)|0;c[s>>2]=q;s=b+24|0;o=a+24|0;m=(c[o>>2]|0)+(c[s>>2]|0)|0;c[o>>2]=m;o=b+28|0;j=a+28|0;x=(c[j>>2]|0)+(c[o>>2]|0)|0;c[j>>2]=x;z=v;A=p;B=l;C=y;D=u;E=q;F=m;G=x;H=t;I=r;J=n;K=k;L=w;M=s;N=o;break}else{z=c[a>>2]|0;A=c[a+4>>2]|0;B=c[a+8>>2]|0;C=c[a+12>>2]|0;D=c[a+16>>2]|0;E=c[a+20>>2]|0;F=c[a+24>>2]|0;G=c[a+28>>2]|0;H=b+4|0;I=b+8|0;J=b+12|0;K=b+16|0;L=b+20|0;M=b+24|0;N=b+28|0;break}}}while(0);a=ba(z,c[d>>2]|0)|0;z=d+4|0;i=ba(A,c[z>>2]|0)|0;A=d+8|0;o=ba(B,c[A>>2]|0)|0;B=d+12|0;s=ba(C,c[B>>2]|0)|0;C=d+16|0;w=ba(D,c[C>>2]|0)|0;D=d+20|0;k=ba(E,c[D>>2]|0)|0;E=d+24|0;n=ba(F,c[E>>2]|0)|0;F=d+28|0;r=a+h+i+o+s+w+k+n+(ba(G,c[F>>2]|0)|0)|0;c[b>>2]=c[H>>2];c[H>>2]=c[I>>2];c[I>>2]=c[J>>2];c[J>>2]=c[K>>2];c[d>>2]=c[z>>2];c[z>>2]=c[A>>2];c[A>>2]=c[B>>2];A=c[C>>2]|0;c[B>>2]=A;c[K>>2]=A>>30|1;c[L>>2]=c[D>>2]>>30&-4|2;c[M>>2]=c[E>>2]>>30&-4|2;c[N>>2]=c[F>>2]>>30&-8|4;c[e>>2]=c[f>>2];c[f>>2]=(c[f>>2]|0)+(r>>g);g=c[D>>2]|0;c[C>>2]=-g;r=c[E>>2]|0;c[D>>2]=-r;e=(c[f>>2]|0)-(c[F>>2]|0)|0;c[E>>2]=e;c[F>>2]=c[f>>2];f=e-r|0;c[D>>2]=f;c[C>>2]=f-g;return}function x$a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;c[d>>2]=tBb(4)|0;e=c[a+420>>2]|0;if((e|0)==1){c[a+796>>2]=16;f=2}else if((e|0)==2){g=a+796|0;if((c[g>>2]|0)>24){yDb(a,24,2179848,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}c[g>>2]=24;f=3}else if((e|0)==0){c[a+796>>2]=8;f=1}else{f=c[a+796>>2]>>3}c[d+4>>2]=f;c[a+424>>2]=(c[a+412>>2]<<8|0)/245|0;f=WDb((c[a+416>>2]|0)*224|0)|0;c[d+8>>2]=f;i=b;return((f|0)==0?-12:0)|0}function y$a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0;j=i;i=i+8|0;k=j|0;l=c[e+60>>2]|0;m=g+76|0;n=e+416|0;o=ba(c[m>>2]<<1,c[n>>2]|0)|0;p=l+4|0;q=ba(o,c[p>>2]|0)|0;o=r0a(e,f,q,(q|0)<0|0?-1:0)|0;if((o|0)<0){r=o;i=j;return r|0}o=f+24|0;q=f+28|0;s=(c[q>>2]|0)<0?0:c[o>>2]|0;t=c[n>>2]|0;if((t|0)>0){u=l+8|0;v=0;while(1){w=c[u>>2]|0;c[w+(v*224|0)>>2]=0;u$a(w+(v*224|0)+4|0,d[1109480+((c[p>>2]|0)-1)|0]|0);t$a((c[u>>2]|0)+(v*224|0)+208|0,10,10);w=v+1|0;y=c[n>>2]|0;if((w|0)<(y|0)){v=w}else{z=y;break}}}else{z=t}do{if((ba(z,c[m>>2]|0)|0)>0){t=l+8|0;v=e+420|0;u=g|0;y=c[277328]|0;w=s;A=32;B=0;C=0;D=0;E=0;G=z;while(1){H=c[t>>2]|0;I=H+(D*224|0)|0;J=E+1|0;K=c[v>>2]|0;L=(K|0)==0;do{if(L){M=c[u>>2]|0;N=(d[M+E|0]|0)-128|0;O=M}else{M=c[u>>2]|0;if((K|0)==1){N=b[M+(E<<1)>>1]|0;O=M;break}else{N=c[M+(E<<2)>>2]>>8;O=M;break}}}while(0);do{if((G|0)>1){if((D|0)>=(G-1|0)){P=C;Q=N-((C|0)/2|0)|0;break}do{if(L){R=(d[O+J|0]|0)-128|0}else{if((K|0)==1){R=b[O+(J<<1)>>1]|0;break}else{R=c[O+(J<<2)>>2]>>8;break}}}while(0);M=R-N|0;P=M;Q=M}else{P=C;Q=N}}while(0);K=c[p>>2]|0;if((K|0)==2|(K|0)==3){L=I|0;M=c[L>>2]|0;S=gHb(M,(M|0)<0|0?-1:0,31,0)|0;T=Q-(S>>>5|F<<27)|0;U=L}else if((K|0)==1){K=I|0;L=c[K>>2]|0;S=gHb(L,(L|0)<0|0?-1:0,15,0)|0;T=Q-(S>>>4|F<<28)|0;U=K}else{T=Q;U=I|0}c[U>>2]=Q;K=H+(D*224|0)+144|0;S=H+(D*224|0)+16|0;L=H+(D*224|0)+80|0;M=c[H+(D*224|0)+8>>2]|0;V=H+(D*224|0)+12|0;W=c[V>>2]|0;do{if((W|0)<0){X=(c[S>>2]|0)-(c[L>>2]|0)|0;c[S>>2]=X;Y=c[H+(D*224|0)+84>>2]|0;Z=H+(D*224|0)+20|0;_=(c[Z>>2]|0)-Y|0;c[Z>>2]=_;Z=c[H+(D*224|0)+88>>2]|0;$=H+(D*224|0)+24|0;aa=(c[$>>2]|0)-Z|0;c[$>>2]=aa;$=c[H+(D*224|0)+92>>2]|0;ca=H+(D*224|0)+28|0;da=(c[ca>>2]|0)-$|0;c[ca>>2]=da;ca=c[H+(D*224|0)+96>>2]|0;ea=H+(D*224|0)+32|0;fa=(c[ea>>2]|0)-ca|0;c[ea>>2]=fa;ea=H+(D*224|0)+100|0;ga=H+(D*224|0)+36|0;ha=(c[ga>>2]|0)-(c[ea>>2]|0)|0;c[ga>>2]=ha;ga=H+(D*224|0)+104|0;ia=H+(D*224|0)+40|0;ja=(c[ia>>2]|0)-(c[ga>>2]|0)|0;c[ia>>2]=ja;ia=H+(D*224|0)+108|0;ka=H+(D*224|0)+44|0;la=(c[ka>>2]|0)-(c[ia>>2]|0)|0;c[ka>>2]=la;ma=X;na=_;oa=aa;pa=da;qa=fa;ra=ha;sa=ja;ta=la;ua=Y;va=Z;wa=$;xa=ca;ya=ea;za=ga;Aa=ia}else{if((W|0)>0){ia=(c[S>>2]|0)+(c[L>>2]|0)|0;c[S>>2]=ia;ga=c[H+(D*224|0)+84>>2]|0;ea=H+(D*224|0)+20|0;ca=(c[ea>>2]|0)+ga|0;c[ea>>2]=ca;ea=c[H+(D*224|0)+88>>2]|0;$=H+(D*224|0)+24|0;Z=(c[$>>2]|0)+ea|0;c[$>>2]=Z;$=c[H+(D*224|0)+92>>2]|0;Y=H+(D*224|0)+28|0;la=(c[Y>>2]|0)+$|0;c[Y>>2]=la;Y=c[H+(D*224|0)+96>>2]|0;ja=H+(D*224|0)+32|0;ha=(c[ja>>2]|0)+Y|0;c[ja>>2]=ha;ja=H+(D*224|0)+100|0;fa=H+(D*224|0)+36|0;da=(c[fa>>2]|0)+(c[ja>>2]|0)|0;c[fa>>2]=da;fa=H+(D*224|0)+104|0;aa=H+(D*224|0)+40|0;_=(c[aa>>2]|0)+(c[fa>>2]|0)|0;c[aa>>2]=_;aa=H+(D*224|0)+108|0;X=H+(D*224|0)+44|0;ka=(c[X>>2]|0)+(c[aa>>2]|0)|0;c[X>>2]=ka;ma=ia;na=ca;oa=Z;pa=la;qa=ha;ra=da;sa=_;ta=ka;ua=ga;va=ea;wa=$;xa=Y;ya=ja;za=fa;Aa=aa;break}else{ma=c[S>>2]|0;na=c[H+(D*224|0)+20>>2]|0;oa=c[H+(D*224|0)+24>>2]|0;pa=c[H+(D*224|0)+28>>2]|0;qa=c[H+(D*224|0)+32>>2]|0;ra=c[H+(D*224|0)+36>>2]|0;sa=c[H+(D*224|0)+40>>2]|0;ta=c[H+(D*224|0)+44>>2]|0;ua=c[H+(D*224|0)+84>>2]|0;va=c[H+(D*224|0)+88>>2]|0;wa=c[H+(D*224|0)+92>>2]|0;xa=c[H+(D*224|0)+96>>2]|0;ya=H+(D*224|0)+100|0;za=H+(D*224|0)+104|0;Aa=H+(D*224|0)+108|0;break}}}while(0);S=ba(c[K>>2]|0,ma)|0;W=H+(D*224|0)+148|0;I=c[W>>2]|0;aa=ba(I,na)|0;fa=H+(D*224|0)+152|0;ja=c[fa>>2]|0;Y=ba(ja,oa)|0;$=H+(D*224|0)+156|0;ea=c[$>>2]|0;ga=ba(ea,pa)|0;ka=H+(D*224|0)+160|0;_=c[ka>>2]|0;da=ba(_,qa)|0;ha=H+(D*224|0)+164|0;la=c[ha>>2]|0;Z=ba(la,ra)|0;ca=H+(D*224|0)+168|0;ia=c[ca>>2]|0;X=ba(ia,sa)|0;Ba=H+(D*224|0)+172|0;Ca=c[Ba>>2]|0;Da=S+M+aa+Y+ga+da+Z+X+(ba(Ca,ta)|0)|0;c[L>>2]=ua;c[H+(D*224|0)+84>>2]=va;c[H+(D*224|0)+88>>2]=wa;c[H+(D*224|0)+92>>2]=xa;c[K>>2]=I;c[W>>2]=ja;c[fa>>2]=ea;c[$>>2]=_;c[H+(D*224|0)+96>>2]=_>>30|1;c[ya>>2]=la>>30&-4|2;c[za>>2]=ia>>30&-4|2;c[Aa>>2]=Ca>>30&-8|4;_=T-Ca|0;c[ca>>2]=_;c[Ba>>2]=T;Ba=_-ia|0;c[ha>>2]=Ba;c[ka>>2]=Ba-la;la=T-(Da>>c[H+(D*224|0)+4>>2])|0;c[V>>2]=la;if((la|0)>0){Ea=(la<<1)-1|0}else{Ea=-la<<1}la=H+(D*224|0)+208|0;Da=c[la>>2]|0;Ba=H+(D*224|0)+216|0;ka=c[Ba>>2]|0;ha=Ea-(ka>>>4)+ka|0;c[Ba>>2]=ha;do{if((Da|0)==0){Fa=36}else{if(!(ha>>>0<(c[y+(Da<<2)>>2]|0)>>>0)){Fa=36;break}c[la>>2]=Da-1}}while(0);do{if((Fa|0)==36){Fa=0;V=Da+1|0;if(!(ha>>>0>(c[y+(V<<2)>>2]|0)>>>0)){break}c[la>>2]=V}}while(0);la=c[1109320+(Da<<2)>>2]|0;a:do{if(Ea>>>0<la>>>0){Ga=Ea;Ha=Da;Ia=B;Ja=A;Ka=w}else{ha=Ea-la|0;V=H+(D*224|0)+212|0;K=c[V>>2]|0;L=H+(D*224|0)+220|0;M=c[L>>2]|0;Ba=ha-(M>>>4)+M|0;c[L>>2]=Ba;do{if((K|0)==0){Fa=42}else{if(!(Ba>>>0<(c[y+(K<<2)>>2]|0)>>>0)){Fa=42;break}c[V>>2]=K-1}}while(0);do{if((Fa|0)==42){Fa=0;L=K+1|0;if(!(Ba>>>0>(c[y+(L<<2)>>2]|0)>>>0)){break}c[V>>2]=L}}while(0);V=(ha>>>(K>>>0))+1|0;Ba=B;L=A;M=w;while(1){if(!(V>>>0>31>>>0)){break}ka=2147483647<<32-L|Ba;if((L|0)>31){La=L;Ma=ka;Na=M}else{ia=M;x=ka;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;La=L+32|0;Ma=2147483647>>>(L>>>0);Na=M+4|0}ia=La-31|0;ka=V-31|0;if((ka|0)==0){Ga=ha;Ha=K;Ia=Ma;Ja=ia;Ka=Na;break a}else{V=ka;Ba=Ma;L=ia;M=Na}}ia=(1<<V)-1|0;ka=ia<<32-L|Ba;if((L|0)>(V|0)){Oa=L;Pa=ka;Qa=M}else{_=M;x=ka;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;Oa=L+32|0;Pa=(L|0)==32?0:ia>>>(L>>>0);Qa=M+4|0}Ga=ha;Ha=K;Ia=Pa;Ja=Oa-V|0;Ka=Qa}}while(0);if((Ja|0)>1){Ra=Ja;Sa=Ia;Ta=Ka}else{H=Ka;x=Ia;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;Ra=Ja+32|0;Sa=0;Ta=Ka+4|0}H=Ra-1|0;if((Ha|0)==0){Ua=Sa;Va=H;Wa=Ta}else{la=(c[1109320+(Ha<<2)>>2]|0)-1&Ga;Da=la<<33-Ra|Sa;if((H|0)>(Ha|0)){Xa=H;Ya=Da;Za=Ta}else{ia=Ta;x=Da;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;Xa=Ra+31|0;Ya=(H|0)==32?0:la>>>(H>>>0);Za=Ta+4|0}Ua=Ya;Va=Xa-Ha|0;Wa=Za}H=c[n>>2]|0;if((J|0)>=(ba(H,c[m>>2]|0)|0)){break}w=Wa;A=Va;B=Ua;C=P;D=(D|0)<(H-1|0)?D+1|0:0;E=J;G=H}if((Va|0)>=32){_a=Wa;break}G=((31-Va|0)>>>3)+1|0;E=Ua&255;D=Ua;C=Va;B=Wa;while(1){a[B]=E;A=D>>>8;w=C+8|0;if((w|0)<32){E=A&255;D=A;C=w;B=B+1|0}else{break}}_a=Wa+G|0}else{_a=s}}while(0);Wa=_a-s<<3>>3;s=_a;x=~(uBb(c[l>>2]|0,-1,c[o>>2]|0,Wa)|0);a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=g+136|0;g=c[s+4>>2]|0;o=f+8|0;c[o>>2]=c[s>>2];c[o+4>>2]=g;c[q>>2]=Wa+4;Wa=c[m>>2]|0;c[k>>2]=1;c[k+4>>2]=c[e+412>>2];m=KDb(Wa,(Wa|0)<0|0?-1:0,k,e+104|0)|0;c[f+48>>2]=m;c[h>>2]=1;r=0;i=j;return r|0}function z$a(a){a=a|0;$Db((c[a+60>>2]|0)+8|0);return 0}function A$a(b,f,h,j){b=b|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0.0,ra=0.0,sa=0,ta=0,ua=0.0,va=0,wa=0,xa=0.0,ya=0.0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0.0,Va=0.0,Wa=0.0,Xa=0,Ya=0,Za=0,_a=0.0,$a=0.0,ab=0,bb=0.0,cb=0.0,db=0.0,eb=0.0,fb=0.0,gb=0.0,hb=0.0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0;k=i;i=i+2152|0;l=k|0;m=k+16|0;n=k+24|0;o=k+152|0;p=k+2072|0;q=c[j+24>>2]|0;r=c[j+28>>2]|0;j=c[b+60>>2]|0;s=j;t=j+232|0;u=c[t>>2]|0;v=j+34208|0;do{if((c[v>>2]|0)>1){c[f+76>>2]=ba(e[u+96>>1]|0,c[j+34232>>2]|0)|0;w=_$a(b,f,0)|0;if((w|0)<0){x=w;i=k;return x|0}else{y=c[f+64>>2]|0;break}}else{y=0}}while(0);f=b+432|0;if((r|0)<(c[f>>2]|0)){yDb(b,16,2205624,(w=i,i=i+8|0,c[w>>2]=r,w)|0);i=w;x=-22;i=k;return x|0}w=_e[c[j+36876>>2]&1023](b,s,q,r)|0;if((w|0)<0){x=w;i=k;return x|0}w=j+34236|0;c[w>>2]=0;q=j+34232|0;if((c[q>>2]|0)>0){b=j+34188|0;z=j+34240|0;A=j;B=j+34184|0;C=o|0;D=j+36884|0;E=p|0;F=m|0;G=m+1|0;H=m+2|0;I=m+3|0;J=j+34224|0;K=j+34212|0;L=j+4|0;M=j+36880|0;N=u+96|0;u=j+34196|0;O=j+34200|0;P=j+34192|0;R=l|0;S=l+4|0;U=l+8|0;V=j+20|0;W=(y|0)==0;X=y+4|0;Y=j+32|0;j=0;do{Z=c[b>>2]|0;$=c[z+(j*1316|0)+4>>2]|0;aa=c[t>>2]|0;ca=c[(c[A>>2]|0)+416>>2]|0;da=aa+($<<5)|0;ea=a[da]|0;fa=ea&255;ga=aa+96|0;ha=((e[ga>>1]|0)>>>0)/(fa>>>0)|0;D$a(s,s+34240+(j*1316|0)+8|0,Z,$,c[aa+($<<5)+20>>2]|0,c[aa+($<<5)+24>>2]|0,d[aa+($<<5)+28|0]|0);ia=c[w>>2]|0;ja=a[(c[t>>2]|0)+($<<5)|0]|0;ka=ja&255;la=($|0)==2;ma=c[(c[A>>2]|0)+416>>2]|0;na=(ma|0)>0;do{if(la){if(na){oa=0}else{pa=24;break}while(1){qa=(+(d[s+34240+(ia*1316|0)+1092+oa|0]|0)*50.98039245605469+25.490196228027344)/13.0e3;if(qa<-1.0){ra=-1.0}else{ra=qa>1.0?1.0:qa}g[n+(oa<<2)>>2]=(ra>0.0?13.0e3:-13.0e3)*(+_(+Q(+ra)*4.61512051684126)+-1.0)/100.0*.0001220703125;sa=oa+1|0;if((sa|0)<(ma|0)){oa=sa}else{pa=23;break}}}else{if(!na){break}if(ja<<24>>24==0){pa=23;break}else{ta=0}while(1){qa=(+(d[s+34240+(ia*1316|0)+1092+ta|0]|0)*50.98039245605469+25.490196228027344)/13.0e3;if(qa<-1.0){ua=-1.0}else{ua=qa>1.0?1.0:qa}qa=(ua>0.0?13.0e3:-13.0e3)*(+_(+Q(+ua)*4.61512051684126)+-1.0)/100.0*1.1920928955078125e-7;sa=ba(ta,ka)|0;va=0;do{wa=va+sa|0;xa=(+(d[s+34240+(ia*1316|0)+1094+wa|0]|0)*145.16128540039062+72.58064270019531)/4500.0;if(xa<-1.0){ya=-1.0}else{ya=xa>1.0?1.0:xa}g[n+(wa<<2)>>2]=qa*((ya>0.0?4500.0:-4500.0)*(+_(+Q(+ya)*4.61512051684126)+-1.0)/100.0);va=va+1|0;}while((va|0)<(ka|0));va=ta+1|0;if((va|0)<(ma|0)){ta=va}else{pa=23;break}}}}while(0);if((pa|0)==23){pa=0;if(la){pa=24}}if((pa|0)==24){pa=0;ma=c[B>>2]|0;ka=(ma-1+(ba(d[aa+114|0]|0,ca)|0)|0)/(ma|0)|0;ma=c[aa+108>>2]|0;D$a(s,s+34240+(j*1316|0)+1032|0,C,3,ma,ma+(ka<<6<<1)|0,ka)}if((ca|0)>0){ka=ea<<24>>24==0;ma=aa+114|0;ia=0;do{ja=ba(e[ga>>1]|0,ia)|0;na=Z+(ja<<2)|0;if(!ka){va=ba(ia,fa)|0;sa=0;do{Je[c[M>>2]&7](s,s+34240+(j*1316|0)+1126+(ia<<6)+(sa<<2)|0,d[s+34240+(j*1316|0)+1254+(ia<<4)+sa|0]|0,ia,c[J>>2]|0,+g[n+(sa+va<<2)>>2],$);wa=Z+((ba(sa,ha)|0)+ja<<2)|0;cf[c[L>>2]&1023](wa,wa,c[J>>2]|0,ha);sa=sa+1|0;}while((sa|0)<(fa|0))}if(la){sa=o+((ba(d[ma]|0,ia)|0)<<2)|0;le[c[D>>2]&1023](s,c[s+34240+(j*1316|0)+1300+(ia<<2)>>2]|0,c[s+34240+(j*1316|0)+1308+(ia<<2)>>2]|0,sa,na)}sa=d[s+34240+(j*1316|0)+1286+ia|0]|0;ja=d[s+34240+(j*1316|0)+1296+ia|0]|0;va=c[t>>2]|0;wa=c[va+100>>2]|0;za=va+98|0;Aa=a[za]|0;Ba=Aa&255;Ca=Ba<<d[va+105|0];Da=Ba<<d[va+106|0];a[F]=-2;Ba=va+107|0;va=a[Ba]|0;Ea=va<<24>>24==4?-2:1;a[G]=Ea;a[H]=Ea;a[I]=0;a:do{if(va<<24>>24==0){Fa=Aa}else{Ea=0;Ga=0;Ha=va&255;Ia=va;Ja=Aa;Ka=-2;while(1){La=Ga+1|0;Ma=((ba(La,Ja&255)|0)+Ka|0)/(Ha|0)|0;if((Ea|0)<(Ma|0)){Na=d[s+34240+(j*1316|0)+1288+(ia<<2)+Ga|0]|0;Oa=Ea;Pa=Ja;while(1){Qa=Pa&255;qa=+g[wa+((ba(Qa,sa)|0)+Oa<<2)>>2];g[p+(Oa<<2)>>2]=qa+ +g[wa+(Oa+Ca+(ba(Qa,Na)|0)<<2)>>2];Qa=Oa+1|0;if((Qa|0)>=(Ma|0)){break}Oa=Qa;Pa=a[za]|0}Ra=Ma;Sa=a[Ba]|0;Ta=a[za]|0}else{Ra=Ea;Sa=Ia;Ta=Ja}Pa=Sa&255;if((La|0)>=(Pa|0)){Fa=Ta;break a}Ea=Ra;Ga=La;Ha=Pa;Ia=Sa;Ja=Ta;Ka=a[m+La|0]|0}}}while(0);Ba=Fa&255;if((Fa&255)>>>0>1>>>0){sa=1;qa=+g[E>>2];while(1){Aa=p+(sa<<2)|0;xa=+g[Aa>>2];if(xa-qa<9999999747378752.0e-20){Ua=(qa+xa)*.5;g[p+(sa-1<<2)>>2]=Ua+-4999999873689376.0e-20;Va=Ua+4999999873689376.0e-20;g[Aa>>2]=Va;Wa=Va}else{Wa=xa}Aa=sa+1|0;if((Aa|0)<(Ba|0)){sa=Aa;qa=Wa}else{break}}Xa=a[za]|0}else{Xa=Fa}do{if(Xa<<24>>24==0){Ya=0}else{sa=Da+Ca|0;Ba=0;Aa=Xa&255;do{qa=+g[wa+(sa+Ba+(ba(Aa,ja)|0)<<2)>>2];va=s+240+(ia*80|0)+(Ba<<2)|0;xa=qa*+g[va>>2];Ka=p+(Ba<<2)|0;Va=+g[Ka>>2];g[va>>2]=Va;g[Ka>>2]=xa+(1.0-qa)*Va;Ba=Ba+1|0;Za=a[za]|0;Aa=Za&255;}while((Ba|0)<(Aa|0));if(!((Za&255)>>>0>1>>>0)){Ya=Za;break}Ba=1;Va=+g[E>>2];while(1){sa=p+(Ba<<2)|0;qa=+g[sa>>2];if(qa-Va<9999999747378752.0e-20){xa=(Va+qa)*.5;g[p+(Ba-1<<2)>>2]=xa+-4999999873689376.0e-20;Ua=xa+4999999873689376.0e-20;g[sa>>2]=Ua;_a=Ua}else{_a=qa}sa=Ba+1|0;if((sa|0)<(Aa|0)){Ba=sa;Va=_a}else{break}}Ba=a[za]|0;Aa=Ba&255;if(!((Ba&255)>>>0>1>>>0)){Ya=Ba;break}Ba=1;Va=+g[E>>2];while(1){sa=p+(Ba<<2)|0;qa=+g[sa>>2];if(qa-Va<9500000305706635.0e-20){Ua=(Va+qa)*.5;g[p+(Ba-1<<2)>>2]=Ua+-47500001528533176.0e-21;xa=Ua+47500001528533176.0e-21;g[sa>>2]=xa;$a=xa}else{$a=qa}sa=Ba+1|0;if((sa|0)<(Aa|0)){Ba=sa;Va=$a}else{break}}Ya=a[za]|0}}while(0);RKa(E,Ya&255);za=c[J>>2]|0;ja=c[t>>2]|0;wa=e[ja+96>>1]|0;Ca=(wa>>>0)/((d[ja+($<<5)|0]|0)>>>0)|0;Da=ja+98|0;if((a[Da]|0)==0){ab=0}else{Ba=0;while(1){Aa=p+(Ba<<2)|0;g[Aa>>2]=+T(+g[Aa>>2])*2.0;Aa=Ba+1|0;sa=a[Da]|0;if((Aa|0)<(sa&255|0)){Ba=Aa}else{ab=sa;break}}}b:do{if(($|0)==2){Ba=Ca>>>1;E$a(s,2,za,E,Ba,8,0);sa=za+(Ba<<2)|0;E$a(s,2,sa,E,Ba,16,1);Va=+g[za+(Ba-8<<2)>>2];qa=(+g[sa>>2]-Va)/9.0;xa=Va+qa;g[za+(Ba-7<<2)>>2]=xa;Va=qa+xa;g[za+(Ba-6<<2)>>2]=Va;xa=qa+Va;g[za+(Ba-5<<2)>>2]=xa;Va=qa+xa;g[za+(Ba-4<<2)>>2]=Va;xa=qa+Va;g[za+(Ba-3<<2)>>2]=xa;Va=qa+xa;g[za+(Ba-2<<2)>>2]=Va;xa=qa+Va;g[za+(Ba-1<<2)>>2]=xa;g[sa>>2]=qa+xa;xa=+g[za+(Ca-16<<2)>>2];g[za+(Ca-15<<2)>>2]=xa;g[za+(Ca-14<<2)>>2]=xa;g[za+(Ca-13<<2)>>2]=xa;g[za+(Ca-12<<2)>>2]=xa;g[za+(Ca-11<<2)>>2]=xa;g[za+(Ca-10<<2)>>2]=xa;g[za+(Ca-9<<2)>>2]=xa;g[za+(Ca-8<<2)>>2]=xa;g[za+(Ca-7<<2)>>2]=xa;g[za+(Ca-6<<2)>>2]=xa;g[za+(Ca-5<<2)>>2]=xa;g[za+(Ca-4<<2)>>2]=xa;g[za+(Ca-3<<2)>>2]=xa;g[za+(Ca-2<<2)>>2]=xa;g[za+(Ca-1<<2)>>2]=xa}else if(($|0)==1){sa=Ca>>>1;E$a(s,1,za,E,sa,2,0);Ba=za+(sa<<2)|0;E$a(s,1,Ba,E,sa,4,1);xa=+g[za+(sa-2<<2)>>2];qa=(+g[Ba>>2]-xa)/3.0;Va=xa+qa;g[za+(sa-1<<2)>>2]=Va;g[Ba>>2]=qa+Va;Va=+g[za+(Ca-4<<2)>>2];g[za+(Ca-3<<2)>>2]=Va;g[za+(Ca-2<<2)>>2]=Va;g[za+(Ca-1<<2)>>2]=Va}else if(($|0)==0){Ba=(wa>>>0)/((d[ja|0]|0)>>>0)|0;sa=Ba>>>1;if((sa|0)==0){break}Aa=Ba-1|0;Ba=c[K>>2]|0;Ka=0;va=ab;while(1){Va=+g[Ba+(Ka<<2)>>2];Ja=va&255;qa=Va*2.0;if((va&255)>>>0>1>>>0){xa=.5;Ua=.5;Ia=0;Ha=1;while(1){bb=Ua*(+g[p+(Ia<<2)>>2]-qa)*(+g[p+((Ia|2)<<2)>>2]-qa);cb=xa*(+g[p+(Ha<<2)>>2]-qa)*(+g[p+((Ia|3)<<2)>>2]-qa);Ga=Ia+4|0;Ea=Ga|1;if((Ea|0)<(Ja|0)){xa=cb;Ua=bb;Ia=Ga;Ha=Ea}else{db=cb;eb=bb;break}}}else{db=.5;eb=.5}g[za+(Ka<<2)>>2]=.5/(eb*(qa+2.0)*eb+db*(2.0-qa)*db);Ha=a[Da]|0;Ia=Ha&255;Ua=Va*-2.0;if((Ha&255)>>>0>1>>>0){xa=.5;bb=.5;Ha=0;Ja=1;while(1){cb=bb*(+g[p+(Ha<<2)>>2]-Ua)*(+g[p+((Ha|2)<<2)>>2]-Ua);fb=xa*(+g[p+(Ja<<2)>>2]-Ua)*(+g[p+((Ha|3)<<2)>>2]-Ua);La=Ha+4|0;Ma=La|1;if((Ma|0)<(Ia|0)){xa=fb;bb=cb;Ha=La;Ja=Ma}else{gb=fb;hb=cb;break}}}else{gb=.5;hb=.5}g[za+(Aa-Ka<<2)>>2]=.5/(hb*(Ua+2.0)*hb+gb*(2.0-Ua)*gb);Ja=Ka+1|0;if((Ja|0)>=(sa|0)){break b}Ka=Ja;va=a[Da]|0}}}while(0);do{if((a[da]|0)!=0){cf[c[L>>2]&1023](na,na,c[J>>2]|0,ha);if((d[da]|0)>>>0>1>>>0){ib=na;jb=1}else{break}do{ib=ib+(ha<<2)|0;jb=jb+1|0;cf[c[L>>2]&1023](ib,ib,c[J>>2]|0,ha);}while((jb|0)<(d[da]|0))}}while(0);ia=ia+1|0;}while((ia|0)<(ca|0))}ca=c[w>>2]|0;ia=c[z+(ca*1316|0)+4>>2]|0;da=c[z+(ca*1316|0)>>2]|0;ha=ba(e[N>>1]|0,ca)|0;ca=c[t>>2]|0;$=c[u>>2]|0;ma=c[O>>2]|0;la=$+(ma<<2)|0;c:do{if((c[(c[A>>2]|0)+416>>2]|0)>0){fa=ca+96|0;Z=s+40+(ia<<6)|0;ka=l+(d[15640+da|0]<<2)|0;ga=(ia|0)==1;aa=(da|0)==4;ea=s+40+(ia<<6)+44|0;na=ga?8:da;Da=(da|0)==7;za=0;ja=ca;while(1){wa=c[b>>2]|0;Ca=e[fa>>1]|0;va=ba(Ca,za)|0;Ka=e[ja+96>>1]|0;sa=ja+(ia<<5)|0;Aa=a[sa]|0;Ba=Aa&255;Ja=(Ka>>>0)/(Ba>>>0)|0;Ha=c[J>>2]|0;Ia=c[P>>2]|0;c[R>>2]=(Ka>>>0)/((d[ja+64|0]|0)>>>0)|0;c[S>>2]=(Ka>>>0)/((d[ja+32|0]|0)>>>0)|0;c[U>>2]=(Ka>>>0)/(d[ja|0]<<1>>>0)|0;Ma=c[ka>>2]|0;if(!(Aa<<24>>24==0)){Aa=za<<1;La=Ja>>>1;Ea=0;Ga=Ia+((ba(Ka,Aa)|0)<<2)|0;Ia=$+((ba(Ca,Aa)|0)+ma+((Ka-Ja|0)/2|0)<<2)|0;Aa=Ba;while(1){if((Ea|0)==0&aa){kb=4}else{kb=(Ea|0)==(Aa-1|0)&Da?7:na}Ba=c[l+(d[15640+kb|0]<<2)>>2]|0;Ca=ba(Ea,Ja)|0;Pa=Ha+(Ca<<2)|0;Xe[c[ea>>2]&4095](Z,Pa,wa+(Ca+va<<2)|0);Oa=Ja-Ba|0;Na=(Oa|0)/2|0;Qa=Ba>>>0>65535>>>0;lb=Qa?Ba>>>16:Ba;mb=Qa?16:0;if((lb&65280|0)==0){nb=mb;ob=lb}else{nb=mb|8;ob=lb>>>8}lb=(Ba|0)/2|0;le[c[V>>2]&1023](Ga,Ia+(Na<<2)|0,Pa,c[1138224+((d[1191992+ob|0]|0)+nb<<2)>>2]|0,lb);UGb(Ga+(Ba<<2)|0,Ha+(lb+Ca<<2)|0,Ja-lb<<2)|0;lb=Ea+1|0;Pa=d[sa]|0;if((lb|0)<(Pa|0)){Ea=lb;Ga=Ga+((ga?Na:Oa)+Ba<<2)|0;Ia=Ha+(Ca+La<<2)|0;Aa=Pa}else{break}}}c[s+34200+(za<<2)>>2]=(Ma+Ka|0)/2|0;Aa=za+1|0;if((Aa|0)>=(c[(c[A>>2]|0)+416>>2]|0)){break c}za=Aa;ja=c[t>>2]|0}}}while(0);do{if(!W){ia=c[O>>2]|0;da=ca+96|0;ja=(e[da>>1]|0)-ia|0;za=c[y>>2]|0;ga=za+(ha<<2)|0;Z=ja<<2;UGb(ga|0,la|0,Z)|0;ea=ja+ha|0;ja=ia<<2;UGb(za+(ea<<2)|0,c[P>>2]|0,ja)|0;if((c[(c[A>>2]|0)+416>>2]|0)!=2){break}za=c[X>>2]|0;ia=za+(ha<<2)|0;UGb(ia|0,$+((e[da>>1]<<1)+ma<<2)|0,Z)|0;UGb(za+(ea<<2)|0,(c[P>>2]|0)+(e[da>>1]<<1<<2)|0,ja)|0;Xe[c[Y>>2]&4095](ga,ia,e[da>>1]|0)}}while(0);ma=c[u>>2]|0;c[u>>2]=c[P>>2];c[P>>2]=ma;j=(c[w>>2]|0)+1|0;c[w>>2]=j;}while((j|0)<(c[q>>2]|0))}q=c[v>>2]|0;if((q|0)<2){c[v>>2]=q+1;c[h>>2]=0;x=r;i=k;return x|0}else{c[h>>2]=1;h=c[f>>2]|0;x=(r|0)==(h+1|0)?r:h;i=k;return x|0}return 0}function B$a(a){a=a|0;var b=0;b=c[a+60>>2]|0;bLa(b+40|0);ZDb(c[b+34212>>2]|0);bLa(b+104|0);ZDb(c[b+34216>>2]|0);bLa(b+168|0);ZDb(c[b+34220>>2]|0);ZDb(c[b+34192>>2]|0);ZDb(c[b+34188>>2]|0);ZDb(c[b+34196>>2]|0);ZDb(c[b+34224>>2]|0);return 0}function C$a(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;h=i;i=i+16|0;j=h|0;k=f+60|0;l=c[k>>2]|0;m=l;n=l;c[n>>2]=f;c[f+420>>2]=8;o=f+432|0;p=c[o>>2]|0;do{if((p|0)==0){q=l+34228|0;r=(c[q>>2]|0)+7>>3;c[o>>2]=r;s=r;t=c[q>>2]|0}else{q=p<<3;r=c[l+34228>>2]|0;if((q|0)>=(r|0)){s=p;t=r;break}yDb(f,16,2313440,(u=i,i=i+16|0,c[u>>2]=q,c[u+8>>2]=r,u)|0);i=u;v=-1094995529;i=h;return v|0}}while(0);p=(s<<3|0)/(t|0)|0;c[l+34232>>2]=p;if((p|0)>2){yDb(f,16,2179808,(u=i,i=i+8|0,c[u>>2]=p,u)|0);i=u;v=-1094995529;i=h;return v|0}fCb(l+4|0,c[f+88>>2]&8388608);p=l+232|0;t=c[p>>2]|0;s=t+96|0;o=e[s>>1]|0;r=t|0;q=(o>>>0)/((d[r]|0)>>>0)|0;w=t+32|0;x=(o>>>0)/((d[w]|0)>>>0)|0;o=c[(c[n>>2]|0)+416>>2]|0;y=(o|0)==1?2.0:1.0;z=0;while(1){if((z|0)>=3){A=10;break}B=c[p>>2]|0;C=((e[B+96>>1]|0)>>>0)/((d[B+(z<<5)|0]|0)>>>0)|0;B=(C&65280|0)==0;D=aLa(m+40+(z<<6)|0,(d[1191992+(B?C:C>>>8)|0]|0)+1+(B?0:8)|0,1,+R(y/+(C|0))*-30517578125.0e-15)|0;if((D|0)==0){z=z+1|0}else{E=D;break}}a:do{if((A|0)==10){z=WDb(e[s>>1]<<2)|0;D=l+34224|0;c[D>>2]=z;C=b[s>>1]|0;do{if((z|0)==0){if(C<<16>>16==0){F=0;break}yDb(c[n>>2]|0,16,2047176,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12;break a}else{F=C&65535}}while(0);C=o<<3;z=WDb(ba(F,C)|0)|0;c[l+34188>>2]=z;B=e[s>>1]|0;do{if((z|0)==0){if(((ba(o<<1,B)|0)&1073741822|0)==0){break}yDb(c[n>>2]|0,16,2047176,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12;break a}}while(0);z=WDb(ba(B,C)|0)|0;c[l+34192>>2]=z;G=e[s>>1]|0;do{if((z|0)==0){if(((ba(o<<1,G)|0)&1073741822|0)==0){break}yDb(c[n>>2]|0,16,2047176,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12;break a}}while(0);z=WDb(ba(G,C)|0)|0;c[l+34196>>2]=z;B=e[s>>1]|0;do{if((z|0)==0){if(((ba(o<<1,B)|0)&1073741822|0)==0){break}yDb(c[n>>2]|0,16,2047176,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12;break a}}while(0);z=(B<<2>>>0)/((d[r]|0)>>>0)|0;y=6.283185307179586/+(z|0);C=z>>>2;G=WDb(C<<2)|0;H=G;c[l+34212>>2]=H;do{if((G|0)!=0|(C|0)==0){I=z>>>3;J=0;do{g[H+(J<<2)>>2]=+T(y*+(J<<1|1|0));J=J+1|0;}while((J|0)<=(I|0));if(z>>>0>15>>>0){J=1;do{g[H+(C-J<<2)>>2]=+g[H+(J<<2)>>2];J=J+1|0;}while((J|0)<(I|0))}I=(e[s>>1]<<2>>>0)/((d[w]|0)>>>0)|0;K=6.283185307179586/+(I|0);J=I>>>2;L=WDb(J<<2)|0;M=L;c[l+34216>>2]=M;if(!((L|0)!=0|(J|0)==0)){break}L=I>>>3;N=0;do{g[M+(N<<2)>>2]=+T(K*+(N<<1|1|0));N=N+1|0;}while((N|0)<=(L|0));if(I>>>0>15>>>0){N=1;do{g[M+(J-N<<2)>>2]=+g[M+(N<<2)>>2];N=N+1|0;}while((N|0)<(L|0))}L=(e[s>>1]<<2>>>0)/((d[t+64|0]|0)>>>0)|0;K=6.283185307179586/+(L|0);N=L>>>2;M=WDb(N<<2)|0;J=M;c[l+34220>>2]=J;if(!((M|0)!=0|(N|0)==0)){break}M=L>>>3;I=0;do{g[J+(I<<2)>>2]=+T(K*+(I<<1|1|0));I=I+1|0;}while((I|0)<=(M|0));if(L>>>0>15>>>0){I=1;do{g[J+(N-I<<2)>>2]=+g[J+(I<<2)>>2];I=I+1|0;}while((I|0)<(M|0))}M=(x&65280|0)==0;VXa((d[1191992+(M?x:x>>>8)|0]|0)+(M?0:8)|0);M=q>>>1;I=(M&32512|0)==0;VXa((d[1191992+(I?M:q>>>9)|0]|0)+(I?0:8)|0);I=e[s>>1]|0;M=(I&65280|0)==0;VXa((M?0:8)+(d[1191992+(M?I:I>>>8)|0]|0)|0);I=c[p>>2]|0;M=c[n>>2]|0;J=c[M+416>>2]|0;N=I+96|0;L=(d[I+105|0]|0)+(d[I+104|0]|0)+(ba(d[I+106|0]|0,d[I+107|0]|0)|0)|0;O=I+113|0;P=ba(d[I+17|0]|0,d[I+16|0]|0)|0;Q=ba(d[I+49|0]|0,d[I+48|0]|0)|0;S=(ba(e[N>>1]|0,c[M+72>>2]|0)|0)/(c[M+412>>2]|0)|0;M=(ba(L,J)|0)+(J<<3|4)|0;L=(ba((d[I+115|0]|0)+1+(d[O]|0)+(d[I+112|0]|0)+(ba(d[I+81|0]|0,d[I+80|0]|0)|0)|0,J)|0)+M|0;U=j+8|0;c[U>>2]=L;c[j>>2]=(ba(ba(P+6|0,J)|0,d[I|0]|0)|0)+M;P=(ba(ba(Q+6|0,J)|0,d[I+32|0]|0)|0)+M|0;M=j+4|0;c[M>>2]=P;do{if((c[l+36872>>2]|0)==1){if((c[l+236>>2]|0)!=0){break}c[M>>2]=P+2;c[U>>2]=L+2}}while(0);L=I+114|0;U=0;while(1){if((U|0)==3){P=ba(d[O]|0,J)|0;V=P;W=d[L]|0}else{V=S-(c[j+(U<<2)>>2]|0)|0;W=e[N>>1]|0}P=ba(W,J)|0;M=(V+13|0)/14|0;Q=m+34172+(U<<2)|0;c[Q>>2]=M;X=(V-1+M|0)/(M|0)|0;Y=(V|0)/(M|0)|0;Z=M+V-(ba(X,M)|0)|0;a[m+34140+(U<<1)|0]=(X+1|0)/2|0;a[m+34148+(U<<1)|0]=(X|0)/2|0;a[m+34140+(U<<1)+1|0]=(Y+1|0)/2|0;a[m+34148+(U<<1)+1|0]=(Y|0)/2|0;c[m+34156+(U<<2)>>2]=Z;Z=c[Q>>2]|0;Q=(P-1+Z|0)/(Z|0)|0;Y=Z+P-(ba(Q,Z)|0)|0;a[m+34128+(U<<1)|0]=Q;a[m+34128+(U<<1)+1|0]=(P|0)/(Z|0)|0;a[m+34136+U|0]=Y;Y=U+1|0;if((Y|0)<4){U=Y}else{_=0;break}}do{U=c[p>>2]|0;J=c[D>>2]|0;N=c[(c[n>>2]|0)+416>>2]|0;if((_|0)==3){$=d[U+114|0]|0;aa=N}else{S=d[U+(_<<5)|0]|0;L=ba(S,N)|0;$=((e[U+96>>1]|0)>>>0)/(S>>>0)|0;aa=L}L=c[m+34172+(_<<2)>>2]|0;S=m+34128+(_<<1)|0;U=m+34136+_|0;N=a[S]|0;if(!(N<<24>>24==0)){O=(aa|0)==1;I=(L|0)>0;Y=ba($,aa)|0;Z=(_|0)==2;P=m+34128+(_<<1)+1|0;Q=(L&1|0)==0;X=0;M=N;while(1){do{if(O){ca=0}else{if(Z){if(((L|0)%(aa|0)|0|0)!=0){ca=0;break}ca=(X|0)==(d[P]|0)?0:X;break}if(!Q){ca=0;break}N=(X|0)==(d[P]|0);if(N){ca=N?0:X;break}ca=ba(X,X)|0}}while(0);N=ba(X,L)|0;if(I){da=0;do{ea=da+N|0;if((ea|0)>=(Y|0)){break}b[J+(ea<<1)>>1]=((da+ca|0)%(L|0)|0)+N;da=da+1|0;}while((da|0)<(L|0));fa=a[S]|0}else{fa=M}da=X+1|0;if((da|0)<(fa&255|0)){X=da;M=fa}else{break}}}M=d[U]|0;if((L|0)>0){X=0;S=0;while(1){Y=((X|0)>=(M|0))+(m+34128+(_<<1))|0;if((a[Y]|0)==0){ga=S}else{I=0;P=S;while(1){Q=P+1|0;b[m+1360+(_<<13)+(P<<1)>>1]=b[J+((ba(I,L)|0)+X<<1)>>1]|0;Z=I+1|0;if((Z|0)<(d[Y]|0)){I=Z;P=Q}else{ga=Q;break}}}P=X+1|0;if((P|0)<(L|0)){X=P;S=ga}else{break}}}S=ba($,aa)|0;if((S|0)>0){X=0;do{L=m+1360+(_<<13)+(X<<1)|0;J=b[L>>1]|0;b[L>>1]=(ba((J|0)%(aa|0)|0,$)|0)+((J|0)/(aa|0)|0);X=X+1|0;}while((X|0)<(S|0))}_=_+1|0;}while(_>>>0<4>>>0);g[l+400>>2]=.10000000149011612;g[l+404>>2]=.10000000149011612;g[l+408>>2]=.10000000149011612;v=0;i=h;return v|0}}while(0);yDb(c[n>>2]|0,16,2047176,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12}}while(0);yDb(f,16,2103480,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;u=c[k>>2]|0;bLa(u+40|0);ZDb(c[u+34212>>2]|0);bLa(u+104|0);ZDb(c[u+34216>>2]|0);bLa(u+168|0);ZDb(c[u+34220>>2]|0);ZDb(c[u+34192>>2]|0);ZDb(c[u+34188>>2]|0);ZDb(c[u+34196>>2]|0);ZDb(c[u+34224>>2]|0);v=E;i=h;return v|0}function D$a(e,f,h,i,j,k,l){e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0;m=c[e+34172+(i<<2)>>2]|0;if((m|0)<=0){return}n=e+34136+i|0;o=c[e+34156+(i<<2)>>2]|0;p=0;q=0;r=f;while(1){f=a[((p|0)>=(d[n]|0))+(e+34128+(i<<1))|0]|0;s=f&255;t=(p|0)>=(o|0)|0;u=d[r]|0;if((a[e+34140+(i<<1)+t|0]|0)==7){v=(u>>>5&2^2)-1|0;w=u&63}else{v=1;w=u}u=r+2|0;x=d[r+1|0]|0;if((a[e+34148+(i<<1)+t|0]|0)==7){y=(x>>>5&2^2)-1|0;z=x&63}else{y=1;z=x}x=ba(w,l)|0;t=ba(z,l)|0;if(!(f<<24>>24==0)){f=0;do{A=ba(b[j+(f+x<<1)>>1]|0,v)|0;B=+((ba(b[k+(f+t<<1)>>1]|0,y)|0)+A|0);g[h+(b[e+1360+(i<<13)+(f+q<<1)>>1]<<2)>>2]=B;f=f+1|0;}while((f|0)<(s|0))}f=p+1|0;if((f|0)>=(m|0)){break}p=f;q=s+q|0;r=u}return}function E$a(b,d,e,f,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0.0,n=0,o=0,p=0.0,q=0.0,r=0,s=0.0,t=0.0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0,K=0,L=0,M=0.0,N=0.0,O=0,P=0,Q=0.0,R=0.0;k=c[b+232>>2]|0;l=c[b+34212+(d<<2)>>2]|0;if((h|0)>0){d=k+98|0;if((j|0)==0){b=0;do{m=+g[l+(b<<2)>>2]*2.0;n=a[d]|0;o=n&255;if((n&255)>>>0>1>>>0){p=.5;q=.5;n=0;r=1;while(1){s=q*(+g[f+(n<<2)>>2]-m)*(+g[f+((n|2)<<2)>>2]-m);t=p*(+g[f+(r<<2)>>2]-m)*(+g[f+((n|3)<<2)>>2]-m);u=n+4|0;v=u|1;if((v|0)<(o|0)){p=t;q=s;n=u;r=v}else{w=t;x=s;break}}}else{w=.5;x=.5}g[e+(b<<2)>>2]=.5/(x*(m+2.0)*x+w*(2.0-m)*w);b=b+i|0;}while((b|0)<(h|0))}else{b=0;do{w=+g[l+(~b+h<<2)>>2]*-2.0;r=a[d]|0;n=r&255;if((r&255)>>>0>1>>>0){x=.5;q=.5;r=0;o=1;while(1){p=q*(+g[f+(r<<2)>>2]-w)*(+g[f+((r|2)<<2)>>2]-w);s=x*(+g[f+(o<<2)>>2]-w)*(+g[f+((r|3)<<2)>>2]-w);v=r+4|0;u=v|1;if((u|0)<(n|0)){x=s;q=p;r=v;o=u}else{y=s;z=p;break}}}else{y=.5;z=.5}g[e+(b<<2)>>2]=.5/(z*(w+2.0)*z+y*(2.0-w)*y);b=b+i|0;}while((b|0)<(h|0))}}b=i<<1;d=h-b|0;if((d|0)<(i|0)){A=i-1|0;B=+(i|0)}else{o=(i|0)/2|0;r=(j|0)==0;j=k+98|0;k=o-1|0;y=+(o|0);n=(k|0)>0;u=1-i|0;v=i-1|0;z=+(i|0);C=(v|0)>0;D=i;while(1){E=D+i|0;q=+g[e+(E<<2)>>2];F=e+(D-i<<2)|0;x=+g[F>>2];G=e+(D<<2)|0;m=+g[G>>2];do{if(q+x<=m*1.95&q<x){H=D-o|0;if(r){I=+g[l+(H<<2)>>2]}else{I=-0.0- +g[l+(~H+h<<2)>>2]}J=a[j]|0;K=J&255;p=I*2.0;if((J&255)>>>0>1>>>0){s=.5;t=.5;J=0;L=1;while(1){M=t*(+g[f+(J<<2)>>2]-p)*(+g[f+((J|2)<<2)>>2]-p);N=s*(+g[f+(L<<2)>>2]-p)*(+g[f+((J|3)<<2)>>2]-p);O=J+4|0;P=O|1;if((P|0)<(K|0)){s=N;t=M;J=O;L=P}else{Q=N;R=M;break}}}else{Q=.5;R=.5}t=.5/(R*(p+2.0)*R+Q*(2.0-p)*Q);L=e+(H<<2)|0;g[L>>2]=t;s=+g[F>>2];M=(t-s)/y;if(!n){break}J=u+D|0;K=0;t=s;do{t=M+t;g[e+(J+K<<2)>>2]=t;K=K+1|0;}while((K|0)<(k|0));t=+g[L>>2];M=(+g[G>>2]-t)/y;if(!n){break}K=D+1-o|0;J=0;p=t;do{p=M+p;g[e+(K+J<<2)>>2]=p;J=J+1|0;}while((J|0)<(k|0))}else{p=(m-x)/z;if(!C){break}J=u+D|0;K=0;M=x;do{M=p+M;g[e+(J+K<<2)>>2]=M;K=K+1|0;}while((K|0)<(v|0))}}while(0);if((E|0)>(d|0)){A=v;B=z;break}else{D=E}}}z=+g[e+(d<<2)>>2];y=(+g[e+(h-i<<2)>>2]-z)/B;if((A|0)<=0){return}i=h+1-b|0;b=0;B=z;do{B=y+B;g[e+(i+b<<2)>>2]=B;b=b+1|0;}while((b|0)<(A|0));return}function F$a(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;f=c[a+60>>2]|0;g=c[a+96>>2]|0;do{if((g|0)!=0){if((c[a+100>>2]|0)<12){break}h=g;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=fe(j|0)|0;k=h+1|0;c[a+416>>2]=k;l=g+4|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)*1e3|0;c[a+72>>2]=m;l=g+8|0;n=fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;if((n-8|0)>>>0>36>>>0){yDb(a,16,2103432,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}if((n|0)==44){c[a+412>>2]=44100;q=44100}else if((n|0)==22){c[a+412>>2]=22050;q=22050}else if((n|0)==11){c[a+412>>2]=11025;q=11025}else{l=n*1e3|0;c[a+412>>2]=l;q=l}if(h>>>0>1>>>0){yDb(a,16,2047056,(o=i,i=i+8|0,c[o>>2]=k,o)|0);i=o;p=-1;i=b;return p|0}h=(j|0)==0;j=a+448|0;c[j>>2]=h?4:3;c[j+4>>2]=h?0:0;h=(m|0)/(k*1e3|0|0)|0;if((h-8|0)>>>0>40>>>0){yDb(a,16,2001392,(o=i,i=i+8|0,c[o>>2]=h,o)|0);i=o;p=-1094995529;i=b;return p|0}k=h+(n<<8)|0;if((k|0)==2056){c[f+232>>2]=677928;r=677928}else if((k|0)==2824){c[f+232>>2]=677808;r=677808}else if((k|0)==5656){c[f+232>>2]=677328;r=677328}else if((k|0)==5652){c[f+232>>2]=677448;r=677448}else if((k|0)==5664){c[f+232>>2]=677208;r=677208}else if((k|0)==4112){c[f+232>>2]=677568;r=677568}else if((k|0)==11304){c[f+232>>2]=677088;r=677088}else if((k|0)==2826){c[f+232>>2]=677688;r=677688}else if((k|0)==11312){c[f+232>>2]=676968;r=676968}else{yDb(a,16,1964288,(o=i,i=i+16|0,c[o>>2]=n,c[o+8>>2]=n,o)|0);i=o;p=-1;i=b;return p|0}c[f+36872>>2]=0;c[f+36876>>2]=676;c[f+36880>>2]=2;c[f+36884>>2]=118;n=((ba(e[r+96>>1]|0,m)|0)/(q|0)|0)+8|0;c[f+34228>>2]=n;c[f+236>>2]=0;m=c[a+432>>2]|0;do{if((m|0)!=0){if(((m<<3|0)/(n|0)|0|0)<=1){break}yDb(a,16,1936176,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}}while(0);p=C$a(a)|0;i=b;return p|0}}while(0);yDb(a,16,2179768,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}function G$a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;j=c[e+232>>2]|0;k=c[(c[e>>2]|0)+416>>2]|0;l=g<<3;g=l>>>0>2147483639>>>0|(f|0)==0;m=g?0:f;f=g?8:l+8|0;l=m;g=((d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)&255)+(f>>>0>8>>>0?8:f)|0;l=f>>>0>g>>>0?g:f;g=m+(l>>>3)|0;n=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(l&7);g=n>>>28;o=l+4|0;l=f>>>0>o>>>0?o:f;c[e+34240>>2]=g;if(n>>>0>2415919103>>>0){yDb(b,16,1912656,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;p=-1094995529;i=h;return p|0}b=c[1109088+(g<<2)>>2]|0;g=e+34244|0;c[g>>2]=b;n=a[j+(b<<5)|0]|0;o=n&255;q=e+34172+(b<<2)|0;if((c[q>>2]|0)>0){r=e+34156+(b<<2)|0;s=0;t=e+34248|0;u=l;while(1){v=(s|0)>=(c[r>>2]|0)|0;w=d[e+34140+(b<<1)+v|0]|0;x=m+(u>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(u&7)>>>((32-w|0)>>>0);x=w+u|0;w=f>>>0>x>>>0?x:f;a[t]=y;y=d[e+34148+(b<<1)+v|0]|0;v=m+(w>>>3)|0;x=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(w&7)>>>((32-y|0)>>>0);v=w+y|0;y=f>>>0>v>>>0?v:f;a[t+1|0]=x;x=s+1|0;if((x|0)<(c[q>>2]|0)){s=x;t=t+2|0;u=y}else{z=y;break}}}else{z=l}l=(k|0)>0;do{if(l){u=n<<24>>24==0;t=z;s=0;while(1){if(u){A=t}else{q=t;b=0;r=c[g>>2]|0;while(1){if((a[j+(r<<5)+16|0]|0)==0){B=q;C=r}else{y=q;x=0;v=r;while(1){w=d[j+(v<<5)+17|0]|0;D=m+(y>>>3)|0;E=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(y&7)>>>((32-w|0)>>>0);D=w+y|0;w=f>>>0>D>>>0?D:f;a[e+35366+(s<<6)+(b<<2)+x|0]=E;E=x+1|0;D=c[g>>2]|0;if((E|0)<(d[j+(D<<5)+16|0]|0)){y=w;x=E;v=D}else{B=w;C=D;break}}}v=b+1|0;if((v|0)<(o|0)){q=B;b=v;r=C}else{A=B;break}}}r=s+1|0;if((r|0)<(k|0)){t=A;s=r}else{break}}if(n<<24>>24==0|l^1){F=A;break}else{G=A;H=0}while(1){s=G;t=0;while(1){I=((s|0)<(f|0))+s|0;a[e+35494+(H<<4)+t|0]=d[m+(s>>>3)|0]<<(s&7)>>>7&1;u=t+1|0;if((u|0)<(o|0)){s=I;t=u}else{break}}t=H+1|0;if((t|0)<(k|0)){G=I;H=t}else{F=I;break}}}else{F=z}}while(0);a:do{if((c[g>>2]|0)==2){if(l){J=F;K=0}else{L=F;break}while(1){z=m+(J>>>3)|0;I=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(J&7)>>>24;z=J+8|0;H=f>>>0>z>>>0?z:f;a[e+35332+K|0]=I;I=K+1|0;if((I|0)<(k|0)){J=H;K=I}else{M=H;N=25;break}}}else{if(!l){L=F;break}if(n<<24>>24==0){H=F;I=0;while(1){z=m+(H>>>3)|0;G=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(H&7)>>>24;z=H+8|0;A=f>>>0>z>>>0?z:f;a[e+35332+I|0]=G;G=I+1|0;if((G|0)<(k|0)){H=A;I=G}else{M=A;N=25;break a}}}else{O=F;P=0}while(1){I=m+(O>>>3)|0;H=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(O&7)>>>24;I=O+8|0;a[e+35332+P|0]=H;H=ba(P,o)|0;A=f>>>0>I>>>0?I:f;I=0;do{G=m+(A>>>3)|0;z=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(A&7)>>>27;G=A+5|0;A=f>>>0>G>>>0?G:f;a[I+H+(e+35334)|0]=z;I=I+1|0;}while((I|0)<(o|0));I=P+1|0;if((I|0)<(k|0)){O=A;P=I}else{M=A;N=25;break}}}}while(0);do{if((N|0)==25){if(!l){L=M;break}P=j+104|0;O=j+105|0;o=j+107|0;F=j+106|0;n=M;K=0;while(1){J=d[P]|0;I=m+(n>>>3)|0;H=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(n&7)>>>((32-J|0)>>>0);I=J+n|0;J=f>>>0>I>>>0?I:f;a[e+35536+K|0]=H;H=d[O]|0;I=m+(J>>>3)|0;z=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>((32-H|0)>>>0);I=J+H|0;H=f>>>0>I>>>0?I:f;a[e+35526+K|0]=z;if((a[o]|0)==0){Q=H}else{z=H;H=0;while(1){I=d[F]|0;J=m+(z>>>3)|0;G=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(z&7)>>>((32-I|0)>>>0);J=I+z|0;I=f>>>0>J>>>0?J:f;a[e+35528+(K<<2)+H|0]=G;G=H+1|0;if((G|0)<(d[o]|0)){z=I;H=G}else{Q=I;break}}}H=K+1|0;if((H|0)<(k|0)){n=Q;K=H}else{L=Q;break}}}}while(0);do{if((c[g>>2]|0)==2){Q=e+34184|0;if((c[Q>>2]|0)>0){M=e+34168|0;N=0;K=e+35272|0;n=L;while(1){o=(N|0)>=(c[M>>2]|0)|0;F=d[e+34146+o|0]|0;O=m+(n>>>3)|0;P=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(n&7)>>>((32-F|0)>>>0);O=F+n|0;F=f>>>0>O>>>0?O:f;a[K]=P;P=d[e+34154+o|0]|0;o=m+(F>>>3)|0;O=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(F&7)>>>((32-P|0)>>>0);o=F+P|0;P=f>>>0>o>>>0?o:f;a[K+1|0]=O;O=N+1|0;if((O|0)<(c[Q>>2]|0)){N=O;K=K+2|0;n=P}else{R=P;break}}}else{R=L}if(!l){S=R;break}n=j+112|0;K=j+115|0;N=R;Q=0;while(1){M=d[n]|0;P=m+(N>>>3)|0;O=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(N&7)>>>((32-M|0)>>>0);P=M+N|0;M=f>>>0>P>>>0?P:f;c[e+35540+(Q<<2)>>2]=O;O=d[K]|0;P=m+(M>>>3)|0;o=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7)>>>((32-O|0)>>>0);P=M+O|0;O=f>>>0>P>>>0?P:f;c[e+35548+(Q<<2)>>2]=o;o=Q+1|0;if((o|0)<(k|0)){N=O;Q=o}else{S=O;break}}}else{S=L}}while(0);p=(S+7|0)/8|0;i=h;return p|0}function H$a(e,f,h,j,k,l,m){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=+l;m=m|0;var n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0.0,G=0,H=0,I=0,J=0,K=0,L=0;n=i;i=i+16|0;o=n|0;p=c[e+232>>2]|0;g[o>>2]=.4000000059604645;g[o+4>>2]=.3499999940395355;g[o+8>>2]=.2800000011920929;q=+g[o+(m<<2)>>2];o=a[p+(m<<5)+16|0]|0;r=o&255;s=(d[p+(m<<5)+8|0]|0)/(o&255)|0;t=s&255;if(s<<24>>24==0){i=n;return}s=o<<24>>24==0;o=p+(m<<5)+12|0;u=(h|0)==0;h=p+(m<<5)+4|0;v=1.0-q;p=r>>>0>1>>>0?r:1;w=0;x=0;y=k;while(1){if(s){z=x;A=y}else{k=c[o>>2]|0;if(u){B=0;C=x;D=y;while(1){E=+(b[k+((ba(d[f+B|0]|0,t)|0)+w<<1)>>1]|0)*.000244140625;F=E+1.0;g[e+400+(m*320|0)+(j*160|0)+(C<<2)>>2]=E;E=(F<-1.0?1.0:F)*l;G=b[(c[h>>2]|0)+(C<<1)>>1]|0;H=G&65535;if(!(G<<16>>16==0)){G=D;I=H;while(1){J=I-1|0;g[G>>2]=E;if((J|0)==0){break}else{G=G+4|0;I=J}}}I=D+(H<<2)|0;G=B+1|0;if((G|0)<(r|0)){B=G;C=C+1|0;D=I}else{K=I;break}}}else{D=0;C=x;B=y;while(1){E=+(b[k+((ba(d[f+D|0]|0,t)|0)+w<<1)>>1]|0)*.000244140625;I=e+400+(m*320|0)+(j*160|0)+(C<<2)|0;F=v*E+q*+g[I>>2]+1.0;g[I>>2]=E;E=(F<-1.0?1.0:F)*l;I=b[(c[h>>2]|0)+(C<<1)>>1]|0;G=I&65535;if(!(I<<16>>16==0)){I=B;J=G;while(1){L=J-1|0;g[I>>2]=E;if((L|0)==0){break}else{I=I+4|0;J=L}}}J=B+(G<<2)|0;I=D+1|0;if((I|0)<(r|0)){D=I;C=C+1|0;B=J}else{K=J;break}}}z=p+x|0;A=K}B=w+1|0;if((B|0)<(t|0)){w=B;x=z;y=A}else{break}}i=n;return}function I$a(b,f,h,i,j){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;k=c[b+232>>2]|0;l=c[b>>2]|0;b=c[l+412>>2]|0;m=(b|0)/1e3|0;n=e[k+96>>1]|0;o=n*80|0;p=m>>1;q=-p|0;r=(((o|0)!=0?p:q)+o|0)/(m|0)|0;o=n*480|0;s=25.0e3/+((1<<(d[k+115|0]|0))-1|0);t=(+(h|0)*s+s*.5)/25.0e3;if(t<-1.0){u=-1.0}else{u=t>1.0?1.0:t}t=(u>0.0?25.0e3:-25.0e3)*(+_(+Q(+u)*5.303304908059076)+-1.0)/200.0*.0001220703125;h=ba(((((o|0)!=0?p:q)+o|0)/(m|0)|0)-r|0,f)|0;f=(1<<(d[k+112|0]|0))-1|0;m=f>>1;o=((((h|0)>0?m:-m|0)+h|0)/(f|0)|0)+r|0;do{if((b-22e3|0)>>>0<1e3>>>0){if(((c[l+72>>2]|0)/((c[l+416>>2]|0)*1e3|0|0)|0|0)!=32){v=6;break}r=ba(e[k+116>>1]|0,o+800|0)|0;f=n*400|0;h=f>>>1;w=(((r|0)>0?h:-h|0)+r|0)/(f|0)|0}else{v=6}}while(0);if((v|0)==6){w=(ba(e[k+116>>1]|0,o)|0)/(n*400|0|0)|0}n=a[k+114|0]|0;k=n&255;l=i+(k<<2)|0;b=(w|0)/2|0;if((w|0)>1){f=(b|0)>1;r=0;h=i;while(1){m=j+(r<<2)|0;g[m>>2]=+g[m>>2]+t*+g[h>>2];m=r+1|0;if((m|0)<(b|0)){r=m;h=h+4|0}else{break}}x=i+((f?b:1)<<2)|0}else{x=i}i=w>>1;b=((n<<24>>24!=0?i:-i|0)+k|0)/(w|0)|0;k=(w|0)/-2|0;i=(w+1|0)/2|0;w=(k|0)<(i|0);n=i-k|0;f=x;x=1;while(1){h=(x|0)<(b|0);r=(ba(x,o)|0)+200|0;do{if(((r|0)%400|0|0)==0){if(((x|0)%5|0|0)!=0){v=14;break}m=(r|0)/400|0;q=(x|0)/5|0;p=c[194072+(q<<3)>>2]|0;y=m-1|0;z=(y<<1|0)/(p|0)|0;A=z>>>0>65535>>>0;B=A?z>>>16:z;z=A?16:0;if((B&65280|0)==0){C=z;D=B}else{C=z|8;D=B>>>8}E=m-(d[(c[194076+(q<<3)>>2]|0)+((ba((d[1191992+D|0]|0)+C|0,p)|0)+((y|0)%(p|0)|0))|0]|0)|0}else{v=14}}while(0);if((v|0)==14){v=0;E=(r|0)/400|0}if(!h){break}if(w){p=k;y=f;while(1){q=j+(p+E<<2)|0;g[q>>2]=+g[q>>2]+t*+g[y>>2];q=p+1|0;if((q|0)<(i|0)){p=q;y=y+4|0}else{break}}F=f+(n<<2)|0}else{F=f}f=F;x=x+1|0}if(w&f>>>0<l>>>0){G=k;H=f}else{return}while(1){f=H+4|0;k=j+(G+E<<2)|0;g[k>>2]=+g[k>>2]+t*+g[H>>2];k=G+1|0;if((k|0)<(i|0)&f>>>0<l>>>0){G=k;H=f}else{break}}return}function J$a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;h=i;i=i+16|0;j=h|0;k=e;l=c[g+24>>2]|0;m=g+28|0;g=c[m>>2]|0;if(!((g|0)>-1)){yDb(0,0,2001352,(n=i,i=i+24|0,c[n>>2]=1964256,c[n+8>>2]=1936088,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}o=j|0;c[o>>2]=l;c[j+8>>2]=l;p=l+g|0;q=j+4|0;c[q>>2]=p;r=p;if((g|0)<4){s=0;t=l}else{g=l+4|0;c[o>>2]=g;u=l;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;t=g}g=r-t|0;u=g>>>0>72>>>0?72:g;g=t+u|0;c[o>>2]=g;if((r-g|0)<4){v=0;w=g}else{l=t+(u+4)|0;c[o>>2]=l;u=g;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;w=l}if((r-w|0)<2){x=0;y=w}else{l=w+2|0;c[o>>2]=l;u=w;x=(d[u]|d[u+1|0]<<8)<<16>>16&65535;y=l}if((r-y|0)<2){z=0;A=y}else{l=y+2|0;c[o>>2]=l;u=y;z=(d[u]|d[u+1|0]<<8)<<16>>16&65535;A=l}if((r-A|0)<1){B=0;C=A}else{l=A+1|0;c[o>>2]=l;B=d[A]|0;C=l}l=r-C|0;A=l>>>0>2>>>0?2:l;l=C+A|0;c[o>>2]=l;if((r-l|0)<1){D=0;E=l}else{u=C+(A+1)|0;c[o>>2]=u;D=a[l]&1;E=u}if((s-8|0)>>>0>1>>>0){yDb(b,16,2179728,(n=i,i=i+8|0,c[n>>2]=s,n)|0);i=n;F=-1163346256;i=h;return F|0}s=(B|0)==8;do{if(s){c[b+140>>2]=11}else{if((B|0)==32|(B|0)==16){c[b+140>>2]=30;break}yDb(b,16,2103400,(n=i,i=i+8|0,c[n>>2]=B,n)|0);i=n;F=-1163346256;i=h;return F|0}}while(0);u=V$a(b,x,z)|0;if((u|0)<0){F=u;i=h;return F|0}u=_$a(b,k,0)|0;if((u|0)<0){F=u;i=h;return F|0}c[e+88>>2]=1;u=c[e>>2]|0;k=c[e+32>>2]|0;a:do{if(s){l=c[e+4>>2]|0;A=0;C=E;while(1){if((r-C|0)<4){G=0;H=C}else{y=C+4|0;c[o>>2]=y;w=C;G=fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;H=y}c[l+(A<<2)>>2]=G>>>8|G<<24;y=A+1|0;if(y>>>0<256>>>0){A=y;C=H}else{break}}C=r-H|0;if(C>>>0<(ba(z,x)|0)>>>0){F=-1094995529;i=h;return F|0}A=H+(C>>>0>4>>>0?4:C)|0;c[o>>2]=A;if((z|0)==0){break}else{I=1;J=u;K=A;L=p}while(1){A=L-K|0;C=A>>>0>x>>>0?x:A;UGb(J|0,K|0,C)|0;A=(c[o>>2]|0)+C|0;c[o>>2]=A;if(!(I>>>0<z>>>0)){break a}I=I+1|0;J=J+k|0;K=A;L=c[q>>2]|0}}else{do{if((B|0)==32){if(!((v-21|0)>>>0<2>>>0)){break}A=x<<2;if((r-E|0)>>>0<(ba(A,z)|0)>>>0){F=-1094995529;i=h;return F|0}if((z|0)==0){break a}else{M=1;N=u;O=E;P=p}while(1){C=P-O|0;l=C>>>0>A>>>0?A:C;UGb(N|0,O|0,l)|0;C=(c[o>>2]|0)+l|0;c[o>>2]=C;if(!(M>>>0<z>>>0)){break a}M=M+1|0;N=N+k|0;O=C;P=c[q>>2]|0}}else if((B|0)==16){A=r-E|0;C=E+(A>>>0>4>>>0?4:A)|0;c[o>>2]=C;if((v|0)==861165636){if((r-C|0)>>>0<(ba(x>>>2<<4,z>>>2)|0)>>>0){F=-1094995529;i=h;return F|0}else{pob(j,u,x,z,k);break a}}else if((v|0)==0){if((D|0)==0){break}}else if((v|0)!=827611204){break}if((r-C|0)>>>0<(ba(x>>>2<<3,z>>>2)|0)>>>0){F=-1094995529;i=h;return F|0}else{nob(j,u,x,z,k);break a}}else{break a}}while(0);yDb(b,16,2047024,(n=i,i=i+8|0,c[n>>2]=v,n)|0);i=n;F=-1163346256;i=h;return F|0}}while(0);c[f>>2]=1;F=c[m>>2]|0;i=h;return F|0}function K$a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;d=c[a+120>>2]|0;c[b+4>>2]=d;e=c[a+124>>2]|0;c[b+8>>2]=e;c[b+12>>2]=ba((e|0)/8|0,(d|0)/8|0)|0;c[a+140>>2]=6;c[b+20>>2]=163344;a=ICb()|0;c[b+16>>2]=a;return((a|0)==0?-12:0)|0}function L$a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;h=i;i=i+40|0;j=h|0;k=h+16|0;l=h+24|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;o=g+16|0;p=$$a(b,c[o>>2]|0)|0;if((p|0)<0){q=p;i=h;return q|0}if(!((n|0)>-1)){yDb(0,0,2001320,(r=i,i=i+24|0,c[r>>2]=1964240,c[r+8>>2]=1936064,c[r+16>>2]=135,r)|0);i=r;Cd();return 0}p=g+24|0;c[p>>2]=m;c[g+32>>2]=m;s=g+28|0;c[s>>2]=m+n;m=g+12|0;t=g+8|0;u=b;b=g+4|0;v=k|0;w=k+1|0;x=k+2|0;y=k+3|0;k=g+20|0;g=j|0;z=j+1|0;A=j+2|0;B=j+3|0;C=j+4|0;D=j+5|0;E=j+6|0;F=j+7|0;G=j+8|0;H=j+9|0;I=j+10|0;J=j+11|0;K=j+12|0;L=j+13|0;M=j+14|0;N=j+15|0;O=l|0;P=l+1|0;Q=l+2|0;R=l+3|0;S=l+4|0;T=l+5|0;U=l+6|0;V=l+7|0;W=l+8|0;X=l+9|0;Y=l+10|0;Z=l+11|0;_=l+12|0;$=l+13|0;aa=l+14|0;ca=l+15|0;da=0;ea=0;fa=0;ga=0;ha=0;ia=0;a:while(1){ja=c[m>>2]|0;if((fa|0)>=(ja|0)){ka=61;break}if((ea|0)>=(c[t>>2]|0)){ka=61;break}la=c[p>>2]|0;ma=c[s>>2]|0;if((ma|0)==(la|0)){ka=62;break}na=la+1|0;c[p>>2]=na;oa=a[la]|0;pa=oa&255;if((pa&248|0)==112){switch(pa|0){case 114:{da=da;ea=ea;fa=fa;ga=ga^1;ha=ha;ia=ia;continue a;break};case 113:{da=da;ea=ea;fa=fa;ga=ga;ha=1;ia=ia;continue a;break};case 115:{ka=61;break a;break};case 116:{if((ma-na|0)<1){qa=0}else{c[p>>2]=la+2;qa=d[na]|0}ra=qa+fa|0;if((ra|0)>=(ja|0)){da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=ia;continue a}ja=(qa<<3)+da|0;sa=c[b>>2]|0;if((ja|0)<(sa|0)){da=ja;ea=ea;fa=ra;ga=ga;ha=ha;ia=ia;continue a}else{ta=ja;ua=ea}while(1){ja=ta-sa|0;va=ua+8|0;if((ja|0)<(sa|0)){da=ja;ea=va;fa=ra;ga=ga;ha=ha;ia=ia;continue a}else{ta=ja;ua=va}}break};case 112:{if((ma-na|0)<1){da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=0;continue a}c[p>>2]=la+2;ra=a[na]|0;sa=ra&255;if(!((ra&255)>>>0>1>>>0)){da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=sa;continue a}yDb(u,32,2179680,(r=i,i=i+8|0,c[r>>2]=sa,r)|0);i=r;da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=sa;continue a;break};default:{yDb(u,32,2103368,(r=i,i=i+8|0,c[r>>2]=pa,r)|0);i=r;da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=ia;continue a}}}do{if((ha|ga|0)==0){if(oa<<24>>24==0){wa=0;xa=1;ya=ha;break}if((ma-na|0)<1){wa=0;xa=1;ya=ha;break}c[p>>2]=la+2;wa=d[na]|0;xa=1;ya=ha}else{wa=0;xa=0;ya=0}}while(0);na=(ia|0)==0;la=0;ma=0;oa=wa;while(1){sa=la<<1;ra=pa>>>((6-sa|0)>>>0)&3;do{if((ra|0)==0){za=oa;Aa=ma}else{do{if(xa){Ba=oa}else{va=c[p>>2]|0;if(((c[s>>2]|0)-va|0)<1){Ba=0;break}c[p>>2]=va+1;Ba=d[va]|0}}while(0);va=(c[1680744+(sa<<2)>>2]|0)+da|0;ja=(c[1680744+((sa|1)<<2)>>2]|0)+ea|0;b:do{if((ra|0)==3){Ca=c[p>>2]|0;Da=(c[s>>2]|0)-Ca|0;if(!na){if(Da>>>0<12>>>0){ka=62;break a}Ea=Ca+3|0;c[p>>2]=Ea;Fa=a[Ca]|0;Ga=(d[Ca+1|0]|0)<<8;Ha=a[Ca+2|0]|0;Ia=(Fa&255)>>>2;a[O]=Ia;a[P]=(Ga|(Fa&255)<<16)>>>12&63;a[Q]=(Ga|Ha&255)>>>6&63;a[R]=Ha&63;Ha=Ca+6|0;c[p>>2]=Ha;Ga=a[Ea]|0;Ea=(d[Ca+4|0]|0)<<8;Fa=a[Ca+5|0]|0;a[S]=(Ga&255)>>>2;a[T]=(Ea|(Ga&255)<<16)>>>12&63;a[U]=(Ea|Fa&255)>>>6&63;a[V]=Fa&63;Fa=Ca+9|0;c[p>>2]=Fa;Ea=a[Ha]|0;Ha=(d[Ca+7|0]|0)<<8;Ga=a[Ca+8|0]|0;a[W]=(Ea&255)>>>2;a[X]=(Ha|(Ea&255)<<16)>>>12&63;a[Y]=(Ha|Ga&255)>>>6&63;a[Z]=Ga&63;c[p>>2]=Ca+12;Ga=a[Fa]|0;Fa=(d[Ca+10|0]|0)<<8;Ha=a[Ca+11|0]|0;a[_]=(Ga&255)>>>2;a[$]=(Fa|(Ga&255)<<16)>>>12&63;a[aa]=(Fa|Ha&255)>>>6&63;a[ca]=Ha&63;Ha=c[o>>2]|0;Fa=Ha+32|0;Ga=(c[Ha>>2]|0)+((ba(c[Fa>>2]|0,ja)|0)+va)|0;Ea=(va|0)/4|0;Ja=(ja|0)/4|0;Ka=(c[Ha+4>>2]|0)+((ba(c[Ha+36>>2]|0,Ja)|0)+Ea)|0;La=(c[Ha+8>>2]|0)+((ba(c[Ha+40>>2]|0,Ja)|0)+Ea)|0;a[Ka]=a[179728+(Ba>>4)|0]|0;a[La]=a[179728+(Ba&15)|0]|0;La=Ga;Ga=0;Ka=Ia;while(1){Ia=Ga&3;a[La+Ia|0]=a[163280+(Ka&255)|0]|0;if((Ia|0)==3){Ma=La+(c[Fa>>2]|0)|0}else{Ma=La}Ia=Ga+1|0;if((Ia|0)>=16){Na=ma;ka=57;break b}La=Ma;Ga=Ia;Ka=a[l+Ia|0]|0}}if(Da>>>0<4>>>0){ka=62;break a}Ka=Ca+1|0;c[p>>2]=Ka;Ga=d[Ca]|0;if((Ga&128|0)!=0){La=Ga>>>4&7;c[p>>2]=Ca+2;Fa=a[Ka]|0;a[v]=(Fa&255|Ga<<8)>>>6&63;a[w]=Fa&63;Fa=c[p>>2]|0;c[p>>2]=Fa+1;a[x]=a[Fa]&63;Fa=c[p>>2]|0;c[p>>2]=Fa+1;a[y]=a[Fa]&63;N$a(c[o>>2]|0,va,ja,v,Ba,La);Na=La;ka=57;break}La=Ca+2|0;c[p>>2]=La;Fa=d[Ka]|0;c[p>>2]=Ca+3;a[v]=a[La]&63;La=c[p>>2]|0;c[p>>2]=La+1;Ka=a[La]&63;a[w]=Ka;La=c[o>>2]|0;Ia=a[v]|0;a[g]=Ia;a[z]=(Ga&64|0)==0?Ia:Ka;a[A]=(Ga&32|0)==0?Ia:Ka;a[B]=(Ga&16|0)==0?Ia:Ka;a[C]=(Ga&8|0)==0?Ia:Ka;a[D]=(Ga&4|0)==0?Ia:Ka;a[E]=(Ga&2|0)==0?Ia:Ka;a[F]=(Ga&1|0)==0?Ia:Ka;a[G]=(Fa&128|0)==0?Ia:Ka;a[H]=(Fa&64|0)==0?Ia:Ka;a[I]=(Fa&32|0)==0?Ia:Ka;a[J]=(Fa&16|0)==0?Ia:Ka;a[K]=(Fa&8|0)==0?Ia:Ka;a[L]=(Fa&4|0)==0?Ia:Ka;a[M]=(Fa&2|0)==0?Ia:Ka;a[N]=(Fa&1|0)==0?Ia:Ka;Ka=La+32|0;Fa=(c[La>>2]|0)+((ba(c[Ka>>2]|0,ja)|0)+va)|0;Ga=(va|0)/4|0;Ea=(ja|0)/4|0;Ja=(c[La+4>>2]|0)+((ba(c[La+36>>2]|0,Ea)|0)+Ga)|0;Ha=(c[La+8>>2]|0)+((ba(c[La+40>>2]|0,Ea)|0)+Ga)|0;a[Ja]=a[179728+(Ba>>4)|0]|0;a[Ha]=a[179728+(Ba&15)|0]|0;Ha=Fa;Fa=0;Ja=Ia;while(1){Ia=Fa&3;a[Ha+Ia|0]=a[163280+(Ja&255)|0]|0;if((Ia|0)==3){Oa=Ha+(c[Ka>>2]|0)|0}else{Oa=Ha}Ia=Fa+1|0;if((Ia|0)>=16){Na=ma;ka=57;break b}Ha=Oa;Fa=Ia;Ja=a[j+Ia|0]|0}}else if((ra|0)==2){Ja=c[p>>2]|0;Fa=(c[s>>2]|0)-Ja|0;if(na){if((Fa|0)<2){Pa=0}else{c[p>>2]=Ja+2;Ha=Ja;Pa=(de((d[Ha]|d[Ha+1|0]<<8)<<16>>16|0)|0)&65535}Ha=Pa<<2&16380;a[v]=a[(c[k>>2]|0)+Ha|0]|0;a[w]=a[(c[k>>2]|0)+(Ha|1)|0]|0;a[x]=a[(c[k>>2]|0)+(Ha|2)|0]|0;a[y]=a[(c[k>>2]|0)+(Ha|3)|0]|0;Na=Pa>>>12;ka=57;break}else{if((Fa|0)<3){Qa=0;Ra=0;Sa=0;Ta=0}else{c[p>>2]=Ja+3;Fa=a[Ja]|0;Ha=(d[Ja+1|0]|0)<<8;Ka=a[Ja+2|0]|0;Qa=(Fa&255)>>>2;Ra=(Ha|(Fa&255)<<16)>>>12&63;Sa=(Ha|Ka&255)>>>6&63;Ta=Ka&63}a[v]=Qa;a[w]=Ra;a[x]=Sa;a[y]=Ta;Na=16;ka=57;break}}else if((ra|0)==1){Ka=c[p>>2]|0;if(((c[s>>2]|0)-Ka|0)<1){Ua=0}else{c[p>>2]=Ka+1;Ua=d[Ka]|0}Ka=Ua>>>6;Ha=c[1795864+(Ka<<2)>>2]|0;Fa=Ua&63;a[v]=Fa;a[w]=Fa;if((Ka|0)==0){a[x]=Fa;a[y]=Fa;Na=Ha;ka=57;break}else{Ka=Fa+1&255;Fa=(Ka&255)>>>0>63>>>0?63:Ka;a[x]=Fa;a[y]=Fa;Na=Ha;ka=57;break}}else{Va=ma}}while(0);if((ka|0)==57){ka=0;if((ra|0)==3){za=Ba;Aa=Na;break}else{Va=Na}}N$a(c[o>>2]|0,va,ja,v,Ba,Va);za=Ba;Aa=Va}}while(0);ra=la+1|0;if((ra|0)<4){la=ra;ma=Aa;oa=za}else{break}}oa=da+8|0;ma=(oa|0)<(c[b>>2]|0);da=ma?oa:0;ea=ma?ea:ea+8|0;fa=fa+1|0;ga=ga;ha=ya;ia=ia}if((ka|0)==61){c[f>>2]=1;f=MCb(e,c[o>>2]|0)|0;q=(f|0)<0?f:n;i=h;return q|0}else if((ka|0)==62){yDb(u,16,2047e3,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;q=-1094995529;i=h;return q|0}return 0}function M$a(a){a=a|0;JCb((c[a+60>>2]|0)+16|0);return 0}function N$a(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;i=i+16|0;l=k|0;if((j&8|0)==0){m=j}else{n=a[g]|0;o=g+3|0;a[g]=a[o]|0;a[o]=n;n=g+1|0;o=a[n]|0;p=g+2|0;a[n]=a[p]|0;a[p]=o;m=j&7}switch(m|0){case 2:{m=a[g+1|0]|0;a[l|0]=m;j=a[g+2|0]|0;a[l+1|0]=j;o=a[g+3|0]|0;a[l+2|0]=o;a[l+3|0]=o;a[l+4|0]=m;a[l+5|0]=j;a[l+6|0]=j;a[l+7|0]=o;o=a[g]|0;a[l+8|0]=o;a[l+9|0]=m;a[l+10|0]=m;a[l+11|0]=j;a[l+12|0]=o;a[l+13|0]=o;a[l+14|0]=m;a[l+15|0]=j;break};case 1:{j=a[g+1|0]|0;a[l|0]=j;m=a[g+2|0]|0;a[l+1|0]=m;o=a[g+3|0]|0;a[l+2|0]=o;a[l+3|0]=o;p=a[g]|0;a[l+4|0]=p;a[l+5|0]=j;a[l+6|0]=m;a[l+7|0]=o;a[l+8|0]=p;a[l+9|0]=j;a[l+10|0]=m;a[l+11|0]=o;a[l+12|0]=p;a[l+13|0]=p;a[l+14|0]=j;a[l+15|0]=m;break};case 3:{m=a[g+2|0]|0;a[l|0]=m;j=a[g+3|0]|0;a[l+1|0]=j;a[l+2|0]=j;a[l+3|0]=j;p=a[g+1|0]|0;a[l+4|0]=p;a[l+5|0]=m;a[l+6|0]=m;a[l+7|0]=j;j=a[g]|0;a[l+8|0]=j;a[l+9|0]=p;a[l+10|0]=p;a[l+11|0]=m;a[l+12|0]=j;a[l+13|0]=j;a[l+14|0]=j;a[l+15|0]=p;break};case 4:{TGb(l|0,a[g+3|0]|0,4)|0;TGb(l+4|0,a[g+2|0]|0,4)|0;TGb(l+8|0,a[g+1|0]|0,4)|0;TGb(l+12|0,a[g]|0,4)|0;break};case 5:{p=a[g+3|0]|0;a[l|0]=p;a[l+1|0]=p;a[l+2|0]=p;j=a[g+2|0]|0;a[l+3|0]=j;a[l+4|0]=p;a[l+5|0]=j;a[l+6|0]=j;p=a[g+1|0]|0;a[l+7|0]=p;a[l+8|0]=j;a[l+9|0]=p;a[l+10|0]=p;j=a[g]|0;a[l+11|0]=j;a[l+12|0]=p;a[l+13|0]=j;a[l+14|0]=j;a[l+15|0]=j;break};case 7:{j=a[g+3|0]|0;a[l|0]=j;a[l+1|0]=j;p=a[g+2|0]|0;a[l+2|0]=p;m=a[g+1|0]|0;a[l+3|0]=m;a[l+4|0]=j;a[l+5|0]=p;a[l+6|0]=m;o=a[g]|0;a[l+7|0]=o;a[l+8|0]=j;a[l+9|0]=p;a[l+10|0]=m;a[l+11|0]=o;a[l+12|0]=p;a[l+13|0]=m;a[l+14|0]=o;a[l+15|0]=o;break};case 6:{o=a[g+3|0]|0;a[l|0]=o;a[l+1|0]=o;m=a[g+2|0]|0;a[l+2|0]=m;a[l+3|0]=m;a[l+4|0]=o;a[l+5|0]=m;o=a[g+1|0]|0;a[l+6|0]=o;a[l+7|0]=o;a[l+8|0]=m;a[l+9|0]=m;a[l+10|0]=o;m=a[g]|0;a[l+11|0]=m;a[l+12|0]=o;a[l+13|0]=o;a[l+14|0]=m;a[l+15|0]=m;break};case 0:{m=a[g]|0;a[l|0]=m;o=a[g+1|0]|0;a[l+1|0]=o;p=a[g+2|0]|0;a[l+2|0]=p;j=a[g+3|0]|0;a[l+3|0]=j;a[l+4|0]=m;a[l+5|0]=o;a[l+6|0]=p;a[l+7|0]=j;a[l+8|0]=m;a[l+9|0]=o;a[l+10|0]=p;a[l+11|0]=j;a[l+12|0]=m;a[l+13|0]=o;a[l+14|0]=p;a[l+15|0]=j;break};default:{j=a[g]|0;a[l|0]=j;a[l+1|0]=j;p=a[g+1|0]|0;a[l+2|0]=p;a[l+3|0]=p;a[l+4|0]=j;a[l+5|0]=j;a[l+6|0]=p;a[l+7|0]=p;p=a[g+2|0]|0;a[l+8|0]=p;a[l+9|0]=p;j=a[g+3|0]|0;a[l+10|0]=j;a[l+11|0]=j;a[l+12|0]=p;a[l+13|0]=p;a[l+14|0]=j;a[l+15|0]=j}}j=b+32|0;p=(c[b>>2]|0)+((ba(c[j>>2]|0,f)|0)+e)|0;g=(e|0)/4|0;e=(f|0)/4|0;f=(c[b+4>>2]|0)+((ba(c[b+36>>2]|0,e)|0)+g)|0;o=(c[b+8>>2]|0)+((ba(c[b+40>>2]|0,e)|0)+g)|0;a[f]=a[179728+(h>>4)|0]|0;a[o]=a[179728+(h&15)|0]|0;h=p;p=0;while(1){o=p&3;a[h+o|0]=a[163280+(d[l+p|0]|0)|0]|0;if((o|0)==3){q=h+(c[j>>2]|0)|0}else{q=h}o=p+1|0;if((o|0)<16){h=q;p=o}else{break}}i=k;return}function O$a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=a;if(d>>>0>4294967279>>>0){$Db(a);c[b>>2]=0;return}a=d+16|0;if((c[b>>2]|0)>>>0>a>>>0){TGb((c[e>>2]|0)+d|0,0,16)|0;return}else{d=((a*17|0)>>>4)+32|0;f=d>>>0>a>>>0?d:a;ZDb(c[e>>2]|0);a=cEb(f)|0;c[e>>2]=a;c[b>>2]=(a|0)==0?0:f;return}}function P$a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=a;if(d>>>0>4294967279>>>0){$Db(a);c[b>>2]=0;return}a=d+16|0;if((c[b>>2]|0)>>>0>a>>>0){TGb(c[e>>2]|0,0,a|0)|0;return}else{d=((a*17|0)>>>4)+32|0;f=d>>>0>a>>>0?d:a;ZDb(c[e>>2]|0);a=cEb(f)|0;c[e>>2]=a;c[b>>2]=(a|0)==0?0:f;return}}function Q$a(a){a=a|0;return c[((a|0)==0?5221512:a+56|0)>>2]|0}function R$a(a){a=a|0;var b=0;do{if((a|0)==0){b=0}else{if((c[a+80>>2]|0)!=0){b=1;break}b=(c[a+84>>2]|0)!=0|0}}while(0);return b|0}function S$a(a){a=a|0;var b=0;if((a|0)==0){b=0;return b|0}b=(c[a+88>>2]|0)!=0|0;return b|0}function T$a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;if(!(a[1775400]|0)){a[1775400]=1;X3()}d=c[214530]|0;e=b+56|0;c[e>>2]=0;f=b;g=d;while(1){d=c[g>>2]|0;if((d|0)==0){h=g;if(((D=c[h>>2]|0,(c[h>>2]|0)==0?(c[h>>2]=f)|0:0,D)|0)==0){break}i=c[g>>2]|0}else{i=d}g=i+56|0}c[214530]=e;e=c[b+72>>2]|0;if((e|0)==0){return}me[e&511](b);return}function U$a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;g=(hDb(b,d,0,f)|0)<0;h=g?0:d;j=g?0:b;c[a+128>>2]=j;c[a+132>>2]=h;k=c[a+800>>2]|0;c[a+120>>2]=-(-j>>k);c[a+124>>2]=-(-h>>k);if(!g){i=e;return}yDb(f,24,2205384,(f=i,i=i+16|0,c[f>>2]=b,c[f+8>>2]=d,f)|0);i=f;i=e;return}function V$a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=hDb(b,d,0,a)|0;f=(e|0)<0;g=f?0:d;d=f?0:b;c[a+128>>2]=d;c[a+132>>2]=g;b=c[a+800>>2]|0;c[a+120>>2]=-(-d>>b);c[a+124>>2]=-(-g>>b);return e|0}function W$a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=VCb(a,3)|0;do{if((d|0)==0){e=TCb(a,3,4)|0;if((e|0)==0){f=-12}else{g=e;break}return f|0}else{g=d}}while(0);c[c[g+4>>2]>>2]=b;f=0;return f|0}function X$a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=bFb(c[e+80>>2]|0)|0;if((a[h+7|0]&16)==0){yDb(0,0,2313288,(j=i,i=i+24|0,c[j>>2]=2179656,c[j+8>>2]=2103344,c[j+16>>2]=706,j)|0);i=j;Cd()}j=h+4|0;k=a[j]|0;if(k<<24>>24==0){i=g;return}l=e+68|0;m=h+5|0;n=e+72|0;o=h+6|0;p=h+8|0;h=0;q=k;while(1){k=c[e+(h<<2)>>2]|0;r=c[l>>2]|0;if((h-1|0)>>>0<2>>>0){s=-(-(c[n>>2]|0)>>(d[o]|0))|0;t=-(-r>>(d[m]|0))|0}else{s=c[n>>2]|0;t=r}if((s|0)>0){r=e+32+(h<<2)|0;u=f+(h<<2)|0;a:do{if((t|0)>0){v=k;w=1;while(1){x=c[u>>2]|0;if((b[p>>1]&16384)>>>0>14336>>>0){y=x&65535;z=v;A=0;do{b[z+(A<<1)>>1]=y;A=A+1|0;}while((A|0)<(t|0))}else{TGb(v|0,x&255|0,t|0)|0}if((w|0)>=(s|0)){break a}v=v+(c[r>>2]|0)|0;w=w+1|0}}else{w=k;v=1;while(1){if(!((b[p>>1]&16384)>>>0>14336>>>0)){TGb(w|0,c[u>>2]&255|0,t|0)|0}if((v|0)>=(s|0)){break a}w=w+(c[r>>2]|0)|0;v=v+1|0}}}while(0);B=a[j]|0}else{B=q}r=h+1|0;if((r|0)<(B&255|0)){h=r;q=B}else{break}}i=g;return}function Y$a(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;d=i;i=i+96|0;f=d|0;g=d+8|0;h=d+16|0;j=d+80|0;k=j;l=a+64|0;m=c[(c[l>>2]|0)+24>>2]|0;n=a+8|0;o=c[n>>2]|0;a:do{if((o|0)==1){p=vCb(b)|0;q=b+80|0;r=(CFb(c[q>>2]|0)|0)!=0;s=r?p:1;r=m+16|0;do{if((c[r>>2]|0)==(c[q>>2]|0)){if((c[m+76>>2]|0)!=(s|0)){break}if((c[m+80>>2]|0)!=(p|0)){break}if((c[b+76>>2]|0)==(c[m+84>>2]|0)){break a}}}while(0);t=m|0;bBb(t);u=m+60|0;v=b+76|0;w=DFb(u,p,c[v>>2]|0,c[q>>2]|0,0)|0;if((w|0)<0){x=w;y=39;break}w=aBb(c[u>>2]|0,0)|0;c[t>>2]=w;if((w|0)==0){x=-12;y=39;break}c[r>>2]=c[q>>2];c[m+76>>2]=s;c[m+80>>2]=p;c[m+84>>2]=c[v>>2]}else if((o|0)==0){TGb(k|0,0,16)|0;v=b+68|0;w=c[v>>2]|0;t=b+72|0;u=c[t>>2]|0;z=m+16|0;A=b+80|0;do{if((c[z>>2]|0)==(c[A>>2]|0)){if((c[m+20>>2]|0)!=(w|0)){break}if((c[m+24>>2]|0)==(u|0)){break a}}}while(0);p=m+28|0;s=a+140|0;q=c[s>>2]|0;b:do{switch(q|0){case 11:case 19:case 22:{r=c[a+48>>2]|0;if(!((r|0)==50|(r|0)==44)){B=1;C=1;break b}B=4;C=4;break};case 3:{r=((c[a+48>>2]|0)-54|0)>>>0<2>>>0?4:1;B=r;C=r;break};case 7:case 320:case 18:{B=8;C=32;break};case 0:case 1:case 17:case 4:case 33:case 5:case 317:case 82:case 8:case 31:case 32:case 12:case 13:case 34:case 14:case 35:case 300:case 299:case 70:case 69:case 72:case 71:case 302:case 301:case 304:case 303:case 54:case 55:case 92:case 91:case 98:case 97:case 104:case 103:case 80:case 79:case 74:case 73:case 306:case 305:case 308:case 307:case 56:case 57:case 94:case 93:case 100:case 99:case 106:case 105:case 76:case 75:case 78:case 77:case 310:case 309:case 312:case 311:case 58:case 59:case 96:case 95:case 102:case 101:case 108:case 107:case 84:case 83:case 86:case 85:case 314:case 313:case 316:case 315:{B=32;C=16;break};case 2:{r=(c[a+48>>2]|0)==44?4:1;B=r;C=r;break};case 46:{r=(c[a+48>>2]|0)==43?4:1;B=r;C=r;break};case 6:{r=(c[a+48>>2]|0)==23?64:1;B=r;C=r;break};default:{B=1;C=1}}}while(0);r=c[a+48>>2]|0;if((r-137|0)>>>0<2>>>0){D=C>>>0>8>>>0?C:8}else{D=C}E=w-1+D&-D;F=u-1+B&-B;if((r|0)==28){y=18}else{if((c[a+800>>2]|0)==0){G=F}else{y=18}}if((y|0)==18){G=F+2|0}c[p>>2]=8;F=m+32|0;c[F>>2]=8;r=m+36|0;c[r>>2]=8;H=m+40|0;c[H>>2]=8;if((c[a+88>>2]&16384|0)==0){I=G+32|0;J=E+32|0}else{I=G;J=E}E=h+32|0;K=h+36|0;L=h+40|0;M=h+44|0;N=J;O=q;while(1){dDb(E,O,N)|0;if(((c[K>>2]|0)%(c[F>>2]|0)|0|((c[E>>2]|0)%(c[p>>2]|0)|0)|((c[L>>2]|0)%(c[r>>2]|0)|0)|((c[M>>2]|0)%(c[H>>2]|0)|0)|0)==0){break}N=(N&-N)+N|0;O=c[s>>2]|0}O=h|0;N=eDb(O,c[s>>2]|0,I,0,E)|0;if((N|0)<0){P=-1;i=d;return P|0}H=c[h+4>>2]|0;r=c[O>>2]|0;do{if((H|0)==0){Q=0;R=j|0;S=r}else{O=H;p=r;F=j|0;c[F>>2]=O-p;q=c[h+8>>2]|0;if((q|0)==0){Q=1;R=F;S=p;break}u=q;c[j+4>>2]=u-O;O=c[h+12>>2]|0;if((O|0)==0){Q=2;R=F;S=p;break}c[j+8>>2]=O-u;Q=3;R=F;S=p}}while(0);c[j+(Q<<2)>>2]=S+N-(c[h+(Q<<2)>>2]|0);r=m|0;bBb(r);c[m+60>>2]=c[E>>2];H=c[R>>2]|0;if((H|0)!=0){s=aBb(H+23|0,728)|0;c[r>>2]=s;if((s|0)==0){x=-12;y=39;break}}s=m+4|0;bBb(s);c[m+64>>2]=c[K>>2];r=c[j+4>>2]|0;if((r|0)!=0){H=aBb(r+23|0,728)|0;c[s>>2]=H;if((H|0)==0){x=-12;y=39;break}}H=m+8|0;bBb(H);c[m+68>>2]=c[L>>2];s=c[j+8>>2]|0;if((s|0)!=0){r=aBb(s+23|0,728)|0;c[H>>2]=r;if((r|0)==0){x=-12;y=39;break}}r=m+12|0;bBb(r);c[m+72>>2]=c[M>>2];H=c[j+12>>2]|0;if((H|0)!=0){s=aBb(H+23|0,728)|0;c[r>>2]=s;if((s|0)==0){x=-12;y=39;break}}c[z>>2]=c[A>>2];c[m+20>>2]=c[v>>2];c[m+24>>2]=c[t>>2]}else{yDb(0,0,2313288,(T=i,i=i+24|0,c[T>>2]=1892224,c[T+8>>2]=2103344,c[T+16>>2]=590,T)|0);i=T;Cd();return 0}}while(0);if((y|0)==39){bBb(m|0);bBb(m+4|0);bBb(m+8|0);bBb(m+12|0);c[m+16>>2]=-1;c[m+84>>2]=0;c[m+80>>2]=0;c[m+76>>2]=0;c[m+24>>2]=0;c[m+20>>2]=0;P=x;i=d;return P|0}c[b+288>>2]=1;x=c[n>>2]|0;if((x|0)==1){n=c[(c[l>>2]|0)+24>>2]|0;m=c[n+76>>2]|0;c[b+32>>2]=c[n+60>>2];do{if((m|0)>8){j=b+64|0;c[j>>2]=cEb(m<<2)|0;R=m-8|0;c[b+396>>2]=R;Q=cEb(R<<2)|0;R=b+392|0;c[R>>2]=Q;if(!((c[j>>2]|0)==0|(Q|0)==0)){U=8;y=73;break}$Db(j);$Db(R);P=-12;i=d;return P|0}else{c[b+64>>2]=b;if((c[b+396>>2]|0)==0){if((m|0)>0){U=m;y=73;break}else{break}}else{yDb(0,0,2313288,(T=i,i=i+24|0,c[T>>2]=2340576,c[T+8>>2]=2103344,c[T+16>>2]=622,T)|0);i=T;Cd();return 0}}}while(0);c:do{if((y|0)==73){m=n|0;R=b+64|0;j=0;while(1){Q=cBb(c[m>>2]|0)|0;c[b+360+(j<<2)>>2]=Q;if((Q|0)==0){break}h=c[Q+4>>2]|0;c[b+(j<<2)>>2]=h;c[(c[R>>2]|0)+(j<<2)>>2]=h;h=j+1|0;if((h|0)<(U|0)){j=h}else{y=75;break}}d:do{if((y|0)==75){j=b+396|0;if((c[b+396>>2]|0)<=0){break c}R=n|0;m=b+392|0;t=b+64|0;v=0;while(1){A=cBb(c[R>>2]|0)|0;c[(c[m>>2]|0)+(v<<2)>>2]=A;A=c[(c[m>>2]|0)+(v<<2)>>2]|0;if((A|0)==0){break d}c[(c[t>>2]|0)+(v+8<<2)>>2]=c[A+4>>2];v=v+1|0;if((v|0)>=(c[j>>2]|0)){break c}}}}while(0);KCb(b);P=-12;i=d;return P|0}}while(0);if((c[a+688>>2]&32768|0)==0){P=0;i=d;return P|0}yDb(a,48,2339376,(T=i,i=i+8|0,c[T>>2]=b,T)|0);i=T;P=0;i=d;return P|0}else if((x|0)==0){x=c[(c[l>>2]|0)+24>>2]|0;l=bFb(c[b+80>>2]|0)|0;n=b|0;if((c[n>>2]|0)!=0){yDb(a,16,2337944,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;P=-1;i=d;return P|0}U=(e[l+8>>1]|0)>>>2&7;TGb(b|0,0,32)|0;c[b+64>>2]=n;n=a+140|0;eFb(c[n>>2]|0,f,g)|0;l=x+8|0;j=a+88|0;v=(U<<4)+16|0;U=0;while(1){t=c[x+(U<<2)>>2]|0;if((t|0)==0){V=U;y=61;break}m=(U|0)==0;R=m?0:c[f>>2]|0;A=m?0:c[g>>2]|0;z=(c[l>>2]|0)!=0;if(z|m^1){W=z}else{W=(c[n>>2]|0)==8}z=b+32+(U<<2)|0;c[z>>2]=c[x+60+(U<<2)>>2];m=cBb(t)|0;c[b+360+(U<<2)>>2]=m;if((m|0)==0){y=67;break}t=c[m+4>>2]|0;if((c[j>>2]&16384|0)!=0|W^1){c[b+(U<<2)>>2]=t}else{m=c[x+28+(U<<2)>>2]|0;c[b+(U<<2)>>2]=t+((v>>R)-1+m+(c[z>>2]<<4>>A)&-m)}X=U+1|0;if((X|0)<4){U=X}else{y=53;break}}if((y|0)==53){if((X|0)<8){V=X;y=61}}else if((y|0)==67){KCb(b);P=-12;i=d;return P|0}if((y|0)==61){while(1){y=0;c[b+(V<<2)>>2]=0;c[b+32+(V<<2)>>2]=0;X=V+1|0;if((X|0)<8){V=X;y=61}else{break}}}y=c[b+4>>2]|0;do{if((y|0)!=0){if((c[b+8>>2]|0)!=0){break}fDb(y,c[n>>2]|0)|0}}while(0);if((c[a+688>>2]&32768|0)==0){P=0;i=d;return P|0}yDb(a,48,2336528,(T=i,i=i+8|0,c[T>>2]=b,T)|0);i=T;P=0;i=d;return P|0}else{P=-1;i=d;return P|0}return 0}function Z$a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a+64|0;f=c[(c[e>>2]|0)+32>>2]|0;if((f|0)==0){g=b+144|0;c[g>>2]=0;c[g+4>>2]=-2147483648;tCb(b,-1,-1);rCb(b,0,0);ACb(b,-1)}else{g=f+8|0;h=c[g+4>>2]|0;j=b+144|0;c[j>>2]=c[g>>2];c[j+4>>2]=h;h=f+64|0;tCb(b,c[h>>2]|0,c[h+4>>2]|0);h=c[(c[(c[e>>2]|0)+32>>2]|0)+48>>2]|0;rCb(b,h,(h|0)<0|0?-1:0);ACb(b,c[(c[(c[e>>2]|0)+32>>2]|0)+28>>2]|0)}e=a+704|0;h=c[e+4>>2]|0;f=b+320|0;c[f>>2]=c[e>>2];c[f+4>>2]=h;h=c[(c[a+12>>2]|0)+8>>2]|0;if((h|0)==1){f=b+344|0;if((c[f>>2]|0)==0){c[f>>2]=c[a+412>>2]}f=b+80|0;if((c[f>>2]|0)<0){c[f>>2]=c[a+420>>2]}f=b+352|0;do{if((c[f>>2]|0)==0&(c[f+4>>2]|0)==0){e=a+448|0;j=c[e>>2]|0;g=c[e+4>>2]|0;if((j|0)==0&(g|0)==0){k=c[a+416>>2]|0;if(!(k>>>0>63>>>0)){l=k;break}yDb(a,16,2001296,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;n=-38;i=d;return n|0}k=hBb(j,g)|0;if((k|0)==(c[a+416>>2]|0)){g=c[e+4>>2]|0;c[f>>2]=c[e>>2];c[f+4>>2]=g;l=k;break}yDb(a,16,2046960,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=d;return n|0}else{l=c[a+416>>2]|0}}while(0);wCb(b,l);n=0;i=d;return n|0}else if((h|0)==0){c[b+80>>2]=c[a+140>>2];h=b+124|0;if((c[h>>2]|0)==0){l=a+224|0;m=h;h=c[l+4>>2]|0;c[m>>2]=c[l>>2];c[m+4>>2]=h}if((BCb(b)|0)==2){CCb(b,c[a+392>>2]|0)}if((DCb(b)|0)!=0){n=0;i=d;return n|0}ECb(b,c[a+396>>2]|0);n=0;i=d;return n|0}else{n=0;i=d;return n|0}return 0}function _$a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=h;l=b+8|0;a:do{if((c[l>>2]|0)==0){m=b+120|0;n=b+124|0;o=b;do{if((hDb(c[m>>2]|0,c[n>>2]|0,0,o)|0)>=0){if((c[b+140>>2]|0)<0){break}if((c[l>>2]|0)!=0){p=1;q=9;break a}r=e+68|0;s=e+72|0;if((c[r>>2]|0)>=1){if((c[s>>2]|0)>=1){p=1;q=9;break a}}t=c[m>>2]|0;u=b+800|0;v=-(-(c[b+128>>2]|0)>>c[u>>2])|0;c[r>>2]=(t|0)>(v|0)?t:v;v=c[n>>2]|0;t=-(-(c[b+132>>2]|0)>>c[u>>2])|0;c[s>>2]=(v|0)>(t|0)?v:t;p=0;q=9;break a}}while(0);yDb(o,16,2341784,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-22}else{p=1;q=9}}while(0);b:do{if((q|0)==9){n=Z$a(b,e)|0;if((n|0)<0){x=n;break}n=c[b+472>>2]|0;if((n|0)==0){m=ze[c[b+484>>2]&511](b,e,f)|0;if((c[l>>2]|p|0)==0){c[e+68>>2]=c[b+120>>2];c[e+72>>2]=c[b+124>>2]}if((m|0)<0){x=m;break}else{y=m}i=g;return y|0}c[h>>2]=0;c[j>>2]=0;if((f&1|0)!=0){c[e+172>>2]=1}m=Oe[n&1023](b,e)|0;if((m|0)<0){x=m;break}c:do{if((c[e+360>>2]|0)==0){m=cEb(2456)|0;c[h>>2]=m;d:do{if((m|0)==0){z=-12}else{UGb(m|0,b|0,960)|0;UGb(m+960|0,e|0,472)|0;n=SAb(0,0,300,m,0)|0;c[j>>2]=n;if((n|0)==0){z=-12;break}n=e+80|0;t=c[n>>2]|0;e:do{if((c[l>>2]|0)==0){v=bFb(t)|0;s=fFb(c[n>>2]|0)|0;if((v|0)==0){z=-22;break d}u=(a[v+7|0]&8)==0?s:1;if((u|0)<1){z=-22;break d}s=v+6|0;v=e+72|0;r=0;while(1){if((r|0)>=(u|0)){break e}if((r-1|0)>>>0<2>>>0){A=d[s]|0}else{A=0}B=c[v>>2]|0;C=c[e+32+(r<<2)>>2]|0;D=WAb(c[j>>2]|0)|0;if((D|0)==0){z=-12;break d}E=ba(B>>A,C)|0;C=SAb(c[e+(r<<2)>>2]|0,E,442,D,0)|0;c[e+360+(r<<2)>>2]=C;if((C|0)==0){break}else{r=r+1|0}}KCb(e);z=-12;break d}else{do{if((CFb(t)|0)==0){F=1}else{r=c[b+416>>2]|0;if(!(r>>>0>8>>>0)){F=r;break}v=r-8|0;c[e+396>>2]=v;r=WDb(v<<2)|0;c[e+392>>2]=r;if((r|0)==0){z=-12;break d}else{F=8}}}while(0);r=e+64|0;v=e+32|0;s=0;while(1){if(!(s>>>0<F>>>0)){break}u=WAb(c[j>>2]|0)|0;if((u|0)==0){z=-12;break d}C=SAb(c[(c[r>>2]|0)+(s<<2)>>2]|0,c[v>>2]|0,442,u,0)|0;c[e+360+(s<<2)>>2]=C;if((C|0)==0){q=35;break}else{s=s+1|0}}if((q|0)==35){KCb(e);z=-12;break d}s=e+396|0;C=e+392|0;u=0;while(1){if((u|0)>=(c[s>>2]|0)){break e}D=WAb(c[j>>2]|0)|0;if((D|0)==0){z=-12;break d}E=SAb(c[(c[r>>2]|0)+(u+8<<2)>>2]|0,c[v>>2]|0,442,D,0)|0;c[(c[C>>2]|0)+(u<<2)>>2]=E;if((c[(c[C>>2]|0)+(u<<2)>>2]|0)==0){break}else{u=u+1|0}}KCb(e);z=-12;break d}}while(0);XAb(j);break c}}while(0);ne[c[b+476>>2]&1023](b,e);$Db(k);XAb(j);x=z;break b}}while(0);c[e+68>>2]=c[b+120>>2];c[e+72>>2]=c[b+124>>2];y=0;i=g;return y|0}}while(0);yDb(b,16,1964216,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=x;i=g;return y|0}function $$a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+8|0;e=d|0;if((c[a+8>>2]|0)!=0){yDb(0,0,2313288,(f=i,i=i+24|0,c[f>>2]=2344672,c[f+8>>2]=2103344,c[f+16>>2]=991,f)|0);i=f;Cd();return 0}g=b|0;a:do{if((c[g>>2]|0)!=0){h=c[b+68>>2]|0;j=a+120|0;k=c[b+72>>2]|0;l=a+124|0;do{if((h|0)==(c[j>>2]|0)){if((k|0)!=(c[l>>2]|0)){break}if((c[b+80>>2]|0)==(c[a+140>>2]|0)){break a}}}while(0);m=ZEb(c[b+80>>2]|0)|0;n=c[j>>2]|0;o=c[l>>2]|0;p=ZEb(c[a+140>>2]|0)|0;yDb(a,24,2343176,(f=i,i=i+48|0,c[f>>2]=h,c[f+8>>2]=k,c[f+16>>2]=m,c[f+24>>2]=n,c[f+32>>2]=o,c[f+40>>2]=p,f)|0);i=f;KCb(b)}}while(0);Z$a(a,b)|0;do{if((c[g>>2]|0)==0){p=_$a(a,b,1)|0;if((p|0)<0){q=p;break}else{r=p}i=d;return r|0}else{if((RCb(b)|0)!=0){p=c[(c[a+64>>2]|0)+32>>2]|0;if((p|0)==0){s=-2147483648;t=0}else{o=p+8|0;s=c[o+4>>2]|0;t=c[o>>2]|0}o=b+144|0;c[o>>2]=t;c[o+4>>2]=s;o=a+704|0;p=c[o+4>>2]|0;n=b+320|0;c[n>>2]=c[o>>2];c[n+4>>2]=p;r=0;i=d;return r|0}p=ICb()|0;c[e>>2]=p;if((p|0)==0){q=-12;break}QCb(p,b);n=_$a(a,b,1)|0;if((n|0)<0){JCb(e);q=n;break}OCb(b,p)|0;JCb(e);r=0;i=d;return r|0}}while(0);yDb(a,16,1936040,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;r=q;i=d;return r|0}function a0a(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;if((f|0)<=0){return 0}if((e|0)==0){h=0;do{i=d+(ba(h,g)|0)|0;Oe[b&1023](a,i)|0;h=h+1|0;}while((h|0)<(f|0));return 0}else{h=0;do{i=d+(ba(h,g)|0)|0;c[e+(h<<2)>>2]=Oe[b&1023](a,i)|0;h=h+1|0;}while((h|0)<(f|0));return 0}return 0}function b0a(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((f|0)<=0){return 0}if((e|0)==0){g=0;do{_e[b&1023](a,d,g,0)|0;g=g+1|0;}while((g|0)<(f|0));return 0}else{g=0;do{c[e+(g<<2)>>2]=_e[b&1023](a,d,g,0)|0;g=g+1|0;}while((g|0)<(f|0));return 0}return 0}function c0a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a;while(1){a=c[d>>2]|0;if(!((a|0)>-1)){e=-1;f=4;break}if((c[d+4>>2]|0)==(b|0)){e=a;f=4;break}else{d=d+8|0}}if((f|0)==4){return e|0}return 0}function d0a(b,d){b=b|0;d=d|0;var e=0,f=0;b=d;while(1){d=c[b>>2]|0;if((d|0)==-1){e=-1;f=5;break}if((a[(bFb(d)|0)+7|0]&8)==0){break}else{b=b+4|0}}if((f|0)==5){return e|0}e=c[b>>2]|0;return e|0}function e0a(a){a=a|0;TGb(a|0,0,472)|0;KCb(a);return}function f0a(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=b;b=i;i=i+8|0;c[b>>2]=c[e>>2];c[b+4>>2]=c[e+4>>2];e=b;b=a+888|0;a=c[e+4>>2]|0;c[b>>2]=c[e>>2];c[b+4>>2]=a;i=d;return}function g0a(a){a=a|0;return c[a+896>>2]|0}function h0a(a,b){a=a|0;b=b|0;c[a+896>>2]=b;return}function i0a(a){a=a|0;return c[a+800>>2]|0}function j0a(a,b){a=a|0;b=b|0;c[a+948>>2]=b;return}function k0a(a,b){a=a|0;b=b|0;c[a+952>>2]=b;return}function l0a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if((c[1989804]|0)==0){yDb(0,0,2313288,(f=i,i=i+24|0,c[f>>2]=1882680,c[f+8>>2]=2103344,c[f+16>>2]=3333,f)|0);i=f;Cd();return 0}c[1989804]=0;c[2039024]=(c[2039024]|0)-1;f=c[1244822]|0;if((f|0)==0){g=m0a(a,b,d)|0;h=n0a(a)|0;i=e;return g|0}Oe[f&1023](8776288,2)|0;g=m0a(a,b,d)|0;h=n0a(a)|0;i=e;return g|0}function m0a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;f=i;i=i+1800|0;g=f|0;h=f+8|0;j=f+136|0;k=f+264|0;l=f+776|0;m=f+1288|0;c[g>>2]=0;n=a+64|0;if((c[n>>2]|0)!=0){o=0;i=f;return o|0}p=a+12|0;q=c[p>>2]|0;r=(q|0)==0;do{if((b|0)==0){if(!r){s=q;break}yDb(a,16,2349856,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;o=-22;i=f;return o|0}else{if(r|(q|0)==(b|0)){s=b;break}u=c[b>>2]|0;yDb(a,16,2329584,(t=i,i=i+16|0,c[t>>2]=c[q>>2],c[t+8>>2]=u,t)|0);i=t;o=-22;i=f;return o|0}}while(0);if((c[a+100>>2]|0)>>>0>268435439>>>0){o=-22;i=f;return o|0}q=(e|0)!=0;if(q){EBb(g,c[e>>2]|0,0)}b=n0a(a)|0;if((b|0)<0){o=b;i=f;return o|0}b=cEb(56)|0;c[n>>2]=b;a:do{if((b|0)==0){v=-12}else{r=cEb(88)|0;c[(c[n>>2]|0)+24>>2]=r;b:do{if((c[(c[n>>2]|0)+24>>2]|0)==0){w=-12}else{r=ICb()|0;c[(c[n>>2]|0)+20>>2]=r;if((c[(c[n>>2]|0)+20>>2]|0)==0){w=-12;break}r=c[s+52>>2]|0;u=a+60|0;do{if((r|0)>0){do{if((c[u>>2]|0)==0){x=cEb(r)|0;c[u>>2]=x;if((x|0)==0){v=-12;break a}y=s+44|0;z=c[y>>2]|0;if((z|0)==0){A=y;break}c[x>>2]=z;DEb(x);A=y}else{A=s+44|0}}while(0);if((c[A>>2]|0)==0){break}y=IEb(c[u>>2]|0,g)|0;if((y|0)<0){w=y;break b}}else{c[u>>2]=0}}while(0);u=a;r=IEb(u,g)|0;if((r|0)<0){w=r;break}y=a+128|0;x=c[y>>2]|0;c:do{if((x|0)==0){B=0;C=30}else{z=a+132|0;D=c[z>>2]|0;if((D|0)==0){B=x;C=30;break}E=c[a+120>>2]|0;do{if((E|0)!=0){if((c[a+124>>2]|0)==0){break}F=c[a+48>>2]|0;if((F|0)==28|(F|0)==93){G=x;H=E;break c}}}while(0);E=hDb(x,D,0,u)|0;F=(E|0)<0;I=F?0:D;J=F?0:x;c[y>>2]=J;c[z>>2]=I;F=c[a+800>>2]|0;K=-(-J>>F)|0;c[a+120>>2]=K;c[a+124>>2]=-(-I>>F);L=E;M=J;N=K;C=33}}while(0);do{if((C|0)==30){x=a+120|0;K=c[x>>2]|0;if((K|0)==0){L=r;M=B;N=0;C=33;break}J=a+124|0;E=c[J>>2]|0;if((E|0)==0){L=r;M=B;N=K;C=33;break}F=hDb(K,E,0,u)|0;I=(F|0)<0;O=I?0:E;E=I?0:K;c[y>>2]=E;c[a+132>>2]=O;K=c[a+800>>2]|0;I=-(-E>>K)|0;c[x>>2]=I;c[J>>2]=-(-O>>K);L=F;M=E;N=I;C=33}}while(0);if((C|0)==33){if((L|0)<0){w=L;break}else{G=M;H=N}}r=c[a+132>>2]|0;do{if((G|r|0)==0){if((H|0)!=0){P=0;C=37;break}if((c[a+124>>2]|0)!=0){P=0;C=37}}else{P=r;C=37}}while(0);do{if((C|0)==37){r=a+132|0;I=a+120|0;if((hDb(G,P,0,u)|0)<0){Q=a+124|0}else{E=a+124|0;if((hDb(c[I>>2]|0,c[E>>2]|0,0,u)|0)<0){Q=E}else{break}}yDb(u,24,2305248,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;hDb(0,0,0,u)|0;c[y>>2]=0;c[r>>2]=0;c[I>>2]=0;c[Q>>2]=0}}while(0);y=(s|0)==0;do{if(!y){if((c[s+88>>2]|0)==0){break}$Db(a+860|0)}}while(0);I=a+416|0;if((c[I>>2]|0)>>>0>63>>>0){w=-22;break}c[p>>2]=s;r=a+8|0;E=c[r>>2]|0;do{if((E|0)==-1){C=48}else{if((E|0)==(c[s+8>>2]|0)){C=48;break}R=E;S=c[a+48>>2]|0}}while(0);do{if((C|0)==48){F=a+48|0;K=c[F>>2]|0;if((K|0)!=0){R=E;S=K;break}K=c[s+8>>2]|0;c[r>>2]=K;O=c[s+12>>2]|0;c[F>>2]=O;R=K;S=O}}while(0);E=a+48|0;O=s+12|0;do{if((S|0)==(c[O>>2]|0)){if(!((R|0)==(c[s+8>>2]|0)|(R|0)==4)){break}c[a+428>>2]=0;K=a+896|0;c[K>>2]=g0(S)|0;do{if((c[(c[p>>2]|0)+16>>2]&512|0)!=0){if(!((c[a+680>>2]|0)>-2)){break}d:do{if(y){F=c[s>>2]|0;yDb(u,16,2241504,(t=i,i=i+24|0,c[t>>2]=2255872,c[t+8>>2]=F,c[t+16>>2]=-2,t)|0);i=t;T=c[O>>2]|0;U=2255872;C=77}else{if((c[s+80>>2]|0)==0){V=(c[s+84>>2]|0)!=0?2271312:2255872}else{V=2271312}F=c[s>>2]|0;yDb(u,16,2241504,(t=i,i=i+24|0,c[t>>2]=V,c[t+8>>2]=F,c[t+16>>2]=-2,t)|0);i=t;if((c[s+80>>2]|0)==0){F=c[O>>2]|0;if((c[s+84>>2]|0)==0){T=F;U=V;C=77;break}else{W=F}}else{W=c[O>>2]|0}F=c[1305378]|0;if((W|0)==175){X=1211250229}else if((W|0)==86077){X=1330664787}else if((W|0)==86079){X=1950507339}else if((W|0)==65564){X=407917392}else if((W|0)==65565){X=542135120}else if((W|0)==171){X=1160852272}else if((W|0)==172){X=4665933}else if((W|0)==173){X=1464156752}else{X=W}if((F|0)==0){Y=0;Z=V;break}else{_=F;$=0}while(1){if((c[_+80>>2]|0)==0){if((c[_+84>>2]|0)==0){aa=$}else{C=74}}else{C=74}do{if((C|0)==74){C=0;if((c[_+12>>2]|0)!=(X|0)){aa=$;break}if((c[_+16>>2]&512|0)!=0&($|0)==0){aa=_}else{Y=_;Z=V;break d}}}while(0);F=c[_+56>>2]|0;if((F|0)==0){Y=aa;Z=V;break}else{_=F;$=aa}}}}while(0);e:do{if((C|0)==77){F=c[1305378]|0;if((T|0)==175){ca=1211250229}else if((T|0)==86077){ca=1330664787}else if((T|0)==86079){ca=1950507339}else if((T|0)==65564){ca=407917392}else if((T|0)==65565){ca=542135120}else if((T|0)==171){ca=1160852272}else if((T|0)==172){ca=4665933}else if((T|0)==173){ca=1464156752}else{ca=T}if((F|0)==0){Y=0;Z=U;break}else{da=F;ea=0}while(1){do{if((c[da+88>>2]|0)==0){fa=ea}else{if((c[da+12>>2]|0)!=(ca|0)){fa=ea;break}if((c[da+16>>2]&512|0)!=0&(ea|0)==0){fa=da}else{Y=da;Z=U;break e}}}while(0);F=c[da+56>>2]|0;if((F|0)==0){Y=fa;Z=U;break}else{da=F;ea=fa}}}}while(0);if((c[Y+16>>2]&512|0)!=0){w=-733130664;break b}F=c[Y>>2]|0;yDb(u,16,2229280,(t=i,i=i+16|0,c[t>>2]=Z,c[t+8>>2]=F,t)|0);i=t;w=-733130664;break b}}while(0);do{if((c[r>>2]|0)==1){z=a+104|0;D=a+108|0;if((c[z>>2]|0)!=0){if((c[D>>2]|0)!=0){break}}c[z>>2]=1;c[D>>2]=c[a+412>>2]}}while(0);yDb(u,24,2217496,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;if((c[s+16>>2]&32768|0)==0){c[a+808>>2]=1}D=c[p>>2]|0;z=d[D+40|0]|0;F=c[a+800>>2]|0;if((z|0)<(F|0)|(F|0)<0){yDb(u,16,2208224,(t=i,i=i+8|0,c[t>>2]=z,t)|0);i=t;w=-22;break b}do{if((D|0)!=0){if((c[D+80>>2]|0)==0){if((c[D+84>>2]|0)==0){break}}z=c[D+32>>2]|0;do{if((z|0)==0){ga=D}else{F=c[z>>2]|0;f:do{if((F|0)==-1){ha=0;ia=D;ja=z}else{J=a+420|0;x=0;ka=F;la=D;ma=z;while(1){na=c[J>>2]|0;if((na|0)==(ka|0)){ha=x;ia=la;ja=ma;break f}if((c[I>>2]|0)==1){oa=zFb(na)|0;na=(oa|0)==(zFb(c[(c[(c[p>>2]|0)+32>>2]|0)+(x<<2)>>2]|0)|0);pa=c[p>>2]|0;qa=c[pa+32>>2]|0;if(na){break}else{ra=pa;sa=qa}}else{ra=la;sa=ma}na=x+1|0;oa=c[sa+(na<<2)>>2]|0;if((oa|0)==-1){ha=na;ia=ra;ja=sa;break f}else{x=na;ka=oa;la=ra;ma=sa}}c[J>>2]=c[qa+(x<<2)>>2];ha=x;ia=pa;ja=qa}}while(0);if(!((c[ja+(ha<<2)>>2]|0)==-1)){ga=ia;break}F=h|0;ma=a+420|0;Lb(F|0,128,2199848,(t=i,i=i+8|0,c[t>>2]=c[ma>>2],t)|0)|0;i=t;la=wFb(c[ma>>2]|0)|0;yDb(u,16,2191296,(t=i,i=i+8|0,c[t>>2]=(la|0)!=0?la:F,t)|0);i=t;w=-22;break b}}while(0);z=c[ga+24>>2]|0;g:do{if((z|0)!=0){F=a+140|0;la=0;while(1){ma=c[z+(la<<2)>>2]|0;if((ma|0)==-1){break}if((c[F>>2]|0)==(ma|0)){break g}else{la=la+1|0}}la=c[E>>2]|0;if((la|0)==8|(la|0)==10){if((c[a+680>>2]|0)<0){break}}la=j|0;Lb(la|0,128,2199848,(t=i,i=i+8|0,c[t>>2]=c[F>>2],t)|0)|0;i=t;ma=ZEb(c[F>>2]|0)|0;yDb(u,16,2174560,(t=i,i=i+8|0,c[t>>2]=(ma|0)!=0?ma:la,t)|0);i=t;w=-22;break b}}while(0);z=c[ga+28>>2]|0;h:do{if((z|0)!=0){la=a+412|0;ma=0;while(1){ka=c[z+(ma<<2)>>2]|0;ta=c[la>>2]|0;if((ka|0)==0){break}if((ta|0)==(ka|0)){break h}else{ma=ma+1|0}}yDb(u,16,2164360,(t=i,i=i+8|0,c[t>>2]=ta,t)|0);i=t;w=-22;break b}}while(0);z=c[ga+36>>2]|0;ma=a+448|0;i:do{if((z|0)!=0){la=c[ma>>2]|0;F=c[ma+4>>2]|0;if((la|0)==0&(F|0)==0){yDb(u,24,2157536,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else{ua=0}while(1){ka=z+(ua<<3)|0;oa=c[ka>>2]|0;na=c[ka+4>>2]|0;if((oa|0)==0&(na|0)==0){break}if((la|0)==(oa|0)&(F|0)==(na|0)){break i}else{ua=ua+1|0}}na=k|0;iBb(na,512,-1,la,F);yDb(u,16,2150760,(t=i,i=i+8|0,c[t>>2]=na,t)|0);i=t;w=-22;break b}}while(0);z=c[ma>>2]|0;na=c[ma+4>>2]|0;do{if(!((z|0)==0&(na|0)==0)){oa=(c[I>>2]|0)==0;ka=hBb(z,na)|0;if(oa){c[I>>2]=ka;break}if((ka|0)==(c[I>>2]|0)){break}oa=l|0;iBb(oa,512,-1,c[ma>>2]|0,c[ma+4>>2]|0);va=c[I>>2]|0;yDb(u,16,2143760,(t=i,i=i+24|0,c[t>>2]=oa,c[t+8>>2]=ka,c[t+16>>2]=va,t)|0);i=t;w=-22;break b}}while(0);ma=c[r>>2]|0;do{if((ma|0)==0){if((c[E>>2]|0)==62){C=143;break}if((c[a+120>>2]|0)>=1){if((c[a+124>>2]|0)>=1){C=142;break}}yDb(u,16,2138312,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;w=-22;break b}else{C=142}}while(0);if((C|0)==142){if(ma>>>0<2>>>0){C=143}}do{if((C|0)==143){na=c[a+72>>2]|0;if(!((na-1|0)>>>0<999>>>0)){break}yDb(u,24,2131688,(t=i,i=i+16|0,c[t>>2]=na,c[t+8>>2]=na,t)|0);i=t}}while(0);ma=a+564|0;if((c[ma>>2]|0)!=0){break}c[ma>>2]=((c[a+524>>2]|0)*3|0|0)/4|0}}while(0);D=a+928|0;TGb(a+904|0,0,16)|0;c[D>>2]=0;c[D+4>>2]=-2147483648;D=a+920|0;c[D>>2]=0;c[D+4>>2]=-2147483648;D=c[p>>2]|0;ma=c[D+76>>2]|0;do{if((ma|0)==0){wa=D}else{if((c[a+816>>2]&1|0)!=0){if((c[(c[n>>2]|0)+44>>2]|0)==0){wa=D;break}}na=re[ma&4095](a)|0;if((na|0)<0){w=na;break b}wa=c[p>>2]|0}}while(0);if((wa|0)==0){v=0;break a}if((c[wa+88>>2]|0)==0){v=0;break a}ma=a+72|0;if((c[ma>>2]|0)==0){j:do{if((c[r>>2]|0)==1){D=c[E>>2]|0;k:do{switch(D|0){case 69649:{xa=2;break};case 69648:{xa=3;break};case 69647:case 69633:case 69632:case 69645:case 69638:{xa=4;break};default:{if((D|0)==65545|(D|0)==65544|(D|0)==542135120|(D|0)==65547|(D|0)==65546|(D|0)==65556|(D|0)==65557){xa=32;break k}else if((D|0)==65558|(D|0)==65559){xa=64;break k}else if((D|0)==86071|(D|0)==86072|(D|0)==69644|(D|0)==69661|(D|0)==69655|(D|0)==1330333984|(D|0)==69636|(D|0)==69660|(D|0)==69646){xa=4;break k}else if((D|0)==65543|(D|0)==65542|(D|0)==65540|(D|0)==65563|(D|0)==65541|(D|0)==65553){xa=8;break k}else if((D|0)==65537|(D|0)==1347637264|(D|0)==65536|(D|0)==65554|(D|0)==65539|(D|0)==65538){xa=16;break k}else if((D|0)==65552|(D|0)==65549|(D|0)==65548|(D|0)==407917392|(D|0)==65551|(D|0)==65550){xa=24;break k}else{ya=0;break j}}}}while(0);ya=ba(ba(c[a+412>>2]|0,xa)|0,c[I>>2]|0)|0}else{ya=0}}while(0);c[ma>>2]=ya}D=a+448|0;na=c[D>>2]|0;z=c[D+4>>2]|0;do{if((na|0)==0&(z|0)==0){C=172}else{va=hBb(na,z)|0;ka=c[I>>2]|0;if((ka|0)==0){c[I>>2]=va;za=va;break}if((va|0)==(ka|0)){C=172;break}ka=m|0;iBb(ka,512,-1,c[D>>2]|0,c[D+4>>2]|0);oa=c[I>>2]|0;yDb(u,24,2125272,(t=i,i=i+24|0,c[t>>2]=ka,c[t+8>>2]=va,c[t+16>>2]=oa,t)|0);i=t;c[D>>2]=0;c[D+4>>2]=0;C=172}}while(0);if((C|0)==172){za=c[I>>2]|0}if((za|0)<0|za>>>0>63>>>0){w=-22;break b}D=a+936|0;z=c[D>>2]|0;if((z|0)==0){v=0;break a}if((c[r>>2]|0)!=3){yDb(u,16,2119616,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;w=-22;break b}na=c[K>>2]|0;if((c[na+16>>2]&65536|0)!=0){yDb(u,24,2113624,(t=i,i=i+8|0,c[t>>2]=c[na+8>>2],t)|0);i=t;c[a+940>>2]=-1;v=0;break a}na=a+940|0;ma=c[na>>2]|0;if((ma|0)==0){c[na>>2]=1}else if((ma|0)!=1){v=0;break a}ma=oGb(2099336,z)|0;if((ma|0)==-1){yDb(u,16,2092992,(t=i,i=i+8|0,c[t>>2]=c[D>>2],t)|0);i=t;w=-(c[(ld()|0)>>2]|0)|0;break b}else{qGb(ma)|0;v=0;break a}}}while(0);yDb(u,16,2287288,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;w=-22}}while(0);DBb(g);$Db(a+60|0);r=c[n>>2]|0;if((r|0)!=0){JCb(r+20|0);$Db((c[n>>2]|0)+24|0)}$Db(n);c[p>>2]=0;v=w}}while(0);if((c[1989804]|0)==0){yDb(0,0,2313288,(t=i,i=i+24|0,c[t>>2]=1882680,c[t+8>>2]=2103344,c[t+16>>2]=3333,t)|0);i=t;Cd();return 0}c[1989804]=0;c[2039024]=(c[2039024]|0)-1;t=c[1244822]|0;if((t|0)!=0){Oe[t&1023](8776288,2)|0}if(!q){o=v;i=f;return o|0}DBb(e);c[e>>2]=c[g>>2];o=v;i=f;return o|0}function n0a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[1244822]|0;do{if((d|0)!=0){if((Oe[d&1023](8776288,1)|0)==0){break}else{e=-1}i=b;return e|0}}while(0);c[2039024]=(c[2039024]|0)+1;if((c[2039024]|0)==1){if((c[1989804]|0)!=0){yDb(0,0,2313288,(f=i,i=i+24|0,c[f>>2]=1883784,c[f+8>>2]=2103344,c[f+16>>2]=3326,f)|0);i=f;Cd();return 0}c[1989804]=1;e=0;i=b;return e|0}d=a;yDb(d,16,1886760,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;if((c[1244822]|0)==0){yDb(d,16,1885104,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}c[1989804]=1;if((c[1989804]|0)==0){yDb(0,0,2313288,(f=i,i=i+24|0,c[f>>2]=1882680,c[f+8>>2]=2103344,c[f+16>>2]=3333,f)|0);i=f;Cd();return 0}c[1989804]=0;c[2039024]=(c[2039024]|0)-1;f=c[1244822]|0;if((f|0)==0){e=-22;i=b;return e|0}Oe[f&1023](8776288,2)|0;e=-22;i=b;return e|0}function o0a(a){a=a|0;return(c[a+64>>2]|0)!=0|0}function p0a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[1305378]|0;if((a|0)==65564){d=407917392}else if((a|0)==171){d=1160852272}else if((a|0)==175){d=1211250229}else if((a|0)==65565){d=542135120}else if((a|0)==173){d=1464156752}else if((a|0)==86079){d=1950507339}else if((a|0)==172){d=4665933}else if((a|0)==86077){d=1330664787}else{d=a}if((b|0)==0){e=0;return e|0}else{f=b;g=0}a:while(1){if((c[f+80>>2]|0)==0){if((c[f+84>>2]|0)==0){h=g}else{i=13}}else{i=13}do{if((i|0)==13){i=0;if((c[f+12>>2]|0)!=(d|0)){h=g;break}if((c[f+16>>2]&512|0)!=0&(g|0)==0){h=f}else{e=f;i=16;break a}}}while(0);b=c[f+56>>2]|0;if((b|0)==0){e=h;i=16;break}else{f=b;g=h}}if((i|0)==16){return e|0}return 0}function q0a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[1305378]|0;if((a|0)==65565){d=542135120}else if((a|0)==175){d=1211250229}else if((a|0)==172){d=4665933}else if((a|0)==65564){d=407917392}else if((a|0)==173){d=1464156752}else if((a|0)==171){d=1160852272}else if((a|0)==86079){d=1950507339}else if((a|0)==86077){d=1330664787}else{d=a}if((b|0)==0){e=0;return e|0}else{f=b;g=0}a:while(1){do{if((c[f+88>>2]|0)==0){h=g}else{if((c[f+12>>2]|0)!=(d|0)){h=g;break}if((c[f+16>>2]&512|0)!=0&(g|0)==0){h=f}else{e=f;i=15;break a}}}while(0);b=c[f+56>>2]|0;if((b|0)==0){e=h;i=15;break}else{f=b;g=h}}if((i|0)==15){return e|0}return 0}function r0a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=b+28|0;h=c[g>>2]|0;if((h|0)<0){yDb(a,16,2087656,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;k=-22;i=f;return k|0}l=0;if(e>>>0>l>>>0|e>>>0==l>>>0&d>>>0>2147483631>>>0){yDb(a,16,2083088,(j=i,i=i+24|0,c[j>>2]=d,c[j+8>>2]=e,c[j+16>>2]=2147483631,j)|0);i=j;k=-22;i=f;return k|0}l=b+24|0;m=c[l>>2]|0;a:do{if((a|0)==0){n=h;o=m}else{p=c[a+64>>2]|0;do{if((m|0)!=0){if((m|0)==(c[p+36>>2]|0)){yDb(0,0,2313288,(j=i,i=i+24|0,c[j>>2]=2077384,c[j+8>>2]=2103344,c[j+16>>2]=1542,j)|0);i=j;Cd();return 0}else{q=(h|0)<0|0?-1:0;if((q|0)<(e|0)|(q|0)==(e|0)&h>>>0<d>>>0){break}else{n=h;o=m;break a}}}}while(0);q=a+64|0;r=p+36|0;s=p+40|0;t=d;do{if(t>>>0>4294967279>>>0){$Db(r);c[s>>2]=0}else{u=t+16|0;if((c[s>>2]|0)>>>0>u>>>0){TGb((c[r>>2]|0)+t|0,0,16)|0;break}else{v=((u*17|0)>>>4)+32|0;w=v>>>0>u>>>0?v:u;ZDb(c[r>>2]|0);u=cEb(w)|0;c[r>>2]=u;c[s>>2]=(u|0)==0?0:w;break}}}while(0);s=c[(c[q>>2]|0)+36>>2]|0;c[l>>2]=s;r=c[(c[q>>2]|0)+40>>2]|0;c[g>>2]=r;c[b+52>>2]=0;n=r;o=s}}while(0);if((o|0)==0){o=wZ(b,d)|0;if((o|0)>=0){k=o;i=f;return k|0}yDb(a,16,2068e3,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=e,j)|0);i=j;k=o;i=f;return k|0}o=b|0;l=b+52|0;m=(n|0)<0|0?-1:0;if((m|0)<(e|0)|(m|0)==(e|0)&n>>>0<d>>>0){yDb(a,16,2072688,(j=i,i=i+24|0,c[j>>2]=n,c[j+8>>2]=d,c[j+16>>2]=e,j)|0);i=j;k=-22;i=f;return k|0}else{j=c[l>>2]|0;e=c[o>>2]|0;vZ(b);c[l>>2]=j;c[o>>2]=e;c[g>>2]=d;k=0;i=f;return k|0}return 0}function s0a(a,b){a=a|0;b=b|0;return r0a(0,a,b,(b|0)<0|0?-1:0)|0}function t0a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;c[j>>2]=0;k=b|0;l=c[k>>2]|0;m=b+24|0;n=c[m>>2]|0;o=b+28|0;p=c[o>>2]|0;q=b+52|0;r=c[q>>2]|0;s=(n|0)!=0;t=s&1^1;c[e>>2]=0;u=a+12|0;v=c[u>>2]|0;w=c[v+16>>2]|0;x=(d|0)==0;if((w&32|0)==0&x){BZ(b);vZ(b);y=0;i=f;return y|0}a:do{if(x){z=0;A=0;B=v;C=26}else{do{if((c[d+64>>2]|0)==0){do{if((CFb(c[a+420>>2]|0)|0)!=0){if((c[a+416>>2]|0)<=8){break}yDb(a,16,2063584,(D=i,i=i+8|0,c[D>>2]=8,D)|0);i=D;y=-22;i=f;return y|0}}while(0);yDb(a,24,2059864,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=ICb()|0;if((E|0)==0){y=-12;i=f;return y|0}else{F=E;UGb(F|0,d|0,472)|0;c[E+64>>2]=E;G=c[u>>2]|0;H=E;I=F;J=G;K=c[G+16>>2]|0;break}}else{H=d;I=0;J=v;K=w}}while(0);if((K&64|0)!=0){if((c[H+76>>2]|0)<=(c[a+424>>2]|0)){z=H;A=I;B=J;C=26;break}yDb(a,16,2055056,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;L=-22;M=I;break}if((K&65536|0)!=0){z=H;A=I;B=J;C=26;break}G=H+76|0;F=c[G>>2]|0;E=a+424|0;N=c[E>>2]|0;b:do{if((F|0)<(N|0)){O=a+64|0;if((c[(c[O>>2]|0)+16>>2]|0)!=0){P=H;Q=F;R=N;break}S=ICb()|0;c[h>>2]=S;if((S|0)==0){L=-12;M=I;break a}c[S+80>>2]=c[H+80>>2];T=H+352|0;U=c[T+4>>2]|0;V=S+352|0;c[V>>2]=c[T>>2];c[V+4>>2]=U;wCb(S,vCb(H)|0);c[S+76>>2]=c[E>>2];U=LCb(S,32)|0;do{if((U|0)<0){W=U}else{V=NCb(S,H)|0;if((V|0)<0){W=V;break}V=a+416|0;T=a+420|0;X=IFb(c[(c[h>>2]|0)+64>>2]|0,c[H+64>>2]|0,0,0,c[G>>2]|0,c[V>>2]|0,c[T>>2]|0)|0;if((X|0)<0){W=X;break}X=c[h>>2]|0;Y=c[G>>2]|0;Z=GFb(c[X+64>>2]|0,Y,(c[X+76>>2]|0)-Y|0,c[V>>2]|0,c[T>>2]|0)|0;if((Z|0)<0){W=Z;break}Z=c[h>>2]|0;c[j>>2]=Z;c[(c[O>>2]|0)+16>>2]=1;P=Z;Q=c[Z+76>>2]|0;R=c[E>>2]|0;break b}}while(0);JCb(h);L=W;M=I;break a}else{P=H;Q=F;R=N}}while(0);if((Q|0)==(R|0)){z=P;A=I;B=c[u>>2]|0;C=26;break}else{yDb(a,16,2044e3,(D=i,i=i+16|0,c[D>>2]=Q,c[D+8>>2]=R,D)|0);i=D;L=-22;M=I;break}}}while(0);c:do{if((C|0)==26){I=_e[c[B+84>>2]&1023](a,b,z,e)|0;do{if((I|0)==0){if((c[e>>2]|0)==0){c[o>>2]=0;break}R=b+8|0;do{if((c[(c[u>>2]|0)+16>>2]&32|0)==0){if((c[R>>2]|0)==0&(c[R+4>>2]|0)==(-2147483648|0)){Q=z+136|0;P=c[Q+4>>2]|0;c[R>>2]=c[Q>>2];c[R+4>>2]=P}P=b+48|0;if((c[P>>2]|0)!=0){break}Q=c[z+76>>2]|0;c[g>>2]=1;c[g+4>>2]=c[a+412>>2];H=KDb(Q,(Q|0)<0|0?-1:0,g,a+104|0)|0;c[P>>2]=H}}while(0);H=c[R+4>>2]|0;P=b+16|0;c[P>>2]=c[R>>2];c[P+4>>2]=H}}while(0);H=c[m>>2]|0;do{if((H|0)==0){_=t;$=I}else{if((H|0)!=(c[(c[a+64>>2]|0)+36>>2]|0)){_=t;$=I;break}if(!s){P=(CZ(b)|0)<0;_=0;$=P?-12:I;break}P=c[o>>2]|0;if((p|0)<(P|0)){yDb(a,16,2039104,(D=i,i=i+8|0,c[D>>2]=P,D)|0);i=D;c[o>>2]=p;aa=-1}else{UGb(n|0,H|0,P)|0;aa=I}c[k>>2]=l;c[m>>2]=n;c[q>>2]=r;_=0;$=aa}}while(0);if(($|0)==0){do{if((_|0)==0){ba=0}else{if((c[m>>2]|0)==0){ba=0;break}I=$Ab(k,(c[o>>2]|0)+16|0)|0;if(!((I|0)>-1)){ba=I;break}c[m>>2]=c[(c[k>>2]|0)+4>>2];ba=I}}while(0);I=a+428|0;c[I>>2]=(c[I>>2]|0)+1;ca=ba}else{ca=$}do{if((ca|0)>=0){if((c[e>>2]|0)==0){break}I=b+36|0;c[I>>2]=c[I>>2]|1;L=ca;M=A;break c}}while(0);BZ(b);vZ(b);L=ca;M=A}}while(0);JCb(j);ZDb(M);y=L;i=f;return y|0}function u0a(a){a=a|0;var b=0;a:do{switch(a|0){case 69649:{b=2;break};case 69648:{b=3;break};case 69647:case 69633:case 69632:case 69645:case 69638:{b=4;break};default:{if((a|0)==65545|(a|0)==65544|(a|0)==542135120|(a|0)==65547|(a|0)==65546|(a|0)==65556|(a|0)==65557){b=32;break a}else if((a|0)==65552|(a|0)==65549|(a|0)==65548|(a|0)==407917392|(a|0)==65551|(a|0)==65550){b=24;break a}else if((a|0)==65543|(a|0)==65542|(a|0)==65540|(a|0)==65563|(a|0)==65541|(a|0)==65553){b=8;break a}else if((a|0)==65537|(a|0)==1347637264|(a|0)==65536|(a|0)==65554|(a|0)==65539|(a|0)==65538){b=16;break a}else if((a|0)==86071|(a|0)==86072|(a|0)==69644|(a|0)==69661|(a|0)==69655|(a|0)==1330333984|(a|0)==69636|(a|0)==69660|(a|0)==69646){b=4;break a}else if((a|0)==65558|(a|0)==65559){b=64;break a}else{b=0;break a}}}}while(0);return b|0}function v0a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;h=d|0;j=c[h>>2]|0;k=d+24|0;l=c[k>>2]|0;m=d+28|0;n=c[m>>2]|0;o=d+52|0;p=c[o>>2]|0;q=(l|0)!=0;r=q&1^1;c[f>>2]=0;do{if((c[b+88>>2]&512|0)!=0){s=c[b+668>>2]|0;if((s|0)==0){break}a[s]=0}}while(0);s=b+12|0;if((c[(c[s>>2]|0)+16>>2]&32|0)==0&(e|0)==0){BZ(d);vZ(d);c[m>>2]=0;t=0;i=g;return t|0}u=b;if((hDb(c[b+120>>2]|0,c[b+124>>2]|0,0,u)|0)!=0){t=-22;i=g;return t|0}v=c[(c[s>>2]|0)+84>>2]|0;if((v|0)==0){yDb(0,0,2313288,(w=i,i=i+24|0,c[w>>2]=2028128,c[w+8>>2]=2103344,c[w+16>>2]=1903,w)|0);i=w;Cd();return 0}x=_e[v&1023](b,d,e,f)|0;if((x|0)>=1){yDb(0,0,2313288,(w=i,i=i+24|0,c[w>>2]=2024488,c[w+8>>2]=2103344,c[w+16>>2]=1906,w)|0);i=w;Cd();return 0}v=c[k>>2]|0;do{if((v|0)==0){y=r;z=x}else{if((v|0)!=(c[(c[b+64>>2]|0)+36>>2]|0)){y=r;z=x;break}if(!q){A=(CZ(d)|0)<0;y=0;z=A?-12:x;break}A=c[m>>2]|0;if((n|0)<(A|0)){yDb(u,16,2039104,(w=i,i=i+8|0,c[w>>2]=A,w)|0);i=w;c[m>>2]=n;B=-1}else{UGb(l|0,v|0,A)|0;B=x}c[h>>2]=j;c[k>>2]=l;c[o>>2]=p;y=0;z=B}}while(0);if((z|0)==0){do{if((c[f>>2]|0)==0){c[m>>2]=0}else{if((c[(c[s>>2]|0)+16>>2]&32|0)!=0){break}B=e+136|0;p=c[B>>2]|0;o=c[B+4>>2]|0;B=d+16|0;c[B>>2]=p;c[B+4>>2]=o;B=d+8|0;c[B>>2]=p;c[B+4>>2]=o}}while(0);do{if((y|0)==0){C=0}else{if((c[k>>2]|0)==0){C=0;break}e=$Ab(h,(c[m>>2]|0)+16|0)|0;if(!((e|0)>-1)){C=e;break}c[k>>2]=c[(c[h>>2]|0)+4>>2];C=e}}while(0);h=b+428|0;c[h>>2]=(c[h>>2]|0)+1;D=C}else{D=z}do{if((D|0)>=0){if((c[f>>2]|0)==0){break}IZ(d)|0;t=D;i=g;return t|0}}while(0);BZ(d);t=D;i=g;return t|0}function w0a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;if((c[e+4>>2]|0)==0){g=_e[c[(c[a+12>>2]|0)+80>>2]&1023](a,b,d,e)|0;e=a+428|0;c[e>>2]=(c[e>>2]|0)+1;h=g;i=f;return h|0}else{yDb(a,16,2021224,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;h=-1;i=f;return h|0}return 0}function x0a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+88|0;g=f|0;h=f+8|0;j=a+64|0;k=c[j>>2]|0;UGb(h|0,e|0,80)|0;l=a+12|0;m=c[l>>2]|0;if((m|0)==0){n=-22;i=f;return n|0}if((c[m+8>>2]|0)!=0){yDb(a,16,2017320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-22;i=f;return n|0}c[d>>2]=0;m=c[a+128>>2]|0;p=c[a+132>>2]|0;do{if((m|p|0)!=0){if((hDb(m,p,0,a)|0)==0){break}else{n=-22}i=f;return n|0}}while(0);KCb(b);do{if((c[(c[l>>2]|0)+16>>2]&32|0)==0){if((c[e+28>>2]|0)!=0){q=9;break}if((c[a+816>>2]&1|0)==0){r=0}else{q=9}}else{q=9}}while(0);do{if((q|0)==9){p=JZ(h)|0;m=y0a(a,h)|0;if((m|0)<0){yDb(a,16,2013384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;if((c[a+696>>2]&8|0)==0){q=11}else{s=m}}else{q=11}if((q|0)==11){c[(c[j>>2]|0)+32>>2]=h;m=_e[c[(c[l>>2]|0)+88>>2]&1023](a,b,d,h)|0;t=e+16|0;u=c[t+4>>2]|0;v=b+152|0;c[v>>2]=c[t>>2];c[v+4>>2]=u;if((c[a+176>>2]|0)==0){u=e+64|0;tCb(b,c[u>>2]|0,c[u+4>>2]|0)}do{if((c[(c[l>>2]|0)+16>>2]&2|0)==0){u=b+124|0;if((c[u>>2]|0)==0){v=a+224|0;t=u;u=c[v+4>>2]|0;c[t>>2]=c[v>>2];c[t+4>>2]=u}u=b+68|0;if((c[u>>2]|0)==0){c[u>>2]=c[a+120>>2]}u=b+72|0;if((c[u>>2]|0)==0){c[u>>2]=c[a+124>>2]}u=b+80|0;if(!((c[u>>2]|0)==-1)){break}c[u>>2]=c[a+140>>2]}}while(0);u=FCb(b)|0;t=HZ(c[(c[j>>2]|0)+32>>2]|0,72,g)|0;LZ(t,c[g>>2]|0,u)|0;s=m}c[(c[j>>2]|0)+32>>2]=0;do{if((p|0)==0){w=s}else{FZ(h);if((s|0)!=(c[h+28>>2]|0)){w=s;break}w=c[e+28>>2]|0}}while(0);if((c[d>>2]|0)==0){KCb(b);r=w;break}do{if((c[a+488>>2]|0)==0){p=z0a(k,b)|0;if((p|0)<0){n=p}else{break}i=f;return n|0}}while(0);p=a+428|0;c[p>>2]=(c[p>>2]|0)+1;p=b+144|0;m=c[p>>2]|0;u=c[p+4>>2]|0;p=b+152|0;t=c[p>>2]|0;v=c[p+4>>2]|0;p=(t|0)!=0|(v|0)!=(-2147483648|0);do{if(p){x=a+928|0;y=c[x+4>>2]|0;z=a+912|0;A=YGb((y|0)>=(v|0)&((y|0)>(v|0)|(c[x>>2]|0)>>>0>=t>>>0)&1,0,c[z>>2]|0,c[z+4>>2]|0)|0;c[z>>2]=A;c[z+4>>2]=F;c[x>>2]=t;c[x+4>>2]=v;q=33}else{if((m|0)==0&(u|0)==(-2147483648|0)){B=1;break}x=a+928|0;c[x>>2]=m;c[x+4>>2]=u;q=33}}while(0);do{if((q|0)==33){if(!((m|0)==0&(u|0)==(-2147483648|0))){x=a+920|0;z=c[x+4>>2]|0;A=a+904|0;y=YGb((z|0)>=(u|0)&((z|0)>(u|0)|(c[x>>2]|0)>>>0>=m>>>0)&1,0,c[A>>2]|0,c[A+4>>2]|0)|0;c[A>>2]=y;c[A+4>>2]=F;c[x>>2]=m;c[x+4>>2]=u;B=0;break}if(!p){B=1;break}x=a+920|0;c[x>>2]=t;c[x+4>>2]=v;B=1}}while(0);x=a+904|0;A=c[x+4>>2]|0;y=a+912|0;z=c[y+4>>2]|0;C=p&((A|0)>(z|0)|(A|0)==(z|0)&(c[x>>2]|0)>>>0>(c[y>>2]|0)>>>0)|B;pCb(b,C?t:m,C?v:u);r=w}}while(0);w=c[b+64>>2]|0;if((w|0)==0|(w|0)==(b|0)){n=r;i=f;return n|0}else{yDb(0,0,2313288,(o=i,i=i+24|0,c[o>>2]=2009080,c[o+8>>2]=2103344,c[o+16>>2]=2200,o)|0);i=o;Cd();return 0}return 0}function y0a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;g=HZ(b,2,f)|0;if((g|0)==0){h=0;i=e;return h|0}if((c[(c[a+12>>2]|0)+16>>2]&16384|0)==0){yDb(a,16,2347760,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-22;i=e;return h|0}b=c[f>>2]|0;a:do{if((b|0)>=4){k=g+4|0;l=g;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b-4|0;c[f>>2]=l;if((m&1|0)==0){n=k;o=l}else{if((l|0)<4){break}l=k;c[a+416>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b-8|0;c[f>>2]=l;n=g+8|0;o=l}if((m&2|0)==0){p=n;q=o}else{if((o|0)<8){break}l=n;k=l|0;r=l+4|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=a+448|0;c[r>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[r+4>>2]=l;l=o-8|0;c[f>>2]=l;p=n+8|0;q=l}if((m&4|0)==0){s=p;t=q}else{if((q|0)<4){break}l=p;c[a+412>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=q-4|0;c[f>>2]=l;s=p+4|0;t=l}do{if((m&8|0)!=0){if((t|0)<8){break a}l=s;r=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+120|0;c[l>>2]=r;k=s+4|0;u=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+124|0;c[k>>2]=u;c[f>>2]=t-8;v=hDb(r,u,0,a)|0;w=(v|0)<0;x=w?0:u;u=w?0:r;c[a+128>>2]=u;c[a+132>>2]=x;r=c[a+800>>2]|0;c[l>>2]=-(-u>>r);c[k>>2]=-(-x>>r);if(w){h=v}else{break}i=e;return h|0}}while(0);h=0;i=e;return h|0}}while(0);yDb(a,16,2346112,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-1094995529;i=e;return h|0}function z0a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+20|0;KCb(c[d>>2]|0);QCb(c[d>>2]|0,b);a=NCb(b,c[d>>2]|0)|0;if((a|0)<0){e=a;return e|0}UGb(b|0,c[d>>2]|0,32)|0;UGb(b+32|0,(c[d>>2]|0)+32|0,32)|0;a=c[d>>2]|0;do{if((c[a+64>>2]|0)==(a|0)){c[b+64>>2]=b;f=c[d>>2]|0}else{g=(vCb(a)|0)<<2;if((g|0)==0){KCb(b);e=-558323010;return e|0}h=WDb(g)|0;c[b+64>>2]=h;if((h|0)!=0){i=c[d>>2]|0;UGb(h|0,c[i+64>>2]|0,g)|0;f=i;break}KCb(b);e=-12;return e|0}}while(0);c[b+80>>2]=c[f+80>>2];c[b+68>>2]=c[f+68>>2];c[b+72>>2]=c[f+72>>2];d=f+352|0;a=c[d+4>>2]|0;i=b+352|0;c[i>>2]=c[d>>2];c[i+4>>2]=a;c[b+76>>2]=c[f+76>>2];wCb(b,vCb(f)|0);e=0;return e|0}function A0a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;i=i+112|0;h=g|0;j=g+8|0;k=g+16|0;l=g+96|0;m=g+104|0;n=a+64|0;o=c[n>>2]|0;c[e>>2]=0;do{if((c[f+24>>2]|0)==0){if((c[f+28>>2]|0)==0){break}yDb(a,16,1987872,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=g;return q|0}}while(0);r=a+12|0;s=c[r>>2]|0;if((s|0)==0){q=-22;i=g;return q|0}if((c[s+8>>2]|0)!=1){yDb(a,16,1983576,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=g;return q|0}KCb(b);do{if((c[(c[r>>2]|0)+16>>2]&32|0)==0){if((c[f+28>>2]|0)!=0){t=10;break}if((c[a+816>>2]&1|0)==0){u=0}else{t=10}}else{t=10}}while(0);a:do{if((t|0)==10){UGb(k|0,f|0,80)|0;s=JZ(k)|0;v=y0a(a,k)|0;if((v|0)<0){yDb(a,16,2013384,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;if((c[a+696>>2]&8|0)==0){t=12}else{w=v}}else{t=12}do{if((t|0)==12){c[(c[n>>2]|0)+32>>2]=k;v=_e[c[(c[r>>2]|0)+88>>2]&1023](a,b,e,k)|0;x=f+16|0;y=c[x+4>>2]|0;z=b+152|0;c[z>>2]=c[x>>2];c[z+4>>2]=y;do{if((v|0)>-1){if((c[e>>2]|0)==0){break}y=FCb(b)|0;x=HZ(c[(c[n>>2]|0)+32>>2]|0,72,h)|0;LZ(x,c[h>>2]|0,y)|0;y=a+428|0;c[y>>2]=(c[y>>2]|0)+1;y=b+144|0;x=c[y>>2]|0;A=c[y+4>>2]|0;y=c[z>>2]|0;B=c[z+4>>2]|0;C=(y|0)!=0|(B|0)!=(-2147483648|0);do{if(C){D=a+928|0;E=c[D+4>>2]|0;G=a+912|0;H=YGb((E|0)>=(B|0)&((E|0)>(B|0)|(c[D>>2]|0)>>>0>=y>>>0)&1,0,c[G>>2]|0,c[G+4>>2]|0)|0;c[G>>2]=H;c[G+4>>2]=F;c[D>>2]=y;c[D+4>>2]=B;t=18}else{if((x|0)==0&(A|0)==(-2147483648|0)){I=1;break}D=a+928|0;c[D>>2]=x;c[D+4>>2]=A;t=18}}while(0);do{if((t|0)==18){if(!((x|0)==0&(A|0)==(-2147483648|0))){D=a+920|0;G=c[D+4>>2]|0;H=a+904|0;E=YGb((G|0)>=(A|0)&((G|0)>(A|0)|(c[D>>2]|0)>>>0>=x>>>0)&1,0,c[H>>2]|0,c[H+4>>2]|0)|0;c[H>>2]=E;c[H+4>>2]=F;c[D>>2]=x;c[D+4>>2]=A;I=0;break}if(!C){I=1;break}D=a+920|0;c[D>>2]=y;c[D+4>>2]=B;I=1}}while(0);D=a+904|0;H=c[D+4>>2]|0;E=a+912|0;G=c[E+4>>2]|0;J=C&((H|0)>(G|0)|(H|0)==(G|0)&(c[D>>2]|0)>>>0>(c[E>>2]|0)>>>0)|I;pCb(b,J?y:x,J?B:A);J=b+80|0;if((c[J>>2]|0)==-1){c[J>>2]=c[a+420>>2]}J=b+352|0;if((c[J>>2]|0)==0&(c[J+4>>2]|0)==0){E=a+448|0;D=c[E+4>>2]|0;c[J>>2]=c[E>>2];c[J+4>>2]=D}if((vCb(b)|0)==0){wCb(b,c[a+416>>2]|0)}D=b+344|0;if((c[D>>2]|0)!=0){break}c[D>>2]=c[a+412>>2]}}while(0);D=HZ(c[(c[n>>2]|0)+32>>2]|0,70,j)|0;if((D|0)!=0&(c[j>>2]|0)>9){J=D;E=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;c[(c[n>>2]|0)+48>>2]=E;yDb(a,48,1980728,(p=i,i=i+8|0,c[p>>2]=E,p)|0);i=p;E=D+4|0;K=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0}else{K=0}E=(c[n>>2]|0)+48|0;D=c[E>>2]|0;do{if((D|0)!=0){if((c[e>>2]|0)==0){break}J=b+76|0;G=c[J>>2]|0;if((G|0)<=(D|0)){c[e>>2]=0;H=(c[E>>2]|0)-(c[J>>2]|0)|0;c[E>>2]=H;yDb(a,48,1977992,(p=i,i=i+8|0,c[p>>2]=H,p)|0);i=p;break}H=c[b+64>>2]|0;IFb(H,H,0,D,G-D|0,c[a+416>>2]|0,c[b+80>>2]|0)|0;G=a+888|0;do{if((c[G>>2]|0)==0){t=44}else{H=c[a+412>>2]|0;if((H|0)==0){t=44;break}L=c[(c[n>>2]|0)+48>>2]|0;c[l>>2]=1;c[l+4>>2]=H;H=KDb(L,(L|0)<0|0?-1:0,l,G)|0;L=F;M=b+144|0;N=c[M>>2]|0;O=c[M+4>>2]|0;if(!((N|0)==0&(O|0)==(-2147483648|0))){P=YGb(N,O,H,L)|0;c[M>>2]=P;c[M+4>>2]=F}M=c[z>>2]|0;P=c[z+4>>2]|0;if(!((M|0)==0&(P|0)==(-2147483648|0))){O=YGb(M,P,H,L)|0;c[z>>2]=O;c[z+4>>2]=F}O=qCb(b)|0;P=F;if((P|0)<(L|0)|(P|0)==(L|0)&O>>>0<H>>>0){break}O=qCb(b)|0;P=ZGb(O,F,H,L)|0;rCb(b,P,F)}}while(0);if((t|0)==44){yDb(a,24,1975408,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}G=c[J>>2]|0;yDb(a,48,1973456,(p=i,i=i+16|0,c[p>>2]=c[(c[n>>2]|0)+48>>2],c[p+8>>2]=G,p)|0);i=p;G=(c[n>>2]|0)+48|0;c[J>>2]=(c[J>>2]|0)-(c[G>>2]|0);c[G>>2]=0}}while(0);if((K|0)==0){w=v;break}z=b+76|0;D=c[z>>2]|0;if(K>>>0>D>>>0){w=v;break}if((c[e>>2]|0)==0){w=v;break}if((K|0)==(D|0)){c[e>>2]=0;w=v;break}E=a+888|0;do{if((c[E>>2]|0)==0){t=55}else{G=c[a+412>>2]|0;if((G|0)==0){t=55;break}c[m>>2]=1;c[m+4>>2]=G;G=KDb(D-K|0,0,m,E)|0;A=F;B=qCb(b)|0;x=F;if((x|0)<(A|0)|(x|0)==(A|0)&B>>>0<G>>>0){break}B=qCb(b)|0;x=ZGb(B,F,G,A)|0;rCb(b,x,F)}}while(0);if((t|0)==55){yDb(a,24,1970624,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}E=c[z>>2]|0;yDb(a,48,1961776,(p=i,i=i+16|0,c[p>>2]=K,c[p+8>>2]=E,p)|0);i=p;c[z>>2]=(c[z>>2]|0)-K;w=v}}while(0);c[(c[n>>2]|0)+32>>2]=0;do{if((s|0)==0){Q=w}else{FZ(k);if((w|0)!=(c[k+28>>2]|0)){Q=w;break}Q=c[f+28>>2]|0}}while(0);do{if((Q|0)>-1){if((c[e>>2]|0)==0){break}if((c[a+488>>2]|0)!=0){u=Q;break a}s=z0a(o,b)|0;if((s|0)<0){q=s}else{u=Q;break a}i=g;return q|0}}while(0);KCb(b);u=Q}}while(0);q=u;i=g;return q|0}function B0a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;i=i+280|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+112|0;q=j+192|0;r=j+272|0;do{if((c[h+24>>2]|0)==0){if((c[h+28>>2]|0)==0){break}yDb(e,16,1987872,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-22;i=j;return t|0}}while(0);u=e+12|0;v=c[u>>2]|0;if((v|0)==0){t=-22;i=j;return t|0}if((c[v+8>>2]|0)!=3){yDb(e,16,1959304,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-22;i=j;return t|0}c[g>>2]=0;v=f;TGb(v|0,0,24)|0;w=f+24|0;c[w>>2]=0;c[w+4>>2]=-2147483648;do{if((c[(c[u>>2]|0)+16>>2]&32|0)==0){if((c[h+28>>2]|0)==0){t=0}else{break}i=j;return t|0}}while(0);x=q;UGb(x|0,h|0,80)|0;y=(JZ(q)|0)!=0;if(y){z=c[q+28>>2]|0;A=(c[h+28>>2]|0)-z|0;TGb((c[q+24>>2]|0)+z|0,0,((A|0)>16?16:A)|0)|0}UGb(p|0,x|0,80)|0;do{if((c[e+940>>2]|0)==1){x=q+28|0;if((c[x>>2]|0)==0){B=0;break}A=e+936|0;z=oGb(2099336,c[A>>2]|0)|0;if((z|0)==-1){yDb(0,0,2313288,(s=i,i=i+24|0,c[s>>2]=1879944,c[s+8>>2]=2103344,c[s+16>>2]=2411,s)|0);i=s;Cd();return 0}C=q+24|0;c[k>>2]=c[C>>2];D=c[x>>2]|0;c[m>>2]=D;a:do{if(D>>>0>536870894>>>0){yDb(e,16,2355752,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;E=-12}else{x=wZ(o,D<<2)|0;if((x|0)<0){E=x;break}c[p>>2]=c[o>>2];G=c[o+24>>2]|0;H=p+24|0;c[H>>2]=G;I=c[o+28>>2]|0;J=p+28|0;c[J>>2]=I;c[l>>2]=G;c[n>>2]=I;do{if(!((rGb(z,k,m,l,n)|0)==-1)){if((rGb(z,0,0,l,n)|0)==-1){break}I=c[n>>2]|0;G=c[J>>2]|0;if(!(I>>>0<G>>>0)){break}if((c[m>>2]|0)!=0){break}K=G-I|0;c[J>>2]=K;TGb((c[H>>2]|0)+K|0,0,I|0)|0;E=x;break a}}while(0);x=c[A>>2]|0;yDb(e,16,2354440,(s=i,i=i+16|0,c[s>>2]=c[C>>2],c[s+8>>2]=x,s)|0);i=s;BZ(o);E=-(c[(ld()|0)>>2]|0)|0}}while(0);qGb(z)|0;B=E}else{B=0}}while(0);if((B|0)<0){c[g>>2]=0;L=B}else{B=e+64|0;c[(c[B>>2]|0)+32>>2]=p;E=e+888|0;do{if((c[e+892>>2]|0)!=0){o=h+8|0;m=c[o>>2]|0;n=c[o+4>>2]|0;if((m|0)==0&(n|0)==(-2147483648|0)){break}c[r>>2]=1;c[r+4>>2]=1e6;o=KDb(m,n,E,r)|0;c[w>>2]=o;c[w+4>>2]=F}}while(0);w=_e[c[(c[u>>2]|0)+88>>2]&1023](e,v,g,p)|0;v=f+12|0;u=c[v>>2]|0;b:do{if((u|0)!=0){r=f+8|0;if((c[r>>2]|0)==0){o=c[h+48>>2]|0;do{if((o|0)==0){M=u}else{if((c[E>>2]|0)==0){M=u;break}n=KDb(o,(o|0)<0|0?-1:0,E,1775408)|0;c[r>>2]=n;M=c[v>>2]|0}}while(0);if((M|0)==0){break}else{N=M}}else{N=u}r=c[f+16>>2]|0;o=0;c:while(1){z=c[(c[r+(o<<2)>>2]|0)+92>>2]|0;d:do{if((z|0)!=0){n=z;while(1){m=a[n]|0;if(m<<24>>24==0){break d}l=m&255;k=l>>>1&64;if((l&192|0)==128|(m&255)>>>0>253>>>0){break c}m=n+1|0;if((k&l|0)==0){O=l;P=k;Q=m}else{C=l;l=k;k=m;while(1){m=(d[k]|0)-128|0;if(m>>>0>63>>>0){break c}A=m+(C<<6)|0;m=l<<5;D=k+1|0;if((A&m|0)==0){O=A;P=m;Q=D;break}else{C=A;l=m;k=D}}}k=(P<<1)-1&O;l=Q-n|0;do{if((l|0)==1){R=0}else{if((l|0)==2){R=128;break}R=1<<(l*5|0)-4}}while(0);if(k>>>0<R>>>0|k>>>0>1114111>>>0|(k|0)==65534|(k-55296|0)>>>0<2048>>>0){break c}else{n=Q}}}}while(0);o=o+1|0;if(!(o>>>0<N>>>0)){break b}}yDb(e,16,1957168,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;C0a(f);t=-1094995529;i=j;return t|0}}while(0);if((c[q+24>>2]|0)!=(c[p+24>>2]|0)){c[p+40>>2]=0;c[p+44>>2]=0;BZ(p)}p=c[(c[e+896>>2]|0)+16>>2]|0;do{if((p&65536|0)==0){if((p&131072|0)==0){break}b[f>>1]=1}else{b[f>>1]=0}}while(0);c[(c[B>>2]|0)+32>>2]=0;L=w}do{if(y){FZ(q);if((L|0)!=(c[q+28>>2]|0)){S=L;break}S=c[h+28>>2]|0}else{S=L}}while(0);if((c[g>>2]|0)==0){t=S;i=j;return t|0}g=e+428|0;c[g>>2]=(c[g>>2]|0)+1;t=S;i=j;return t|0}function C0a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+12|0;d=a+16|0;if((c[b>>2]|0)==0){e=d;$Db(e);f=a;TGb(f|0,0,32)|0;return}else{g=0}do{$Db((c[(c[d>>2]|0)+(g<<2)>>2]|0)+20|0);$Db((c[(c[d>>2]|0)+(g<<2)>>2]|0)+24|0);$Db((c[(c[d>>2]|0)+(g<<2)>>2]|0)+28|0);$Db((c[(c[d>>2]|0)+(g<<2)>>2]|0)+32|0);$Db((c[(c[d>>2]|0)+(g<<2)>>2]|0)+88|0);$Db((c[(c[d>>2]|0)+(g<<2)>>2]|0)+92|0);$Db((c[d>>2]|0)+(g<<2)|0);g=g+1|0;}while(g>>>0<(c[b>>2]|0)>>>0);e=d;$Db(e);f=a;TGb(f|0,0,32)|0;return}function D0a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[1989804]|0)==0){yDb(0,0,2313288,(d=i,i=i+24|0,c[d>>2]=1882680,c[d+8>>2]=2103344,c[d+16>>2]=3333,d)|0);i=d;Cd();return 0}c[1989804]=0;c[2039024]=(c[2039024]|0)-1;d=c[1244822]|0;if((d|0)==0){e=E0a(a)|0;f=n0a(0)|0;i=b;return e|0}Oe[d&1023](8776288,2)|0;e=E0a(a)|0;f=n0a(0)|0;i=b;return e|0}function E0a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;if((a|0)==0){d=0;i=b;return d|0}e=n0a(a)|0;if((e|0)<0){d=e;i=b;return d|0}e=a+64|0;f=c[e>>2]|0;if((f|0)!=0){g=c[f+24>>2]|0;h=c[a+12>>2]|0;do{if((h|0)==0){j=f}else{k=c[h+92>>2]|0;if((k|0)==0){j=f;break}re[k&4095](a)|0;j=c[e>>2]|0}}while(0);c[a+804>>2]=0;c[j+40>>2]=0;$Db(j+36|0);JCb((c[e>>2]|0)+20|0);bBb(g|0);bBb(g+4|0);bBb(g+8|0);bBb(g+12|0);$Db((c[e>>2]|0)+24|0);$Db(e)}e=a+60|0;g=c[e>>2]|0;j=a+12|0;do{if((g|0)!=0){f=c[j>>2]|0;if((f|0)==0){break}if((c[f+44>>2]|0)==0){break}HEb(g)}}while(0);HEb(a);$Db(e);e=c[j>>2]|0;do{if((e|0)!=0){if((c[e+80>>2]|0)==0){if((c[e+84>>2]|0)==0){break}}$Db(a+96|0)}}while(0);c[j>>2]=0;c[a+816>>2]=0;if((c[1989804]|0)==0){yDb(0,0,2313288,(a=i,i=i+24|0,c[a>>2]=1882680,c[a+8>>2]=2103344,c[a+16>>2]=3333,a)|0);i=a;Cd();return 0}c[1989804]=0;c[2039024]=(c[2039024]|0)-1;a=c[1244822]|0;if((a|0)==0){d=0;i=b;return d|0}Oe[a&1023](8776288,2)|0;d=0;i=b;return d|0}function F0a(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){b=0;return b|0}d=c[1305378]|0;if((d|0)==0){b=0;return b|0}else{e=d}while(1){if((c[e+80>>2]|0)==0){if((c[e+84>>2]|0)!=0){f=5}}else{f=5}if((f|0)==5){f=0;if((QGb(a,c[e>>2]|0)|0)==0){b=e;f=7;break}}d=c[e+56>>2]|0;if((d|0)==0){b=0;f=7;break}else{e=d}}if((f|0)==7){return b|0}return 0}function G0a(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){b=0;return b|0}d=c[1305378]|0;if((d|0)==0){b=0;return b|0}else{e=d}while(1){if((c[e+88>>2]|0)!=0){if((QGb(a,c[e>>2]|0)|0)==0){b=e;f=6;break}}d=c[e+56>>2]|0;if((d|0)==0){b=0;f=6;break}else{e=d}}if((f|0)==6){return b|0}return 0}function H0a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;if((a|0)==0){d=1954872;i=b;return d|0}e=g0(a)|0;if((e|0)!=0){d=c[e+8>>2]|0;i=b;return d|0}yDb(0,24,1952640,(e=i,i=i+8|0,c[e>>2]=a,e)|0);i=e;e=c[1305378]|0;if((a|0)==171){f=1160852272}else if((a|0)==86079){f=1950507339}else if((a|0)==172){f=4665933}else if((a|0)==65564){f=407917392}else if((a|0)==175){f=1211250229}else if((a|0)==173){f=1464156752}else if((a|0)==86077){f=1330664787}else if((a|0)==65565){f=542135120}else{f=a}g=(e|0)==0;do{if(!g){h=e;j=0;a:while(1){do{if((c[h+88>>2]|0)==0){k=j}else{if((c[h+12>>2]|0)!=(f|0)){k=j;break}if((c[h+16>>2]&512|0)!=0&(j|0)==0){k=h}else{l=h;break a}}}while(0);m=c[h+56>>2]|0;if((m|0)==0){l=k;break}else{h=m;j=k}}if((l|0)==0){break}d=c[l>>2]|0;i=b;return d|0}}while(0);if((a|0)==171){n=1160852272}else if((a|0)==86077){n=1330664787}else if((a|0)==175){n=1211250229}else if((a|0)==173){n=1464156752}else if((a|0)==86079){n=1950507339}else if((a|0)==65565){n=542135120}else if((a|0)==172){n=4665933}else if((a|0)==65564){n=407917392}else{n=a}if(g){d=1950416;i=b;return d|0}else{o=e;p=0}b:while(1){if((c[o+80>>2]|0)==0){if((c[o+84>>2]|0)==0){q=p}else{r=32}}else{r=32}do{if((r|0)==32){r=0;if((c[o+12>>2]|0)!=(n|0)){q=p;break}if((c[o+16>>2]&512|0)!=0&(p|0)==0){q=o}else{s=o;break b}}}while(0);e=c[o+56>>2]|0;if((e|0)==0){s=q;break}else{o=e;p=q}}if((s|0)==0){d=1950416;i=b;return d|0}d=c[s>>2]|0;i=b;return d|0}function I0a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=d&255;do{if((f-48|0)>>>0<10>>>0|(f-97|0)>>>0<26>>>0|(f-65|0)>>>0<26>>>0){g=1948592}else{if((f|0)==46|(f|0)==45|(f|0)==32){g=1948592;break}g=(f|0)==95?1948592:1946552}}while(0);h=Lb(a|0,b|0,g|0,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;f=a+h|0;j=h>>>0<b>>>0?b-h|0:0;b=d>>>8&255;do{if((b-48|0)>>>0<10>>>0|(b-97|0)>>>0<26>>>0|(b-65|0)>>>0<26>>>0){k=1948592}else{if((b|0)==46|(b|0)==45|(b|0)==32){k=1948592;break}k=(b|0)==95?1948592:1946552}}while(0);l=Lb(f|0,j|0,k|0,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;b=h+l|0;k=a+b|0;f=j>>>0>l>>>0?j-l|0:0;j=l+h|0;h=d>>>16&255;do{if((h-48|0)>>>0<10>>>0|(h-97|0)>>>0<26>>>0|(h-65|0)>>>0<26>>>0){m=1948592}else{if((h|0)==46|(h|0)==45|(h|0)==32){m=1948592;break}m=(h|0)==95?1948592:1946552}}while(0);l=Lb(k|0,f|0,m|0,(g=i,i=i+8|0,c[g>>2]=h,g)|0)|0;i=g;h=a+(b+l)|0;b=f>>>0>l>>>0?f-l|0:0;f=l+j|0;j=d>>>24;if((j-48|0)>>>0<10>>>0|(j-97|0)>>>0<26>>>0|(j-65|0)>>>0<26>>>0){n=1948592;o=Lb(h|0,b|0,n|0,(g=i,i=i+8|0,c[g>>2]=j,g)|0)|0;i=g;p=o+f|0;i=e;return p|0}if((j|0)==46|(j|0)==45|(j|0)==32){n=1948592;o=Lb(h|0,b|0,n|0,(g=i,i=i+8|0,c[g>>2]=j,g)|0)|0;i=g;p=o+f|0;i=e;return p|0}n=(j|0)==95?1948592:1946552;o=Lb(h|0,b|0,n|0,(g=i,i=i+8|0,c[g>>2]=j,g)|0)|0;i=g;p=o+f|0;i=e;return p|0}function J0a(b,d,f,g){b=b|0;d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+296|0;j=h|0;k=h+8|0;l=h+40|0;if((b|0)==0|(d|0)<1){i=h;return}m=f+8|0;n=lGb(c[m>>2]|0)|0;o=f+48|0;p=H0a(c[o>>2]|0)|0;q=c[f+840>>2]|0;r=f+12|0;a:do{if((q|0)==-99){s=0}else{t=c[r>>2]|0;if((t|0)==0){u=c[o>>2]|0;v=c[1305378]|0;b:do{if((g|0)==0){if((u|0)==171){w=1160852272}else if((u|0)==86077){w=1330664787}else if((u|0)==175){w=1211250229}else if((u|0)==173){w=1464156752}else if((u|0)==65565){w=542135120}else if((u|0)==172){w=4665933}else if((u|0)==86079){w=1950507339}else if((u|0)==65564){w=407917392}else{w=u}if((v|0)==0){s=0;break a}else{x=v;y=0}while(1){do{if((c[x+88>>2]|0)==0){z=y}else{if((c[x+12>>2]|0)!=(w|0)){z=y;break}if((c[x+16>>2]&512|0)!=0&(y|0)==0){z=x}else{A=x;break b}}}while(0);B=c[x+56>>2]|0;if((B|0)==0){A=z;break}else{x=B;y=z}}}else{if((u|0)==173){C=1464156752}else if((u|0)==86079){C=1950507339}else if((u|0)==171){C=1160852272}else if((u|0)==86077){C=1330664787}else if((u|0)==175){C=1211250229}else if((u|0)==65564){C=407917392}else if((u|0)==172){C=4665933}else if((u|0)==65565){C=542135120}else{C=u}if((v|0)==0){s=0;break a}else{D=v;E=0}while(1){if((c[D+80>>2]|0)==0){if((c[D+84>>2]|0)==0){F=E}else{G=17}}else{G=17}do{if((G|0)==17){G=0;if((c[D+12>>2]|0)!=(C|0)){F=E;break}if((c[D+16>>2]&512|0)!=0&(E|0)==0){F=D}else{A=D;break b}}}while(0);B=c[D+56>>2]|0;if((B|0)==0){A=F;break}else{D=B;E=F}}}}while(0);if((A|0)==0){s=0;break}else{H=A}}else{H=t}v=c[H+48>>2]|0;if((v|0)==0){s=0;break}else{I=v}while(1){v=c[I>>2]|0;if((v|0)==-99){s=0;break a}if((v|0)==(q|0)){break}else{I=I+8|0}}s=c[I+4>>2]|0}}while(0);Lb(b|0,d|0,1944544,(I=i,i=i+16|0,c[I>>2]=(n|0)!=0?n:1942e3,c[I+8>>2]=p,I)|0)|0;i=I;a[b]=a[b]^32;n=c[r>>2]|0;do{if((n|0)!=0){r=c[n>>2]|0;if((QGb(r,p)|0)==0){break}q=SGb(b|0)|0;Lb(b+q|0,d-q|0,1933864,(I=i,i=i+8|0,c[I>>2]=r,I)|0)|0;i=I}}while(0);if((s|0)!=0){p=SGb(b|0)|0;Lb(b+p|0,d-p|0,1933864,(I=i,i=i+8|0,c[I>>2]=s,I)|0)|0;i=I}s=f+52|0;p=c[s>>2]|0;if((p|0)!=0){n=k|0;I0a(n,32,p)|0;p=SGb(b|0)|0;k=c[s>>2]|0;Lb(b+p|0,d-p|0,1931520,(I=i,i=i+16|0,c[I>>2]=n,c[I+8>>2]=k,I)|0)|0;i=I}k=c[m>>2]|0;do{if((k|0)==0){n=f+140|0;p=c[n>>2]|0;do{if(!((p|0)==-1)){s=l|0;TGb(s|0,0,256)|0;a[s]=40;r=SGb(b|0)|0;q=ZEb(p)|0;Lb(b+r|0,d-r|0,1929648,(I=i,i=i+8|0,c[I>>2]=q,I)|0)|0;i=I;q=f+796|0;r=c[q>>2]|0;do{if((r|0)!=0){if((r|0)>((e[(bFb(c[n>>2]|0)|0)+8>>1]|0)>>>11&15|0)){break}uAb(s,256,1927888,(I=i,i=i+8|0,c[I>>2]=c[q>>2],I)|0)|0;i=I}}while(0);q=c[f+396>>2]|0;if((q|0)!=0){uAb(s,256,(q|0)==1?1926200:1924696,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}q=HCb(c[f+392>>2]|0)|0;if((q|0)!=0){uAb(s,256,1923136,(I=i,i=i+8|0,c[I>>2]=q,I)|0)|0;i=I}q=SGb(s|0)|0;if(!(q>>>0>1>>>0)){break}a[l+(q-2)|0]=0;uAb(b,d,1921392,(I=i,i=i+8|0,c[I>>2]=s,I)|0)|0;i=I}}while(0);n=f+120|0;p=c[n>>2]|0;do{if((p|0)!=0){q=SGb(b|0)|0;r=f+124|0;H=c[r>>2]|0;Lb(b+q|0,d-q|0,1919536,(I=i,i=i+16|0,c[I>>2]=p,c[I+8>>2]=H,I)|0)|0;i=I;H=f+224|0;q=c[H>>2]|0;if((q|0)!=0){A=j|0;F=j+4|0;E=ba(c[n>>2]|0,q)|0;q=f+228|0;D=ba(c[q>>2]|0,c[r>>2]|0)|0;iFb(A,F,E,(E|0)<0|0?-1:0,D,(D|0)<0|0?-1:0,1048576,0)|0;D=SGb(b|0)|0;E=c[q>>2]|0;q=c[A>>2]|0;A=c[F>>2]|0;Lb(b+D|0,d-D|0,1917704,(I=i,i=i+32|0,c[I>>2]=c[H>>2],c[I+8>>2]=E,c[I+16>>2]=q,c[I+24>>2]=A,I)|0)|0;i=I}if((zDb()|0)<=47){break}A=c[f+104>>2]|0;q=c[f+108>>2]|0;E=GDb(A,(A|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;H=E;E=SGb(b|0)|0;Lb(b+E|0,d-E|0,1910912,(I=i,i=i+16|0,c[I>>2]=(A|0)/(H|0)|0,c[I+8>>2]=(q|0)/(H|0)|0,I)|0)|0;i=I}}while(0);if((g|0)==0){break}n=SGb(b|0)|0;p=c[f+504>>2]|0;Lb(b+n|0,d-n|0,1908936,(I=i,i=i+16|0,c[I>>2]=c[f+500>>2],c[I+8>>2]=p,I)|0)|0;i=I;G=73}else if((k|0)==1){p=c[f+412>>2]|0;if((p|0)!=0){n=SGb(b|0)|0;Lb(b+n|0,d-n|0,1907528,(I=i,i=i+8|0,c[I>>2]=p,I)|0)|0;i=I}tAb(b,1905888,d)|0;p=SGb(b|0)|0;n=f+448|0;iBb(b+p|0,d-p|0,c[f+416>>2]|0,c[n>>2]|0,c[n+4>>2]|0);n=c[f+420>>2]|0;if((n|0)==-1){G=73;break}p=SGb(b|0)|0;H=wFb(n)|0;Lb(b+p|0,d-p|0,1929648,(I=i,i=i+8|0,c[I>>2]=H,I)|0)|0;i=I;G=73}else if((k|0)==3){H=c[f+120>>2]|0;if((H|0)==0){G=73;break}p=SGb(b|0)|0;n=c[f+124>>2]|0;Lb(b+p|0,d-p|0,1919536,(I=i,i=i+16|0,c[I>>2]=H,c[I+8>>2]=n,I)|0)|0;i=I;G=73}else if((k|0)==2){if((zDb()|0)<=47){G=73;break}n=c[f+104>>2]|0;H=c[f+108>>2]|0;p=GDb(n,(n|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;q=p;if((q|0)==0){G=73;break}p=SGb(b|0)|0;Lb(b+p|0,d-p|0,1910912,(I=i,i=i+16|0,c[I>>2]=(n|0)/(q|0)|0,c[I+8>>2]=(H|0)/(q|0)|0,I)|0)|0;i=I;G=73}else{i=h;return}}while(0);do{if((G|0)==73){if((g|0)==0){break}k=f+88|0;j=c[k>>2]|0;if((j&512|0)==0){J=j}else{j=SGb(b|0)|0;Lb(b+j|0,d-j|0,1904200,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;J=c[k>>2]|0}if((J&1024|0)==0){break}k=SGb(b|0)|0;Lb(b+k|0,d-k|0,1902608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}}while(0);c:do{switch(c[m>>2]|0){case 0:case 2:case 3:case 4:{K=c[f+72>>2]|0;G=91;break};case 1:{J=c[o>>2]|0;d:do{switch(J|0){case 69649:{L=2;break};case 69648:{L=3;break};case 69647:case 69633:case 69632:case 69645:case 69638:{L=4;break};default:{if((J|0)==65543|(J|0)==65542|(J|0)==65540|(J|0)==65563|(J|0)==65541|(J|0)==65553){L=8;break d}else if((J|0)==65537|(J|0)==1347637264|(J|0)==65536|(J|0)==65554|(J|0)==65539|(J|0)==65538){L=16;break d}else if((J|0)==65552|(J|0)==65549|(J|0)==65548|(J|0)==407917392|(J|0)==65551|(J|0)==65550){L=24;break d}else if((J|0)==65545|(J|0)==65544|(J|0)==542135120|(J|0)==65547|(J|0)==65546|(J|0)==65556|(J|0)==65557){L=32;break d}else if((J|0)==65558|(J|0)==65559){L=64;break d}else if((J|0)==86071|(J|0)==86072|(J|0)==69644|(J|0)==69661|(J|0)==69655|(J|0)==1330333984|(J|0)==69636|(J|0)==69660|(J|0)==69646){L=4;break d}else{K=c[f+72>>2]|0;G=91;break c}}}}while(0);K=ba(ba(c[f+412>>2]|0,L)|0,c[f+416>>2]|0)|0;G=91;break};default:{}}}while(0);do{if((G|0)==91){if((K|0)==0){break}L=SGb(b|0)|0;Lb(b+L|0,d-L|0,1901544,(I=i,i=i+8|0,c[I>>2]=(K|0)/1e3|0,I)|0)|0;i=I;i=h;return}}while(0);K=c[f+540>>2]|0;if((K|0)<=0){i=h;return}f=SGb(b|0)|0;Lb(b+f|0,d-f|0,1900048,(I=i,i=i+8|0,c[I>>2]=(K|0)/1e3|0,I)|0)|0;i=I;i=h;return}function K0a(){return 3617894}function L0a(){return 1898592}function M0a(a){a=a|0;var b=0;b=c[(c[a+12>>2]|0)+96>>2]|0;if((b|0)!=0){me[b&511](a)}b=a+928|0;c[b>>2]=0;c[b+4>>2]=-2147483648;b=a+920|0;c[b>>2]=0;c[b+4>>2]=-2147483648;if((c[a+488>>2]|0)!=0){return}KCb(c[(c[a+64>>2]|0)+20>>2]|0);return}function N0a(a){a=a|0;var b=0;if((a|0)==65558|(a|0)==65559){b=64}else if((a|0)==65545|(a|0)==65544|(a|0)==542135120|(a|0)==65547|(a|0)==65546|(a|0)==65556|(a|0)==65557){b=32}else if((a|0)==65537|(a|0)==1347637264|(a|0)==65536|(a|0)==65554|(a|0)==65539|(a|0)==65538){b=16}else if((a|0)==65552|(a|0)==65549|(a|0)==65548|(a|0)==407917392|(a|0)==65551|(a|0)==65550){b=24}else if((a|0)==86071|(a|0)==86072|(a|0)==69644|(a|0)==69661|(a|0)==69655|(a|0)==1330333984|(a|0)==69636|(a|0)==69660|(a|0)==69646){b=4}else if((a|0)==65543|(a|0)==65542|(a|0)==65540|(a|0)==65563|(a|0)==65541|(a|0)==65553){b=8}else{b=0}return b|0}function O0a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[a+48>>2]|0;e=c[a+412>>2]|0;f=c[a+416>>2]|0;g=c[a+432>>2]|0;h=c[a+52>>2]|0;if((d|0)==65537|(d|0)==1347637264|(d|0)==65536|(d|0)==65554|(d|0)==65539|(d|0)==65538){i=16}else if((d|0)==65558|(d|0)==65559){i=64}else if((d|0)==65552|(d|0)==65549|(d|0)==65548|(d|0)==407917392|(d|0)==65551|(d|0)==65550){i=24}else if((d|0)==65543|(d|0)==65542|(d|0)==65540|(d|0)==65563|(d|0)==65541|(d|0)==65553){i=8}else if((d|0)==65545|(d|0)==65544|(d|0)==542135120|(d|0)==65547|(d|0)==65546|(d|0)==65556|(d|0)==65557){i=32}else if((d|0)==86071|(d|0)==86072|(d|0)==69644|(d|0)==69661|(d|0)==69655|(d|0)==1330333984|(d|0)==69636|(d|0)==69660|(d|0)==69646){i=4}else{i=0}j=(f|0)>0;k=(b|0)>0;a:do{if((i|0)!=0&j&k&(f|0)<32768){l=b;m=ba(i,f)|0;n=eHb(l<<3|0>>>29,((b|0)<0|0?-1:0)<<3|l>>>29,m,(m|0)<0|0?-1:0)|0;o=n}else{n=c[a+792>>2]|0;if((d|0)==86016|(d|0)==86044){o=1152;break}else if((d|0)==73729|(d|0)==86046){o=320;break}else if((d|0)==69657){o=128;break}else if((d|0)==69641){o=32;break}else if((d|0)==86059){o=384;break}else if((d|0)==86047){o=1024;break}else if((d|0)==86063){o=512;break}else if((d|0)==73728|(d|0)==1936029283|(d|0)==86034|(d|0)==86040|(d|0)==77825){o=160;break}else if((d|0)==69632){o=64;break}else if((d|0)==86019){o=1536;break}else{do{if((e|0)>0){if((d|0)==86038){o=(e<<8|0)/245|0;break a}if(!(j&(d|0)==86065)){break}o=(480<<((e|0)/22050|0)|0)/(f|0)|0;break a}}while(0);m=(g|0)>0;do{if(m){if((d|0)==86076){if((g|0)==38){o=160;break a}else if((g|0)!=50){break}o=240;break a}else if((d|0)!=86058){break}if((g|0)==19){o=144;break a}else if((g|0)==29){o=288;break a}else if((g|0)==20){o=160;break a}else if((g|0)==37){o=480;break a}else{break}}}while(0);if(!k){o=0;break}if((d|0)==86050){o=((b|0)/64|0)<<8;break}else if((d|0)==86037){o=((b|0)/32|0)*240|0;break}else if((d|0)==86069){o=((b|0)/24|0)*240|0;break}else if((d|0)==77824){o=((b|0)/20|0)*160|0;break}else{l=(n|0)>0;if(l&(d|0)==69643){o=(b<<3|0)/(n|0)|0;break}if(!j){o=0;break}if((d|0)==1095123744){o=((b|0)/(f*9|0|0)|0)<<4;break}else if((d|0)==1146374944){o=((b|0)/(f<<4|0)|0)*28|0;break}else if((d|0)==69651){o=((b<<1)-16|0)/(f|0)|0;break}else if((d|0)==69639|(d|0)==69659){o=(b-(f<<2)<<1|0)/(f|0)|0;break}else if((d|0)==69637){o=((b<<1)-8|0)/(f|0)|0;break}else if((d|0)==86025){o=(b*3|0|0)/(f|0)|0;break}else if((d|0)==69640){o=(((b|0)/128|0)*224|0|0)/(f|0)|0;break}else if((d|0)==81921){o=(b-6-f|0)/(f|0)|0;break}else if((d|0)==81922){o=(b-(f<<1)|0)/(f|0)|0;break}else if((d|0)==86075|(d|0)==86043){o=(b<<2|0)/(f|0)|0;break}else if((d|0)==65561){o=((b|0)/(f*5|0|0)|0)<<1;break}else if((d|0)==86026){o=(b*6|0|0)/(f|0)|0;break}else if((d|0)==81920){o=(b-8|0)/(f|0)|0;break}else{if((h|0)!=0&(d|0)==81923){if((h|0)==3){o=(b|0)/(f|0)|0;break}else{o=(b<<1|0)/(f|0)|0;break}}do{if(m){p=(b|0)/(g|0)|0;if((d|0)==69638){o=ba(((g+(f*-7|0)<<1|0)/(f|0)|0)+2|0,p)|0;break a}else if((d|0)==1380008992){o=ba((g-(f<<2)<<1|0)/(f|0)|0,p)|0;break a}else if((d|0)==69633){if((n-2|0)>>>0>3>>>0){o=0;break a}o=ba(((g-(f<<2)|0)/(ba(n,f)|0)|0)<<3|1,p)|0;break a}else if((d|0)==69634){o=ba(((((g<<1)-32|0)/3|0)<<2|0)/(f|0)|0,p)|0;break a}else if((d|0)==69635){o=ba(((g-(f<<2)<<1|0)/(f|0)|0)+1|0,p)|0;break a}else{break}}}while(0);if(!l){o=0;break}if((d|0)==65555){if((n|0)<4){o=0;break}o=((b|0)/(ba((n<<1|0)/8|0,f)|0)|0)<<1;break}else if((d|0)==65560){if((n|0)<4){o=0;break}o=(b|0)/((ba(n,f+1&-2)|0)/8|0|0)|0;break}else if((d|0)==65562){o=(((b|0)/((n+4|0)/4|0|0)|0)<<1|0)/(f|0)|0;break}else{o=0;break}}}}}}while(0);return o|0}function P0a(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c&255;if(c>>>0>254>>>0){e=b;f=c;c=1;while(1){g=e+1|0;a[e]=-1;h=f-255|0;i=c+1|0;if(h>>>0>254>>>0){e=g;f=h;c=i}else{break}}j=g;k=h&255;l=i}else{j=b;k=d;l=1}a[j]=k;return l|0}function Q0a(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0;if((b|0)>0){f=0}else{g=0;return g|0}while(1){if((e[a+(f<<2)>>1]|0|0)==(c|0)){if((e[a+(f<<2)+2>>1]|0|0)==(d|0)){g=f;h=5;break}}i=f+1|0;if((i|0)<(b|0)){f=i}else{g=i;h=5;break}}if((h|0)==5){return g|0}return 0}function R0a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[(c[a+12>>2]|0)+12>>2]|0;d=c[a+140>>2]|0;a=c[1305372]|0;if((a|0)==0){e=0;return e|0}else{f=a}while(1){if((c[f+8>>2]|0)==(b|0)){if((c[f+12>>2]|0)==(d|0)){e=f;g=5;break}}a=c[((f|0)==0?5221488:f+20|0)>>2]|0;if((a|0)==0){e=0;g=5;break}else{f=a}}if((g|0)==5){return e|0}return 0}function S0a(a){a=a|0;var b=0,c=0,d=0,e=0;b=a&255;c=a>>>8&255;d=a>>>16&255;e=a>>>24;return((e-97|0)>>>0<26>>>0?e^32:e)<<24|((b-97|0)>>>0<26>>>0?b^32:b)|((c-97|0)>>>0<26>>>0?c^32:c)<<8|((d-97|0)>>>0<26>>>0?d^32:d)<<16|0}function T0a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;c[a+4>>2]=c[b+4>>2];d=a|0;e=MCb(c[d>>2]|0,c[b>>2]|0)|0;if((e|0)<0){f=e;return f|0}e=c[b+8>>2]|0;if((e|0)==0){f=0;return f|0}b=WAb(e)|0;c[a+8>>2]=b;if((b|0)!=0){f=0;return f|0}KCb(c[d>>2]|0);f=-12;return f|0}function U0a(a,b){a=a|0;b=b|0;KCb(c[b>>2]|0);return}function V0a(a,b){a=a|0;b=b|0;return Oe[c[a+152>>2]&1023](a,b)|0}function W0a(a,b,d){a=a|0;b=b|0;d=d|0;c[b+4>>2]=a;return _$a(a,c[b>>2]|0,d)|0}function X0a(a){a=a|0;return}function Y0a(a,b,c){a=a|0;b=b|0;c=c|0;return}function Z0a(a,b,c){a=a|0;b=b|0;c=c|0;return}function _0a(a){a=a|0;return 1}function $0a(a,b){a=a|0;b=b|0;return 0}function a1a(a){a=a|0;return}function b1a(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return}function c1a(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return}function d1a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[1305378]|0;if((a|0)==172){d=4665933}else if((a|0)==65565){d=542135120}else if((a|0)==65564){d=407917392}else if((a|0)==171){d=1160852272}else if((a|0)==175){d=1211250229}else if((a|0)==86079){d=1950507339}else if((a|0)==86077){d=1330664787}else if((a|0)==173){d=1464156752}else{d=a}e=(b|0)==0;if(e){f=16}else{g=b;h=0;a:while(1){do{if((c[g+88>>2]|0)==0){i=h}else{if((c[g+12>>2]|0)!=(d|0)){i=h;break}if((c[g+16>>2]&512|0)!=0&(h|0)==0){i=g}else{j=g;break a}}}while(0);k=c[g+56>>2]|0;if((k|0)==0){j=i;break}else{g=k;h=i}}if((j|0)==0){f=16}else{l=j}}do{if((f|0)==16){if((a|0)==172){m=4665933}else if((a|0)==173){m=1464156752}else if((a|0)==86079){m=1950507339}else if((a|0)==175){m=1211250229}else if((a|0)==65564){m=407917392}else if((a|0)==86077){m=1330664787}else if((a|0)==65565){m=542135120}else if((a|0)==171){m=1160852272}else{m=a}if(!e){j=b;i=0;b:while(1){if((c[j+80>>2]|0)==0){if((c[j+84>>2]|0)==0){n=i}else{f=28}}else{f=28}do{if((f|0)==28){f=0;if((c[j+12>>2]|0)!=(m|0)){n=i;break}if((c[j+16>>2]&512|0)!=0&(i|0)==0){n=j}else{o=j;break b}}}while(0);h=c[j+56>>2]|0;if((h|0)==0){o=n;break}else{j=h;i=n}}if((o|0)!=0){l=o;break}}if((a|0)==0){p=-1;return p|0}if(a>>>0<65536>>>0){p=0;return p|0}if(a>>>0<94208>>>0){p=1;return p|0}p=a>>>0<98304>>>0?3:-1;return p|0}}while(0);p=c[l+8>>2]|0;return p|0}function e1a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=QAb(b,e)|0;if((f|0)<0){g=f;i=d;return g|0}c[a+96>>2]=c[e>>2];c[a+100>>2]=c[b+4>>2];g=0;i=d;return g|0}function f1a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;if(b>>>0>e>>>0){yDb(0,0,2313288,(h=i,i=i+24|0,c[h>>2]=1881424,c[h+8>>2]=2103344,c[h+16>>2]=3491,h)|0);i=h;Cd();return 0}if(b>>>0<e>>>0){j=0;k=b}else{l=e;i=g;return l|0}while(1){if((j|0)>=3){break}b=c[f>>2]<<8;h=k+1|0;c[f>>2]=d[k]|b;if((b|0)==256|(h|0)==(e|0)){l=h;m=14;break}else{j=j+1|0;k=h}}if((m|0)==14){i=g;return l|0}a:do{if(k>>>0<e>>>0){m=k;while(1){j=a[m-1|0]|0;h=j&255;do{if((j&255)>>>0>1>>>0){n=m+3|0}else{if((a[m-2|0]|0)==0){b=m+1|0;if((d[m-3|0]|h-1|0)==0){o=b;break a}else{n=b;break}}else{n=m+2|0;break}}}while(0);if(n>>>0<e>>>0){m=n}else{o=n;break}}}else{o=k}}while(0);k=o>>>0>e>>>0?e:o;o=k-4|0;c[f>>2]=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;l=k;i=g;return l|0}function g1a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;e=c[a+476>>2]|0;if((e|0)==0){f=d;$Db(f);i=b;return}ne[e&1023](a,a+960|0);f=d;$Db(f);i=b;return}function h1a(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;XAb(d);i=b;return}function i1a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;Z3(e+4|0,a);f=c[a+100>>2]|0;g=a;if((f|0)<16){yDb(g,16,2241344,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;j=-1094995529;i=b;return j|0}f=a+96|0;k=c[f>>2]|0;l=d[k+2|0]|0;m=d[k+1|0]|0;n=d[k]|0;yDb(g,48,2229200,(h=i,i=i+32|0,c[h>>2]=d[k+3|0]|0,c[h+8>>2]=l,c[h+16>>2]=m,c[h+24>>2]=n,h)|0);i=h;n=(c[f>>2]|0)+4|0;m=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;yDb(g,48,2217464,(h=i,i=i+8|0,c[h>>2]=m,h)|0);i=h;m=c[f>>2]|0;f=m+8|0;n=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[e+1248>>2]=n;f=m+12|0;m=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=e+1252|0;c[f>>2]=m;if((n|0)==4){o=m}else{DDb(g,2208160,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;o=c[f>>2]|0}yDb(g,48,2199808,(h=i,i=i+8|0,c[h>>2]=o,h)|0);i=h;o=c[f>>2]|0;c[e+1264>>2]=(o>>>24)+1;c[e+1268>>2]=o&1;c[e+1272>>2]=o&2048;c[e+1304>>2]=0;o=c[a+52>>2]|0;if((o|0)==810044501){c[e+1260>>2]=3;c[a+140>>2]=0;c[a+392>>2]=1;j=0;i=b;return j|0}else if((o|0)==843598933){c[e+1260>>2]=3;c[a+140>>2]=4;c[a+392>>2]=1;j=0;i=b;return j|0}else if((o|0)==844713045){c[e+1260>>2]=3;c[a+140>>2]=4;c[a+392>>2]=5;j=0;i=b;return j|0}else if((o|0)==1196575829){c[e+1260>>2]=3;c[a+140>>2]=2;j=0;i=b;return j|0}else if((o|0)==1095912533){c[e+1260>>2]=4;c[a+140>>2]=28;j=0;i=b;return j|0}else if((o|0)==811158613){c[e+1260>>2]=3;c[a+140>>2]=0;c[a+392>>2]=5;j=0;i=b;return j|0}else{yDb(g,16,2191184,(h=i,i=i+8|0,c[h>>2]=o,h)|0);i=h;j=-1094995529;i=b;return j|0}return 0}function j1a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;i=i+40|0;j=h|0;k=h+24|0;l=c[g+24>>2]|0;m=c[g+28>>2]|0;g=c[b+60>>2]|0;n=g;o=k|0;c[o>>2]=e;c[k+4>>2]=0;c[k+8>>2]=0;e=W0a(b,k,0)|0;if((e|0)<0){p=e;i=h;return p|0}if(!((m|0)>-1)){yDb(0,0,2287256,(q=i,i=i+24|0,c[q>>2]=2271288,c[q+8>>2]=2255792,c[q+16>>2]=135,q)|0);i=q;Cd();return 0}e=g+1260|0;k=c[e>>2]|0;r=l+m|0;a:do{if((k|0)>0){s=c[g+1264>>2]|0;t=l;u=0;v=0;b:while(1){c[j+(u<<2)>>2]=t;if((r-t|0)>>>0<((s<<2)+256|0)>>>0){w=7;break}x=t+256|0;if((s|0)>0){y=x;z=0;A=v;B=0;while(1){C=y+4|0;D=y;E=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=E-B|0;if((D|E|0)<0){w=11;break b}if((r-C|0)>>>0<E>>>0){w=11;break b}F=(A|0)>(D|0)?A:D;D=z+1|0;if((D|0)<(s|0)){y=C;z=D;A=F;B=E}else{G=C;H=F;I=E;break}}}else{G=x;H=v;I=0}B=G+I|0;A=u+1|0;if((A|0)<(k|0)){t=B;u=A;v=H}else{J=B;K=H;break a}}if((w|0)==7){yDb(b,16,2179536,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-1094995529;i=h;return p|0}else if((w|0)==11){yDb(b,16,2103288,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-1094995529;i=h;return p|0}}else{J=l;K=0}}while(0);c[j+(k<<2)>>2]=J;if((r-J|0)>>>0<(c[g+1248>>2]|0)>>>0){yDb(b,16,2046920,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-1094995529;i=h;return p|0}r=J;J=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+1256|0;c[r>>2]=J;k=b;yDb(k,48,2001256,(q=i,i=i+8|0,c[q>>2]=J,q)|0);i=q;J=(c[r>>2]|0)>>>8&3;r=g+1276|0;c[r>>2]=J;if((J|0)==2){DDb(k,1964184,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-1163346256;i=h;return p|0}J=g+1284|0;kEb(J,g+1304|0,K+16|0);if((c[J>>2]|0)==0){yDb(k,16,1936e3,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-12;i=h;return p|0}q=c[(c[g>>2]|0)+140>>2]|0;c:do{if((q|0)==2|(q|0)==28){k=c[e>>2]|0;J=c[o>>2]|0;K=c[J>>2]|0;d:do{if((k|0)>0){l=b+120|0;w=b+124|0;H=g+1272|0;I=g+1264|0;G=0;v=k;u=J;t=K;while(1){s=c[1108160+(G<<2)>>2]|0;B=l1a(n,G,t+s|0,v,c[u+32>>2]|0,c[l>>2]|0,c[w>>2]|0,c[j+(G<<2)>>2]|0,(c[r>>2]|0)==1|0)|0;if((B|0)!=0){p=B;break}do{if((c[r>>2]|0)==3){B=c[o>>2]|0;A=(c[B>>2]|0)+s|0;z=c[e>>2]|0;y=c[B+32>>2]|0;B=c[l>>2]|0;E=c[w>>2]|0;F=c[I>>2]|0;if((c[H>>2]|0)==0){m1a(A,z,y,B,E,F,0);break}else{n1a(A,z,y,B,E,F,0);break}}}while(0);s=G+1|0;F=c[e>>2]|0;E=c[o>>2]|0;B=c[E>>2]|0;if((s|0)<(F|0)){G=s;v=F;u=E;t=B}else{L=F;M=E;N=B;O=w;break d}}i=h;return p|0}else{L=k;M=J;N=K;O=b+124|0}}while(0);K=c[M+32>>2]|0;J=c[O>>2]|0;if((J|0)<=0){break}k=ba(c[b+120>>2]|0,L)|0;w=(k|0)>0;t=0;u=N;while(1){if(w){v=0;do{G=u+v|0;H=a[u+(v+1)|0]|0;I=u+(v+2)|0;l=a[I]|0;a[G]=H+(a[G]|0)&255^-128;a[I]=l+H&255^-128;v=v+L|0;}while((v|0)<(k|0))}v=t+1|0;if((v|0)<(J|0)){t=v;u=u+K|0}else{break}}}else if((q|0)==0){K=b+120|0;u=b+124|0;t=g+1272|0;J=g+1264|0;k=0;while(1){w=c[o>>2]|0;v=(k|0)!=0|0;H=l1a(n,k,c[w+(k<<2)>>2]|0,1,c[w+32+(k<<2)>>2]|0,c[K>>2]>>v,c[u>>2]>>v,c[j+(k<<2)>>2]|0,(c[r>>2]|0)==1|0)|0;if((H|0)!=0){p=H;break}do{if((c[r>>2]|0)==3){H=c[o>>2]|0;w=c[H+(k<<2)>>2]|0;l=c[H+32+(k<<2)>>2]|0;H=c[K>>2]>>v;I=c[u>>2]>>v;G=c[J>>2]|0;x=v^1;if((c[t>>2]|0)==0){m1a(w,1,l,H,I,G,x);break}else{n1a(w,1,l,H,I,G,x);break}}}while(0);k=k+1|0;if((k|0)>=3){break c}}i=h;return p|0}else if((q|0)==4){k=b+120|0;t=b+124|0;J=g+1272|0;u=g+1264|0;K=0;while(1){v=c[o>>2]|0;x=(K|0)!=0|0;G=l1a(n,K,c[v+(K<<2)>>2]|0,1,c[v+32+(K<<2)>>2]|0,c[k>>2]>>x,c[t>>2]|0,c[j+(K<<2)>>2]|0,(c[r>>2]|0)==1|0)|0;if((G|0)!=0){p=G;break}do{if((c[r>>2]|0)==3){G=c[o>>2]|0;v=c[G+(K<<2)>>2]|0;I=c[G+32+(K<<2)>>2]|0;G=c[k>>2]>>x;H=c[t>>2]|0;l=c[u>>2]|0;if((c[J>>2]|0)==0){m1a(v,1,I,G,H,l,0);break}else{n1a(v,1,I,G,H,l,0);break}}}while(0);K=K+1|0;if((K|0)>=3){break c}}i=h;return p|0}}while(0);r=c[o>>2]|0;c[r+84>>2]=1;c[r+88>>2]=1;c[r+296>>2]=(c[g+1272>>2]|0)!=0;c[f>>2]=1;p=m;i=h;return p|0}function k1a(a){a=a|0;$Db((c[a+60>>2]|0)+1284|0);return 0}function l1a(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;o=i;i=i+3608|0;p=o|0;q=o+2048|0;r=o+3072|0;s=o+3328|0;t=o+3584|0;if((f|0)==0){u=~((c[(c[e>>2]|0)+140>>2]|0)==0)}else{u=-1}f=p|0;v=q;w=r|0;x=s|0;y=m;z=0;while(1){a[p+(z<<3)|0]=z;a[p+(z<<3)+1|0]=a[y]|0;A=z+1|0;if((A|0)<256){y=y+1|0;z=A}else{break}}Yc(f|0,256,8,864);z=a[p+1|0]|0;do{if(z<<24>>24==0){B=1;C=d[f]|0}else{if((z&255)>>>0>32>>>0){B=0;C=-1;break}else{D=255}while(1){E=a[p+(D<<3)+1|0]|0;if(E<<24>>24!=-1|(D|0)==0){break}else{D=D-1|0}}y=E&255;do{if((D|0)>-1){c[q+(D<<2)>>2]=1>>>((32-y|0)>>>0);a[r+D|0]=E;a[s+D|0]=a[p+(D<<3)|0]|0;if((D|0)>0){F=1;G=y;H=D}else{break}do{H=H-1|0;F=(-2147483648>>>((G-1|0)>>>0))+F|0;A=a[p+(H<<3)+1|0]|0;G=A&255;c[q+(H<<2)>>2]=F>>>((32-G|0)>>>0);a[r+H|0]=A;a[s+H|0]=a[p+(H<<3)|0]|0;}while((H|0)>0)}}while(0);B=(N_(t,(E&255)>>>0>10>>>0?10:y,D+1|0,w,1,1,v,4,4,x,1,1,0)|0)==0;C=-1}}while(0);if(!B){yDb(c[e>>2]|0,16,1912616,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-1094995529;i=o;return J|0}B=e+1264|0;x=c[B>>2]|0;v=(x|0)>0;if((C|0)>-1){if(!v){J=0;i=o;return J|0}w=ba(k,h)|0;D=(n|0)==0;E=C&255;H=0;p=0;s=x;while(1){r=H+1|0;G=((ba(r,l)|0)/(s|0)|0)&u;F=g+(ba(p,j)|0)|0;if((p|0)>=(G|0)|(w|0)<1){K=s}else{if(D){q=p;z=F;while(1){f=0;do{a[z+f|0]=E;f=f+h|0;}while((f|0)<(w|0));f=q+1|0;if((f|0)<(G|0)){q=f;z=z+j|0}else{break}}}else{z=128;q=p;y=F;while(1){f=z;A=0;do{f=f+C|0;a[y+A|0]=f;A=A+h|0;}while((A|0)<(w|0));A=q+1|0;if((A|0)<(G|0)){z=f;q=A;y=y+j|0}else{break}}}K=c[B>>2]|0}if((r|0)<(K|0)){H=r;p=G;s=K}else{J=0;break}}i=o;return J|0}a:do{if(v){K=e+1284|0;s=e+1100|0;p=e|0;H=ba(k,h)|0;w=(H|0)>0;C=t+4|0;E=t|0;D=(n|0)==0;y=0;q=0;z=x;b:while(1){F=y+1|0;A=((ba(F,l)|0)/(z|0)|0)&u;L=g+(ba(q,j)|0)|0;M=y<<2;if((y|0)==0){N=0}else{O=m+(M+252)|0;N=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0}O=m+(M+256)|0;M=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=M-N|0;if((M|0)==(N|0)){P=33;break}UGb(c[K>>2]|0,m+(N+256+(z<<2))|0,O)|0;TGb((c[K>>2]|0)+O|0,0,16)|0;M=c[K>>2]|0;Xe[c[s>>2]&4095](M,M,O+3>>2);M=c[K>>2]|0;Q=O<<3;O=Q>>>0>2147483639>>>0|(M|0)==0;R=O?0:M;M=O?0:Q;Q=M+8|0;if((q|0)<(A|0)){O=0;S=128;T=q;U=L;while(1){if(w){L=O;V=S;W=0;while(1){if((M-L|0)<1){P=37;break b}X=c[C>>2]|0;Y=c[E>>2]|0;Z=R+(L>>>3)|0;_=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(L&7)>>>((32-Y|0)>>>0);Z=b[X+(_<<2)>>1]|0;$=b[X+(_<<2)+2>>1]|0;_=$<<16>>16;do{if($<<16>>16<0){aa=Y+L|0;ca=Q>>>0>aa>>>0?aa:Q;aa=R+(ca>>>3)|0;da=((fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ca&7)>>>((_+32|0)>>>0))+Z|0;aa=b[X+(da<<2)>>1]|0;ea=b[X+(da<<2)+2>>1]|0;da=ea<<16>>16;if(!(ea<<16>>16<0)){fa=da;ga=aa;ha=ca;break}ea=ca-_|0;ca=Q>>>0>ea>>>0?ea:Q;ea=R+(ca>>>3)|0;ia=((fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ca&7)>>>((da+32|0)>>>0))+aa|0;fa=b[X+(ia<<2)+2>>1]|0;ga=b[X+(ia<<2)>>1]|0;ha=ca}else{fa=_;ga=Z;ha=L}}while(0);Z=fa+ha|0;_=Q>>>0>Z>>>0?Z:Q;if((ga|0)<0){P=42;break b}if(D){ja=V;ka=ga&255}else{Z=ga+V|0;ja=Z;ka=Z&255}a[U+W|0]=ka;Z=W+h|0;if((Z|0)<(H|0)){L=_;V=ja;W=Z}else{la=_;ma=ja;break}}}else{la=O;ma=S}W=T+1|0;if((W|0)<(A|0)){O=la;S=ma;T=W;U=U+j|0}else{na=la;break}}}else{na=0}U=M-na|0;if((U|0)>32){yDb(c[p>>2]|0,24,2305128,(I=i,i=i+8|0,c[I>>2]=U,I)|0);i=I}U=c[B>>2]|0;if((F|0)<(U|0)){y=F;q=A;z=U}else{break a}}if((P|0)==33){yDb(c[p>>2]|0,16,1892136,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}else if((P|0)==37){yDb(c[p>>2]|0,16,2349808,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}else if((P|0)==42){yDb(c[p>>2]|0,16,2329552,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}Q_(t);J=-1094995529;i=o;return J|0}}while(0);Q_(t);J=0;i=o;return J|0}function m1a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;j=~i;if((h|0)<=0){return}i=ba(f,c)|0;f=(i|0)>(c|0);k=0;do{l=((ba(k,g)|0)/(h|0)|0)&j;k=k+1|0;m=(((ba(k,g)|0)/(h|0)|0)&j)-l|0;n=ba(l,e)|0;l=b+n|0;o=a[l]^-128;a[l]=o;if(f){p=o;o=c;do{q=b+(o+n)|0;p=(a[q]|0)+p&255;a[q]=p;o=o+c|0;}while((o|0)<(i|0))}o=n+e|0;p=b+o|0;do{if((m|0)!=1){q=a[l]|0;r=q&255;s=(a[p]|0)+q&255;a[p]=s;q=s&255;if(f){t=s;s=r;u=c;v=q;while(1){w=a[b+(u+n)|0]|0;x=w&255;y=v-s+x&255;do{if((t&255)>>>0>(w&255)>>>0){if(!(y>>>0>x>>>0)){z=x;break}z=y>>>0>v>>>0?v:y}else{if(!(x>>>0>y>>>0)){z=x;break}z=y>>>0>v>>>0?y:v}}while(0);y=b+(u+o)|0;w=(d[y]|0)+z|0;A=w&255;a[y]=A;y=u+c|0;B=w&255;if((y|0)<(i|0)){t=A;s=x;u=y;v=B}else{C=x;D=B;break}}}else{C=r;D=q}if((m|0)<=2){break}v=(i|0)>0;u=D;s=C;t=b+(o+e)|0;B=2;while(1){if(v){y=u;A=s;w=0;while(1){E=d[t+(w-e)|0]|0;F=y-A+E&255;do{if((y|0)>(E|0)){if(!(F>>>0>E>>>0)){G=E;break}G=(F|0)>(y|0)?y:F}else{if(!(E>>>0>F>>>0)){G=E;break}G=(F|0)>(y|0)?F:y}}while(0);F=t+w|0;H=(d[F]|0)+G|0;a[F]=H;F=H&255;H=w+c|0;if((H|0)<(i|0)){y=F;A=E;w=H}else{I=F;J=E;break}}}else{I=u;J=s}w=B+1|0;if((w|0)<(m|0)){u=I;s=J;t=t+e|0;B=w}else{break}}}}while(0);}while((k|0)<(h|0));return}function n1a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=(i|0)!=0?-4:-2;i=e<<1;if((h|0)<=0){return}k=ba(f,c)|0;f=(k|0)>(c|0);l=0;do{m=((ba(l,g)|0)/(h|0)|0)&j;l=l+1|0;n=(((ba(l,g)|0)/(h|0)|0)&j)-m|0;o=n>>1;p=ba(m,e)|0;m=b+p|0;q=a[m]^-128;a[m]=q;if(f){r=q;s=c;while(1){t=b+(s+p)|0;u=(a[t]|0)+r&255;a[t]=u;t=s+c|0;if((t|0)<(k|0)){r=u;s=t}else{v=u;break}}}else{v=q}s=(k|0)>0;if(s){r=p+e|0;u=v;t=0;do{w=b+(r+t)|0;u=(a[w]|0)+u&255;a[w]=u;t=t+c|0;}while((t|0)<(k|0))}t=p+i|0;u=b+t|0;do{if((o|0)!=1){r=a[m]|0;q=r&255;w=(a[u]|0)+r&255;a[u]=w;r=w&255;if(f){x=w;w=q;y=c;z=r;while(1){A=a[b+(y+p)|0]|0;B=A&255;C=z-w+B&255;do{if((x&255)>>>0>(A&255)>>>0){if(!(C>>>0>B>>>0)){D=B;break}D=C>>>0>z>>>0?z:C}else{if(!(B>>>0>C>>>0)){D=B;break}D=C>>>0>z>>>0?C:z}}while(0);C=b+(y+t)|0;A=(d[C]|0)+D|0;E=A&255;a[C]=E;C=y+c|0;F=A&255;if((C|0)<(k|0)){x=E;w=B;y=C;z=F}else{G=B;H=F;break}}}else{G=q;H=r}if(s){z=t-e|0;y=t+e|0;w=H;x=G;F=0;while(1){C=d[b+(z+F)|0]|0;E=w-x+C&255;do{if(w>>>0>C>>>0){if(!(E>>>0>C>>>0)){I=C;break}I=E>>>0>w>>>0?w:E}else{if(!(C>>>0>E>>>0)){I=C;break}I=E>>>0>w>>>0?E:w}}while(0);E=b+(y+F)|0;B=(d[E]|0)+I|0;a[E]=B;E=B&255;B=F+c|0;if((B|0)<(k|0)){w=E;x=C;F=B}else{J=E;K=C;break}}}else{J=H;K=G}if((n|0)<=4){break}F=J;x=K;w=b+(t+i)|0;y=2;while(1){do{if(s){z=F;r=x;q=0;while(1){L=d[w+(q-i)|0]|0;E=z-r+L&255;do{if((z|0)>(L|0)){if(!(E>>>0>L>>>0)){M=L;break}M=(E|0)>(z|0)?z:E}else{if(!(L>>>0>E>>>0)){M=L;break}M=(E|0)>(z|0)?E:z}}while(0);E=w+q|0;B=(d[E]|0)+M|0;a[E]=B;N=B&255;B=q+c|0;if((B|0)<(k|0)){z=N;r=L;q=B}else{break}}if(s){O=N;P=L;Q=0}else{R=N;S=L;break}while(1){q=d[w+(Q-e)|0]|0;r=O-P+q&255;do{if(O>>>0>q>>>0){if(!(r>>>0>q>>>0)){T=q;break}T=r>>>0>O>>>0?O:r}else{if(!(q>>>0>r>>>0)){T=q;break}T=r>>>0>O>>>0?r:O}}while(0);r=w+(Q+e)|0;z=(d[r]|0)+T|0;a[r]=z;r=z&255;z=Q+c|0;if((z|0)<(k|0)){O=r;P=q;Q=z}else{R=r;S=q;break}}}else{R=F;S=x}}while(0);C=y+1|0;if((C|0)<(o|0)){F=R;x=S;w=w+i|0;y=C}else{break}}}}while(0);}while((l|0)<(h|0));return}function o1a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;e=i;f=b+60|0;g=c[f>>2]|0;c[g>>2]=b;h=g+1248|0;c[h>>2]=4;j=b+120|0;k=g+1280|0;c[k>>2]=(c[j>>2]|0)+31&-32;l=b+140|0;m=c[l>>2]|0;a:do{if((m|0)==0){do{if((c[j>>2]&1|0)==0){if((c[b+124>>2]&1|0)!=0){break}c[g+1260>>2]=3;c[b+52>>2]=(c[b+392>>2]|0)==1?810044501:811158613;n=842094169;break a}}while(0);yDb(b,16,1892088,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=e;return p|0}else if((m|0)==28){c[g+1260>>2]=4;c[b+52>>2]=1095912533;n=402784256}else if((m|0)==4){if((c[j>>2]&1|0)==0){c[g+1260>>2]=3;c[b+52>>2]=(c[b+392>>2]|0)==1?843598933:844713045;n=844715353;break}yDb(b,16,2349768,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=e;return p|0}else if((m|0)==2){c[g+1260>>2]=3;c[b+52>>2]=1196575829;n=402718720}else{yDb(b,16,2046888,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;p=-1094995529;i=e;return p|0}}while(0);Z3(g+4|0,b);m=c[b+216>>2]|0;if(m>>>0>4>>>0){yDb(b,24,2329496,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;p=-1414549496;i=e;return p|0}if((m|0)==1){yDb(b,16,2305040,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1414549496;i=e;return p|0}j=c[1108176+(m<<2)>>2]|0;c[g+1276>>2]=j;if((j|0)==2){yDb(b,16,2287216,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1414549496;i=e;return p|0}j=b+404|0;m=c[j>>2]|0;if(m>>>0>256>>>0){yDb(b,16,2271176,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;p=-22;i=e;return p|0}m=b+124|0;q=c[m>>2]|0;r=q>>(d[(bFb(c[l>>2]|0)|0)+6|0]|0);l=c[j>>2]|0;if((l|0)>(r|0)){yDb(b,16,2255720,(o=i,i=i+16|0,c[o>>2]=l,c[o+8>>2]=r,o)|0);i=o;p=-22;i=e;return p|0}l=ICb()|0;q=b+804|0;c[q>>2]=l;if((l|0)==0){yDb(b,16,2241312,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;l=c[f>>2]|0;$Db(q);$Db(l+1284|0);$Db(l+1288|0);$Db(l+1292|0);$Db(l+1296|0);$Db(l+1300|0);p=-12;i=e;return p|0}c[b+100>>2]=16;l=cEb(32)|0;s=b+96|0;c[s>>2]=l;if((l|0)==0){yDb(b,16,2229168,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;l=c[f>>2]|0;$Db(q);$Db(l+1284|0);$Db(l+1288|0);$Db(l+1292|0);$Db(l+1296|0);$Db(l+1300|0);p=-12;i=e;return p|0}l=g+1260|0;t=g+1288|0;u=0;while(1){if((u|0)>=(c[l>>2]|0)){break}v=WDb((ba((c[m>>2]|0)+2|0,c[k>>2]|0)|0)+16|0)|0;c[t+(u<<2)>>2]=v;if((v|0)==0){w=29;break}else{u=u+1|0}}if((w|0)==29){yDb(b,16,2217424,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;o=c[f>>2]|0;$Db(q);$Db(o+1284|0);$Db(o+1288|0);$Db(o+1292|0);$Db(o+1296|0);$Db(o+1300|0);p=-12;i=e;return p|0}o=c[s>>2]|0;x=16777456;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=(c[s>>2]|0)+4|0;x=n;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=(c[s>>2]|0)+8|0;x=c[h>>2]|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=c[j>>2]|0;do{if((o|0)==0){j=(r|0)/120|0;h=g+1264|0;c[h>>2]=j;if(!((r+119|0)>>>0>238>>>0)){c[h>>2]=1;y=1;break}if((r|0)<=30839){y=j;break}c[h>>2]=256;y=256}else{c[g+1264>>2]=o;y=o}}while(0);c[g+1268>>2]=1;o=(y<<24)-16777216|1;c[g+1252>>2]=o;g=(c[s>>2]|0)+12|0;x=o;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;p=0;i=e;return p|0}function p1a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+16|0;j=h|0;k=c[b+60>>2]|0;l=c[b+120>>2]|0;m=c[b+124>>2]|0;n=ba(m,l)|0;o=k+1260|0;p=(ba(n+256+(c[k+1264>>2]<<2)|0,c[o>>2]|0)|0)+4|0;q=r0a(b,e,p,(p|0)<0|0?-1:0)|0;if((q|0)<0){r=q;i=h;return r|0}q=c[e+24>>2]|0;p=e+28|0;s=c[p>>2]|0;if(!((s|0)>-1)){yDb(0,0,1964152,(t=i,i=i+24|0,c[t>>2]=1935984,c[t+8>>2]=1912592,c[t+16>>2]=145,t)|0);i=t;Cd();return 0}u=j|0;c[u>>2]=q;v=j+8|0;c[v>>2]=q;w=j+4|0;c[w>>2]=q+s;s=j+12|0;c[s>>2]=0;q=k+1284|0;O$a(q,k+1304|0,n+4|0);if((c[q>>2]|0)==0){yDb(b,16,2179456,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;r=-12;i=h;return r|0}q=b+140|0;n=c[q>>2]|0;if((n|0)==28|(n|0)==2){y=k+1288|0;z=c[k+1280>>2]|0;A=c[f>>2]|0;B=c[o>>2]|0;C=c[f+32>>2]|0;D=z<<1;if((m|0)>0){E=z-l|0;z=ba(B,l)|0;F=(z|0)>0;G=k+1292|0;H=k+1296|0;I=k+1300|0;if((B|0)==3){J=A;K=0;L=D;while(1){if(F){M=0;N=L;while(1){O=a[J+(M+1)|0]|0;a[(c[y>>2]|0)+N|0]=O;P=(O&255)+128|0;a[(c[G>>2]|0)+N|0]=(d[J+(M+2)|0]|0)-P;a[(c[H>>2]|0)+N|0]=(d[J+M|0]|0)-P;P=N+1|0;O=M+3|0;if((O|0)<(z|0)){M=O;N=P}else{Q=P;break}}}else{Q=L}N=K+1|0;if((N|0)<(m|0)){J=J+C|0;K=N;L=Q+E|0}else{break}}}else{Q=A;A=0;L=D;while(1){if(F){D=0;K=L;while(1){J=a[Q+(D+1)|0]|0;a[(c[y>>2]|0)+K|0]=J;N=(J&255)+128|0;a[(c[G>>2]|0)+K|0]=(d[Q+(D+2)|0]|0)-N;a[(c[H>>2]|0)+K|0]=(d[Q+D|0]|0)-N;a[(c[I>>2]|0)+K|0]=a[Q+(D+3)|0]|0;N=K+1|0;J=D+B|0;if((J|0)<(z|0)){D=J;K=N}else{R=N;break}}}else{R=L}K=A+1|0;if((K|0)<(m|0)){Q=Q+C|0;A=K;L=R+E|0}else{break}}}}S=c[q>>2]|0}else{S=n}a:do{if((S|0)==0){n=k+1288|0;q=0;while(1){if((q|0)>=(c[o>>2]|0)){break a}E=(q|0)!=0|0;T=r1a(b,c[f+(q<<2)>>2]|0,c[n>>2]|0,c[f+32+(q<<2)>>2]|0,l>>E,m>>E,j)|0;if((T|0)!=0){break}q=q+1|0}yDb(b,16,2103248,(t=i,i=i+8|0,c[t>>2]=q,t)|0);i=t;r=T;i=h;return r|0}else if((S|0)==4){n=k+1288|0;E=0;while(1){if((E|0)>=(c[o>>2]|0)){break a}U=r1a(b,c[f+(E<<2)>>2]|0,c[n>>2]|0,c[f+32+(E<<2)>>2]|0,l>>((E|0)!=0),m,j)|0;if((U|0)!=0){break}E=E+1|0}yDb(b,16,2103248,(t=i,i=i+8|0,c[t>>2]=E,t)|0);i=t;r=U;i=h;return r|0}else if((S|0)==2|(S|0)==28){n=k+1288|0;q=k+1280|0;R=0;while(1){if((R|0)>=(c[o>>2]|0)){break a}L=c[n+(R<<2)>>2]|0;A=c[q>>2]|0;V=r1a(b,L+(A<<1)|0,L,A,l,m,j)|0;if((V|0)!=0){break}R=R+1|0}yDb(b,16,2103248,(t=i,i=i+8|0,c[t>>2]=R,t)|0);i=t;r=V;i=h;return r|0}else{yDb(b,16,2046888,(t=i,i=i+8|0,c[t>>2]=S,t)|0);i=t;r=-1094995529;i=h;return r|0}}while(0);t=c[k+1276>>2]<<8;do{if((c[s>>2]|0)==0){k=c[u>>2]|0;if(((c[w>>2]|0)-k|0)<=3){W=k;X=37;break}S=k;x=t;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;S=(c[u>>2]|0)+4|0;c[u>>2]=S;Y=S}else{W=c[u>>2]|0;X=37}}while(0);if((X|0)==37){c[s>>2]=1;Y=W}W=c[b+804>>2]|0;c[W+84>>2]=1;c[W+88>>2]=1;c[p>>2]=Y-(c[v>>2]|0);v=e+36|0;c[v>>2]=c[v>>2]|1;c[g>>2]=1;r=0;i=h;return r|0}function q1a(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(a+804|0);$Db(b+1284|0);$Db(b+1288|0);$Db(b+1292|0);$Db(b+1296|0);$Db(b+1300|0);return 0}function r1a(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;l=i;i=i+4368|0;m=l|0;n=l+8|0;o=l+16|0;p=l+272|0;q=l+2320|0;r=c[b+60>>2]|0;TGb(p|0,0,2048)|0;s=c[r+1276>>2]|0;do{if((s|0)==1){t=r+1264|0;u=c[t>>2]|0;if((u|0)<=0){break}v=(h|0)>0;w=0;y=0;z=u;while(1){u=w+1|0;A=(ba(u,j)|0)/(z|0)|0;B=A-y|0;if((B|0)>0&v){C=f+(ba(y,h)|0)|0;D=e+(ba(y,g)|0)|0;E=0;G=-128;while(1){H=C;I=0;J=G;while(1){K=D+I|0;a[H]=(a[K]|0)-J;L=a[K]|0;K=I+1|0;if((K|0)<(h|0)){H=H+1|0;I=K;J=L}else{break}}J=E+1|0;if((J|0)<(B|0)){C=C+h|0;D=D+g|0;E=J;G=L}else{break}}M=c[t>>2]|0}else{M=z}if((u|0)<(M|0)){w=u;y=A;z=M}else{break}}}else if((s|0)==0){z=r+1264|0;y=c[z>>2]|0;if((y|0)>0){N=0;O=0;P=y}else{break}while(1){y=N+1|0;w=(ba(y,j)|0)/(P|0)|0;iDb(f+(ba(O,h)|0)|0,h,e+(ba(O,g)|0)|0,g,h,w-O|0);t=c[z>>2]|0;if((y|0)<(t|0)){N=y;O=w;P=t}else{break}}}else if((s|0)==3){z=r+1264|0;t=c[z>>2]|0;if((t|0)<=0){break}w=(h|0)>0;y=r+1084|0;v=0;G=0;E=t;while(1){t=v+1|0;D=(ba(t,j)|0)/(E|0)|0;C=ba(G,g)|0;B=e+C|0;J=ba(G,h)|0;I=f+J|0;H=D-G|0;if(w){K=I;Q=0;R=-128;while(1){S=e+(Q+C)|0;a[K]=(a[S]|0)-R;T=Q+1|0;if((T|0)<(h|0)){K=K+1|0;Q=T;R=a[S]|0}else{break}}U=f+(J+h)|0}else{U=I}do{if((H|0)!=1){c[n>>2]=0;c[m>>2]=0;if((H|0)>1){V=U;W=1;X=B}else{break}while(1){R=X+g|0;Se[c[y>>2]&511](V,X,R,h,m,n);Q=W+1|0;if((Q|0)<(H|0)){V=V+h|0;W=Q;X=R}else{break}}}}while(0);H=c[z>>2]|0;if((t|0)<(H|0)){v=t;G=D;E=H}else{break}}}else{yDb(b,16,2001224,(E=i,i=i+8|0,c[E>>2]=s,E)|0);i=E;Y=-1414549496;i=l;return Y|0}}while(0);s=p|0;b=(h|0)>0;if((j|0)>0&b){X=f;W=0;while(1){V=0;do{n=p+((d[X+V|0]|0)<<3)|0;m=YGb(c[n>>2]|0,c[n+4>>2]|0,1,0)|0;c[n>>2]=m;c[n+4>>2]=F;V=V+1|0;}while((V|0)<(h|0));V=W+1|0;if((V|0)<(j|0)){X=X+h|0;W=V}else{Z=0;break}}}else{Z=0}while(1){if((Z|0)>=256){break}W=p+(Z<<3)|0;_=c[W>>2]|0;$=c[W+4>>2]|0;if((_|0)==0&($|0)==0){Z=Z+1|0}else{aa=29;break}}do{if((aa|0)==29){p=gHb(j,(j|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;if(!((_|0)==(p|0)&($|0)==(F|0))){break}p=k+12|0;W=k+4|0;X=k|0;V=0;do{n=(c[p>>2]|0)==0;a:do{if((V|0)==(Z|0)){do{if(n){m=c[X>>2]|0;if(((c[W>>2]|0)-m|0)<=0){break}a[m]=0;c[X>>2]=(c[X>>2]|0)+1;break a}}while(0);c[p>>2]=1}else{do{if(n){m=c[X>>2]|0;if(((c[W>>2]|0)-m|0)<=0){break}a[m]=-1;c[X>>2]=(c[X>>2]|0)+1;break a}}while(0);c[p>>2]=1}}while(0);V=V+1|0;}while((V|0)<256);V=r+1264|0;if((c[V>>2]|0)>0){ca=1}else{Y=0;i=l;return Y|0}while(1){do{if((c[p>>2]|0)==0){n=c[X>>2]|0;if(((c[W>>2]|0)-n|0)<=3){aa=45;break}D=n;x=0;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[X>>2]=(c[X>>2]|0)+4}else{aa=45}}while(0);if((aa|0)==45){aa=0;c[p>>2]=1}if((ca|0)>=(c[V>>2]|0)){Y=0;break}ca=ca+1|0}i=l;return Y|0}}while(0);ca=sGa(o|0,s,256)|0;if((ca|0)<0){Y=ca;i=l;return Y|0}ca=k+12|0;s=k+4|0;Z=k|0;$=0;do{_=o+$|0;V=a[_]|0;do{if((c[ca>>2]|0)==0){p=c[Z>>2]|0;if(((c[s>>2]|0)-p|0)<=0){aa=53;break}a[p]=V;c[Z>>2]=(c[Z>>2]|0)+1;da=a[_]|0}else{aa=53}}while(0);if((aa|0)==53){aa=0;c[ca>>2]=1;da=V}a[q+($<<3)+1|0]=da;a[q+($<<3)|0]=$;$=$+1|0;}while(($|0)<256);$=q|0;Yc($|0,256,8,864);da=255;while(1){ea=a[q+(da<<3)+1|0]|0;if(ea<<24>>24!=-1|(da|0)==0){break}else{da=da-1|0}}do{if((da|0)>-1){o=ea&255;c[q+(da<<3)+4>>2]=1>>>((32-o|0)>>>0);if((da|0)>0){fa=1;ga=o;ha=da}else{break}do{ha=ha-1|0;fa=(-2147483648>>>((ga-1|0)>>>0))+fa|0;ga=d[q+(ha<<3)+1|0]|0;c[q+(ha<<3)+4>>2]=fa>>>((32-ga|0)>>>0);}while((ha|0)>0)}}while(0);Yc($|0,256,8,238);$=r+1264|0;ha=c[$>>2]|0;if((ha|0)>0){ga=r+1284|0;fa=((ba(j,h)|0)+4|0)<0;da=r+1100|0;r=k+8|0;ea=0;V=0;o=0;_=ha;while(1){ha=V+1|0;p=(ba(ha,j)|0)/(_|0)|0;X=p-o|0;W=fa?0:c[ga>>2]|0;if((X|0)>0){D=W;n=32;t=f+(ba(o,h)|0)|0;m=0;g=0;while(1){if(b){U=D;e=n;P=0;O=g;while(1){N=d[t+P|0]|0;M=d[q+(N<<3)+1|0]|0;L=c[q+(N<<3)+4>>2]|0;if((e|0)>(M|0)){ia=e;ja=O<<M|L;ka=U}else{N=U;x=fe(L>>>((M-e|0)>>>0)|O<<e|0)|0;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;ia=e+32|0;ja=L;ka=U+4|0}L=ia-M|0;M=P+1|0;if((M|0)<(h|0)){U=ka;e=L;P=M;O=ja}else{la=ka;ma=L;na=ja;break}}}else{la=D;ma=n;na=g}O=m+1|0;if((O|0)<(X|0)){D=la;n=ma;t=t+h|0;m=O;g=na}else{oa=la;pa=ma;qa=na;break}}}else{oa=W;pa=32;qa=0}g=W;m=32-pa+(oa-g<<3)&31;do{if((m|0)==0){ra=pa;sa=oa;ta=qa}else{t=32-m|0;if((pa|0)>(t|0)){ra=pa-t|0;sa=oa;ta=qa<<t;break}else{t=oa;x=fe(qa<<pa|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;ra=m+pa|0;sa=oa+4|0;ta=0;break}}}while(0);m=32-ra+(sa-g<<3)|0;if((ra|0)<32){W=ta<<ra;t=W>>>24&255;n=ra;D=sa;X=W;while(1){a[D]=t;W=n+8|0;if((W|0)<32){t=X>>>16&255;n=W;D=D+1|0;X=X<<8}else{break}}}X=m>>3;D=X+ea|0;n=c[ga>>2]|0;Xe[c[da>>2]&4095](n,n,X>>>2);do{if((c[ca>>2]|0)==0){n=c[Z>>2]|0;if(((c[s>>2]|0)-n|0)<=3){ua=n;aa=82;break}t=n;x=D;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[Z>>2]|0)+4|0;c[Z>>2]=t;va=t}else{ua=c[Z>>2]|0;aa=82}}while(0);if((aa|0)==82){aa=0;c[ca>>2]=1;va=ua}m=ea-4+((c[$>>2]|0)-V<<2)|0;c[ca>>2]=0;t=c[s>>2]|0;n=t;g=va;W=n-g|0;O=(W|0)<(m|0);if(O){c[ca>>2]=1;wa=1}else{wa=0}P=(c[r>>2]|0)-g|0;if((P|0)>(m|0)){xa=P}else{xa=O?W:m}m=va+xa|0;c[Z>>2]=m;W=c[ga>>2]|0;if((wa|0)==0){O=n-m|0;n=O>>>0>X>>>0?X:O;if((n|0)!=(X|0)){c[ca>>2]=1}UGb(m|0,W|0,n)|0;W=(c[Z>>2]|0)+n|0;c[Z>>2]=W;ya=c[s>>2]|0;za=W}else{ya=t;za=m}m=4-D+(V-(c[$>>2]|0)<<2)|0;t=za;W=ya-t|0;n=(W|0)<(m|0);if(n){Aa=1}else{Aa=0}c[ca>>2]=Aa;O=(c[r>>2]|0)-t|0;if((O|0)>(m|0)){Ba=O}else{Ba=n?W:m}m=za+Ba|0;c[Z>>2]=m;W=c[$>>2]|0;if((ha|0)<(W|0)){ea=D;V=ha;o=p;_=W}else{Ca=D;Da=ya;Ea=m;break}}}else{Ca=0;Da=c[s>>2]|0;Ea=c[Z>>2]|0}s=Ea;ya=Da-s|0;Da=(ya|0)<(Ca|0);if(Da){Fa=1}else{Fa=0}c[ca>>2]=Fa;Fa=(c[k+8>>2]|0)-s|0;if((Fa|0)>(Ca|0)){Ga=Fa}else{Ga=Da?ya:Ca}c[Z>>2]=Ea+Ga;Y=0;i=l;return Y|0}function s1a(a,b){a=a|0;b=b|0;return(d[a]|0)-(d[b]|0)|0}function t1a(a){a=a|0;var b=0,d=0,e=0;b=i;if((c[a+120>>2]&1|0)==0){d=c[a+60>>2]|0;c[a+140>>2]=74;c[a+796>>2]=10;c[d+16>>2]=546;e=0;i=b;return e|0}else{yDb(a,16,2046864,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1094995529;i=b;return e|0}return 0}function u1a(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=i;h=c[a+60>>2]|0;j=d;k=c[f+24>>2]|0;l=c[h+4>>2]|0;if((l|0)==0){m=(c[a+120>>2]|0)+47|0;n=(m-((m|0)%48|0)<<3|0)/3|0}else{n=l}l=f+28|0;f=c[l>>2]|0;m=a+124|0;o=c[m>>2]|0;if((f|0)<(ba(o,n)|0)){p=(c[a+120>>2]|0)+23|0;if((ba((p-((p|0)%24|0)<<3|0)/3|0,o)|0)!=(f|0)){yDb(a,16,2103224,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=g;return r|0}p=h+12|0;if((c[p>>2]|0)==0){yDb(a,24,2179392,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}c[p>>2]=1;s=(f|0)/(o|0)|0}else{s=n}if((k&15|0)==0){t=(s&15|0)==0|0}else{t=0}n=h+8|0;if((t|0)!=(c[n>>2]|0)){c[n>>2]=t}t=_$a(a,j,0)|0;if((t|0)<0){r=t;i=g;return r|0}t=c[d>>2]|0;j=c[d+4>>2]|0;n=c[d+8>>2]|0;c[d+88>>2]=1;c[d+84>>2]=1;if((c[m>>2]|0)>0){o=a+120|0;f=h+16|0;h=d+32|0;p=d+36|0;q=d+40|0;u=0;v=k;k=t;t=j;j=n;n=c[o>>2]|0;while(1){w=v;x=n-((n|0)%6|0)|0;le[c[f>>2]&1023](w,k,t,j,x);y=k+(x<<1)|0;z=x>>1;A=t+(z<<1)|0;B=j+(z<<1)|0;C=(x<<1|0)/3|0;D=c[o>>2]|0;do{if((x|0)<(D-1|0)){E=c[w+(C<<2)>>2]|0;F=z+1|0;G=t+(F<<1)|0;b[A>>1]=E&1023;b[y>>1]=E>>>10&1023;H=j+(F<<1)|0;b[B>>1]=E>>>20&1023;E=c[w+(C+1<<2)>>2]|0;F=k+(x+2<<1)|0;b[k+(x+1<<1)>>1]=E&1023;if((x|0)>=(D-3|0)){I=H;J=G;K=F;break}L=z+2|0;b[G>>1]=E>>>10&1023;b[F>>1]=E>>>20&1023;E=c[w+(C+2<<2)>>2]|0;b[H>>1]=E&1023;b[k+(x+3<<1)>>1]=E>>>10&1023;I=j+(L<<1)|0;J=t+(L<<1)|0;K=k+(x+4<<1)|0}else{I=B;J=A;K=y}}while(0);y=(D|0)/2|0;A=u+1|0;if((A|0)<(c[m>>2]|0)){u=A;v=v+s|0;k=K+(((c[h>>2]|0)/2|0)-D<<1)|0;t=J+(((c[p>>2]|0)/2|0)-y<<1)|0;j=I+(((c[q>>2]|0)/2|0)-y<<1)|0;n=D}else{break}}}n=c[a+408>>2]|0;do{if(n>>>0>1>>>0){c[d+296>>2]=1;if(!((n|0)==2|(n|0)==4)){break}c[d+300>>2]=1}}while(0);c[e>>2]=1;r=c[l>>2]|0;i=g;return r|0}function v1a(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;h=g-5|0;if((h|0)>0){i=e;j=f;k=d;l=a;m=0}else{return}while(1){a=c[l>>2]|0;b[i>>1]=a&1023;b[k>>1]=a>>>10&1023;b[j>>1]=a>>>20&1023;a=c[l+4>>2]|0;b[k+2>>1]=a&1023;b[i+2>>1]=a>>>10&1023;b[k+4>>1]=a>>>20&1023;a=c[l+8>>2]|0;b[j+2>>1]=a&1023;b[k+6>>1]=a>>>10&1023;b[i+4>>1]=a>>>20&1023;a=c[l+12>>2]|0;b[k+8>>1]=a&1023;b[j+4>>1]=a>>>10&1023;b[k+10>>1]=a>>>20&1023;a=m+6|0;if((a|0)<(h|0)){i=i+6|0;j=j+6|0;k=k+12|0;l=l+16|0;m=a}else{break}}return}function w1a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[a+120>>2]&1|0)!=0){yDb(a,16,2001184,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-22;i=b;return e|0}f=c[a+796>>2]|0;if((f|0)!=10){yDb(a,24,1964096,(d=i,i=i+8|0,c[d>>2]=f,d)|0);i=d}d=ICb()|0;c[a+804>>2]=d;if((d|0)==0){e=-12;i=b;return e|0}c[d+88>>2]=1;e=0;i=b;return e|0}function x1a(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;h=i;j=d+120|0;k=c[j>>2]|0;l=k+47|0;m=(l-((l|0)%48|0)<<3|0)/3|0;l=m-((((k<<3)+11|0)/12|0)<<2)|0;k=c[f>>2]|0;n=c[f+4>>2]|0;o=c[f+8>>2]|0;p=d+124|0;q=ba(c[p>>2]|0,m)|0;m=r0a(d,e,q,(q|0)<0|0?-1:0)|0;if((m|0)<0){r=m;i=h;return r|0}m=c[e+24>>2]|0;q=c[e+28>>2]|0;if(!((q|0)>-1)){yDb(0,0,2179352,(d=i,i=i+24|0,c[d>>2]=2103200,c[d+8>>2]=2046840,c[d+16>>2]=145,d)|0);i=d;Cd();return 0}if((c[p>>2]|0)>0){d=m+q|0;q=f+32|0;s=f+36|0;t=f+40|0;f=0;u=m;m=0;v=k;k=n;n=o;o=c[j>>2]|0;while(1){if((o-5|0)>0){w=u;y=0;z=v;A=k;B=n;while(1){C=b[A>>1]|0;D=C&65535;if((C&65535)>>>0<4>>>0){E=4}else{E=D>>>0>1019>>>0?1019:D}D=b[z>>1]|0;if((D&65535)>>>0<4>>>0){F=4096}else{F=(D&65535)>>>0>1019>>>0?1043456:(D&65535)<<10}D=b[B>>1]|0;if((D&65535)>>>0<4>>>0){G=4194304}else{G=(D&65535)>>>0>1019>>>0?1068498944:(D&65535)<<20}D=w;x=F|E|G;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;D=b[z+2>>1]|0;C=D&65535;if((D&65535)>>>0<4>>>0){H=4}else{H=C>>>0>1019>>>0?1019:C}C=b[A+2>>1]|0;if((C&65535)>>>0<4>>>0){I=4096}else{I=(C&65535)>>>0>1019>>>0?1043456:(C&65535)<<10}C=b[z+4>>1]|0;if((C&65535)>>>0<4>>>0){J=4194304}else{J=(C&65535)>>>0>1019>>>0?1068498944:(C&65535)<<20}C=w+4|0;x=I|H|J;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=b[B+2>>1]|0;D=C&65535;if((C&65535)>>>0<4>>>0){K=4}else{K=D>>>0>1019>>>0?1019:D}D=b[z+6>>1]|0;if((D&65535)>>>0<4>>>0){L=4096}else{L=(D&65535)>>>0>1019>>>0?1043456:(D&65535)<<10}D=A+6|0;C=b[A+4>>1]|0;if((C&65535)>>>0<4>>>0){M=4194304}else{M=(C&65535)>>>0>1019>>>0?1068498944:(C&65535)<<20}C=w+8|0;x=L|K|M;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=b[z+8>>1]|0;N=C&65535;if((C&65535)>>>0<4>>>0){O=4}else{O=N>>>0>1019>>>0?1019:N}N=B+6|0;C=b[B+4>>1]|0;if((C&65535)>>>0<4>>>0){P=4096}else{P=(C&65535)>>>0>1019>>>0?1043456:(C&65535)<<10}C=z+12|0;Q=b[z+10>>1]|0;if((Q&65535)>>>0<4>>>0){R=4194304}else{R=(Q&65535)>>>0>1019>>>0?1068498944:(Q&65535)<<20}Q=w+12|0;x=P|O|R;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=w+16|0;S=y+6|0;T=c[j>>2]|0;if((S|0)<(T-5|0)){w=Q;y=S;z=C;A=D;B=N}else{U=Q;V=S;W=C;X=D;Y=N;Z=T;break}}}else{U=u;V=0;W=v;X=k;Y=n;Z=o}do{if((V|0)<(Z-1|0)){B=X+2|0;A=b[X>>1]|0;z=A&65535;if((A&65535)>>>0<4>>>0){_=4}else{_=z>>>0>1019>>>0?1019:z}z=b[W>>1]|0;if((z&65535)>>>0<4>>>0){$=4096}else{$=(z&65535)>>>0>1019>>>0?1043456:(z&65535)<<10}z=Y+2|0;A=b[Y>>1]|0;if((A&65535)>>>0<4>>>0){aa=4194304}else{aa=(A&65535)>>>0>1019>>>0?1068498944:(A&65535)<<20}A=U;x=$|_|aa;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;A=U+4|0;y=W+4|0;w=b[W+2>>1]|0;T=w&65535;if((w&65535)>>>0<4>>>0){ca=4}else{ca=T>>>0>1019>>>0?1019:T}T=c[j>>2]|0;if((V|0)==(T-2|0)){w=A;x=ca;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;da=U+8|0;ea=c[j>>2]|0}else{da=A;ea=T}if((V|0)>=(ea-3|0)){fa=z;ga=B;ha=y;ia=da;break}T=b[B>>1]|0;if((T&65535)>>>0<4>>>0){ja=4096}else{ja=(T&65535)>>>0>1019>>>0?1043456:(T&65535)<<10}T=b[y>>1]|0;if((T&65535)>>>0<4>>>0){ka=4194304}else{ka=(T&65535)>>>0>1019>>>0?1068498944:(T&65535)<<20}T=da;x=ja|ca|ka;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;T=b[z>>1]|0;z=T&65535;if((T&65535)>>>0<4>>>0){la=4}else{la=z>>>0>1019>>>0?1019:z}z=b[W+6>>1]|0;if((z&65535)>>>0<4>>>0){ma=4096}else{ma=(z&65535)>>>0>1019>>>0?1043456:(z&65535)<<10}z=da+4|0;x=ma|la;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;fa=Y+4|0;ga=X+4|0;ha=W+8|0;ia=da+8|0}else{fa=Y;ga=X;ha=W;ia=U}}while(0);if((f|0)==0){z=d-ia|0;T=z>>>0>l>>>0?l:z;TGb(ia|0,0,T|0)|0;na=ia+T|0;oa=(T|0)!=(l|0)|0}else{na=ia;oa=f}T=c[j>>2]|0;z=(T|0)/2|0;y=m+1|0;if((y|0)<(c[p>>2]|0)){f=oa;u=na;m=y;v=ha+(((c[q>>2]|0)/2|0)-T<<1)|0;k=ga+(((c[s>>2]|0)/2|0)-z<<1)|0;n=fa+(((c[t>>2]|0)/2|0)-z<<1)|0;o=T}else{break}}}o=e+36|0;c[o>>2]=c[o>>2]|1;c[g>>2]=1;r=0;i=h;return r|0}function y1a(a){a=a|0;$Db(a+804|0);return 0}function z1a(a){a=a|0;var b=0,d=0;b=i;if((c[a+120>>2]&1|0)==0){c[a+140>>2]=56;c[a+796>>2]=10;d=0;i=b;return d|0}else{yDb(a,16,2046776,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;d=-22;i=b;return d|0}return 0}function A1a(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;h=c[f+24>>2]|0;j=c[a+120>>2]|0;k=f+28|0;f=c[k>>2]|0;l=a+124|0;m=(ba(j<<3,c[l>>2]|0)|0)/3|0;if((f|0)<(m|0)){yDb(a,16,2179328,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}if((f|0)>(m|0)){DDb(a,2103176,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}n=_$a(a,d,0)|0;if((n|0)<0){o=n;i=g;return o|0}n=c[d>>2]|0;a=c[d+4>>2]|0;m=c[d+8>>2]|0;c[d+88>>2]=1;c[d+84>>2]=1;f=d+32|0;p=2-j|0;q=d+36|0;r=(j|0)/-2|0;s=d+40|0;d=r+1|0;t=n+(j<<1)|0;j=m;m=a;a=n;n=0;u=h;while(1){h=fe(c[u>>2]|0)|0;b[m>>1]=h>>>16&65535&-64;b[a>>1]=h>>>6&65535&-64;b[j>>1]=h<<4&65535&-64;h=u+8|0;v=fe(c[u+4>>2]|0)|0;w=a+4|0;b[a+2>>1]=v>>>16&65535&-64;if(w>>>0<t>>>0){x=t;y=j+2|0;z=m+2|0;A=w;B=n}else{w=(c[f>>2]|0)/2|0;C=n+1|0;if((C|0)<(c[l>>2]|0)){x=a+(w+2<<1)|0;y=j+(d+((c[s>>2]|0)/2|0)<<1)|0;z=m+(((c[q>>2]|0)/2|0)+1+r<<1)|0;A=a+(p+w<<1)|0;B=C}else{break}}b[z>>1]=v>>>6&65535&-64;b[A>>1]=v<<4&65535&-64;v=u+12|0;C=fe(c[h>>2]|0)|0;b[y>>1]=C>>>16&65535&-64;h=A+4|0;b[A+2>>1]=C>>>6&65535&-64;if(h>>>0<x>>>0){D=x;E=y+2|0;F=z+2|0;G=h;H=B}else{h=(c[f>>2]|0)/2|0;w=B+1|0;if((w|0)<(c[l>>2]|0)){D=A+(h+2<<1)|0;E=y+(d+((c[s>>2]|0)/2|0)<<1)|0;F=z+(((c[q>>2]|0)/2|0)+1+r<<1)|0;G=A+(p+h<<1)|0;H=w}else{break}}b[F>>1]=C<<4&65535&-64;C=u+16|0;w=fe(c[v>>2]|0)|0;b[G>>1]=w>>>16&65535&-64;b[E>>1]=w>>>6&65535&-64;v=G+4|0;b[G+2>>1]=w<<4&65535&-64;if(v>>>0<D>>>0){t=D;j=E+2|0;m=F+2|0;a=v;n=H;u=C;continue}v=(c[f>>2]|0)/2|0;w=H+1|0;if((w|0)<(c[l>>2]|0)){t=G+(v+2<<1)|0;j=E+(d+((c[s>>2]|0)/2|0)<<1)|0;m=F+(((c[q>>2]|0)/2|0)+1+r<<1)|0;a=G+(p+v<<1)|0;n=w;u=C}else{break}}c[e>>2]=1;o=c[k>>2]|0;i=g;return o|0}function B1a(a){a=a|0;var b=0;b=i;c[a+140>>2]=5;if((c[a+120>>2]&1|0)==0){i=b;return 0}yDb(a,24,2103136,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function C1a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=b+124|0;k=b+120|0;if((c[j>>2]|0)<(ba((c[f>>2]|0)*3|0,c[k>>2]|0)|0)){yDb(b,16,2179296,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=g;return m|0}l=_$a(b,d,0)|0;if((l|0)<0){m=l;i=g;return m|0}c[d+84>>2]=1;c[d+88>>2]=1;l=c[f>>2]|0;if((l|0)>0){b=d+32|0;n=d+36|0;o=d+40|0;p=h;h=c[d>>2]|0;q=c[d+4>>2]|0;r=c[d+8>>2]|0;d=0;s=c[k>>2]|0;t=l;while(1){if((s|0)>0){l=p;u=0;while(1){a[r+u|0]=a[l]|0;a[h+u|0]=a[l+1|0]|0;v=l+3|0;a[q+u|0]=a[l+2|0]|0;w=u+1|0;x=c[k>>2]|0;if((w|0)<(x|0)){l=v;u=w}else{break}}y=v;z=x;A=c[f>>2]|0}else{y=p;z=s;A=t}u=d+1|0;if((u|0)<(A|0)){p=y;h=h+(c[b>>2]|0)|0;q=q+(c[n>>2]|0)|0;r=r+(c[o>>2]|0)|0;d=u;s=z;t=A}else{break}}}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function D1a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[a+120>>2]&1|0)!=0){yDb(a,16,2179256,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-1094995529;i=b;return e|0}f=ICb()|0;c[a+804>>2]=f;if((f|0)!=0){e=0;i=b;return e|0}yDb(a,16,2103104,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-12;i=b;return e|0}function E1a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=b+120|0;h=b+124|0;i=ba((c[g>>2]|0)*3|0,c[h>>2]|0)|0;j=r0a(b,d,i,(i|0)<0|0?-1:0)|0;if((j|0)<0){k=j;return k|0}j=c[d+24>>2]|0;i=c[b+804>>2]|0;c[i+84>>2]=1;c[i+88>>2]=1;i=c[h>>2]|0;if((i|0)>0){b=e+32|0;l=e+36|0;m=e+40|0;n=j;j=c[e>>2]|0;o=c[e+4>>2]|0;p=c[e+8>>2]|0;e=0;q=c[g>>2]|0;r=i;while(1){if((q|0)>0){i=n;s=0;while(1){a[i]=a[p+s|0]|0;a[i+1|0]=a[j+s|0]|0;t=i+3|0;a[i+2|0]=a[o+s|0]|0;u=s+1|0;v=c[g>>2]|0;if((u|0)<(v|0)){i=t;s=u}else{break}}w=t;x=v;y=c[h>>2]|0}else{w=n;x=q;y=r}s=e+1|0;if((s|0)<(y|0)){n=w;j=j+(c[b>>2]|0)|0;o=o+(c[l>>2]|0)|0;p=p+(c[m>>2]|0)|0;e=s;q=x;r=y}else{break}}}y=d+36|0;c[y>>2]=c[y>>2]|1;c[f>>2]=1;k=0;return k|0}function F1a(a){a=a|0;$Db(a+804|0);return 0}function G1a(a){a=a|0;c[a+140>>2]=299;return 0}function H1a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=b+124|0;k=b+120|0;if((c[j>>2]|0)<(ba(c[f>>2]<<2,c[k>>2]|0)|0)){yDb(b,16,2046744,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=g;return m|0}l=_$a(b,d,0)|0;if((l|0)<0){m=l;i=g;return m|0}c[d+84>>2]=1;c[d+88>>2]=1;l=c[f>>2]|0;if((l|0)>0){n=d+32|0;o=d+36|0;p=d+40|0;q=d+44|0;r=b+48|0;b=h;h=c[d>>2]|0;s=c[d+4>>2]|0;t=c[d+8>>2]|0;u=c[d+12>>2]|0;d=0;v=c[k>>2]|0;w=l;while(1){if((v|0)>0){l=b;x=0;do{y=l+1|0;z=a[l]|0;if((c[r>>2]|0)==1096373590){a[t+x|0]=z;a[s+x|0]=a[y]|0;a[h+x|0]=a[l+2|0]|0;a[u+x|0]=a[l+3|0]|0}else{a[s+x|0]=z;a[h+x|0]=a[y]|0;a[t+x|0]=a[l+2|0]|0;a[u+x|0]=a[l+3|0]|0}l=l+4|0;x=x+1|0;A=c[k>>2]|0;}while((x|0)<(A|0));B=l;C=A;D=c[f>>2]|0}else{B=b;C=v;D=w}x=d+1|0;if((x|0)<(D|0)){b=B;h=h+(c[n>>2]|0)|0;s=s+(c[o>>2]|0)|0;t=t+(c[p>>2]|0)|0;u=u+(c[q>>2]|0)|0;d=x;v=C;w=D}else{break}}}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function I1a(a){a=a|0;var b=0,d=0,e=0;b=i;d=ICb()|0;c[a+804>>2]=d;if((d|0)!=0){e=0;i=b;return e|0}yDb(a,16,2001152,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-12;i=b;return e|0}function J1a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=b+120|0;h=b+124|0;i=ba(c[g>>2]<<2,c[h>>2]|0)|0;j=r0a(b,d,i,(i|0)<0|0?-1:0)|0;if((j|0)<0){k=j;return k|0}j=c[d+24>>2]|0;i=c[b+804>>2]|0;c[i+84>>2]=1;c[i+88>>2]=1;i=c[h>>2]|0;if((i|0)>0){l=e+32|0;m=e+36|0;n=e+40|0;o=e+44|0;p=b+48|0;b=j;j=c[e>>2]|0;q=c[e+4>>2]|0;r=c[e+8>>2]|0;s=c[e+12>>2]|0;e=0;t=c[g>>2]|0;u=i;while(1){if((t|0)>0){i=b;v=0;do{if((c[p>>2]|0)==1096373590){a[i]=a[r+v|0]|0;a[i+1|0]=a[q+v|0]|0;a[i+2|0]=a[j+v|0]|0;a[i+3|0]=a[s+v|0]|0}else{a[i]=a[q+v|0]|0;a[i+1|0]=a[j+v|0]|0;a[i+2|0]=a[r+v|0]|0;a[i+3|0]=a[s+v|0]|0}i=i+4|0;v=v+1|0;w=c[g>>2]|0;}while((v|0)<(w|0));x=i;y=w;z=c[h>>2]|0}else{x=b;y=t;z=u}v=e+1|0;if((v|0)<(z|0)){b=x;j=j+(c[l>>2]|0)|0;q=q+(c[m>>2]|0)|0;r=r+(c[n>>2]|0)|0;s=s+(c[o>>2]|0)|0;e=v;t=y;u=z}else{break}}}z=d+36|0;c[z>>2]=c[z>>2]|1;c[f>>2]=1;k=0;return k|0}function K1a(a){a=a|0;$Db(a+804|0);return 0}function L1a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;c[a+140>>2]=78;c[a+796>>2]=10;if((c[a+120>>2]&1|0)==0){d=0;i=b;return d|0}e=a;if((c[a+696>>2]&8|0)==0){yDb(e,24,2046680,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;d=0;i=b;return d|0}else{yDb(e,16,2102944,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;d=-1094995529;i=b;return d|0}return 0}function M1a(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;j=c[g+24>>2]|0;k=g+28|0;g=a+124|0;l=a+120|0;if((c[k>>2]|0)<(ba(c[g>>2]<<2,c[l>>2]|0)|0)){yDb(a,16,2179168,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=h;return n|0}m=_$a(a,e,0)|0;if((m|0)<0){n=m;i=h;return n|0}c[e+84>>2]=1;c[e+88>>2]=1;m=c[g>>2]|0;if((m|0)>0){g=e+32|0;a=e+36|0;o=e+40|0;p=c[l>>2]|0;l=c[e>>2]|0;q=c[e+4>>2]|0;r=c[e+8>>2]|0;e=j;j=0;while(1){if((p|0)>0){s=e;t=0;while(1){u=s;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;b[q+(t<<1)>>1]=v>>>2&1023;b[l+(t<<1)>>1]=v>>>12&1023;b[r+(t<<1)>>1]=v>>>22;v=s+4|0;u=t+1|0;if((u|0)<(p|0)){s=v;t=u}else{w=v;break}}}else{w=e}t=j+1|0;if((t|0)<(m|0)){l=l+(c[g>>2]>>1<<1)|0;q=q+(c[a>>2]>>1<<1)|0;r=r+(c[o>>2]>>1<<1)|0;e=w;j=t}else{break}}}c[f>>2]=1;n=c[k>>2]|0;i=h;return n|0}function N1a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[a+120>>2]&1|0)!=0){yDb(a,16,2179128,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-1094995529;i=b;return e|0}f=ICb()|0;c[a+804>>2]=f;if((f|0)!=0){e=0;i=b;return e|0}yDb(a,16,2102912,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-12;i=b;return e|0}function O1a(b,d,f,g){b=b|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;h=b+120|0;i=b+124|0;j=ba(c[h>>2]<<2,c[i>>2]|0)|0;k=r0a(b,d,j,(j|0)<0|0?-1:0)|0;if((k|0)<0){l=k;return l|0}k=c[d+24>>2]|0;j=c[b+804>>2]|0;c[j+84>>2]=1;c[j+88>>2]=1;j=c[i>>2]|0;if((j|0)>0){b=f+32|0;m=f+36|0;n=f+40|0;o=c[f>>2]|0;p=c[f+4>>2]|0;q=c[f+8>>2]|0;f=k;k=0;r=c[h>>2]|0;s=j;while(1){if((r|0)>0){j=f;t=0;do{u=j;x=(e[o+(t<<1)>>1]|0)<<12|(e[p+(t<<1)>>1]|0)<<2|(e[q+(t<<1)>>1]|0)<<22;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;j=j+4|0;t=t+1|0;v=c[h>>2]|0;}while((t|0)<(v|0));w=j;y=v;z=c[i>>2]|0}else{w=f;y=r;z=s}t=k+1|0;if((t|0)<(z|0)){o=o+(c[b>>2]>>1<<1)|0;p=p+(c[m>>2]>>1<<1)|0;q=q+(c[n>>2]>>1<<1)|0;f=w;k=t;r=y;s=z}else{break}}}z=d+36|0;c[z>>2]=c[z>>2]|1;c[g>>2]=1;l=0;return l|0}function P1a(a){a=a|0;$Db(a+804|0);return 0}function Q1a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;d=a+120|0;e=a+124|0;c[b+4>>2]=cEb(ba(c[e>>2]|0,c[d>>2]|0)|0)|0;c[b+8>>2]=cEb(ba(c[e>>2]|0,c[d>>2]|0)|0)|0;return 0}function R1a(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;j=i;k=c[b+60>>2]|0;l=k;m=c[h+24>>2]|0;n=h+28|0;h=c[n>>2]|0;if(!((h|0)>-1)){yDb(0,0,1935928,(o=i,i=i+24|0,c[o>>2]=1912576,c[o+8>>2]=1892064,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}p=k+1036|0;c[p>>2]=m;c[k+1044>>2]=m;q=k+1040|0;c[q>>2]=m+h;h=_$a(b,f,0)|0;if((h|0)<0){r=h;i=j;return r|0}h=c[q>>2]|0;m=c[p>>2]|0;s=h;a:do{if((s-m|0)<2){t=0}else{u=m+2|0;c[p>>2]=u;v=m;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;if((w&1|0)==0){y=0;z=u}else{if((s-u|0)<2){A=0;B=u}else{v=m+4|0;c[p>>2]=v;C=u;A=(d[C]|d[C+1|0]<<8)<<16>>16<<16>>16;B=v}if((s-B|0)<2){D=0;E=B}else{v=B+2|0;c[p>>2]=v;C=B;D=(d[C]|d[C+1|0]<<8)<<16>>16<<16>>16;E=v}y=(ba(c[b+120>>2]|0,D)|0)+A|0;z=E}b:do{if((w&8|0)==0){F=h;G=z}else{do{if((s-z|0)>=4){v=z+4|0;c[p>>2]=v;C=z;u=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;if(u>>>0>(4-v+s|0)>>>0|u>>>0<4>>>0){break}C=k;H=c[C>>2]|0;I=c[H+120>>2]|0;J=c[k+8>>2]|0;K=c[H+124>>2]|0;H=J+(ba(K,I)|0)|0;L=I>>2;M=ba(K>>2,L)|0;c:do{if((M|0)>0){K=I*3|0;N=K+4|0;O=I<<1;P=O+4|0;Q=I+4|0;R=I+1|0;S=I+2|0;T=I+3|0;U=O|1;V=O+2|0;W=O+3|0;X=K+1|0;Y=K+2|0;Z=K+3|0;_=v;$=0;aa=0;ca=0;da=c[k+4>>2]|0;ea=J+y|0;d:while(1){do{if((ca&3|0)==0){if((s-_|0)<1){fa=_;ga=0;ha=21;break}ia=d[_]|0;ja=_+1|0;ha=20}else{ia=aa;ja=_;ha=20}}while(0);e:do{if((ha|0)==20){ha=0;ka=ia&192;if((ka|0)==192){do{if((s-ja|0)<1){la=ja;ma=1632}else{na=ja+1|0;oa=d[ja]|0;pa=oa>>>6;qa=e[159696+((oa&63)<<1)>>1]|0;if((pa|0)==3){ha=54;break d}else if((pa|0)==2){ra=qa}else if((pa|0)==0){la=na;ma=qa;break}else if((pa|0)==1){ra=~qa}else{sa=na;ta=ia;break e}if((s-na|0)<1){ua=0;va=na}else{ua=a[na]|0;va=ja+2|0}na=0;qa=ra;while(1){pa=ba(na,I)|0;do{if((qa&1|0)==0){ha=52}else{oa=ea+pa|0;if(!(oa>>>0>=J>>>0&oa>>>0<H>>>0)){ha=52;break}a[da+pa|0]=a[oa]|0}}while(0);if((ha|0)==52){ha=0;a[da+pa|0]=ua}oa=pa+1|0;do{if((qa&2|0)==0){ha=60}else{wa=ea+oa|0;if(!(wa>>>0>=J>>>0&wa>>>0<H>>>0)){ha=60;break}a[da+oa|0]=a[wa]|0}}while(0);if((ha|0)==60){ha=0;a[da+oa|0]=ua}wa=pa+2|0;do{if((qa&4|0)==0){ha=64}else{xa=ea+wa|0;if(!(xa>>>0>=J>>>0&xa>>>0<H>>>0)){ha=64;break}a[da+wa|0]=a[xa]|0}}while(0);if((ha|0)==64){ha=0;a[da+wa|0]=ua}oa=pa+3|0;do{if((qa&8|0)==0){ha=68}else{xa=ea+oa|0;if(!(xa>>>0>=J>>>0&xa>>>0<H>>>0)){ha=68;break}a[da+oa|0]=a[xa]|0}}while(0);if((ha|0)==68){ha=0;a[da+oa|0]=ua}pa=na+1|0;if((pa|0)<4){na=pa;qa=qa>>4}else{sa=va;ta=ia;break e}}}}while(0);if((s-la|0)<1){ya=0;za=la}else{ya=a[la]|0;za=la+1|0}if((s-za|0)<1){Aa=0;Ba=za}else{Aa=a[za]|0;Ba=za+1|0}a[da]=(ma&1|0)!=0?Aa:ya;a[da+1|0]=(ma&2|0)!=0?Aa:ya;a[da+2|0]=(ma&4|0)!=0?Aa:ya;a[da+3|0]=(ma&8|0)!=0?Aa:ya;a[da+I|0]=(ma&16|0)!=0?Aa:ya;a[da+R|0]=(ma&32|0)!=0?Aa:ya;a[da+S|0]=(ma&64|0)!=0?Aa:ya;a[da+T|0]=(ma&128|0)!=0?Aa:ya;a[da+O|0]=(ma&256|0)!=0?Aa:ya;a[da+U|0]=(ma&512|0)!=0?Aa:ya;a[da+V|0]=(ma&1024|0)!=0?Aa:ya;a[da+W|0]=(ma&2048|0)!=0?Aa:ya;a[da+K|0]=(ma&4096|0)!=0?Aa:ya;a[da+X|0]=(ma&8192|0)!=0?Aa:ya;a[da+Y|0]=(ma&16384|0)!=0?Aa:ya;a[da+Z|0]=(ma&32768|0)!=0?Aa:ya;sa=Ba;ta=ia;break}else if((ka|0)==64){do{if((s-ja|0)<1){Ca=ja}else{qa=ja+1|0;na=a[ja]|0;pa=na&255;if(na<<24>>24==0){Ca=qa;break}na=(ba(pa>>>4<<28>>28,I)|0)+(pa<<28>>28)|0;pa=ea+na|0;do{if(pa>>>0<J>>>0){ha=33}else{if((ea+(na+4)|0)>>>0>H>>>0){ha=33;break}wa=pa;xa=da;x=d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x}}while(0);if((ha|0)==33){ha=0;pa=da;x=0;a[pa]=x;x=x>>8;a[pa+1|0]=x;x=x>>8;a[pa+2|0]=x;x=x>>8;a[pa+3|0]=x}pa=na+I|0;xa=ea+pa|0;do{if(xa>>>0<J>>>0){Da=da+I|0;ha=73}else{wa=da+I|0;if((ea+(pa+4)|0)>>>0>H>>>0){Da=wa;ha=73;break}Ea=xa;Fa=wa;x=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x}}while(0);if((ha|0)==73){ha=0;xa=Da;x=0;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x}xa=na+O|0;pa=ea+xa|0;do{if(pa>>>0<J>>>0){Ga=da+O|0;ha=78}else{Fa=da+O|0;if((ea+(xa+4)|0)>>>0>H>>>0){Ga=Fa;ha=78;break}Ea=pa;wa=Fa;x=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0;a[wa]=x;x=x>>8;a[wa+1|0]=x;x=x>>8;a[wa+2|0]=x;x=x>>8;a[wa+3|0]=x}}while(0);if((ha|0)==78){ha=0;pa=Ga;x=0;a[pa]=x;x=x>>8;a[pa+1|0]=x;x=x>>8;a[pa+2|0]=x;x=x>>8;a[pa+3|0]=x}pa=na+K|0;xa=ea+pa|0;do{if(xa>>>0<J>>>0){Ha=da+K|0}else{wa=da+K|0;if((ea+(pa+4)|0)>>>0>H>>>0){Ha=wa;break}Ea=xa;Fa=wa;x=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;sa=qa;ta=ia;break e}}while(0);xa=Ha;x=0;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;sa=qa;ta=ia;break e}}while(0);if((s-Ca|0)>>>0<16>>>0){ha=29;break d}xa=Ca;pa=da;x=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;a[pa]=x;x=x>>8;a[pa+1|0]=x;x=x>>8;a[pa+2|0]=x;x=x>>8;a[pa+3|0]=x;pa=Ca+4|0;xa=s-pa|0;na=xa>>>0>4>>>0?4:xa;UGb(da+I|0,pa|0,na)|0;pa=na+4|0;na=Ca+pa|0;xa=s-na|0;Fa=xa>>>0>4>>>0?4:xa;UGb(da+O|0,na|0,Fa)|0;na=Fa+pa|0;pa=Ca+na|0;Fa=s-pa|0;xa=Fa>>>0>4>>>0?4:Fa;UGb(da+K|0,pa|0,xa)|0;sa=Ca+(xa+na)|0;ta=ia;break}else if((ka|0)==128){if((s-ja|0)<1){Ia=0;Ja=ja}else{Ia=a[ja]|0;Ja=ja+1|0}TGb(da|0,Ia|0,4)|0;TGb(da+I|0,Ia|0,4)|0;TGb(da+O|0,Ia|0,4)|0;TGb(da+K|0,Ia|0,4)|0;sa=Ja;ta=ia;break}else if((ka|0)==0){fa=ja;ga=ia;ha=21;break}else{sa=ja;ta=ia;break}}}while(0);f:do{if((ha|0)==21){ha=0;if(ea>>>0<J>>>0|(ea+4|0)>>>0>H>>>0){na=da;x=0;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x}else{na=ea;xa=da;x=d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x}xa=ea+I|0;do{if(xa>>>0<J>>>0){Ka=da+I|0;ha=87}else{na=da+I|0;if((ea+Q|0)>>>0>H>>>0){Ka=na;ha=87;break}pa=xa;Fa=na;x=d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x}}while(0);if((ha|0)==87){ha=0;xa=Ka;x=0;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x}xa=ea+O|0;do{if(xa>>>0<J>>>0){La=da+O|0;ha=92}else{ka=da+O|0;if((ea+P|0)>>>0>H>>>0){La=ka;ha=92;break}Fa=xa;pa=ka;x=d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0;a[pa]=x;x=x>>8;a[pa+1|0]=x;x=x>>8;a[pa+2|0]=x;x=x>>8;a[pa+3|0]=x}}while(0);if((ha|0)==92){ha=0;xa=La;x=0;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x}xa=ea+K|0;do{if(xa>>>0<J>>>0){Ma=da+K|0}else{pa=da+K|0;if((ea+N|0)>>>0>H>>>0){Ma=pa;break}Fa=xa;ka=pa;x=d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;sa=fa;ta=ga;break f}}while(0);xa=Ma;x=0;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;sa=fa;ta=ga}}while(0);xa=$+1|0;if((xa|0)==(L|0)){Na=ea+N|0;Oa=da+N|0;Pa=0}else{Na=ea+4|0;Oa=da+4|0;Pa=xa}xa=ca+1|0;if((xa|0)<(M|0)){_=sa;$=Pa;aa=ta<<2;ca=xa;da=Oa;ea=Na}else{break c}}if((ha|0)==29){yDb(c[C>>2]|0,16,2001120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((ha|0)==54){yDb(c[C>>2]|0,16,1964056,(o=i,i=i+8|0,c[o>>2]=ca,o)|0);i=o;break}}}while(0);C=u-4|0;M=c[q>>2]|0;L=c[p>>2]|0;H=M-L|0;J=L+(H>>>0>C>>>0?C:H)|0;c[p>>2]=J;F=M;G=J;break b}}while(0);yDb(b,16,2179104,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;r=-1;i=j;return r|0}}while(0);J=w&16;if((J|0)==0){t=0;break}M=F;if((M-G|0)<4){Qa=0;Ra=G}else{H=G+4|0;c[p>>2]=H;C=G;Qa=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;Ra=H}if((M-Ra|0)<1){Sa=0;Ta=Ra}else{H=Ra+1|0;c[p>>2]=H;Sa=d[Ra]|0;Ta=H}if((M-Ta|0)<1){Ua=255;Va=Ta}else{M=Ta+1|0;c[p>>2]=M;Ua=(d[Ta]|0)+255&255;Va=M}M=Ua+Sa|0;if((M|0)>255){yDb(c[k>>2]|0,16,2102872,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=J;break}if(((Ua*3|0)+2|0)>(Qa|0)){yDb(c[k>>2]|0,16,2046624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=J;break}else{Wa=Sa;Xa=F;Ya=Va}while(1){if((Xa-Ya|0)<3){Za=-16777216}else{c[p>>2]=Ya+3;Za=(d[Ya]|0)<<16|(d[Ya+1|0]|0)<<8|(d[Ya+2|0]|0)|-16777216}c[l+12+(Wa<<2)>>2]=Za;H=Wa+1|0;if((H|0)>(M|0)){t=J;break a}Wa=H;Xa=c[q>>2]|0;Ya=c[p>>2]|0}}}while(0);UGb(c[f+4>>2]|0,k+12|0,1024)|0;c[f+304>>2]=t;t=k+4|0;p=b+124|0;if((c[p>>2]|0)>0){Ya=b+120|0;b=f+32|0;q=0;Xa=c[t>>2]|0;Wa=c[f>>2]|0;f=c[Ya>>2]|0;while(1){UGb(Wa|0,Xa|0,f)|0;Za=c[Ya>>2]|0;l=q+1|0;if((l|0)<(c[p>>2]|0)){q=l;Xa=Xa+Za|0;Wa=Wa+(c[b>>2]|0)|0;f=Za}else{break}}}f=k+8|0;k=c[f>>2]|0;c[f>>2]=c[t>>2];c[t>>2]=k;c[g>>2]=1;r=c[n>>2]|0;i=j;return r|0}function S1a(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+4|0);$Db(b+8|0);return 0}function T1a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+60|0;e=c[d>>2]|0;c[e>>2]=a;Z3(e+4|0,a);c[a+140>>2]=0;c[a+796>>2]=8;f=QZ(0,c[a+120>>2]|0,c[a+124>>2]|0)|0;c[e+1248>>2]=f;g=WDb(f)|0;c[e+1252>>2]=g;if((g|0)!=0){h=0;i=b;return h|0}yDb(a,16,2001080,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;$Db((c[d>>2]|0)+1252|0);h=-12;i=b;return h|0}function U1a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;i=i+24|0;j=h|0;k=c[b+60>>2]|0;l=k;m=e;n=c[g+24>>2]|0;o=b+120|0;p=(c[o>>2]|0)/2|0;q=b+124|0;r=(c[q>>2]|0)/2|0;s=g+28|0;g=c[s>>2]|0;if((g|0)<4|(g-4|0)>268435455){yDb(b,16,2179064,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}g=_$a(b,m,0)|0;if((g|0)<0){u=g;i=h;return u|0}c[e+84>>2]=1;c[e+88>>2]=1;e=n;g=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if((g|0)!=1){yDb(b,24,2102840,(t=i,i=i+8|0,c[t>>2]=g,t)|0);i=t}g=n+4|0;n=(c[s>>2]<<3)-32|0;e=n>>>0>2147483639>>>0|(g|0)==0;v=e?0:g;g=e?0:n;c[j>>2]=v;c[j+12>>2]=g;n=g+8|0;c[j+16>>2]=n;c[j+4>>2]=v+(g>>3);e=j+8|0;c[e>>2]=0;w=k+1248|0;a:do{if((c[w>>2]|0)>0){x=k+1252|0;y=0;z=0;A=0;while(1){B=v+(A>>>3)|0;C=(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)>>>((A&7)>>>0)&255;if((C|0)==0){B=A+8|0;D=n>>>0>B>>>0?B:n;B=d[v+(D>>>3)|0]|0;E=((D|0)<(n|0))+D|0;c[e>>2]=E;if((1<<(D&7)&B|0)==0){break a}a[(c[x>>2]|0)+y|0]=8;F=E}else{E=a[159440+C|0]|0;C=A+1+(E&255)|0;B=n>>>0>C>>>0?C:n;c[e>>2]=B;a[(c[x>>2]|0)+y|0]=E;F=B}B=(d[(c[x>>2]|0)+y|0]|0)+z|0;E=y+1|0;if((E|0)<(c[w>>2]|0)){y=E;z=B;A=F}else{G=B;H=F;I=13;break}}}else{G=0;H=0;I=13}}while(0);do{if((I|0)==13){if((g-H|0)<(G|0)){break}W1a(l,m,j,0,0,c[o>>2]|0,c[q>>2]|0);if((c[(c[k>>2]|0)+88>>2]&8192|0)==0){F=ba(c[q>>2]|0,c[o>>2]|0)|0;W1a(l,m,j,1,F,p,r);W1a(l,m,j,2,F+(ba(r,p)|0)|0,p,r)}c[f>>2]=1;u=c[s>>2]|0;i=h;return u|0}}while(0);yDb(b,16,2046608,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}function V1a(a){a=a|0;$Db((c[a+60>>2]|0)+1252|0);return 0}function W1a(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;l=i;i=i+16|0;m=l|0;n=l+8|0;o=c[e+(g<<2)>>2]|0;p=(c[b+1252>>2]|0)+h|0;h=c[e+32+(g<<2)>>2]|0;if((k|0)<=0){i=l;return}g=(j|0)>1;e=-h|0;q=b+1088|0;b=f+8|0;r=f+16|0;s=f|0;if((j|0)>0){t=p;u=0;v=o}else{f=p;p=0;w=o;while(1){do{if((p|0)==0){o=a[f]|0;a[w]=o;if(g){x=1;y=o}else{break}do{y=y+(a[f+x|0]|0)&255;a[w+x|0]=y;x=x+1|0;}while((x|0)<(j|0))}else{c[m>>2]=0;o=w+e|0;c[n>>2]=d[o]|0;Se[c[q>>2]&511](w,o,f,j,m,n)}}while(0);o=p+1|0;if((o|0)<(k|0)){f=f+j|0;p=o;w=w+h|0}else{break}}i=l;return}while(1){w=0;do{p=t+w|0;f=a[p]|0;if(!(f<<24>>24==0)){x=f&255;f=c[b>>2]|0;y=c[r>>2]|0;o=(c[s>>2]|0)+(f>>>3)|0;z=32-x|0;A=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((f&7)>>>0)<<z>>>(z>>>0);z=f+x|0;c[b>>2]=y>>>0>z>>>0?z:y;y=(1<<x)-1+A|0;a[p]=y>>>1^-(y&1)}w=w+1|0;}while((w|0)<(j|0));do{if((u|0)==0){w=a[t]|0;a[v]=w;if(g){B=1;C=w}else{break}do{C=C+(a[t+B|0]|0)&255;a[v+B|0]=C;B=B+1|0;}while((B|0)<(j|0))}else{c[m>>2]=0;w=v+e|0;c[n>>2]=d[w]|0;Se[c[q>>2]&511](v,w,t,j,m,n)}}while(0);w=u+1|0;if((w|0)<(k|0)){t=t+j|0;u=w;v=v+h|0}else{break}}i=l;return}function X1a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;f=i;g=a;h=e|0;j=c[h>>2]|0;k=e+8|0;l=c[k>>2]|0;m=e+16|0;e=c[m>>2]|0;n=j+(l>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(l&7)&-65536;n=l+16|0;l=e>>>0>n>>>0?n:e;e=j+(l>>>3)|0;j=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(l&7)>>>16|o;yDb(g,48,2203200,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;j=c[k>>2]|0;l=c[m>>2]|0;e=(c[h>>2]|0)+(j>>>3)|0;n=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(j&7)>>>30;e=j+2|0;c[k>>2]=l>>>0>e>>>0?e:l;l=b+15660|0;c[l>>2]=n;if((n|0)==2){yDb(g,24,2312512,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=c[l>>2]|0}else{p=n}if((p|0)==3){c[b+15996>>2]=1099904;c[b+16e3>>2]=1099936;c[b+15608>>2]=1;p=c[k>>2]|0;n=c[m>>2]|0;e=c[h>>2]|0;j=e+(p>>>3)|0;q=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(p&7);j=q>>>29;r=p+3|0;c[k>>2]=n>>>0>r>>>0?r:n;n=b+15616|0;c[n>>2]=j;if(q>>>0>2684354559>>>0){yDb(c[b+4>>2]|0,16,2083064,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;s=c[h>>2]|0}else{s=e}e=c[k>>2]|0;j=c[m>>2]|0;q=s+(e>>>3)|0;r=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(e&7)>>>30;q=e+2|0;c[k>>2]=j>>>0>q>>>0?q:j;j=b+15620|0;c[j>>2]=r;if((r|0)!=1){yDb(c[b+4>>2]|0,16,2077312,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}r=c[k>>2]|0;q=c[m>>2]|0;e=s+(r>>>3)|0;p=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(r&7)>>>29;e=r+3|0;c[k>>2]=q>>>0>e>>>0?e:q;q=b+15664|0;c[q>>2]=p;p=c[k>>2]|0;e=c[m>>2]|0;r=s+(p>>>3)|0;u=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(p&7)>>>27;r=p+5|0;c[k>>2]=e>>>0>r>>>0?r:e;e=b+15668|0;c[e>>2]=u;u=c[k>>2]|0;r=(d[s+(u>>>3)|0]|0)<<(u&7)>>>7;c[k>>2]=((u|0)<(c[m>>2]|0))+u;c[b+15624>>2]=r&1;r=c[k>>2]|0;u=c[m>>2]|0;p=s+(r>>>3)|0;v=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>20;p=r+12|0;c[k>>2]=u>>>0>p>>>0?p:u;c[b+15672>>2]=(v<<1)+2;v=c[k>>2]|0;u=c[m>>2]|0;p=s+(v>>>3)|0;r=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(v&7)>>>20;p=v+12|0;c[k>>2]=u>>>0>p>>>0?p:u;c[b+15676>>2]=(r<<1)+2;r=c[k>>2]|0;u=(d[s+(r>>>3)|0]|0)<<(r&7)>>>7;c[k>>2]=((r|0)<(c[m>>2]|0))+r;r=b+15628|0;c[r>>2]=u&1;u=c[k>>2]|0;p=(d[s+(u>>>3)|0]|0)<<(u&7)>>>7;c[k>>2]=((u|0)<(c[m>>2]|0))+u;u=b+15632|0;c[u>>2]=p&1;p=c[k>>2]|0;v=(d[s+(p>>>3)|0]|0)<<(p&7)>>>7;c[k>>2]=((p|0)<(c[m>>2]|0))+p;p=b+15636|0;c[p>>2]=v&1;v=c[k>>2]|0;w=(d[s+(v>>>3)|0]|0)<<(v&7)>>>7;c[k>>2]=((v|0)<(c[m>>2]|0))+v;v=b+15704|0;c[v>>2]=w&1;w=c[m>>2]|0;s=(c[k>>2]|0)+1|0;c[k>>2]=w>>>0>s>>>0?s:w;w=b+4|0;s=c[q>>2]|0;q=c[e>>2]|0;e=c[b+13836>>2]|0;x=c[j>>2]|0;j=c[r>>2]|0;y=c[u>>2]|0;u=c[p>>2]|0;p=c[v>>2]|0;yDb(c[w>>2]|0,48,2072528,(o=i,i=i+72|0,c[o>>2]=c[n>>2],c[o+8>>2]=s,c[o+16>>2]=q,c[o+24>>2]=e,c[o+32>>2]=x,c[o+40>>2]=j,c[o+48>>2]=y,c[o+56>>2]=u,c[o+64>>2]=p,o)|0);i=o;p=c[k>>2]|0;u=c[h>>2]|0;y=(d[u+(p>>>3)|0]|0)<<(p&7)>>>7;c[k>>2]=((p|0)<(c[m>>2]|0))+p;p=y&1;c[b+15656>>2]=p;y=c[w>>2]|0;if((p|0)!=0){yDb(y,16,2067920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}c[y+156>>2]=7;c[b+68>>2]=7;p=c[k>>2]|0;j=d[u+(p>>>3)|0]|0;x=c[m>>2]|0;e=((p|0)<(x|0))+p|0;c[k>>2]=e;do{if((j&128>>>((p&7)>>>0)|0)==0){z=e;A=u;B=x}else{yDb(y,48,2063560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;q=c[k>>2]|0;s=c[m>>2]|0;n=c[h>>2]|0;v=n+(q>>>3)|0;C=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(q&7)>>>18;v=q+14|0;q=s>>>0>v>>>0?v:s;c[k>>2]=q;v=C+1|0;C=n+(q>>>3)|0;n=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(q&7)>>>18;C=q+14|0;c[k>>2]=s>>>0>C>>>0?C:s;s=n+1|0;yDb(c[w>>2]|0,48,2059832,(o=i,i=i+16|0,c[o>>2]=v,c[o+8>>2]=s,o)|0);i=o;n=c[k>>2]|0;C=c[h>>2]|0;q=d[C+(n>>>3)|0]|0;D=c[m>>2]|0;E=((n|0)<(D|0))+n|0;c[k>>2]=E;do{if((q&128>>>((n&7)>>>0)|0)==0){F=16}else{G=C+(E>>>3)|0;H=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7);G=H>>>28;I=E+4|0;J=D>>>0>I>>>0?I:D;c[k>>2]=J;if((G|0)!=0&H>>>0<3758096384>>>0){H=1094920+(G<<3)|0;I=(c[w>>2]|0)+224|0;K=c[H+4>>2]|0;c[I>>2]=c[H>>2];c[I+4>>2]=K;break}if((G|0)!=15){F=16;break}G=C+(J>>>3)|0;K=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(J&7)>>>24;G=J+8|0;J=D>>>0>G>>>0?G:D;c[k>>2]=J;G=C+(J>>>3)|0;I=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(J&7)>>>24;G=J+8|0;c[k>>2]=D>>>0>G>>>0?G:D;G=c[w>>2]|0;c[G+224>>2]=K+1;c[G+228>>2]=I+1}}while(0);if((F|0)==16){D=c[w>>2]|0;C=ba(c[D+124>>2]|0,v)|0;E=ba(c[D+120>>2]|0,s)|0;iFb(D+224|0,D+228|0,C,(C|0)<0|0?-1:0,E,(E|0)<0|0?-1:0,1073741824,0)|0}E=c[w>>2]|0;C=c[E+228>>2]|0;yDb(E,48,2054952,(o=i,i=i+16|0,c[o>>2]=c[E+224>>2],c[o+8>>2]=C,o)|0);i=o;C=c[k>>2]|0;E=c[h>>2]|0;D=d[E+(C>>>3)|0]|0;n=c[m>>2]|0;q=((C|0)<(n|0))+C|0;c[k>>2]=q;do{if((D&128>>>((C&7)>>>0)|0)!=0){I=d[E+(q>>>3)|0]|0;G=((q|0)<(n|0))+q|0;c[k>>2]=G;do{if((I&128>>>((q&7)>>>0)|0)==0){K=E+(G>>>3)|0;J=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(G&7)>>>24;K=G+8|0;H=n>>>0>K>>>0?K:n;c[k>>2]=H;K=E+(H>>>3)|0;L=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0;K=H+4|0;c[k>>2]=n>>>0>K>>>0?K:n;K=J-1|0;if(!(K>>>0<7>>>0)){break}J=((fe(L|0)|0)<<(H&7)>>>28)-1|0;if(!(J>>>0<2>>>0)){break}H=c[w>>2]|0;c[H+104>>2]=c[1098424+(J<<2)>>2];c[H+108>>2]=(c[1098392+(K<<2)>>2]|0)*1e3|0}else{K=c[w>>2]|0;c[K+104>>2]=32;H=c[k>>2]|0;J=c[m>>2]|0;L=E+(H>>>3)|0;M=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(H&7)>>>16;L=H+16|0;c[k>>2]=J>>>0>L>>>0?L:J;c[K+108>>2]=M+1}}while(0);if((c[r>>2]|0)==0){break}G=c[w>>2]|0;I=G+108|0;c[I>>2]=c[I>>2]<<1;c[G+112>>2]=2}}while(0);n=c[k>>2]|0;q=d[E+(n>>>3)|0]|0;C=c[m>>2]|0;D=((n|0)<(C|0))+n|0;c[k>>2]=D;if((q&128>>>((n&7)>>>0)|0)==0){z=D;A=E;B=C;break}n=E+(D>>>3)|0;q=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(D&7)>>>24;n=D+8|0;D=C>>>0>n>>>0?n:C;c[k>>2]=D;n=c[w>>2]|0;c[n+384>>2]=q;q=E+(D>>>3)|0;s=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(D&7)>>>24;q=D+8|0;D=C>>>0>q>>>0?q:C;c[k>>2]=D;c[n+388>>2]=s;s=E+(D>>>3)|0;q=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(D&7)>>>24;s=D+8|0;D=C>>>0>s>>>0?s:C;c[k>>2]=D;c[n+392>>2]=q;c[n+396>>2]=1;z=D;A=E;B=C}}while(0);w=(d[A+(z>>>3)|0]|0)<<(z&7)>>>7;c[k>>2]=((z|0)<(B|0))+z;z=w&1;c[b+15652>>2]=z;if((z|0)==0){t=0;i=f;return t|0}z=c[k>>2]|0;w=c[m>>2]|0;B=A+(z>>>3)|0;A=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7)>>>27;B=z+5|0;c[k>>2]=w>>>0>B>>>0?B:w;w=b+19244|0;c[w>>2]=A;A=c[m>>2]|0;B=(c[k>>2]|0)+4|0;z=(A>>>0>B>>>0?B:A)+4|0;B=A>>>0>z>>>0?z:A;c[k>>2]=B;if((c[w>>2]|0)>0){N=0;O=B}else{t=0;i=f;return t|0}while(1){B=O+16|0;z=(A>>>0>B>>>0?B:A)+16|0;B=A>>>0>z>>>0?z:A;c[k>>2]=B;z=N+1|0;if((z|0)<(c[w>>2]|0)){N=z;O=B}else{t=0;break}}i=f;return t|0}c[b+15620>>2]=1;c[b+15996>>2]=1080128;c[b+16e3>>2]=1080064;O=c[k>>2]|0;N=c[h>>2]|0;w=(d[N+(O>>>3)|0]|0)<<(O&7)>>>7;c[k>>2]=((O|0)<(c[m>>2]|0))+O;O=b+15584|0;c[O>>2]=w&1;w=c[k>>2]|0;A=(d[N+(w>>>3)|0]|0)<<(w&7)>>>7;c[k>>2]=((w|0)<(c[m>>2]|0))+w;w=b+15580|0;c[w>>2]=A&1;if((c[O>>2]|0)!=0){yDb(g,16,2179024,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}O=c[k>>2]|0;A=c[m>>2]|0;B=N+(O>>>3)|0;z=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(O&7)>>>29;B=O+3|0;c[k>>2]=A>>>0>B>>>0?B:A;A=b+15664|0;c[A>>2]=z;z=c[k>>2]|0;B=c[m>>2]|0;O=N+(z>>>3)|0;r=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(z&7)>>>27;O=z+5|0;c[k>>2]=B>>>0>O>>>0?O:B;B=b+15668|0;c[B>>2]=r;r=c[k>>2]|0;O=(d[N+(r>>>3)|0]|0)<<(r&7)>>>7;c[k>>2]=((r|0)<(c[m>>2]|0))+r;r=O&1;O=b+13836|0;c[O>>2]=r;do{if((r|0)!=0){if((c[l>>2]|0)!=0){break}yDb(g,16,2102784,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);r=b+4|0;if((c[(c[r>>2]|0)+848>>2]|0)>47){c[O>>2]=0}N=c[k>>2]|0;z=c[h>>2]|0;y=(d[z+(N>>>3)|0]|0)<<(N&7)>>>7;c[k>>2]=((N|0)<(c[m>>2]|0))+N;N=b+15588|0;c[N>>2]=y&1;y=c[k>>2]|0;x=(d[z+(y>>>3)|0]|0)<<(y&7)>>>7;c[k>>2]=((y|0)<(c[m>>2]|0))+y;y=b+15592|0;c[y>>2]=x&1;x=c[k>>2]|0;u=(d[z+(x>>>3)|0]|0)<<(x&7)>>>7;c[k>>2]=((x|0)<(c[m>>2]|0))+x;x=u&1;u=b+15596|0;c[u>>2]=x;if((x|0)==0){c[b+15332>>2]=258;c[b+15336>>2]=1746;c[b+15340>>2]=2014;c[b+15344>>2]=636;c[b+15348>>2]=246;c[b+15352>>2]=1746;c[b+15356>>2]=2014;c[b+15360>>2]=636;P=c[h>>2]|0}else{P=z}z=c[k>>2]|0;x=(d[P+(z>>>3)|0]|0)<<(z&7)>>>7;c[k>>2]=((z|0)<(c[m>>2]|0))+z;z=x&1;x=b+15680|0;c[x>>2]=z;if((z|c[l>>2]|0)==0){yDb(g,16,2046568,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}z=c[k>>2]|0;e=(d[P+(z>>>3)|0]|0)<<(z&7)>>>7;c[k>>2]=((z|0)<(c[m>>2]|0))+z;z=e&1;e=b+15684|0;c[e>>2]=z;if(!((c[l>>2]|0)!=0|(z|0)==0)){yDb(g,16,2001032,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}z=c[k>>2]|0;p=c[m>>2]|0;j=P+(z>>>3)|0;C=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(z&7)>>>30;j=z+2|0;c[k>>2]=p>>>0>j>>>0?j:p;p=b+15688|0;c[p>>2]=C;C=c[k>>2]|0;j=(d[P+(C>>>3)|0]|0)<<(C&7)>>>7;c[k>>2]=((C|0)<(c[m>>2]|0))+C;C=b+15692|0;c[C>>2]=j&1;j=c[k>>2]|0;z=(d[P+(j>>>3)|0]|0)<<(j&7)>>>7;c[k>>2]=((j|0)<(c[m>>2]|0))+j;j=z&1;c[b+15600>>2]=j;if((j|0)!=0){yDb(g,16,1964008,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}j=c[k>>2]|0;z=(d[P+(j>>>3)|0]|0)<<(j&7)>>>7;c[k>>2]=((j|0)<(c[m>>2]|0))+j;j=b+15696|0;c[j>>2]=z&1;z=c[k>>2]|0;D=(d[P+(z>>>3)|0]|0)<<(z&7)>>>7;c[k>>2]=((z|0)<(c[m>>2]|0))+z;z=b+19616|0;c[z>>2]=D&1;D=c[k>>2]|0;n=(d[P+(D>>>3)|0]|0)<<(D&7)>>>7;c[k>>2]=((D|0)<(c[m>>2]|0))+D;D=n&1;n=b+15604|0;c[n>>2]=D;do{if((D|0)==0){Q=P}else{if((c[l>>2]|0)!=0){Q=P;break}yDb(g,32,1935840,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;Q=c[h>>2]|0}}while(0);P=c[k>>2]|0;D=c[m>>2]|0;q=Q+(P>>>3)|0;s=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(P&7)>>>29;q=P+3|0;c[k>>2]=D>>>0>q>>>0?q:D;D=a+156|0;c[D>>2]=s;c[b+68>>2]=s;s=c[k>>2]|0;a=c[m>>2]|0;q=Q+(s>>>3)|0;P=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(s&7)>>>30;q=s+2|0;c[k>>2]=a>>>0>q>>>0?q:a;a=b+15700|0;c[a>>2]=P;P=c[k>>2]|0;q=(d[Q+(P>>>3)|0]|0)<<(P&7)>>>7;c[k>>2]=((P|0)<(c[m>>2]|0))+P;c[b+15704>>2]=q&1;q=c[k>>2]|0;do{if((c[w>>2]|0)==0){P=(d[Q+(q>>>3)|0]|0)<<(q&7)>>>7;c[k>>2]=((q|0)<(c[m>>2]|0))+q;s=P&1;c[b+15608>>2]=s;if((s|0)==0){F=53}}else{s=c[m>>2]|0;P=Q+(q>>>3)|0;v=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(q&7)>>>21;P=q+11|0;G=s>>>0>P>>>0?P:s;c[k>>2]=G;P=Q+(G>>>3)|0;I=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(G&7)>>>21;P=G+11|0;c[k>>2]=s>>>0>P>>>0?P:s;U$a(c[r>>2]|0,v,I);I=c[m>>2]|0;v=(c[k>>2]|0)+5|0;s=I>>>0>v>>>0?v:I;c[k>>2]=s;v=c[h>>2]|0;P=(d[v+(s>>>3)|0]|0)<<(s&7)>>>7;c[k>>2]=((s|0)<(I|0))+s;c[N>>2]=P&1;P=c[k>>2]|0;s=d[v+(P>>>3)|0]|0;v=c[m>>2]|0;I=((P|0)<(v|0))+P|0;c[k>>2]=I;if((s&128>>>((P&7)>>>0)|0)==0){P=I+3|0;c[k>>2]=v>>>0>P>>>0?P:v;c[b+15608>>2]=0;F=53;break}yDb(g,16,1912536,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}}while(0);if((F|0)==53){yDb(g,16,1891992,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}if((c[u>>2]|0)==0){u=c[m>>2]|0;m=(c[k>>2]|0)+16|0;c[k>>2]=u>>>0>m>>>0?m:u}u=c[A>>2]|0;A=c[B>>2]|0;B=c[O>>2]|0;O=c[y>>2]|0;y=c[x>>2]|0;x=c[e>>2]|0;e=c[n>>2]|0;n=c[C>>2]|0;C=c[j>>2]|0;j=c[z>>2]|0;z=c[p>>2]|0;p=c[a>>2]|0;a=c[D>>2]|0;yDb(g,48,2349552,(o=i,i=i+112|0,c[o>>2]=c[l>>2],c[o+8>>2]=u,c[o+16>>2]=A,c[o+24>>2]=B,c[o+32>>2]=O,c[o+40>>2]=y,c[o+48>>2]=x,c[o+56>>2]=e,c[o+64>>2]=n,c[o+72>>2]=C,c[o+80>>2]=j,c[o+88>>2]=z,c[o+96>>2]=p,c[o+104>>2]=a,o)|0);i=o;t=0;i=f;return t|0}function Y1a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=i;h=b;j=f|0;k=c[j>>2]|0;l=f+8|0;m=c[l>>2]|0;n=f+16|0;f=c[n>>2]|0;o=k+(m>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(m&7)&-65536;o=m+16|0;m=f>>>0>o>>>0?o:f;f=k+(m>>>3)|0;k=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(m&7)>>>16|p;yDb(h,48,2329448,(p=i,i=i+8|0,c[p>>2]=k,p)|0);i=p;k=c[l>>2]|0;m=(d[(c[j>>2]|0)+(k>>>3)|0]|0)<<(k&7)>>>7;c[l>>2]=((k|0)<(c[n>>2]|0))+k;k=e+19605|0;a[k]=m&1;m=c[l>>2]|0;f=(d[(c[j>>2]|0)+(m>>>3)|0]|0)<<(m&7)>>>7;c[l>>2]=((m|0)<(c[n>>2]|0))+m;m=e+19606|0;a[m]=f&1;f=c[l>>2]|0;o=c[j>>2]|0;q=(d[o+(f>>>3)|0]|0)<<(f&7)>>>7;c[l>>2]=((f|0)<(c[n>>2]|0))+f;f=e+15640|0;c[f>>2]=q&1;q=c[l>>2]|0;r=(d[o+(q>>>3)|0]|0)<<(q&7)>>>7;c[l>>2]=((q|0)<(c[n>>2]|0))+q;q=e+15644|0;c[q>>2]=r&1;r=c[l>>2]|0;s=(d[o+(r>>>3)|0]|0)<<(r&7)>>>7;c[l>>2]=((r|0)<(c[n>>2]|0))+r;r=e+13836|0;c[r>>2]=s&1;if((c[(c[e+4>>2]|0)+848>>2]|0)>47){c[r>>2]=0}s=c[l>>2]|0;t=(d[o+(s>>>3)|0]|0)<<(s&7)>>>7;c[l>>2]=((s|0)<(c[n>>2]|0))+s;s=e+15680|0;c[s>>2]=t&1;t=c[l>>2]|0;u=(d[o+(t>>>3)|0]|0)<<(t&7)>>>7;c[l>>2]=((t|0)<(c[n>>2]|0))+t;t=e+15684|0;c[t>>2]=u&1;u=c[l>>2]|0;v=c[n>>2]|0;w=o+(u>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>30;w=u+2|0;c[l>>2]=v>>>0>w>>>0?w:v;v=e+15688|0;c[v>>2]=x;x=c[l>>2]|0;w=(d[o+(x>>>3)|0]|0)<<(x&7)>>>7;c[l>>2]=((x|0)<(c[n>>2]|0))+x;x=e+15692|0;c[x>>2]=w&1;w=c[l>>2]|0;u=(d[o+(w>>>3)|0]|0)<<(w&7)>>>7;c[l>>2]=((w|0)<(c[n>>2]|0))+w;w=e+15696|0;c[w>>2]=u&1;u=c[l>>2]|0;y=c[n>>2]|0;z=o+(u>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(u&7)>>>30;z=u+2|0;c[l>>2]=y>>>0>z>>>0?z:y;y=e+15700|0;c[y>>2]=A;do{if((c[e+15652>>2]|0)!=0){A=e+19244|0;if((c[A>>2]|0)<=0){break}z=c[n>>2]|0;u=0;B=c[l>>2]|0;do{C=B+8|0;B=z>>>0>C>>>0?C:z;c[l>>2]=B;u=u+1|0;}while((u|0)<(c[A>>2]|0))}}while(0);A=c[l>>2]|0;u=d[o+(A>>>3)|0]|0;B=c[n>>2]|0;z=((A|0)<(B|0))+A|0;c[l>>2]=z;if((u&128>>>((A&7)>>>0)|0)==0){D=c[e+15676>>2]|0;E=c[e+15672>>2]|0}else{A=o+(z>>>3)|0;u=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7)>>>20;A=z+12|0;z=B>>>0>A>>>0?A:B;c[l>>2]=z;A=o+(z>>>3)|0;o=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7)>>>20;A=z+12|0;c[l>>2]=B>>>0>A>>>0?A:B;D=(o<<1)+2|0;E=(u<<1)+2|0}U$a(b,E,D);if((c[t>>2]|0)==0){F=c[j>>2]|0}else{D=c[l>>2]|0;E=c[j>>2]|0;b=(d[E+(D>>>3)|0]|0)<<(D&7)>>>7;c[l>>2]=((D|0)<(c[n>>2]|0))+D;c[e+15648>>2]=b&1;F=E}E=c[l>>2]|0;b=(d[F+(E>>>3)|0]|0)<<(E&7)>>>7;c[l>>2]=((E|0)<(c[n>>2]|0))+E;E=b&1;a[e+19284|0]=E;if(!(E<<24>>24==0)){yDb(h,16,2304984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;E=c[l>>2]|0;b=c[n>>2]|0;F=(c[j>>2]|0)+(E>>>3)|0;D=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>29;F=E+3|0;c[l>>2]=b>>>0>F>>>0?F:b;a[e+19286|0]=D}D=c[l>>2]|0;b=(d[(c[j>>2]|0)+(D>>>3)|0]|0)<<(D&7)>>>7;c[l>>2]=((D|0)<(c[n>>2]|0))+D;D=b&1;a[e+19285|0]=D;if(D<<24>>24==0){G=a[k]|0;H=G&255;I=a[m]|0;J=I&255;K=c[f>>2]|0;L=c[q>>2]|0;M=c[r>>2]|0;N=c[s>>2]|0;O=c[t>>2]|0;P=c[v>>2]|0;Q=c[x>>2]|0;R=c[w>>2]|0;S=c[y>>2]|0;yDb(h,48,2271016,(p=i,i=i+88|0,c[p>>2]=H,c[p+8>>2]=J,c[p+16>>2]=K,c[p+24>>2]=L,c[p+32>>2]=M,c[p+40>>2]=N,c[p+48>>2]=O,c[p+56>>2]=P,c[p+64>>2]=Q,c[p+72>>2]=R,c[p+80>>2]=S,p)|0);i=p;i=g;return 0}yDb(h,16,2287160,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;D=c[l>>2]|0;b=c[n>>2]|0;n=(c[j>>2]|0)+(D>>>3)|0;j=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(D&7)>>>29;n=D+3|0;c[l>>2]=b>>>0>n>>>0?n:b;a[e+19287|0]=j;G=a[k]|0;H=G&255;I=a[m]|0;J=I&255;K=c[f>>2]|0;L=c[q>>2]|0;M=c[r>>2]|0;N=c[s>>2]|0;O=c[t>>2]|0;P=c[v>>2]|0;Q=c[x>>2]|0;R=c[w>>2]|0;S=c[y>>2]|0;yDb(h,48,2271016,(p=i,i=i+88|0,c[p>>2]=H,c[p+8>>2]=J,c[p+16>>2]=K,c[p+24>>2]=L,c[p+32>>2]=M,c[p+40>>2]=N,c[p+48>>2]=O,c[p+56>>2]=P,c[p+64>>2]=Q,c[p+72>>2]=R,c[p+80>>2]=S,p)|0);i=p;i=g;return 0}function Z1a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=i;i=i+1024|0;h=g|0;j=g+512|0;c[e+19428>>2]=0;c[e+19224>>2]=0;if((c[e+15704>>2]|0)!=0){k=f+8|0;l=c[k>>2]|0;m=d[(c[f>>2]|0)+(l>>>3)|0]<<(l&7)>>>7;c[k>>2]=((l|0)<(c[f+16>>2]|0))+l;a[e+19221|0]=m&1}m=e+4|0;l=c[m>>2]|0;if((c[l+12>>2]|0)==0){n=-1;i=g;return n|0}k=f+8|0;o=c[k>>2]|0;p=f+16|0;q=c[p>>2]|0;if((c[l+48>>2]|0)==168){r=(c[f>>2]|0)+(o>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(o&7);r=o+2|0;c[k>>2]=q>>>0>r>>>0?r:q;r=(s&-1073741824|0)==1073741824;s=r&1;c[e+15592>>2]=s;c[e+15604>>2]=s;a[e+16073|0]=r&1;t=s}else{s=o+2|0;c[k>>2]=q>>>0>s>>>0?s:q;t=c[e+15604>>2]|0}q=e+19220|0;a[q]=0;if((t|0)==0){u=f|0}else{t=c[k>>2]|0;s=f|0;f=d[(c[s>>2]|0)+(t>>>3)|0]<<(t&7)>>>7;c[k>>2]=((t|0)<(c[p>>2]|0))+t;a[q]=f&1;u=s}s=c[k>>2]|0;f=c[u>>2]|0;q=d[f+(s>>>3)|0]<<(s&7)>>>7;c[k>>2]=((s|0)<(c[p>>2]|0))+s;s=q&1;q=e+9992|0;c[q>>2]=s;a:do{if((c[l+156>>2]|0)==0){t=s+1|0;c[q>>2]=t;o=e+19548|0;c[o>>2]=0;if((t|0)==3){v=o;w=18}else{x=t;y=o;w=23}}else{do{if((s|0)==0){o=c[k>>2]|0;t=d[f+(o>>>3)|0]|0;c[k>>2]=((o|0)<(c[p>>2]|0))+o;if((t&128>>>((o&7)>>>0)|0)==0){c[q>>2]=3;o=e+19548|0;c[o>>2]=0;v=o;w=18;break a}else{z=1;A=1;break}}else{z=2;A=2}}while(0);c[q>>2]=A;o=e+19548|0;c[o>>2]=0;x=z;y=o;w=23}}while(0);do{if((w|0)==18){z=c[1346959]|0;A=c[k>>2]|0;s=c[p>>2]|0;o=f+(A>>>3)|0;t=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(A&7)>>>25;o=b[z+(t<<2)>>1]|0;r=(b[z+(t<<2)+2>>1]|0)+A|0;c[k>>2]=s>>>0>r>>>0?r:s;if(o<<16>>16==21|o<<16>>16<0){yDb(l,16,2087624,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;n=-1094995529;i=g;return n|0}a[e+19604|0]=o;s=b[1099752+((o&255)<<1)>>1]|0;b[e+16070>>1]=s;if(s<<16>>16==0){c[q>>2]=7;C=v;w=24;break}else{x=c[q>>2]|0;y=v;w=23;break}}}while(0);if((w|0)==23){if((x|0)==1|(x|0)==7){C=y;w=24}else{D=y}}if((w|0)==24){y=c[p>>2]|0;x=(c[k>>2]|0)+7|0;c[k>>2]=y>>>0>x>>>0?x:y;D=C}if((c[e+19612>>2]|0)!=0){n=0;i=g;return n|0}C=c[q>>2]|0;if((C|0)==2){w=28}else if((C|0)==1|(C|0)==7){c[e+19216>>2]=1;if((C|0)==2){w=28}}if((w|0)==28){C=e+19216|0;c[C>>2]=c[C>>2]^1}C=c[k>>2]|0;y=c[p>>2]|0;x=(c[u>>2]|0)+(C>>>3)|0;v=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(C&7);x=v>>>27;l=C+5|0;c[k>>2]=y>>>0>l>>>0?l:y;if((x|0)==0){n=-1;i=g;return n|0}y=e+15700|0;l=c[y>>2]|0;if((l|0)==0){a[e+15728|0]=a[1094824+x|0]|0;E=v>>>0<1207959552>>>0}else{a[e+15728|0]=a[1094856+x|0]|0;E=(l|0)!=2}C=e+16081|0;a[C]=E&1;c[e+16040>>2]=x;if(v>>>0<1207959552>>>0){v=c[k>>2]|0;x=d[(c[u>>2]|0)+(v>>>3)|0]<<(v&7)>>>7;c[k>>2]=((v|0)<(c[p>>2]|0))+v;a[e+16072|0]=x&1;F=c[y>>2]|0}else{a[e+16072|0]=0;F=l}if((F|0)==1){F=c[k>>2]|0;l=d[(c[u>>2]|0)+(F>>>3)|0]<<(F&7)>>>7;c[k>>2]=((F|0)<(c[p>>2]|0))+F;a[C]=l&1}a[e+16004|0]=0;if((c[e+15684>>2]|0)==1){l=0;while(1){if((l|0)>=3){break}C=c[k>>2]|0;F=d[(c[u>>2]|0)+(C>>>3)|0]|0;c[k>>2]=((C|0)<(c[p>>2]|0))+C;if((F&128>>>((C&7)>>>0)|0)==0){break}else{l=l+1|0}}C=l&255;a[e+16080|0]=C;G=C}else{G=a[e+16080|0]|0}C=G&255;G=C+9+(C>>>1)|0;c[e+15712>>2]=G;c[e+15716>>2]=C+8;c[e+15720>>2]=1<<G-1;c[e+15724>>2]=1<<C+7;do{if((c[e+15592>>2]|0)!=0){if((c[q>>2]|0)==3){break}C=c[k>>2]|0;G=c[p>>2]|0;l=(c[u>>2]|0)+(C>>>3)|0;F=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(C&7)>>>30;l=C+2|0;c[k>>2]=G>>>0>l>>>0?l:G;a[e+16073|0]=F}}while(0);do{if((c[e+15588>>2]|0)==0){w=49}else{F=c[q>>2]|0;if(!((F|0)==1|(F|0)==7)){w=49;break}F=c[k>>2]|0;G=d[(c[u>>2]|0)+(F>>>3)|0]<<(F&7)>>>7;c[k>>2]=((F|0)<(c[p>>2]|0))+F;c[e+19552>>2]=G&1}}while(0);if((w|0)==49){c[e+19552>>2]=0}if((c[e+19492>>2]|0)!=0){G=h|0;h=j|0;j=c[q>>2]|0;if((j|0)==7|(j|0)==3){c[e+19204>>2]=e+19212}else{F=e+19200|0;l=c[F>>2]|0;C=e+19208|0;c[F>>2]=c[C>>2];c[C>>2]=l;c[e+19204>>2]=C}if((j|0)==7|(j|0)==3){C=e+17144|0;c[e+19192>>2]=C;H=C}else{C=e+16120|0;UGb(G|0,C|0,512)|0;l=e+18168|0;F=l|0;UGb(C|0,F|0,512)|0;UGb(F|0,G|0,512)|0;G=l|0;c[e+19192>>2]=G;H=G}if((j|0)==7|(j|0)==3){c[e+19196>>2]=e+17656}else{j=e+16632|0;UGb(h|0,j|0,512)|0;G=e+18680|0;l=G|0;UGb(j|0,l|0,512)|0;UGb(l|0,h|0,512)|0;c[e+19196>>2]=G}G=e+19192|0;h=e+19196|0;l=0;j=H;while(1){H=l&255;a[j+l|0]=H;a[(c[h>>2]|0)+l|0]=H;H=l+1|0;if((H|0)>=256){I=0;break}l=H;j=c[G>>2]|0}do{j=I&255;a[(c[G>>2]|0)+256+I|0]=j;a[(c[h>>2]|0)+256+I|0]=j;I=I+1|0;}while((I|0)<256);c[c[e+19204>>2]>>2]=0;}I=c[q>>2]|0;do{if((I|0)==3){h=a[e+15728|0]|0;do{if((h&255)>>>0<5>>>0){c[e+16088>>2]=0}else{G=e+16088|0;if((h&255)>>>0<13>>>0){c[G>>2]=1;break}else{c[G>>2]=2;break}}}while(0);h=c[k>>2]|0;G=d[(c[u>>2]|0)+(h>>>3)|0]<<(h&7);c[k>>2]=((h|0)<(c[p>>2]|0))+h;h=G>>>7&1;a[e+15708|0]=h;G=e+13924|0;c[e+19476>>2]=c[G>>2];j=h&255;c[G>>2]=j;c[e+14116>>2]=j;j=_1a(c[e+16096>>2]|0,e+16108|0,e)|0;if((j|0)<0){n=-1;i=g;return n|0}yDb(c[m>>2]|0,48,2217368,(B=i,i=i+16|0,c[B>>2]=j>>1,c[B+8>>2]=j&1,B)|0);i=B;j=_1a(c[e+9928>>2]|0,e+16116|0,e)|0;if((j|0)<0){n=-1;i=g;return n|0}yDb(c[m>>2]|0,48,2241264,(B=i,i=i+16|0,c[B>>2]=j>>1,c[B+8>>2]=j&1,B)|0);i=B;j=c[k>>2]|0;G=c[p>>2]|0;h=c[u>>2]|0;l=h+(j>>>3)|0;H=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(j&7)>>>30;l=j+2|0;c[k>>2]=G>>>0>l>>>0?l:G;c[e+14060>>2]=H;H=c[k>>2]|0;G=c[p>>2]|0;l=h+(H>>>3)|0;h=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(H&7)>>>30;l=H+2|0;c[k>>2]=G>>>0>l>>>0?l:G;c[e+16084>>2]=5387752+(h*20|0);if((c[e+15688>>2]|0)!=0){yDb(c[m>>2]|0,48,2229144,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;$1a(e)}h=e+16016|0;c[h>>2]=0;if((c[e+15692>>2]|0)==0){a[e+16020|0]=1;c[h>>2]=0;break}G=c[k>>2]|0;l=d[(c[u>>2]|0)+(G>>>3)|0]<<(G&7)>>>7;c[k>>2]=((G|0)<(c[p>>2]|0))+G;G=l&1;a[e+16020|0]=G;if(G<<24>>24==0){break}G=c[k>>2]|0;l=c[p>>2]|0;H=(c[u>>2]|0)+(G>>>3)|0;j=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(G&7)>>>30;H=G+2|0;c[k>>2]=l>>>0>H>>>0?H:l;c[h>>2]=c[1094552+(j<<2)>>2]}else if((I|0)==2){j=a[e+15728|0]|0;do{if((j&255)>>>0<5>>>0){c[e+16088>>2]=0}else{h=e+16088|0;if((j&255)>>>0<13>>>0){c[h>>2]=1;break}else{c[h>>2]=2;break}}}while(0);h=(j&255)>>>0<13>>>0|0;l=0;while(1){if((l|0)>=4){break}H=c[k>>2]|0;G=d[(c[u>>2]|0)+(H>>>3)|0]|0;c[k>>2]=((H|0)<(c[p>>2]|0))+H;if((G&128>>>((H&7)>>>0)|0)==0){l=l+1|0}else{break}}j=a[1095264+(h*5|0)+l|0]|0;H=e+15708|0;a[H]=j;if(j<<24>>24==4){G=0;while(1){if((G|0)>=3){break}F=c[k>>2]|0;C=d[(c[u>>2]|0)+(F>>>3)|0]|0;c[k>>2]=((F|0)<(c[p>>2]|0))+F;if((C&128>>>((F&7)>>>0)|0)==0){G=G+1|0}else{break}}a[e+15709|0]=a[1095256+(h<<2)+G|0]|0;l=c[k>>2]|0;F=c[p>>2]|0;C=(c[u>>2]|0)+(l>>>3)|0;y=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(l&7)>>>26;C=l+6|0;c[k>>2]=F>>>0>C>>>0?C:F;F=e+16068|0;a[F]=y;y=c[k>>2]|0;C=c[p>>2]|0;l=(c[u>>2]|0)+(y>>>3)|0;x=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(y&7)>>>26;l=y+6|0;c[k>>2]=C>>>0>l>>>0?l:C;C=x&255;l=e+16069|0;a[l]=C;c[e+19200>>2]=1;y=a[F]|0;do{if(y<<24>>24==0){v=x<<7^16320;if(!((C&255)>>>0>31>>>0)){J=-64;K=v;break}J=-64;K=v+8192|0}else{v=(y&255)+32|0;E=x<<6;if(!((C&255)>>>0>31>>>0)){J=v;K=E;break}J=v;K=E|-4096}}while(0);C=K+32|0;x=0;do{y=e+16120+x|0;G=e+16632+x|0;h=d[G]|0;E=C+(ba(d[y]|0,J)|0)>>6;if(E>>>0>255>>>0){L=-E>>31&255}else{L=E&255}a[y]=L;y=(ba(h-128|0,J)|0)+8224>>6;if(y>>>0>255>>>0){M=-y>>31&255}else{M=y&255}a[G]=M;x=x+1|0;}while((x|0)<256);x=a[F]|0;do{if(x<<24>>24==0){C=a[l]|0;G=255-((C&255)<<1)<<6;if(!((C&255)>>>0>31>>>0)){N=G;O=-64;break}N=G+8192|0;O=-64}else{G=(x&255)+32|0;C=a[l]|0;y=(C&255)<<6;if(!((C&255)>>>0>31>>>0)){N=y;O=G;break}N=y-4096|0;O=G}}while(0);l=N+32|0;x=0;do{F=e+16376+x|0;G=e+16888+x|0;y=d[G]|0;C=l+(ba(d[F]|0,O)|0)>>6;if(C>>>0>255>>>0){P=-C>>31&255}else{P=C&255}a[F]=P;F=(ba(y-128|0,O)|0)+8224>>6;if(F>>>0>255>>>0){Q=-F>>31&255}else{Q=F&255}a[G]=Q;x=x+1|0;}while((x|0)<256);R=a[H]|0}else{R=j}x=e+13924|0;c[e+19476>>2]=c[x>>2];do{if((R<<24>>24|0)==2|(R<<24>>24|0)==0){c[x>>2]=0;w=106}else if((R<<24>>24|0)==4){l=a[e+15709|0]|0;if((l<<24>>24|0)==2|(l<<24>>24|0)==0){c[x>>2]=0;w=108;break}else{c[x>>2]=1;w=106;break}}else{c[x>>2]=1;w=106}}while(0);do{if((w|0)==106){if((R<<24>>24|0)==4){w=108;break}else if((R<<24>>24|0)!=0){S=1;w=109;break}c[e+14116>>2]=0;w=113}}while(0);if((w|0)==108){S=(a[e+15709|0]|0)!=0|0;w=109}do{if((w|0)==109){c[e+14116>>2]=S;if((R<<24>>24|0)==4){if((a[e+15709|0]|0)!=3){w=113;break}}else if((R<<24>>24|0)!=3){w=113;break}x=_1a(c[e+16092>>2]|0,e+16104|0,e)|0;if((x|0)<0){n=-1;i=g;return n|0}else{yDb(c[m>>2]|0,48,2255664,(B=i,i=i+16|0,c[B>>2]=x>>1,c[B+8>>2]=x&1,B)|0);i=B;break}}}while(0);if((w|0)==113){c[e+16104>>2]=0;TGb(c[e+16092>>2]|0,0,ba(c[e+120>>2]|0,c[e+124>>2]|0)|0)|0}x=_1a(c[e+9928>>2]|0,e+16116|0,e)|0;if((x|0)<0){n=-1;i=g;return n|0}yDb(c[m>>2]|0,48,2241264,(B=i,i=i+16|0,c[B>>2]=x>>1,c[B+8>>2]=x&1,B)|0);i=B;x=c[k>>2]|0;j=c[p>>2]|0;H=c[u>>2]|0;l=H+(x>>>3)|0;G=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(x&7)>>>30;l=x+2|0;c[k>>2]=j>>>0>l>>>0?l:j;c[e+14060>>2]=G;G=c[k>>2]|0;j=c[p>>2]|0;l=H+(G>>>3)|0;H=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(G&7)>>>30;l=G+2|0;c[k>>2]=j>>>0>l>>>0?l:j;c[e+16084>>2]=5387752+(H*20|0);if((c[e+15688>>2]|0)!=0){yDb(c[m>>2]|0,48,2229144,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;$1a(e)}H=e+16016|0;c[H>>2]=0;if((c[e+15692>>2]|0)==0){a[e+16020|0]=1;c[H>>2]=0;break}j=c[k>>2]|0;l=d[(c[u>>2]|0)+(j>>>3)|0]<<(j&7)>>>7;c[k>>2]=((j|0)<(c[p>>2]|0))+j;j=l&1;a[e+16020|0]=j;if(j<<24>>24==0){break}j=c[k>>2]|0;l=c[p>>2]|0;G=(c[u>>2]|0)+(j>>>3)|0;x=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(j&7)>>>30;G=j+2|0;c[k>>2]=l>>>0>G>>>0?G:l;c[H>>2]=c[1094552+(x<<2)>>2]}}while(0);if((c[e+19552>>2]|0)==0){B=c[k>>2]|0;m=c[u>>2]|0;u=d[m+(B>>>3)|0]|0;w=c[p>>2]|0;R=((B|0)<(w|0))+B|0;c[k>>2]=R;if((u&128>>>((B&7)>>>0)|0)==0){T=0}else{B=d[m+(R>>>3)|0]<<(R&7)>>>7;c[k>>2]=((R|0)<(w|0))+R;T=(B&1)+1|0}c[e+16008>>2]=T;T=c[q>>2]|0;if((T|0)==1|(T|0)==7){T=c[k>>2]|0;B=d[m+(T>>>3)|0]|0;R=c[p>>2]|0;w=((T|0)<(R|0))+T|0;c[k>>2]=w;if((B&128>>>((T&7)>>>0)|0)==0){U=0}else{T=d[m+(w>>>3)|0]<<(w&7)>>>7;c[k>>2]=((w|0)<(R|0))+w;U=(T&1)+1|0}c[e+16012>>2]=U}U=c[k>>2]|0;T=d[m+(U>>>3)|0]<<(U&7)>>>7;c[k>>2]=((U|0)<(c[p>>2]|0))+U;c[e+14072>>2]=T&1}if((c[q>>2]|0)!=7){n=0;i=g;return n|0}c[q>>2]=3;c[D>>2]=1;n=0;i=g;return n|0}function _1a(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0;h=i;j=g+14120|0;k=c[g+116>>2]|0;l=c[g+120>>2]>>c[g+19428>>2];m=c[g+124>>2]|0;n=g+14128|0;o=c[n>>2]|0;p=j|0;q=c[p>>2]|0;r=d[q+(o>>>3)|0]<<(o&7)>>>7;s=g+14136|0;t=c[s>>2]|0;u=((o|0)<(t|0))+o|0;c[n>>2]=u;o=r&1;r=c[1346813]|0;v=q+(u>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(u&7)>>>28;v=b[r+(w<<2)>>1]|0;x=(b[r+(w<<2)+2>>1]|0)+u|0;c[n>>2]=t>>>0>x>>>0?x:t;c[f>>2]=0;a:do{switch(v|0){case 6:{c2a(e,k,l,m,j);y=58;break};case 5:{d2a(e,k,l,m,j);y=58;break};case 2:case 1:{t=ba(l,k)|0;do{if((t&1|0)==0){z=0;A=e;B=0}else{x=c[n>>2]|0;u=d[q+(x>>>3)|0]<<(x&7)>>>7;c[n>>2]=((x|0)<(c[s>>2]|0))+x;a[e]=u&1;if((k|0)!=1){z=1;A=e+1|0;B=1;break}z=1;A=e+m|0;B=0}}while(0);if((z|0)>=(t|0)){y=46;break a}u=1-k+m|0;x=B;w=A;r=z;while(1){C=c[1313667]|0;D=c[n>>2]|0;E=c[s>>2]|0;F=(c[p>>2]|0)+(D>>>3)|0;G=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(D&7)>>>29;F=b[C+(G<<2)>>1]|0;H=(b[C+(G<<2)+2>>1]|0)+D|0;c[n>>2]=E>>>0>H>>>0?H:E;a[w]=F&1;E=x+1|0;if((E|0)==(k|0)){I=w+u|0;J=0}else{I=w+1|0;J=E}a[I]=(F&65535)>>>1;F=J+1|0;if((F|0)==(k|0)){K=I+u|0;L=0}else{K=I+1|0;L=F}F=r+2|0;if((F|0)<(t|0)){x=L;w=K;r=F}else{y=46;break}}break};case 0:{c[f>>2]=1;M=o;i=h;return M|0};case 4:case 3:{r=(k|0)%3|0;do{if(((l|0)%3|0|0)==0){if((r|0)==0){N=0;break}w=(l|0)>0;x=k&1;b:do{if(w){t=(x|0)<(k|0);u=m*3|0;F=m<<1;E=e;H=0;c:while(1){if(t){D=x;do{G=c[1313661]|0;C=c[n>>2]|0;O=c[s>>2]|0;P=c[p>>2]|0;Q=P+(C>>>3)|0;R=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(C&7)>>>23;Q=b[G+(R<<2)>>1]|0;S=b[G+(R<<2)+2>>1]|0;R=S<<16>>16;if(S<<16>>16<0){S=C+9|0;T=O>>>0>S>>>0?S:O;S=P+(T>>>3)|0;P=((fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(T&7)>>>((R+32|0)>>>0))+Q|0;U=b[G+(P<<2)+2>>1]|0;V=b[G+(P<<2)>>1]|0;W=T}else{U=R;V=Q;W=C}C=U+W|0;c[n>>2]=O>>>0>C>>>0?C:O;if((V|0)<0){break c}a[E+D|0]=V&1;O=D+1|0;a[E+O|0]=V>>>1&1;a[E+(D+m)|0]=V>>>2&1;a[E+(O+m)|0]=V>>>3&1;a[E+(D+F)|0]=V>>>4&1;a[E+(O+F)|0]=V>>>5&1;D=D+2|0;}while((D|0)<(k|0))}D=H+3|0;if((D|0)<(l|0)){E=E+u|0;H=D}else{break b}}yDb(c[g+4>>2]|0,48,2092920,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;M=-1;i=h;return M|0}}while(0);if((x|0)==0){y=46;break a}if(!w){H=c[n>>2]|0;c[n>>2]=((H|0)<(c[s>>2]|0))+H;y=46;break a}H=c[n>>2]|0;u=c[p>>2]|0;E=d[u+(H>>>3)|0]|0;F=c[s>>2]|0;t=((H|0)<(F|0))+H|0;c[n>>2]=t;if((E&128>>>((H&7)>>>0)|0)==0){H=0;while(1){a[e+(ba(H,m)|0)|0]=0;E=H+1|0;if((E|0)<(l|0)){H=E}else{y=46;break a}}}else{Y=0;Z=t;_=u;$=F}while(1){H=d[_+(Z>>>3)|0]<<(Z&7)>>>7;c[n>>2]=((Z|0)<($|0))+Z;a[e+(ba(Y,m)|0)|0]=H&1;H=Y+1|0;if((H|0)>=(l|0)){y=46;break a}Y=H;Z=c[n>>2]|0;_=c[p>>2]|0;$=c[s>>2]|0}}else{N=r}}while(0);r=l&1;d:do{if((r|0)<(l|0)){F=(N|0)<(k|0);u=m<<1;t=e+(m&-r)|0;H=r;e:while(1){if(F){w=N;do{x=c[1313661]|0;E=c[n>>2]|0;D=c[s>>2]|0;O=c[p>>2]|0;C=O+(E>>>3)|0;Q=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>23;C=b[x+(Q<<2)>>1]|0;R=b[x+(Q<<2)+2>>1]|0;Q=R<<16>>16;if(R<<16>>16<0){R=E+9|0;T=D>>>0>R>>>0?R:D;R=O+(T>>>3)|0;O=((fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(T&7)>>>((Q+32|0)>>>0))+C|0;aa=b[x+(O<<2)+2>>1]|0;ca=b[x+(O<<2)>>1]|0;da=T}else{aa=Q;ca=C;da=E}E=aa+da|0;c[n>>2]=D>>>0>E>>>0?E:D;if((ca|0)<0){break e}a[t+w|0]=ca&1;D=w+1|0;a[t+D|0]=ca>>>1&1;E=w+2|0;a[t+E|0]=ca>>>2&1;a[t+(w+m)|0]=ca>>>3&1;a[t+(D+m)|0]=ca>>>4&1;a[t+(E+m)|0]=ca>>>5&1;w=w+3|0;}while((w|0)<(k|0))}w=H+2|0;if((w|0)<(l|0)){t=t+u|0;H=w}else{break d}}yDb(c[g+4>>2]|0,48,2092920,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;M=-1;i=h;return M|0}}while(0);if((N|0)!=0){c2a(e,N,l,m,j)}if((r|0)==0){y=46;break a}d2a(e+N|0,k-N|0,1,m,j);y=46;break};default:{y=58}}}while(0);f:do{if((y|0)==46){if(!((v|0)==4|(v|0)==2)){y=58;break}j=(d[e]^o)&255;a[e]=j;N=(k|0)>1;if(N){X=1;g=j;do{j=e+X|0;g=a[j]^g;a[j]=g;X=X+1|0;}while((X|0)<(k|0))}if((l|0)<=1){break}X=m-1|0;g=e;r=2;while(1){j=g+m|0;a[j]=a[j]^a[g];if(N){ca=1;do{n=a[g+(X+ca)|0]|0;da=g+(ca+m)|0;aa=a[da]|0;if(n<<24>>24==(a[g+ca|0]|0)){ea=aa^n}else{ea=(aa&255^o)&255}a[da]=ea;ca=ca+1|0;}while((ca|0)<(k|0))}if((r|0)>=(l|0)){break f}g=j;r=r+1|0}}}while(0);do{if((y|0)==58){if((o|0)==0){break}k=ba(m,l)|0;if((k|0)>0){fa=0}else{break}do{ea=e+fa|0;a[ea]=(a[ea]|0)==0|0;fa=fa+1|0;}while((fa|0)<(k|0))}}while(0);M=v<<1|o;i=h;return M|0}function $1a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b+14120|0;f=b+14128|0;g=c[f>>2]|0;if((c[b+15688>>2]|0)==2){h=c[b+14136>>2]|0;i=c[e>>2]|0;j=i+(g>>>3)|0;k=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(g&7)>>>29;j=g+3|0;l=h>>>0>j>>>0?j:h;c[f>>2]=l;if((k|0)==7){j=i+(l>>>3)|0;i=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(l&7)>>>27;j=l+5|0;c[f>>2]=h>>>0>j>>>0?j:h;a[b+15729|0]=i;return}else{a[b+15729|0]=k+1+(d[b+15728|0]|0);return}}k=c[e>>2]|0;e=d[k+(g>>>3)|0]<<(g&7)>>>7;i=c[b+14136>>2]|0;h=((g|0)<(i|0))+g|0;c[f>>2]=h;g=e&1;a[b+16004|0]=g;if(g<<24>>24==0){return}g=k+(h>>>3)|0;e=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(h&7)>>>30;g=h+2|0;h=i>>>0>g>>>0?g:i;c[f>>2]=h;g=e&255;a[b+16005|0]=g;do{if((e|0)==3){j=d[k+(h>>>3)|0]<<(h&7)>>>7;l=((h|0)<(i|0))+h|0;c[f>>2]=l;m=j&1;a[b+16007|0]=m;if(!(m<<24>>24==0)){n=l;break}a[b+16072|0]=0;n=l}else if((e|0)==2|(e|0)==1){l=k+(h>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>30;l=h+2|0;j=i>>>0>l>>>0?l:i;c[f>>2]=j;a[b+16006|0]=m;n=j}else{n=h}}while(0);if((a[b+16007|0]|0)==0&g<<24>>24==3){return}g=k+(n>>>3)|0;h=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(n&7)>>>29;g=n+3|0;n=i>>>0>g>>>0?g:i;c[f>>2]=n;if((h|0)==7){g=k+(n>>>3)|0;k=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(n&7)>>>27;g=n+5|0;c[f>>2]=i>>>0>g>>>0?g:i;a[b+15729|0]=k;return}else{a[b+15729|0]=h+1+(d[b+15728|0]|0);return}}function a2a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;g=i;i=i+1024|0;h=g|0;j=g+512|0;k=e+19444|0;c[k>>2]=0;l=e+19544|0;c[l>>2]=0;m=e+19436|0;if((c[m>>2]|0)==0){n=7}else{if((c[e+19224>>2]|0)!=2){o=-1;i=g;return o|0}if((c[e+19428>>2]|0)!=1){o=-1;i=g;return o|0}p=c[e+19432>>2]|0;if((p&4|0)==0){q=(p&1)+1|0}else{q=p<<2&4|3}c[e+9992>>2]=q;c[(c[e+9856>>2]|0)+88>>2]=q;if((c[e+19496>>2]|0)!=0){n=7}}do{if((n|0)==7){q=e+15632|0;if((c[q>>2]|0)==0){r=0;s=0}else{p=f+8|0;t=c[p>>2]|0;u=c[f>>2]|0;v=d[u+(t>>>3)|0]|0;w=c[f+16>>2]|0;x=((t|0)<(w|0))+t|0;c[p>>2]=x;if((v&128>>>((t&7)>>>0)|0)==0){y=0}else{t=d[u+(x>>>3)|0]<<(x&7)>>>7;c[p>>2]=((x|0)<(w|0))+x;y=(t&1)+1|0}r=(y|0)==2|0;s=y}t=e+19428|0;do{if((c[e+19492>>2]|0)==0){if((c[t>>2]|0)==(r|0)){break}else{o=-1094995529}i=g;return o|0}}while(0);c[t>>2]=r;x=e+19224|0;c[x>>2]=s;w=e+120|0;p=c[w>>2]|0;u=(c[e+12>>2]|0)+15>>4;do{if((p|0)!=(u|0)){if((p|0)==(u+1&-2|0)){break}yDb(0,0,2208104,(z=i,i=i+24|0,c[z>>2]=2199704,c[z+8>>2]=2191136,c[z+16>>2]=883,z)|0);i=z;Cd();return 0}}while(0);a:do{if((r|0)==0){c[w>>2]=u;p=f+8|0;v=f|0;A=f+16|0;B=0;while(1){if((B|0)>=4){break}C=c[p>>2]|0;D=d[(c[v>>2]|0)+(C>>>3)|0]|0;c[p>>2]=((C|0)<(c[A>>2]|0))+C;if((D&128>>>((C&7)>>>0)|0)==0){break}else{B=B+1|0}}switch(B|0){case 2:{c[e+9992>>2]=1;break a;break};case 3:{c[e+9992>>2]=7;break a;break};case 0:{c[e+9992>>2]=2;break a;break};case 1:{c[e+9992>>2]=3;break a;break};case 4:{c[e+9992>>2]=2;c[l>>2]=1;break a;break};default:{break a}}}else{c[w>>2]=u+1&-2;A=f+8|0;p=c[A>>2]|0;v=c[f+16>>2]|0;C=(c[f>>2]|0)+(p>>>3)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(p&7);C=D>>>29;E=p+3|0;c[A>>2]=v>>>0>E>>>0?E:v;c[e+19432>>2]=C;v=e+9992|0;c[v>>2]=(D>>>30&1)+1;if((C&4|0)==0){break}c[v>>2]=C<<1&4|3}}while(0);if((c[e+15636>>2]|0)!=0){u=f+8|0;w=c[f+16>>2]|0;C=(c[u>>2]|0)+8|0;c[u>>2]=w>>>0>C>>>0?C:w}b:do{if((c[e+15628>>2]|0)==0){a[e+19231|0]=1}else{do{if((c[q>>2]|0)!=0){if((c[e+15656>>2]|0)!=0){break}w=f+8|0;C=c[w>>2]|0;u=f|0;v=d[(c[u>>2]|0)+(C>>>3)|0]<<(C&7)>>>7;D=f+16|0;c[w>>2]=((C|0)<(c[D>>2]|0))+C;a[e+19231|0]=v&1;v=c[w>>2]|0;C=d[(c[u>>2]|0)+(v>>>3)|0]<<(v&7)>>>7;c[w>>2]=((v|0)<(c[D>>2]|0))+v;a[e+19232|0]=C&1;break b}}while(0);B=f+8|0;C=c[B>>2]|0;v=c[f+16>>2]|0;D=(c[f>>2]|0)+(C>>>3)|0;w=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>>30;D=C+2|0;c[B>>2]=v>>>0>D>>>0?D:v;a[e+19230|0]=w}}while(0);if((c[e+15640>>2]|0)!=0){EDb(c[e+4>>2]|0,2174456,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}if((c[l>>2]|0)!=0){o=0;i=g;return o|0}w=f+8|0;v=c[w>>2]|0;D=f|0;B=c[D>>2]|0;C=d[B+(v>>>3)|0]<<(v&7)>>>7;u=f+16|0;c[w>>2]=((v|0)<(c[u>>2]|0))+v;c[e+19216>>2]=C&1;if((c[q>>2]|0)!=0){C=c[w>>2]|0;v=d[B+(C>>>3)|0]<<(C&7)>>>7;c[w>>2]=((C|0)<(c[u>>2]|0))+C;a[e+19242|0]=v&1}v=c[1346959]|0;if((v|0)==0){o=0;i=g;return o|0}if((c[t>>2]|0)==0){if((c[x>>2]|0)!=0){break}if((c[e+15704>>2]|0)!=0){C=c[w>>2]|0;B=d[(c[D>>2]|0)+(C>>>3)|0]<<(C&7)>>>7;c[w>>2]=((C|0)<(c[u>>2]|0))+C;a[e+19221|0]=B&1}B=e+9992|0;if((c[B>>2]|0)!=3){break}C=c[1346959]|0;E=c[w>>2]|0;A=c[u>>2]|0;p=(c[D>>2]|0)+(E>>>3)|0;F=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(E&7)>>>25;p=b[C+(F<<2)>>1]|0;G=(b[C+(F<<2)+2>>1]|0)+E|0;c[w>>2]=A>>>0>G>>>0?G:A;if(p<<16>>16==21|p<<16>>16<0){yDb(c[e+4>>2]|0,16,2087624,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=g;return o|0}else{a[e+19604|0]=p;A=b[1099752+((p&255)<<1)>>1]|0;b[e+16070>>1]=A;if(!(A<<16>>16==0)){break}c[B>>2]=7;break}}do{if((c[e+15644>>2]|0)==0){c[e+19440>>2]=0;H=e+9992|0}else{B=e+9992|0;A=c[B>>2]|0;if((A|0)==3|(A|0)==7){H=B;break}A=c[w>>2]|0;p=c[u>>2]|0;G=c[D>>2]|0;E=G+(A>>>3)|0;F=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(A&7)>>>30;E=A+2|0;c[w>>2]=p>>>0>E>>>0?E:p;p=e+19440|0;c[p>>2]=F;if((F|0)==3){I=0}else{H=B;break}while(1){if((I|0)>=16){break}F=c[w>>2]|0;E=d[G+(F>>>3)|0]|0;c[w>>2]=((F|0)<(c[u>>2]|0))+F;if((E&128>>>((F&7)>>>0)|0)==0){break}else{I=I+1|0}}c[p>>2]=(c[p>>2]|0)+I;H=B}}while(0);x=c[H>>2]|0;if(!((x|0)==3|(x|0)==7)){break}x=c[w>>2]|0;t=c[u>>2]|0;q=(c[D>>2]|0)+(x>>>3)|0;G=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(x&7)>>>25;q=b[v+(G<<2)>>1]|0;F=(b[v+(G<<2)+2>>1]|0)+x|0;c[w>>2]=t>>>0>F>>>0?F:t;if(q<<16>>16==21|q<<16>>16<0){yDb(c[e+4>>2]|0,16,2087624,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=g;return o|0}else{a[e+19604|0]=q;t=b[1099752+((q&255)<<1)>>1]|0;b[e+16070>>1]=t;q=c[e+19440>>2]|0;F=(ba(t<<16>>16,q)|0)>>8;c[e+19484>>2]=F;t=q-F-1|0;F=e+19488|0;c[F>>2]=t;if((t|0)>=0){break}c[F>>2]=0;break}}}while(0);H=e+19428|0;if((c[H>>2]|0)!=0){c[e+19456>>2]=(d[e+19231|0]|0)==(c[m>>2]|0)}I=f+8|0;l=c[I>>2]|0;r=f+16|0;s=c[r>>2]|0;y=f|0;f=(c[y>>2]|0)+(l>>>3)|0;F=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7);f=F>>>27;t=l+5|0;c[I>>2]=s>>>0>t>>>0?t:s;if((f|0)==0){o=-1;i=g;return o|0}s=e+16040|0;c[s>>2]=f;t=e+15700|0;l=c[t>>2]|0;if((l|0)==0){a[e+15728|0]=a[1094824+f|0]|0;J=F>>>0<1207959552>>>0}else{a[e+15728|0]=a[1094856+f|0]|0;J=(l|0)!=2}q=e+16081|0;a[q]=J&1;c[s>>2]=f;if(F>>>0<1207959552>>>0){F=c[I>>2]|0;f=d[(c[y>>2]|0)+(F>>>3)|0]<<(F&7)>>>7;c[I>>2]=((F|0)<(c[r>>2]|0))+F;a[e+16072|0]=f&1;K=c[t>>2]|0}else{a[e+16072|0]=0;K=l}if((K|0)==1){K=c[I>>2]|0;l=d[(c[y>>2]|0)+(K>>>3)|0]<<(K&7)>>>7;c[I>>2]=((K|0)<(c[r>>2]|0))+K;a[q]=l&1}if((c[e+15624>>2]|0)!=0){l=c[I>>2]|0;q=c[r>>2]|0;K=(c[y>>2]|0)+(l>>>3)|0;t=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(l&7)>>>30;K=l+2|0;c[I>>2]=q>>>0>K>>>0?K:q;a[e+19243|0]=t}if((c[e+19612>>2]|0)!=0){o=0;i=g;return o|0}if((c[e+19492>>2]|0)==0){L=e+9992|0}else{t=h|0;h=j|0;j=e+9992|0;q=c[j>>2]|0;if((q|0)==7|(q|0)==3){c[e+19204>>2]=e+19212}else{K=e+19200|0;l=c[K>>2]|0;f=e+19208|0;c[K>>2]=c[f>>2];c[f>>2]=l;c[e+19204>>2]=f}if((q|0)==7|(q|0)==3){f=e+17144|0;c[e+19192>>2]=f;M=f}else{f=e+16120|0;UGb(t|0,f|0,512)|0;l=e+18168|0;K=l|0;UGb(f|0,K|0,512)|0;UGb(K|0,t|0,512)|0;t=l|0;c[e+19192>>2]=t;M=t}if((q|0)==7|(q|0)==3){c[e+19196>>2]=e+17656}else{q=e+16632|0;UGb(h|0,q|0,512)|0;t=e+18680|0;l=t|0;UGb(q|0,l|0,512)|0;UGb(l|0,h|0,512)|0;c[e+19196>>2]=t}t=e+19192|0;h=e+19196|0;l=0;q=M;while(1){M=l&255;a[q+l|0]=M;a[(c[h>>2]|0)+l|0]=M;M=l+1|0;if((M|0)>=256){N=0;break}l=M;q=c[t>>2]|0}do{q=N&255;a[(c[t>>2]|0)+256+N|0]=q;a[(c[h>>2]|0)+256+N|0]=q;N=N+1|0;}while((N|0)<256);c[c[e+19204>>2]>>2]=0;L=j}j=c[L>>2]|0;do{if((j|0)==2){do{if((c[H>>2]|0)!=0){N=c[I>>2]|0;h=c[y>>2]|0;t=d[h+(N>>>3)|0]<<(N&7)>>>7;c[I>>2]=((N|0)<(c[r>>2]|0))+N;N=t&1;c[k>>2]=N;if((N|0)!=0){break}N=c[I>>2]|0;t=d[h+(N>>>3)|0]<<(N&7)>>>7;c[I>>2]=((N|0)<(c[r>>2]|0))+N;N=t&1;c[e+19448>>2]=N;c[e+19460>>2]=N^(c[e+19456>>2]|0)==0}}while(0);if((c[e+15684>>2]|0)==0){a[e+16080|0]=0}else{w=0;while(1){if((w|0)>=3){break}v=c[I>>2]|0;D=d[(c[y>>2]|0)+(v>>>3)|0]|0;c[I>>2]=((v|0)<(c[r>>2]|0))+v;if((D&128>>>((v&7)>>>0)|0)==0){break}else{w=w+1|0}}a[e+16080|0]=w}do{if((c[e+15632>>2]|0)!=0){if((c[e+15648>>2]|0)==0){a[e+19288|0]=0}else{v=0;while(1){if((v|0)>=3){break}D=c[I>>2]|0;u=d[(c[y>>2]|0)+(D>>>3)|0]|0;c[I>>2]=((D|0)<(c[r>>2]|0))+D;if((u&128>>>((D&7)>>>0)|0)==0){break}else{v=v+1|0}}a[e+19288|0]=v}if((c[e+19224>>2]|0)!=1){break}B=c[I>>2]|0;p=c[y>>2]|0;D=d[p+(B>>>3)|0]<<(B&7)>>>7;c[I>>2]=((B|0)<(c[r>>2]|0))+B;B=e+19292|0;c[B>>2]=D&1;D=c[I>>2]|0;u=d[p+(D>>>3)|0]<<(D&7)>>>7;c[I>>2]=((D|0)<(c[r>>2]|0))+D;D=u&1;c[e+19296>>2]=D;if((D|0)!=0){D=c[I>>2]|0;u=c[r>>2]|0;N=p+(D>>>3)|0;p=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(D&7)>>>26;N=D+6|0;c[I>>2]=u>>>0>N>>>0?N:u;u=e+16068|0;a[u]=p;p=c[I>>2]|0;N=c[r>>2]|0;D=(c[y>>2]|0)+(p>>>3)|0;t=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(p&7);D=t>>>26;h=p+6|0;c[I>>2]=N>>>0>h>>>0?h:N;N=e+16069|0;a[N]=D;h=a[u]|0;do{if(h<<24>>24==0){p=D<<7^16320;if((t|0)>=0){O=-64;P=p;break}O=-64;P=p+8192|0}else{p=(h&255)+32|0;q=D<<6;if((t|0)>=0){O=p;P=q;break}O=p;P=q|-4096}}while(0);t=P+32|0;D=0;do{h=e+16120+D|0;v=e+16632+D|0;q=d[v]|0;p=t+(ba(d[h]|0,O)|0)>>6;if(p>>>0>255>>>0){Q=-p>>31&255}else{Q=p&255}a[h]=Q;h=(ba(q-128|0,O)|0)+8224>>6;if(h>>>0>255>>>0){R=-h>>31&255}else{R=h&255}a[v]=R;D=D+1|0;}while((D|0)<256);D=a[u]|0;do{if(D<<24>>24==0){t=a[N]|0;v=255-((t&255)<<1)<<6;if(!((t&255)>>>0>31>>>0)){S=-64;T=v;break}S=-64;T=v+8192|0}else{v=(D&255)+32|0;t=a[N]|0;h=(t&255)<<6;if(!((t&255)>>>0>31>>>0)){S=v;T=h;break}S=v;T=h-4096|0}}while(0);N=T+32|0;D=0;do{u=e+16376+D|0;h=e+16888+D|0;v=d[h]|0;t=N+(ba(d[u]|0,S)|0)>>6;if(t>>>0>255>>>0){U=-t>>31&255}else{U=t&255}a[u]=U;u=(ba(v-128|0,S)|0)+8224>>6;if(u>>>0>255>>>0){V=-u>>31&255}else{V=u&255}a[h]=V;D=D+1|0;}while((D|0)<256);c[e+19200>>2]=1}D=_1a(c[e+9928>>2]|0,e+16116|0,e)|0;yDb(c[e+4>>2]|0,48,2143696,(z=i,i=i+16|0,c[z>>2]=D>>1,c[z+8>>2]=D&1,z)|0);i=z;D=c[I>>2]|0;N=c[r>>2]|0;h=(c[y>>2]|0)+(D>>>3)|0;u=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(D&7)>>>30;h=D+2|0;D=N>>>0>h>>>0?h:N;c[I>>2]=D;if((c[B>>2]|0)==0){c[e+19304>>2]=5254768+(u*20|0)}else{c[e+19304>>2]=5254848+(u*20|0)}u=(c[y>>2]|0)+(D>>>3)|0;h=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(D&7)>>>30;u=D+2|0;D=N>>>0>u>>>0?u:N;c[I>>2]=D;c[e+19308>>2]=5388336+(h*20|0);h=(c[y>>2]|0)+(D>>>3)|0;u=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(D&7)>>>29;h=D+3|0;D=N>>>0>h>>>0?h:N;c[I>>2]=D;c[e+16084>>2]=5387592+(u*20|0);u=(c[y>>2]|0)+(D>>>3)|0;h=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(D&7)>>>30;u=D+2|0;D=N>>>0>u>>>0?u:N;c[I>>2]=D;c[e+19312>>2]=5388256+(h*20|0);if((c[B>>2]|0)==0){break}h=(c[y>>2]|0)+(D>>>3)|0;u=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(D&7)>>>30;h=D+2|0;c[I>>2]=N>>>0>h>>>0?h:N;c[e+19316>>2]=5388016+(u*20|0)}}while(0);w=d[e+16080|0]|0;u=w+9+(w>>>1)|0;c[e+15712>>2]=u;c[e+15716>>2]=w+8;c[e+15720>>2]=1<<u-1;c[e+15724>>2]=1<<w+7;w=e+15728|0;u=a[w]|0;do{if((u&255)>>>0<5>>>0){c[e+16088>>2]=0}else{N=e+16088|0;if((u&255)>>>0<13>>>0){c[N>>2]=1;break}else{c[N>>2]=2;break}}}while(0);u=e+19224|0;do{if((c[u>>2]|0)==1){W=c[e+13924>>2]|0;X=e+19476|0;Y=e+14116|0;n=261}else{N=0;while(1){if((N|0)>=4){break}h=c[I>>2]|0;D=d[(c[y>>2]|0)+(h>>>3)|0]|0;c[I>>2]=((h|0)<(c[r>>2]|0))+h;if((D&128>>>((h&7)>>>0)|0)==0){N=N+1|0}else{break}}B=(d[w]|0)>>>0<13>>>0|0;h=a[1095264+(B*5|0)+N|0]|0;D=e+15708|0;a[D]=h;if(h<<24>>24==4){v=0;while(1){if((v|0)>=3){break}t=c[I>>2]|0;q=d[(c[y>>2]|0)+(t>>>3)|0]|0;c[I>>2]=((t|0)<(c[r>>2]|0))+t;if((q&128>>>((t&7)>>>0)|0)==0){v=v+1|0}else{break}}a[e+15709|0]=a[1095256+(B<<2)+v|0]|0;if((c[H>>2]|0)==0){c[e+19452>>2]=3;Z=3}else{N=c[I>>2]|0;t=c[y>>2]|0;q=d[t+(N>>>3)|0]|0;p=c[r>>2]|0;l=((N|0)<(p|0))+N|0;c[I>>2]=l;if((q&128>>>((N&7)>>>0)|0)==0){N=d[t+(l>>>3)|0]<<(l&7)>>>7;c[I>>2]=((l|0)<(p|0))+l;_=2-(N&1)^3}else{_=3}c[e+19452>>2]=_;Z=_}N=e+16068|0;a[N]=32;l=e+19300|0;a[l]=32;p=e+16069|0;a[p]=0;t=e+19301|0;a[t]=0;if((Z&1|0)==0){$=Z;aa=0}else{q=c[I>>2]|0;M=c[r>>2]|0;K=(c[y>>2]|0)+(q>>>3)|0;f=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(q&7)>>>26;K=q+6|0;c[I>>2]=M>>>0>K>>>0?K:M;a[N]=f;f=c[I>>2]|0;M=c[r>>2]|0;K=(c[y>>2]|0)+(f>>>3)|0;q=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(f&7)>>>26;K=f+6|0;c[I>>2]=M>>>0>K>>>0?K:M;M=q&255;a[p]=M;$=c[e+19452>>2]|0;aa=M}M=(c[H>>2]|0)==0;do{if(($&2|0)==0){if(M){n=172}else{n=174}}else{if(M){n=172;break}q=c[I>>2]|0;K=c[r>>2]|0;f=(c[y>>2]|0)+(q>>>3)|0;F=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(q&7)>>>26;f=q+6|0;c[I>>2]=K>>>0>f>>>0?f:K;a[l]=F;F=c[I>>2]|0;K=c[r>>2]|0;f=(c[y>>2]|0)+(F>>>3)|0;q=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(F&7)>>>26;f=F+6|0;c[I>>2]=K>>>0>f>>>0?f:K;K=c[H>>2]|0;a[t]=q;if((K|0)==0){n=221}else{n=174}}}while(0);do{if((n|0)==172){a[l]=a[N]|0;a[t]=aa;n=221}else if((n|0)==174){if((c[m>>2]|0)==0){n=221;break}M=e+19456|0;if((c[M>>2]|0)==0){v=a[l]|0;do{if(v<<24>>24==0){B=a[t]|0;K=255-((B&255)<<1)<<6;if(!((B&255)>>>0>31>>>0)){ca=K;da=-64;break}ca=K+8192|0;da=-64}else{K=(v&255)+32|0;B=a[t]|0;q=(B&255)<<6;if(!((B&255)>>>0>31>>>0)){ca=q;da=K;break}ca=q-4096|0;da=K}}while(0);v=ca+32|0;K=e+19192|0;q=e+19196|0;B=0;do{f=v+(ba(B,da)|0)>>6;if(f>>>0>255>>>0){ea=-f>>31&255}else{ea=f&255}a[(c[K>>2]|0)+((c[M>>2]^1)<<8)+B|0]=ea;f=(ba(B-128|0,da)|0)+8224>>6;if(f>>>0>255>>>0){fa=-f>>31&255}else{fa=f&255}a[(c[q>>2]|0)+((c[M>>2]^1)<<8)+B|0]=fa;B=B+1|0;}while((B|0)<256);B=a[N]|0;do{if(B<<24>>24==0){q=a[p]|0;K=255-((q&255)<<1)<<6;if(!((q&255)>>>0>31>>>0)){ga=K;ha=-64;break}ga=K+8192|0;ha=-64}else{K=(B&255)+32|0;q=a[p]|0;v=(q&255)<<6;if(!((q&255)>>>0>31>>>0)){ga=v;ha=K;break}ga=v-4096|0;ha=K}}while(0);B=ga+32|0;K=0;do{v=c[M>>2]|0;q=e+16120+(v<<8)+K|0;f=d[e+16632+(v<<8)+K|0]|0;v=B+(ba(d[q]|0,ha)|0)>>6;if(v>>>0>255>>>0){ia=-v>>31&255}else{ia=v&255}a[q]=ia;q=(ba(f-128|0,ha)|0)+8224>>6;if(q>>>0>255>>>0){ja=-q>>31&255}else{ja=q&255}a[e+16632+(c[M>>2]<<8)+K|0]=ja;K=K+1|0;}while((K|0)<256)}else{K=a[N]|0;do{if(K<<24>>24==0){B=a[p]|0;q=255-((B&255)<<1)<<6;if(!((B&255)>>>0>31>>>0)){ka=q;la=-64;break}ka=q+8192|0;la=-64}else{q=(K&255)+32|0;B=a[p]|0;f=(B&255)<<6;if(!((B&255)>>>0>31>>>0)){ka=f;la=q;break}ka=f-4096|0;la=q}}while(0);K=ka+32|0;q=e+19192|0;f=e+19196|0;B=0;do{v=K+(ba(B,la)|0)>>6;if(v>>>0>255>>>0){ma=-v>>31&255}else{ma=v&255}a[(c[q>>2]|0)+((c[M>>2]^1)<<8)+B|0]=ma;v=(ba(B-128|0,la)|0)+8224>>6;if(v>>>0>255>>>0){na=-v>>31&255}else{na=v&255}a[(c[f>>2]|0)+((c[M>>2]^1)<<8)+B|0]=na;B=B+1|0;}while((B|0)<256);B=a[l]|0;do{if(B<<24>>24==0){f=a[t]|0;q=255-((f&255)<<1)<<6;if(!((f&255)>>>0>31>>>0)){oa=q;pa=-64;break}oa=q+8192|0;pa=-64}else{q=(B&255)+32|0;f=a[t]|0;K=(f&255)<<6;if(!((f&255)>>>0>31>>>0)){oa=K;pa=q;break}oa=K-4096|0;pa=q}}while(0);B=oa+32|0;q=0;do{K=c[M>>2]|0;f=e+16120+(K<<8)+q|0;v=d[e+16632+(K<<8)+q|0]|0;K=B+(ba(d[f]|0,pa)|0)>>6;if(K>>>0>255>>>0){qa=-K>>31&255}else{qa=K&255}a[f]=qa;f=(ba(v-128|0,pa)|0)+8224>>6;if(f>>>0>255>>>0){ra=-f>>31&255}else{ra=f&255}a[e+16632+(c[M>>2]<<8)+q|0]=ra;q=q+1|0;}while((q|0)<256)}c[c[e+19204>>2]>>2]=1;c[e+19208>>2]=1}}while(0);if((n|0)==221){q=a[N]|0;do{if(q<<24>>24==0){M=a[p]|0;B=255-((M&255)<<1)<<6;if(!((M&255)>>>0>31>>>0)){sa=B;ta=-64;break}sa=B+8192|0;ta=-64}else{B=(q&255)+32|0;M=a[p]|0;f=(M&255)<<6;if(!((M&255)>>>0>31>>>0)){sa=f;ta=B;break}sa=f-4096|0;ta=B}}while(0);p=sa+32|0;q=0;do{N=e+16120+q|0;B=e+16632+q|0;f=d[B]|0;M=p+(ba(d[N]|0,ta)|0)>>6;if(M>>>0>255>>>0){ua=-M>>31&255}else{ua=M&255}a[N]=ua;N=(ba(f-128|0,ta)|0)+8224>>6;if(N>>>0>255>>>0){va=-N>>31&255}else{va=N&255}a[B]=va;q=q+1|0;}while((q|0)<256);q=a[l]|0;do{if(q<<24>>24==0){p=a[t]|0;B=255-((p&255)<<1)<<6;if(!((p&255)>>>0>31>>>0)){wa=B;xa=-64;break}wa=B+8192|0;xa=-64}else{B=(q&255)+32|0;p=a[t]|0;N=(p&255)<<6;if(!((p&255)>>>0>31>>>0)){wa=N;xa=B;break}wa=N-4096|0;xa=B}}while(0);t=wa+32|0;q=0;do{l=e+16376+q|0;B=e+16888+q|0;N=d[B]|0;p=t+(ba(d[l]|0,xa)|0)>>6;if(p>>>0>255>>>0){ya=-p>>31&255}else{ya=p&255}a[l]=ya;l=(ba(N-128|0,xa)|0)+8224>>6;if(l>>>0>255>>>0){za=-l>>31&255}else{za=l&255}a[B]=za;q=q+1|0;}while((q|0)<256)}c[e+19200>>2]=1;Aa=a[D]|0}else{Aa=h}q=e+13924|0;t=e+19476|0;c[t>>2]=c[q>>2];do{if((Aa<<24>>24|0)==4){B=a[e+15709|0]|0;if((B<<24>>24|0)==2|(B<<24>>24|0)==0){c[q>>2]=0;Ba=0;n=252;break}else{c[q>>2]=1;Ca=1;n=250;break}}else if((Aa<<24>>24|0)==2|(Aa<<24>>24|0)==0){c[q>>2]=0;Ca=0;n=250}else{c[q>>2]=1;Ca=1;n=250}}while(0);do{if((n|0)==250){if(Aa<<24>>24==0){Da=0;Ea=Ca;break}if(Aa<<24>>24==4){Ba=Ca;n=252}else{Da=1;Ea=Ca}}}while(0);if((n|0)==252){Da=(a[e+15709|0]|0)!=0|0;Ea=Ba}q=e+14116|0;c[q>>2]=Da;h=c[u>>2]|0;if((h|0)==1){W=Ea;X=t;Y=q;n=261;break}else if((h|0)!=0){h=c[I>>2]|0;q=c[r>>2]|0;B=c[y>>2]|0;l=B+(h>>>3)|0;N=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>29;l=h+3|0;h=q>>>0>l>>>0?l:q;c[I>>2]=h;l=c[k>>2]|0;p=B+(h>>>3)|0;B=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(h&7)>>>((30-l|0)>>>0);p=h+2+l|0;l=q>>>0>p>>>0?p:q;c[I>>2]=l;if((c[k>>2]|0)==0){c[e+19308>>2]=5388336+(B*20|0)}else{c[e+19308>>2]=5388096+(B*20|0)}B=(c[y>>2]|0)+(l>>>3)|0;p=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(l&7)>>>29;B=l+3|0;l=q>>>0>B>>>0?B:q;c[I>>2]=l;c[e+16084>>2]=5387592+(p*20|0);p=a[D]|0;if((p<<24>>24|0)==4){if((a[e+15709|0]|0)==3){n=267}else{n=268}}else if((p<<24>>24|0)==3){n=267}else{n=268}if((n|0)==267){p=(c[y>>2]|0)+(l>>>3)|0;B=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(l&7)>>>30;p=l+2|0;c[I>>2]=q>>>0>p>>>0?p:q;c[e+19316>>2]=5388016+(B*20|0);c[e+19304>>2]=5387272+(N*20|0);break}else if((n|0)==268){c[e+19304>>2]=5387432+(N*20|0);break}}if((Aa<<24>>24|0)==4){if((a[e+15709|0]|0)==3){n=256}else{n=258}}else if((Aa<<24>>24|0)==3){n=256}else{n=258}do{if((n|0)==256){N=_1a(c[e+16092>>2]|0,e+16104|0,e)|0;if((N|0)<0){o=-1;i=g;return o|0}else{yDb(c[e+4>>2]|0,48,2255664,(z=i,i=i+16|0,c[z>>2]=N>>1,c[z+8>>2]=N&1,z)|0);i=z;break}}else if((n|0)==258){c[e+16104>>2]=0;TGb(c[e+16092>>2]|0,0,ba(c[e+120>>2]|0,c[e+124>>2]|0)|0)|0}}while(0);D=_1a(c[e+9928>>2]|0,e+16116|0,e)|0;if((D|0)<0){o=-1;i=g;return o|0}else{yDb(c[e+4>>2]|0,48,2241264,(z=i,i=i+16|0,c[z>>2]=D>>1,c[z+8>>2]=D&1,z)|0);i=z;D=c[I>>2]|0;t=c[r>>2]|0;N=c[y>>2]|0;B=N+(D>>>3)|0;q=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(D&7)>>>30;B=D+2|0;c[I>>2]=t>>>0>B>>>0?B:t;c[e+14060>>2]=q;q=c[I>>2]|0;t=c[r>>2]|0;B=N+(q>>>3)|0;N=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(q&7)>>>30;B=q+2|0;c[I>>2]=t>>>0>B>>>0?B:t;c[e+16084>>2]=5387752+(N*20|0);break}}}while(0);if((n|0)==261){c[X>>2]=W;c[e+13924>>2]=1;c[Y>>2]=1}if((c[e+15688>>2]|0)!=0){yDb(c[e+4>>2]|0,48,2229144,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;$1a(e)}w=e+16016|0;c[w>>2]=0;if((c[e+15692>>2]|0)==0){a[e+16020|0]=1;c[w>>2]=0;Fa=u;break}N=c[I>>2]|0;t=d[(c[y>>2]|0)+(N>>>3)|0]<<(N&7)>>>7;c[I>>2]=((N|0)<(c[r>>2]|0))+N;N=t&1;a[e+16020|0]=N;if(N<<24>>24==0){Fa=u;break}N=c[I>>2]|0;t=c[r>>2]|0;B=(c[y>>2]|0)+(N>>>3)|0;q=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(N&7)>>>30;B=N+2|0;c[I>>2]=t>>>0>B>>>0?B:t;c[w>>2]=c[1094552+(q<<2)>>2];Fa=u}else if((j|0)==3){q=e+19224|0;w=(c[q>>2]|0)==1;do{if(w){t=c[1346959]|0;B=c[I>>2]|0;N=c[r>>2]|0;D=(c[y>>2]|0)+(B>>>3)|0;p=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7)>>>25;D=b[t+(p<<2)>>1]|0;l=(b[t+(p<<2)+2>>1]|0)+B|0;c[I>>2]=N>>>0>l>>>0?l:N;if(D<<16>>16==21|D<<16>>16<0){yDb(c[e+4>>2]|0,16,2087624,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=g;return o|0}else{a[e+19604|0]=D;N=b[1099752+((D&255)<<1)>>1]|0;b[e+16070>>1]=N;if(N<<16>>16==0){o=-1}else{break}i=g;return o|0}}}while(0);if((c[e+15684>>2]|0)==0){a[e+16080|0]=0;Ga=0}else{u=0;while(1){if((u|0)>=3){break}N=c[I>>2]|0;D=d[(c[y>>2]|0)+(N>>>3)|0]|0;c[I>>2]=((N|0)<(c[r>>2]|0))+N;if((D&128>>>((N&7)>>>0)|0)==0){break}else{u=u+1|0}}a[e+16080|0]=u;Ga=u&255}N=Ga+9+(Ga>>>1)|0;c[e+15712>>2]=N;c[e+15716>>2]=Ga+8;c[e+15720>>2]=1<<N-1;c[e+15724>>2]=1<<Ga+7;N=e+15728|0;D=a[N]|0;do{if((D&255)>>>0<5>>>0){c[e+16088>>2]=0}else{l=e+16088|0;if((D&255)>>>0<13>>>0){c[l>>2]=1;break}else{c[l>>2]=2;break}}}while(0);do{if((c[H>>2]|0)==0){if(!w){D=c[I>>2]|0;u=d[(c[y>>2]|0)+(D>>>3)|0]<<(D&7);c[I>>2]=((D|0)<(c[r>>2]|0))+D;D=u>>>7&1;a[e+15708|0]=D;u=e+13924|0;c[e+19476>>2]=c[u>>2];l=D&255;c[u>>2]=l;c[e+14116>>2]=l;l=_1a(c[e+16096>>2]|0,e+16108|0,e)|0;if((l|0)<0){o=-1;i=g;return o|0}u=e+4|0;yDb(c[u>>2]|0,48,2217368,(z=i,i=i+16|0,c[z>>2]=l>>1,c[z+8>>2]=l&1,z)|0);i=z;l=_1a(c[e+9928>>2]|0,e+16116|0,e)|0;if((l|0)<0){o=-1;i=g;return o|0}else{yDb(c[u>>2]|0,48,2241264,(z=i,i=i+16|0,c[z>>2]=l>>1,c[z+8>>2]=l&1,z)|0);i=z;l=c[I>>2]|0;u=c[r>>2]|0;D=c[y>>2]|0;B=D+(l>>>3)|0;p=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(l&7)>>>30;B=l+2|0;c[I>>2]=u>>>0>B>>>0?B:u;c[e+14060>>2]=p;p=c[I>>2]|0;u=c[r>>2]|0;B=D+(p>>>3)|0;D=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(p&7)>>>30;B=p+2|0;c[I>>2]=u>>>0>B>>>0?B:u;c[e+16084>>2]=5387752+(D*20|0);break}}if((c[e+15648>>2]|0)!=0){D=0;while(1){if((D|0)>=3){break}u=c[I>>2]|0;B=d[(c[y>>2]|0)+(u>>>3)|0]|0;c[I>>2]=((u|0)<(c[r>>2]|0))+u;if((B&128>>>((u&7)>>>0)|0)==0){break}else{D=D+1|0}}a[e+19288|0]=D}u=c[I>>2]|0;B=d[(c[y>>2]|0)+(u>>>3)|0]|0;c[I>>2]=((u|0)<(c[r>>2]|0))+u;if((B&128>>>((u&7)>>>0)|0)!=0){yDb(c[e+4>>2]|0,24,2125176,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}c[e+19296>>2]=0;a[e+15708|0]=1;c[e+19292>>2]=0;u=e+13924|0;c[e+19476>>2]=c[u>>2];c[u>>2]=1;c[e+14116>>2]=1;u=_1a(c[e+16096>>2]|0,e+16108|0,e)|0;if((u|0)<0){o=-1;i=g;return o|0}B=e+4|0;yDb(c[B>>2]|0,48,2217368,(z=i,i=i+16|0,c[z>>2]=u>>1,c[z+8>>2]=u&1,z)|0);i=z;u=_1a(c[e+9928>>2]|0,e+16116|0,e)|0;if((u|0)<0){o=-1;i=g;return o|0}else{yDb(c[B>>2]|0,48,2241264,(z=i,i=i+16|0,c[z>>2]=u>>1,c[z+8>>2]=u&1,z)|0);i=z;u=c[I>>2]|0;B=c[r>>2]|0;p=(c[y>>2]|0)+(u>>>3)|0;l=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(u&7)>>>30;p=u+2|0;u=B>>>0>p>>>0?p:B;c[I>>2]=u;c[e+19304>>2]=5254768+(l*20|0);l=(c[y>>2]|0)+(u>>>3)|0;p=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(u&7)>>>30;l=u+2|0;u=B>>>0>l>>>0?l:B;c[I>>2]=u;c[e+19308>>2]=5388336+(p*20|0);p=(c[y>>2]|0)+(u>>>3)|0;l=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(u&7)>>>29;p=u+3|0;u=B>>>0>p>>>0?p:B;c[I>>2]=u;c[e+16084>>2]=5387592+(l*20|0);l=(c[y>>2]|0)+(u>>>3)|0;p=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(u&7)>>>30;l=u+2|0;u=B>>>0>l>>>0?l:B;c[I>>2]=u;c[e+19312>>2]=5388256+(p*20|0);p=(c[y>>2]|0)+(u>>>3)|0;l=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(u&7)>>>30;p=u+2|0;c[I>>2]=B>>>0>p>>>0?p:B;c[e+19316>>2]=5388016+(l*20|0);break}}else{l=e+4|0;yDb(c[l>>2]|0,48,2138256,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;if((c[e+15648>>2]|0)==0){Ha=0}else{B=0;while(1){if((B|0)>=3){break}p=c[I>>2]|0;u=d[(c[y>>2]|0)+(p>>>3)|0]|0;c[I>>2]=((p|0)<(c[r>>2]|0))+p;if((u&128>>>((p&7)>>>0)|0)==0){break}else{B=B+1|0}}a[e+19288|0]=B;Ha=0}while(1){if((Ha|0)>=3){break}D=c[I>>2]|0;p=d[(c[y>>2]|0)+(D>>>3)|0]|0;c[I>>2]=((D|0)<(c[r>>2]|0))+D;if((p&128>>>((D&7)>>>0)|0)==0){Ha=Ha+1|0}else{break}}B=a[1095256+(((d[N]|0)>>>0<13>>>0)<<2)+Ha|0]|0;D=e+15708|0;a[D]=B;p=e+13924|0;c[e+19476>>2]=c[p>>2];if(B<<24>>24==1){c[p>>2]=1;n=299}else{c[p>>2]=B<<24>>24==3;if(B<<24>>24==0){Ia=0}else{n=299}}if((n|0)==299){Ia=B<<24>>24!=2|0}c[e+14116>>2]=Ia;B=_1a(c[e+16100>>2]|0,e+16112|0,e)|0;if((B|0)<0){o=-1;i=g;return o|0}yDb(c[l>>2]|0,48,2131600,(z=i,i=i+16|0,c[z>>2]=B>>1,c[z+8>>2]=B&1,z)|0);i=z;B=c[I>>2]|0;p=c[r>>2]|0;u=(c[y>>2]|0)+(B>>>3)|0;t=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(B&7)>>>29;u=B+3|0;B=p>>>0>u>>>0?u:p;c[I>>2]=B;if((a[D]|0)==3){c[e+19304>>2]=5387272+(t*20|0)}else{c[e+19304>>2]=5387432+(t*20|0)}t=(c[y>>2]|0)+(B>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(B&7)>>>29;t=B+3|0;B=p>>>0>t>>>0?t:p;c[I>>2]=B;c[e+19308>>2]=5388096+(u*20|0);u=(c[y>>2]|0)+(B>>>3)|0;t=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(B&7)>>>29;u=B+3|0;B=p>>>0>u>>>0?u:p;c[I>>2]=B;c[e+16084>>2]=5387592+(t*20|0);if((a[D]|0)==3){D=(c[y>>2]|0)+(B>>>3)|0;t=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7)>>>30;D=B+2|0;c[I>>2]=p>>>0>D>>>0?D:p;c[e+19316>>2]=5388016+(t*20|0)}c[k>>2]=1}}while(0);if((c[e+15688>>2]|0)!=0){yDb(c[e+4>>2]|0,48,2229144,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;$1a(e)}N=e+16016|0;c[N>>2]=0;if((c[e+15692>>2]|0)==0){a[e+16020|0]=1;c[N>>2]=0;Fa=q;break}w=c[I>>2]|0;t=d[(c[y>>2]|0)+(w>>>3)|0]<<(w&7)>>>7;c[I>>2]=((w|0)<(c[r>>2]|0))+w;w=t&1;a[e+16020|0]=w;if(w<<24>>24==0){Fa=q;break}w=c[I>>2]|0;t=c[r>>2]|0;p=(c[y>>2]|0)+(w>>>3)|0;D=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(w&7)>>>30;p=w+2|0;c[I>>2]=t>>>0>p>>>0?p:t;c[N>>2]=c[1094552+(D<<2)>>2];Fa=q}else if((j|0)==1|(j|0)==7){D=e+19224|0;do{if((c[D>>2]|0)==1){N=_1a(c[e+19324>>2]|0,e+19328|0,e)|0;if((N|0)<0){o=-1;i=g;return o|0}else{yDb(c[e+4>>2]|0,48,2164272,(z=i,i=i+16|0,c[z>>2]=N>>1,c[z+8>>2]=N&1,z)|0);i=z;break}}}while(0);q=_1a(c[e+19252>>2]|0,e+19256|0,e)|0;if((q|0)<0){o=-1;i=g;return o|0}N=e+4|0;yDb(c[N>>2]|0,48,2157480,(z=i,i=i+16|0,c[z>>2]=q>>1,c[z+8>>2]=q&1,z)|0);i=z;q=e+19268|0;a[q]=0;if((c[e+15696>>2]|0)==0){Fa=D;break}if(!((d[e+15728|0]|0)>>>0<9>>>0)){Fa=D;break}t=c[I>>2]|0;p=c[y>>2]|0;w=d[p+(t>>>3)|0]|0;B=c[r>>2]|0;u=((t|0)<(B|0))+t|0;c[I>>2]=u;if((w&128>>>((t&7)>>>0)|0)==0){a[q]=0;Fa=D;break}t=d[p+(u>>>3)|0]<<(u&7)>>>7;c[I>>2]=((u|0)<(B|0))+u;u=(t&1)+1|0;a[q]=u;if((u&255|0)!=2){Fa=D;break}u=_1a(c[e+19260>>2]|0,e+19264|0,e)|0;if((u|0)<0){o=-1;i=g;return o|0}else{yDb(c[N>>2]|0,48,2150664,(z=i,i=i+16|0,c[z>>2]=u>>1,c[z+8>>2]=u&1,z)|0);i=z;Fa=D;break}}else{Fa=e+19224|0}}while(0);do{if((c[Fa>>2]|0)!=0){if((c[e+13924>>2]|0)!=0){break}j=e+15720|0;c[j>>2]=c[j>>2]<<1;j=e+15724|0;c[j>>2]=c[j>>2]<<1}}while(0);Fa=c[I>>2]|0;j=c[y>>2]|0;y=d[j+(Fa>>>3)|0]|0;k=c[r>>2]|0;Ia=((Fa|0)<(k|0))+Fa|0;c[I>>2]=Ia;if((y&128>>>((Fa&7)>>>0)|0)==0){Ja=0}else{Fa=d[j+(Ia>>>3)|0]<<(Ia&7)>>>7;c[I>>2]=((Ia|0)<(k|0))+Ia;Ja=(Fa&1)+1|0}c[e+16008>>2]=Ja;Ja=c[L>>2]|0;if((Ja|0)==1|(Ja|0)==7){Ja=c[I>>2]|0;Fa=d[j+(Ja>>>3)|0]|0;Ia=c[r>>2]|0;k=((Ja|0)<(Ia|0))+Ja|0;c[I>>2]=k;if((Fa&128>>>((Ja&7)>>>0)|0)==0){Ka=0}else{Ja=d[j+(k>>>3)|0]<<(k&7)>>>7;c[I>>2]=((k|0)<(Ia|0))+k;Ka=(Ja&1)+1|0}c[e+16012>>2]=Ka}Ka=c[I>>2]|0;Ja=d[j+(Ka>>>3)|0]<<(Ka&7)>>>7;c[I>>2]=((Ka|0)<(c[r>>2]|0))+Ka;c[e+14072>>2]=Ja&1;Ja=c[L>>2]|0;if(!((Ja|0)==1|(Ja|0)==7)){c[e+19548>>2]=0;o=0;i=g;return o|0}if((c[e+15688>>2]|0)==0){La=Ja}else{yDb(c[e+4>>2]|0,48,2229144,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;$1a(e);La=c[L>>2]|0}z=e+19548|0;c[z>>2]=0;if((La|0)!=7){o=0;i=g;return o|0}c[L>>2]=3;c[z>>2]=1;o=0;i=g;return o|0}function b2a(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[b+19276>>2]=0;c[b+19272>>2]=0;if(a[1096632]|0){d=b+15728|0;a[d]=-1;f=b+16080|0;a[f]=0;return 0}c[1346959]=5386736;c[1346961]=128;N_(5387832,7,23,1099824,1,1,1099800,1,1,0,0,0,4)|0;c[1313667]=5386704;c[1313669]=8;N_(5254664,3,4,1095248,1,1,1095240,1,1,0,0,0,4)|0;c[1313661]=5384480;c[1313663]=556;N_(5254640,9,64,1095176,1,1,1095048,2,2,0,0,0,4)|0;c[1346813]=5384416;c[1346815]=16;N_(5387248,4,7,1096648,1,1,1096640,1,1,0,0,0,4)|0;g=0;while(1){h=g*3|0;i=e[135048+(h<<1)>>1]|0;c[5254452+(g*20|0)>>2]=5254928+(i<<2);j=e[135048+(h+1<<1)>>1]|0;c[5254460+(g*20|0)>>2]=j-i;N_(5254448+(g*20|0)|0,9,16,1094504+(g<<4)|0,1,1,1094408+(g<<5)|0,2,2,0,0,0,4)|0;c[5254516+(g*20|0)>>2]=5254928+(j<<2);i=e[135048+(h+2<<1)>>1]|0;c[5254524+(g*20|0)>>2]=i-j;N_(5254512+(g*20|0)|0,5,8,1094688+(g<<3)|0,1,1,1094664+(g<<3)|0,1,1,0,0,0,4)|0;c[5254580+(g*20|0)>>2]=5254928+(i<<2);c[5254588+(g*20|0)>>2]=(e[135048+(h+3<<1)>>1]|0)-i;N_(5254576+(g*20|0)|0,6,15,1094760+(g*15|0)|0,1,1,1094712+(g*15|0)|0,1,1,0,0,0,4)|0;i=g+1|0;if((i|0)<3){g=i}else{k=0;break}}while(1){g=k*3|0;i=e[135048+(g+9<<1)>>1]|0;c[5388020+(k*20|0)>>2]=5254928+(i<<2);h=e[135048+(g+10<<1)>>1]|0;c[5388028+(k*20|0)>>2]=h-i;N_(5388016+(k*20|0)|0,6,16,1100208+(k<<4)|0,1,1,1100144+(k<<4)|0,1,1,0,0,0,4)|0;c[5387756+(k*20|0)>>2]=5254928+(h<<2);i=e[135048+(g+11<<1)>>1]|0;c[5387764+(k*20|0)>>2]=i-h;N_(5387752+(k*20|0)|0,9,64,1099496+(k<<6)|0,1,1,1098984+(k<<7)|0,2,2,0,0,0,4)|0;c[5254692+(k*20|0)>>2]=5254928+(i<<2);c[5254700+(k*20|0)>>2]=(e[135048+(g+12<<1)>>1]|0)-i;N_(5254688+(k*20|0)|0,9,73,1095864+(k*73|0)|0,1,1,1095280+(k*146|0)|0,2,2,0,0,0,4)|0;i=k+1|0;if((i|0)<4){k=i}else{l=0;break}}while(1){k=l<<1;i=e[135048+(k+21<<1)>>1]|0;c[5387860+(l*20|0)>>2]=5254928+(i<<2);g=e[135048+(k+22<<1)>>1]|0;c[5387868+(l*20|0)>>2]=g-i;N_(5387856+(l*20|0)|0,9,c[1100112+(l<<2)>>2]|0,147540+(l*1488|0)|0,8,4,147536+(l*1488|0)|0,8,4,0,0,0,4)|0;c[5388100+(l*20|0)>>2]=5254928+(g<<2);c[5388108+(l*20|0)>>2]=(e[135048+(k+23<<1)>>1]|0)-g;N_(5388096+(l*20|0)|0,9,126,1104304+(l*126|0)|0,1,1,1100272+(l*504|0)|0,4,4,0,0,0,4)|0;g=l+1|0;if((g|0)<8){l=g}else{m=0;break}}do{l=m*3|0;g=e[135048+(l+37<<1)>>1]|0;c[5254852+(m*20|0)>>2]=5254928+(g<<2);k=e[135048+(l+38<<1)>>1]|0;c[5254860+(m*20|0)>>2]=k-g;N_(5254848+(m*20|0)|0,9,15,1096568+(m*15|0)|0,1,1,1096448+(m*30|0)|0,2,2,0,0,0,4)|0;c[5254772+(m*20|0)>>2]=5254928+(k<<2);g=e[135048+(l+39<<1)>>1]|0;c[5254780+(m*20|0)>>2]=g-k;N_(5254768+(m*20|0)|0,6,9,1096408+(m*9|0)|0,1,1,1096368+(m*9|0)|0,1,1,0,0,0,4)|0;c[5388340+(m*20|0)>>2]=5254928+(g<<2);c[5388348+(m*20|0)>>2]=(e[135048+(l+40<<1)>>1]|0)-g;N_(5388336+(m*20|0)|0,9,72,1106496+(m*72|0)|0,1,1,1105344+(m*288|0)|0,4,4,0,0,0,4)|0;m=m+1|0;}while((m|0)<4);c[1347065]=5365296;c[1347067]=8;N_(5388256,3,4,1105328,1,1,1105312,1,1,0,0,0,4)|0;c[1347070]=5365328;c[1347072]=8;N_(5388276,3,4,1105332,1,1,1105316,1,1,0,0,0,4)|0;c[1347075]=5365360;c[1347077]=8;N_(5388296,3,4,1105336,1,1,1105320,1,1,0,0,0,4)|0;c[1347080]=5365392;c[1347082]=8;N_(5388316,3,4,1105340,1,1,1105324,1,1,0,0,0,4)|0;m=0;do{g=m*3|0;l=e[135048+(g+53<<1)>>1]|0;c[5387596+(m*20|0)>>2]=5254928+(l<<2);k=e[135048+(g+54<<1)>>1]|0;c[5387604+(m*20|0)>>2]=k-l;N_(5387592+(m*20|0)|0,9,63,1097888+(m*63|0)|0,1,1,1096880+(m*126|0)|0,2,2,0,0,0,4)|0;c[5387276+(m*20|0)>>2]=5254928+(k<<2);l=e[135048+(g+55<<1)>>1]|0;c[5387284+(m*20|0)>>2]=l-k;N_(5387272+(m*20|0)|0,5,8,1096720+(m<<3)|0,1,1,1096656+(m<<3)|0,1,1,0,0,0,4)|0;c[5387436+(m*20|0)>>2]=5254928+(l<<2);c[5387444+(m*20|0)>>2]=(e[135048+(g+56<<1)>>1]|0)-l;N_(5387432+(m*20|0)|0,5,6,1096832+(m*6|0)|0,1,1,1096784+(m*6|0)|0,1,1,0,0,0,4)|0;m=m+1|0;}while((m|0)<8);a[1096632]=1;d=b+15728|0;a[d]=-1;f=b+16080|0;a[f]=0;return 0}function c2a(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((e|0)<=0){return}i=h+8|0;j=h|0;k=h+16|0;if((f|0)>0){l=b;m=1}else{b=1;while(1){h=c[i>>2]|0;c[i>>2]=((h|0)<(c[k>>2]|0))+h;if((b|0)>=(e|0)){break}b=b+1|0}return}while(1){b=c[i>>2]|0;h=c[j>>2]|0;n=d[h+(b>>>3)|0]|0;o=c[k>>2]|0;p=((b|0)<(o|0))+b|0;c[i>>2]=p;a:do{if((n&128>>>((b&7)>>>0)|0)==0){q=0;do{a[l+(ba(q,g)|0)|0]=0;q=q+1|0;}while((q|0)<(f|0))}else{q=0;r=p;s=h;t=o;while(1){u=(d[s+(r>>>3)|0]|0)<<(r&7)>>>7;c[i>>2]=((r|0)<(t|0))+r;a[l+(ba(q,g)|0)|0]=u&1;u=q+1|0;if((u|0)>=(f|0)){break a}q=u;r=c[i>>2]|0;s=c[j>>2]|0;t=c[k>>2]|0}}}while(0);if((m|0)>=(e|0)){break}l=l+1|0;m=m+1|0}return}function d2a(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((f|0)<=0){return}i=h+8|0;j=h|0;k=h+16|0;if((e|0)>0){l=b;m=1}else{h=b;b=1;while(1){n=c[i>>2]|0;o=d[(c[j>>2]|0)+(n>>>3)|0]|0;c[i>>2]=((n|0)<(c[k>>2]|0))+n;if((o&128>>>((n&7)>>>0)|0)==0){TGb(h|0,0,e|0)|0}if((b|0)>=(f|0)){break}h=h+g|0;b=b+1|0}return}while(1){b=c[i>>2]|0;h=c[j>>2]|0;n=d[h+(b>>>3)|0]|0;o=c[k>>2]|0;p=((b|0)<(o|0))+b|0;c[i>>2]=p;a:do{if((n&128>>>((b&7)>>>0)|0)==0){TGb(l|0,0,e|0)|0}else{q=0;r=p;s=h;t=o;while(1){u=(d[s+(r>>>3)|0]|0)<<(r&7)>>>7;c[i>>2]=((r|0)<(t|0))+r;a[l+q|0]=u&1;u=q+1|0;if((u|0)>=(e|0)){break a}q=u;r=c[i>>2]|0;s=c[j>>2]|0;t=c[k>>2]|0}}}while(0);if((m|0)>=(f|0)){break}l=l+g|0;m=m+1|0}return}function e2a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;c[b+14100>>2]=0;if((c[b+19552>>2]|0)!=0){e=d[b+15728|0]|0;nlb(b+14672|0,(e<<1)+(d[b+16072|0]|0)|0,e&-((a[b+16081|0]|0)==0|0))|0;return}c[b+19564>>2]=0;c[b+19568>>2]=-1;c[b+19572>>2]=1;c[b+19576>>2]=2;e=b+9992|0;f=c[e>>2]|0;if((f|0)==1){if((c[b+15660>>2]|0)==3){f2a(b);return}else{g2a(b);return}}else if((f|0)==2){if((c[b+19544>>2]|0)==0){h2a(b);return}g=b|0;h=b+952|0;if((c[h>>2]|0)==0){return}i=b+808|0;j=b+812|0;Lkb(b+14424|0,0,c[i>>2]|0,(c[b+116>>2]|0)-1|0,(c[j>>2]|0)-1|0,112);k=b+14084|0;c[k>>2]=1;l=c[i>>2]|0;i=b+12480|0;c[i>>2]=l;if((l|0)<(c[j>>2]|0)){l=b+12476|0;m=b+19428|0;n=b+4|0;o=b+12496|0;p=b+12500|0;q=b+12504|0;r=b+12508|0;s=b+12512|0;t=b+12516|0;u=b+12544|0;v=b+12548|0;w=b+12552|0;x=b+148|0;y=b+956|0;z=b+152|0;A=b+960|0;B=b+19436|0;C=b+19231|0;D=b+9856|0;do{c[l>>2]=0;$Oa(g);do{if((c[m>>2]|0)!=0){if((c[B>>2]|0)!=(d[C]|0)){break}E=c[D>>2]|0;c[u>>2]=(c[u>>2]|0)+(c[E+32>>2]|0);c[v>>2]=(c[v>>2]|0)+(c[E+36>>2]|0);c[w>>2]=(c[w>>2]|0)+(c[E+40>>2]|0)}}while(0);E=8>>>((c[(c[n>>2]|0)+800>>2]|0)>>>0);c[o>>2]=(c[o>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;c[q>>2]=(c[q>>2]|0)+2;c[r>>2]=(c[r>>2]|0)+2;c[s>>2]=(c[s>>2]|0)+1;c[t>>2]=(c[t>>2]|0)+1;F=(c[u>>2]|0)+(E<<1)|0;c[u>>2]=F;c[v>>2]=(c[v>>2]|0)+E;c[w>>2]=(c[w>>2]|0)+E;E=c[x>>2]|0;UGb(F|0,(c[h>>2]|0)+(ba(c[i>>2]<<4,E)|0)|0,E<<4)|0;E=c[z>>2]|0;UGb(c[v>>2]|0,(c[y>>2]|0)+(ba(c[i>>2]<<3,E)|0)|0,E<<3)|0;E=c[z>>2]|0;UGb(c[w>>2]|0,(c[A>>2]|0)+(ba(c[i>>2]<<3,E)|0)|0,E<<3)|0;_Oa(g,c[i>>2]<<4,16);c[k>>2]=0;E=(c[i>>2]|0)+1|0;c[i>>2]=E;}while((E|0)<(c[j>>2]|0))}c[e>>2]=2;return}else if((f|0)==3){if((c[b+19548>>2]|0)==0){i2a(b);return}if((c[b+15660>>2]|0)==3){f2a(b);return}else{g2a(b);return}}else{return}}function f2a(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0;g=i;i=i+40|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=f|0;o=f+15728|0;p=d[o]|0;q=c[f+16012>>2]|0;if((q|0)==1){c[f+16032>>2]=0}else if((q|0)==2){c[f+16032>>2]=4}else if((q|0)==0){c[f+16032>>2]=(c[f+16040>>2]|0)<9?6:2}q=c[f+16008>>2]|0;if((q|0)==0){c[f+16036>>2]=(c[f+16040>>2]|0)<9?7:3}else if((q|0)==1){c[f+16036>>2]=1}else if((q|0)==2){c[f+16036>>2]=5}q=f+12480|0;r=f+12476|0;c[r>>2]=0;c[f+12488>>2]=1;s=f+14084|0;c[s>>2]=1;t=f+808|0;u=c[t>>2]|0;c[q>>2]=u;if((u|0)==0){v=0;w=f+19428|0;x=f+12496|0;y=f+128|0;z=f+9904|0}else{c[r>>2]=0;$Oa(n);u=f+19428|0;do{if((c[u>>2]|0)!=0){if((c[f+19436>>2]|0)!=(d[f+19231|0]|0)){break}A=c[f+9856>>2]|0;B=f+12544|0;c[B>>2]=(c[B>>2]|0)+(c[A+32>>2]|0);B=f+12548|0;c[B>>2]=(c[B>>2]|0)+(c[A+36>>2]|0);B=f+12552|0;c[B>>2]=(c[B>>2]|0)+(c[A+40>>2]|0)}}while(0);A=f+12496|0;B=f+128|0;C=c[B>>2]|0;D=f+9904|0;TGb((c[D>>2]|0)+((c[A>>2]|0)-C)|0,0,C+1|0)|0;v=c[q>>2]|0;w=u;x=A;y=B;z=D}D=f+812|0;B=f+116|0;A=f+13836|0;u=f+19564|0;C=f+19556|0;E=f+4|0;F=f+12500|0;G=f+12504|0;H=f+12508|0;I=f+12512|0;J=f+12516|0;K=f+12544|0;L=f+12548|0;M=f+12552|0;N=f+10096|0;O=f+124|0;P=f+19472|0;Q=f+9160|0;R=f+19468|0;S=f+9152|0;T=f+19328|0;U=f+14128|0;V=f+14136|0;W=f+14120|0;X=f+19256|0;Y=f+19252|0;Z=f+176|0;_=f+19268|0;$=f+19264|0;aa=f+19260|0;ca=f+16004|0;da=f+9136|0;ea=f+9888|0;fa=f+168|0;ga=f+9892|0;ha=f+172|0;ia=f+16044|0;ja=f+16048|0;ka=f+16032|0;la=f+16036|0;ma=f+14072|0;na=f+60|0;oa=f+15332|0;pa=f+9912|0;qa=f+16072|0;ra=f+15992|0;sa=f+16081|0;ta=f+15988|0;ua=f+19224|0;va=f+19332|0;wa=f+15794|0;xa=f+15858|0;ya=f+15922|0;za=f+15576|0;Aa=f+15376|0;Ba=f+15372|0;Ca=f+19576|0;Da=f+19568|0;Ea=f+19572|0;Fa=f+16005|0;Ga=f+16007|0;Ha=f+15729|0;Ia=f+16006|0;Ja=f+120|0;Ka=f+19324|0;La=f+19436|0;Ma=f+19231|0;Na=f+9856|0;Oa=p;p=v;a:while(1){v=(p|0)<(c[D>>2]|0);c[r>>2]=0;$Oa(n);do{if((c[w>>2]|0)!=0){if((c[La>>2]|0)!=(d[Ma]|0)){break}Pa=c[Na>>2]|0;c[K>>2]=(c[K>>2]|0)+(c[Pa+32>>2]|0);c[L>>2]=(c[L>>2]|0)+(c[Pa+36>>2]|0);c[M>>2]=(c[M>>2]|0)+(c[Pa+40>>2]|0)}}while(0);Qa=c[B>>2]|0;Ra=(c[r>>2]|0)<(Qa|0);if(!v){break}if(Ra){Pa=Oa;while(1){Sa=c[u>>2]|0;Ta=c[C>>2]|0;Ua=8>>>((c[(c[E>>2]|0)+800>>2]|0)>>>0);c[x>>2]=(c[x>>2]|0)+2;c[F>>2]=(c[F>>2]|0)+2;c[G>>2]=(c[G>>2]|0)+2;c[H>>2]=(c[H>>2]|0)+2;c[I>>2]=(c[I>>2]|0)+1;c[J>>2]=(c[J>>2]|0)+1;c[K>>2]=(c[K>>2]|0)+(Ua<<1);c[L>>2]=(c[L>>2]|0)+Ua;c[M>>2]=(c[M>>2]|0)+Ua;me[c[N>>2]&511](Ta+(Sa*768|0)|0);Ua=(ba(c[O>>2]|0,c[q>>2]|0)|0)+(c[r>>2]|0)|0;c[(c[Q>>2]|0)+(Ua+(c[P>>2]|0)<<2)>>2]=1;Va=(c[R>>2]|0)+(c[x>>2]|0)|0;Wa=c[S>>2]|0;b[Wa+(Va<<2)>>1]=0;b[Wa+(Va<<2)+2>>1]=0;if((c[T>>2]|0)!=0){Va=c[U>>2]|0;Wa=d[(c[W>>2]|0)+(Va>>>3)|0]<<(Va&7)>>>7;c[U>>2]=((Va|0)<(c[V>>2]|0))+Va;a[(c[Ka>>2]|0)+Ua|0]=Wa&1}Wa=c[1620609]|0;Va=c[U>>2]|0;Xa=c[V>>2]|0;Ya=c[W>>2]|0;Za=Ya+(Va>>>3)|0;_a=(fe(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(Va&7)>>>23;Za=b[Wa+(_a<<2)>>1]|0;$a=b[Wa+(_a<<2)+2>>1]|0;_a=$a<<16>>16;if($a<<16>>16<0){$a=Va+9|0;ab=Xa>>>0>$a>>>0?$a:Xa;$a=Ya+(ab>>>3)|0;bb=((fe(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(ab&7)>>>((_a+32|0)>>>0))+Za|0;cb=b[Wa+(bb<<2)+2>>1]|0;db=b[Wa+(bb<<2)>>1]|0;eb=ab}else{cb=_a;db=Za;eb=Va}Va=cb+eb|0;Za=Xa>>>0>Va>>>0?Va:Xa;c[U>>2]=Za;if((c[X>>2]|0)==0){fb=Za;gb=d[(c[Y>>2]|0)+Ua|0]|0}else{Va=d[Ya+(Za>>>3)|0]<<(Za&7)>>>7;_a=((Za|0)<(Xa|0))+Za|0;c[U>>2]=_a;fb=_a;gb=Va&1}c[Z>>2]=gb;do{if((a[_]|0)==2){if((c[$>>2]|0)==0){break}Va=d[Ya+(fb>>>3)|0]<<(fb&7)>>>7;c[U>>2]=((fb|0)<(Xa|0))+fb;a[(c[aa>>2]|0)+Ua|0]=Va&1}}while(0);do{if((a[ca]|0)==0){hb=Pa}else{Xa=a[Fa]|0;do{if(Xa<<24>>24==3){Ya=c[U>>2]|0;if((a[Ga]|0)!=0){Va=d[(c[W>>2]|0)+(Ya>>>3)|0]|0;c[U>>2]=((Ya|0)<(c[V>>2]|0))+Ya;ib=d[(Va&128>>>((Ya&7)>>>0)|0)==0?o:Ha]|0;jb=39;break}Va=c[V>>2]|0;_a=c[W>>2]|0;Za=_a+(Ya>>>3)|0;ab=(fe(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(Ya&7)>>>29;Za=Ya+3|0;Ya=Va>>>0>Za>>>0?Za:Va;c[U>>2]=Ya;if((ab|0)==7){Za=_a+(Ya>>>3)|0;_a=(fe(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(Ya&7)>>>27;Za=Ya+5|0;c[U>>2]=Va>>>0>Za>>>0?Za:Va;ib=_a;jb=39;break}else{kb=(d[o]|0)+ab|0;break}}else{ib=Pa;jb=39}}while(0);do{if((jb|0)==39){jb=0;if((Xa<<24>>24|0)==2){lb=1<<d[Ia];jb=42}else if((Xa<<24>>24|0)==1){lb=(3<<d[Ia]|0)%15|0;jb=42}else if((Xa<<24>>24|0)==0){mb=15;jb=43}else{kb=ib;break}if((jb|0)==42){jb=0;if((lb&1|0)==0){nb=ib;ob=lb}else{mb=lb;jb=43}}do{if((jb|0)==43){jb=0;if((c[r>>2]|0)!=0){nb=ib;ob=mb;break}nb=d[Ha]|0;ob=mb}}while(0);do{if((ob&2|0)==0){pb=nb}else{if((c[s>>2]|0)==0){pb=nb;break}pb=d[Ha]|0}}while(0);do{if((ob&4|0)==0){qb=pb}else{if((c[r>>2]|0)!=((c[B>>2]|0)-1|0)){qb=pb;break}qb=d[Ha]|0}}while(0);if((ob&8|0)==0){kb=qb;break}if((c[q>>2]|0)!=((c[Ja>>2]|0)-1|0)){kb=qb;break}kb=d[Ha]|0}}while(0);if(!((kb|0)==0|(kb|0)>31)){hb=kb;break}yDb(c[E>>2]|0,16,2024400,(rb=i,i=i+8|0,c[rb>>2]=kb,rb)|0);i=rb;hb=1}}while(0);a[(c[da>>2]|0)+Ua|0]=hb;c[fa>>2]=d[(c[ea>>2]|0)+hb|0]|0;c[ha>>2]=d[(c[ga>>2]|0)+hb|0]|0;Xa=hb<<1;ab=-hb|0;_a=(hb|0)==1;Va=(hb|0)==2;Za=db;Ya=0;do{bb=5-Ya|0;Wa=Za>>>(bb>>>0)&1;$a=(Ya|0)<4;if($a){sb=c[f+12496+(Ya<<2)>>2]|0;tb=c[y>>2]|0;ub=sb-1|0;vb=c[z>>2]|0;wb=a[vb+(sb-tb)|0]|0;if((a[vb+(ub-tb)|0]|0)==wb<<24>>24){xb=a[vb+ub|0]|0}else{xb=wb}wb=xb&255^Wa;a[vb+sb|0]=wb;yb=wb}else{yb=Wa}Za=yb<<bb|Za;bb=(Ya|0)==2;if((c[s>>2]|0)==0|bb){zb=1}else{zb=(Ya|0)==3|0}c[ia>>2]=zb;Wa=c[r>>2]|0;wb=(Ya|0)==1;if((Wa|0)!=0|wb){Ab=1}else{Ab=(Ya|0)==3|0}c[ja>>2]=Ab;sb=Ta+(Sa*768|0)+(Ya<<7)|0;vb=c[($a?ka:la)>>2]|0;c[h>>2]=0;c[j>>2]=0;ub=c[Z>>2]|0;tb=(ba(c[O>>2]|0,c[q>>2]|0)|0)+Wa|0;Wa=c[ma>>2]|0;if($a){Bb=c[6482460+(Wa*20|0)>>2]|0;Cb=c[U>>2]|0;Db=c[V>>2]|0;Eb=c[W>>2]|0;Fb=Eb+(Cb>>>3)|0;Gb=(fe(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(Cb&7)>>>23;Fb=b[Bb+(Gb<<2)>>1]|0;Hb=b[Bb+(Gb<<2)+2>>1]|0;Gb=Hb<<16>>16;do{if(Hb<<16>>16<0){Ib=Cb+9|0;Jb=Db>>>0>Ib>>>0?Ib:Db;Ib=Eb+(Jb>>>3)|0;Kb=((fe(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)|0)<<(Jb&7)>>>((Gb+32|0)>>>0))+Fb|0;Ib=b[Bb+(Kb<<2)>>1]|0;Lb=b[Bb+(Kb<<2)+2>>1]|0;Kb=Lb<<16>>16;if(!(Lb<<16>>16<0)){Mb=Kb;Nb=Ib;Ob=Jb;break}Lb=Jb-Gb|0;Jb=Db>>>0>Lb>>>0?Lb:Db;Lb=Eb+(Jb>>>3)|0;Pb=((fe(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(Jb&7)>>>((Kb+32|0)>>>0))+Ib|0;Mb=b[Bb+(Pb<<2)+2>>1]|0;Nb=b[Bb+(Pb<<2)>>1]|0;Ob=Jb}else{Mb=Gb;Nb=Fb;Ob=Cb}}while(0);Cb=Mb+Ob|0;Qb=Nb;Rb=Db;Sb=Eb;Tb=Db>>>0>Cb>>>0?Cb:Db}else{Cb=c[6482500+(Wa*20|0)>>2]|0;Fb=c[U>>2]|0;Gb=c[V>>2]|0;Bb=c[W>>2]|0;Hb=Bb+(Fb>>>3)|0;Jb=(fe(d[Hb]|d[Hb+1|0]<<8|d[Hb+2|0]<<16|d[Hb+3|0]<<24|0)|0)<<(Fb&7)>>>23;Hb=b[Cb+(Jb<<2)>>1]|0;Pb=b[Cb+(Jb<<2)+2>>1]|0;Jb=Pb<<16>>16;do{if(Pb<<16>>16<0){Ib=Fb+9|0;Kb=Gb>>>0>Ib>>>0?Ib:Gb;Ib=Bb+(Kb>>>3)|0;Lb=((fe(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)|0)<<(Kb&7)>>>((Jb+32|0)>>>0))+Hb|0;Ib=b[Cb+(Lb<<2)>>1]|0;Ub=b[Cb+(Lb<<2)+2>>1]|0;Lb=Ub<<16>>16;if(!(Ub<<16>>16<0)){Vb=Lb;Wb=Ib;Xb=Kb;break}Ub=Kb-Jb|0;Kb=Gb>>>0>Ub>>>0?Ub:Gb;Ub=Bb+(Kb>>>3)|0;Yb=((fe(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Kb&7)>>>((Lb+32|0)>>>0))+Ib|0;Vb=b[Cb+(Yb<<2)+2>>1]|0;Wb=b[Cb+(Yb<<2)>>1]|0;Xb=Kb}else{Vb=Jb;Wb=Hb;Xb=Fb}}while(0);Fb=Vb+Xb|0;Qb=Wb;Rb=Gb;Sb=Bb;Tb=Gb>>>0>Fb>>>0?Fb:Gb}c[U>>2]=Tb;b:do{if((Qb|0)<0){yDb(c[E>>2]|0,16,2021120,(rb=i,i=i+1|0,i=i+7&-8,c[rb>>2]=0,rb)|0);i=rb}else{do{if((Qb|0)==0){Zb=0}else if((Qb|0)==119){Fb=Sb+(Tb>>>3)|0;Hb=(fe(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(Tb&7);if(_a){Fb=Tb+10|0;Jb=Rb>>>0>Fb>>>0?Fb:Rb;c[U>>2]=Jb;_b=Hb>>>22;$b=Jb;jb=86;break}if(Va){Jb=Tb+9|0;Fb=Rb>>>0>Jb>>>0?Jb:Rb;c[U>>2]=Fb;_b=Hb>>>23;$b=Fb;jb=86;break}else{Fb=Tb+8|0;Jb=Rb>>>0>Fb>>>0?Fb:Rb;c[U>>2]=Jb;_b=Hb>>>24;$b=Jb;jb=86;break}}else{if(_a){Jb=Sb+(Tb>>>3)|0;Hb=(fe(d[Jb]|d[Jb+1|0]<<8|d[Jb+2|0]<<16|d[Jb+3|0]<<24|0)|0)<<(Tb&7)>>>30;Jb=Tb+2|0;Fb=Rb>>>0>Jb>>>0?Jb:Rb;c[U>>2]=Fb;_b=(Hb|Qb<<2)-3|0;$b=Fb;jb=86;break}if(!Va){_b=Qb;$b=Tb;jb=86;break}Fb=d[Sb+(Tb>>>3)|0]<<(Tb&7)>>>7;Hb=((Tb|0)<(Rb|0))+Tb|0;c[U>>2]=Hb;_b=(Fb&1|Qb<<1)-1|0;$b=Hb;jb=86}}while(0);do{if((jb|0)==86){jb=0;Hb=d[Sb+($b>>>3)|0]|0;c[U>>2]=(($b|0)<(Rb|0))+$b;if((Hb&128>>>(($b&7)>>>0)|0)==0){Zb=_b;break}Zb=-_b|0}}while(0);Hb=(w2a(n,Ya,zb,Ab,j,h)|0)+Zb|0;b[c[j>>2]>>1]=Hb;b[sb>>1]=ba(c[($a?fa:ha)>>2]|0,Hb)|0;Hb=(Ab|zb|0)==0?0:ub;Fb=c[pa>>2]|0;Jb=c[f+12496+(Ya<<2)>>2]<<4;Cb=Fb+(Jb<<1)|0;if((d[o]|0)==(hb|0)){ac=d[qa]|0}else{ac=0}Pb=ac+Xa|0;Wa=c[h>>2]|0;Db=(Wa|0)==0;if(Db){bc=Jb-(c[f+12520+(Ya<<2)>>2]<<4)|0}else{bc=Jb-16|0}Eb=Fb+(bc<<1)|0;Kb=c[da>>2]|0;Yb=a[Kb+tb|0]|0;if(Db|(Ab|0)==0|(tb|0)==0){cc=0}else{cc=a[Kb+(tb-1)|0]|0}Ib=(Wa|0)!=0;do{if(Ib|(zb|0)==0){dc=cc}else{Lb=c[O>>2]|0;if((tb|0)<(Lb|0)){dc=cc;break}dc=a[Kb+(tb-Lb)|0]|0}}while(0);Kb=(Ya|0)==3?Yb:Db&bb?Yb:Ib&wb?Yb:dc;c:do{if((yb|0)==0){Lb=Cb;TGb(Lb|0,0,32)|0;Ub=(Hb|0)!=0;do{if(Db){if(!Ub){ec=1;break c}UGb(Fb+((Jb|8)<<1)|0,Fb+(bc+8<<1)|0,16)|0;if((Kb|0)==0|(Yb|0)==(Kb|0)){break}fc=d[o]|0;if((Yb|0)==(fc|0)){gc=d[qa]|0}else{gc=0}hc=gc+(Yb<<1)|0;if((Kb|0)==(fc|0)){ic=d[qa]|0}else{ic=0}if((hc-1|0)<1){break b}fc=Fb+((Jb|9)<<1)|0;jc=ba(c[1098544+(hc-2<<2)>>2]|0,(Kb<<1)-1+ic|0)|0;b[fc>>1]=(ba(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|10)<<1)|0;b[fc>>1]=(ba(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|11)<<1)|0;b[fc>>1]=(ba(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|12)<<1)|0;b[fc>>1]=(ba(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|13)<<1)|0;b[fc>>1]=(ba(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|14)<<1)|0;b[fc>>1]=(ba(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|15)<<1)|0;b[fc>>1]=(ba(jc,b[fc>>1]|0)|0)+131072>>18;jb=143}else{if(!Ub){ec=1;break c}UGb(Lb|0,Eb|0,16)|0;if((Kb|0)==0|(Yb|0)==(Kb|0)){break}fc=d[o]|0;if((Yb|0)==(fc|0)){kc=d[qa]|0}else{kc=0}jc=kc+(Yb<<1)|0;if((Kb|0)==(fc|0)){lc=d[qa]|0}else{lc=0}if((jc-1|0)<1){break b}fc=Fb+((Jb|1)<<1)|0;hc=ba(c[1098544+(jc-2<<2)>>2]|0,(Kb<<1)-1+lc|0)|0;b[fc>>1]=(ba(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|2)<<1)|0;b[fc>>1]=(ba(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|3)<<1)|0;b[fc>>1]=(ba(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|4)<<1)|0;b[fc>>1]=(ba(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|5)<<1)|0;b[fc>>1]=(ba(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|6)<<1)|0;b[fc>>1]=(ba(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|7)<<1)|0;b[fc>>1]=(ba(hc,b[fc>>1]|0)|0)+131072>>18;jb=143}}while(0);if((jb|0)==143){jb=0;if(!Ub){ec=1;break}}if(Db){Lb=Jb|8;fc=c[ra>>2]|0;hc=1;while(1){jc=ba(b[Fb+(hc+Lb<<1)>>1]|0,Pb)|0;mc=jc&65535;nc=Ta+(Sa*768|0)+(Ya<<7)+(hc<<fc<<1)|0;b[nc>>1]=mc;if(!((a[sa]|0)!=0|mc<<16>>16==0)){b[nc>>1]=(mc<<16>>16<0?ab:hb)+jc}jc=hc+1|0;if((jc|0)<8){hc=jc}else{ec=63;break}}}else{hc=c[ta>>2]|0;fc=1;while(1){Lb=ba(b[Fb+(fc+Jb<<1)>>1]|0,Pb)|0;Ub=Lb&65535;jc=Ta+(Sa*768|0)+(Ya<<7)+(fc<<hc<<1)|0;b[jc>>1]=Ub;if(!((a[sa]|0)!=0|Ub<<16>>16==0)){b[jc>>1]=(Ub<<16>>16<0?ab:hb)+Lb}Lb=fc+1|0;if((Lb|0)<8){fc=Lb}else{ec=63;break}}}}else{c[k>>2]=0;do{if((c[Z>>2]|0)==0){oc=(c[ua>>2]|0)==1?va:wa}else{if((Hb|0)==0){if((c[ua>>2]|0)==1){oc=va;break}}oc=Db?xa:ya}}while(0);fc=1;while(1){v2a(f,k,l,m,vb);hc=(c[l>>2]|0)+fc|0;if((hc|0)>63){pc=hc;break}Lb=hc+1|0;b[Ta+(Sa*768|0)+(Ya<<7)+(d[oc+hc|0]<<1)>>1]=c[m>>2];if((c[k>>2]|0)==0){fc=Lb}else{pc=Lb;break}}fc=(Hb|0)!=0;do{if(fc){if((Kb|0)==0|(Yb|0)==(Kb|0)){if((Wa|0)==0){Lb=c[ra>>2]|0;hc=Ta+(Sa*768|0)+(Ya<<7)+(1<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+9<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(2<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+10<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(3<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+11<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(4<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+12<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(5<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+13<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(6<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+14<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(7<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+15<<1)>>1]|0);break}else{hc=c[ta>>2]|0;Lb=Ta+(Sa*768|0)+(Ya<<7)+(1<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+1<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(2<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+2<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(3<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+3<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(4<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+4<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(5<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+5<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(6<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+6<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(7<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+7<<1)>>1]|0);break}}Lb=d[o]|0;if((Yb|0)==(Lb|0)){qc=d[qa]|0}else{qc=0}hc=qc+(Yb<<1)|0;if((Kb|0)==(Lb|0)){rc=d[qa]|0}else{rc=0}Lb=(Kb<<1)-1+rc|0;if((hc-1|0)<1){break b}Ub=c[1098544+(hc-2<<2)>>2]|0;if((Wa|0)==0){hc=c[ra>>2]|0;jc=ba(Ub,Lb)|0;mc=(ba(jc,b[Fb+(bc+9<<1)>>1]|0)|0)+131072>>18;nc=Ta+(Sa*768|0)+(Ya<<7)+(1<<hc<<1)|0;b[nc>>1]=mc+(e[nc>>1]|0);nc=(ba(jc,b[Fb+(bc+10<<1)>>1]|0)|0)+131072>>18;mc=Ta+(Sa*768|0)+(Ya<<7)+(2<<hc<<1)|0;b[mc>>1]=nc+(e[mc>>1]|0);mc=(ba(jc,b[Fb+(bc+11<<1)>>1]|0)|0)+131072>>18;nc=Ta+(Sa*768|0)+(Ya<<7)+(3<<hc<<1)|0;b[nc>>1]=mc+(e[nc>>1]|0);nc=(ba(jc,b[Fb+(bc+12<<1)>>1]|0)|0)+131072>>18;mc=Ta+(Sa*768|0)+(Ya<<7)+(4<<hc<<1)|0;b[mc>>1]=nc+(e[mc>>1]|0);mc=(ba(jc,b[Fb+(bc+13<<1)>>1]|0)|0)+131072>>18;nc=Ta+(Sa*768|0)+(Ya<<7)+(5<<hc<<1)|0;b[nc>>1]=mc+(e[nc>>1]|0);nc=(ba(jc,b[Fb+(bc+14<<1)>>1]|0)|0)+131072>>18;mc=Ta+(Sa*768|0)+(Ya<<7)+(6<<hc<<1)|0;b[mc>>1]=nc+(e[mc>>1]|0);mc=(ba(jc,b[Fb+(bc+15<<1)>>1]|0)|0)+131072>>18;jc=Ta+(Sa*768|0)+(Ya<<7)+(7<<hc<<1)|0;b[jc>>1]=mc+(e[jc>>1]|0);break}else{jc=c[ta>>2]|0;mc=ba(Ub,Lb)|0;Lb=(ba(mc,b[Fb+(bc+1<<1)>>1]|0)|0)+131072>>18;Ub=Ta+(Sa*768|0)+(Ya<<7)+(1<<jc<<1)|0;b[Ub>>1]=Lb+(e[Ub>>1]|0);Ub=(ba(mc,b[Fb+(bc+2<<1)>>1]|0)|0)+131072>>18;Lb=Ta+(Sa*768|0)+(Ya<<7)+(2<<jc<<1)|0;b[Lb>>1]=Ub+(e[Lb>>1]|0);Lb=(ba(mc,b[Fb+(bc+3<<1)>>1]|0)|0)+131072>>18;Ub=Ta+(Sa*768|0)+(Ya<<7)+(3<<jc<<1)|0;b[Ub>>1]=Lb+(e[Ub>>1]|0);Ub=(ba(mc,b[Fb+(bc+4<<1)>>1]|0)|0)+131072>>18;Lb=Ta+(Sa*768|0)+(Ya<<7)+(4<<jc<<1)|0;b[Lb>>1]=Ub+(e[Lb>>1]|0);Lb=(ba(mc,b[Fb+(bc+5<<1)>>1]|0)|0)+131072>>18;Ub=Ta+(Sa*768|0)+(Ya<<7)+(5<<jc<<1)|0;b[Ub>>1]=Lb+(e[Ub>>1]|0);Ub=(ba(mc,b[Fb+(bc+6<<1)>>1]|0)|0)+131072>>18;Lb=Ta+(Sa*768|0)+(Ya<<7)+(6<<jc<<1)|0;b[Lb>>1]=Ub+(e[Lb>>1]|0);Lb=(ba(mc,b[Fb+(bc+7<<1)>>1]|0)|0)+131072>>18;mc=Ta+(Sa*768|0)+(Ya<<7)+(7<<jc<<1)|0;b[mc>>1]=Lb+(e[mc>>1]|0);break}}}while(0);mc=c[ta>>2]|0;Lb=c[ra>>2]|0;b[Fb+((Jb|1)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(1<<mc<<1)>>1]|0;b[Fb+((Jb|9)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(1<<Lb<<1)>>1]|0;b[Fb+((Jb|2)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(2<<mc<<1)>>1]|0;b[Fb+((Jb|10)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(2<<Lb<<1)>>1]|0;b[Fb+((Jb|3)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(3<<mc<<1)>>1]|0;b[Fb+((Jb|11)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(3<<Lb<<1)>>1]|0;b[Fb+((Jb|4)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(4<<mc<<1)>>1]|0;b[Fb+((Jb|12)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(4<<Lb<<1)>>1]|0;b[Fb+((Jb|5)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(5<<mc<<1)>>1]|0;b[Fb+((Jb|13)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(5<<Lb<<1)>>1]|0;b[Fb+((Jb|6)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(6<<mc<<1)>>1]|0;b[Fb+((Jb|14)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(6<<Lb<<1)>>1]|0;b[Fb+((Jb|7)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(7<<mc<<1)>>1]|0;b[Fb+((Jb|15)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(7<<Lb<<1)>>1]|0;Lb=1;do{mc=Ta+(Sa*768|0)+(Ya<<7)+(Lb<<1)|0;jc=b[mc>>1]|0;do{if(!(jc<<16>>16==0)){Ub=ba(jc<<16>>16,Pb)|0;hc=Ub&65535;b[mc>>1]=hc;if((a[sa]|0)!=0){break}b[mc>>1]=(hc<<16>>16<0?ab:hb)+Ub}}while(0);Lb=Lb+1|0;}while((Lb|0)<64);ec=fc?63:pc}}while(0);c[f+180+(Ya<<2)>>2]=ec}}while(0);if((Ya|0)>3){if((c[na>>2]&8192|0)==0){jb=156}}else{jb=156}if((jb|0)==156){jb=0;me[c[oa>>2]&511](sb)}Ya=Ya+1|0;}while((Ya|0)<6);Ya=a[_]|0;do{if(!(Ya<<24>>24==0)){ab=c[r>>2]|0;Sa=(ba(c[O>>2]|0,c[q>>2]|0)|0)+ab|0;Ta=Ya<<24>>24==1;do{if(Ta){jb=162}else{if((d[o]|0)>>>0>8>>>0){jb=162;break}if((a[(c[aa>>2]|0)+Sa|0]|0)==0){sc=ab}else{jb=162}}}while(0);do{if((jb|0)==162){jb=0;d:do{if((ab|0)!=0){do{if(!Ta){if((d[o]|0)>>>0>8>>>0){break}if((a[(c[aa>>2]|0)+(Sa-1)|0]|0)==0){break d}}}while(0);fc=c[C>>2]|0;ne[c[Aa>>2]&1023](fc+((c[Da>>2]|0)*768|0)+128|0,fc+((c[u>>2]|0)*768|0)|0);fc=c[C>>2]|0;ne[c[Aa>>2]&1023](fc+((c[Da>>2]|0)*768|0)+384|0,fc+((c[u>>2]|0)*768|0)+256|0);if((c[na>>2]&8192|0)!=0){break}fc=c[C>>2]|0;ne[c[Aa>>2]&1023](fc+((c[Da>>2]|0)*768|0)+512|0,fc+((c[u>>2]|0)*768|0)+512|0);fc=c[C>>2]|0;ne[c[Aa>>2]&1023](fc+((c[Da>>2]|0)*768|0)+640|0,fc+((c[u>>2]|0)*768|0)+640|0)}}while(0);fc=c[u>>2]|0;sb=c[C>>2]|0;ne[c[Aa>>2]&1023](sb+(fc*768|0)|0,sb+(fc*768|0)+128|0);fc=c[u>>2]|0;sb=c[C>>2]|0;ne[c[Aa>>2]&1023](sb+(fc*768|0)+256|0,sb+(fc*768|0)+384|0);fc=c[r>>2]|0;if((fc|0)!=((c[B>>2]|0)-1|0)){sc=fc;break}e:do{if((c[s>>2]|0)==0){do{if((a[_]|0)!=1){if((d[o]|0)>>>0>8>>>0){break}if((a[(c[aa>>2]|0)+(Sa-(c[O>>2]|0))|0]|0)==0){break e}}}while(0);fc=c[C>>2]|0;ne[c[Ba>>2]&1023](fc+((c[Ca>>2]|0)*768|0)+256|0,fc+((c[u>>2]|0)*768|0)|0);fc=c[C>>2]|0;ne[c[Ba>>2]&1023](fc+((c[Ca>>2]|0)*768|0)+384|0,fc+((c[u>>2]|0)*768|0)+128|0);if((c[na>>2]&8192|0)!=0){break}fc=c[C>>2]|0;ne[c[Ba>>2]&1023](fc+((c[Ca>>2]|0)*768|0)+512|0,fc+((c[u>>2]|0)*768|0)+512|0);fc=c[C>>2]|0;ne[c[Ba>>2]&1023](fc+((c[Ca>>2]|0)*768|0)+640|0,fc+((c[u>>2]|0)*768|0)+640|0)}}while(0);fc=c[u>>2]|0;sb=c[C>>2]|0;ne[c[Ba>>2]&1023](sb+(fc*768|0)|0,sb+(fc*768|0)+256|0);fc=c[u>>2]|0;sb=c[C>>2]|0;ne[c[Ba>>2]&1023](sb+(fc*768|0)+128|0,sb+(fc*768|0)+384|0);sc=c[r>>2]|0}}while(0);if((sc|0)==0){break}Ta=(a[_]|0)==1;if(!Ta){if((a[(c[aa>>2]|0)+(Sa-1)|0]|0)==0){break}}f:do{if((c[s>>2]|0)==0){do{if(!Ta){if((d[o]|0)>>>0>8>>>0){break}if((a[(c[aa>>2]|0)+(Sa-1-(c[O>>2]|0))|0]|0)==0){break f}}}while(0);ab=c[C>>2]|0;ne[c[Ba>>2]&1023](ab+((c[Ea>>2]|0)*768|0)+256|0,ab+((c[Da>>2]|0)*768|0)|0);ab=c[C>>2]|0;ne[c[Ba>>2]&1023](ab+((c[Ea>>2]|0)*768|0)+384|0,ab+((c[Da>>2]|0)*768|0)+128|0);if((c[na>>2]&8192|0)!=0){break}ab=c[C>>2]|0;ne[c[Ba>>2]&1023](ab+((c[Ea>>2]|0)*768|0)+512|0,ab+((c[Da>>2]|0)*768|0)+512|0);ab=c[C>>2]|0;ne[c[Ba>>2]&1023](ab+((c[Ea>>2]|0)*768|0)+640|0,ab+((c[Da>>2]|0)*768|0)+640|0)}}while(0);Sa=c[Da>>2]|0;Ta=c[C>>2]|0;ne[c[Ba>>2]&1023](Ta+(Sa*768|0)|0,Ta+(Sa*768|0)+256|0);Sa=c[Da>>2]|0;Ta=c[C>>2]|0;ne[c[Ba>>2]&1023](Ta+(Sa*768|0)+128|0,Ta+(Sa*768|0)+384|0)}}while(0);G2a(f);if((c[A>>2]|0)!=0){H2a(f,d[o]|0)}if((c[U>>2]|0)>(c[za>>2]|0)){jb=189;break a}Ya=(c[r>>2]|0)+1|0;c[r>>2]=Ya;if((Ya|0)<(c[B>>2]|0)){Pa=hb}else{tc=hb;break}}}else{tc=Oa}Pa=c[q>>2]|0;do{if((c[A>>2]|0)==0){_Oa(n,Pa<<4,16)}else{if((Pa|0)==0){break}_Oa(n,(Pa<<4)-16|0,16)}}while(0);c[s>>2]=0;Pa=(c[q>>2]|0)+1|0;c[q>>2]=Pa;Oa=tc;p=Pa}if((jb|0)==189){Lkb(f+14424|0,0,c[t>>2]|0,c[r>>2]|0,c[q>>2]|0,14);q=c[za>>2]|0;yDb(c[E>>2]|0,16,1987832,(rb=i,i=i+16|0,c[rb>>2]=c[U>>2],c[rb+8>>2]=q,rb)|0);i=rb;i=g;return}if(Ra){while(1){Ra=8>>>((c[(c[E>>2]|0)+800>>2]|0)>>>0);c[x>>2]=(c[x>>2]|0)+2;c[F>>2]=(c[F>>2]|0)+2;c[G>>2]=(c[G>>2]|0)+2;c[H>>2]=(c[H>>2]|0)+2;c[I>>2]=(c[I>>2]|0)+1;c[J>>2]=(c[J>>2]|0)+1;c[K>>2]=(c[K>>2]|0)+(Ra<<1);c[L>>2]=(c[L>>2]|0)+Ra;c[M>>2]=(c[M>>2]|0)+Ra;G2a(f);if((c[A>>2]|0)!=0){H2a(f,d[o]|0)}Ra=(c[r>>2]|0)+1|0;c[r>>2]=Ra;rb=c[B>>2]|0;if((Ra|0)>=(rb|0)){uc=rb;break}}}else{uc=Qa}if((c[A>>2]|0)==0){vc=uc}else{_Oa(n,(c[D>>2]<<4)-16|0,16);vc=c[B>>2]|0}B=c[w>>2]|0;Lkb(f+14424|0,0,c[t>>2]<<B,vc-1|0,(c[D>>2]<<B)-1|0,112);i=g;return}function g2a(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0;g=i;i=i+48|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=f|0;n=c[f+16012>>2]|0;if((n|0)==1){c[f+16032>>2]=0}else if((n|0)==2){c[f+16032>>2]=4}else if((n|0)==0){c[f+16032>>2]=(c[f+16040>>2]|0)<9?6:2}n=c[f+16008>>2]|0;if((n|0)==2){c[f+16036>>2]=5}else if((n|0)==1){c[f+16036>>2]=1}else if((n|0)==0){c[f+16036>>2]=(c[f+16040>>2]|0)<9?7:3}n=f+15728|0;o=d[n]|0;p=f+168|0;c[p>>2]=d[(c[f+9888>>2]|0)+o|0]|0;q=f+172|0;c[q>>2]=d[(c[f+9892>>2]|0)+o|0]|0;o=f+12480|0;r=f+12476|0;c[r>>2]=0;c[f+12488>>2]=1;s=f+14084|0;c[s>>2]=1;c[o>>2]=0;t=f+812|0;u=c[t>>2]|0;a:do{if((u|0)>0){v=f+19428|0;w=f+19436|0;x=f+19231|0;y=f+9856|0;z=f+12544|0;A=f+12548|0;B=f+12552|0;C=f+19608|0;D=f+13836|0;E=f+4|0;F=f+12496|0;G=f+12500|0;H=f+12504|0;I=f+12508|0;J=f+12512|0;K=f+12516|0;L=l|0;M=l+4|0;N=f+148|0;O=l+8|0;P=l+12|0;Q=l+16|0;R=l+20|0;S=f+10096|0;T=f+14340|0;U=f+116|0;V=f+9160|0;W=f+9136|0;X=f+9152|0;Y=f+14128|0;Z=f+14136|0;_=f+14120|0;$=f+176|0;aa=f+128|0;ca=f+9904|0;da=f+16032|0;ea=f+16036|0;fa=f+14072|0;ga=f+60|0;ha=f+15332|0;ia=f+15696|0;ja=f+19220|0;ka=f+10068|0;la=f+152|0;ma=f+10064|0;na=f+9876|0;oa=f+16072|0;pa=f+9912|0;qa=f+15992|0;ra=f+16081|0;sa=f+15988|0;ta=f+15794|0;ua=f+15858|0;va=f+15922|0;wa=f+15368|0;xa=f+15364|0;ya=f+15576|0;b:while(1){c[r>>2]=0;$Oa(m);do{if((c[v>>2]|0)!=0){if((c[w>>2]|0)!=(d[x]|0)){break}za=c[y>>2]|0;c[z>>2]=(c[z>>2]|0)+(c[za+32>>2]|0);c[A>>2]=(c[A>>2]|0)+(c[za+36>>2]|0);c[B>>2]=(c[B>>2]|0)+(c[za+40>>2]|0)}}while(0);if((c[r>>2]|0)<(c[C>>2]|0)){do{za=8>>>((c[(c[E>>2]|0)+800>>2]|0)>>>0);c[F>>2]=(c[F>>2]|0)+2;c[G>>2]=(c[G>>2]|0)+2;c[H>>2]=(c[H>>2]|0)+2;c[I>>2]=(c[I>>2]|0)+2;c[J>>2]=(c[J>>2]|0)+1;c[K>>2]=(c[K>>2]|0)+1;Aa=za<<1;Ba=c[z>>2]|0;Ca=Ba+Aa|0;c[z>>2]=Ca;Da=(c[A>>2]|0)+za|0;c[A>>2]=Da;Ea=(c[B>>2]|0)+za|0;c[B>>2]=Ea;c[L>>2]=Ca;c[M>>2]=Ba+(Aa+8);Ca=c[N>>2]<<3;c[O>>2]=Ba+(Aa+Ca);c[P>>2]=Ba+(Aa+(Ca+8));c[Q>>2]=Da;c[R>>2]=Ea;me[c[S>>2]&511](c[T>>2]|0);Ea=(ba(c[U>>2]|0,c[o>>2]|0)|0)+(c[r>>2]|0)|0;c[(c[V>>2]|0)+(Ea<<2)>>2]=1;a[(c[W>>2]|0)+Ea|0]=a[n]|0;Ea=c[F>>2]|0;Da=c[X>>2]|0;b[Da+(Ea<<2)>>1]=0;b[Da+(Ea<<2)+2>>1]=0;Ea=c[1620609]|0;Da=c[Y>>2]|0;Ca=c[Z>>2]|0;Aa=c[_>>2]|0;Ba=Aa+(Da>>>3)|0;za=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Da&7)>>>23;Ba=b[Ea+(za<<2)>>1]|0;Fa=b[Ea+(za<<2)+2>>1]|0;za=Fa<<16>>16;if(Fa<<16>>16<0){Fa=Da+9|0;Ga=Ca>>>0>Fa>>>0?Fa:Ca;Fa=Aa+(Ga>>>3)|0;Ha=((fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ga&7)>>>((za+32|0)>>>0))+Ba|0;Ia=b[Ea+(Ha<<2)+2>>1]|0;Ja=b[Ea+(Ha<<2)>>1]|0;Ka=Ga}else{Ia=za;Ja=Ba;Ka=Da}Da=Ia+Ka|0;Ba=Ca>>>0>Da>>>0?Da:Ca;c[Y>>2]=Ba;Da=d[Aa+(Ba>>>3)|0]<<(Ba&7)>>>7;c[Y>>2]=((Ba|0)<(Ca|0))+Ba;c[$>>2]=Da&1;Da=Ja;Ba=0;do{Ca=5-Ba|0;Aa=Da>>>(Ca>>>0)&1;za=(Ba|0)<4;if(za){Ga=c[f+12496+(Ba<<2)>>2]|0;Ha=c[aa>>2]|0;Ea=Ga-1|0;Fa=c[ca>>2]|0;La=a[Fa+(Ga-Ha)|0]|0;if((a[Fa+(Ea-Ha)|0]|0)==La<<24>>24){Ma=a[Fa+Ea|0]|0}else{Ma=La}La=Ma&255^Aa;a[Fa+Ga|0]=La;Na=La}else{Na=Aa}Da=Na<<Ca|Da;Ca=c[T>>2]|0;Aa=Ca+(Ba<<7)|0;La=c[(za?da:ea)>>2]|0;Ga=c[fa>>2]|0;if(za){Fa=c[6482460+(Ga*20|0)>>2]|0;Ea=c[Y>>2]|0;Ha=c[Z>>2]|0;Oa=c[_>>2]|0;Pa=Oa+(Ea>>>3)|0;Qa=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Ea&7)>>>23;Pa=b[Fa+(Qa<<2)>>1]|0;Ra=b[Fa+(Qa<<2)+2>>1]|0;Qa=Ra<<16>>16;do{if(Ra<<16>>16<0){Sa=Ea+9|0;Ta=Ha>>>0>Sa>>>0?Sa:Ha;Sa=Oa+(Ta>>>3)|0;Ua=((fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ta&7)>>>((Qa+32|0)>>>0))+Pa|0;Sa=b[Fa+(Ua<<2)>>1]|0;Va=b[Fa+(Ua<<2)+2>>1]|0;Ua=Va<<16>>16;if(!(Va<<16>>16<0)){Wa=Ua;Xa=Sa;Ya=Ta;break}Va=Ta-Qa|0;Ta=Ha>>>0>Va>>>0?Va:Ha;Va=Oa+(Ta>>>3)|0;Za=((fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)>>>((Ua+32|0)>>>0))+Sa|0;Wa=b[Fa+(Za<<2)+2>>1]|0;Xa=b[Fa+(Za<<2)>>1]|0;Ya=Ta}else{Wa=Qa;Xa=Pa;Ya=Ea}}while(0);Ea=Wa+Ya|0;_a=Xa;$a=Ha;ab=Oa;bb=Ha>>>0>Ea>>>0?Ea:Ha}else{Ea=c[6482500+(Ga*20|0)>>2]|0;Pa=c[Y>>2]|0;Qa=c[Z>>2]|0;Fa=c[_>>2]|0;Ra=Fa+(Pa>>>3)|0;Ta=(fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Pa&7)>>>23;Ra=b[Ea+(Ta<<2)>>1]|0;Za=b[Ea+(Ta<<2)+2>>1]|0;Ta=Za<<16>>16;do{if(Za<<16>>16<0){Sa=Pa+9|0;Ua=Qa>>>0>Sa>>>0?Sa:Qa;Sa=Fa+(Ua>>>3)|0;Va=((fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ua&7)>>>((Ta+32|0)>>>0))+Ra|0;Sa=b[Ea+(Va<<2)>>1]|0;cb=b[Ea+(Va<<2)+2>>1]|0;Va=cb<<16>>16;if(!(cb<<16>>16<0)){db=Va;eb=Sa;fb=Ua;break}cb=Ua-Ta|0;Ua=Qa>>>0>cb>>>0?cb:Qa;cb=Fa+(Ua>>>3)|0;gb=((fe(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Ua&7)>>>((Va+32|0)>>>0))+Sa|0;db=b[Ea+(gb<<2)+2>>1]|0;eb=b[Ea+(gb<<2)>>1]|0;fb=Ua}else{db=Ta;eb=Ra;fb=Pa}}while(0);Pa=db+fb|0;_a=eb;$a=Qa;ab=Fa;bb=Qa>>>0>Pa>>>0?Pa:Qa}c[Y>>2]=bb;if((_a|0)<0){yDb(c[E>>2]|0,16,2021120,(hb=i,i=i+1|0,i=i+7&-8,c[hb>>2]=0,hb)|0);i=hb}else{do{if((_a|0)==0){ib=0;jb=a[n]|0}else{Pa=a[n]|0;Ra=Pa<<24>>24==1;do{if((_a|0)==119){if(Ra){Ta=ab+(bb>>>3)|0;Ea=(fe(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(bb&7)>>>22;Ta=bb+10|0;Za=$a>>>0>Ta>>>0?Ta:$a;c[Y>>2]=Za;kb=Ea;lb=Za;break}Za=ab+(bb>>>3)|0;Ea=(fe(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(bb&7);if(Pa<<24>>24==2){Za=bb+9|0;Ta=$a>>>0>Za>>>0?Za:$a;c[Y>>2]=Ta;kb=Ea>>>23;lb=Ta;break}else{Ta=bb+8|0;Za=$a>>>0>Ta>>>0?Ta:$a;c[Y>>2]=Za;kb=Ea>>>24;lb=Za;break}}else{if(Ra){Za=ab+(bb>>>3)|0;Ea=(fe(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(bb&7)>>>30;Za=bb+2|0;Ta=$a>>>0>Za>>>0?Za:$a;c[Y>>2]=Ta;kb=(Ea|_a<<2)-3|0;lb=Ta;break}if(!(Pa<<24>>24==2)){kb=_a;lb=bb;break}Ta=d[ab+(bb>>>3)|0]<<(bb&7)>>>7;Ea=((bb|0)<($a|0))+bb|0;c[Y>>2]=Ea;kb=(Ta&1|_a<<1)-1|0;lb=Ea}}while(0);Ra=d[ab+(lb>>>3)|0]|0;c[Y>>2]=((lb|0)<($a|0))+lb;if((Ra&128>>>((lb&7)>>>0)|0)==0){ib=kb;jb=Pa;break}ib=-kb|0;jb=Pa}}while(0);Qa=za?p:q;Fa=c[Qa>>2]|0;Ra=f+12520+(Ba<<2)|0;Ea=c[Ra>>2]|0;Ta=c[na>>2]|0;Za=f+12496+(Ba<<2)|0;Ga=c[Za>>2]|0;Ha=Ta+(Ga<<1)|0;Oa=b[Ta+(Ga-1<<1)>>1]|0;Ua=b[Ta+(Ga+~Ea<<1)>>1]|0;gb=b[Ta+(Ga-Ea<<1)>>1]|0;Ea=(c[s>>2]|0)==0;do{if((jb&255)>>>0<9>>>0|(c[ia>>2]|0)==0){do{if(Ea){mb=gb;nb=Ua}else{if(!((Ba-2|0)>>>0>1>>>0)){mb=gb;nb=Ua;break}Ga=e[146696+(Fa<<1)>>1]|0;mb=Ga;nb=Ga}}while(0);if((c[r>>2]|0)!=0){ob=mb;pb=nb;qb=Oa;break}if((Ba|0)==3|(Ba|0)==1){ob=mb;pb=nb;qb=Oa;break}Pa=e[146696+(Fa<<1)>>1]|0;ob=mb;pb=Pa;qb=Pa}else{if(Ea){rb=gb;sb=Ua}else{Pa=(Ba-2|0)>>>0>1>>>0;rb=Pa?0:gb;sb=Pa?0:Ua}if((c[r>>2]|0)!=0){ob=rb;pb=sb;qb=Oa;break}if((Ba|0)==3|(Ba|0)==1){ob=rb;pb=sb;qb=Oa;break}ob=rb;pb=0;qb=0}}while(0);Oa=ob-pb|0;Ua=pb-qb|0;gb=(((Oa|0)>-1?Oa:-Oa|0)|0)>(((Ua|0)>-1?Ua:-Ua|0)|0);Ua=(gb?ob:qb)+ib|0;b[Ha>>1]=Ua;b[Aa>>1]=ba(Ua,c[Qa>>2]|0)|0;do{if((Na|0)==0){Ua=c[pa>>2]|0;Oa=c[Za>>2]<<4;Ea=(d[n]<<1)+(d[oa]|0)|0;Fa=Ua+(Oa<<1)|0;TGb(Fa|0,0,32)|0;if(gb){za=Oa-(c[Ra>>2]<<4)|0;if((c[$>>2]|0)==0){tb=0;break}UGb(Ua+((Oa|8)<<1)|0,Ua+((za|8)<<1)|0,16)|0;ub=Ua+(za<<1)|0}else{za=Ua+(Oa-16<<1)|0;if((c[$>>2]|0)==0){tb=0;break}UGb(Fa|0,za|0,16)|0;ub=za}if((c[$>>2]|0)==0){tb=0;break}if(gb){za=c[qa>>2]|0;Fa=1;while(1){Oa=ba(b[ub+(Fa+8<<1)>>1]|0,Ea)|0;Ua=Oa&65535;Pa=Ca+(Ba<<7)+(Fa<<za<<1)|0;b[Pa>>1]=Ua;if(!((a[ra]|0)!=0|Ua<<16>>16==0)){Ga=d[n]|0;b[Pa>>1]=(Ua<<16>>16<0?-Ga|0:Ga)+Oa}Oa=Fa+1|0;if((Oa|0)<8){Fa=Oa}else{tb=63;break}}}else{Fa=c[sa>>2]|0;za=1;while(1){Oa=ba(b[ub+(za<<1)>>1]|0,Ea)|0;Ga=Oa&65535;Ua=Ca+(Ba<<7)+(za<<Fa<<1)|0;b[Ua>>1]=Ga;if(!((a[ra]|0)!=0|Ga<<16>>16==0)){Pa=d[n]|0;b[Ua>>1]=(Ga<<16>>16<0?-Pa|0:Pa)+Oa}Oa=za+1|0;if((Oa|0)<8){za=Oa}else{tb=63;break}}}}else{c[h>>2]=0;za=(d[n]<<1)+(d[oa]|0)&65535;Fa=(c[$>>2]|0)==0;Ea=c[pa>>2]|0;Oa=c[Za>>2]<<4;if(gb){vb=Fa?ta:ua;wb=1;xb=Oa-(c[Ra>>2]<<4)|0}else{vb=Fa?ta:va;wb=0;xb=Oa-16|0}Fa=1;while(1){v2a(f,h,j,k,La);Pa=(c[j>>2]|0)+Fa|0;if((Pa|0)>63){yb=Pa;break}Ga=Pa+1|0;b[Ca+(Ba<<7)+(d[vb+Pa|0]<<1)>>1]=c[k>>2];if((c[h>>2]|0)==0){Fa=Ga}else{yb=Ga;break}}Fa=(c[$>>2]|0)==0;do{if(!Fa){if(wb){Ga=c[qa>>2]|0;Pa=Ca+(Ba<<7)+(1<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+9<<1)>>1]|0);Pa=Ca+(Ba<<7)+(2<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+10<<1)>>1]|0);Pa=Ca+(Ba<<7)+(3<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+11<<1)>>1]|0);Pa=Ca+(Ba<<7)+(4<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+12<<1)>>1]|0);Pa=Ca+(Ba<<7)+(5<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+13<<1)>>1]|0);Pa=Ca+(Ba<<7)+(6<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+14<<1)>>1]|0);Pa=Ca+(Ba<<7)+(7<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+15<<1)>>1]|0);break}else{Pa=c[sa>>2]|0;Ga=Ca+(Ba<<7)+(1<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+1<<1)>>1]|0);Ga=Ca+(Ba<<7)+(2<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+2<<1)>>1]|0);Ga=Ca+(Ba<<7)+(3<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+3<<1)>>1]|0);Ga=Ca+(Ba<<7)+(4<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+4<<1)>>1]|0);Ga=Ca+(Ba<<7)+(5<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+5<<1)>>1]|0);Ga=Ca+(Ba<<7)+(6<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+6<<1)>>1]|0);Ga=Ca+(Ba<<7)+(7<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+7<<1)>>1]|0);break}}}while(0);Ga=c[sa>>2]|0;Pa=c[qa>>2]|0;b[Ea+((Oa|1)<<1)>>1]=b[Ca+(Ba<<7)+(1<<Ga<<1)>>1]|0;b[Ea+((Oa|9)<<1)>>1]=b[Ca+(Ba<<7)+(1<<Pa<<1)>>1]|0;b[Ea+((Oa|2)<<1)>>1]=b[Ca+(Ba<<7)+(2<<Ga<<1)>>1]|0;b[Ea+((Oa|10)<<1)>>1]=b[Ca+(Ba<<7)+(2<<Pa<<1)>>1]|0;b[Ea+((Oa|3)<<1)>>1]=b[Ca+(Ba<<7)+(3<<Ga<<1)>>1]|0;b[Ea+((Oa|11)<<1)>>1]=b[Ca+(Ba<<7)+(3<<Pa<<1)>>1]|0;b[Ea+((Oa|4)<<1)>>1]=b[Ca+(Ba<<7)+(4<<Ga<<1)>>1]|0;b[Ea+((Oa|12)<<1)>>1]=b[Ca+(Ba<<7)+(4<<Pa<<1)>>1]|0;b[Ea+((Oa|5)<<1)>>1]=b[Ca+(Ba<<7)+(5<<Ga<<1)>>1]|0;b[Ea+((Oa|13)<<1)>>1]=b[Ca+(Ba<<7)+(5<<Pa<<1)>>1]|0;b[Ea+((Oa|6)<<1)>>1]=b[Ca+(Ba<<7)+(6<<Ga<<1)>>1]|0;b[Ea+((Oa|14)<<1)>>1]=b[Ca+(Ba<<7)+(6<<Pa<<1)>>1]|0;b[Ea+((Oa|7)<<1)>>1]=b[Ca+(Ba<<7)+(7<<Ga<<1)>>1]|0;b[Ea+((Oa|15)<<1)>>1]=b[Ca+(Ba<<7)+(7<<Pa<<1)>>1]|0;Pa=1;do{Ga=Ca+(Ba<<7)+(Pa<<1)|0;Ua=b[Ga>>1]|0;do{if(!(Ua<<16>>16==0)){Ta=ba(Ua,za)|0;b[Ga>>1]=Ta;if((a[ra]|0)!=0){break}Sa=d[n]|0;b[Ga>>1]=(Ta<<16>>16<0?-Sa|0:Sa)+(Ta&65535)}}while(0);Pa=Pa+1|0;}while((Pa|0)<64);tb=Fa?yb:63}}while(0);c[f+180+(Ba<<2)>>2]=tb}if((Ba|0)>3){if((c[ga>>2]&8192|0)==0){zb=95}}else{zb=95}c:do{if((zb|0)==95){zb=0;me[c[ha>>2]&511]((c[T>>2]|0)+(Ba<<7)|0);do{if((d[n]|0)>>>0>8>>>0){if((c[ia>>2]|0)==0){break}Ca=c[T>>2]|0;if((a[ja]|0)!=0){La=0;do{Ra=Ca+(Ba<<7)+(La<<1)|0;b[Ra>>1]=b[Ra>>1]<<1;La=La+1|0;}while((La|0)<64)}Xe[c[ka>>2]&4095](Ca+(Ba<<7)|0,c[l+(Ba<<2)>>2]|0,c[((Ba&4|0)==0?N:la)>>2]|0);break c}}while(0);Fa=c[T>>2]|0;if((a[ja]|0)!=0){La=0;do{Ra=Fa+(Ba<<7)+(La<<1)|0;b[Ra>>1]=(b[Ra>>1]<<1)-128;La=La+1|0;}while((La|0)<64)}Xe[c[ma>>2]&4095](Fa+(Ba<<7)|0,c[l+(Ba<<2)>>2]|0,c[((Ba&4|0)==0?N:la)>>2]|0)}}while(0);Ba=Ba+1|0;}while((Ba|0)<6);do{if((d[n]|0)>>>0>8>>>0){if((c[ia>>2]|0)==0){break}do{if((c[r>>2]|0)!=0){ne[c[wa>>2]&1023](c[z>>2]|0,c[N>>2]|0);Ba=c[N>>2]|0;ne[c[wa>>2]&1023]((c[z>>2]|0)+(Ba<<3)|0,Ba);if((c[ga>>2]&8192|0)!=0){break}ne[c[wa>>2]&1023](c[A>>2]|0,c[la>>2]|0);ne[c[wa>>2]&1023](c[B>>2]|0,c[la>>2]|0)}}while(0);ne[c[wa>>2]&1023]((c[z>>2]|0)+8|0,c[N>>2]|0);Ba=c[N>>2]|0;ne[c[wa>>2]&1023]((c[z>>2]|0)+((Ba<<3)+8)|0,Ba);do{if((c[s>>2]|0)==0){ne[c[xa>>2]&1023](c[z>>2]|0,c[N>>2]|0);ne[c[xa>>2]&1023]((c[z>>2]|0)+8|0,c[N>>2]|0);if((c[ga>>2]&8192|0)!=0){break}ne[c[xa>>2]&1023](c[A>>2]|0,c[la>>2]|0);ne[c[xa>>2]&1023](c[B>>2]|0,c[la>>2]|0)}}while(0);Ba=c[N>>2]|0;ne[c[xa>>2]&1023]((c[z>>2]|0)+(Ba<<3)|0,Ba);Ba=c[N>>2]|0;ne[c[xa>>2]&1023]((c[z>>2]|0)+((Ba<<3)+8)|0,Ba)}}while(0);if((c[D>>2]|0)!=0){r2a(f,d[n]|0)}if((c[Y>>2]|0)>(c[ya>>2]|0)){break b}Ba=(c[r>>2]|0)+1|0;c[r>>2]=Ba;}while((Ba|0)<(c[C>>2]|0))}Ba=c[o>>2]|0;do{if((c[D>>2]|0)==0){_Oa(m,Ba<<4,16)}else{if((Ba|0)==0){break}_Oa(m,(Ba<<4)-16|0,16)}}while(0);c[s>>2]=0;Ba=(c[o>>2]|0)+1|0;c[o>>2]=Ba;Da=c[t>>2]|0;if((Ba|0)>=(Da|0)){Ab=Da;Bb=D;break a}}Lkb(f+14424|0,0,0,c[r>>2]|0,c[o>>2]|0,14);D=c[ya>>2]|0;yDb(c[E>>2]|0,16,1987832,(hb=i,i=i+16|0,c[hb>>2]=c[Y>>2],c[hb+8>>2]=D,hb)|0);i=hb;i=g;return}else{Ab=u;Bb=f+13836|0}}while(0);if((c[Bb>>2]|0)!=0){_Oa(m,(Ab<<4)-16|0,16)}Lkb(f+14424|0,0,0,(c[f+116>>2]|0)-1|0,(c[f+120>>2]|0)-1|0,112);i=g;return}function h2a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+32|0;k=f+56|0;l=f+64|0;m=e|0;n=c[e+16008>>2]|0;if((n|0)==1){c[e+16032>>2]=0;c[e+16036>>2]=1}else if((n|0)==2){c[e+16032>>2]=4;c[e+16036>>2]=5}else if((n|0)==0){c[e+16032>>2]=(c[e+16040>>2]|0)<9?6:2;c[e+16036>>2]=(c[e+16040>>2]|0)<9?7:3}do{if((c[e+13836>>2]|0)==0){o=0}else{if((c[(c[e+4>>2]|0)+848>>2]|0)>31){o=0;break}o=(c[e+19224>>2]|0)==0}}while(0);n=e+14084|0;c[n>>2]=1;p=e+19580|0;q=e+124|0;TGb(c[p>>2]|0,0,c[q>>2]<<3|0)|0;r=e+808|0;s=c[r>>2]|0;t=e+12480|0;c[t>>2]=s;u=e+812|0;v=c[u>>2]|0;a:do{if((s|0)<(v|0)){w=e+12476|0;x=e+19428|0;y=e+19436|0;z=e+19231|0;A=e+9856|0;B=e+12544|0;C=e+12548|0;D=e+12552|0;E=e+116|0;F=e+19584|0;G=e+16024|0;H=e+16028|0;I=e+19588|0;J=e+19592|0;K=e+19596|0;L=e+19600|0;M=e+4|0;N=e+12496|0;O=e+12500|0;P=e+12504|0;Q=e+12508|0;R=e+12512|0;S=e+12516|0;T=e+19224|0;U=e+16016|0;V=e+15728|0;W=e+16104|0;X=e+16092|0;Y=e+16116|0;Z=e+9928|0;_=e+12488|0;$=e+16056|0;aa=e+9876|0;ca=e+9160|0;da=e+9136|0;ea=e+15720|0;fa=e+15724|0;ga=e+14060|0;ha=e+14128|0;ia=e+14136|0;ja=e+14120|0;ka=e+13924|0;la=e+16004|0;ma=e+176|0;na=e+16005|0;oa=e+16007|0;pa=e+15729|0;qa=e+16006|0;ra=e+120|0;sa=e+16020|0;ta=e+16088|0;ua=e+14340|0;va=e+152|0;wa=e+148|0;xa=e+60|0;ya=e+16048|0;za=e+16044|0;Aa=e+16036|0;Ba=e+16032|0;Ca=e+15332|0;Da=e+19220|0;Ea=e+10068|0;Fa=e+15696|0;Ga=e+15364|0;Ha=e+15368|0;Ia=e+16084|0;Ja=e+15712|0;Ka=e+15716|0;La=e+9152|0;Ma=o^1;Na=e+15576|0;Oa=e+19304|0;Pa=e+14120|0;Qa=e+19468|0;Ra=e+19472|0;Sa=e+9888|0;Ta=e+168|0;Ua=e+9892|0;Va=e+172|0;Wa=e+19252|0;Xa=e+19444|0;Ya=e+19288|0;Za=e+19308|0;_a=e+19316|0;$a=e+19321|0;ab=e+19292|0;bb=e+19324|0;cb=e+19320|0;db=e+19312|0;eb=e+19400|0;b:while(1){c[w>>2]=0;$Oa(m);do{if((c[x>>2]|0)!=0){if((c[y>>2]|0)!=(d[z]|0)){break}fb=c[A>>2]|0;c[B>>2]=(c[B>>2]|0)+(c[fb+32>>2]|0);c[C>>2]=(c[C>>2]|0)+(c[fb+36>>2]|0);c[D>>2]=(c[D>>2]|0)+(c[fb+40>>2]|0)}}while(0);fb=c[w>>2]|0;if((fb|0)<(c[E>>2]|0)){gb=fb;while(1){fb=8>>>((c[(c[M>>2]|0)+800>>2]|0)>>>0);hb=(c[N>>2]|0)+2|0;c[N>>2]=hb;c[O>>2]=(c[O>>2]|0)+2;c[P>>2]=(c[P>>2]|0)+2;c[Q>>2]=(c[Q>>2]|0)+2;c[R>>2]=(c[R>>2]|0)+1;c[S>>2]=(c[S>>2]|0)+1;c[B>>2]=(c[B>>2]|0)+(fb<<1);c[C>>2]=(c[C>>2]|0)+fb;c[D>>2]=(c[D>>2]|0)+fb;fb=c[T>>2]|0;do{if((fb|0)==2){ib=(ba(c[q>>2]|0,c[t>>2]|0)|0)+gb|0;jb=c[U>>2]|0;c[l>>2]=0;kb=d[V]|0;lb=c[(c[Oa>>2]|0)+4>>2]|0;mb=c[ha>>2]|0;nb=c[ia>>2]|0;ob=c[Pa>>2]|0;pb=ob+(mb>>>3)|0;qb=(fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(mb&7)>>>27;pb=b[lb+(qb<<2)>>1]|0;rb=b[lb+(qb<<2)+2>>1]|0;qb=rb<<16>>16;if(rb<<16>>16<0){rb=mb+5|0;sb=nb>>>0>rb>>>0?rb:nb;rb=ob+(sb>>>3)|0;ob=((fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(sb&7)>>>((qb+32|0)>>>0))+pb|0;tb=b[lb+(ob<<2)+2>>1]|0;ub=b[lb+(ob<<2)>>1]|0;vb=sb}else{tb=qb;ub=pb;vb=mb}mb=tb+vb|0;c[ha>>2]=nb>>>0>mb>>>0?mb:nb;nb=(c[J>>2]|0)+gb|0;if((ub|0)<2){a[nb]=1;c[_>>2]=1;mb=(c[Qa>>2]|0)+(c[N>>2]|0)|0;pb=c[La>>2]|0;b[pb+(mb<<2)>>1]=0;b[pb+(mb<<2)+2>>1]=0;c[(c[ca>>2]|0)+((c[Ra>>2]|0)+ib<<2)>>2]=1;do{if((a[la]|0)==0){wb=kb}else{mb=a[na]|0;do{if(mb<<24>>24==3){pb=c[ha>>2]|0;if((a[oa]|0)!=0){qb=d[(c[Pa>>2]|0)+(pb>>>3)|0]|0;c[ha>>2]=((pb|0)<(c[ia>>2]|0))+pb;xb=d[(qb&128>>>((pb&7)>>>0)|0)==0?V:pa]|0;break}qb=c[ia>>2]|0;sb=c[Pa>>2]|0;ob=sb+(pb>>>3)|0;lb=(fe(d[ob]|d[ob+1|0]<<8|d[ob+2|0]<<16|d[ob+3|0]<<24|0)|0)<<(pb&7)>>>29;ob=pb+3|0;pb=qb>>>0>ob>>>0?ob:qb;c[ha>>2]=pb;if((lb|0)==7){ob=sb+(pb>>>3)|0;sb=(fe(d[ob]|d[ob+1|0]<<8|d[ob+2|0]<<16|d[ob+3|0]<<24|0)|0)<<(pb&7)>>>27;ob=pb+5|0;c[ha>>2]=qb>>>0>ob>>>0?ob:qb;yb=sb;zb=25;break}else{xb=(d[V]|0)+lb|0;break}}else{yb=kb;zb=25}}while(0);do{if((zb|0)==25){zb=0;if((mb<<24>>24|0)==0){Ab=15;zb=29}else if((mb<<24>>24|0)==2){Bb=1<<d[qa];zb=28}else if((mb<<24>>24|0)==1){Bb=(3<<d[qa]|0)%15|0;zb=28}else{xb=yb;break}if((zb|0)==28){zb=0;if((Bb&1|0)==0){Cb=yb;Db=Bb}else{Ab=Bb;zb=29}}do{if((zb|0)==29){zb=0;if((c[w>>2]|0)!=0){Cb=yb;Db=Ab;break}Cb=d[pa]|0;Db=Ab}}while(0);do{if((Db&2|0)==0){Eb=Cb}else{if((c[n>>2]|0)==0){Eb=Cb;break}Eb=d[pa]|0}}while(0);do{if((Db&4|0)==0){Fb=Eb}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){Fb=Eb;break}Fb=d[pa]|0}}while(0);if((Db&8|0)==0){xb=Fb;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){xb=Fb;break}xb=d[pa]|0}}while(0);if(!((xb|0)==0|(xb|0)>31)){wb=xb;break}yDb(c[M>>2]|0,16,2024400,(Gb=i,i=i+8|0,c[Gb>>2]=xb,Gb)|0);i=Gb;wb=1}}while(0);a[(c[da>>2]|0)+ib|0]=wb;c[Ta>>2]=d[(c[Sa>>2]|0)+wb|0]|0;c[Va>>2]=d[(c[Ua>>2]|0)+wb|0]|0;mb=c[ha>>2]|0;lb=d[(c[Pa>>2]|0)+(mb>>>3)|0]<<(mb&7)>>>7;c[ha>>2]=((mb|0)<(c[ia>>2]|0))+mb;mb=lb&1;a[(c[Wa>>2]|0)+ib|0]=mb;c[ma>>2]=mb;if((ub&1|0)==0){Hb=0}else{mb=c[(c[Ia>>2]|0)+4>>2]|0;lb=c[ha>>2]|0;sb=c[ia>>2]|0;qb=c[Pa>>2]|0;ob=qb+(lb>>>3)|0;pb=(fe(d[ob]|d[ob+1|0]<<8|d[ob+2|0]<<16|d[ob+3|0]<<24|0)|0)<<(lb&7)>>>23;ob=b[mb+(pb<<2)>>1]|0;rb=b[mb+(pb<<2)+2>>1]|0;pb=rb<<16>>16;if(rb<<16>>16<0){rb=lb+9|0;Ib=sb>>>0>rb>>>0?rb:sb;rb=qb+(Ib>>>3)|0;qb=((fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(Ib&7)>>>((pb+32|0)>>>0))+ob|0;Jb=b[mb+(qb<<2)+2>>1]|0;Kb=b[mb+(qb<<2)>>1]|0;Lb=Ib}else{Jb=pb;Kb=ob;Lb=lb}lb=Jb+Lb|0;c[ha>>2]=sb>>>0>lb>>>0?lb:sb;Hb=Kb+1|0}sb=0;lb=0;do{ob=e+12496+(lb<<2)|0;pb=c[ob>>2]|0;b[(c[aa>>2]|0)+(pb<<1)>>1]=0;a[(c[$>>2]|0)+pb|0]=1;sb=(lb>>2)+sb|0;pb=Hb>>>((5-lb|0)>>>0)&1;c[ya>>2]=0;c[za>>2]=0;if((lb-2|0)>>>0<2>>>0){zb=49}else{if((c[n>>2]|0)==0){zb=49}}if((zb|0)==49){zb=0;c[za>>2]=d[(c[$>>2]|0)+((c[ob>>2]|0)-(c[e+12520+(lb<<2)>>2]|0))|0]|0}if((lb|0)==3|(lb|0)==1){zb=52}else{if((c[w>>2]|0)!=0){zb=52}}if((zb|0)==52){zb=0;c[ya>>2]=d[(c[$>>2]|0)+((c[ob>>2]|0)-1)|0]|0}ob=(lb&4|0)!=0;t2a(e,(c[ua>>2]|0)+(lb<<7)|0,lb,pb,wb,c[(ob?Aa:Ba)>>2]|0);if((lb|0)>3){if((c[xa>>2]&8192|0)==0){zb=55}}else{zb=55}if((zb|0)==55){zb=0;me[c[Ca>>2]&511]((c[ua>>2]|0)+(lb<<7)|0);if(ob){Mb=0}else{Mb=(ba(c[wa>>2]|0,lb<<2&8)|0)+(lb<<3&8)|0}Xe[c[Ea>>2]&4095]((c[ua>>2]|0)+(lb<<7)|0,(c[e+12544+(sb<<2)>>2]|0)+Mb|0,c[(ob?va:wa)>>2]|0)}lb=lb+1|0;}while((lb|0)<6)}else{a[nb]=0;c[_>>2]=0;c[(c[ca>>2]|0)+((c[Ra>>2]|0)+ib<<2)>>2]=8;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;if((ub|0)<6){do{if((ub&1|0)==0){Nb=0;Ob=0;Pb=0}else{lb=c[Xa>>2]|0;sb=(lb|0)==0;ob=sb?71:125;pb=d[Ya]|0;if((pb|0)==2){Qb=0;Rb=1}else if((pb|0)==3){Qb=1;Rb=1}else if((pb|0)==1){Qb=1;Rb=0}else{Qb=0;Rb=0}pb=c[(c[Za>>2]|0)+4>>2]|0;Ib=c[ha>>2]|0;qb=c[ia>>2]|0;mb=c[Pa>>2]|0;rb=mb+(Ib>>>3)|0;Sb=(fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(Ib&7)>>>23;rb=b[pb+(Sb<<2)>>1]|0;Tb=b[pb+(Sb<<2)+2>>1]|0;Sb=Tb<<16>>16;do{if(Tb<<16>>16<0){Ub=Ib+9|0;Vb=qb>>>0>Ub>>>0?Ub:qb;Ub=mb+(Vb>>>3)|0;Wb=((fe(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Vb&7)>>>((Sb+32|0)>>>0))+rb|0;Ub=b[pb+(Wb<<2)>>1]|0;Xb=b[pb+(Wb<<2)+2>>1]|0;Wb=Xb<<16>>16;if(!(Xb<<16>>16<0)){Yb=Wb;Zb=Ub;_b=Vb;break}Xb=Vb-Sb|0;Vb=qb>>>0>Xb>>>0?Xb:qb;Xb=mb+(Vb>>>3)|0;$b=((fe(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Vb&7)>>>((Wb+32|0)>>>0))+Ub|0;Yb=b[pb+($b<<2)+2>>1]|0;Zb=b[pb+($b<<2)>>1]|0;_b=Vb}else{Yb=Sb;Zb=rb;_b=Ib}}while(0);Ib=Yb+_b|0;rb=qb>>>0>Ib>>>0?Ib:qb;c[ha>>2]=rb;if((Zb|0)==(ob|0)){Ib=c[Ja>>2]|0;Sb=mb+(rb>>>3)|0;pb=(fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(rb&7)>>>((32-Ib|0)>>>0);Sb=Ib+rb|0;Ib=qb>>>0>Sb>>>0?Sb:qb;c[ha>>2]=Ib;Sb=c[Ka>>2]|0;Tb=mb+(Ib>>>3)|0;Vb=(fe(d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0)|0)<<(Ib&7)>>>((32-Sb|0)>>>0);Tb=Ib+Sb|0;c[ha>>2]=qb>>>0>Tb>>>0?Tb:qb;if(sb){Nb=0;Ob=Vb;Pb=pb;break}Tb=Vb&1;Nb=Tb;Ob=Tb+Vb>>1;Pb=pb;break}if((Zb|0)>=(ob|0)){zb=72;break b}pb=Zb+1|0;Vb=(pb|0)%9|0;if((Vb|0)==0){ac=0;bc=rb}else{Tb=Vb+Qb|0;Sb=mb+(rb>>>3)|0;Ib=(fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(rb&7)>>>((32-Tb|0)>>>0);Sb=Tb+rb|0;rb=qb>>>0>Sb>>>0?Sb:qb;c[ha>>2]=rb;Sb=Ib&1;ac=((Ib>>1)+(c[((Qb|0)==0?628544:628504)+(Vb<<2)>>2]|0)^-Sb)+Sb|0;bc=rb}rb=(pb|0)/9|0;if((rb|0)>(lb|0)){pb=rb+(Rb<<lb)>>lb;Sb=mb+(bc>>>3)|0;Vb=(fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(bc&7)>>>((32-pb|0)>>>0);Sb=pb+bc|0;c[ha>>2]=qb>>>0>Sb>>>0?Sb:qb;Sb=Vb&1;cc=((Vb>>1)+(c[((Rb|0)==0?628544:628504)+(rb>>lb<<2)>>2]|0)^-Sb)+Sb|0}else{cc=0}Nb=sb?0:rb&1;Ob=cc;Pb=ac}}while(0);E2a(e,0,Pb,Ob,1,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,Nb,0);x2a(e,0);dc=ub>>>1&1^1}else{nb=c[(c[_a>>2]|0)+4>>2]|0;rb=c[ha>>2]|0;Sb=c[ia>>2]|0;Vb=(c[Pa>>2]|0)+(rb>>>3)|0;pb=(fe(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(rb&7)>>>26;Vb=b[nb+(pb<<2)>>1]|0;Ib=(b[nb+(pb<<2)+2>>1]|0)+rb|0;c[ha>>2]=Sb>>>0>Ib>>>0?Ib:Sb;a[$a]=Vb;Vb=0;c:while(1){do{if((Vb|0)<4){do{if((d[$a]&1<<3-Vb|0)==0){ec=0;fc=0;gc=0}else{Sb=c[Xa>>2]|0;Ib=(Sb|0)==0;rb=Ib?71:125;pb=d[Ya]|0;if((pb|0)==1){hc=1;ic=0}else if((pb|0)==2){hc=0;ic=1}else if((pb|0)==3){hc=1;ic=1}else{hc=0;ic=0}pb=c[(c[Za>>2]|0)+4>>2]|0;nb=c[ha>>2]|0;Tb=c[ia>>2]|0;$b=c[Pa>>2]|0;Ub=$b+(nb>>>3)|0;Wb=(fe(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(nb&7)>>>23;Ub=b[pb+(Wb<<2)>>1]|0;Xb=b[pb+(Wb<<2)+2>>1]|0;Wb=Xb<<16>>16;do{if(Xb<<16>>16<0){jc=nb+9|0;kc=Tb>>>0>jc>>>0?jc:Tb;jc=$b+(kc>>>3)|0;lc=((fe(d[jc]|d[jc+1|0]<<8|d[jc+2|0]<<16|d[jc+3|0]<<24|0)|0)<<(kc&7)>>>((Wb+32|0)>>>0))+Ub|0;jc=b[pb+(lc<<2)>>1]|0;mc=b[pb+(lc<<2)+2>>1]|0;lc=mc<<16>>16;if(!(mc<<16>>16<0)){nc=lc;oc=jc;pc=kc;break}mc=kc-Wb|0;kc=Tb>>>0>mc>>>0?mc:Tb;mc=$b+(kc>>>3)|0;qc=((fe(d[mc]|d[mc+1|0]<<8|d[mc+2|0]<<16|d[mc+3|0]<<24|0)|0)<<(kc&7)>>>((lc+32|0)>>>0))+jc|0;nc=b[pb+(qc<<2)+2>>1]|0;oc=b[pb+(qc<<2)>>1]|0;pc=kc}else{nc=Wb;oc=Ub;pc=nb}}while(0);nb=nc+pc|0;Ub=Tb>>>0>nb>>>0?nb:Tb;c[ha>>2]=Ub;if((oc|0)==(rb|0)){nb=c[Ja>>2]|0;Wb=$b+(Ub>>>3)|0;pb=(fe(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Ub&7)>>>((32-nb|0)>>>0);Wb=nb+Ub|0;nb=Tb>>>0>Wb>>>0?Wb:Tb;c[ha>>2]=nb;Wb=c[Ka>>2]|0;Xb=$b+(nb>>>3)|0;kc=(fe(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(nb&7)>>>((32-Wb|0)>>>0);Xb=nb+Wb|0;c[ha>>2]=Tb>>>0>Xb>>>0?Xb:Tb;if(Ib){ec=0;fc=kc;gc=pb;break}Xb=kc&1;ec=Xb;fc=Xb+kc>>1;gc=pb;break}if((oc|0)>=(rb|0)){zb=93;break b}pb=oc+1|0;kc=(pb|0)%9|0;if((kc|0)==0){rc=0;sc=Ub}else{Xb=kc+hc|0;Wb=$b+(Ub>>>3)|0;nb=(fe(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Ub&7)>>>((32-Xb|0)>>>0);Wb=Xb+Ub|0;Ub=Tb>>>0>Wb>>>0?Wb:Tb;c[ha>>2]=Ub;Wb=nb&1;rc=((nb>>1)+(c[((hc|0)==0?628544:628504)+(kc<<2)>>2]|0)^-Wb)+Wb|0;sc=Ub}Ub=(pb|0)/9|0;if((Ub|0)>(Sb|0)){pb=Ub+(ic<<Sb)>>Sb;Wb=$b+(sc>>>3)|0;kc=(fe(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(sc&7)>>>((32-pb|0)>>>0);Wb=pb+sc|0;c[ha>>2]=Tb>>>0>Wb>>>0?Wb:Tb;Wb=kc&1;tc=((kc>>1)+(c[((ic|0)==0?628544:628504)+(Ub>>Sb<<2)>>2]|0)^-Wb)+Wb|0}else{tc=0}ec=Ib?0:Ub&1;fc=tc;gc=rc}}while(0);E2a(e,Vb,gc,fc,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,ec,0);z2a(e,Vb,0,0)}else{if((Vb|0)!=4){break}D2a(e,0);Vb=5;continue c}}while(0);Vb=Vb+1|0;if((Vb|0)>=6){break}}dc=ub&1}do{if((dc|0)==0){uc=kb;vc=0;wc=1}else{Vb=c[(c[Ia>>2]|0)+4>>2]|0;sb=c[ha>>2]|0;lb=c[ia>>2]|0;qb=c[Pa>>2]|0;mb=qb+(sb>>>3)|0;ob=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(sb&7)>>>23;mb=b[Vb+(ob<<2)>>1]|0;Ub=b[Vb+(ob<<2)+2>>1]|0;ob=Ub<<16>>16;if(Ub<<16>>16<0){Ub=sb+9|0;Wb=lb>>>0>Ub>>>0?Ub:lb;Ub=qb+(Wb>>>3)|0;kc=((fe(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Wb&7)>>>((ob+32|0)>>>0))+mb|0;xc=b[Vb+(kc<<2)+2>>1]|0;yc=b[Vb+(kc<<2)>>1]|0;zc=Wb}else{xc=ob;yc=mb;zc=sb}sb=xc+zc|0;mb=lb>>>0>sb>>>0?sb:lb;c[ha>>2]=mb;sb=yc+1|0;if((sb|0)==0){uc=kb;vc=0;wc=1;break}if((a[la]|0)==0){uc=kb;vc=sb;wc=0;break}ob=a[na]|0;do{if(ob<<24>>24==3){Wb=qb+(mb>>>3)|0;if((a[oa]|0)!=0){kc=d[Wb]|0;c[ha>>2]=((mb|0)<(lb|0))+mb;Ac=d[(kc&128>>>((mb&7)>>>0)|0)==0?V:pa]|0;break}kc=Wb;Wb=(fe(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0)<<(mb&7)>>>29;kc=mb+3|0;Vb=lb>>>0>kc>>>0?kc:lb;c[ha>>2]=Vb;if((Wb|0)==7){kc=qb+(Vb>>>3)|0;Ub=(fe(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0)<<(Vb&7)>>>27;kc=Vb+5|0;c[ha>>2]=lb>>>0>kc>>>0?kc:lb;Bc=Ub;zb=115;break}else{Ac=(d[V]|0)+Wb|0;break}}else{Bc=kb;zb=115}}while(0);do{if((zb|0)==115){zb=0;if((ob<<24>>24|0)==0){Cc=15;zb=119}else if((ob<<24>>24|0)==2){Dc=1<<d[qa];zb=118}else if((ob<<24>>24|0)==1){Dc=(3<<d[qa]|0)%15|0;zb=118}else{Ac=Bc;break}if((zb|0)==118){zb=0;if((Dc&1|0)==0){Ec=Bc;Fc=Dc}else{Cc=Dc;zb=119}}do{if((zb|0)==119){zb=0;if((c[w>>2]|0)!=0){Ec=Bc;Fc=Cc;break}Ec=d[pa]|0;Fc=Cc}}while(0);do{if((Fc&2|0)==0){Gc=Ec}else{if((c[n>>2]|0)==0){Gc=Ec;break}Gc=d[pa]|0}}while(0);do{if((Fc&4|0)==0){Hc=Gc}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){Hc=Gc;break}Hc=d[pa]|0}}while(0);if((Fc&8|0)==0){Ac=Hc;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){Ac=Hc;break}Ac=d[pa]|0}}while(0);if(!((Ac|0)==0|(Ac|0)>31)){uc=Ac;vc=sb;wc=0;break}yDb(c[M>>2]|0,16,2024400,(Gb=i,i=i+8|0,c[Gb>>2]=Ac,Gb)|0);i=Gb;uc=1;vc=sb;wc=0}}while(0);a[(c[da>>2]|0)+ib|0]=uc;if((a[sa]|0)!=0|wc){Ic=jb;Jc=1;Kc=0;Lc=0}else{kb=c[5254452+((c[ta>>2]|0)*20|0)>>2]|0;ob=c[ha>>2]|0;lb=c[ia>>2]|0;qb=c[Pa>>2]|0;mb=qb+(ob>>>3)|0;Wb=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(ob&7)>>>23;mb=b[kb+(Wb<<2)>>1]|0;Ub=b[kb+(Wb<<2)+2>>1]|0;Wb=Ub<<16>>16;if(Ub<<16>>16<0){Ub=ob+9|0;kc=lb>>>0>Ub>>>0?Ub:lb;Ub=qb+(kc>>>3)|0;qb=((fe(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(kc&7)>>>((Wb+32|0)>>>0))+mb|0;Mc=b[kb+(qb<<2)+2>>1]|0;Nc=b[kb+(qb<<2)>>1]|0;Oc=kc}else{Mc=Wb;Nc=mb;Oc=ob}ob=Mc+Oc|0;c[ha>>2]=lb>>>0>ob>>>0?ob:lb;Ic=Nc;Jc=1;Kc=0;Lc=0}while(1){b[(c[aa>>2]|0)+(c[e+12496+(Lc<<2)>>2]<<1)>>1]=0;lb=(Lc>>2)+Kc|0;ob=(Lc&4|0)!=0;if(ob){Pc=0}else{Pc=(ba(c[wa>>2]|0,Lc<<2&8)|0)+(Lc<<3&8)|0}if((1<<5-Lc&vc|0)==0){Qc=Jc;Rc=Ic}else{if(ob){Sc=(c[xa>>2]|0)>>>13&1}else{Sc=0}u2a(e,(c[ua>>2]|0)+(Lc<<7)|0,Lc,uc,Ic,Jc,(c[e+12544+(lb<<2)>>2]|0)+Pc|0,c[(ob?va:wa)>>2]|0,Sc,l)|0;Qc=0;Rc=(a[sa]|0)==0&(Ic|0)<8?-1:Ic}ob=Lc+1|0;if((ob|0)<6){Ic=Rc;Jc=Qc;Kc=lb;Lc=ob}else{break}}}if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){break}VGb(c[I>>2]|0,c[J>>2]|0,c[q>>2]|0)|0}else if((fb|0)==1){jb=(ba(c[q>>2]|0,c[t>>2]|0)|0)+gb|0;ib=c[U>>2]|0;c[k>>2]=0;ob=d[V]|0;if((c[Y>>2]|0)==0){Tc=d[(c[Z>>2]|0)+jb|0]|0}else{lb=c[ha>>2]|0;mb=d[(c[ja>>2]|0)+(lb>>>3)|0]<<(lb&7)>>>7;c[ha>>2]=((lb|0)<(c[ia>>2]|0))+lb;Tc=mb&1}d:do{if((Tc|0)==0){mb=c[ab>>2]|0;lb=c[(c[Oa>>2]|0)+4>>2]|0;Wb=c[ha>>2]|0;kc=c[ia>>2]|0;qb=c[ja>>2]|0;kb=qb+(Wb>>>3)|0;Ub=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Wb&7);if((mb|0)==0){kb=Ub>>>26;Vb=b[lb+(kb<<2)>>1]|0;pb=b[lb+(kb<<2)+2>>1]|0;kb=pb<<16>>16;if(pb<<16>>16<0){pb=Wb+6|0;nb=kc>>>0>pb>>>0?pb:kc;pb=qb+(nb>>>3)|0;Xb=((fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(nb&7)>>>((kb+32|0)>>>0))+Vb|0;Uc=b[lb+(Xb<<2)+2>>1]|0;Vc=b[lb+(Xb<<2)>>1]|0;Wc=nb}else{Uc=kb;Vc=Vb;Wc=Wb}Vb=Uc+Wc|0;Xc=Vc;Yc=kc>>>0>Vb>>>0?Vb:kc}else{Vb=Ub>>>23;Ub=b[lb+(Vb<<2)>>1]|0;kb=b[lb+(Vb<<2)+2>>1]|0;Vb=kb<<16>>16;if(kb<<16>>16<0){kb=Wb+9|0;nb=kc>>>0>kb>>>0?kb:kc;kb=qb+(nb>>>3)|0;qb=((fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(nb&7)>>>((Vb+32|0)>>>0))+Ub|0;Zc=b[lb+(qb<<2)+2>>1]|0;_c=b[lb+(qb<<2)>>1]|0;$c=nb}else{Zc=Vb;_c=Ub;$c=Wb}Wb=Zc+$c|0;Xc=_c;Yc=kc>>>0>Wb>>>0?Wb:kc}c[ha>>2]=Yc;kc=d[1096248+(mb*60|0)+(Xc<<2)|0]|0;if((kc|0)==4){a[(c[eb>>2]|0)+hb|0]=0;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=0;ad=0;bd=1}else if((kc|0)==3){a[(c[eb>>2]|0)+hb|0]=1;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=1;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=1;ad=0;bd=1}else if((kc|0)==1){a[(c[eb>>2]|0)+hb|0]=1;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=1;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=1;ad=1;bd=0}else if((kc|0)==0){a[(c[eb>>2]|0)+hb|0]=0;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=0;ad=0;bd=0}else{ad=0;bd=0}kc=c[ab>>2]|0;mb=a[1096248+(kc*60|0)+(Xc<<2)|0]|0;if(mb<<24>>24==5){Wb=c[La>>2]|0;Ub=c[N>>2]|0;b[Wb+(Ub<<2)>>1]=0;b[Wb+(Ub<<2)+2>>1]=0;Ub=c[O>>2]|0;b[Wb+(Ub<<2)>>1]=0;b[Wb+(Ub<<2)+2>>1]=0;Ub=c[P>>2]|0;b[Wb+(Ub<<2)>>1]=0;b[Wb+(Ub<<2)+2>>1]=0;Ub=c[Q>>2]|0;b[Wb+(Ub<<2)>>1]=0;b[Wb+(Ub<<2)+2>>1]=0;c[(c[ca>>2]|0)+(jb<<2)>>2]=1;a[(c[J>>2]|0)+(c[w>>2]|0)|0]=1;c[_>>2]=1;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=1;Ub=c[ha>>2]|0;Wb=d[(c[ja>>2]|0)+(Ub>>>3)|0]<<(Ub&7)>>>7;c[ha>>2]=((Ub|0)<(c[ia>>2]|0))+Ub;Ub=Wb&1;a[(c[bb>>2]|0)+jb|0]=Ub;Wb=c[ha>>2]|0;Vb=c[ja>>2]|0;nb=d[Vb+(Wb>>>3)|0]|0;qb=c[ia>>2]|0;lb=((Wb|0)<(qb|0))+Wb|0;c[ha>>2]=lb;if((nb&128>>>((Wb&7)>>>0)|0)==0){cd=0;dd=lb}else{Wb=c[(c[Ia>>2]|0)+4>>2]|0;nb=Vb+(lb>>>3)|0;kb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(lb&7)>>>23;nb=b[Wb+(kb<<2)>>1]|0;Xb=b[Wb+(kb<<2)+2>>1]|0;kb=Xb<<16>>16;if(Xb<<16>>16<0){Xb=lb+9|0;pb=qb>>>0>Xb>>>0?Xb:qb;Xb=Vb+(pb>>>3)|0;qc=((fe(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(pb&7)>>>((kb+32|0)>>>0))+nb|0;ed=b[Wb+(qc<<2)+2>>1]|0;fd=b[Wb+(qc<<2)>>1]|0;gd=pb}else{ed=kb;fd=nb;gd=lb}lb=ed+gd|0;nb=qb>>>0>lb>>>0?lb:qb;c[ha>>2]=nb;cd=fd+1|0;dd=nb}nb=d[Vb+(dd>>>3)|0]<<(dd&7)>>>7;c[ha>>2]=((dd|0)<(qb|0))+dd;qb=nb&1;a[(c[Wa>>2]|0)+jb|0]=qb;c[ma>>2]=qb;do{if((a[la]|0)==0){hd=ob}else{qb=a[na]|0;do{if(qb<<24>>24==3){nb=c[ha>>2]|0;if((a[oa]|0)!=0){Vb=d[(c[ja>>2]|0)+(nb>>>3)|0]|0;c[ha>>2]=((nb|0)<(c[ia>>2]|0))+nb;id=d[(Vb&128>>>((nb&7)>>>0)|0)==0?V:pa]|0;break}Vb=c[ia>>2]|0;lb=c[ja>>2]|0;kb=lb+(nb>>>3)|0;pb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(nb&7)>>>29;kb=nb+3|0;nb=Vb>>>0>kb>>>0?kb:Vb;c[ha>>2]=nb;if((pb|0)==7){kb=lb+(nb>>>3)|0;lb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(nb&7)>>>27;kb=nb+5|0;c[ha>>2]=Vb>>>0>kb>>>0?kb:Vb;jd=lb;zb=173;break}else{id=(d[V]|0)+pb|0;break}}else{jd=ob;zb=173}}while(0);do{if((zb|0)==173){zb=0;if((qb<<24>>24|0)==2){kd=1<<d[qa];zb=176}else if((qb<<24>>24|0)==1){kd=(3<<d[qa]|0)%15|0;zb=176}else if((qb<<24>>24|0)==0){ld=15;zb=177}else{id=jd;break}if((zb|0)==176){zb=0;if((kd&1|0)==0){md=jd;nd=kd}else{ld=kd;zb=177}}do{if((zb|0)==177){zb=0;if((c[w>>2]|0)!=0){md=jd;nd=ld;break}md=d[pa]|0;nd=ld}}while(0);do{if((nd&2|0)==0){od=md}else{if((c[n>>2]|0)==0){od=md;break}od=d[pa]|0}}while(0);do{if((nd&4|0)==0){pd=od}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){pd=od;break}pd=d[pa]|0}}while(0);if((nd&8|0)==0){id=pd;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){id=pd;break}id=d[pa]|0}}while(0);if(!((id|0)==0|(id|0)>31)){hd=id;break}yDb(c[M>>2]|0,16,2024400,(Gb=i,i=i+8|0,c[Gb>>2]=id,Gb)|0);i=Gb;hd=1}}while(0);a[(c[da>>2]|0)+jb|0]=hd;c[Ta>>2]=d[(c[Sa>>2]|0)+hd|0]|0;c[Va>>2]=d[(c[Ua>>2]|0)+hd|0]|0;sb=(Ub|0)==0;qb=0;Ib=0;while(1){Sb=e+12496+(Ib<<2)|0;Tb=c[Sb>>2]|0;b[(c[aa>>2]|0)+(Tb<<1)>>1]=0;qb=(Ib>>2)+qb|0;$b=cd>>>((5-Ib|0)>>>0)&1;a[(c[$>>2]|0)+Tb|0]=c[_>>2];c[ya>>2]=0;c[za>>2]=0;if((Ib-2|0)>>>0<2>>>0){zb=193}else{if((c[n>>2]|0)==0){zb=193}}if((zb|0)==193){zb=0;c[za>>2]=d[(c[$>>2]|0)+((c[Sb>>2]|0)-(c[e+12520+(Ib<<2)>>2]|0))|0]|0}if((Ib|0)==3|(Ib|0)==1){zb=196}else{if((c[w>>2]|0)!=0){zb=196}}if((zb|0)==196){zb=0;c[ya>>2]=d[(c[$>>2]|0)+((c[Sb>>2]|0)-1)|0]|0}t2a(e,(c[ua>>2]|0)+(Ib<<7)|0,Ib,$b,hd,c[((Ib&4|0)==0?Ba:Aa)>>2]|0);if((Ib|0)>3){if((c[xa>>2]&8192|0)==0){zb=199}}else{zb=199}if((zb|0)==199){zb=0;me[c[Ca>>2]&511]((c[ua>>2]|0)+(Ib<<7)|0);if((Ib|0)<4){$b=c[wa>>2]|0;Sb=Ib&2;qd=$b<<Ub;rd=(ba($b,sb?Sb<<2:Sb>>>1)|0)+(Ib<<3&8)|0}else{qd=c[va>>2]|0;rd=0}Xe[c[Ea>>2]&4095]((c[ua>>2]|0)+(Ib<<7)|0,(c[e+12544+(qb<<2)>>2]|0)+rd|0,qd)}Ib=Ib+1|0;if((Ib|0)>=6){break d}}}if((a[1096248+(kc*60|0)+(Xc<<2)+3|0]|0)==0){sd=0}else{Ib=c[(c[Ia>>2]|0)+4>>2]|0;qb=c[ha>>2]|0;sb=c[ia>>2]|0;Ub=c[ja>>2]|0;Sb=Ub+(qb>>>3)|0;$b=(fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(qb&7)>>>23;Sb=b[Ib+($b<<2)>>1]|0;Tb=b[Ib+($b<<2)+2>>1]|0;$b=Tb<<16>>16;if(Tb<<16>>16<0){Tb=qb+9|0;rb=sb>>>0>Tb>>>0?Tb:sb;Tb=Ub+(rb>>>3)|0;Ub=((fe(d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0)|0)<<(rb&7)>>>(($b+32|0)>>>0))+Sb|0;td=b[Ib+(Ub<<2)+2>>1]|0;ud=b[Ib+(Ub<<2)>>1]|0;vd=rb}else{td=$b;ud=Sb;vd=qb}qb=td+vd|0;c[ha>>2]=sb>>>0>qb>>>0?qb:sb;sd=ud+1|0}if((mb<<24>>24|0)==1){sb=c[(c[db>>2]|0)+4>>2]|0;qb=c[ha>>2]|0;Sb=c[ia>>2]|0;$b=(c[ja>>2]|0)+(qb>>>3)|0;rb=(fe(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(qb&7)>>>29;$b=b[sb+(rb<<2)>>1]|0;Ub=(b[sb+(rb<<2)+2>>1]|0)+qb|0;c[ha>>2]=Sb>>>0>Ub>>>0?Ub:Sb;a[cb]=$b}else if((mb<<24>>24|0)==4|(mb<<24>>24|0)==3){$b=c[(c[_a>>2]|0)+4>>2]|0;Sb=c[ha>>2]|0;Ub=c[ia>>2]|0;qb=(c[ja>>2]|0)+(Sb>>>3)|0;rb=(fe(d[qb]|d[qb+1|0]<<8|d[qb+2|0]<<16|d[qb+3|0]<<24|0)|0)<<(Sb&7)>>>26;qb=b[$b+(rb<<2)>>1]|0;sb=(b[$b+(rb<<2)+2>>1]|0)+Sb|0;c[ha>>2]=Ub>>>0>sb>>>0?sb:Ub;a[$a]=qb}a[(c[J>>2]|0)+(c[w>>2]|0)|0]=0;c[_>>2]=0;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;qb=a[1096248+((c[ab>>2]|0)*60|0)+(Xc<<2)+1|0]|0;a[(c[bb>>2]|0)+jb|0]=qb;Ub=qb&255;do{if((bd|0)==0){if((ad|0)==0){do{if((a[1096248+((c[ab>>2]|0)*60|0)+(Xc<<2)+2|0]|0)==0){wd=0;xd=0}else{sb=c[Xa>>2]|0;Sb=(sb|0)==0;rb=Sb?71:125;$b=d[Ya]|0;if(($b|0)==1){yd=1;zd=0}else if(($b|0)==2){yd=0;zd=1}else if(($b|0)==3){yd=1;zd=1}else{yd=0;zd=0}$b=c[(c[Za>>2]|0)+4>>2]|0;Ib=c[ha>>2]|0;Tb=c[ia>>2]|0;pb=c[Pa>>2]|0;lb=pb+(Ib>>>3)|0;Vb=(fe(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(Ib&7)>>>23;lb=b[$b+(Vb<<2)>>1]|0;kb=b[$b+(Vb<<2)+2>>1]|0;Vb=kb<<16>>16;do{if(kb<<16>>16<0){nb=Ib+9|0;qc=Tb>>>0>nb>>>0?nb:Tb;nb=pb+(qc>>>3)|0;Wb=((fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(qc&7)>>>((Vb+32|0)>>>0))+lb|0;nb=b[$b+(Wb<<2)>>1]|0;Xb=b[$b+(Wb<<2)+2>>1]|0;Wb=Xb<<16>>16;if(!(Xb<<16>>16<0)){Ad=Wb;Bd=nb;Dd=qc;break}Xb=qc-Vb|0;qc=Tb>>>0>Xb>>>0?Xb:Tb;Xb=pb+(qc>>>3)|0;jc=((fe(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(qc&7)>>>((Wb+32|0)>>>0))+nb|0;Ad=b[$b+(jc<<2)+2>>1]|0;Bd=b[$b+(jc<<2)>>1]|0;Dd=qc}else{Ad=Vb;Bd=lb;Dd=Ib}}while(0);Ib=Ad+Dd|0;lb=Tb>>>0>Ib>>>0?Ib:Tb;c[ha>>2]=lb;if((Bd|0)==(rb|0)){Ib=c[Ja>>2]|0;Vb=pb+(lb>>>3)|0;$b=(fe(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(lb&7)>>>((32-Ib|0)>>>0);Vb=Ib+lb|0;Ib=Tb>>>0>Vb>>>0?Vb:Tb;c[ha>>2]=Ib;Vb=c[Ka>>2]|0;kb=pb+(Ib>>>3)|0;qc=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Ib&7)>>>((32-Vb|0)>>>0);kb=Ib+Vb|0;c[ha>>2]=Tb>>>0>kb>>>0?kb:Tb;if(Sb){wd=qc;xd=$b;break}wd=(qc&1)+qc>>1;xd=$b;break}if((Bd|0)>=(rb|0)){zb=283;break b}$b=Bd+1|0;qc=($b|0)%9|0;if((qc|0)==0){Ed=0;Fd=lb}else{kb=qc+yd|0;Vb=pb+(lb>>>3)|0;Ib=(fe(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(lb&7)>>>((32-kb|0)>>>0);Vb=kb+lb|0;lb=Tb>>>0>Vb>>>0?Vb:Tb;c[ha>>2]=lb;Vb=Ib&1;Ed=((Ib>>1)+(c[((yd|0)==0?628544:628504)+(qc<<2)>>2]|0)^-Vb)+Vb|0;Fd=lb}lb=($b|0)/9|0;if((lb|0)<=(sb|0)){wd=0;xd=Ed;break}$b=lb+(zd<<sb)>>sb;Vb=pb+(Fd>>>3)|0;qc=(fe(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(Fd&7)>>>((32-$b|0)>>>0);Vb=$b+Fd|0;c[ha>>2]=Tb>>>0>Vb>>>0?Vb:Tb;Vb=qc&1;wd=((qc>>1)+(c[((zd|0)==0?628544:628504)+(lb>>sb<<2)>>2]|0)^-Vb)+Vb|0;xd=Ed}}while(0);B2a(e,0,xd,wd,1,c[ea>>2]|0,c[fa>>2]|0,0);x2a(e,0);break}Vb=d[cb]|0;do{if((Vb&2|0)==0){Gd=0;Hd=0}else{lb=c[Xa>>2]|0;qc=(lb|0)==0;$b=qc?71:125;Ib=d[Ya]|0;if((Ib|0)==1){Id=1;Jd=0}else if((Ib|0)==2){Id=0;Jd=1}else if((Ib|0)==3){Id=1;Jd=1}else{Id=0;Jd=0}Ib=c[(c[Za>>2]|0)+4>>2]|0;kb=c[ha>>2]|0;jc=c[ia>>2]|0;nb=c[Pa>>2]|0;Wb=nb+(kb>>>3)|0;Xb=(fe(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(kb&7)>>>23;Wb=b[Ib+(Xb<<2)>>1]|0;lc=b[Ib+(Xb<<2)+2>>1]|0;Xb=lc<<16>>16;do{if(lc<<16>>16<0){mc=kb+9|0;Kd=jc>>>0>mc>>>0?mc:jc;mc=nb+(Kd>>>3)|0;Ld=((fe(d[mc]|d[mc+1|0]<<8|d[mc+2|0]<<16|d[mc+3|0]<<24|0)|0)<<(Kd&7)>>>((Xb+32|0)>>>0))+Wb|0;mc=b[Ib+(Ld<<2)>>1]|0;Md=b[Ib+(Ld<<2)+2>>1]|0;Ld=Md<<16>>16;if(!(Md<<16>>16<0)){Nd=Ld;Od=mc;Pd=Kd;break}Md=Kd-Xb|0;Kd=jc>>>0>Md>>>0?Md:jc;Md=nb+(Kd>>>3)|0;Qd=((fe(d[Md]|d[Md+1|0]<<8|d[Md+2|0]<<16|d[Md+3|0]<<24|0)|0)<<(Kd&7)>>>((Ld+32|0)>>>0))+mc|0;Nd=b[Ib+(Qd<<2)+2>>1]|0;Od=b[Ib+(Qd<<2)>>1]|0;Pd=Kd}else{Nd=Xb;Od=Wb;Pd=kb}}while(0);kb=Nd+Pd|0;Wb=jc>>>0>kb>>>0?kb:jc;c[ha>>2]=Wb;if((Od|0)==($b|0)){kb=c[Ja>>2]|0;Xb=nb+(Wb>>>3)|0;Ib=(fe(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-kb|0)>>>0);Xb=kb+Wb|0;kb=jc>>>0>Xb>>>0?Xb:jc;c[ha>>2]=kb;Xb=c[Ka>>2]|0;lc=nb+(kb>>>3)|0;sb=(fe(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(kb&7)>>>((32-Xb|0)>>>0);lc=kb+Xb|0;c[ha>>2]=jc>>>0>lc>>>0?lc:jc;if(qc){Gd=sb;Hd=Ib;break}Gd=(sb&1)+sb>>1;Hd=Ib;break}if((Od|0)>=($b|0)){zb=248;break b}Ib=Od+1|0;sb=(Ib|0)%9|0;if((sb|0)==0){Rd=0;Sd=Wb}else{lc=sb+Id|0;Xb=nb+(Wb>>>3)|0;kb=(fe(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-lc|0)>>>0);Xb=lc+Wb|0;Wb=jc>>>0>Xb>>>0?Xb:jc;c[ha>>2]=Wb;Xb=kb&1;Rd=((kb>>1)+(c[((Id|0)==0?628544:628504)+(sb<<2)>>2]|0)^-Xb)+Xb|0;Sd=Wb}Wb=(Ib|0)/9|0;if((Wb|0)<=(lb|0)){Gd=0;Hd=Rd;break}Ib=Wb+(Jd<<lb)>>lb;Xb=nb+(Sd>>>3)|0;sb=(fe(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Sd&7)>>>((32-Ib|0)>>>0);Xb=Ib+Sd|0;c[ha>>2]=jc>>>0>Xb>>>0?Xb:jc;Xb=sb&1;Gd=((sb>>1)+(c[((Jd|0)==0?628544:628504)+(Wb>>lb<<2)>>2]|0)^-Xb)+Xb|0;Hd=Rd}}while(0);B2a(e,0,Hd,Gd,2,c[ea>>2]|0,c[fa>>2]|0,0);z2a(e,0,0,0);z2a(e,1,0,0);do{if((Vb&1|0)==0){Td=0;Ud=0}else{Xb=c[Xa>>2]|0;Wb=(Xb|0)==0;sb=Wb?71:125;Ib=d[Ya]|0;if((Ib|0)==1){Vd=1;Wd=0}else if((Ib|0)==2){Vd=0;Wd=1}else if((Ib|0)==3){Vd=1;Wd=1}else{Vd=0;Wd=0}Ib=c[(c[Za>>2]|0)+4>>2]|0;kb=c[ha>>2]|0;lc=c[ia>>2]|0;Tb=c[Pa>>2]|0;pb=Tb+(kb>>>3)|0;rb=(fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(kb&7)>>>23;pb=b[Ib+(rb<<2)>>1]|0;Sb=b[Ib+(rb<<2)+2>>1]|0;rb=Sb<<16>>16;do{if(Sb<<16>>16<0){Kd=kb+9|0;Qd=lc>>>0>Kd>>>0?Kd:lc;Kd=Tb+(Qd>>>3)|0;mc=((fe(d[Kd]|d[Kd+1|0]<<8|d[Kd+2|0]<<16|d[Kd+3|0]<<24|0)|0)<<(Qd&7)>>>((rb+32|0)>>>0))+pb|0;Kd=b[Ib+(mc<<2)>>1]|0;Ld=b[Ib+(mc<<2)+2>>1]|0;mc=Ld<<16>>16;if(!(Ld<<16>>16<0)){Xd=mc;Yd=Kd;Zd=Qd;break}Ld=Qd-rb|0;Qd=lc>>>0>Ld>>>0?Ld:lc;Ld=Tb+(Qd>>>3)|0;Md=((fe(d[Ld]|d[Ld+1|0]<<8|d[Ld+2|0]<<16|d[Ld+3|0]<<24|0)|0)<<(Qd&7)>>>((mc+32|0)>>>0))+Kd|0;Xd=b[Ib+(Md<<2)+2>>1]|0;Yd=b[Ib+(Md<<2)>>1]|0;Zd=Qd}else{Xd=rb;Yd=pb;Zd=kb}}while(0);kb=Xd+Zd|0;pb=lc>>>0>kb>>>0?kb:lc;c[ha>>2]=pb;if((Yd|0)==(sb|0)){kb=c[Ja>>2]|0;rb=Tb+(pb>>>3)|0;Ib=(fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(pb&7)>>>((32-kb|0)>>>0);rb=kb+pb|0;kb=lc>>>0>rb>>>0?rb:lc;c[ha>>2]=kb;rb=c[Ka>>2]|0;Sb=Tb+(kb>>>3)|0;lb=(fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(kb&7)>>>((32-rb|0)>>>0);Sb=kb+rb|0;c[ha>>2]=lc>>>0>Sb>>>0?Sb:lc;if(Wb){Td=lb;Ud=Ib;break}Td=(lb&1)+lb>>1;Ud=Ib;break}if((Yd|0)>=(sb|0)){zb=265;break b}Ib=Yd+1|0;lb=(Ib|0)%9|0;if((lb|0)==0){_d=0;$d=pb}else{Sb=lb+Vd|0;rb=Tb+(pb>>>3)|0;kb=(fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(pb&7)>>>((32-Sb|0)>>>0);rb=Sb+pb|0;pb=lc>>>0>rb>>>0?rb:lc;c[ha>>2]=pb;rb=kb&1;_d=((kb>>1)+(c[((Vd|0)==0?628544:628504)+(lb<<2)>>2]|0)^-rb)+rb|0;$d=pb}pb=(Ib|0)/9|0;if((pb|0)<=(Xb|0)){Td=0;Ud=_d;break}Ib=pb+(Wd<<Xb)>>Xb;rb=Tb+($d>>>3)|0;lb=(fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<($d&7)>>>((32-Ib|0)>>>0);rb=Ib+$d|0;c[ha>>2]=lc>>>0>rb>>>0?rb:lc;rb=lb&1;Td=((lb>>1)+(c[((Wd|0)==0?628544:628504)+(pb>>Xb<<2)>>2]|0)^-rb)+rb|0;Ud=_d}}while(0);B2a(e,2,Ud,Td,2,c[ea>>2]|0,c[fa>>2]|0,0);z2a(e,2,0,0);z2a(e,3,0,0);A2a(e,0,0,0)}else{Vb=d[$a]|0;rb=0;e:while(1){do{if((rb|0)<4){do{if((1<<3-rb&Vb|0)==0){ae=0;be=0}else{pb=c[Xa>>2]|0;lb=(pb|0)==0;Ib=lb?71:125;kb=d[Ya]|0;if((kb|0)==3){ce=1;de=1}else if((kb|0)==1){ce=1;de=0}else if((kb|0)==2){ce=0;de=1}else{ce=0;de=0}kb=c[(c[Za>>2]|0)+4>>2]|0;Sb=c[ha>>2]|0;jc=c[ia>>2]|0;nb=c[Pa>>2]|0;$b=nb+(Sb>>>3)|0;qc=(fe(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(Sb&7)>>>23;$b=b[kb+(qc<<2)>>1]|0;Qd=b[kb+(qc<<2)+2>>1]|0;qc=Qd<<16>>16;do{if(Qd<<16>>16<0){Md=Sb+9|0;Kd=jc>>>0>Md>>>0?Md:jc;Md=nb+(Kd>>>3)|0;mc=((fe(d[Md]|d[Md+1|0]<<8|d[Md+2|0]<<16|d[Md+3|0]<<24|0)|0)<<(Kd&7)>>>((qc+32|0)>>>0))+$b|0;Md=b[kb+(mc<<2)>>1]|0;Ld=b[kb+(mc<<2)+2>>1]|0;mc=Ld<<16>>16;if(!(Ld<<16>>16<0)){ee=mc;ge=Md;he=Kd;break}Ld=Kd-qc|0;Kd=jc>>>0>Ld>>>0?Ld:jc;Ld=nb+(Kd>>>3)|0;ie=((fe(d[Ld]|d[Ld+1|0]<<8|d[Ld+2|0]<<16|d[Ld+3|0]<<24|0)|0)<<(Kd&7)>>>((mc+32|0)>>>0))+Md|0;ee=b[kb+(ie<<2)+2>>1]|0;ge=b[kb+(ie<<2)>>1]|0;he=Kd}else{ee=qc;ge=$b;he=Sb}}while(0);Sb=ee+he|0;$b=jc>>>0>Sb>>>0?Sb:jc;c[ha>>2]=$b;if((ge|0)==(Ib|0)){Sb=c[Ja>>2]|0;qc=nb+($b>>>3)|0;kb=(fe(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<($b&7)>>>((32-Sb|0)>>>0);qc=Sb+$b|0;Sb=jc>>>0>qc>>>0?qc:jc;c[ha>>2]=Sb;qc=c[Ka>>2]|0;Qd=nb+(Sb>>>3)|0;Kd=(fe(d[Qd]|d[Qd+1|0]<<8|d[Qd+2|0]<<16|d[Qd+3|0]<<24|0)|0)<<(Sb&7)>>>((32-qc|0)>>>0);Qd=Sb+qc|0;c[ha>>2]=jc>>>0>Qd>>>0?Qd:jc;if(lb){ae=Kd;be=kb;break}ae=(Kd&1)+Kd>>1;be=kb;break}if((ge|0)>=(Ib|0)){zb=226;break b}kb=ge+1|0;Kd=(kb|0)%9|0;if((Kd|0)==0){je=0;ke=$b}else{Qd=Kd+ce|0;qc=nb+($b>>>3)|0;Sb=(fe(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<($b&7)>>>((32-Qd|0)>>>0);qc=Qd+$b|0;$b=jc>>>0>qc>>>0?qc:jc;c[ha>>2]=$b;qc=Sb&1;je=((Sb>>1)+(c[((ce|0)==0?628544:628504)+(Kd<<2)>>2]|0)^-qc)+qc|0;ke=$b}$b=(kb|0)/9|0;if(($b|0)<=(pb|0)){ae=0;be=je;break}kb=$b+(de<<pb)>>pb;qc=nb+(ke>>>3)|0;Kd=(fe(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<(ke&7)>>>((32-kb|0)>>>0);qc=kb+ke|0;c[ha>>2]=jc>>>0>qc>>>0?qc:jc;qc=Kd&1;ae=((Kd>>1)+(c[((de|0)==0?628544:628504)+($b>>pb<<2)>>2]|0)^-qc)+qc|0;be=je}}while(0);B2a(e,rb,be,ae,0,c[ea>>2]|0,c[fa>>2]|0,0);z2a(e,rb,0,0)}else{if((rb|0)!=4){break}A2a(e,0,0,0);rb=5;continue e}}while(0);rb=rb+1|0;if((rb|0)>=6){break}}}}while(0);mb=(sd|0)!=0;do{if(mb){if((a[la]|0)==0){le=ob;break}kc=a[na]|0;do{if(kc<<24>>24==3){rb=c[ha>>2]|0;if((a[oa]|0)!=0){Vb=d[(c[ja>>2]|0)+(rb>>>3)|0]|0;c[ha>>2]=((rb|0)<(c[ia>>2]|0))+rb;oe=d[(Vb&128>>>((rb&7)>>>0)|0)==0?V:pa]|0;break}Vb=c[ia>>2]|0;Xb=c[ja>>2]|0;lc=Xb+(rb>>>3)|0;Tb=(fe(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(rb&7)>>>29;lc=rb+3|0;rb=Vb>>>0>lc>>>0?lc:Vb;c[ha>>2]=rb;if((Tb|0)==7){lc=Xb+(rb>>>3)|0;Xb=(fe(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(rb&7)>>>27;lc=rb+5|0;c[ha>>2]=Vb>>>0>lc>>>0?lc:Vb;pe=Xb;zb=297;break}else{oe=(d[V]|0)+Tb|0;break}}else{pe=ob;zb=297}}while(0);do{if((zb|0)==297){zb=0;if((kc<<24>>24|0)==2){qe=1<<d[qa];zb=300}else if((kc<<24>>24|0)==1){qe=(3<<d[qa]|0)%15|0;zb=300}else if((kc<<24>>24|0)==0){re=15;zb=301}else{oe=pe;break}if((zb|0)==300){zb=0;if((qe&1|0)==0){se=pe;te=qe}else{re=qe;zb=301}}do{if((zb|0)==301){zb=0;if((c[w>>2]|0)!=0){se=pe;te=re;break}se=d[pa]|0;te=re}}while(0);do{if((te&2|0)==0){ue=se}else{if((c[n>>2]|0)==0){ue=se;break}ue=d[pa]|0}}while(0);do{if((te&4|0)==0){ve=ue}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){ve=ue;break}ve=d[pa]|0}}while(0);if((te&8|0)==0){oe=ve;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){oe=ve;break}oe=d[pa]|0}}while(0);if(!((oe|0)==0|(oe|0)>31)){le=oe;break}yDb(c[M>>2]|0,16,2024400,(Gb=i,i=i+8|0,c[Gb>>2]=oe,Gb)|0);i=Gb;le=1}else{le=ob}}while(0);a[(c[da>>2]|0)+jb|0]=le;if((a[sa]|0)!=0|mb^1){we=ib}else{kc=c[5254452+((c[ta>>2]|0)*20|0)>>2]|0;Tb=c[ha>>2]|0;Xb=c[ia>>2]|0;Vb=c[ja>>2]|0;lc=Vb+(Tb>>>3)|0;rb=(fe(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(Tb&7)>>>23;lc=b[kc+(rb<<2)>>1]|0;sb=b[kc+(rb<<2)+2>>1]|0;rb=sb<<16>>16;if(sb<<16>>16<0){sb=Tb+9|0;Wb=Xb>>>0>sb>>>0?sb:Xb;sb=Vb+(Wb>>>3)|0;Vb=((fe(d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)|0)<<(Wb&7)>>>((rb+32|0)>>>0))+lc|0;xe=b[kc+(Vb<<2)+2>>1]|0;ye=b[kc+(Vb<<2)>>1]|0;ze=Wb}else{xe=rb;ye=lc;ze=Tb}Tb=xe+ze|0;c[ha>>2]=Xb>>>0>Tb>>>0?Tb:Xb;we=ye}Xb=qb<<24>>24==0;Tb=we;lc=1;rb=0;Wb=0;while(1){b[(c[aa>>2]|0)+(c[e+12496+(Wb<<2)>>2]<<1)>>1]=0;Vb=(Wb>>2)+rb|0;kc=5-Wb|0;sb=(Wb&4|0)!=0;do{if(Xb){if(sb){Ae=0;break}Ae=(ba(c[wa>>2]|0,Wb<<2&8)|0)+(Wb<<3&8)|0}else{if(sb){Ae=0;break}Ae=(c[wa>>2]&-((Wb|0)>1|0))+(Wb<<3&8)|0}}while(0);if((1<<kc&sd|0)==0){Be=lc;Ce=Tb}else{if(sb){De=(c[xa>>2]|0)>>>13&1;Ee=c[va>>2]|0}else{De=0;Ee=c[wa>>2]<<Ub}u2a(e,(c[ua>>2]|0)+(Wb<<7)|0,Wb,le,Tb,lc,(c[e+12544+(Vb<<2)>>2]|0)+Ae|0,Ee,De,k)|0;Be=0;Ce=(a[sa]|0)==0&(Tb|0)<8?-1:Tb}qc=Wb+1|0;if((qc|0)<6){Tb=Ce;lc=Be;rb=Vb;Wb=qc}else{break}}}else{a[(c[J>>2]|0)+gb|0]=0;c[_>>2]=0;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[N>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[O>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[P>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[Q>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[R>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[S>>2]<<1)>>1]=0;c[(c[ca>>2]|0)+(jb<<2)>>2]=2048;a[(c[da>>2]|0)+jb|0]=0;a[(c[eb>>2]|0)+(c[N>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=0;B2a(e,0,0,0,1,c[ea>>2]|0,c[fa>>2]|0,0);x2a(e,0)}}while(0);if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){break}VGb(c[I>>2]|0,c[J>>2]|0,c[q>>2]|0)|0}else{jb=(ba(c[q>>2]|0,c[t>>2]|0)|0)+gb|0;ib=c[U>>2]|0;c[g>>2]=0;ob=d[V]|0;if((c[W>>2]|0)==0){Fe=d[(c[X>>2]|0)+jb|0]|0}else{Wb=c[ha>>2]|0;rb=d[(c[ja>>2]|0)+(Wb>>>3)|0]<<(Wb&7)>>>7;c[ha>>2]=((Wb|0)<(c[ia>>2]|0))+Wb;Fe=rb&1}if((c[Y>>2]|0)==0){Ge=d[(c[Z>>2]|0)+jb|0]|0}else{rb=c[ha>>2]|0;Wb=d[(c[ja>>2]|0)+(rb>>>3)|0]<<(rb&7)>>>7;c[ha>>2]=((rb|0)<(c[ia>>2]|0))+rb;Ge=Wb&1}Wb=(Ge|0)!=0;do{if((Fe|0)==0){if(Wb){c[_>>2]=0;a[(c[$>>2]|0)+hb|0]=0;b[(c[aa>>2]|0)+(c[N>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[O>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[P>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[Q>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[R>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[S>>2]<<1)>>1]=0;c[(c[ca>>2]|0)+(jb<<2)>>2]=2048;a[(c[da>>2]|0)+jb|0]=0;E2a(e,0,0,0,1,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);x2a(e,0);He=0;Ie=0;break}rb=c[5254692+((c[ga>>2]|0)*20|0)>>2]|0;lc=c[ha>>2]|0;Tb=c[ia>>2]|0;Ub=c[ja>>2]|0;Xb=Ub+(lc>>>3)|0;qb=(fe(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(lc&7)>>>23;Xb=b[rb+(qb<<2)>>1]|0;mb=b[rb+(qb<<2)+2>>1]|0;qb=mb<<16>>16;if(mb<<16>>16<0){mb=lc+9|0;qc=Tb>>>0>mb>>>0?mb:Tb;mb=Ub+(qc>>>3)|0;$b=((fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(qc&7)>>>((qb+32|0)>>>0))+Xb|0;Je=b[rb+($b<<2)+2>>1]|0;Ke=b[rb+($b<<2)>>1]|0;Le=qc}else{Je=qb;Ke=Xb;Le=lc}lc=Je+Le|0;Xb=Tb>>>0>lc>>>0?lc:Tb;c[ha>>2]=Xb;lc=Ke+1|0;qb=(lc|0)>36;qc=qb?Ke-36|0:lc;c[_>>2]=0;if((qc|0)==36){c[_>>2]=1;lc=c[La>>2]|0;b[lc+(hb<<2)>>1]=0;b[lc+(hb<<2)+2>>1]=0;Me=0;Ne=0;Oe=1}else if((qc|0)==0){Me=0;Ne=0;Oe=8}else if((qc|0)==35){lc=c[ka>>2]|0;$b=(c[Ja>>2]|0)-1+lc|0;rb=Ub+(Xb>>>3)|0;mb=(fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(Xb&7)>>>((32-$b|0)>>>0);rb=$b+Xb|0;$b=Tb>>>0>rb>>>0?rb:Tb;c[ha>>2]=$b;rb=lc-1+(c[Ka>>2]|0)|0;lc=Ub+($b>>>3)|0;Kd=(fe(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<($b&7)>>>((32-rb|0)>>>0);lc=rb+$b|0;c[ha>>2]=Tb>>>0>lc>>>0?lc:Tb;Me=mb;Ne=Kd;Oe=8}else{Kd=(qc|0)%6|0;mb=(c[ka>>2]|0)==0;lc=(c[436024+(Kd<<2)>>2]|0)-(mb&(Kd|0)==5&1)|0;if((lc|0)>0){$b=Ub+(Xb>>>3)|0;rb=(fe(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(Xb&7)>>>((32-lc|0)>>>0);$b=lc+Xb|0;lc=Tb>>>0>$b>>>0?$b:Tb;c[ha>>2]=lc;Pe=rb;Qe=lc}else{Pe=0;Qe=Xb}Xb=Pe&1;lc=((Pe>>1)+(c[628480+(Kd<<2)>>2]|0)^-Xb)+Xb|0;Xb=(qc|0)/6|0;if(mb){if((qc-30|0)>>>0<6>>>0){Re=1}else{zb=349}}else{zb=349}if((zb|0)==349){zb=0;Re=0}qc=(c[436024+(Xb<<2)>>2]|0)-Re|0;if((qc|0)>0){mb=Ub+(Qe>>>3)|0;Ub=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(Qe&7)>>>((32-qc|0)>>>0);mb=qc+Qe|0;c[ha>>2]=Tb>>>0>mb>>>0?mb:Tb;Se=Ub}else{Se=0}Ub=Se&1;Me=lc;Ne=((Se>>1)+(c[628480+(Xb<<2)>>2]|0)^-Ub)+Ub|0;Oe=8}c[(c[ca>>2]|0)+(jb<<2)>>2]=Oe;E2a(e,0,Me,Ne,1,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);Ub=c[_>>2]|0;Xb=qb^1;do{if((Ub|0)!=0&Xb){do{if((a[la]|0)==0){Te=ob}else{lc=a[na]|0;do{if(lc<<24>>24==3){Tb=c[ha>>2]|0;if((a[oa]|0)!=0){mb=d[(c[ja>>2]|0)+(Tb>>>3)|0]|0;c[ha>>2]=((Tb|0)<(c[ia>>2]|0))+Tb;Ue=d[(mb&128>>>((Tb&7)>>>0)|0)==0?V:pa]|0;break}mb=c[ia>>2]|0;qc=c[ja>>2]|0;Kd=qc+(Tb>>>3)|0;rb=(fe(d[Kd]|d[Kd+1|0]<<8|d[Kd+2|0]<<16|d[Kd+3|0]<<24|0)|0)<<(Tb&7)>>>29;Kd=Tb+3|0;Tb=mb>>>0>Kd>>>0?Kd:mb;c[ha>>2]=Tb;if((rb|0)==7){Kd=qc+(Tb>>>3)|0;qc=(fe(d[Kd]|d[Kd+1|0]<<8|d[Kd+2|0]<<16|d[Kd+3|0]<<24|0)|0)<<(Tb&7)>>>27;Kd=Tb+5|0;c[ha>>2]=mb>>>0>Kd>>>0?Kd:mb;Ve=qc;zb=362;break}else{Ue=(d[V]|0)+rb|0;break}}else{Ve=ob;zb=362}}while(0);do{if((zb|0)==362){zb=0;if((lc<<24>>24|0)==2){We=1<<d[qa];zb=365}else if((lc<<24>>24|0)==1){We=(3<<d[qa]|0)%15|0;zb=365}else if((lc<<24>>24|0)==0){Ye=15;zb=366}else{Ue=Ve;break}if((zb|0)==365){zb=0;if((We&1|0)==0){Ze=Ve;_e=We}else{Ye=We;zb=366}}do{if((zb|0)==366){zb=0;if((c[w>>2]|0)!=0){Ze=Ve;_e=Ye;break}Ze=d[pa]|0;_e=Ye}}while(0);do{if((_e&2|0)==0){$e=Ze}else{if((c[n>>2]|0)==0){$e=Ze;break}$e=d[pa]|0}}while(0);do{if((_e&4|0)==0){af=$e}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){af=$e;break}af=d[pa]|0}}while(0);if((_e&8|0)==0){Ue=af;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){Ue=af;break}Ue=d[pa]|0}}while(0);if(!((Ue|0)==0|(Ue|0)>31)){Te=Ue;break}yDb(c[M>>2]|0,16,2024400,(Gb=i,i=i+8|0,c[Gb>>2]=Ue,Gb)|0);i=Gb;Te=1}}while(0);Vb=c[ha>>2]|0;sb=d[(c[ja>>2]|0)+(Vb>>>3)|0]<<(Vb&7)>>>7;c[ha>>2]=((Vb|0)<(c[ia>>2]|0))+Vb;c[ma>>2]=sb&1;bf=Te;cf=0}else{if(!qb){bf=d[V]|0;cf=0;break}sb=c[ha>>2]|0;if((Ub|0)==0){df=sb;ef=c[ia>>2]|0;ff=c[ja>>2]|0}else{Vb=c[ja>>2]|0;kc=d[Vb+(sb>>>3)|0]<<(sb&7)>>>7;lc=c[ia>>2]|0;rb=((sb|0)<(lc|0))+sb|0;c[ha>>2]=rb;c[ma>>2]=kc&1;df=rb;ef=lc;ff=Vb}Vb=c[(c[Ia>>2]|0)+4>>2]|0;lc=ff+(df>>>3)|0;rb=(fe(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(df&7)>>>23;lc=b[Vb+(rb<<2)>>1]|0;kc=b[Vb+(rb<<2)+2>>1]|0;rb=kc<<16>>16;if(kc<<16>>16<0){kc=df+9|0;sb=ef>>>0>kc>>>0?kc:ef;kc=ff+(sb>>>3)|0;qc=((fe(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0)<<(sb&7)>>>((rb+32|0)>>>0))+lc|0;gf=b[Vb+(qc<<2)+2>>1]|0;hf=b[Vb+(qc<<2)>>1]|0;jf=sb}else{gf=rb;hf=lc;jf=df}lc=gf+jf|0;rb=ef>>>0>lc>>>0?lc:ef;c[ha>>2]=rb;if((a[la]|0)==0){bf=ob;cf=hf;break}lc=a[na]|0;do{if(lc<<24>>24==3){sb=ff+(rb>>>3)|0;if((a[oa]|0)!=0){qc=d[sb]|0;c[ha>>2]=((rb|0)<(ef|0))+rb;kf=d[(qc&128>>>((rb&7)>>>0)|0)==0?V:pa]|0;break}qc=sb;sb=(fe(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<(rb&7)>>>29;qc=rb+3|0;Vb=ef>>>0>qc>>>0?qc:ef;c[ha>>2]=Vb;if((sb|0)==7){qc=ff+(Vb>>>3)|0;kc=(fe(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<(Vb&7)>>>27;qc=Vb+5|0;c[ha>>2]=ef>>>0>qc>>>0?qc:ef;lf=kc;zb=393;break}else{kf=(d[V]|0)+sb|0;break}}else{lf=ob;zb=393}}while(0);do{if((zb|0)==393){zb=0;if((lc<<24>>24|0)==2){mf=1<<d[qa];zb=396}else if((lc<<24>>24|0)==1){mf=(3<<d[qa]|0)%15|0;zb=396}else if((lc<<24>>24|0)==0){nf=15;zb=397}else{kf=lf;break}if((zb|0)==396){zb=0;if((mf&1|0)==0){of=lf;pf=mf}else{nf=mf;zb=397}}do{if((zb|0)==397){zb=0;if((c[w>>2]|0)!=0){of=lf;pf=nf;break}of=d[pa]|0;pf=nf}}while(0);do{if((pf&2|0)==0){qf=of}else{if((c[n>>2]|0)==0){qf=of;break}qf=d[pa]|0}}while(0);do{if((pf&4|0)==0){rf=qf}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){rf=qf;break}rf=d[pa]|0}}while(0);if((pf&8|0)==0){kf=rf;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){kf=rf;break}kf=d[pa]|0}}while(0);if(!((kf|0)==0|(kf|0)>31)){bf=kf;cf=hf;break}yDb(c[M>>2]|0,16,2024400,(Gb=i,i=i+8|0,c[Gb>>2]=kf,Gb)|0);i=Gb;bf=1;cf=hf}}while(0);a[(c[da>>2]|0)+jb|0]=bf;Ub=c[_>>2]|0;do{if((a[sa]|0)==0){if((Ub|0)!=0|Xb){zb=416;break}qb=c[5254452+((c[ta>>2]|0)*20|0)>>2]|0;lc=c[ha>>2]|0;rb=c[ia>>2]|0;sb=c[ja>>2]|0;kc=sb+(lc>>>3)|0;qc=(fe(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0)<<(lc&7)>>>23;kc=b[qb+(qc<<2)>>1]|0;Vb=b[qb+(qc<<2)+2>>1]|0;qc=Vb<<16>>16;if(Vb<<16>>16<0){Vb=lc+9|0;mb=rb>>>0>Vb>>>0?Vb:rb;Vb=sb+(mb>>>3)|0;sb=((fe(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(mb&7)>>>((qc+32|0)>>>0))+kc|0;sf=b[qb+(sb<<2)+2>>1]|0;tf=b[qb+(sb<<2)>>1]|0;uf=mb}else{sf=qc;tf=kc;uf=lc}lc=sf+uf|0;c[ha>>2]=rb>>>0>lc>>>0?lc:rb;vf=tf;zb=417}else{zb=416}}while(0);if((zb|0)==416){zb=0;if((Ub|0)==0){vf=ib;zb=417}else{wf=0;xf=ib;yf=1;zf=0;Af=0;Bf=0}}if((zb|0)==417){zb=0;x2a(e,0);wf=0;xf=vf;yf=1;zf=0;Af=0;Bf=0}while(1){Xb=e+12496+(wf<<2)|0;rb=c[Xb>>2]|0;b[(c[aa>>2]|0)+(rb<<1)>>1]=0;lc=(wf>>2)+zf|0;kc=cf>>>((5-wf|0)>>>0)&1;qc=(wf&4|0)!=0;if(qc){Cf=0}else{Cf=(ba(c[wa>>2]|0,wf<<2&8)|0)+(wf<<3&8)|0}a[(c[$>>2]|0)+rb|0]=c[_>>2];do{if((c[_>>2]|0)==0){if((kc|0)==0){Df=Bf;Ef=Af;Ff=yf;Gf=xf;break}if(qc){Hf=(c[xa>>2]|0)>>>13&1}else{Hf=0}rb=(u2a(e,(c[ua>>2]|0)+(wf<<7)|0,wf,bf,xf,yf,(c[e+12544+(lc<<2)>>2]|0)+Cf|0,c[(qc?va:wa)>>2]|0,Hf,g)|0)<<(wf<<2)|Af;Df=Bf;Ef=rb;Ff=0;Gf=(a[sa]|0)==0&(xf|0)<8?-1:xf}else{c[ya>>2]=0;c[za>>2]=0;if((wf-2|0)>>>0<2>>>0){zb=423}else{if((c[n>>2]|0)==0){zb=423}}if((zb|0)==423){zb=0;c[za>>2]=d[(c[$>>2]|0)+((c[Xb>>2]|0)-(c[e+12520+(wf<<2)>>2]|0))|0]|0}if((wf|0)==3|(wf|0)==1){zb=426}else{if((c[w>>2]|0)!=0){zb=426}}if((zb|0)==426){zb=0;c[ya>>2]=d[(c[$>>2]|0)+((c[Xb>>2]|0)-1)|0]|0}t2a(e,(c[ua>>2]|0)+(wf<<7)|0,wf,kc,bf,c[(qc?Aa:Ba)>>2]|0);if((wf|0)>3){if((c[xa>>2]&8192|0)!=0){Df=Bf;Ef=Af;Ff=yf;Gf=xf;break}}me[c[Ca>>2]&511]((c[ua>>2]|0)+(wf<<7)|0);rb=c[ua>>2]|0;if((a[Da]|0)!=0){mb=0;do{sb=rb+(wf<<7)+(mb<<1)|0;b[sb>>1]=b[sb>>1]<<1;mb=mb+1|0;}while((mb|0)<64)}mb=e+12544+(lc<<2)|0;sb=qc?va:wa;Xe[c[Ea>>2]&4095](rb+(wf<<7)|0,(c[mb>>2]|0)+Cf|0,c[sb>>2]|0);do{if((d[V]|0)>>>0>8>>>0){if((c[Fa>>2]|0)==0){break}if((c[ya>>2]|0)!=0){ne[c[Ha>>2]&1023]((c[mb>>2]|0)+Cf|0,c[sb>>2]|0)}if((c[za>>2]|0)==0){break}ne[c[Ga>>2]&1023]((c[mb>>2]|0)+Cf|0,c[sb>>2]|0)}}while(0);Df=1<<wf|Bf;Ef=15<<(wf<<2)|Af;Ff=yf;Gf=xf}}while(0);qc=wf+1|0;if((qc|0)<6){wf=qc;xf=Gf;yf=Ff;zf=lc;Af=Ef;Bf=Df}else{break}}He=Df&255;Ie=Ef}else{if(Wb){c[_>>2]=0;a[(c[da>>2]|0)+jb|0]=0;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[N>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[O>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[P>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[Q>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[R>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[S>>2]<<1)>>1]=0;E2a(e,0,0,0,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);z2a(e,0,0,0);E2a(e,1,0,0,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);z2a(e,1,0,0);E2a(e,2,0,0,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);z2a(e,2,0,0);E2a(e,3,0,0,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);z2a(e,3,0,0);D2a(e,0);a[(c[da>>2]|0)+jb|0]=0;He=0;Ie=0;break}Ub=c[(c[Ia>>2]|0)+4>>2]|0;qc=c[ha>>2]|0;kc=c[ia>>2]|0;Xb=c[ja>>2]|0;sb=Xb+(qc>>>3)|0;mb=(fe(d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)|0)<<(qc&7)>>>23;sb=b[Ub+(mb<<2)>>1]|0;rb=b[Ub+(mb<<2)+2>>1]|0;mb=rb<<16>>16;if(rb<<16>>16<0){rb=qc+9|0;qb=kc>>>0>rb>>>0?rb:kc;rb=Xb+(qb>>>3)|0;Xb=((fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(qb&7)>>>((mb+32|0)>>>0))+sb|0;If=b[Ub+(Xb<<2)+2>>1]|0;Jf=b[Ub+(Xb<<2)>>1]|0;Kf=qb}else{If=mb;Jf=sb;Kf=qc}qc=If+Kf|0;c[ha>>2]=kc>>>0>qc>>>0?qc:kc;kc=0;qc=0;sb=0;mb=hb;while(1){qb=Jf>>>((5-kc|0)>>>0)&1;Xb=e+12496+(kc<<2)|0;b[(c[aa>>2]|0)+(mb<<1)>>1]=0;c[_>>2]=0;if((kc|0)<4){c[_>>2]=0;do{if((qb|0)==0){Lf=0;Mf=0;Nf=0;Of=0}else{Ub=c[5254692+((c[ga>>2]|0)*20|0)>>2]|0;rb=c[ha>>2]|0;Vb=c[ia>>2]|0;Kd=c[ja>>2]|0;Tb=Kd+(rb>>>3)|0;$b=(fe(d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0)|0)<<(rb&7)>>>23;Tb=b[Ub+($b<<2)>>1]|0;kb=b[Ub+($b<<2)+2>>1]|0;$b=kb<<16>>16;if(kb<<16>>16<0){kb=rb+9|0;Sb=Vb>>>0>kb>>>0?kb:Vb;kb=Kd+(Sb>>>3)|0;Qd=((fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Sb&7)>>>(($b+32|0)>>>0))+Tb|0;Pf=b[Ub+(Qd<<2)+2>>1]|0;Qf=b[Ub+(Qd<<2)>>1]|0;Rf=Sb}else{Pf=$b;Qf=Tb;Rf=rb}rb=Pf+Rf|0;Tb=Vb>>>0>rb>>>0?rb:Vb;c[ha>>2]=Tb;rb=Qf+1|0;$b=(rb|0)>36;Sb=$b&1;Qd=$b?Qf-36|0:rb;c[_>>2]=0;if((Qd|0)==35){rb=c[ka>>2]|0;$b=(c[Ja>>2]|0)-1+rb|0;Ub=Kd+(Tb>>>3)|0;kb=(fe(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Tb&7)>>>((32-$b|0)>>>0);Ub=$b+Tb|0;$b=Vb>>>0>Ub>>>0?Ub:Vb;c[ha>>2]=$b;Ub=rb-1+(c[Ka>>2]|0)|0;rb=Kd+($b>>>3)|0;ie=(fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<($b&7)>>>((32-Ub|0)>>>0);rb=Ub+$b|0;c[ha>>2]=Vb>>>0>rb>>>0?rb:Vb;Lf=qb;Mf=ie;Nf=kb;Of=Sb;break}else if((Qd|0)==36){c[_>>2]=1;Lf=qb;Mf=0;Nf=0;Of=Sb;break}else if((Qd|0)==0){Lf=qb;Mf=0;Nf=0;Of=Sb;break}else{kb=(Qd|0)%6|0;ie=(c[ka>>2]|0)==0;rb=(c[436024+(kb<<2)>>2]|0)-(ie&(kb|0)==5&1)|0;if((rb|0)>0){$b=Kd+(Tb>>>3)|0;Ub=(fe(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(Tb&7)>>>((32-rb|0)>>>0);$b=rb+Tb|0;rb=Vb>>>0>$b>>>0?$b:Vb;c[ha>>2]=rb;Sf=Ub;Tf=rb}else{Sf=0;Tf=Tb}Tb=Sf&1;rb=((Sf>>1)+(c[628480+(kb<<2)>>2]|0)^-Tb)+Tb|0;Tb=(Qd|0)/6|0;if(ie){if((Qd-30|0)>>>0<6>>>0){Uf=1}else{zb=459}}else{zb=459}if((zb|0)==459){zb=0;Uf=0}Qd=(c[436024+(Tb<<2)>>2]|0)-Uf|0;if((Qd|0)>0){ie=Kd+(Tf>>>3)|0;Kd=(fe(d[ie]|d[ie+1|0]<<8|d[ie+2|0]<<16|d[ie+3|0]<<24|0)|0)<<(Tf&7)>>>((32-Qd|0)>>>0);ie=Qd+Tf|0;c[ha>>2]=Vb>>>0>ie>>>0?ie:Vb;Vf=Kd}else{Vf=0}Kd=Vf&1;Lf=Vf;Mf=((Vf>>1)+(c[628480+(Tb<<2)>>2]|0)^-Kd)+Kd|0;Nf=rb;Of=Sb;break}}}while(0);E2a(e,kc,Nf,Mf,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);lc=c[_>>2]|0;if((lc|0)==0){z2a(e,kc,0,0);Wf=c[_>>2]|0}else{Wf=lc}c[h+(kc<<2)>>2]=Wf;c[j+(kc<<2)>>2]=Of;Xf=Wf+qc|0;Yf=Lf}else{Xf=qc;Yf=qb}if((kc&4|0)!=0){c[h+(kc<<2)>>2]=(Xf|0)>2;c[j+(kc<<2)>>2]=Yf}if((kc|0)==4){D2a(e,0)}lc=c[h+(kc<<2)>>2]|0;a[(c[$>>2]|0)+(c[Xb>>2]|0)|0]=lc;if((sb|0)==0){Zf=c[j+(kc<<2)>>2]&(lc|0)==0}else{Zf=sb}lc=kc+1|0;if((lc|0)>=6){break}kc=lc;qc=Xf;sb=Zf;mb=c[e+12496+(lc<<2)>>2]|0}mb=(Zf|0)==0;if((Zf|Xf|0)==0){He=0;Ie=0;break}do{if((a[la]|0)==0){_f=ob}else{sb=a[na]|0;do{if(sb<<24>>24==3){qc=c[ha>>2]|0;if((a[oa]|0)!=0){kc=d[(c[ja>>2]|0)+(qc>>>3)|0]|0;c[ha>>2]=((qc|0)<(c[ia>>2]|0))+qc;$f=d[(kc&128>>>((qc&7)>>>0)|0)==0?V:pa]|0;break}kc=c[ia>>2]|0;lc=c[ja>>2]|0;Sb=lc+(qc>>>3)|0;rb=(fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(qc&7)>>>29;Sb=qc+3|0;qc=kc>>>0>Sb>>>0?Sb:kc;c[ha>>2]=qc;if((rb|0)==7){Sb=lc+(qc>>>3)|0;lc=(fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(qc&7)>>>27;Sb=qc+5|0;c[ha>>2]=kc>>>0>Sb>>>0?Sb:kc;ag=lc;zb=482;break}else{$f=(d[V]|0)+rb|0;break}}else{ag=ob;zb=482}}while(0);do{if((zb|0)==482){zb=0;if((sb<<24>>24|0)==2){bg=1<<d[qa];zb=485}else if((sb<<24>>24|0)==1){bg=(3<<d[qa]|0)%15|0;zb=485}else if((sb<<24>>24|0)==0){cg=15;zb=486}else{$f=ag;break}if((zb|0)==485){zb=0;if((bg&1|0)==0){dg=ag;eg=bg}else{cg=bg;zb=486}}do{if((zb|0)==486){zb=0;if((c[w>>2]|0)!=0){dg=ag;eg=cg;break}dg=d[pa]|0;eg=cg}}while(0);do{if((eg&2|0)==0){fg=dg}else{if((c[n>>2]|0)==0){fg=dg;break}fg=d[pa]|0}}while(0);do{if((eg&4|0)==0){gg=fg}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){gg=fg;break}gg=d[pa]|0}}while(0);if((eg&8|0)==0){$f=gg;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){$f=gg;break}$f=d[pa]|0}}while(0);if(!(($f|0)==0|($f|0)>31)){_f=$f;break}yDb(c[M>>2]|0,16,2024400,(Gb=i,i=i+8|0,c[Gb>>2]=$f,Gb)|0);i=Gb;_f=1}}while(0);a[(c[da>>2]|0)+jb|0]=_f;sb=0;f:while(1){do{if((c[h+(sb<<2)>>2]|0)!=0){if((c[n>>2]|0)==0){zb=503}else{if((sb-2|0)>>>0<2>>>0){zb=503}}if((zb|0)==503){zb=0;if((a[(c[$>>2]|0)+((c[e+12496+(sb<<2)>>2]|0)-(c[e+12520+(sb<<2)>>2]|0))|0]|0)!=0){zb=508;break f}}if((c[w>>2]|0)==0){if(!((sb|0)==3|(sb|0)==1)){break}}if((a[(c[$>>2]|0)+((c[e+12496+(sb<<2)>>2]|0)-1)|0]|0)!=0){zb=508;break f}}}while(0);Xb=sb+1|0;if((Xb|0)<6){sb=Xb}else{hg=0;break}}if((zb|0)==508){zb=0;sb=c[ha>>2]|0;Xb=d[(c[ja>>2]|0)+(sb>>>3)|0]<<(sb&7)>>>7;c[ha>>2]=((sb|0)<(c[ia>>2]|0))+sb;hg=Xb&1}c[ma>>2]=hg;if((a[sa]|0)!=0|mb){ig=0;jg=ib;kg=1;lg=0;mg=0;ng=0}else{Xb=c[5254452+((c[ta>>2]|0)*20|0)>>2]|0;sb=c[ha>>2]|0;qb=c[ia>>2]|0;rb=c[ja>>2]|0;lc=rb+(sb>>>3)|0;kc=(fe(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(sb&7)>>>23;lc=b[Xb+(kc<<2)>>1]|0;Sb=b[Xb+(kc<<2)+2>>1]|0;kc=Sb<<16>>16;if(Sb<<16>>16<0){Sb=sb+9|0;qc=qb>>>0>Sb>>>0?Sb:qb;Sb=rb+(qc>>>3)|0;rb=((fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(qc&7)>>>((kc+32|0)>>>0))+lc|0;og=b[Xb+(rb<<2)+2>>1]|0;pg=b[Xb+(rb<<2)>>1]|0;qg=qc}else{og=kc;pg=lc;qg=sb}sb=og+qg|0;c[ha>>2]=qb>>>0>sb>>>0?sb:qb;ig=0;jg=pg;kg=1;lg=0;mg=0;ng=0}while(1){qb=(ig>>2)+lg|0;sb=(ig&4|0)!=0;if(sb){rg=0}else{rg=(ba(c[wa>>2]|0,ig<<2&8)|0)+(ig<<3&8)|0}lc=c[h+(ig<<2)>>2]|0;c[_>>2]=lc;do{if((lc|0)==0){if((c[j+(ig<<2)>>2]|0)==0){sg=ng;tg=mg;ug=kg;vg=jg;break}if(sb){wg=(c[xa>>2]|0)>>>13&1}else{wg=0}kc=(u2a(e,(c[ua>>2]|0)+(ig<<7)|0,ig,_f,jg,kg,(c[e+12544+(qb<<2)>>2]|0)+rg|0,c[(sb?va:wa)>>2]|0,wg,g)|0)<<(ig<<2)|mg;sg=ng;tg=kc;ug=0;vg=(a[sa]|0)==0&(jg|0)<8?-1:jg}else{c[ya>>2]=0;c[za>>2]=0;if((ig-2|0)>>>0<2>>>0){zb=518}else{if((c[n>>2]|0)==0){zb=518}}if((zb|0)==518){zb=0;c[za>>2]=d[(c[$>>2]|0)+((c[e+12496+(ig<<2)>>2]|0)-(c[e+12520+(ig<<2)>>2]|0))|0]|0}if((ig|0)==3|(ig|0)==1){zb=521}else{if((c[w>>2]|0)!=0){zb=521}}if((zb|0)==521){zb=0;c[ya>>2]=d[(c[$>>2]|0)+((c[e+12496+(ig<<2)>>2]|0)-1)|0]|0}t2a(e,(c[ua>>2]|0)+(ig<<7)|0,ig,c[j+(ig<<2)>>2]|0,_f,c[(sb?Aa:Ba)>>2]|0);if((ig|0)>3){if((c[xa>>2]&8192|0)!=0){sg=ng;tg=mg;ug=kg;vg=jg;break}}me[c[Ca>>2]&511]((c[ua>>2]|0)+(ig<<7)|0);kc=c[ua>>2]|0;if((a[Da]|0)!=0){qc=0;do{rb=kc+(ig<<7)+(qc<<1)|0;b[rb>>1]=b[rb>>1]<<1;qc=qc+1|0;}while((qc|0)<64)}qc=e+12544+(qb<<2)|0;rb=sb?va:wa;Xe[c[Ea>>2]&4095](kc+(ig<<7)|0,(c[qc>>2]|0)+rg|0,c[rb>>2]|0);do{if((d[V]|0)>>>0>8>>>0){if((c[Fa>>2]|0)==0){break}if((c[ya>>2]|0)!=0){ne[c[Ha>>2]&1023]((c[qc>>2]|0)+rg|0,c[rb>>2]|0)}if((c[za>>2]|0)==0){break}ne[c[Ga>>2]&1023]((c[qc>>2]|0)+rg|0,c[rb>>2]|0)}}while(0);sg=1<<ig|ng;tg=15<<(ig<<2)|mg;ug=kg;vg=jg}}while(0);sb=ig+1|0;if((sb|0)<6){ig=sb;jg=vg;kg=ug;lg=qb;mg=tg;ng=sg}else{break}}He=sg&255;Ie=tg}}while(0);c[(c[F>>2]|0)+(c[w>>2]<<2)>>2]=Ie;c[(c[H>>2]|0)+(c[w>>2]<<2)>>2]=c[g>>2];a[(c[J>>2]|0)+(c[w>>2]|0)|0]=He}}while(0);if(!((c[t>>2]|0)==(c[r>>2]|0)|Ma)){F2a(e)}hb=c[ha>>2]|0;if((hb|0)>(c[Na>>2]|0)|(hb|0)<0){zb=545;break b}gb=(c[w>>2]|0)+1|0;c[w>>2]=gb;if((gb|0)>=(c[E>>2]|0)){break}}}VGb(c[p>>2]|0,c[F>>2]|0,c[q>>2]<<2|0)|0;VGb(c[G>>2]|0,c[H>>2]|0,c[q>>2]<<2|0)|0;VGb(c[I>>2]|0,c[J>>2]|0,c[q>>2]|0)|0;VGb(c[K>>2]|0,c[L>>2]|0,c[q>>2]<<2|0)|0;gb=c[t>>2]|0;if((gb|0)==(c[r>>2]|0)){xg=gb}else{_Oa(m,(gb<<4)-16|0,16);xg=c[t>>2]|0}c[n>>2]=0;gb=xg+1|0;c[t>>2]=gb;hb=c[u>>2]|0;if((gb|0)>=(hb|0)){yg=hb;break a}}if((zb|0)==72){yDb(0,0,2287080,(Gb=i,i=i+24|0,c[Gb>>2]=1998536,c[Gb+8>>2]=2255584,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Cd()}else if((zb|0)==93){yDb(0,0,2287080,(Gb=i,i=i+24|0,c[Gb>>2]=1998536,c[Gb+8>>2]=2255584,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Cd()}else if((zb|0)==226){yDb(0,0,2287080,(Gb=i,i=i+24|0,c[Gb>>2]=1998536,c[Gb+8>>2]=2255584,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Cd()}else if((zb|0)==248){yDb(0,0,2287080,(Gb=i,i=i+24|0,c[Gb>>2]=1998536,c[Gb+8>>2]=2255584,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Cd()}else if((zb|0)==265){yDb(0,0,2287080,(Gb=i,i=i+24|0,c[Gb>>2]=1998536,c[Gb+8>>2]=2255584,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Cd()}else if((zb|0)==283){yDb(0,0,2287080,(Gb=i,i=i+24|0,c[Gb>>2]=1998536,c[Gb+8>>2]=2255584,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Cd()}else if((zb|0)==545){Lkb(e+14424|0,0,c[r>>2]|0,c[w>>2]|0,c[t>>2]|0,14);L=c[Na>>2]|0;K=c[w>>2]|0;J=c[t>>2]|0;yDb(c[M>>2]|0,16,2028048,(Gb=i,i=i+32|0,c[Gb>>2]=c[ha>>2],c[Gb+8>>2]=L,c[Gb+16>>2]=K,c[Gb+24>>2]=J,Gb)|0);i=Gb;i=f;return}}else{yg=v}}while(0);if(o){o=e+12476|0;c[o>>2]=0;$Oa(m);do{if((c[e+19428>>2]|0)!=0){if((c[e+19436>>2]|0)!=(d[e+19231|0]|0)){break}v=c[e+9856>>2]|0;Gb=e+12544|0;c[Gb>>2]=(c[Gb>>2]|0)+(c[v+32>>2]|0);Gb=e+12548|0;c[Gb>>2]=(c[Gb>>2]|0)+(c[v+36>>2]|0);Gb=e+12552|0;c[Gb>>2]=(c[Gb>>2]|0)+(c[v+40>>2]|0)}}while(0);v=e+116|0;if((c[o>>2]|0)<(c[v>>2]|0)){Gb=e+4|0;t=e+12496|0;zb=e+12500|0;xg=e+12504|0;n=e+12508|0;q=e+12512|0;p=e+12516|0;He=e+12544|0;g=e+12548|0;Ie=e+12552|0;do{tg=8>>>((c[(c[Gb>>2]|0)+800>>2]|0)>>>0);c[t>>2]=(c[t>>2]|0)+2;c[zb>>2]=(c[zb>>2]|0)+2;c[xg>>2]=(c[xg>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;c[q>>2]=(c[q>>2]|0)+1;c[p>>2]=(c[p>>2]|0)+1;c[He>>2]=(c[He>>2]|0)+(tg<<1);c[g>>2]=(c[g>>2]|0)+tg;c[Ie>>2]=(c[Ie>>2]|0)+tg;F2a(e);tg=(c[o>>2]|0)+1|0;c[o>>2]=tg;}while((tg|0)<(c[v>>2]|0))}zg=c[u>>2]|0}else{zg=yg}yg=c[r>>2]|0;if((zg|0)<(yg|0)){Ag=yg;Bg=zg}else{_Oa(m,(zg<<4)-16|0,16);Ag=c[r>>2]|0;Bg=c[u>>2]|0}u=c[e+19428>>2]|0;Lkb(e+14424|0,0,Ag<<u,(c[e+116>>2]|0)-1|0,(Bg<<u)-1|0,112);i=f;return}function i2a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=e|0;l=c[e+16008>>2]|0;if((l|0)==1){c[e+16032>>2]=0;c[e+16036>>2]=1}else if((l|0)==2){c[e+16032>>2]=4;c[e+16036>>2]=5}else if((l|0)==0){c[e+16032>>2]=(c[e+16040>>2]|0)<9?6:2;c[e+16036>>2]=(c[e+16040>>2]|0)<9?7:3}l=e+14084|0;c[l>>2]=1;m=e+808|0;n=c[m>>2]|0;o=e+12480|0;c[o>>2]=n;p=e+812|0;q=c[p>>2]|0;a:do{if((n|0)<(q|0)){r=e+12476|0;s=e+19428|0;t=e+19436|0;u=e+19231|0;v=e+9856|0;w=e+12544|0;x=e+12548|0;y=e+12552|0;z=e+116|0;A=e+13836|0;B=e+4|0;C=e+12496|0;D=e+12500|0;E=e+12504|0;F=e+12508|0;G=e+12512|0;H=e+12516|0;I=e+19224|0;J=e+124|0;K=e+16016|0;L=e+15728|0;M=e+12488|0;N=e+16108|0;O=e+16096|0;P=e+16116|0;Q=e+9928|0;R=h+4|0;S=h|0;T=g+4|0;U=g|0;V=e+16056|0;W=e+9876|0;X=e+9136|0;Y=e+16084|0;Z=e+14128|0;_=e+14136|0;$=e+14120|0;aa=e+16004|0;ca=e+16020|0;da=e+16088|0;ea=e+16005|0;fa=e+16007|0;ga=e+15729|0;ha=e+16006|0;ia=e+120|0;ja=e+14340|0;ka=e+152|0;la=e+148|0;ma=e+60|0;na=e+16048|0;oa=e+16044|0;pa=e+16036|0;qa=e+16032|0;ra=e+15332|0;sa=e+19220|0;ta=e+10068|0;ua=e+176|0;va=e+14060|0;wa=e+13924|0;xa=e+15712|0;ya=e+15716|0;za=e+16070|0;Aa=e+15576|0;Ba=e+19304|0;Ca=e+14120|0;Da=e+19592|0;Ea=e+9152|0;Fa=e+19472|0;Ga=e+9160|0;Ha=e+9888|0;Ia=e+168|0;Ja=e+9892|0;Ka=e+172|0;La=e+19252|0;Ma=e+16112|0;Na=e+16100|0;Oa=j+4|0;Pa=j|0;Qa=e+19480|0;Ra=e+9852|0;Sa=e+19444|0;Ta=e+19288|0;Ua=e+19308|0;Va=e+19316|0;Wa=e+19321|0;b:while(1){c[r>>2]=0;$Oa(k);do{if((c[s>>2]|0)!=0){if((c[t>>2]|0)!=(d[u]|0)){break}Xa=c[v>>2]|0;c[w>>2]=(c[w>>2]|0)+(c[Xa+32>>2]|0);c[x>>2]=(c[x>>2]|0)+(c[Xa+36>>2]|0);c[y>>2]=(c[y>>2]|0)+(c[Xa+40>>2]|0)}}while(0);Xa=c[r>>2]|0;if((Xa|0)<(c[z>>2]|0)){Ya=Xa;while(1){Xa=8>>>((c[(c[B>>2]|0)+800>>2]|0)>>>0);Za=(c[C>>2]|0)+2|0;c[C>>2]=Za;c[D>>2]=(c[D>>2]|0)+2;c[E>>2]=(c[E>>2]|0)+2;c[F>>2]=(c[F>>2]|0)+2;c[G>>2]=(c[G>>2]|0)+1;c[H>>2]=(c[H>>2]|0)+1;c[w>>2]=(c[w>>2]|0)+(Xa<<1);c[x>>2]=(c[x>>2]|0)+Xa;c[y>>2]=(c[y>>2]|0)+Xa;Xa=c[I>>2]|0;c:do{if((Xa|0)==2){_a=(ba(c[J>>2]|0,c[o>>2]|0)|0)+Ya|0;$a=c[K>>2]|0;ab=d[L]|0;c[M>>2]=0;bb=c[(c[Ba>>2]|0)+4>>2]|0;cb=c[Z>>2]|0;db=c[_>>2]|0;eb=c[Ca>>2]|0;fb=eb+(cb>>>3)|0;gb=(fe(d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0)|0)<<(cb&7)>>>27;fb=b[bb+(gb<<2)>>1]|0;hb=b[bb+(gb<<2)+2>>1]|0;gb=hb<<16>>16;if(hb<<16>>16<0){hb=cb+5|0;ib=db>>>0>hb>>>0?hb:db;hb=eb+(ib>>>3)|0;eb=((fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(ib&7)>>>((gb+32|0)>>>0))+fb|0;jb=b[bb+(eb<<2)+2>>1]|0;kb=b[bb+(eb<<2)>>1]|0;lb=ib}else{jb=gb;kb=fb;lb=cb}cb=jb+lb|0;c[Z>>2]=db>>>0>cb>>>0?cb:db;db=(c[Da>>2]|0)+Ya|0;if((kb|0)<2){a[db]=1;c[M>>2]=1;cb=c[C>>2]|0;fb=c[Ea>>2]|0;b[fb+(cb<<2)>>1]=0;b[fb+(cb<<2)+2>>1]=0;c[(c[Ga>>2]|0)+((c[Fa>>2]|0)+_a<<2)>>2]=1;do{if((a[aa]|0)==0){mb=ab}else{cb=a[ea]|0;do{if(cb<<24>>24==3){fb=c[Z>>2]|0;if((a[fa]|0)!=0){gb=d[(c[Ca>>2]|0)+(fb>>>3)|0]|0;c[Z>>2]=((fb|0)<(c[_>>2]|0))+fb;nb=d[(gb&128>>>((fb&7)>>>0)|0)==0?L:ga]|0;break}gb=c[_>>2]|0;ib=c[Ca>>2]|0;eb=ib+(fb>>>3)|0;bb=(fe(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(fb&7)>>>29;eb=fb+3|0;fb=gb>>>0>eb>>>0?eb:gb;c[Z>>2]=fb;if((bb|0)==7){eb=ib+(fb>>>3)|0;ib=(fe(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(fb&7)>>>27;eb=fb+5|0;c[Z>>2]=gb>>>0>eb>>>0?eb:gb;ob=ib;pb=23;break}else{nb=(d[L]|0)+bb|0;break}}else{ob=ab;pb=23}}while(0);do{if((pb|0)==23){pb=0;if((cb<<24>>24|0)==2){qb=1<<d[ha];pb=26}else if((cb<<24>>24|0)==1){qb=(3<<d[ha]|0)%15|0;pb=26}else if((cb<<24>>24|0)==0){rb=15;pb=27}else{nb=ob;break}if((pb|0)==26){pb=0;if((qb&1|0)==0){sb=ob;tb=qb}else{rb=qb;pb=27}}do{if((pb|0)==27){pb=0;if((c[r>>2]|0)!=0){sb=ob;tb=rb;break}sb=d[ga]|0;tb=rb}}while(0);do{if((tb&2|0)==0){ub=sb}else{if((c[l>>2]|0)==0){ub=sb;break}ub=d[ga]|0}}while(0);do{if((tb&4|0)==0){vb=ub}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){vb=ub;break}vb=d[ga]|0}}while(0);if((tb&8|0)==0){nb=vb;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){nb=vb;break}nb=d[ga]|0}}while(0);if(!((nb|0)==0|(nb|0)>31)){mb=nb;break}yDb(c[B>>2]|0,16,2024400,(wb=i,i=i+8|0,c[wb>>2]=nb,wb)|0);i=wb;mb=1}}while(0);a[(c[X>>2]|0)+_a|0]=mb;c[Ia>>2]=d[(c[Ha>>2]|0)+mb|0]|0;c[Ka>>2]=d[(c[Ja>>2]|0)+mb|0]|0;cb=c[Z>>2]|0;bb=d[(c[Ca>>2]|0)+(cb>>>3)|0]<<(cb&7)>>>7;c[Z>>2]=((cb|0)<(c[_>>2]|0))+cb;cb=bb&1;a[(c[La>>2]|0)+_a|0]=cb;c[ua>>2]=cb;if((kb&1|0)==0){xb=0}else{cb=c[(c[Y>>2]|0)+4>>2]|0;bb=c[Z>>2]|0;ib=c[_>>2]|0;gb=c[Ca>>2]|0;eb=gb+(bb>>>3)|0;fb=(fe(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(bb&7)>>>23;eb=b[cb+(fb<<2)>>1]|0;hb=b[cb+(fb<<2)+2>>1]|0;fb=hb<<16>>16;if(hb<<16>>16<0){hb=bb+9|0;yb=ib>>>0>hb>>>0?hb:ib;hb=gb+(yb>>>3)|0;gb=((fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(yb&7)>>>((fb+32|0)>>>0))+eb|0;zb=b[cb+(gb<<2)+2>>1]|0;Ab=b[cb+(gb<<2)>>1]|0;Bb=yb}else{zb=fb;Ab=eb;Bb=bb}bb=zb+Bb|0;c[Z>>2]=ib>>>0>bb>>>0?bb:ib;xb=Ab+1|0}ib=0;bb=0;while(1){eb=e+12496+(bb<<2)|0;fb=c[eb>>2]|0;b[(c[W>>2]|0)+(fb<<1)>>1]=0;ib=(bb>>2)+ib|0;yb=xb>>>((5-bb|0)>>>0)&1;a[(c[V>>2]|0)+fb|0]=c[M>>2];c[na>>2]=0;c[oa>>2]=0;if((bb-2|0)>>>0<2>>>0){pb=47}else{if((c[l>>2]|0)==0){pb=47}}if((pb|0)==47){pb=0;c[oa>>2]=d[(c[V>>2]|0)+((c[eb>>2]|0)-(c[e+12520+(bb<<2)>>2]|0))|0]|0}if((bb|0)==3|(bb|0)==1){pb=50}else{if((c[r>>2]|0)!=0){pb=50}}if((pb|0)==50){pb=0;c[na>>2]=d[(c[V>>2]|0)+((c[eb>>2]|0)-1)|0]|0}eb=(bb&4|0)!=0;t2a(e,(c[ja>>2]|0)+(bb<<7)|0,bb,yb,mb,c[(eb?pa:qa)>>2]|0);if((bb|0)>3){if((c[ma>>2]&8192|0)==0){pb=53}}else{pb=53}if((pb|0)==53){pb=0;me[c[ra>>2]&511]((c[ja>>2]|0)+(bb<<7)|0);if((a[sa]|0)!=0){yb=c[ja>>2]|0;fb=0;do{gb=yb+(bb<<7)+(fb<<1)|0;b[gb>>1]=b[gb>>1]<<1;fb=fb+1|0;}while((fb|0)<64)}if(eb){Cb=0}else{Cb=(ba(c[la>>2]|0,bb<<2&8)|0)+(bb<<3&8)|0}Xe[c[ta>>2]&4095]((c[ja>>2]|0)+(bb<<7)|0,(c[e+12544+(ib<<2)>>2]|0)+Cb|0,c[(eb?ka:la)>>2]|0)}bb=bb+1|0;if((bb|0)>=6){break c}}}a[db]=0;c[M>>2]=0;c[(c[Ga>>2]|0)+((c[Fa>>2]|0)+_a<<2)>>2]=8;a[(c[V>>2]|0)+(c[C>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[D>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[E>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[F>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[G>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[H>>2]|0)|0]=0;if((c[Ma>>2]|0)==0){Db=a[(c[Na>>2]|0)+_a|0]|0}else{bb=c[Z>>2]|0;ib=d[(c[Ca>>2]|0)+(bb>>>3)|0]<<(bb&7)>>>7;c[Z>>2]=((bb|0)<(c[_>>2]|0))+bb;bb=ib&1;a[(c[Na>>2]|0)+_a|0]=bb;Db=bb}if((kb|0)<6){c[R>>2]=0;c[S>>2]=0;c[T>>2]=0;c[U>>2]=0;c[Oa>>2]=0;c[Pa>>2]=0;do{if(Db<<24>>24==0){bb=c[Z>>2]|0;ib=c[Ca>>2]|0;fb=d[ib+(bb>>>3)|0]|0;yb=c[_>>2]|0;gb=((bb|0)<(yb|0))+bb|0;c[Z>>2]=gb;if((fb&128>>>((bb&7)>>>0)|0)==0){Eb=0;Fb=0;pb=69;break}bb=d[ib+(gb>>>3)|0]<<(gb&7)>>>7;fb=((gb|0)<(yb|0))+gb|0;c[Z>>2]=fb;gb=bb&1;bb=gb+1|0;if((gb|0)==0){c[Qa>>2]=3}else if((gb|0)==1){gb=d[ib+(fb>>>3)|0]<<(fb&7)>>>7;c[Z>>2]=((fb|0)<(yb|0))+fb;Eb=gb&1;Fb=2;pb=69;break}else{c[Qa>>2]=bb;if((bb|0)!=3){Gb=bb;Hb=0;pb=71;break}}c[S>>2]=0;c[U>>2]=0;c[Pa>>2]=0;c[R>>2]=0;c[T>>2]=0;if((c[(c[Ra>>2]|0)+2164>>2]|0)==0){yDb(c[B>>2]|0,16,1991328,(wb=i,i=i+1|0,i=i+7&-8,c[wb>>2]=0,wb)|0);i=wb;break c}else{C2a(e,0,U,S,1,Pa);x2a(e,0);y2a(e);break}}else{Eb=0;Fb=1;pb=69}}while(0);if((pb|0)==69){pb=0;c[Qa>>2]=Fb;Gb=Fb;Hb=Eb;pb=71}do{if((pb|0)==71){pb=0;do{if((kb&1|0)!=0){db=(Gb|0)==0|0;bb=g+(db<<2)|0;gb=h+(db<<2)|0;fb=j+(db<<2)|0;db=c[Sa>>2]|0;yb=(db|0)==0;ib=yb?71:125;cb=d[Ta]|0;if((cb|0)==1){Ib=1;Jb=0}else if((cb|0)==2){Ib=0;Jb=1}else if((cb|0)==3){Ib=1;Jb=1}else{Ib=0;Jb=0}cb=c[(c[Ua>>2]|0)+4>>2]|0;hb=c[Z>>2]|0;Kb=c[_>>2]|0;Lb=c[Ca>>2]|0;Mb=Lb+(hb>>>3)|0;Nb=(fe(d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0)|0)<<(hb&7)>>>23;Mb=b[cb+(Nb<<2)>>1]|0;Ob=b[cb+(Nb<<2)+2>>1]|0;Nb=Ob<<16>>16;do{if(Ob<<16>>16<0){Pb=hb+9|0;Qb=Kb>>>0>Pb>>>0?Pb:Kb;Pb=Lb+(Qb>>>3)|0;Rb=((fe(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(Qb&7)>>>((Nb+32|0)>>>0))+Mb|0;Pb=b[cb+(Rb<<2)>>1]|0;Sb=b[cb+(Rb<<2)+2>>1]|0;Rb=Sb<<16>>16;if(!(Sb<<16>>16<0)){Tb=Rb;Ub=Pb;Vb=Qb;break}Sb=Qb-Nb|0;Qb=Kb>>>0>Sb>>>0?Sb:Kb;Sb=Lb+(Qb>>>3)|0;Wb=((fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(Qb&7)>>>((Rb+32|0)>>>0))+Pb|0;Tb=b[cb+(Wb<<2)+2>>1]|0;Ub=b[cb+(Wb<<2)>>1]|0;Vb=Qb}else{Tb=Nb;Ub=Mb;Vb=hb}}while(0);hb=Tb+Vb|0;Mb=Kb>>>0>hb>>>0?hb:Kb;c[Z>>2]=Mb;if((Ub|0)==(ib|0)){hb=c[xa>>2]|0;Nb=Lb+(Mb>>>3)|0;cb=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Mb&7)>>>((32-hb|0)>>>0);Nb=hb+Mb|0;hb=Kb>>>0>Nb>>>0?Nb:Kb;c[Z>>2]=hb;c[bb>>2]=cb;cb=c[ya>>2]|0;Nb=Lb+(hb>>>3)|0;Ob=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(hb&7)>>>((32-cb|0)>>>0);Nb=hb+cb|0;c[Z>>2]=Kb>>>0>Nb>>>0?Nb:Kb;c[gb>>2]=Ob;if(yb){break}Nb=Ob&1;c[fb>>2]=Nb;c[gb>>2]=Nb+Ob>>1;break}if((Ub|0)>=(ib|0)){pb=83;break b}Ob=Ub+1|0;Nb=(Ob|0)%9|0;if((Nb|0)==0){Xb=0;Yb=Mb}else{cb=Nb+Ib|0;hb=Lb+(Mb>>>3)|0;Qb=(fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(Mb&7)>>>((32-cb|0)>>>0);hb=cb+Mb|0;Mb=Kb>>>0>hb>>>0?hb:Kb;c[Z>>2]=Mb;hb=Qb&1;Xb=((Qb>>1)+(c[((Ib|0)==0?628544:628504)+(Nb<<2)>>2]|0)^-hb)+hb|0;Yb=Mb}c[bb>>2]=Xb;Mb=(Ob|0)/9|0;if((Mb|0)>(db|0)){Ob=Mb+(Jb<<db)>>db;hb=Lb+(Yb>>>3)|0;Nb=(fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(Yb&7)>>>((32-Ob|0)>>>0);hb=Ob+Yb|0;c[Z>>2]=Kb>>>0>hb>>>0?hb:Kb;hb=Nb&1;Zb=((Nb>>1)+(c[((Jb|0)==0?628544:628504)+(Mb>>db<<2)>>2]|0)^-hb)+hb|0}else{Zb=0}c[gb>>2]=Zb;if(yb){break}c[fb>>2]=Mb&1}}while(0);do{if((Hb|0)!=0){eb=c[Sa>>2]|0;Mb=(eb|0)==0;hb=Mb?71:125;Nb=d[Ta]|0;if((Nb|0)==1){_b=1;$b=0}else if((Nb|0)==2){_b=0;$b=1}else if((Nb|0)==3){_b=1;$b=1}else{_b=0;$b=0}Nb=c[(c[Ua>>2]|0)+4>>2]|0;Ob=c[Z>>2]|0;Qb=c[_>>2]|0;cb=c[Ca>>2]|0;Wb=cb+(Ob>>>3)|0;Pb=(fe(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Ob&7)>>>23;Wb=b[Nb+(Pb<<2)>>1]|0;Rb=b[Nb+(Pb<<2)+2>>1]|0;Pb=Rb<<16>>16;do{if(Rb<<16>>16<0){Sb=Ob+9|0;ac=Qb>>>0>Sb>>>0?Sb:Qb;Sb=cb+(ac>>>3)|0;bc=((fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(ac&7)>>>((Pb+32|0)>>>0))+Wb|0;Sb=b[Nb+(bc<<2)>>1]|0;cc=b[Nb+(bc<<2)+2>>1]|0;bc=cc<<16>>16;if(!(cc<<16>>16<0)){dc=bc;ec=Sb;fc=ac;break}cc=ac-Pb|0;ac=Qb>>>0>cc>>>0?cc:Qb;cc=cb+(ac>>>3)|0;gc=((fe(d[cc]|d[cc+1|0]<<8|d[cc+2|0]<<16|d[cc+3|0]<<24|0)|0)<<(ac&7)>>>((bc+32|0)>>>0))+Sb|0;dc=b[Nb+(gc<<2)+2>>1]|0;ec=b[Nb+(gc<<2)>>1]|0;fc=ac}else{dc=Pb;ec=Wb;fc=Ob}}while(0);Ob=dc+fc|0;Wb=Qb>>>0>Ob>>>0?Ob:Qb;c[Z>>2]=Wb;if((ec|0)==(hb|0)){Ob=c[xa>>2]|0;Pb=cb+(Wb>>>3)|0;Nb=(fe(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-Ob|0)>>>0);Pb=Ob+Wb|0;Ob=Qb>>>0>Pb>>>0?Pb:Qb;c[Z>>2]=Ob;c[T>>2]=Nb;Nb=c[ya>>2]|0;Pb=cb+(Ob>>>3)|0;Rb=(fe(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(Ob&7)>>>((32-Nb|0)>>>0);Pb=Ob+Nb|0;c[Z>>2]=Qb>>>0>Pb>>>0?Pb:Qb;c[R>>2]=Rb;if(Mb){break}Pb=Rb&1;c[Oa>>2]=Pb;c[R>>2]=Pb+Rb>>1;break}if((ec|0)>=(hb|0)){pb=102;break b}Rb=ec+1|0;Pb=(Rb|0)%9|0;if((Pb|0)==0){hc=0;ic=Wb}else{Nb=Pb+_b|0;Ob=cb+(Wb>>>3)|0;fb=(fe(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Wb&7)>>>((32-Nb|0)>>>0);Ob=Nb+Wb|0;Wb=Qb>>>0>Ob>>>0?Ob:Qb;c[Z>>2]=Wb;Ob=fb&1;hc=((fb>>1)+(c[((_b|0)==0?628544:628504)+(Pb<<2)>>2]|0)^-Ob)+Ob|0;ic=Wb}c[T>>2]=hc;Wb=(Rb|0)/9|0;if((Wb|0)>(eb|0)){Rb=Wb+($b<<eb)>>eb;Ob=cb+(ic>>>3)|0;Pb=(fe(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(ic&7)>>>((32-Rb|0)>>>0);Ob=Rb+ic|0;c[Z>>2]=Qb>>>0>Ob>>>0?Ob:Qb;Ob=Pb&1;jc=((Pb>>1)+(c[(($b|0)==0?628544:628504)+(Wb>>eb<<2)>>2]|0)^-Ob)+Ob|0}else{jc=0}c[R>>2]=jc;if(Mb){break}c[Oa>>2]=Wb&1}}while(0);C2a(e,0,U,S,1,Pa);if((Gb|0)==2){x2a(e,0);y2a(e);break}else{x2a(e,(Gb|0)==0|0);break}}}while(0);kc=kb>>>1&1^1}else{Wb=Db<<24>>24!=0|0;c[Qa>>2]=Wb;Ob=c[(c[Va>>2]|0)+4>>2]|0;Pb=c[Z>>2]|0;Rb=c[_>>2]|0;fb=(c[Ca>>2]|0)+(Pb>>>3)|0;Nb=(fe(d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0)|0)<<(Pb&7)>>>26;fb=b[Ob+(Nb<<2)>>1]|0;yb=(b[Ob+(Nb<<2)+2>>1]|0)+Pb|0;c[Z>>2]=Rb>>>0>yb>>>0?yb:Rb;a[Wa]=fb;fb=Wb^1;Wb=g+(fb<<2)|0;Rb=h+(fb<<2)|0;yb=j+(fb<<2)|0;Pb=0;d:while(1){do{if((Pb|0)<4){c[Pa>>2]=0;c[S>>2]=0;c[U>>2]=0;c[Oa>>2]=0;c[R>>2]=0;c[T>>2]=0;do{if((d[Wa]&1<<3-Pb|0)!=0){Nb=c[Sa>>2]|0;Ob=(Nb|0)==0;gb=Ob?71:125;db=d[Ta]|0;if((db|0)==1){lc=1;mc=0}else if((db|0)==2){lc=0;mc=1}else if((db|0)==3){lc=1;mc=1}else{lc=0;mc=0}db=c[(c[Ua>>2]|0)+4>>2]|0;Kb=c[Z>>2]|0;Lb=c[_>>2]|0;bb=c[Ca>>2]|0;ib=bb+(Kb>>>3)|0;ac=(fe(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)|0)<<(Kb&7)>>>23;ib=b[db+(ac<<2)>>1]|0;gc=b[db+(ac<<2)+2>>1]|0;ac=gc<<16>>16;do{if(gc<<16>>16<0){Sb=Kb+9|0;bc=Lb>>>0>Sb>>>0?Sb:Lb;Sb=bb+(bc>>>3)|0;cc=((fe(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(bc&7)>>>((ac+32|0)>>>0))+ib|0;Sb=b[db+(cc<<2)>>1]|0;nc=b[db+(cc<<2)+2>>1]|0;cc=nc<<16>>16;if(!(nc<<16>>16<0)){oc=cc;pc=Sb;qc=bc;break}nc=bc-ac|0;bc=Lb>>>0>nc>>>0?nc:Lb;nc=bb+(bc>>>3)|0;rc=((fe(d[nc]|d[nc+1|0]<<8|d[nc+2|0]<<16|d[nc+3|0]<<24|0)|0)<<(bc&7)>>>((cc+32|0)>>>0))+Sb|0;oc=b[db+(rc<<2)+2>>1]|0;pc=b[db+(rc<<2)>>1]|0;qc=bc}else{oc=ac;pc=ib;qc=Kb}}while(0);Kb=oc+qc|0;ib=Lb>>>0>Kb>>>0?Kb:Lb;c[Z>>2]=ib;if((pc|0)==(gb|0)){Kb=c[xa>>2]|0;ac=bb+(ib>>>3)|0;db=(fe(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(ib&7)>>>((32-Kb|0)>>>0);ac=Kb+ib|0;Kb=Lb>>>0>ac>>>0?ac:Lb;c[Z>>2]=Kb;c[Wb>>2]=db;db=c[ya>>2]|0;ac=bb+(Kb>>>3)|0;gc=(fe(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(Kb&7)>>>((32-db|0)>>>0);ac=Kb+db|0;c[Z>>2]=Lb>>>0>ac>>>0?ac:Lb;c[Rb>>2]=gc;if(Ob){break}ac=gc&1;c[yb>>2]=ac;c[Rb>>2]=ac+gc>>1;break}if((pc|0)>=(gb|0)){pb=130;break b}gc=pc+1|0;ac=(gc|0)%9|0;if((ac|0)==0){sc=0;tc=ib}else{db=ac+lc|0;Kb=bb+(ib>>>3)|0;bc=(fe(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(ib&7)>>>((32-db|0)>>>0);Kb=db+ib|0;ib=Lb>>>0>Kb>>>0?Kb:Lb;c[Z>>2]=ib;Kb=bc&1;sc=((bc>>1)+(c[((lc|0)==0?628544:628504)+(ac<<2)>>2]|0)^-Kb)+Kb|0;tc=ib}c[Wb>>2]=sc;ib=(gc|0)/9|0;if((ib|0)>(Nb|0)){gc=ib+(mc<<Nb)>>Nb;Kb=bb+(tc>>>3)|0;ac=(fe(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(tc&7)>>>((32-gc|0)>>>0);Kb=gc+tc|0;c[Z>>2]=Lb>>>0>Kb>>>0?Kb:Lb;Kb=ac&1;uc=((ac>>1)+(c[((mc|0)==0?628544:628504)+(ib>>Nb<<2)>>2]|0)^-Kb)+Kb|0}else{uc=0}c[Rb>>2]=uc;if(Ob){break}c[yb>>2]=ib&1}}while(0);C2a(e,Pb,U,S,0,Pa);z2a(e,Pb,fb,0)}else{if((Pb|0)!=4){break}D2a(e,fb);Pb=5;continue d}}while(0);Pb=Pb+1|0;if((Pb|0)>=6){break}}kc=kb&1}do{if((kc|0)==0){vc=ab;wc=0;xc=1}else{Pb=c[(c[Y>>2]|0)+4>>2]|0;fb=c[Z>>2]|0;yb=c[_>>2]|0;Rb=c[Ca>>2]|0;Wb=Rb+(fb>>>3)|0;Mb=(fe(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(fb&7)>>>23;Wb=b[Pb+(Mb<<2)>>1]|0;eb=b[Pb+(Mb<<2)+2>>1]|0;Mb=eb<<16>>16;if(eb<<16>>16<0){eb=fb+9|0;Qb=yb>>>0>eb>>>0?eb:yb;eb=Rb+(Qb>>>3)|0;cb=((fe(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(Qb&7)>>>((Mb+32|0)>>>0))+Wb|0;yc=b[Pb+(cb<<2)+2>>1]|0;zc=b[Pb+(cb<<2)>>1]|0;Ac=Qb}else{yc=Mb;zc=Wb;Ac=fb}fb=yc+Ac|0;Wb=yb>>>0>fb>>>0?fb:yb;c[Z>>2]=Wb;fb=zc+1|0;if((fb|0)==0){vc=ab;wc=0;xc=1;break}if((a[aa]|0)==0){vc=ab;wc=fb;xc=0;break}Mb=a[ea]|0;do{if(Mb<<24>>24==3){Qb=Rb+(Wb>>>3)|0;if((a[fa]|0)!=0){cb=d[Qb]|0;c[Z>>2]=((Wb|0)<(yb|0))+Wb;Bc=d[(cb&128>>>((Wb&7)>>>0)|0)==0?L:ga]|0;break}cb=Qb;Qb=(fe(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Wb&7)>>>29;cb=Wb+3|0;Pb=yb>>>0>cb>>>0?cb:yb;c[Z>>2]=Pb;if((Qb|0)==7){cb=Rb+(Pb>>>3)|0;eb=(fe(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Pb&7)>>>27;cb=Pb+5|0;c[Z>>2]=yb>>>0>cb>>>0?cb:yb;Cc=eb;pb=153;break}else{Bc=(d[L]|0)+Qb|0;break}}else{Cc=ab;pb=153}}while(0);do{if((pb|0)==153){pb=0;if((Mb<<24>>24|0)==2){Dc=1<<d[ha];pb=156}else if((Mb<<24>>24|0)==1){Dc=(3<<d[ha]|0)%15|0;pb=156}else if((Mb<<24>>24|0)==0){Ec=15;pb=157}else{Bc=Cc;break}if((pb|0)==156){pb=0;if((Dc&1|0)==0){Fc=Cc;Gc=Dc}else{Ec=Dc;pb=157}}do{if((pb|0)==157){pb=0;if((c[r>>2]|0)!=0){Fc=Cc;Gc=Ec;break}Fc=d[ga]|0;Gc=Ec}}while(0);do{if((Gc&2|0)==0){Hc=Fc}else{if((c[l>>2]|0)==0){Hc=Fc;break}Hc=d[ga]|0}}while(0);do{if((Gc&4|0)==0){Ic=Hc}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){Ic=Hc;break}Ic=d[ga]|0}}while(0);if((Gc&8|0)==0){Bc=Ic;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){Bc=Ic;break}Bc=d[ga]|0}}while(0);if(!((Bc|0)==0|(Bc|0)>31)){vc=Bc;wc=fb;xc=0;break}yDb(c[B>>2]|0,16,2024400,(wb=i,i=i+8|0,c[wb>>2]=Bc,wb)|0);i=wb;vc=1;wc=fb;xc=0}}while(0);a[(c[X>>2]|0)+_a|0]=vc;if((a[ca]|0)!=0|xc){Jc=$a;Kc=1;Lc=0;Mc=0}else{ab=c[5254452+((c[da>>2]|0)*20|0)>>2]|0;Mb=c[Z>>2]|0;yb=c[_>>2]|0;Rb=c[Ca>>2]|0;Wb=Rb+(Mb>>>3)|0;Qb=(fe(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Mb&7)>>>23;Wb=b[ab+(Qb<<2)>>1]|0;eb=b[ab+(Qb<<2)+2>>1]|0;Qb=eb<<16>>16;if(eb<<16>>16<0){eb=Mb+9|0;cb=yb>>>0>eb>>>0?eb:yb;eb=Rb+(cb>>>3)|0;Rb=((fe(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(cb&7)>>>((Qb+32|0)>>>0))+Wb|0;Nc=b[ab+(Rb<<2)+2>>1]|0;Oc=b[ab+(Rb<<2)>>1]|0;Pc=cb}else{Nc=Qb;Oc=Wb;Pc=Mb}Mb=Nc+Pc|0;c[Z>>2]=yb>>>0>Mb>>>0?Mb:yb;Jc=Oc;Kc=1;Lc=0;Mc=0}while(1){b[(c[W>>2]|0)+(c[e+12496+(Mc<<2)>>2]<<1)>>1]=0;yb=(Mc>>2)+Lc|0;Mb=(Mc&4|0)!=0;if(Mb){Qc=0}else{Qc=(ba(c[la>>2]|0,Mc<<2&8)|0)+(Mc<<3&8)|0}if((1<<5-Mc&wc|0)==0){Rc=Kc;Sc=Jc}else{if(Mb){Tc=(c[ma>>2]|0)>>>13&1}else{Tc=0}u2a(e,(c[ja>>2]|0)+(Mc<<7)|0,Mc,vc,Jc,Kc,(c[e+12544+(yb<<2)>>2]|0)+Qc|0,c[(Mb?ka:la)>>2]|0,Tc,0)|0;Rc=0;Sc=(a[ca]|0)==0&(Jc|0)<8?-1:Jc}Mb=Mc+1|0;if((Mb|0)<6){Jc=Sc;Kc=Rc;Lc=yb;Mc=Mb}else{break}}}else if((Xa|0)==1){q2a(e)}else{$a=(ba(c[J>>2]|0,c[o>>2]|0)|0)+Ya|0;_a=c[K>>2]|0;Mb=d[L]|0;c[M>>2]=0;if((c[N>>2]|0)==0){Uc=d[(c[O>>2]|0)+$a|0]|0}else{yb=c[Z>>2]|0;Wb=d[(c[$>>2]|0)+(yb>>>3)|0]<<(yb&7)>>>7;c[Z>>2]=((yb|0)<(c[_>>2]|0))+yb;Uc=Wb&1}if((c[P>>2]|0)==0){Vc=d[(c[Q>>2]|0)+$a|0]|0}else{Wb=c[Z>>2]|0;yb=d[(c[$>>2]|0)+(Wb>>>3)|0]<<(Wb&7)>>>7;c[Z>>2]=((Wb|0)<(c[_>>2]|0))+Wb;Vc=yb&1}c[R>>2]=0;c[S>>2]=0;c[T>>2]=0;c[U>>2]=0;a[(c[V>>2]|0)+Za|0]=0;b[(c[W>>2]|0)+(c[C>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[D>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[D>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[E>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[E>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[F>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[F>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[G>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[G>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[H>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[H>>2]<<1)>>1]=0;a[(c[X>>2]|0)+$a|0]=0;yb=(Uc|0)!=0;do{if(yb){Wc=0;Xc=0}else{if((Vc|0)==0){Wb=c[5254692+((c[va>>2]|0)*20|0)>>2]|0;Qb=c[Z>>2]|0;cb=c[_>>2]|0;Rb=c[$>>2]|0;ab=Rb+(Qb>>>3)|0;eb=(fe(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(Qb&7)>>>23;ab=b[Wb+(eb<<2)>>1]|0;Pb=b[Wb+(eb<<2)+2>>1]|0;eb=Pb<<16>>16;if(Pb<<16>>16<0){Pb=Qb+9|0;hb=cb>>>0>Pb>>>0?Pb:cb;Pb=Rb+(hb>>>3)|0;ib=((fe(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(hb&7)>>>((eb+32|0)>>>0))+ab|0;Yc=b[Wb+(ib<<2)+2>>1]|0;Zc=b[Wb+(ib<<2)>>1]|0;_c=hb}else{Yc=eb;Zc=ab;_c=Qb}Qb=Yc+_c|0;ab=cb>>>0>Qb>>>0?Qb:cb;c[Z>>2]=ab;Qb=Zc+1|0;eb=(Qb|0)>36;hb=eb&1;ib=eb?Zc-36|0:Qb;c[M>>2]=0;if((ib|0)==0){c[S>>2]=0;c[U>>2]=0;$c=0;ad=0;bd=ab}else if((ib|0)==35){Qb=c[wa>>2]|0;eb=(c[xa>>2]|0)-1+Qb|0;Wb=Rb+(ab>>>3)|0;Pb=(fe(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(ab&7)>>>((32-eb|0)>>>0);Wb=eb+ab|0;eb=cb>>>0>Wb>>>0?Wb:cb;c[Z>>2]=eb;c[U>>2]=Pb;Wb=Qb-1+(c[ya>>2]|0)|0;Qb=Rb+(eb>>>3)|0;Kb=(fe(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(eb&7)>>>((32-Wb|0)>>>0);Qb=eb+Wb|0;Wb=cb>>>0>Qb>>>0?Qb:cb;c[Z>>2]=Wb;c[S>>2]=Kb;$c=Pb;ad=Kb;bd=Wb}else if((ib|0)==36){c[U>>2]=0;c[S>>2]=0;c[M>>2]=1;c[T>>2]=0;c[R>>2]=0;Wc=0;Xc=hb;break}else{Wb=(ib|0)%6|0;Kb=(c[wa>>2]|0)==0;Pb=(c[436024+(Wb<<2)>>2]|0)-(Kb&(Wb|0)==5&1)|0;if((Pb|0)>0){Qb=Rb+(ab>>>3)|0;eb=(fe(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(ab&7)>>>((32-Pb|0)>>>0);Qb=Pb+ab|0;Pb=cb>>>0>Qb>>>0?Qb:cb;c[Z>>2]=Pb;cd=eb;dd=Pb}else{cd=0;dd=ab}ab=cd&1;Pb=((cd>>1)+(c[628480+(Wb<<2)>>2]|0)^-ab)+ab|0;c[U>>2]=Pb;ab=(ib|0)/6|0;if(Kb){if((ib-30|0)>>>0<6>>>0){ed=1}else{pb=200}}else{pb=200}if((pb|0)==200){pb=0;ed=0}ib=(c[436024+(ab<<2)>>2]|0)-ed|0;if((ib|0)>0){Kb=Rb+(dd>>>3)|0;Wb=(fe(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(dd&7)>>>((32-ib|0)>>>0);Kb=ib+dd|0;ib=cb>>>0>Kb>>>0?Kb:cb;c[Z>>2]=ib;fd=Wb;gd=ib}else{fd=0;gd=dd}ib=fd&1;Wb=((fd>>1)+(c[628480+(ab<<2)>>2]|0)^-ib)+ib|0;c[S>>2]=Wb;$c=Pb;ad=Wb;bd=gd}c[T>>2]=$c;c[R>>2]=ad;hd=hb;id=bd;jd=Rb;kd=cb}else{hd=0;id=c[Z>>2]|0;jd=c[$>>2]|0;kd=c[_>>2]|0}cb=d[jd+(id>>>3)|0]|0;Rb=((id|0)<(kd|0))+id|0;c[Z>>2]=Rb;if((cb&128>>>((id&7)>>>0)|0)==0){Wc=(b[za>>1]|0)<128|0;Xc=hd;break}cb=d[jd+(Rb>>>3)|0]<<(Rb&7)>>>7;c[Z>>2]=((Rb|0)<(kd|0))+Rb;Rb=cb&1;if((Rb|0)==0){Wc=(b[za>>1]|0)>127|0;Xc=hd;break}else if((Rb|0)==1){c[S>>2]=0;c[U>>2]=0;Wc=2;Xc=hd;break}else{Wc=Rb+1|0;Xc=hd;break}}}while(0);a[(c[V>>2]|0)+(c[C>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[D>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[E>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[F>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[G>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[H>>2]|0)|0]=c[M>>2];if((Vc|0)!=0){Rb=yb?2:Wc;s2a(e,U,S,Uc,Rb);if((Uc|0)!=0){x2a(e,0);y2a(e);break}if((Rb|0)==2){x2a(e,0);y2a(e);break}else{x2a(e,(Rb|0)==0|0);break}}do{if(yb){Rb=c[(c[Y>>2]|0)+4>>2]|0;cb=c[Z>>2]|0;hb=c[_>>2]|0;Wb=c[$>>2]|0;Pb=Wb+(cb>>>3)|0;ib=(fe(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(cb&7)>>>23;Pb=b[Rb+(ib<<2)>>1]|0;ab=b[Rb+(ib<<2)+2>>1]|0;ib=ab<<16>>16;if(ab<<16>>16<0){ab=cb+9|0;Kb=hb>>>0>ab>>>0?ab:hb;ab=Wb+(Kb>>>3)|0;eb=((fe(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(Kb&7)>>>((ib+32|0)>>>0))+Pb|0;ld=b[Rb+(eb<<2)+2>>1]|0;md=b[Rb+(eb<<2)>>1]|0;nd=Kb}else{ld=ib;md=Pb;nd=cb}cb=ld+nd|0;Pb=hb>>>0>cb>>>0?cb:hb;c[Z>>2]=Pb;do{if((a[aa]|0)==0){od=Mb}else{cb=a[ea]|0;do{if(cb<<24>>24==3){ib=Wb+(Pb>>>3)|0;if((a[fa]|0)!=0){Kb=d[ib]|0;c[Z>>2]=((Pb|0)<(hb|0))+Pb;pd=d[(Kb&128>>>((Pb&7)>>>0)|0)==0?L:ga]|0;break}Kb=ib;ib=(fe(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(Pb&7)>>>29;Kb=Pb+3|0;eb=hb>>>0>Kb>>>0?Kb:hb;c[Z>>2]=eb;if((ib|0)==7){Kb=Wb+(eb>>>3)|0;Rb=(fe(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(eb&7)>>>27;Kb=eb+5|0;c[Z>>2]=hb>>>0>Kb>>>0?Kb:hb;qd=Rb;pb=228;break}else{pd=(d[L]|0)+ib|0;break}}else{qd=Mb;pb=228}}while(0);do{if((pb|0)==228){pb=0;if((cb<<24>>24|0)==2){rd=1<<d[ha];pb=231}else if((cb<<24>>24|0)==1){rd=(3<<d[ha]|0)%15|0;pb=231}else if((cb<<24>>24|0)==0){sd=15;pb=232}else{pd=qd;break}if((pb|0)==231){pb=0;if((rd&1|0)==0){td=qd;ud=rd}else{sd=rd;pb=232}}do{if((pb|0)==232){pb=0;if((c[r>>2]|0)!=0){td=qd;ud=sd;break}td=d[ga]|0;ud=sd}}while(0);do{if((ud&2|0)==0){vd=td}else{if((c[l>>2]|0)==0){vd=td;break}vd=d[ga]|0}}while(0);do{if((ud&4|0)==0){wd=vd}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){wd=vd;break}wd=d[ga]|0}}while(0);if((ud&8|0)==0){pd=wd;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){pd=wd;break}pd=d[ga]|0}}while(0);if(!((pd|0)==0|(pd|0)>31)){od=pd;break}yDb(c[B>>2]|0,16,2024400,(wb=i,i=i+8|0,c[wb>>2]=pd,wb)|0);i=wb;od=1}}while(0);c[M>>2]=0;a[(c[X>>2]|0)+$a|0]=od;if((a[ca]|0)==0){hb=c[5254452+((c[da>>2]|0)*20|0)>>2]|0;Wb=c[Z>>2]|0;Pb=c[_>>2]|0;fb=c[$>>2]|0;cb=fb+(Wb>>>3)|0;Ob=(fe(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Wb&7)>>>23;cb=b[hb+(Ob<<2)>>1]|0;Nb=b[hb+(Ob<<2)+2>>1]|0;Ob=Nb<<16>>16;if(Nb<<16>>16<0){Nb=Wb+9|0;Lb=Pb>>>0>Nb>>>0?Nb:Pb;Nb=fb+(Lb>>>3)|0;fb=((fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Lb&7)>>>((Ob+32|0)>>>0))+cb|0;xd=b[hb+(fb<<2)+2>>1]|0;yd=b[hb+(fb<<2)>>1]|0;zd=Lb}else{xd=Ob;yd=cb;zd=Wb}Wb=xd+zd|0;c[Z>>2]=Pb>>>0>Wb>>>0?Wb:Pb;Ad=yd}else{Ad=_a}c[R>>2]=0;c[T>>2]=0;c[S>>2]=0;c[U>>2]=0;s2a(e,U,S,Uc,Wc);x2a(e,0);y2a(e);Bd=Ad;Dd=od;Ed=md}else{if((Xc|0)==0){if((c[M>>2]|0)==0){s2a(e,U,S,0,Wc);if((Wc|0)==2){x2a(e,0);y2a(e);break c}else{x2a(e,(Wc|0)==0|0);break c}}do{if((a[aa]|0)==0){Fd=Mb}else{Pb=a[ea]|0;do{if(Pb<<24>>24==3){Wb=c[Z>>2]|0;if((a[fa]|0)!=0){cb=d[(c[$>>2]|0)+(Wb>>>3)|0]|0;c[Z>>2]=((Wb|0)<(c[_>>2]|0))+Wb;Gd=d[(cb&128>>>((Wb&7)>>>0)|0)==0?L:ga]|0;break}cb=c[_>>2]|0;Ob=c[$>>2]|0;Lb=Ob+(Wb>>>3)|0;fb=(fe(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(Wb&7)>>>29;Lb=Wb+3|0;Wb=cb>>>0>Lb>>>0?Lb:cb;c[Z>>2]=Wb;if((fb|0)==7){Lb=Ob+(Wb>>>3)|0;Ob=(fe(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(Wb&7)>>>27;Lb=Wb+5|0;c[Z>>2]=cb>>>0>Lb>>>0?Lb:cb;Hd=Ob;pb=262;break}else{Gd=(d[L]|0)+fb|0;break}}else{Hd=Mb;pb=262}}while(0);do{if((pb|0)==262){pb=0;if((Pb<<24>>24|0)==0){Id=15;pb=266}else if((Pb<<24>>24|0)==2){Jd=1<<d[ha];pb=265}else if((Pb<<24>>24|0)==1){Jd=(3<<d[ha]|0)%15|0;pb=265}else{Gd=Hd;break}if((pb|0)==265){pb=0;if((Jd&1|0)==0){Kd=Hd;Ld=Jd}else{Id=Jd;pb=266}}do{if((pb|0)==266){pb=0;if((c[r>>2]|0)!=0){Kd=Hd;Ld=Id;break}Kd=d[ga]|0;Ld=Id}}while(0);do{if((Ld&2|0)==0){Md=Kd}else{if((c[l>>2]|0)==0){Md=Kd;break}Md=d[ga]|0}}while(0);do{if((Ld&4|0)==0){Nd=Md}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){Nd=Md;break}Nd=d[ga]|0}}while(0);if((Ld&8|0)==0){Gd=Nd;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){Gd=Nd;break}Gd=d[ga]|0}}while(0);if(!((Gd|0)==0|(Gd|0)>31)){Fd=Gd;break}yDb(c[B>>2]|0,16,2024400,(wb=i,i=i+8|0,c[wb>>2]=Gd,wb)|0);i=wb;Fd=1}}while(0);a[(c[X>>2]|0)+$a|0]=Fd;Pb=c[Z>>2]|0;fb=d[(c[$>>2]|0)+(Pb>>>3)|0]<<(Pb&7)>>>7;c[Z>>2]=((Pb|0)<(c[_>>2]|0))+Pb;c[ua>>2]=fb&1;s2a(e,U,S,0,Wc);Bd=_a;Dd=Fd;Ed=0;break}fb=(Wc|0)==2;do{if(fb){Pb=c[5254692+((c[va>>2]|0)*20|0)>>2]|0;Ob=c[Z>>2]|0;cb=c[_>>2]|0;Lb=c[$>>2]|0;Wb=Lb+(Ob>>>3)|0;hb=(fe(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Ob&7)>>>23;Wb=b[Pb+(hb<<2)>>1]|0;Nb=b[Pb+(hb<<2)+2>>1]|0;hb=Nb<<16>>16;if(Nb<<16>>16<0){Nb=Ob+9|0;bb=cb>>>0>Nb>>>0?Nb:cb;Nb=Lb+(bb>>>3)|0;gb=((fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(bb&7)>>>((hb+32|0)>>>0))+Wb|0;Od=b[Pb+(gb<<2)+2>>1]|0;Pd=b[Pb+(gb<<2)>>1]|0;Qd=bb}else{Od=hb;Pd=Wb;Qd=Ob}Ob=Od+Qd|0;Wb=cb>>>0>Ob>>>0?Ob:cb;c[Z>>2]=Wb;Ob=Pd+1|0;hb=(Ob|0)>36;bb=hb&1;gb=hb?Pd-36|0:Ob;c[M>>2]=0;if((gb|0)==0){c[S>>2]=0;c[U>>2]=0}else if((gb|0)==35){Ob=c[wa>>2]|0;Pb=(c[xa>>2]|0)-1+Ob|0;Nb=Lb+(Wb>>>3)|0;ib=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-Pb|0)>>>0);Nb=Pb+Wb|0;Pb=cb>>>0>Nb>>>0?Nb:cb;c[Z>>2]=Pb;c[U>>2]=ib;ib=Ob-1+(c[ya>>2]|0)|0;Ob=Lb+(Pb>>>3)|0;Nb=(fe(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Pb&7)>>>((32-ib|0)>>>0);Ob=Pb+ib|0;c[Z>>2]=cb>>>0>Ob>>>0?Ob:cb;c[S>>2]=Nb}else if((gb|0)==36){c[U>>2]=0;c[S>>2]=0;c[M>>2]=1}else{Nb=(gb|0)%6|0;Ob=(c[wa>>2]|0)==0;ib=(c[436024+(Nb<<2)>>2]|0)-(Ob&(Nb|0)==5&1)|0;if((ib|0)>0){Pb=Lb+(Wb>>>3)|0;Rb=(fe(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-ib|0)>>>0);Pb=ib+Wb|0;ib=cb>>>0>Pb>>>0?Pb:cb;c[Z>>2]=ib;Rd=Rb;Sd=ib}else{Rd=0;Sd=Wb}Wb=Rd&1;c[U>>2]=((Rd>>1)+(c[628480+(Nb<<2)>>2]|0)^-Wb)+Wb;Wb=(gb|0)/6|0;if(Ob){if((gb-30|0)>>>0<6>>>0){Td=1}else{pb=291}}else{pb=291}if((pb|0)==291){pb=0;Td=0}gb=(c[436024+(Wb<<2)>>2]|0)-Td|0;if((gb|0)>0){Ob=Lb+(Sd>>>3)|0;Lb=(fe(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Sd&7)>>>((32-gb|0)>>>0);Ob=gb+Sd|0;c[Z>>2]=cb>>>0>Ob>>>0?Ob:cb;Ud=Lb}else{Ud=0}Lb=Ud&1;c[S>>2]=((Ud>>1)+(c[628480+(Wb<<2)>>2]|0)^-Lb)+Lb}if(hb){Vd=bb;break}s2a(e,U,S,0,2);x2a(e,0);y2a(e);break c}else{Vd=Xc}}while(0);s2a(e,U,S,0,Wc);do{if((c[M>>2]|0)==0){if(fb){x2a(e,0);y2a(e)}else{x2a(e,(Wc|0)==0|0)}if((c[M>>2]|0)!=0){pb=303;break}Wd=c[Z>>2]|0;Xd=c[_>>2]|0;Yd=c[$>>2]|0}else{pb=303}}while(0);if((pb|0)==303){pb=0;fb=c[Z>>2]|0;bb=c[$>>2]|0;hb=d[bb+(fb>>>3)|0]<<(fb&7)>>>7;Lb=c[_>>2]|0;Wb=((fb|0)<(Lb|0))+fb|0;c[Z>>2]=Wb;c[ua>>2]=hb&1;Wd=Wb;Xd=Lb;Yd=bb}bb=c[(c[Y>>2]|0)+4>>2]|0;Lb=Yd+(Wd>>>3)|0;Wb=(fe(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(Wd&7)>>>23;Lb=b[bb+(Wb<<2)>>1]|0;hb=b[bb+(Wb<<2)+2>>1]|0;Wb=hb<<16>>16;if(hb<<16>>16<0){hb=Wd+9|0;fb=Xd>>>0>hb>>>0?hb:Xd;hb=Yd+(fb>>>3)|0;cb=((fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(fb&7)>>>((Wb+32|0)>>>0))+Lb|0;Zd=b[bb+(cb<<2)+2>>1]|0;_d=b[bb+(cb<<2)>>1]|0;$d=fb}else{Zd=Wb;_d=Lb;$d=Wd}Lb=Zd+$d|0;Wb=Xd>>>0>Lb>>>0?Lb:Xd;c[Z>>2]=Wb;do{if((a[aa]|0)==0){ae=Mb}else{Lb=a[ea]|0;do{if(Lb<<24>>24==3){fb=Yd+(Wb>>>3)|0;if((a[fa]|0)!=0){cb=d[fb]|0;c[Z>>2]=((Wb|0)<(Xd|0))+Wb;be=d[(cb&128>>>((Wb&7)>>>0)|0)==0?L:ga]|0;break}cb=fb;fb=(fe(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Wb&7)>>>29;cb=Wb+3|0;bb=Xd>>>0>cb>>>0?cb:Xd;c[Z>>2]=bb;if((fb|0)==7){cb=Yd+(bb>>>3)|0;hb=(fe(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(bb&7)>>>27;cb=bb+5|0;c[Z>>2]=Xd>>>0>cb>>>0?cb:Xd;ce=hb;pb=313;break}else{be=(d[L]|0)+fb|0;break}}else{ce=Mb;pb=313}}while(0);do{if((pb|0)==313){pb=0;if((Lb<<24>>24|0)==2){de=1<<d[ha];pb=316}else if((Lb<<24>>24|0)==1){de=(3<<d[ha]|0)%15|0;pb=316}else if((Lb<<24>>24|0)==0){ee=15;pb=317}else{be=ce;break}if((pb|0)==316){pb=0;if((de&1|0)==0){ge=ce;he=de}else{ee=de;pb=317}}do{if((pb|0)==317){pb=0;if((c[r>>2]|0)!=0){ge=ce;he=ee;break}ge=d[ga]|0;he=ee}}while(0);do{if((he&2|0)==0){ie=ge}else{if((c[l>>2]|0)==0){ie=ge;break}ie=d[ga]|0}}while(0);do{if((he&4|0)==0){je=ie}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){je=ie;break}je=d[ga]|0}}while(0);if((he&8|0)==0){be=je;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){be=je;break}be=d[ga]|0}}while(0);if(!((be|0)==0|(be|0)>31)){ae=be;break}yDb(c[B>>2]|0,16,2024400,(wb=i,i=i+8|0,c[wb>>2]=be,wb)|0);i=wb;ae=1}}while(0);a[(c[X>>2]|0)+$a|0]=ae;if((a[ca]|0)!=0){Bd=_a;Dd=ae;Ed=_d;break}if((c[M>>2]|0)!=0|(Vd|0)==0){Bd=_a;Dd=ae;Ed=_d;break}Wb=c[5254452+((c[da>>2]|0)*20|0)>>2]|0;Lb=c[Z>>2]|0;fb=c[_>>2]|0;hb=c[$>>2]|0;cb=hb+(Lb>>>3)|0;bb=(fe(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Lb&7)>>>23;cb=b[Wb+(bb<<2)>>1]|0;Ob=b[Wb+(bb<<2)+2>>1]|0;bb=Ob<<16>>16;if(Ob<<16>>16<0){Ob=Lb+9|0;gb=fb>>>0>Ob>>>0?Ob:fb;Ob=hb+(gb>>>3)|0;hb=((fe(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(gb&7)>>>((bb+32|0)>>>0))+cb|0;ke=b[Wb+(hb<<2)+2>>1]|0;le=b[Wb+(hb<<2)>>1]|0;ne=gb}else{ke=bb;le=cb;ne=Lb}Lb=ke+ne|0;c[Z>>2]=fb>>>0>Lb>>>0?Lb:fb;Bd=le;Dd=ae;Ed=_d}}while(0);_a=Bd;$a=1;Mb=0;yb=0;while(1){fb=e+12496+(yb<<2)|0;Lb=c[fb>>2]|0;b[(c[W>>2]|0)+(Lb<<1)>>1]=0;cb=(yb>>2)+Mb|0;bb=Ed>>>((5-yb|0)>>>0)&1;gb=(yb&4|0)!=0;if(gb){oe=0}else{oe=(ba(c[la>>2]|0,yb<<2&8)|0)+(yb<<3&8)|0}a[(c[V>>2]|0)+Lb|0]=c[M>>2];do{if((c[M>>2]|0)==0){if((bb|0)==0){pe=$a;qe=_a;break}if(gb){re=(c[ma>>2]|0)>>>13&1}else{re=0}u2a(e,(c[ja>>2]|0)+(yb<<7)|0,yb,Dd,_a,$a,(c[e+12544+(cb<<2)>>2]|0)+oe|0,c[(gb?ka:la)>>2]|0,re,0)|0;pe=0;qe=(a[ca]|0)==0&(_a|0)<8?-1:_a}else{c[na>>2]=0;c[oa>>2]=0;if((yb-2|0)>>>0<2>>>0){pb=341}else{if((c[l>>2]|0)==0){pb=341}}if((pb|0)==341){pb=0;c[oa>>2]=d[(c[V>>2]|0)+((c[fb>>2]|0)-(c[e+12520+(yb<<2)>>2]|0))|0]|0}if((yb|0)==3|(yb|0)==1){pb=344}else{if((c[r>>2]|0)!=0){pb=344}}if((pb|0)==344){pb=0;c[na>>2]=d[(c[V>>2]|0)+((c[fb>>2]|0)-1)|0]|0}t2a(e,(c[ja>>2]|0)+(yb<<7)|0,yb,bb,Dd,c[(gb?pa:qa)>>2]|0);if((yb|0)>3){if((c[ma>>2]&8192|0)!=0){pe=$a;qe=_a;break}}me[c[ra>>2]&511]((c[ja>>2]|0)+(yb<<7)|0);Lb=c[ja>>2]|0;if((a[sa]|0)!=0){hb=0;do{Wb=Lb+(yb<<7)+(hb<<1)|0;b[Wb>>1]=b[Wb>>1]<<1;hb=hb+1|0;}while((hb|0)<64)}Xe[c[ta>>2]&4095](Lb+(yb<<7)|0,(c[e+12544+(cb<<2)>>2]|0)+oe|0,c[(gb?ka:la)>>2]|0);pe=$a;qe=_a}}while(0);gb=yb+1|0;if((gb|0)<6){_a=qe;$a=pe;Mb=cb;yb=gb}else{break}}}}while(0);Za=c[Z>>2]|0;if((Za|0)>(c[Aa>>2]|0)|(Za|0)<0){pb=356;break b}if((c[A>>2]|0)!=0){r2a(e,d[L]|0)}Ya=(c[r>>2]|0)+1|0;c[r>>2]=Ya;if((Ya|0)>=(c[z>>2]|0)){break}}}Ya=c[o>>2]|0;do{if((c[A>>2]|0)==0){_Oa(k,Ya<<4,16)}else{if((Ya|0)==0){break}_Oa(k,(Ya<<4)-16|0,16)}}while(0);c[l>>2]=0;Ya=(c[o>>2]|0)+1|0;c[o>>2]=Ya;Za=c[p>>2]|0;if((Ya|0)>=(Za|0)){se=Za;te=A;break a}}if((pb|0)==83){yDb(0,0,2287080,(wb=i,i=i+24|0,c[wb>>2]=1998536,c[wb+8>>2]=2255584,c[wb+16>>2]=1214,wb)|0);i=wb;Cd()}else if((pb|0)==102){yDb(0,0,2287080,(wb=i,i=i+24|0,c[wb>>2]=1998536,c[wb+8>>2]=2255584,c[wb+16>>2]=1214,wb)|0);i=wb;Cd()}else if((pb|0)==130){yDb(0,0,2287080,(wb=i,i=i+24|0,c[wb>>2]=1998536,c[wb+8>>2]=2255584,c[wb+16>>2]=1214,wb)|0);i=wb;Cd()}else if((pb|0)==356){Lkb(e+14424|0,0,c[m>>2]|0,c[r>>2]|0,c[o>>2]|0,14);A=c[Aa>>2]|0;z=c[r>>2]|0;L=c[o>>2]|0;yDb(c[B>>2]|0,16,2028048,(wb=i,i=i+32|0,c[wb>>2]=c[Z>>2],c[wb+8>>2]=A,c[wb+16>>2]=z,c[wb+24>>2]=L,wb)|0);i=wb;i=f;return}}else{se=q;te=e+13836|0}}while(0);if((c[te>>2]|0)==0){ue=se}else{_Oa(k,(se<<4)-16|0,16);ue=c[p>>2]|0}p=c[e+19428>>2]|0;Lkb(e+14424|0,0,c[m>>2]<<p,(c[e+116>>2]|0)-1|0,(ue<<p)-1|0,112);i=f;return}function j2a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=(c[a+120>>2]|0)+1|0;d=b&-2;e=a+124|0;f=a+16092|0;c[f>>2]=WDb(ba(d,c[e>>2]|0)|0)|0;g=a+16096|0;c[g>>2]=WDb(ba(c[e>>2]|0,d)|0)|0;c[a+16100>>2]=WDb(ba(c[e>>2]|0,d)|0)|0;c[a+19324>>2]=cEb(ba(c[e>>2]|0,d)|0)|0;h=a+19252|0;c[h>>2]=WDb(ba(c[e>>2]|0,d)|0)|0;i=a+19260|0;c[i>>2]=WDb(ba(c[e>>2]|0,d)|0)|0;j=(c[a+116>>2]|0)+2|0;c[a+19560>>2]=j;k=a+19556|0;c[k>>2]=WDb(j*768|0)|0;j=WDb(c[e>>2]<<3)|0;l=a+19580|0;c[l>>2]=j;m=c[e>>2]|0;c[a+19584>>2]=j+(m<<2);j=WDb(m<<3)|0;m=a+16024|0;c[m>>2]=j;n=c[e>>2]|0;c[a+16028>>2]=j+(n<<2);j=cEb(n<<1)|0;n=a+19588|0;c[n>>2]=j;o=c[e>>2]|0;c[a+19592>>2]=j+o;j=cEb(o<<3)|0;o=a+19596|0;c[o>>2]=j;p=c[e>>2]|0;c[a+19600>>2]=j+(p<<2);j=a+128|0;q=d<<1|1;d=b|1;b=d<<1;r=WDb((ba(b,p)|0)+(ba(c[j>>2]|0,q)|0)|0)|0;p=a+16052|0;c[p>>2]=r;s=c[j>>2]|0;c[a+16056>>2]=r+(s+1);t=ba(s,q)|0;s=c[e>>2]|0;u=s+1+t|0;c[a+16060>>2]=r+u;c[a+16064>>2]=r+(u+(ba(s,d)|0));d=cEb((ba(b,s)|0)+t|0)|0;c[a+19396>>2]=d;t=c[j>>2]|0;c[a+19400>>2]=d+(t+1);d=ba(t,q)|0;t=cEb((ba(b,c[e>>2]|0)|0)+d<<1)|0;c[a+19404>>2]=t;d=c[j>>2]|0;s=d+1|0;c[a+19408>>2]=t+s;u=ba(d,q)|0;d=ba(b,c[e>>2]|0)|0;c[a+19412>>2]=t+(u+s+d);s=cEb(d+u<<1)|0;c[a+19416>>2]=s;u=c[j>>2]|0;j=u+1|0;c[a+19420>>2]=s+j;d=ba(u,q)|0;c[a+19424>>2]=s+(d+j+(ba(b,c[e>>2]|0)|0));llb(a+14672|0,a|0);a:do{if(((c[(c[a+4>>2]|0)+48>>2]|0)-152|0)>>>0<2>>>0){e=a+19512|0;b=0;while(1){if((b|0)>=4){break a}j=WDb(c[e>>2]|0)|0;c[a+19528+(b>>1<<3)+((b&1)<<2)>>2]=j;if((j|0)==0){v=-12;break}else{b=b+1|0}}return v|0}}while(0);do{if((c[f>>2]|0)!=0){if((c[g>>2]|0)==0){break}if((c[h>>2]|0)==0){break}if((c[i>>2]|0)==0){break}if((c[k>>2]|0)==0){break}if((c[l>>2]|0)==0){break}if((c[m>>2]|0)==0){break}if((c[n>>2]|0)==0){break}if((c[o>>2]|0)==0){break}if((c[p>>2]|0)==0){break}else{v=0}return v|0}}while(0);$Db(f);$Db(g);$Db(h);$Db(i);$Db(k);$Db(l);$Db(m);$Db(n);$Db(o);$Db(p);v=-12;return v|0}function k2a(b){b=b|0;var d=0,e=0;d=0;do{e=a[1080496+d|0]|0;a[b+15730+d|0]=e<<3&56|(e&255)>>>3;e=a[1080560+d|0]|0;a[b+15794+d|0]=e<<3&56|(e&255)>>>3;e=a[1080624+d|0]|0;a[b+15858+d|0]=e<<3&56|(e&255)>>>3;e=a[1080688+d|0]|0;a[b+15922+d|0]=e<<3&56|(e&255)>>>3;e=a[1099968+d|0]|0;a[b+19332+d|0]=e<<3&56|(e&255)>>>3;d=d+1|0;}while((d|0)<64);c[b+15988>>2]=0;c[b+15992>>2]=3;return}function l2a(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+19508|0);$Db(b+19528|0);$Db(b+19532|0);$Db(b+19536|0);$Db(b+19540|0);$Db(b+19272|0);$Db(b+19276|0);LOa(b);$Db(b+16092|0);$Db(b+16096|0);$Db(b+16100|0);$Db(b+19324|0);$Db(b+19252|0);$Db(b+19260|0);$Db(b+16052|0);$Db(b+19396|0);$Db(b+19404|0);$Db(b+19416|0);$Db(b+19556|0);$Db(b+19580|0);$Db(b+16024|0);$Db(b+19588|0);$Db(b+19596|0);mlb(b+14672|0);return 0}function m2a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+24|0;f=e|0;g=c[b+60>>2]|0;h=g;j=b+120|0;k=g+19512|0;c[k>>2]=c[j>>2];l=b+124|0;m=g+19516|0;c[m>>2]=c[l>>2];n=b+100|0;if((c[n>>2]|0)==0){o=-1;i=e;return o|0}p=b+96|0;if((c[p>>2]|0)==0){o=-1;i=e;return o|0}if((c[b+88>>2]&8192|0)==0){c[b+140>>2]=Oe[c[b+152>>2]&1023](b,c[(c[b+12>>2]|0)+24>>2]|0)|0}else{c[b+140>>2]=8}c[b+712>>2]=R0a(b)|0;c[g+4>>2]=b;q=b2a(h)|0;if((q|0)<0){o=q;i=e;return o|0}q=SPa(b)|0;if((q|0)<0){o=q;i=e;return o|0}q=j2a(h)|0;if((q|0)<0){o=q;i=e;return o|0}l2a(b)|0;pea(g+15300|0,8);I2a(g+15332|0);q=b+48|0;r=c[q>>2]|0;do{if((r|0)==72|(r|0)==152){s=c[p>>2]|0;t=c[n>>2]<<3;u=t>>>0>2147483639>>>0|(s|0)==0;v=u?0:s;s=u?0:t;t=f|0;c[t>>2]=v;c[f+12>>2]=s;u=f+16|0;c[u>>2]=s+8;c[f+4>>2]=v+(s>>3);s=f+8|0;c[s>>2]=0;v=X1a(b,h,f)|0;if((v|0)<0){o=v;i=e;return o|0}v=c[n>>2]<<3;w=c[s>>2]|0;x=v-w|0;if((x|0)>0){y=c[u>>2]|0;u=(c[t>>2]|0)+(w>>>3)|0;t=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(w&7)>>>((32-x|0)>>>0);c[s>>2]=y>>>0>v>>>0?v:y;yDb(b,32,2072472,(z=i,i=i+16|0,c[z>>2]=x,c[z+8>>2]=t,z)|0);i=z;break}if((x|0)>=0){break}yDb(b,32,2067880,(z=i,i=i+8|0,c[z>>2]=-x,z)|0);i=z}else{x=c[p>>2]|0;t=c[n>>2]|0;y=x+t|0;if((t|0)<16){yDb(b,16,2063464,(z=i,i=i+8|0,c[z>>2]=t,z)|0);i=z;o=-1;i=e;return o|0}v=cEb(t+16|0)|0;t=y;s=-1;w=x;while(1){if(!(w>>>0<y>>>0)){A=y;break}x=s<<8;if((x|0)==256){B=20;break}else{s=d[w]|x;w=w+1|0}}if((B|0)==20){A=w-3|0}s=(v|0)==0;x=f|0;u=f+12|0;C=f+16|0;D=f+4|0;E=f+8|0;F=0;G=0;H=A;a:while(1){I=F;J=H;b:while(1){if(J>>>0<y>>>0){K=J}else{B=45;break a}while(1){L=K+4|0;c:do{if((t-L|0)<4){M=y}else{N=-1;O=L;while(1){if(!(O>>>0<y>>>0)){M=y;break c}P=N<<8;if((P|0)==256){break}else{N=d[O]|P;O=O+1|0}}M=O-3|0}}while(0);N=M-K|0;P=N-4|0;if((P|0)>=1){if((P|0)<4){Q=L;R=v;S=0;while(1){a[R]=a[Q]|0;T=S+1|0;if((T|0)<(P|0)){Q=Q+1|0;R=R+1|0;S=T}else{U=P;break}}}else{S=N-5|0;R=L;Q=0;T=0;while(1){V=a[R]|0;do{if(V<<24>>24==3&(T|0)>1){if((a[R-1|0]|0)!=0){B=37;break}if(!((a[R-2|0]|0)==0&(T|0)<(S|0))){B=37;break}W=R+1|0;X=a[W]|0;if(!((X&255)>>>0<4>>>0)){B=37;break}a[v+Q|0]=X;Y=T+1|0;Z=W}else{B=37}}while(0);if((B|0)==37){B=0;a[v+Q|0]=V;Y=T;Z=R}O=Q+1|0;W=Y+1|0;if((W|0)<(P|0)){R=Z+1|0;Q=O;T=W}else{U=O;break}}}T=U<<3;Q=T>>>0>2147483639>>>0|s;R=Q?0:v;P=Q?0:T;c[x>>2]=R;c[u>>2]=P;c[C>>2]=P+8;c[D>>2]=R+(P>>3);c[E>>2]=0;P=K;R=fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;if((R|0)==271){break b}else if((R|0)==270){break}}if(M>>>0<y>>>0){K=M}else{B=45;break a}}_=Y1a(b,h,f)|0;if((_|0)<0){B=44;break a}else{I=1;J=M}}$=X1a(b,h,f)|0;if(($|0)<0){B=42;break}else{F=I;G=1;H=M}}if((B|0)==42){ZDb(v);o=$;i=e;return o|0}else if((B|0)==44){ZDb(v);o=_;i=e;return o|0}else if((B|0)==45){ZDb(v);if(!((G|0)==0|(I|0)==0)){c[g+15580>>2]=(c[q>>2]|0)==153;break}yDb(b,16,2059792,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1;i=e;return o|0}}}while(0);I=ICb()|0;c[g+19508>>2]=I;if((I|0)==0){o=-12;i=e;return o|0}I=g+15660|0;c[b+840>>2]=c[I>>2];if((c[I>>2]|0)==3){c[b+844>>2]=c[g+15616>>2]}c[b+176>>2]=(c[b+156>>2]|0)!=0;_=b+128|0;c[g+116>>2]=(c[_>>2]|0)+15>>4;$=b+132|0;c[g+120>>2]=(c[$>>2]|0)+15>>4;do{if((c[I>>2]|0)==3){aa=0;B=53}else{if((c[g+15596>>2]|0)!=0){aa=0;B=53;break}UGb(g+15730|0,1080496,256)|0;c[g+15988>>2]=3;c[g+15992>>2]=0}}while(0);if((B|0)==53){while(1){B=0;I=a[1080496+aa|0]|0;a[h+15730+aa|0]=I<<3&56|(I&255)>>>3;I=a[1080560+aa|0]|0;a[h+15794+aa|0]=I<<3&56|(I&255)>>>3;I=a[1080624+aa|0]|0;a[h+15858+aa|0]=I<<3&56|(I&255)>>>3;I=a[1080688+aa|0]|0;a[h+15922+aa|0]=I<<3&56|(I&255)>>>3;I=a[1099968+aa|0]|0;a[h+19332+aa|0]=I<<3&56|(I&255)>>>3;I=aa+1|0;if((I|0)<64){aa=I;B=53}else{break}}c[g+15988>>2]=0;c[g+15992>>2]=3}if(!(((c[q>>2]|0)-152|0)>>>0<2>>>0)){o=0;i=e;return o|0}q=g+19520|0;c[q>>2]=c[_>>2];B=g+19524|0;c[B>>2]=c[$>>2];g=c[k>>2]|0;c[j>>2]=g;c[_>>2]=g;g=c[m>>2]|0;c[l>>2]=g;c[$>>2]=g;g=c[q>>2]|0;if((g|0)>16384){o=-1;i=e;return o|0}q=c[B>>2]|0;if((q|0)>16384){o=-1;i=e;return o|0}if((c[k>>2]|0)>16384){o=-1;i=e;return o|0}if((c[m>>2]|0)>16384){o=-1;i=e;return o|0}do{if((g&1|0)==0){if((q&1|0)==0){o=0}else{break}i=e;return o|0}}while(0);DDb(b,2054848,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1163346256;i=e;return o|0}function n2a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0;h=i;i=i+248|0;j=h|0;k=h+16|0;l=h+32|0;m=h+40|0;n=h+48|0;o=h+56|0;p=h+64|0;q=h+72|0;r=c[g+24>>2]|0;s=c[g+28>>2]|0;g=c[b+60>>2]|0;t=g;u=g;v=e;e=g+19436|0;c[e>>2]=0;w=g+60|0;if((c[w>>2]&524288|0)!=0){c[g+13944>>2]=1}if((s|0)==4){x=r;if((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)==167837696){y=5}}else if((s|0)==0){y=5}if((y|0)==5){if((c[g+13944>>2]|0)!=0){z=s;i=h;return z|0}x=g+9852|0;A=c[x>>2]|0;if((A|0)==0){z=s;i=h;return z|0}B=MCb(v,A|0)|0;if((B|0)<0){z=B;i=h;return z|0}c[x>>2]=0;c[f>>2]=1;z=s;i=h;return z|0}x=g+4|0;do{if((c[(c[(c[x>>2]|0)+12>>2]|0)+16>>2]&128|0)!=0){B=b+140|0;if((c[g+15660>>2]|0)<3){c[B>>2]=39;break}else{c[B>>2]=40;break}}}while(0);B=b+48|0;A=c[B>>2]|0;a:do{if((A|0)==71|(A|0)==153){C=s+16|0;D=cEb(C)|0;if((D|0)==0){z=-12;i=h;return z|0}E=r;F=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=F&255;b:do{if(((fe(F|0)|0)&-256|0)==256){G=r+s|0;if((s|0)<=0){H=0;I=r;J=0;K=-1;L=0;M=0;break}N=G;O=b+712|0;P=g+120|0;Q=g+14120|0;R=Q;S=Q;Q=g+14132|0;T=g+14136|0;U=g+14124|0;V=g+14128|0;W=0;X=0;Y=r;Z=-1;_=0;$=r;aa=0;while(1){ca=Y+4|0;c:do{if((N-ca|0)<4){da=G}else{ea=-1;fa=ca;while(1){if(!(fa>>>0<G>>>0)){da=G;break c}ga=ea<<8;if((ga|0)==256){break}else{ea=d[fa]|ga;fa=fa+1|0}}da=fa-3|0}}while(0);ea=da-Y|0;ga=ea-4|0;d:do{if((ga|0)<1){ha=aa;ia=$;ja=_;ka=Z;la=X;ma=W}else{na=Y;oa=fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0;if((oa|0)==267){na=aa+1|0;pa=XDb(W,na*28|0)|0;qa=pa;if((pa|0)==0){ra=aa;sa=D;ta=W;y=342;break a}pa=cEb(C)|0;ua=qa+(aa*28|0)|0;c[ua>>2]=pa;if((pa|0)==0){ra=aa;sa=D;ta=qa;y=342;break a}do{if((ga|0)<4){if((ga|0)>0){va=ca;wa=pa;xa=0}else{ya=ga;break}while(1){a[wa]=a[va]|0;za=xa+1|0;if((za|0)<(ga|0)){va=va+1|0;wa=wa+1|0;xa=za}else{ya=ga;break}}}else{za=ea-5|0;Aa=ca;Ba=0;Ca=0;while(1){Da=a[Aa]|0;do{if(Da<<24>>24==3&(Ca|0)>1){if((a[Aa-1|0]|0)!=0){y=79;break}if(!((a[Aa-2|0]|0)==0&(Ca|0)<(za|0))){y=79;break}Ea=Aa+1|0;Fa=a[Ea]|0;if(!((Fa&255)>>>0<4>>>0)){y=79;break}a[pa+Ba|0]=Fa;Ga=Ca+1|0;Ha=Ea}else{y=79}}while(0);if((y|0)==79){y=0;a[pa+Ba|0]=Da;Ga=Ca;Ha=Aa}Ea=Ba+1|0;Fa=Ga+1|0;if((Fa|0)<(ga|0)){Aa=Ha+1|0;Ba=Ea;Ca=Fa}else{ya=Ea;break}}}}while(0);pa=c[ua>>2]|0;fa=ya<<3;Ca=fa>>>0>2147483639>>>0|(pa|0)==0;Ba=Ca?0:pa;pa=Ca?0:fa;c[qa+(aa*28|0)+4>>2]=Ba;c[qa+(aa*28|0)+16>>2]=pa;fa=pa+8|0;c[qa+(aa*28|0)+20>>2]=fa;c[qa+(aa*28|0)+8>>2]=Ba+(pa>>3);pa=qa+(aa*28|0)+12|0;c[pa>>2]=0;Ca=Ba;Ba=(fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)>>>23;c[pa>>2]=fa>>>0>9>>>0?9:fa;c[qa+(aa*28|0)+24>>2]=Ba;ha=na;ia=$;ja=_;ka=Z;la=X;ma=qa;break}else if((oa|0)==268){if((c[O>>2]|0)==0){if((c[(c[(c[x>>2]|0)+12>>2]|0)+16>>2]&128|0)==0){Ia=_}else{y=41}}else{y=41}if((y|0)==41){y=0;Ia=Y}Ba=aa+1|0;fa=XDb(W,Ba*28|0)|0;pa=fa;if((fa|0)==0){ra=aa;sa=D;ta=W;y=342;break a}fa=cEb(C)|0;Ca=pa+(aa*28|0)|0;c[Ca>>2]=fa;if((fa|0)==0){ra=aa;sa=D;ta=pa;y=342;break a}do{if((ga|0)<4){if((ga|0)>0){Ja=ca;Ka=fa;La=0}else{Ma=ga;break}while(1){a[Ka]=a[Ja]|0;Aa=La+1|0;if((Aa|0)<(ga|0)){Ja=Ja+1|0;Ka=Ka+1|0;La=Aa}else{Ma=ga;break}}}else{Aa=ea-5|0;za=ca;Ea=0;Fa=0;while(1){Na=a[za]|0;do{if(Na<<24>>24==3&(Fa|0)>1){if((a[za-1|0]|0)!=0){y=53;break}if(!((a[za-2|0]|0)==0&(Fa|0)<(Aa|0))){y=53;break}Oa=za+1|0;Pa=a[Oa]|0;if(!((Pa&255)>>>0<4>>>0)){y=53;break}a[fa+Ea|0]=Pa;Qa=Fa+1|0;Ra=Oa}else{y=53}}while(0);if((y|0)==53){y=0;a[fa+Ea|0]=Na;Qa=Fa;Ra=za}Da=Ea+1|0;Oa=Qa+1|0;if((Oa|0)<(ga|0)){za=Ra+1|0;Ea=Da;Fa=Oa}else{Ma=Da;break}}}}while(0);fa=c[Ca>>2]|0;qa=Ma<<3;na=qa>>>0>2147483639>>>0|(fa|0)==0;ua=na?0:fa;fa=na?0:qa;c[pa+(aa*28|0)+4>>2]=ua;c[pa+(aa*28|0)+16>>2]=fa;c[pa+(aa*28|0)+20>>2]=fa+8;c[pa+(aa*28|0)+8>>2]=ua+(fa>>3);c[pa+(aa*28|0)+12>>2]=0;c[pa+(aa*28|0)+24>>2]=(c[P>>2]|0)+1>>1;ha=Ba;ia=$;ja=Ia;ka=aa-1|0;la=X;ma=pa;break}else if((oa|0)==270){do{if((ga|0)<4){if((ga|0)>0){Sa=ca;Ta=D;Ua=0}else{Va=ga;break}while(1){a[Ta]=a[Sa]|0;fa=Ua+1|0;if((fa|0)<(ga|0)){Sa=Sa+1|0;Ta=Ta+1|0;Ua=fa}else{Va=ga;break}}}else{fa=ea-5|0;ua=ca;qa=0;na=0;while(1){Fa=a[ua]|0;do{if(Fa<<24>>24==3&(na|0)>1){if((a[ua-1|0]|0)!=0){y=65;break}if(!((a[ua-2|0]|0)==0&(na|0)<(fa|0))){y=65;break}Ea=ua+1|0;za=a[Ea]|0;if(!((za&255)>>>0<4>>>0)){y=65;break}a[D+qa|0]=za;Wa=na+1|0;Xa=Ea}else{y=65}}while(0);if((y|0)==65){y=0;a[D+qa|0]=Fa;Wa=na;Xa=ua}Na=qa+1|0;Ea=Wa+1|0;if((Ea|0)<(ga|0)){ua=Xa+1|0;qa=Na;na=Ea}else{Va=Na;break}}}}while(0);pa=Va<<3;Ba=pa>>>0>2147483639>>>0;Ca=Ba?0:D;na=Ba?0:pa;c[S>>2]=Ca;c[Q>>2]=na;c[T>>2]=na+8;c[U>>2]=Ca+(na>>3);c[V>>2]=0;Y1a(b,t,R)|0;ha=aa;ia=$;ja=_;ka=Z;la=Va;ma=W;break}else if((oa|0)==269){if((c[O>>2]|0)==0){if((c[(c[(c[x>>2]|0)+12>>2]|0)+16>>2]&128|0)==0){Ya=$}else{y=27}}else{y=27}if((y|0)==27){y=0;Ya=Y}if((ga|0)<4){if((ga|0)>0){Za=ca;_a=D;$a=0}else{ha=aa;ia=Ya;ja=_;ka=Z;la=ga;ma=W;break}while(1){a[_a]=a[Za]|0;na=$a+1|0;if((na|0)<(ga|0)){Za=Za+1|0;_a=_a+1|0;$a=na}else{ha=aa;ia=Ya;ja=_;ka=Z;la=ga;ma=W;break d}}}oa=ea-5|0;na=ca;Ca=0;pa=0;while(1){Ba=a[na]|0;do{if(Ba<<24>>24==3&(pa|0)>1){if((a[na-1|0]|0)!=0){y=37;break}if(!((a[na-2|0]|0)==0&(pa|0)<(oa|0))){y=37;break}qa=na+1|0;ua=a[qa]|0;if(!((ua&255)>>>0<4>>>0)){y=37;break}a[D+Ca|0]=ua;ab=pa+1|0;bb=qa}else{y=37}}while(0);if((y|0)==37){y=0;a[D+Ca|0]=Ba;ab=pa;bb=na}qa=Ca+1|0;ua=ab+1|0;if((ua|0)<(ga|0)){na=bb+1|0;Ca=qa;pa=ua}else{ha=aa;ia=Ya;ja=_;ka=Z;la=qa;ma=W;break}}}else{ha=aa;ia=$;ja=_;ka=Z;la=X;ma=W;break}}}while(0);if(da>>>0<G>>>0){W=ma;X=la;Y=da;Z=ka;_=ja;$=ia;aa=ha}else{H=ha;I=ia;J=ja;K=ka;L=la;M=ma;break}}}else{do{if((c[g+15632>>2]|0)!=0){if(!((E&-64)<<24>>24==-64)){break}aa=r+s|0;$=aa;_=r;e:do{if((s|0)<4){y=89}else{Z=-1;Y=r;while(1){if(!(Y>>>0<aa>>>0)){y=89;break e}X=Z<<8;cb=Y+1|0;if((X|0)==256){break}else{Z=d[Y]|X;Y=cb}}Z=Y-3|0;if((Z|0)==(aa|0)){y=89;break}X=Z;if((d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)!=201392128){y=89;break}if((c[b+712>>2]|0)==0){if((c[(c[(c[x>>2]|0)+12>>2]|0)+16>>2]&128|0)==0){db=0}else{y=92}}else{y=92}if((y|0)==92){db=Z}X=XDb(0,28)|0;W=X;if((X|0)==0){eb=0;break}G=cEb(C)|0;O=X;c[O>>2]=G;if((G|0)==0){eb=W;break}R=Z;Z=$-R|0;V=Z-4|0;do{if((V|0)<4){if((V|0)>0){fb=cb;gb=G;hb=0}else{ib=V;break}while(1){a[gb]=a[fb]|0;U=hb+1|0;if((U|0)<(V|0)){fb=fb+1|0;gb=gb+1|0;hb=U}else{ib=V;break}}}else{Ba=Z-5|0;U=cb;T=0;Q=0;while(1){S=a[U]|0;do{if(S<<24>>24==3&(Q|0)>1){if((a[U-1|0]|0)!=0){y=104;break}if(!((a[U-2|0]|0)==0&(Q|0)<(Ba|0))){y=104;break}P=U+1|0;N=a[P]|0;if(!((N&255)>>>0<4>>>0)){y=104;break}a[G+T|0]=N;jb=Q+1|0;kb=P}else{y=104}}while(0);if((y|0)==104){y=0;a[G+T|0]=S;jb=Q;kb=U}Fa=T+1|0;P=jb+1|0;if((P|0)<(V|0)){U=kb+1|0;T=Fa;Q=P}else{ib=Fa;break}}}}while(0);V=c[O>>2]|0;G=ib<<3;Z=G>>>0>2147483639>>>0|(V|0)==0;Y=Z?0:V;V=Z?0:G;c[X+4>>2]=Y;c[X+16>>2]=V;c[X+20>>2]=V+8;c[X+8>>2]=Y+(V>>3);c[X+12>>2]=0;c[X+24>>2]=(c[g+120>>2]|0)+1>>1;V=R-_|0;if((V|0)<4){if((V|0)>0){lb=r;mb=D;nb=0}else{H=1;I=r;J=db;K=-1;L=V;M=W;break b}while(1){a[mb]=a[lb]|0;Y=nb+1|0;if((Y|0)<(V|0)){lb=lb+1|0;mb=mb+1|0;nb=Y}else{H=1;I=r;J=db;K=-1;L=V;M=W;break b}}}R=V-1|0;X=r;O=0;Y=0;while(1){G=a[X]|0;do{if(G<<24>>24==3&(Y|0)>1){if((a[X-1|0]|0)!=0){y=115;break}if(!((a[X-2|0]|0)==0&(Y|0)<(R|0))){y=115;break}Z=X+1|0;Q=a[Z]|0;if(!((Q&255)>>>0<4>>>0)){y=115;break}a[D+O|0]=Q;ob=Y+1|0;pb=Z}else{y=115}}while(0);if((y|0)==115){y=0;a[D+O|0]=G;ob=Y;pb=X}Z=O+1|0;Q=ob+1|0;if((Q|0)<(V|0)){X=pb+1|0;O=Z;Y=Q}else{H=1;I=r;J=db;K=-1;L=Z;M=W;break b}}}}while(0);if((y|0)==89){yDb(b,16,1912464,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;eb=0}ZDb(D);rb=eb;break a}}while(0);if((s|0)<4){if((s|0)>0){sb=r;tb=D;ub=1;vb=E}else{H=0;I=r;J=0;K=-1;L=s;M=0;break}while(1){_=sb+1|0;a[tb]=vb;if((ub|0)>=(s|0)){H=0;I=r;J=0;K=-1;L=s;M=0;break b}sb=_;tb=tb+1|0;ub=ub+1|0;vb=a[_]|0}}_=s-1|0;$=r;aa=0;W=0;Y=E;while(1){do{if(Y<<24>>24==3&(W|0)>1){if((a[$-1|0]|0)!=0){y=127;break}if(!((a[$-2|0]|0)==0&(W|0)<(_|0))){y=127;break}O=$+1|0;X=a[O]|0;if(!((X&255)>>>0<4>>>0)){y=127;break}a[D+aa|0]=X;wb=W+1|0;xb=O}else{y=127}}while(0);if((y|0)==127){y=0;a[D+aa|0]=Y;wb=W;xb=$}O=aa+1|0;X=wb+1|0;V=xb+1|0;if((X|0)>=(s|0)){H=0;I=r;J=0;K=-1;L=O;M=0;break b}$=V;aa=O;W=X;Y=a[V]|0}}}while(0);E=L<<3;C=E>>>0>2147483639>>>0;F=C?0:D;Y=C?0:E;c[g+14120>>2]=F;c[g+14132>>2]=Y;E=Y+8|0;c[g+14136>>2]=E;c[g+14124>>2]=F+(Y>>3);c[g+14128>>2]=0;yb=H;zb=D;Ab=I;Bb=J;Cb=K;Db=M;Eb=F;Fb=E;y=132}else{E=s<<3;F=E>>>0>2147483639>>>0|(r|0)==0;Y=F?0:r;C=F?0:E;c[g+14120>>2]=Y;c[g+14132>>2]=C;E=C+8|0;c[g+14136>>2]=E;c[g+14124>>2]=Y+(C>>3);c[g+14128>>2]=0;yb=0;zb=0;Ab=r;Bb=0;Cb=-1;Db=0;Eb=Y;Fb=E;y=132}}while(0);f:do{if((y|0)==132){M=g+15580|0;do{if((c[M>>2]|0)==0){y=137}else{K=g+14128|0;J=d[Eb]|0;I=(Fb|0)>0|0;c[K>>2]=I;H=J>>>7;c[g+19500>>2]=H^1;J=d[Eb]<<I>>>7;c[K>>2]=((I|0)<(Fb|0))+I;c[g+19504>>2]=J&1;if(!(((c[B>>2]|0)-152|0)>>>0<2>>>0)){y=137;break}if((H|0)==1){Gb=b+856|0;y=240;break}else{H=c[g+19520>>2]|0;c[b+128>>2]=H;c[b+120>>2]=H;H=c[g+19524>>2]|0;c[b+132>>2]=H;c[b+124>>2]=H;y=137;break}}}while(0);g:do{if((y|0)==137){D=g+96|0;H=c[D>>2]|0;do{if((H|0)==0){y=143}else{if((c[g+8>>2]|0)==(c[b+128>>2]|0)){if((c[g+12>>2]|0)==(c[b+132>>2]|0)){Hb=H}else{y=140}}else{y=140}if((y|0)==140){l2a(b)|0;Hb=c[D>>2]|0}if((Hb|0)==0){y=143;break}Ib=c[g+15660>>2]|0;y=152}}while(0);do{if((y|0)==143){if((SPa(b)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}if((j2a(t)|0)<0){LOa(u);ra=yb;sa=zb;ta=Db;y=342;break f}if((c[b+176>>2]|0)==0){Jb=1}else{Jb=(c[M>>2]|0)!=0|0}c[g+13944>>2]=Jb;D=c[g+15660>>2]|0;if((D|0)!=3){Ib=D;y=152;break}D=c[b+128>>2]|0;if((D|0)<2){ra=yb;sa=zb;ta=Db;y=342;break f}H=b+132|0;if((c[H>>2]|0)<2){ra=yb;sa=zb;ta=Db;y=342;break f}c[g+136>>2]=D;c[g+140>>2]=c[H>>2];H=g+19496|0;c[H>>2]=0;D=g+19492|0;c[D>>2]=1;J=g+14120|0;Kb=H;Lb=D;Mb=J;Nb=J;y=154}}while(0);do{if((y|0)==152){J=g+19496|0;c[J>>2]=0;D=g+19492|0;c[D>>2]=1;H=g+14120|0;I=H;if((Ib|0)>=3){Kb=J;Lb=D;Mb=H;Nb=I;y=154;break}if((Z1a(t,I)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}else{Ob=J;Pb=D;Qb=H;Rb=I}}}while(0);if((y|0)==154){if((a2a(t,Nb)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}else{Ob=Kb;Pb=Lb;Qb=Mb;Rb=Nb}}c[Pb>>2]=0;if((c[b+688>>2]&1|0)!=0){I=c[x>>2]|0;H=(mGb(c[g+9992>>2]|0)|0)<<24>>24;yDb(I,48,1891912,(qb=i,i=i+8|0,c[qb>>2]=H,qb)|0);i=qb}do{if(((c[B>>2]|0)-152|0)>>>0<2>>>0){if((c[g+9992>>2]|0)==1){break}yDb(c[x>>2]|0,16,2349448,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;ra=yb;sa=zb;ta=Db;y=342;break f}}while(0);H=g+120|0;I=g+19428|0;if((c[H>>2]>>c[I>>2]|0)==0){yDb(c[x>>2]|0,16,2329304,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;ra=yb;sa=zb;ta=Db;y=342;break f}D=g+9992|0;J=c[D>>2]|0;c[g+7712>>2]=J;K=(J|0)==1;c[g+7708>>2]=K&1;L=g+9848|0;if((c[L>>2]|0)==0){if((J|0)==3){ra=yb;sa=zb;ta=Db;y=342;break f}if((c[g+10008>>2]|0)!=0){ra=yb;sa=zb;ta=Db;y=342;break f}}xb=b+856|0;wb=c[xb>>2]|0;do{if((wb|0)>7){if((J|0)==3){break g}if((wb|0)<=31){break}if((wb|0)>47|K^1){break g}}}while(0);K=g+13736|0;if((c[K>>2]|0)!=0){if((J|0)==3){break}c[K>>2]=0}if((ROa(u,b)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}K=g+9856|0;wb=c[K>>2]|0;c[wb+2164>>2]=c[I>>2];c[wb+296>>2]=(c[g+19224>>2]|0)!=0;vb=g+19231|0;c[wb+300>>2]=d[vb]|0;ub=wb+292|0;c[ub>>2]=0;do{if((a[g+19232|0]|0)==0){wb=a[g+19230|0]|0;if(wb<<24>>24==0){break}c[ub>>2]=(wb&255)<<1}else{c[ub>>2]=1}}while(0);c[g+12452>>2]=g+10680;c[g+12456>>2]=g+10808;ub=b+712|0;J=c[ub>>2]|0;do{if((J|0)==0){ePa(u);c[g+15576>>2]=s<<3;c[g+19608>>2]=c[g+116>>2];wb=c[I>>2]|0;if((wb|0)!=0){tb=g+7656|0;c[tb>>2]=c[tb>>2]<<1;tb=g+7660|0;c[tb>>2]=c[tb>>2]<<1;tb=g+7664|0;c[tb>>2]=c[tb>>2]<<1;tb=g+148|0;c[tb>>2]=c[tb>>2]<<1;tb=g+152|0;c[tb>>2]=c[tb>>2]<<1}tb=c[H>>2]>>wb;if((tb|0)<=0){yDb(0,0,2287080,(qb=i,i=i+24|0,c[qb>>2]=2270912,c[qb+8>>2]=2255584,c[qb+16>>2]=6106,qb)|0);i=qb;Cd();return 0}do{if((yb|0)<0){Sb=wb}else{sb=g+128|0;eb=g+19468|0;db=g+124|0;pb=g+19472|0;ob=g+808|0;nb=(tb|0)>-1;mb=g+812|0;lb=g+19544|0;ib=g+16084|0;kb=Cb+1|0;jb=g+14128|0;cb=Qb;hb=g+14136|0;gb=b+696|0;fb=Cb+2|0;ma=0;la=0;h:while(1){do{if((ma|0)>0){ka=c[Db+((ma-1|0)*28|0)+24>>2]|0;if((ka|0)<(tb|0)){y=203;break}if((c[I>>2]|0)<1){yDb(c[x>>2]|0,16,2241144,(qb=i,i=i+24|0,c[qb>>2]=ma,c[qb+8>>2]=ka,c[qb+16>>2]=tb,qb)|0);i=qb;Tb=la;break}c[e>>2]=1;ka=c[H>>2]|0;if((ka&1|0)!=0){y=201;break h}c[eb>>2]=ba(c[sb>>2]|0,ka&-2)|0;Ub=(ba(ka,c[db>>2]|0)|0)>>1;y=204}else{y=203}}while(0);if((y|0)==203){y=0;c[e>>2]=0;c[eb>>2]=0;Ub=0;y=204}i:do{if((y|0)==204){y=0;c[pb>>2]=Ub;G=(ma|0)==0;do{if(G){y=211}else{c[Ob>>2]=0;if((c[I>>2]|0)!=0&(ma|0)==(fb|0)){ka=a2a(t,Rb)|0;if((ka|0)>=0){Vb=ka;y=213;break}yDb(c[x>>2]|0,16,2217264,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;if((c[gb>>2]&8|0)==0){Tb=ka;break i}else{ra=yb;sa=zb;ta=Db;y=342;break f}}ka=c[jb>>2]|0;ja=d[(c[cb>>2]|0)+(ka>>>3)|0]|0;c[jb>>2]=((ka|0)<(c[hb>>2]|0))+ka;if((ja&128>>>((ka&7)>>>0)|0)==0){y=211;break}c[Ob>>2]=1;ka=a2a(t,Rb)|0;if((ka|0)>=0){Wb=ka;y=212;break}yDb(c[x>>2]|0,16,2207928,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;if((c[gb>>2]&8|0)==0){Tb=ka;break i}else{ra=yb;sa=zb;ta=Db;y=342;break f}}}while(0);if((y|0)==211){y=0;if((la|0)<0){Tb=la;break}else{Wb=la;y=212}}if((y|0)==212){y=0;if(G){Xb=0;Yb=Wb}else{Vb=Wb;y=213}}if((y|0)==213){y=0;S=(c[Db+((ma-1|0)*28|0)+24>>2]|0)%(tb|0)|0;Xb=(S|0)<0?0:S;Yb=Vb}c[ob>>2]=Xb;do{if((c[I>>2]|0)==0){y=216}else{if((c[e>>2]|0)!=0){y=216;break}if((ma|0)>=(yb|0)){yDb(c[x>>2]|0,16,2199608,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;Tb=Yb;break i}if(!((ma|0)>(kb|0)&nb)){Zb=tb;break}Zb=(c[Db+(ma*28|0)+24>>2]|0)%(tb|0)|0}}while(0);do{if((y|0)==216){y=0;if(!((ma|0)!=(yb|0)&nb)){Zb=tb;break}Zb=(c[Db+(ma*28|0)+24>>2]|0)%(tb|0)|0}}while(0);c[mb>>2]=Zb;if((Zb|0)<=(Xb|0)){yDb(c[x>>2]|0,16,2190984,(qb=i,i=i+16|0,c[qb>>2]=Zb,c[qb+8>>2]=Xb,qb)|0);i=qb;Tb=Yb;break}do{if((c[lb>>2]|0)==0){if((c[D>>2]|0)==1){break}if((c[ib>>2]|0)!=0){break}yDb(c[x>>2]|0,16,2174344,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;Tb=Yb;break i}}while(0);e2a(t);if((ma|0)==(yb|0)){Tb=Yb;break}G=Db+(ma*28|0)+4|0;c[Qb>>2]=c[G>>2];c[Qb+4>>2]=c[G+4>>2];c[Qb+8>>2]=c[G+8>>2];c[Qb+12>>2]=c[G+12>>2];c[Qb+16>>2]=c[G+16>>2];Tb=Yb}}while(0);G=ma+1|0;if((G|0)>(yb|0)){y=231;break}else{ma=G;la=Tb}}if((y|0)==201){yDb(0,0,2287080,(qb=i,i=i+24|0,c[qb>>2]=2229056,c[qb+8>>2]=2255584,c[qb+16>>2]=6117,qb)|0);i=qb;Cd();return 0}else if((y|0)==231){Sb=c[I>>2]|0;break}}}while(0);tb=(Sb|0)==0;do{if(!tb){c[e>>2]=0;wb=g+7656|0;c[wb>>2]=c[wb>>2]>>1;wb=g+7660|0;c[wb>>2]=c[wb>>2]>>1;wb=g+7664|0;c[wb>>2]=c[wb>>2]>>1;wb=g+148|0;c[wb>>2]=c[wb>>2]>>1;wb=g+152|0;c[wb>>2]=c[wb>>2]>>1;wb=c[D>>2]|0;if((wb|0)==7|(wb|0)==3){break}wb=g+19408|0;la=c[wb>>2]|0;ma=g+19420|0;c[wb>>2]=c[ma>>2];c[ma>>2]=la;la=g+19412|0;ma=c[la>>2]|0;wb=g+19424|0;c[la>>2]=c[wb>>2];c[wb>>2]=ma}}while(0);ma=g+14424|0;if((c[g+14460>>2]|0)!=0){if((c[D>>2]|0)==3){ra=yb;sa=zb;ta=Db;y=342;break f}}if(!tb){break}Mkb(ma)}else{if((c[I>>2]|0)==0|(Bb|0)==0){c[g+14172>>2]=3;ma=r+s-Ab|0;if((ze[c[J+24>>2]&511](b,Ab,ma)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}if((ze[c[(c[ub>>2]|0)+28>>2]&511](b,Ab,ma)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}if((re[c[(c[ub>>2]|0)+32>>2]&4095](b)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}else{break}}ma=g+14172|0;c[ma>>2]=2-(d[vb]|0);wb=Bb;la=wb-Ab|0;if((ze[c[J+24>>2]&511](b,Ab,la)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}if((ze[c[(c[ub>>2]|0)+28>>2]&511](b,Ab,la)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}if((re[c[(c[ub>>2]|0)+32>>2]&4095](b)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}la=Db+((Cb+1|0)*28|0)+4|0;c[Qb>>2]=c[la>>2];c[Qb+4>>2]=c[la+4>>2];c[Qb+8>>2]=c[la+8>>2];c[Qb+12>>2]=c[la+12>>2];c[Qb+16>>2]=c[la+16>>2];c[ma>>2]=(d[vb]|0)+1;c[e>>2]=1;c[Ob>>2]=0;if((a2a(t,Rb)|0)<0){yDb(b,16,2304872,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;ra=yb;sa=zb;ta=Db;y=342;break f}c[(c[K>>2]|0)+88>>2]=c[D>>2];ma=r+s-wb|0;if((ze[c[(c[ub>>2]|0)+24>>2]&511](b,Bb,ma)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}if((ze[c[(c[ub>>2]|0)+28>>2]&511](b,Bb,ma)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}if((re[c[(c[ub>>2]|0)+32>>2]&4095](b)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}}}while(0);SOa(u);if(((c[B>>2]|0)-152|0)>>>0<2>>>0){Gb=xb;y=240;break}do{if((c[D>>2]|0)!=3){if((c[g+13944>>2]|0)!=0){break}ub=c[L>>2]|0;if((ub|0)==0){break g}if((MCb(v,ub|0)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}VOa(u,c[L>>2]|0,v);c[f>>2]=1;break g}}while(0);if((MCb(v,c[K>>2]|0)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}VOa(u,c[K>>2]|0,v);c[f>>2]=1}}while(0);do{if((y|0)==240){M=g+19512|0;L=c[M>>2]|0;c[b+128>>2]=L;c[b+120>>2]=L;L=g+19516|0;D=c[L>>2]|0;c[b+132>>2]=D;c[b+124>>2]=D;if((c[Gb>>2]|0)>7){break}D=g+14120|0;xb=D;ub=c[x>>2]|0;TGb(q|0,0,172)|0;vb=g+19504|0;if((c[vb>>2]|0)>=0){J=ub;I=0;do{H=q+(I*28|0)|0;p2a(xb,H);ma=q+(I*28|0)+4|0;wb=q+(I*28|0)+12|0;if((c[ma>>2]|0)==0){if((c[wb>>2]|0)!=0){y=245}}else{y=245}if((y|0)==245){y=0;DDb(J,2150616,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb}yDb(J,48,(I|0)!=0?2143640:2138224,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;la=c[H>>2]|0;yDb(J,48,2131552,(qb=i,i=i+16|0,c[qb>>2]=(la|0)/65536|0,c[qb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,qb)|0);i=qb;la=c[ma>>2]|0;yDb(J,48,2131552,(qb=i,i=i+16|0,c[qb>>2]=(la|0)/65536|0,c[qb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,qb)|0);i=qb;la=c[q+(I*28|0)+8>>2]|0;yDb(J,48,2131552,(qb=i,i=i+16|0,c[qb>>2]=(la|0)/65536|0,c[qb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,qb)|0);i=qb;la=c[wb>>2]|0;yDb(J,48,2131552,(qb=i,i=i+16|0,c[qb>>2]=(la|0)/65536|0,c[qb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,qb)|0);i=qb;la=c[q+(I*28|0)+16>>2]|0;yDb(J,48,2131552,(qb=i,i=i+16|0,c[qb>>2]=(la|0)/65536|0,c[qb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,qb)|0);i=qb;la=c[q+(I*28|0)+20>>2]|0;yDb(J,48,2131552,(qb=i,i=i+16|0,c[qb>>2]=(la|0)/65536|0,c[qb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,qb)|0);i=qb;la=c[q+(I*28|0)+24>>2]|0;yDb(J,48,2131552,(qb=i,i=i+16|0,c[qb>>2]=(la|0)/65536|0,c[qb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,qb)|0);i=qb;yDb(J,48,2125104,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;I=I+1|0;}while((I|0)<=(c[vb>>2]|0))}I=g+14128|0;J=g+14136|0;K=c[J>>2]|0;la=(c[I>>2]|0)+2|0;wb=K>>>0>la>>>0?la:K;c[I>>2]=wb;la=D;ma=c[la>>2]|0;H=ma+(wb>>>3)|0;ib=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(wb&7)>>>16;H=wb+16|0;wb=K>>>0>H>>>0?H:K;c[I>>2]=wb;H=ma+(wb>>>3)|0;lb=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(wb&7)>>>18;H=wb+14|0;wb=K>>>0>H>>>0?H:K;c[I>>2]=wb;H=lb|ib<<14;ib=q+56|0;c[ib>>2]=H;do{if((H|0)==0){_b=ma;$b=wb;ac=K}else{lb=ma+(wb>>>3)|0;mb=(fe(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(wb&7)>>>28;lb=wb+4|0;nb=K>>>0>lb>>>0?lb:K;c[I>>2]=nb;lb=q+64|0;c[lb>>2]=mb;if((mb|0)==14){p2a(xb,q+72|0);p2a(xb,q+100|0)}else if((mb|0)==7){p2a(xb,q+72|0)}else if((mb|0)!=0){mb=0;kb=nb;do{nb=ma+(kb>>>3)|0;ob=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(kb&7)>>>16;nb=kb+16|0;gb=K>>>0>nb>>>0?nb:K;c[I>>2]=gb;nb=ma+(gb>>>3)|0;hb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(gb&7)>>>18;nb=gb+14|0;kb=K>>>0>nb>>>0?nb:K;c[I>>2]=kb;c[q+72+(mb<<2)>>2]=((hb|ob<<14)<<1)-1073741824;mb=mb+1|0;}while((mb|0)<(c[lb>>2]|0))}mb=c[ib>>2]|0;if((mb|0)==13){if((c[q+72>>2]|0)!=(c[q+24>>2]|0)){y=254}}else{y=254}if((y|0)==254){kb=ub;yDb(kb,48,2119576,(qb=i,i=i+8|0,c[qb>>2]=mb,qb)|0);i=qb;if((c[lb>>2]|0)>0){mb=0;do{tb=c[q+72+(mb<<2)>>2]|0;yDb(kb,48,2113464,(qb=i,i=i+16|0,c[qb>>2]=(tb|0)/65536|0,c[qb+8>>2]=((((tb|0)>-1?tb:-tb|0)&65535)*1e3|0)>>>16,qb)|0);i=qb;mb=mb+1|0;}while((mb|0)<(c[lb>>2]|0))}yDb(kb,48,2125104,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb}lb=c[I>>2]|0;mb=c[J>>2]|0;tb=c[la>>2]|0;ob=tb+(lb>>>3)|0;hb=(fe(d[ob]|d[ob+1|0]<<8|d[ob+2|0]<<16|d[ob+3|0]<<24|0)|0)<<(lb&7);ob=hb>>>16;nb=lb+16|0;lb=mb>>>0>nb>>>0?nb:mb;c[I>>2]=lb;nb=q+68|0;c[nb>>2]=ob;if(hb>>>0>720895>>>0){yDb(ub,16,2099200,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;ra=yb;sa=zb;ta=Db;y=342;break f}if((ob|0)==0){_b=tb;$b=lb;ac=mb;break}mb=ub;yDb(mb,48,2092880,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;if((c[nb>>2]|0)>0){lb=0;do{tb=c[I>>2]|0;ob=c[J>>2]|0;hb=c[la>>2]|0;gb=hb+(tb>>>3)|0;jb=(fe(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(tb&7)>>>16;gb=tb+16|0;tb=ob>>>0>gb>>>0?gb:ob;c[I>>2]=tb;gb=hb+(tb>>>3)|0;hb=(fe(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(tb&7)>>>18;gb=tb+14|0;c[I>>2]=ob>>>0>gb>>>0?gb:ob;ob=(hb|jb<<14)<<1;jb=ob-1073741824|0;c[q+132+(lb<<2)>>2]=jb;yDb(mb,48,2113464,(qb=i,i=i+16|0,c[qb>>2]=(jb|0)/65536|0,c[qb+8>>2]=((((jb|0)>-1?jb:1073741824-ob|0)&65534)*1e3|0)>>>16,qb)|0);i=qb;lb=lb+1|0;}while((lb|0)<(c[nb>>2]|0))}yDb(mb,48,2125104,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;_b=c[la>>2]|0;$b=c[I>>2]|0;ac=c[J>>2]|0}}while(0);J=d[_b+($b>>>3)|0]<<($b&7)>>>7;la=(($b|0)<(ac|0))+$b|0;c[I>>2]=la;ib=J&1;c[q+60>>2]=ib;if((ib|0)==0){bc=la}else{yDb(ub,48,2087592,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;bc=c[I>>2]|0}la=c[g+14132>>2]|0;if((bc|0)>=(((c[ub+48>>2]|0)==152?64:0)+la|0)){yDb(ub,16,2082968,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;ra=yb;sa=zb;ta=Db;y=342;break f}if((bc|0)<(la-8|0)){yDb(ub,24,2077256,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb}if((c[g+7624>>2]|0)==0){yDb(ub,16,2164240,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;ra=yb;sa=zb;ta=Db;y=342;break f}do{if((c[vb>>2]|0)!=0){if((c[g+9848>>2]|0)!=0){if((c[g+952>>2]|0)!=0){break}}yDb(ub,24,2157424,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;c[vb>>2]=0}}while(0);I=g+19508|0;KCb(c[I>>2]|0);if((_$a(ub,c[I>>2]|0,0)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}la=j;c[la>>2]=c[36692];c[la+4>>2]=c[36693];c[la+8>>2]=c[36694];c[la+12>>2]=c[36695];la=c[vb>>2]|0;if((la|0)>=0){ib=c[g+19520>>2]<<16;J=ib-65536|0;K=c[g+19524>>2]<<16;ma=K-65536|0;xb=c[L>>2]|0;wb=c[M>>2]|0;H=ib-(wb<<16)|0;D=0;do{nb=c[q+(D*28|0)+8>>2]|0;if((nb|0)<0){cc=0}else{cc=(nb|0)>(J|0)?J:nb}c[l+(D<<2)>>2]=cc;nb=c[q+(D*28|0)>>2]|0;lb=m+(D<<2)|0;c[lb>>2]=nb;if((nb|0)==65536){if((H|0)!=(cc|0)){y=283}}else{if((nb|0)<0){dc=0;y=284}else{y=283}}if((y|0)==283){y=0;kb=(ib+~cc|0)/(wb|0)|0;dc=(nb|0)>(kb|0)?kb:nb;y=284}if((y|0)==284){y=0;c[lb>>2]=dc}lb=c[q+(D*28|0)+20>>2]|0;if((lb|0)<0){ec=0}else{ec=(lb|0)>(ma|0)?ma:lb}c[n+(D<<2)>>2]=ec;lb=c[q+(D*28|0)+16>>2]|0;nb=(K-ec|0)/(xb|0)|0;if((lb|0)<0){fc=0}else{fc=(lb|0)>(nb|0)?nb:lb}c[o+(D<<2)>>2]=fc;D=D+1|0;}while((D|0)<=(la|0))}la=c[q+52>>2]|0;if((la|0)<0){gc=0}else{gc=(la|0)>65535?65535:la}la=p|0;D=g+15560|0;xb=k|0;K=k+4|0;ma=p+4|0;wb=g+15572|0;ib=k+8|0;H=k+12|0;J=g+15564|0;ub=g+15568|0;lb=65535-gc|0;nb=g+19524|0;kb=g+15556|0;ob=0;jb=c[L>>2]|0;hb=0;gb=0;while(1){tb=(ob|0)!=0;cb=tb&1;fb=c[M>>2]>>cb;if((jb>>cb|0)>0){pb=t+7624+(ob<<2)|0;eb=t+7656+(ob<<2)|0;db=t+952+(ob<<2)|0;sb=t+984+(ob<<2)|0;G=0;S=hb;ka=gb;while(1){ja=c[I>>2]|0;ia=(c[ja+(ob<<2)>>2]|0)+(ba(c[ja+32+(ob<<2)>>2]|0,G)|0)|0;ja=c[vb>>2]|0;do{if((ja|0)<0){if((S|0)==0){hc=ka;y=319}else{ic=S;jc=ka;y=317}}else{ha=0;da=ja;while(1){Ya=c[pb>>2]|0;bb=c[eb>>2]|0;ab=(ba(c[o+(ha<<2)>>2]|0,G)|0)+(c[n+(ha<<2)>>2]|0)|0;$a=ab>>16;_a=ab&65535;c[p+(ha<<2)>>2]=_a;if((ha|0)==0){kc=Ya;lc=bb}else{kc=c[db>>2]|0;lc=c[sb>>2]|0}bb=$a+1|0;Ya=(c[nb>>2]>>cb)-1|0;ab=ba((bb|0)>(Ya|0)?Ya:bb,lc)|0;Ya=c[l+(ha<<2)>>2]|0;do{if((Ya&65535|0)==0){if((c[m+(ha<<2)>>2]|0)!=65536){y=303;break}Za=Ya>>16;c[k+(ha<<3)>>2]=kc+(Za+(ba(lc,$a)|0));if((_a|0)==0){mc=da;break}c[k+(ha<<3)+4>>2]=kc+(ab+Za);mc=da}else{y=303}}while(0);if((y|0)==303){y=0;Za=j+(ha<<3)|0;Va=c[Za>>2]|0;do{if((Va|0)!=($a|0)){Xa=j+(ha<<3)+4|0;if((c[Xa>>2]|0)==($a|0)){Wa=t+19528+(ha<<3)+4|0;Ua=c[Wa>>2]|0;Ta=t+19528+(ha<<3)|0;c[Wa>>2]=c[Ta>>2];c[Ta>>2]=Ua;c[Xa>>2]=Va;c[Za>>2]=$a;break}else{Xa=kc+(ba(lc,$a)|0)|0;le[c[kb>>2]&1023](c[t+19528+(ha<<3)>>2]|0,Xa,Ya,c[m+(ha<<2)>>2]|0,fb);c[Za>>2]=$a;break}}}while(0);do{if((_a|0)!=0){$a=j+(ha<<3)+4|0;if((c[$a>>2]|0)==(bb|0)){break}le[c[kb>>2]&1023](c[t+19528+(ha<<3)+4>>2]|0,kc+ab|0,Ya,c[m+(ha<<2)>>2]|0,fb);c[$a>>2]=bb}}while(0);c[k+(ha<<3)>>2]=c[t+19528+(ha<<3)>>2];c[k+(ha<<3)+4>>2]=c[t+19528+(ha<<3)+4>>2];mc=c[vb>>2]|0}bb=ha+1|0;if((bb|0)>(mc|0)){break}else{ha=bb;da=mc}}da=c[la>>2]|0;ha=(da|0)!=0;if((mc|0)!=0){if(ha){ic=da;jc=da;y=317;break}else{y=321;break}}if(ha){le[c[D>>2]&1023](ia,c[xb>>2]|0,c[K>>2]|0,da,fb);nc=da;oc=da;break}else{UGb(ia|0,c[xb>>2]|0,fb)|0;nc=0;oc=0;break}}}while(0);do{if((y|0)==317){y=0;ja=c[ma>>2]|0;if((ja|0)==0){hc=jc;y=319;break}Le[c[wb>>2]&255](ia,c[xb>>2]|0,c[K>>2]|0,ic,c[ib>>2]|0,c[H>>2]|0,ja,gc,fb);nc=ic;oc=jc}}while(0);do{if((y|0)==319){y=0;if((hc|0)==0){y=321;break}Ke[c[ub>>2]&1023](ia,c[xb>>2]|0,c[K>>2]|0,hc,c[ib>>2]|0,gc,fb);nc=hc;oc=hc}}while(0);do{if((y|0)==321){y=0;ja=c[ma>>2]|0;if((ja|0)==0){le[c[J>>2]&1023](ia,c[xb>>2]|0,c[ib>>2]|0,gc,fb);nc=0;oc=0;break}else{Ke[c[ub>>2]&1023](ia,c[ib>>2]|0,c[H>>2]|0,ja,c[xb>>2]|0,lb,fb);nc=0;oc=0;break}}}while(0);ia=G+1|0;ja=c[L>>2]|0;if((ia|0)<(ja>>cb|0)){G=ia;S=nc;ka=oc}else{pc=ja;qc=nc;rc=oc;break}}}else{pc=jb;qc=hb;rc=gb}do{if(!tb){ka=c[vb>>2]|0;if((ka|0)<0){break}else{sc=0}do{S=l+(sc<<2)|0;c[S>>2]=c[S>>2]>>1;S=n+(sc<<2)|0;c[S>>2]=c[S>>2]>>1;sc=sc+1|0;}while((sc|0)<=(ka|0))}}while(0);tb=ob+1|0;if((tb|0)<((c[w>>2]|0)>>>12&2^3|0)){ob=tb;jb=pc;hb=qc;gb=rc}else{break}}if((MCb(v,c[I>>2]|0)|0)<0){ra=yb;sa=zb;ta=Db;y=342;break f}c[f>>2]=1}}while(0);ZDb(zb);if((yb|0)>0){gb=0;do{ZDb(c[Db+(gb*28|0)>>2]|0);gb=gb+1|0;}while((gb|0)<(yb|0))}ZDb(Db);z=s;i=h;return z|0}}while(0);do{if((y|0)==342){ZDb(sa);if((ra|0)>0){tc=0}else{rb=ta;break}while(1){ZDb(c[ta+(tc*28|0)>>2]|0);s=tc+1|0;if((s|0)<(ra|0)){tc=s}else{rb=ta;break}}}}while(0);ZDb(rb);z=-1;i=h;return z|0}function o2a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a+60>>2]|0;a=b+7624|0;d=a;if((c[a>>2]|0)==0){return}a=b+60|0;e=b+19524|0;f=b+7656|0;b=0;g=c[e>>2]|0;while(1){h=(b|0)!=0;i=h&1;if((g>>i|0)>0){j=d+(b<<2)|0;k=f+(b<<2)|0;l=h?-128:0;h=0;while(1){m=c[k>>2]|0;TGb((c[j>>2]|0)+(ba(m,h)|0)|0,l|0,m|0)|0;m=h+1|0;n=c[e>>2]|0;if((m|0)<(n>>i|0)){h=m}else{o=n;break}}}else{o=g}h=b+1|0;if((h|0)<((c[a>>2]|0)>>>12&2^3|0)){b=h;g=o}else{break}}return}function p2a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b+12|0;c[e>>2]=0;f=b+4|0;c[f>>2]=0;g=a+8|0;h=c[g>>2]|0;i=a+16|0;j=c[i>>2]|0;k=c[a>>2]|0;a=k+(h>>>3)|0;l=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(h&7)>>>30;a=h+2|0;h=j>>>0>a>>>0?a:j;c[g>>2]=h;if((l|0)==1){a=k+(h>>>3)|0;m=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(h&7)>>>16;a=h+16|0;n=j>>>0>a>>>0?a:j;c[g>>2]=n;a=k+(n>>>3)|0;o=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(n&7)>>>18;a=n+14|0;c[g>>2]=j>>>0>a>>>0?a:j;a=((o|m<<14)<<1)-1073741824|0;c[b+16>>2]=a;c[b>>2]=a;a=c[g>>2]|0;m=c[i>>2]|0;o=k+(a>>>3)|0;n=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(a&7)>>>16;o=a+16|0;a=m>>>0>o>>>0?o:m;c[g>>2]=a;o=k+(a>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(a&7)>>>18;o=a+14|0;c[g>>2]=m>>>0>o>>>0?o:m;c[b+8>>2]=((p|n<<14)<<1)-1073741824}else if((l|0)==2){n=k+(h>>>3)|0;p=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>16;n=h+16|0;m=j>>>0>n>>>0?n:j;c[g>>2]=m;n=k+(m>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(m&7)>>>18;n=m+14|0;c[g>>2]=j>>>0>n>>>0?n:j;c[b>>2]=((o|p<<14)<<1)-1073741824;p=c[g>>2]|0;o=c[i>>2]|0;n=k+(p>>>3)|0;m=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(p&7)>>>16;n=p+16|0;p=o>>>0>n>>>0?n:o;c[g>>2]=p;n=k+(p>>>3)|0;a=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(p&7)>>>18;n=p+14|0;c[g>>2]=o>>>0>n>>>0?n:o;c[b+8>>2]=((a|m<<14)<<1)-1073741824;m=c[g>>2]|0;a=c[i>>2]|0;o=k+(m>>>3)|0;n=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(m&7)>>>16;o=m+16|0;m=a>>>0>o>>>0?o:a;c[g>>2]=m;o=k+(m>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(m&7)>>>18;o=m+14|0;c[g>>2]=a>>>0>o>>>0?o:a;c[b+16>>2]=((p|n<<14)<<1)-1073741824}else if((l|0)==0){c[b>>2]=65536;n=c[g>>2]|0;p=c[i>>2]|0;a=k+(n>>>3)|0;o=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(n&7)>>>16;a=n+16|0;n=p>>>0>a>>>0?a:p;c[g>>2]=n;a=k+(n>>>3)|0;m=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(n&7)>>>18;a=n+14|0;c[g>>2]=p>>>0>a>>>0?a:p;c[b+8>>2]=((m|o<<14)<<1)-1073741824;c[b+16>>2]=65536}else if((l|0)==3){l=k+(h>>>3)|0;o=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>16;l=h+16|0;h=j>>>0>l>>>0?l:j;c[g>>2]=h;l=k+(h>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>18;l=h+14|0;c[g>>2]=j>>>0>l>>>0?l:j;c[b>>2]=((m|o<<14)<<1)-1073741824;o=c[g>>2]|0;m=c[i>>2]|0;j=k+(o>>>3)|0;l=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(o&7)>>>16;j=o+16|0;o=m>>>0>j>>>0?j:m;c[g>>2]=o;j=k+(o>>>3)|0;h=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(o&7)>>>18;j=o+14|0;c[g>>2]=m>>>0>j>>>0?j:m;c[f>>2]=((h|l<<14)<<1)-1073741824;l=c[g>>2]|0;h=c[i>>2]|0;f=k+(l>>>3)|0;m=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7)>>>16;f=l+16|0;l=h>>>0>f>>>0?f:h;c[g>>2]=l;f=k+(l>>>3)|0;j=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7)>>>18;f=l+14|0;c[g>>2]=h>>>0>f>>>0?f:h;c[b+8>>2]=((j|m<<14)<<1)-1073741824;m=c[g>>2]|0;j=c[i>>2]|0;h=k+(m>>>3)|0;f=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(m&7)>>>16;h=m+16|0;m=j>>>0>h>>>0?h:j;c[g>>2]=m;h=k+(m>>>3)|0;l=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(m&7)>>>18;h=m+14|0;c[g>>2]=j>>>0>h>>>0?h:j;c[e>>2]=((l|f<<14)<<1)-1073741824;f=c[g>>2]|0;l=c[i>>2]|0;e=k+(f>>>3)|0;j=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(f&7)>>>16;e=f+16|0;f=l>>>0>e>>>0?e:l;c[g>>2]=f;e=k+(f>>>3)|0;h=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(f&7)>>>18;e=f+14|0;c[g>>2]=l>>>0>e>>>0?e:l;c[b+16>>2]=((h|j<<14)<<1)-1073741824}j=c[g>>2]|0;h=c[i>>2]|0;l=k+(j>>>3)|0;e=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(j&7)>>>16;l=j+16|0;j=h>>>0>l>>>0?l:h;c[g>>2]=j;l=k+(j>>>3)|0;f=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(j&7)>>>18;l=j+14|0;c[g>>2]=h>>>0>l>>>0?l:h;c[b+20>>2]=((f|e<<14)<<1)-1073741824;e=c[g>>2]|0;f=d[k+(e>>>3)|0]|0;h=c[i>>2]|0;i=((e|0)<(h|0))+e|0;c[g>>2]=i;if((f&128>>>((e&7)>>>0)|0)==0){c[b+24>>2]=65536;return}else{e=k+(i>>>3)|0;f=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(i&7)>>>16;e=i+16|0;i=h>>>0>e>>>0?e:h;c[g>>2]=i;e=k+(i>>>3)|0;k=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(i&7)>>>18;e=i+14|0;c[g>>2]=h>>>0>e>>>0?e:h;c[b+24>>2]=((k|f<<14)<<1)-1073741824;return}}function q2a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0;f=i;i=i+8|0;g=f|0;h=e+14120|0;j=e+12476|0;k=e+12480|0;l=e+124|0;m=(ba(c[l>>2]|0,c[k>>2]|0)|0)+(c[j>>2]|0)|0;n=c[e+16016>>2]|0;c[g>>2]=0;o=e+15728|0;p=d[o]|0;q=e+12488|0;c[q>>2]=0;if((c[e+16116>>2]|0)==0){r=d[(c[e+9928>>2]|0)+m|0]|0}else{s=e+14128|0;t=c[s>>2]|0;u=d[(c[h>>2]|0)+(t>>>3)|0]<<(t&7)>>>7;c[s>>2]=((t|0)<(c[e+14136>>2]|0))+t;r=u&1}u=(r|0)!=0;do{if(u){v=0;w=0}else{r=c[(c[e+19304>>2]|0)+4>>2]|0;t=e+14128|0;s=c[t>>2]|0;x=c[e+14136>>2]|0;y=c[h>>2]|0;z=y+(s>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(s&7)>>>26;z=b[r+(A<<2)>>1]|0;B=b[r+(A<<2)+2>>1]|0;A=B<<16>>16;if(B<<16>>16<0){B=s+6|0;C=x>>>0>B>>>0?B:x;B=y+(C>>>3)|0;y=((fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>((A+32|0)>>>0))+z|0;D=b[r+(y<<2)+2>>1]|0;E=b[r+(y<<2)>>1]|0;F=C}else{D=A;E=z;F=s}s=D+F|0;c[t>>2]=x>>>0>s>>>0?s:x;x=e+19400|0;s=(c[x>>2]|0)+(c[e+12496>>2]|0)|0;if((a[1096248+(E<<2)|0]|0)==1){a[s]=1;a[(c[x>>2]|0)+(c[e+12500>>2]|0)|0]=1;a[(c[x>>2]|0)+(c[e+12504>>2]|0)|0]=1;a[(c[x>>2]|0)+(c[e+12508>>2]|0)|0]=1;v=E;w=1;break}else{a[s]=0;a[(c[x>>2]|0)+(c[e+12500>>2]|0)|0]=0;a[(c[x>>2]|0)+(c[e+12504>>2]|0)|0]=0;a[(c[x>>2]|0)+(c[e+12508>>2]|0)|0]=0;v=E;w=0;break}}}while(0);if((c[e+16108>>2]|0)==0){G=d[(c[e+16096>>2]|0)+m|0]|0}else{E=e+14128|0;F=c[E>>2]|0;D=d[(c[h>>2]|0)+(F>>>3)|0]<<(F&7)>>>7;c[E>>2]=((F|0)<(c[e+14136>>2]|0))+F;G=D&1}D=(G|0)!=0;do{if(D){if((c[(c[e+9852>>2]|0)+2164>>2]|0)!=0){yDb(c[e+4>>2]|0,24,2008880,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}G=c[e+12496>>2]|0;F=c[e+4704>>2]|0;E=F+(G<<2)|0;x=e+16070|0;s=(c[e+13924>>2]|0)==0;t=ba(b[x>>1]|0,b[E>>1]|0)|0;if(s){I=t+255>>9<<1&65535}else{I=(t+128|0)>>>8&65535}t=c[e+9148>>2]|0;b[t+(G<<2)>>1]=I;c[e+11744>>2]=I<<16>>16;z=F+(G<<2)+2|0;A=ba(b[x>>1]|0,b[z>>1]|0)|0;if(s){J=A+255>>9<<1&65535}else{J=(A+128|0)>>>8&65535}b[t+(G<<2)+2>>1]=J;c[e+11748>>2]=J<<16>>16;A=ba((b[x>>1]|0)-256|0,b[E>>1]|0)|0;if(s){K=A+255>>9<<1&65535}else{K=(A+128|0)>>>8&65535}A=c[e+9152>>2]|0;b[A+(G<<2)>>1]=K;c[e+11776>>2]=K<<16>>16;E=ba((b[x>>1]|0)-256|0,b[z>>1]|0)|0;if(s){L=E+255>>9<<1&65535}else{L=(E+128|0)>>>8&65535}b[A+(G<<2)+2>>1]=L;c[e+11780>>2]=L<<16>>16;if((w|0)==0){G=c[e+12500>>2]|0;b[t+(G<<2)>>1]=I;E=I<<16>>16;c[e+11752>>2]=E;b[t+(G<<2)+2>>1]=J;z=J<<16>>16;c[e+11756>>2]=z;b[A+(G<<2)>>1]=K;C=K<<16>>16;c[e+11784>>2]=C;b[A+(G<<2)+2>>1]=L;G=L<<16>>16;c[e+11788>>2]=G;y=c[e+12504>>2]|0;b[t+(y<<2)>>1]=I;c[e+11760>>2]=E;b[t+(y<<2)+2>>1]=J;c[e+11764>>2]=z;b[A+(y<<2)>>1]=K;c[e+11792>>2]=C;b[A+(y<<2)+2>>1]=L;c[e+11796>>2]=G;y=c[e+12508>>2]|0;b[t+(y<<2)>>1]=I;c[e+11768>>2]=E;b[t+(y<<2)+2>>1]=J;c[e+11772>>2]=z;b[A+(y<<2)>>1]=K;c[e+11800>>2]=C;b[A+(y<<2)+2>>1]=L;c[e+11804>>2]=G;break}G=c[e+12504>>2]|0;y=F+(G<<2)|0;C=ba(b[x>>1]|0,b[y>>1]|0)|0;if(s){M=C+255>>9<<1&65535}else{M=(C+128|0)>>>8&65535}b[t+(G<<2)>>1]=M;c[e+11760>>2]=M<<16>>16;C=F+(G<<2)+2|0;F=ba(b[x>>1]|0,b[C>>1]|0)|0;if(s){N=F+255>>9<<1&65535}else{N=(F+128|0)>>>8&65535}b[t+(G<<2)+2>>1]=N;c[e+11764>>2]=N<<16>>16;F=ba((b[x>>1]|0)-256|0,b[y>>1]|0)|0;if(s){O=F+255>>9<<1&65535}else{O=(F+128|0)>>>8&65535}b[A+(G<<2)>>1]=O;c[e+11792>>2]=O<<16>>16;F=ba((b[x>>1]|0)-256|0,b[C>>1]|0)|0;if(s){P=F+255>>9<<1&65535}else{P=(F+128|0)>>>8&65535}b[A+(G<<2)+2>>1]=P;c[e+11796>>2]=P<<16>>16;G=c[e+12500>>2]|0;b[t+(G<<2)>>1]=I;c[e+11752>>2]=I<<16>>16;b[t+(G<<2)+2>>1]=J;c[e+11756>>2]=J<<16>>16;b[A+(G<<2)>>1]=K;c[e+11784>>2]=K<<16>>16;b[A+(G<<2)+2>>1]=L;c[e+11788>>2]=L<<16>>16;G=c[e+12508>>2]|0;b[t+(G<<2)>>1]=M;c[e+11768>>2]=M<<16>>16;b[t+(G<<2)+2>>1]=N;c[e+11772>>2]=N<<16>>16;b[A+(G<<2)>>1]=O;c[e+11800>>2]=O<<16>>16;b[A+(G<<2)+2>>1]=P;c[e+11804>>2]=P<<16>>16}}while(0);a:do{if((a[1096248+(v<<2)|0]|0)==5){P=e+12496|0;O=c[P>>2]|0;N=c[e+9148>>2]|0;b[N+(O<<2)>>1]=0;c[e+11744>>2]=0;b[N+(O<<2)+2>>1]=0;c[e+11748>>2]=0;M=c[e+9152>>2]|0;b[M+(O<<2)>>1]=0;c[e+11776>>2]=0;b[M+(O<<2)+2>>1]=0;c[e+11780>>2]=0;O=e+12500|0;L=c[O>>2]|0;b[N+(L<<2)>>1]=0;c[e+11752>>2]=0;b[N+(L<<2)+2>>1]=0;c[e+11756>>2]=0;b[M+(L<<2)>>1]=0;c[e+11784>>2]=0;b[M+(L<<2)+2>>1]=0;c[e+11788>>2]=0;L=e+12504|0;K=c[L>>2]|0;b[N+(K<<2)>>1]=0;c[e+11760>>2]=0;b[N+(K<<2)+2>>1]=0;c[e+11764>>2]=0;b[M+(K<<2)>>1]=0;c[e+11792>>2]=0;b[M+(K<<2)+2>>1]=0;c[e+11796>>2]=0;K=e+12508|0;J=c[K>>2]|0;b[N+(J<<2)>>1]=0;c[e+11768>>2]=0;b[N+(J<<2)+2>>1]=0;c[e+11772>>2]=0;b[M+(J<<2)>>1]=0;c[e+11800>>2]=0;b[M+(J<<2)+2>>1]=0;c[e+11804>>2]=0;c[(c[e+9160>>2]|0)+(m<<2)>>2]=1;a[(c[e+19592>>2]|0)+(c[j>>2]|0)|0]=1;c[q>>2]=1;J=e+16056|0;a[(c[J>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[O>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[L>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[K>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[e+12512>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[e+12516>>2]|0)|0]=1;K=e+14128|0;L=c[K>>2]|0;O=h|0;P=d[(c[O>>2]|0)+(L>>>3)|0]<<(L&7)>>>7;M=e+14136|0;c[K>>2]=((L|0)<(c[M>>2]|0))+L;L=P&1;a[(c[e+19324>>2]|0)+m|0]=L;P=c[K>>2]|0;N=c[O>>2]|0;I=d[N+(P>>>3)|0]|0;G=c[M>>2]|0;A=((P|0)<(G|0))+P|0;c[K>>2]=A;if((I&128>>>((P&7)>>>0)|0)==0){Q=0;R=A}else{P=c[(c[e+16084>>2]|0)+4>>2]|0;I=N+(A>>>3)|0;t=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(A&7)>>>23;I=b[P+(t<<2)>>1]|0;F=b[P+(t<<2)+2>>1]|0;t=F<<16>>16;if(F<<16>>16<0){F=A+9|0;s=G>>>0>F>>>0?F:G;F=N+(s>>>3)|0;C=((fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(s&7)>>>((t+32|0)>>>0))+I|0;S=b[P+(C<<2)+2>>1]|0;T=b[P+(C<<2)>>1]|0;U=s}else{S=t;T=I;U=A}A=S+U|0;I=G>>>0>A>>>0?A:G;c[K>>2]=I;Q=T+1|0;R=I}I=d[N+(R>>>3)|0]<<(R&7)>>>7;c[K>>2]=((R|0)<(G|0))+R;G=I&1;a[(c[e+19252>>2]|0)+m|0]=G;c[e+176>>2]=G;do{if((a[e+16004|0]|0)==0){V=p}else{G=a[e+16005|0]|0;do{if(G<<24>>24==3){I=c[K>>2]|0;if((a[e+16007|0]|0)!=0){N=d[(c[O>>2]|0)+(I>>>3)|0]|0;c[K>>2]=((I|0)<(c[M>>2]|0))+I;W=d[(N&128>>>((I&7)>>>0)|0)==0?o:e+15729|0]|0;X=55;break}N=c[M>>2]|0;A=c[O>>2]|0;t=A+(I>>>3)|0;s=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(I&7)>>>29;t=I+3|0;I=N>>>0>t>>>0?t:N;c[K>>2]=I;if((s|0)==7){t=A+(I>>>3)|0;A=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(I&7)>>>27;t=I+5|0;c[K>>2]=N>>>0>t>>>0?t:N;W=A;X=55;break}else{Y=(d[o]|0)+s|0;break}}else{W=p;X=55}}while(0);do{if((X|0)==55){if((G<<24>>24|0)==2){Z=1<<d[e+16006|0];X=58}else if((G<<24>>24|0)==1){Z=(3<<d[e+16006|0]|0)%15|0;X=58}else if((G<<24>>24|0)==0){_=15;X=59}else{Y=W;break}if((X|0)==58){if((Z&1|0)==0){$=W;aa=Z}else{_=Z;X=59}}do{if((X|0)==59){if((c[j>>2]|0)!=0){$=W;aa=_;break}$=d[e+15729|0]|0;aa=_}}while(0);do{if((aa&2|0)==0){ca=$}else{if((c[e+14084>>2]|0)==0){ca=$;break}ca=d[e+15729|0]|0}}while(0);do{if((aa&4|0)==0){da=ca}else{if((c[j>>2]|0)!=((c[e+116>>2]|0)-1|0)){da=ca;break}da=d[e+15729|0]|0}}while(0);if((aa&8|0)==0){Y=da;break}if((c[k>>2]|0)!=((c[e+120>>2]|0)-1|0)){Y=da;break}Y=d[e+15729|0]|0}}while(0);if(!((Y|0)==0|(Y|0)>31)){V=Y;break}yDb(c[e+4>>2]|0,16,2024400,(H=i,i=i+8|0,c[H>>2]=Y,H)|0);i=H;V=1}}while(0);a[(c[e+9136>>2]|0)+m|0]=V;c[e+168>>2]=d[(c[e+9888>>2]|0)+V|0]|0;c[e+172>>2]=d[(c[e+9892>>2]|0)+V|0]|0;K=e+9876|0;O=e+16048|0;M=e+16044|0;G=e+14340|0;s=e+16036|0;A=e+16032|0;N=e+60|0;t=e+15332|0;I=e+148|0;C=(L|0)==0;P=e+10068|0;F=e+152|0;x=e+14084|0;y=0;z=0;while(1){E=e+12496+(z<<2)|0;r=c[E>>2]|0;b[(c[K>>2]|0)+(r<<1)>>1]=0;B=(z>>2)+y|0;ea=Q>>>((5-z|0)>>>0)&1;a[(c[J>>2]|0)+r|0]=c[q>>2];c[O>>2]=0;c[M>>2]=0;if((z-2|0)>>>0<2>>>0){X=75}else{if((c[x>>2]|0)==0){X=75}}if((X|0)==75){X=0;c[M>>2]=d[(c[J>>2]|0)+((c[E>>2]|0)-(c[e+12520+(z<<2)>>2]|0))|0]|0}if((z|0)==3|(z|0)==1){X=78}else{if((c[j>>2]|0)!=0){X=78}}if((X|0)==78){X=0;c[O>>2]=d[(c[J>>2]|0)+((c[E>>2]|0)-1)|0]|0}t2a(e,(c[G>>2]|0)+(z<<7)|0,z,ea,V,c[((z&4|0)==0?A:s)>>2]|0);if((z|0)>3){if((c[N>>2]&8192|0)==0){X=81}}else{X=81}if((X|0)==81){X=0;me[c[t>>2]&511]((c[G>>2]|0)+(z<<7)|0);if((z|0)<4){ea=c[I>>2]|0;E=z&2;fa=ea<<L;ga=(ba(ea,C?E<<2:E>>>1)|0)+(z<<3&8)|0}else{fa=c[F>>2]|0;ga=0}Xe[c[P>>2]&4095]((c[G>>2]|0)+(z<<7)|0,(c[e+12544+(B<<2)>>2]|0)+ga|0,fa)}E=z+1|0;if((E|0)<6){y=B;z=E}else{ha=0;break}}}else{a[(c[e+19592>>2]|0)+(c[j>>2]|0)|0]=0;c[q>>2]=0;b:do{if(D){ia=0;ja=0}else{z=e+14128|0;y=c[z>>2]|0;G=c[h>>2]|0;P=d[G+(y>>>3)|0]|0;F=c[e+14136>>2]|0;C=((y|0)<(F|0))+y|0;c[z>>2]=C;do{if((P&128>>>((y&7)>>>0)|0)==0){ka=(b[e+16070>>1]|0)<128|0;la=C}else{L=d[G+(C>>>3)|0]<<(C&7)>>>7;I=((C|0)<(F|0))+C|0;c[z>>2]=I;t=L&1;L=t+1|0;if((t|0)==1){ia=2;ja=0;break b}else if((t|0)!=0){ka=L;la=I;break}ka=(b[e+16070>>1]|0)>127|0;la=I}}while(0);if((w|0)==0|(ka|0)==2){ia=ka;ja=0;break}C=d[G+(la>>>3)|0]<<(la&7)>>>7;c[z>>2]=((la|0)<(F|0))+la;ia=ka;ja=C&1}}while(0);if(u){C=e+16056|0;y=e+9876|0;P=e+12496|0;a[(c[C>>2]|0)+(c[P>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[P>>2]<<1)>>1]=0;I=e+12500|0;a[(c[C>>2]|0)+(c[I>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[I>>2]<<1)>>1]=0;L=e+12504|0;a[(c[C>>2]|0)+(c[L>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[L>>2]<<1)>>1]=0;t=e+12508|0;a[(c[C>>2]|0)+(c[t>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[t>>2]<<1)>>1]=0;N=e+12512|0;a[(c[C>>2]|0)+(c[N>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[N>>2]<<1)>>1]=0;N=e+12516|0;a[(c[C>>2]|0)+(c[N>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[N>>2]<<1)>>1]=0;c[(c[e+9160>>2]|0)+(m<<2)>>2]=2048;a[(c[e+9136>>2]|0)+m|0]=0;N=e+19400|0;a[(c[N>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[N>>2]|0)+(c[I>>2]|0)|0]=0;a[(c[N>>2]|0)+(c[L>>2]|0)|0]=0;a[(c[N>>2]|0)+(c[t>>2]|0)|0]=0;do{if(D){x2a(e,0)}else{if((ia|0)==2){y=e+15720|0;C=e+15724|0;B2a(e,0,0,0,1,c[y>>2]|0,c[C>>2]|0,0);B2a(e,0,0,0,1,c[y>>2]|0,c[C>>2]|0,1);x2a(e,0);break}C=(ia|0)==0|0;y=e+15720|0;s=e+15724|0;B2a(e,0,0,0,1,c[y>>2]|0,c[s>>2]|0,C);if((ja|0)==0){a[(c[N>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[N>>2]|0)+(c[I>>2]|0)|0]=1;a[(c[N>>2]|0)+(c[L>>2]|0)|0]=1;a[(c[N>>2]|0)+(c[t>>2]|0)|0]=1;A=C^1;B2a(e,0,0,0,2,c[y>>2]|0,c[s>>2]|0,A);s=e+9148+(A<<2)|0;y=c[s>>2]|0;J=b[y+(c[P>>2]<<2)>>1]|0;O=c[L>>2]|0;b[y+(O<<2)>>1]=J;y=J<<16>>16;c[e+11744+(A<<5)>>2]=y;c[e+11744+(A<<5)+16>>2]=y;y=c[s>>2]|0;J=b[y+(c[P>>2]<<2)+2>>1]|0;b[y+(O<<2)+2>>1]=J;O=J<<16>>16;c[e+11744+(A<<5)+4>>2]=O;c[e+11744+(A<<5)+20>>2]=O;O=c[I>>2]|0;J=c[s>>2]|0;y=b[J+(O<<2)>>1]|0;M=c[t>>2]|0;b[J+(M<<2)>>1]=y;J=y<<16>>16;c[e+11744+(A<<5)+8>>2]=J;c[e+11744+(A<<5)+24>>2]=J;J=c[s>>2]|0;s=b[J+(O<<2)+2>>1]|0;b[J+(M<<2)+2>>1]=s;M=s<<16>>16;c[e+11744+(A<<5)+12>>2]=M;c[e+11744+(A<<5)+28>>2]=M}else{M=C^1;A=e+9148+(C<<2)|0;s=e+9148+(M<<2)|0;J=c[A>>2]|0;O=b[J+(c[P>>2]<<2)>>1]|0;y=c[L>>2]|0;b[J+(y<<2)>>1]=O;J=O<<16>>16;c[e+11744+(C<<5)>>2]=J;c[e+11744+(C<<5)+16>>2]=J;J=c[P>>2]|0;O=c[A>>2]|0;x=b[O+(J<<2)+2>>1]|0;b[O+(y<<2)+2>>1]=x;O=x<<16>>16;c[e+11744+(C<<5)+4>>2]=O;c[e+11744+(C<<5)+20>>2]=O;O=c[s>>2]|0;x=b[O+(y<<2)>>1]|0;b[O+(J<<2)>>1]=x;J=x<<16>>16;c[e+11744+(M<<5)>>2]=J;c[e+11744+(M<<5)+16>>2]=J;J=c[s>>2]|0;x=b[J+(y<<2)+2>>1]|0;b[J+(c[P>>2]<<2)+2>>1]=x;J=x<<16>>16;c[e+11744+(M<<5)+4>>2]=J;c[e+11744+(M<<5)+20>>2]=J;J=c[I>>2]|0;x=c[A>>2]|0;y=b[x+(J<<2)>>1]|0;O=c[t>>2]|0;b[x+(O<<2)>>1]=y;x=y<<16>>16;c[e+11744+(C<<5)+8>>2]=x;c[e+11744+(C<<5)+24>>2]=x;x=c[A>>2]|0;A=b[x+(J<<2)+2>>1]|0;b[x+(O<<2)+2>>1]=A;O=A<<16>>16;c[e+11744+(C<<5)+12>>2]=O;c[e+11744+(C<<5)+28>>2]=O;O=c[t>>2]|0;A=c[s>>2]|0;x=b[A+(O<<2)>>1]|0;b[A+(J<<2)>>1]=x;A=x<<16>>16;c[e+11744+(M<<5)+8>>2]=A;c[e+11744+(M<<5)+24>>2]=A;A=c[s>>2]|0;s=b[A+(O<<2)+2>>1]|0;b[A+(J<<2)+2>>1]=s;J=s<<16>>16;c[e+11744+(M<<5)+12>>2]=J;c[e+11744+(M<<5)+28>>2]=J}x2a(e,C);ha=0;break a}}while(0);y2a(e);ha=0;break}if((a[1096251+(v<<2)|0]|0)==0){ma=0}else{t=c[(c[e+16084>>2]|0)+4>>2]|0;I=e+14128|0;P=c[I>>2]|0;L=c[e+14136>>2]|0;N=c[h>>2]|0;C=N+(P>>>3)|0;J=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(P&7)>>>23;C=b[t+(J<<2)>>1]|0;M=b[t+(J<<2)+2>>1]|0;J=M<<16>>16;if(M<<16>>16<0){M=P+9|0;s=L>>>0>M>>>0?M:L;M=N+(s>>>3)|0;N=((fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(s&7)>>>((J+32|0)>>>0))+C|0;na=b[t+(N<<2)+2>>1]|0;oa=b[t+(N<<2)>>1]|0;pa=s}else{na=J;oa=C;pa=P}P=na+pa|0;c[I>>2]=L>>>0>P>>>0?P:L;ma=oa+1|0}do{if(!D){L=(ia|0)!=2;P=(w|0)==0;if(!(L|P)){I=c[(c[e+19316>>2]|0)+4>>2]|0;C=e+14128|0;J=c[C>>2]|0;s=c[e+14136>>2]|0;N=(c[h>>2]|0)+(J>>>3)|0;t=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(J&7)>>>26;N=b[I+(t<<2)>>1]|0;M=(b[I+(t<<2)+2>>1]|0)+J|0;c[C>>2]=s>>>0>M>>>0?M:s;a[e+19321|0]=N;break}if(L&P){break}P=c[(c[e+19312>>2]|0)+4>>2]|0;L=e+14128|0;N=c[L>>2]|0;s=c[e+14136>>2]|0;M=(c[h>>2]|0)+(N>>>3)|0;C=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(N&7)>>>29;M=b[P+(C<<2)>>1]|0;J=(b[P+(C<<2)+2>>1]|0)+N|0;c[L>>2]=s>>>0>J>>>0?J:s;a[e+19320|0]=M}}while(0);M=e+16056|0;s=e+12496|0;a[(c[M>>2]|0)+(c[s>>2]|0)|0]=0;J=e+12500|0;a[(c[M>>2]|0)+(c[J>>2]|0)|0]=0;L=e+12504|0;a[(c[M>>2]|0)+(c[L>>2]|0)|0]=0;N=e+12508|0;a[(c[M>>2]|0)+(c[N>>2]|0)|0]=0;a[(c[M>>2]|0)+(c[e+12512>>2]|0)|0]=0;a[(c[M>>2]|0)+(c[e+12516>>2]|0)|0]=0;M=a[1096249+(v<<2)|0]|0;a[(c[e+19324>>2]|0)+m|0]=M;C=M&255;P=(w|0)!=0;do{if(D){if(P){z2a(e,0,0,0);z2a(e,0,1,1);z2a(e,1,0,0);z2a(e,1,1,1);z2a(e,2,0,0);z2a(e,2,1,1);z2a(e,3,0,0);z2a(e,3,1,1);A2a(e,0,0,0);A2a(e,1,1,1);break}else{x2a(e,0);y2a(e);break}}else{t=(ia|0)==2;if(P&t){I=d[e+19321|0]|0;A=e+15720|0;O=e+15724|0;x=e+19444|0;y=e+19288|0;K=e+19308|0;E=e+14128|0;B=e+14136|0;ea=e+14120|0;r=e+15712|0;qa=e+15716|0;ra=0;c:while(1){if((ra|0)==1){sa=1}else{sa=(ra|0)==3|0}do{if((1<<3-ra&I|0)==0){ta=0;ua=0}else{va=c[x>>2]|0;wa=(va|0)==0;xa=wa?71:125;ya=d[y]|0;if((ya|0)==1){za=1;Aa=0}else if((ya|0)==2){za=0;Aa=1}else if((ya|0)==3){za=1;Aa=1}else{za=0;Aa=0}ya=c[(c[K>>2]|0)+4>>2]|0;Ba=c[E>>2]|0;Ca=c[B>>2]|0;Da=c[ea>>2]|0;Ea=Da+(Ba>>>3)|0;Fa=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ba&7)>>>23;Ea=b[ya+(Fa<<2)>>1]|0;Ga=b[ya+(Fa<<2)+2>>1]|0;Fa=Ga<<16>>16;do{if(Ga<<16>>16<0){Ha=Ba+9|0;Ia=Ca>>>0>Ha>>>0?Ha:Ca;Ha=Da+(Ia>>>3)|0;Ja=((fe(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ia&7)>>>((Fa+32|0)>>>0))+Ea|0;Ha=b[ya+(Ja<<2)>>1]|0;Ka=b[ya+(Ja<<2)+2>>1]|0;Ja=Ka<<16>>16;if(!(Ka<<16>>16<0)){La=Ja;Ma=Ha;Na=Ia;break}Ka=Ia-Fa|0;Ia=Ca>>>0>Ka>>>0?Ka:Ca;Ka=Da+(Ia>>>3)|0;Oa=((fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ia&7)>>>((Ja+32|0)>>>0))+Ha|0;La=b[ya+(Oa<<2)+2>>1]|0;Ma=b[ya+(Oa<<2)>>1]|0;Na=Ia}else{La=Fa;Ma=Ea;Na=Ba}}while(0);Ba=La+Na|0;Ea=Ca>>>0>Ba>>>0?Ba:Ca;c[E>>2]=Ea;if((Ma|0)==(xa|0)){Ba=c[r>>2]|0;Fa=Da+(Ea>>>3)|0;ya=(fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ea&7)>>>((32-Ba|0)>>>0);Fa=Ba+Ea|0;Ba=Ca>>>0>Fa>>>0?Fa:Ca;c[E>>2]=Ba;Fa=c[qa>>2]|0;Ga=Da+(Ba>>>3)|0;Ia=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ba&7)>>>((32-Fa|0)>>>0);Ga=Ba+Fa|0;c[E>>2]=Ca>>>0>Ga>>>0?Ga:Ca;if(wa){ta=Ia;ua=ya;break}ta=(Ia&1)+Ia>>1;ua=ya;break}if((Ma|0)>=(xa|0)){X=124;break c}ya=Ma+1|0;Ia=(ya|0)%9|0;if((Ia|0)==0){Pa=0;Qa=Ea}else{Ga=Ia+za|0;Fa=Da+(Ea>>>3)|0;Ba=(fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ea&7)>>>((32-Ga|0)>>>0);Fa=Ga+Ea|0;Ea=Ca>>>0>Fa>>>0?Fa:Ca;c[E>>2]=Ea;Fa=Ba&1;Pa=((Ba>>1)+(c[((za|0)==0?628544:628504)+(Ia<<2)>>2]|0)^-Fa)+Fa|0;Qa=Ea}Ea=(ya|0)/9|0;if((Ea|0)<=(va|0)){ta=0;ua=Pa;break}ya=(Aa<<va)+Ea>>va;Fa=Da+(Qa>>>3)|0;Ia=(fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Qa&7)>>>((32-ya|0)>>>0);Fa=Qa+ya|0;c[E>>2]=Ca>>>0>Fa>>>0?Fa:Ca;Fa=Ia&1;ta=((Ia>>1)+(c[((Aa|0)==0?628544:628504)+(Ea>>va<<2)>>2]|0)^-Fa)+Fa|0;ua=Pa}}while(0);Fa=(ra|0)>1?2:0;B2a(e,Fa,ua,ta,2,c[A>>2]|0,c[O>>2]|0,sa);z2a(e,Fa,sa,sa);z2a(e,Fa|1,sa,sa);Fa=ra+1|0;if((Fa|0)<4){ra=Fa}else{X=130;break}}if((X|0)==124){yDb(0,0,2287080,(H=i,i=i+24|0,c[H>>2]=1998536,c[H+8>>2]=2255584,c[H+16>>2]=1214,H)|0);i=H;Cd()}else if((X|0)==130){A2a(e,0,0,0);A2a(e,1,1,1);break}}if(t){ra=d[e+19320|0]|0;do{if((ra&2|0)==0){Ra=0;Sa=0}else{O=c[e+19444>>2]|0;A=(O|0)==0;E=A?71:125;qa=d[e+19288|0]|0;if((qa|0)==3){Ta=1;Ua=1}else if((qa|0)==1){Ta=1;Ua=0}else if((qa|0)==2){Ta=0;Ua=1}else{Ta=0;Ua=0}qa=c[(c[e+19308>>2]|0)+4>>2]|0;r=e+14128|0;ea=c[r>>2]|0;B=c[e+14136>>2]|0;K=c[e+14120>>2]|0;y=K+(ea>>>3)|0;x=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(ea&7)>>>23;y=b[qa+(x<<2)>>1]|0;I=b[qa+(x<<2)+2>>1]|0;x=I<<16>>16;do{if(I<<16>>16<0){F=ea+9|0;z=B>>>0>F>>>0?F:B;F=K+(z>>>3)|0;G=((fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(z&7)>>>((x+32|0)>>>0))+y|0;F=b[qa+(G<<2)>>1]|0;Fa=b[qa+(G<<2)+2>>1]|0;G=Fa<<16>>16;if(!(Fa<<16>>16<0)){Va=G;Wa=F;Xa=z;break}Fa=z-x|0;z=B>>>0>Fa>>>0?Fa:B;Fa=K+(z>>>3)|0;Ea=((fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(z&7)>>>((G+32|0)>>>0))+F|0;Va=b[qa+(Ea<<2)+2>>1]|0;Wa=b[qa+(Ea<<2)>>1]|0;Xa=z}else{Va=x;Wa=y;Xa=ea}}while(0);ea=Va+Xa|0;y=B>>>0>ea>>>0?ea:B;c[r>>2]=y;if((Wa|0)==(E|0)){ea=c[e+15712>>2]|0;x=K+(y>>>3)|0;qa=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7)>>>((32-ea|0)>>>0);x=ea+y|0;ea=B>>>0>x>>>0?x:B;c[r>>2]=ea;x=c[e+15716>>2]|0;I=K+(ea>>>3)|0;z=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(ea&7)>>>((32-x|0)>>>0);I=ea+x|0;c[r>>2]=B>>>0>I>>>0?I:B;if(A){Ra=z;Sa=qa;break}Ra=(z&1)+z>>1;Sa=qa;break}if((Wa|0)>=(E|0)){yDb(0,0,2287080,(H=i,i=i+24|0,c[H>>2]=1998536,c[H+8>>2]=2255584,c[H+16>>2]=1214,H)|0);i=H;Cd()}qa=Wa+1|0;z=(qa|0)%9|0;if((z|0)==0){Ya=0;Za=y}else{I=z+Ta|0;x=K+(y>>>3)|0;ea=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7)>>>((32-I|0)>>>0);x=I+y|0;y=B>>>0>x>>>0?x:B;c[r>>2]=y;x=ea&1;Ya=((ea>>1)+(c[((Ta|0)==0?628544:628504)+(z<<2)>>2]|0)^-x)+x|0;Za=y}y=(qa|0)/9|0;if((y|0)<=(O|0)){Ra=0;Sa=Ya;break}qa=(Ua<<O)+y>>O;x=K+(Za>>>3)|0;z=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(Za&7)>>>((32-qa|0)>>>0);x=Za+qa|0;c[r>>2]=B>>>0>x>>>0?x:B;x=z&1;Ra=((z>>1)+(c[((Ua|0)==0?628544:628504)+(y>>O<<2)>>2]|0)^-x)+x|0;Sa=Ya}}while(0);t=e+15720|0;x=e+15724|0;B2a(e,0,Sa,Ra,1,c[t>>2]|0,c[x>>2]|0,0);x2a(e,0);do{if((ra&1|0)==0){_a=0;$a=0}else{y=c[e+19444>>2]|0;z=(y|0)==0;qa=z?71:125;ea=d[e+19288|0]|0;if((ea|0)==1){ab=1;bb=0}else if((ea|0)==2){ab=0;bb=1}else if((ea|0)==3){ab=1;bb=1}else{ab=0;bb=0}ea=c[(c[e+19308>>2]|0)+4>>2]|0;I=e+14128|0;Ea=c[I>>2]|0;F=c[e+14136>>2]|0;G=c[e+14120>>2]|0;Fa=G+(Ea>>>3)|0;Ia=(fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ea&7)>>>23;Fa=b[ea+(Ia<<2)>>1]|0;ya=b[ea+(Ia<<2)+2>>1]|0;Ia=ya<<16>>16;do{if(ya<<16>>16<0){Ba=Ea+9|0;Ga=F>>>0>Ba>>>0?Ba:F;Ba=G+(Ga>>>3)|0;Oa=((fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ga&7)>>>((Ia+32|0)>>>0))+Fa|0;Ba=b[ea+(Oa<<2)>>1]|0;Ha=b[ea+(Oa<<2)+2>>1]|0;Oa=Ha<<16>>16;if(!(Ha<<16>>16<0)){cb=Oa;db=Ba;eb=Ga;break}Ha=Ga-Ia|0;Ga=F>>>0>Ha>>>0?Ha:F;Ha=G+(Ga>>>3)|0;Ja=((fe(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ga&7)>>>((Oa+32|0)>>>0))+Ba|0;cb=b[ea+(Ja<<2)+2>>1]|0;db=b[ea+(Ja<<2)>>1]|0;eb=Ga}else{cb=Ia;db=Fa;eb=Ea}}while(0);Ea=cb+eb|0;Fa=F>>>0>Ea>>>0?Ea:F;c[I>>2]=Fa;if((db|0)==(qa|0)){Ea=c[e+15712>>2]|0;Ia=G+(Fa>>>3)|0;ea=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Fa&7)>>>((32-Ea|0)>>>0);Ia=Ea+Fa|0;Ea=F>>>0>Ia>>>0?Ia:F;c[I>>2]=Ea;Ia=c[e+15716>>2]|0;ya=G+(Ea>>>3)|0;O=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(Ea&7)>>>((32-Ia|0)>>>0);ya=Ea+Ia|0;c[I>>2]=F>>>0>ya>>>0?ya:F;if(z){_a=O;$a=ea;break}_a=(O&1)+O>>1;$a=ea;break}if((db|0)>=(qa|0)){yDb(0,0,2287080,(H=i,i=i+24|0,c[H>>2]=1998536,c[H+8>>2]=2255584,c[H+16>>2]=1214,H)|0);i=H;Cd()}ea=db+1|0;O=(ea|0)%9|0;if((O|0)==0){fb=0;gb=Fa}else{ya=O+ab|0;Ia=G+(Fa>>>3)|0;Ea=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Fa&7)>>>((32-ya|0)>>>0);Ia=ya+Fa|0;Fa=F>>>0>Ia>>>0?Ia:F;c[I>>2]=Fa;Ia=Ea&1;fb=((Ea>>1)+(c[((ab|0)==0?628544:628504)+(O<<2)>>2]|0)^-Ia)+Ia|0;gb=Fa}Fa=(ea|0)/9|0;if((Fa|0)<=(y|0)){_a=0;$a=fb;break}ea=(bb<<y)+Fa>>y;Ia=G+(gb>>>3)|0;O=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(gb&7)>>>((32-ea|0)>>>0);Ia=gb+ea|0;c[I>>2]=F>>>0>Ia>>>0?Ia:F;Ia=O&1;_a=((O>>1)+(c[((bb|0)==0?628544:628504)+(Fa>>y<<2)>>2]|0)^-Ia)+Ia|0;$a=fb}}while(0);B2a(e,0,$a,_a,1,c[t>>2]|0,c[x>>2]|0,1);y2a(e);break}ra=(ia|0)==0;Ia=ra&1;if(!P){do{if((a[1096250+(v<<2)|0]|0)==0){hb=0;ib=0}else{Fa=c[e+19444>>2]|0;O=(Fa|0)==0;ea=O?71:125;Ea=d[e+19288|0]|0;if((Ea|0)==1){jb=1;kb=0}else if((Ea|0)==2){jb=0;kb=1}else if((Ea|0)==3){jb=1;kb=1}else{jb=0;kb=0}Ea=c[(c[e+19308>>2]|0)+4>>2]|0;ya=e+14128|0;B=c[ya>>2]|0;r=c[e+14136>>2]|0;K=c[e+14120>>2]|0;E=K+(B>>>3)|0;A=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(B&7)>>>23;E=b[Ea+(A<<2)>>1]|0;Ga=b[Ea+(A<<2)+2>>1]|0;A=Ga<<16>>16;do{if(Ga<<16>>16<0){Ja=B+9|0;Ba=r>>>0>Ja>>>0?Ja:r;Ja=K+(Ba>>>3)|0;Oa=((fe(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Ba&7)>>>((A+32|0)>>>0))+E|0;Ja=b[Ea+(Oa<<2)>>1]|0;Ha=b[Ea+(Oa<<2)+2>>1]|0;Oa=Ha<<16>>16;if(!(Ha<<16>>16<0)){lb=Oa;mb=Ja;nb=Ba;break}Ha=Ba-A|0;Ba=r>>>0>Ha>>>0?Ha:r;Ha=K+(Ba>>>3)|0;Ka=((fe(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ba&7)>>>((Oa+32|0)>>>0))+Ja|0;lb=b[Ea+(Ka<<2)+2>>1]|0;mb=b[Ea+(Ka<<2)>>1]|0;nb=Ba}else{lb=A;mb=E;nb=B}}while(0);B=lb+nb|0;E=r>>>0>B>>>0?B:r;c[ya>>2]=E;if((mb|0)==(ea|0)){B=c[e+15712>>2]|0;A=K+(E>>>3)|0;Ea=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(E&7)>>>((32-B|0)>>>0);A=B+E|0;B=r>>>0>A>>>0?A:r;c[ya>>2]=B;A=c[e+15716>>2]|0;Ga=K+(B>>>3)|0;y=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(B&7)>>>((32-A|0)>>>0);Ga=B+A|0;c[ya>>2]=r>>>0>Ga>>>0?Ga:r;if(O){hb=y;ib=Ea;break}hb=(y&1)+y>>1;ib=Ea;break}if((mb|0)>=(ea|0)){yDb(0,0,2287080,(H=i,i=i+24|0,c[H>>2]=1998536,c[H+8>>2]=2255584,c[H+16>>2]=1214,H)|0);i=H;Cd()}Ea=mb+1|0;y=(Ea|0)%9|0;if((y|0)==0){ob=0;pb=E}else{Ga=y+jb|0;A=K+(E>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(E&7)>>>((32-Ga|0)>>>0);A=Ga+E|0;E=r>>>0>A>>>0?A:r;c[ya>>2]=E;A=B&1;ob=((B>>1)+(c[((jb|0)==0?628544:628504)+(y<<2)>>2]|0)^-A)+A|0;pb=E}E=(Ea|0)/9|0;if((E|0)<=(Fa|0)){hb=0;ib=ob;break}Ea=(kb<<Fa)+E>>Fa;A=K+(pb>>>3)|0;y=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(pb&7)>>>((32-Ea|0)>>>0);A=pb+Ea|0;c[ya>>2]=r>>>0>A>>>0?A:r;A=y&1;hb=((y>>1)+(c[((kb|0)==0?628544:628504)+(E>>Fa<<2)>>2]|0)^-A)+A|0;ib=ob}}while(0);x=e+15720|0;t=e+15724|0;B2a(e,0,ib,hb,1,c[x>>2]|0,c[t>>2]|0,Ia);A=e+19400|0;a[(c[A>>2]|0)+(c[s>>2]|0)|0]=1;a[(c[A>>2]|0)+(c[J>>2]|0)|0]=1;a[(c[A>>2]|0)+(c[L>>2]|0)|0]=1;a[(c[A>>2]|0)+(c[N>>2]|0)|0]=1;A=Ia^1;B2a(e,0,0,0,2,c[x>>2]|0,c[t>>2]|0,A);t=e+9148+(A<<2)|0;x=c[t>>2]|0;E=b[x+(c[s>>2]<<2)>>1]|0;y=c[L>>2]|0;b[x+(y<<2)>>1]=E;x=E<<16>>16;c[e+11744+(A<<5)>>2]=x;c[e+11744+(A<<5)+16>>2]=x;x=c[t>>2]|0;E=b[x+(c[s>>2]<<2)+2>>1]|0;b[x+(y<<2)+2>>1]=E;y=E<<16>>16;c[e+11744+(A<<5)+4>>2]=y;c[e+11744+(A<<5)+20>>2]=y;y=c[J>>2]|0;E=c[t>>2]|0;x=b[E+(y<<2)>>1]|0;Ea=c[N>>2]|0;b[E+(Ea<<2)>>1]=x;E=x<<16>>16;c[e+11744+(A<<5)+8>>2]=E;c[e+11744+(A<<5)+24>>2]=E;E=c[t>>2]|0;t=b[E+(y<<2)+2>>1]|0;b[E+(Ea<<2)+2>>1]=t;Ea=t<<16>>16;c[e+11744+(A<<5)+12>>2]=Ea;c[e+11744+(A<<5)+28>>2]=Ea;x2a(e,Ia);break}Ea=(ja|0)!=0;A=(ra^Ea)&1;t=d[e+19320|0]|0;do{if((t&2|0)==0){qb=0;rb=0}else{E=c[e+19444>>2]|0;y=(E|0)==0;x=y?71:125;B=d[e+19288|0]|0;if((B|0)==2){sb=0;tb=1}else if((B|0)==3){sb=1;tb=1}else if((B|0)==1){sb=1;tb=0}else{sb=0;tb=0}B=c[(c[e+19308>>2]|0)+4>>2]|0;Ga=e+14128|0;F=c[Ga>>2]|0;I=c[e+14136>>2]|0;G=c[e+14120>>2]|0;qa=G+(F>>>3)|0;z=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(F&7)>>>23;qa=b[B+(z<<2)>>1]|0;Ba=b[B+(z<<2)+2>>1]|0;z=Ba<<16>>16;do{if(Ba<<16>>16<0){Ka=F+9|0;Ja=I>>>0>Ka>>>0?Ka:I;Ka=G+(Ja>>>3)|0;Oa=((fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ja&7)>>>((z+32|0)>>>0))+qa|0;Ka=b[B+(Oa<<2)>>1]|0;Ha=b[B+(Oa<<2)+2>>1]|0;Oa=Ha<<16>>16;if(!(Ha<<16>>16<0)){ub=Oa;vb=Ka;wb=Ja;break}Ha=Ja-z|0;Ja=I>>>0>Ha>>>0?Ha:I;Ha=G+(Ja>>>3)|0;xb=((fe(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ja&7)>>>((Oa+32|0)>>>0))+Ka|0;ub=b[B+(xb<<2)+2>>1]|0;vb=b[B+(xb<<2)>>1]|0;wb=Ja}else{ub=z;vb=qa;wb=F}}while(0);F=ub+wb|0;qa=I>>>0>F>>>0?F:I;c[Ga>>2]=qa;if((vb|0)==(x|0)){F=c[e+15712>>2]|0;z=G+(qa>>>3)|0;B=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(qa&7)>>>((32-F|0)>>>0);z=F+qa|0;F=I>>>0>z>>>0?z:I;c[Ga>>2]=F;z=c[e+15716>>2]|0;Ba=G+(F>>>3)|0;Fa=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(F&7)>>>((32-z|0)>>>0);Ba=F+z|0;c[Ga>>2]=I>>>0>Ba>>>0?Ba:I;if(y){qb=Fa;rb=B;break}qb=(Fa&1)+Fa>>1;rb=B;break}if((vb|0)>=(x|0)){yDb(0,0,2287080,(H=i,i=i+24|0,c[H>>2]=1998536,c[H+8>>2]=2255584,c[H+16>>2]=1214,H)|0);i=H;Cd()}B=vb+1|0;Fa=(B|0)%9|0;if((Fa|0)==0){yb=0;zb=qa}else{Ba=Fa+sb|0;z=G+(qa>>>3)|0;F=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(qa&7)>>>((32-Ba|0)>>>0);z=Ba+qa|0;qa=I>>>0>z>>>0?z:I;c[Ga>>2]=qa;z=F&1;yb=((F>>1)+(c[((sb|0)==0?628544:628504)+(Fa<<2)>>2]|0)^-z)+z|0;zb=qa}qa=(B|0)/9|0;if((qa|0)<=(E|0)){qb=0;rb=yb;break}B=(tb<<E)+qa>>E;z=G+(zb>>>3)|0;Fa=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(zb&7)>>>((32-B|0)>>>0);z=zb+B|0;c[Ga>>2]=I>>>0>z>>>0?z:I;z=Fa&1;qb=((Fa>>1)+(c[((tb|0)==0?628544:628504)+(qa>>E<<2)>>2]|0)^-z)+z|0;rb=yb}}while(0);ra=e+15720|0;z=e+15724|0;B2a(e,0,rb,qb,2,c[ra>>2]|0,c[z>>2]|0,Ia);do{if((t&1|0)==0){Ab=0;Bb=0}else{qa=c[e+19444>>2]|0;Fa=(qa|0)==0;B=Fa?71:125;F=d[e+19288|0]|0;if((F|0)==1){Cb=1;Db=0}else if((F|0)==2){Cb=0;Db=1}else if((F|0)==3){Cb=1;Db=1}else{Cb=0;Db=0}F=c[(c[e+19308>>2]|0)+4>>2]|0;Ba=e+14128|0;r=c[Ba>>2]|0;ya=c[e+14136>>2]|0;K=c[e+14120>>2]|0;ea=K+(r>>>3)|0;O=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(r&7)>>>23;ea=b[F+(O<<2)>>1]|0;Ja=b[F+(O<<2)+2>>1]|0;O=Ja<<16>>16;do{if(Ja<<16>>16<0){xb=r+9|0;Ka=ya>>>0>xb>>>0?xb:ya;xb=K+(Ka>>>3)|0;Oa=((fe(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0)<<(Ka&7)>>>((O+32|0)>>>0))+ea|0;xb=b[F+(Oa<<2)>>1]|0;Ha=b[F+(Oa<<2)+2>>1]|0;Oa=Ha<<16>>16;if(!(Ha<<16>>16<0)){Eb=Oa;Fb=xb;Gb=Ka;break}Ha=Ka-O|0;Ka=ya>>>0>Ha>>>0?Ha:ya;Ha=K+(Ka>>>3)|0;Hb=((fe(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ka&7)>>>((Oa+32|0)>>>0))+xb|0;Eb=b[F+(Hb<<2)+2>>1]|0;Fb=b[F+(Hb<<2)>>1]|0;Gb=Ka}else{Eb=O;Fb=ea;Gb=r}}while(0);r=Eb+Gb|0;ea=ya>>>0>r>>>0?r:ya;c[Ba>>2]=ea;if((Fb|0)==(B|0)){r=c[e+15712>>2]|0;O=K+(ea>>>3)|0;F=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(ea&7)>>>((32-r|0)>>>0);O=r+ea|0;r=ya>>>0>O>>>0?O:ya;c[Ba>>2]=r;O=c[e+15716>>2]|0;Ja=K+(r>>>3)|0;E=(fe(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(r&7)>>>((32-O|0)>>>0);Ja=r+O|0;c[Ba>>2]=ya>>>0>Ja>>>0?Ja:ya;if(Fa){Ab=E;Bb=F;break}Ab=(E&1)+E>>1;Bb=F;break}if((Fb|0)>=(B|0)){yDb(0,0,2287080,(H=i,i=i+24|0,c[H>>2]=1998536,c[H+8>>2]=2255584,c[H+16>>2]=1214,H)|0);i=H;Cd()}F=Fb+1|0;E=(F|0)%9|0;if((E|0)==0){Ib=0;Jb=ea}else{Ja=E+Cb|0;O=K+(ea>>>3)|0;r=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(ea&7)>>>((32-Ja|0)>>>0);O=Ja+ea|0;ea=ya>>>0>O>>>0?O:ya;c[Ba>>2]=ea;O=r&1;Ib=((r>>1)+(c[((Cb|0)==0?628544:628504)+(E<<2)>>2]|0)^-O)+O|0;Jb=ea}ea=(F|0)/9|0;if((ea|0)<=(qa|0)){Ab=0;Bb=Ib;break}F=(Db<<qa)+ea>>qa;O=K+(Jb>>>3)|0;E=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(Jb&7)>>>((32-F|0)>>>0);O=Jb+F|0;c[Ba>>2]=ya>>>0>O>>>0?O:ya;O=E&1;Ab=((E>>1)+(c[((Db|0)==0?628544:628504)+(ea>>qa<<2)>>2]|0)^-O)+O|0;Bb=Ib}}while(0);B2a(e,2,Bb,Ab,2,c[ra>>2]|0,c[z>>2]|0,A);if(Ea){t=e+9148+(Ia<<2)|0;O=e+9148+(A<<2)|0;ea=c[t>>2]|0;E=b[ea+(c[s>>2]<<2)>>1]|0;F=c[L>>2]|0;b[ea+(F<<2)>>1]=E;ea=E<<16>>16;c[e+11744+(Ia<<5)>>2]=ea;c[e+11744+(Ia<<5)+16>>2]=ea;ea=c[s>>2]|0;E=c[t>>2]|0;r=b[E+(ea<<2)+2>>1]|0;b[E+(F<<2)+2>>1]=r;E=r<<16>>16;c[e+11744+(Ia<<5)+4>>2]=E;c[e+11744+(Ia<<5)+20>>2]=E;E=c[O>>2]|0;r=b[E+(F<<2)>>1]|0;b[E+(ea<<2)>>1]=r;ea=r<<16>>16;c[e+11744+(A<<5)>>2]=ea;c[e+11744+(A<<5)+16>>2]=ea;ea=c[O>>2]|0;r=b[ea+(F<<2)+2>>1]|0;b[ea+(c[s>>2]<<2)+2>>1]=r;ea=r<<16>>16;c[e+11744+(A<<5)+4>>2]=ea;c[e+11744+(A<<5)+20>>2]=ea;ea=c[J>>2]|0;r=c[t>>2]|0;F=b[r+(ea<<2)>>1]|0;E=c[N>>2]|0;b[r+(E<<2)>>1]=F;r=F<<16>>16;c[e+11744+(Ia<<5)+8>>2]=r;c[e+11744+(Ia<<5)+24>>2]=r;r=c[t>>2]|0;t=b[r+(ea<<2)+2>>1]|0;b[r+(E<<2)+2>>1]=t;E=t<<16>>16;c[e+11744+(Ia<<5)+12>>2]=E;c[e+11744+(Ia<<5)+28>>2]=E;E=c[N>>2]|0;t=c[O>>2]|0;r=b[t+(E<<2)>>1]|0;b[t+(ea<<2)>>1]=r;t=r<<16>>16;c[e+11744+(A<<5)+8>>2]=t;c[e+11744+(A<<5)+24>>2]=t;t=c[O>>2]|0;O=b[t+(E<<2)+2>>1]|0;b[t+(ea<<2)+2>>1]=O;ea=O<<16>>16;c[e+11744+(A<<5)+12>>2]=ea;c[e+11744+(A<<5)+28>>2]=ea}else{ea=Ia^1;B2a(e,0,0,0,2,c[ra>>2]|0,c[z>>2]|0,ea);B2a(e,2,0,0,2,c[ra>>2]|0,c[z>>2]|0,ea)}z2a(e,0,Ia,0);z2a(e,1,Ia,0);z2a(e,2,A,0);z2a(e,3,A,0);A2a(e,Ia,A,0)}}while(0);N=(ma|0)!=0;do{if(N){if((a[e+16004|0]|0)==0){Kb=p;break}J=a[e+16005|0]|0;do{if(J<<24>>24==3){s=e+14128|0;L=c[s>>2]|0;if((a[e+16007|0]|0)!=0){P=d[(c[h>>2]|0)+(L>>>3)|0]|0;c[s>>2]=((L|0)<(c[e+14136>>2]|0))+L;Lb=d[(P&128>>>((L&7)>>>0)|0)==0?o:e+15729|0]|0;X=232;break}P=c[e+14136>>2]|0;ea=c[h>>2]|0;O=ea+(L>>>3)|0;t=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>29;O=L+3|0;L=P>>>0>O>>>0?O:P;c[s>>2]=L;if((t|0)==7){O=ea+(L>>>3)|0;ea=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>27;O=L+5|0;c[s>>2]=P>>>0>O>>>0?O:P;Lb=ea;X=232;break}else{Mb=(d[o]|0)+t|0;break}}else{Lb=p;X=232}}while(0);do{if((X|0)==232){if((J<<24>>24|0)==0){Nb=15;X=236}else if((J<<24>>24|0)==2){Ob=1<<d[e+16006|0];X=235}else if((J<<24>>24|0)==1){Ob=(3<<d[e+16006|0]|0)%15|0;X=235}else{Mb=Lb;break}if((X|0)==235){if((Ob&1|0)==0){Pb=Lb;Qb=Ob}else{Nb=Ob;X=236}}do{if((X|0)==236){if((c[j>>2]|0)!=0){Pb=Lb;Qb=Nb;break}Pb=d[e+15729|0]|0;Qb=Nb}}while(0);do{if((Qb&2|0)==0){Rb=Pb}else{if((c[e+14084>>2]|0)==0){Rb=Pb;break}Rb=d[e+15729|0]|0}}while(0);do{if((Qb&4|0)==0){Sb=Rb}else{if((c[j>>2]|0)!=((c[e+116>>2]|0)-1|0)){Sb=Rb;break}Sb=d[e+15729|0]|0}}while(0);if((Qb&8|0)==0){Mb=Sb;break}if((c[k>>2]|0)!=((c[e+120>>2]|0)-1|0)){Mb=Sb;break}Mb=d[e+15729|0]|0}}while(0);if(!((Mb|0)==0|(Mb|0)>31)){Kb=Mb;break}yDb(c[e+4>>2]|0,16,2024400,(H=i,i=i+8|0,c[H>>2]=Mb,H)|0);i=H;Kb=1}else{Kb=p}}while(0);a[(c[e+9136>>2]|0)+m|0]=Kb;J=e+16020|0;if((a[J]|0)!=0|N^1){Tb=n}else{qa=c[5254452+((c[e+16088>>2]|0)*20|0)>>2]|0;ya=e+14128|0;Ba=c[ya>>2]|0;K=c[e+14136>>2]|0;B=c[h>>2]|0;Fa=B+(Ba>>>3)|0;A=(fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ba&7)>>>23;Fa=b[qa+(A<<2)>>1]|0;Ia=b[qa+(A<<2)+2>>1]|0;A=Ia<<16>>16;if(Ia<<16>>16<0){Ia=Ba+9|0;z=K>>>0>Ia>>>0?Ia:K;Ia=B+(z>>>3)|0;B=((fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(z&7)>>>((A+32|0)>>>0))+Fa|0;Ub=b[qa+(B<<2)+2>>1]|0;Vb=b[qa+(B<<2)>>1]|0;Wb=z}else{Ub=A;Vb=Fa;Wb=Ba}Ba=Ub+Wb|0;c[ya>>2]=K>>>0>Ba>>>0?Ba:K;Tb=Vb}K=e+9876|0;Ba=M<<24>>24==0;ya=e+148|0;Fa=e+14340|0;A=e+152|0;z=e+60|0;B=Tb;qa=1;Ia=0;ra=0;Ea=0;while(1){b[(c[K>>2]|0)+(c[e+12496+(Ea<<2)>>2]<<1)>>1]=0;t=(Ea>>2)+Ia|0;ea=5-Ea|0;P=(Ea&4|0)!=0;do{if(Ba){if(P){Xb=0;break}Xb=(ba(c[ya>>2]|0,Ea<<2&8)|0)+(Ea<<3&8)|0}else{if(P){Xb=0;break}Xb=(c[ya>>2]&-((Ea|0)>1|0))+(Ea<<3&8)|0}}while(0);if((1<<ea&ma|0)==0){Yb=ra;Zb=qa;_b=B}else{if(P){$b=(c[z>>2]|0)>>>13&1;ac=c[A>>2]|0}else{$b=0;ac=c[ya>>2]<<C}O=(u2a(e,(c[Fa>>2]|0)+(Ea<<7)|0,Ea,Kb,B,qa,(c[e+12544+(t<<2)>>2]|0)+Xb|0,ac,$b,g)|0)<<(Ea<<2)|ra;Yb=O;Zb=0;_b=(a[J]|0)==0&(B|0)<8?-1:B}O=Ea+1|0;if((O|0)<6){B=_b;qa=Zb;Ia=t;ra=Yb;Ea=O}else{ha=Yb;break}}}}while(0);Yb=c[j>>2]|0;if((Yb|0)!=((c[e+116>>2]|0)-1|0)){bc=Yb;cc=e+19584|0;dc=c[cc>>2]|0;ec=dc+(bc<<2)|0;c[ec>>2]=ha;fc=c[g>>2]|0;gc=c[j>>2]|0;hc=e+16028|0;ic=c[hc>>2]|0;jc=ic+(gc<<2)|0;c[jc>>2]=fc;i=f;return}VGb(c[e+19588>>2]|0,c[e+19592>>2]|0,c[l>>2]|0)|0;bc=c[j>>2]|0;cc=e+19584|0;dc=c[cc>>2]|0;ec=dc+(bc<<2)|0;c[ec>>2]=ha;fc=c[g>>2]|0;gc=c[j>>2]|0;hc=e+16028|0;ic=c[hc>>2]|0;jc=ic+(gc<<2)|0;c[jc>>2]=fc;i=f;return}function r2a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a+15396|0;do{if((c[a+14084>>2]|0)==0){e=a+12544|0;f=a+148|0;Xe[c[d>>2]&4095](c[e>>2]|0,c[f>>2]|0,b);g=a+12476|0;h=a+15400|0;if((c[g>>2]|0)!=0){i=c[f>>2]|0;Xe[c[h>>2]&4095]((c[e>>2]|0)+(-(i<<4)|0)|0,i,b)}i=c[f>>2]|0;Xe[c[h>>2]&4095]((c[e>>2]|0)+(-(i<<4)|8)|0,i,b);i=a+15388|0;h=a+152|0;j=a+15392|0;k=a+12548|0;Xe[c[i>>2]&4095](c[k>>2]|0,c[h>>2]|0,b);if((c[g>>2]|0)!=0){l=c[h>>2]|0;Xe[c[j>>2]&4095]((c[k>>2]|0)+(-(l<<3)|0)|0,l,b)}l=a+12552|0;Xe[c[i>>2]&4095](c[l>>2]|0,c[h>>2]|0,b);if((c[g>>2]|0)==0){m=e;n=f;break}g=c[h>>2]|0;Xe[c[j>>2]&4095]((c[l>>2]|0)+(-(g<<3)|0)|0,g,b);m=e;n=f}else{m=a+12544|0;n=a+148|0}}while(0);f=c[n>>2]|0;Xe[c[d>>2]&4095]((c[m>>2]|0)+(f<<3)|0,f,b);if((c[a+12480>>2]|0)!=((c[a+812>>2]|0)-1|0)){return}f=a+15400|0;if((c[a+12476>>2]|0)!=0){Xe[c[f>>2]&4095](c[m>>2]|0,c[n>>2]|0,b);d=a+15392|0;e=a+152|0;Xe[c[d>>2]&4095](c[a+12548>>2]|0,c[e>>2]|0,b);Xe[c[d>>2]&4095](c[a+12552>>2]|0,c[e>>2]|0,b)}Xe[c[f>>2]&4095]((c[m>>2]|0)+8|0,c[n>>2]|0,b);return}function s2a(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;h=i;if((c[a+19428>>2]|0)!=0){yDb(0,0,2287080,(j=i,i=i+24|0,c[j>>2]=2013320,c[j+8>>2]=2255584,c[j+16>>2]=2116,j)|0);i=j;Cd()}k=c[a+15720>>2]|0;l=c[a+15724>>2]|0;m=a+13924|0;c[d>>2]=c[d>>2]<<1-(c[m>>2]|0);c[e>>2]=c[e>>2]<<1-(c[m>>2]|0);n=d+4|0;c[n>>2]=c[n>>2]<<1-(c[m>>2]|0);o=e+4|0;c[o>>2]=c[o>>2]<<1-(c[m>>2]|0);p=c[a+128>>2]|0;q=c[a+12496>>2]|0;if((c[a+12488>>2]|0)!=0){r=c[a+9152>>2]|0;b[r+(q<<2)+2>>1]=0;b[r+(q<<2)>>1]=0;r=c[a+9148>>2]|0;b[r+(q<<2)+2>>1]=0;b[r+(q<<2)>>1]=0;i=h;return}r=(f|0)!=0;do{if(r){if((c[(c[a+9852>>2]|0)+2164>>2]|0)==0){break}yDb(c[a+4>>2]|0,24,2008880,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}}while(0);j=c[a+4704>>2]|0;f=b[j+(q<<2)>>1]|0;s=b[a+16070>>1]|0;t=ba(s,f)|0;if((c[m>>2]|0)==0){m=t+255>>9<<1;u=a+11744|0;c[u>>2]=m;v=b[j+(q<<2)+2>>1]|0;w=(ba(s,v)|0)+255>>9<<1;x=a+11748|0;c[x>>2]=w;y=s-256|0;z=(ba(y,f)|0)+255>>9<<1;A=a+11776|0;c[A>>2]=z;B=(ba(y,v)|0)+255>>9<<1;C=x;D=w;E=m;F=u;G=z;H=A}else{A=t+128>>8;t=a+11744|0;c[t>>2]=A;z=b[j+(q<<2)+2>>1]|0;j=(ba(s,z)|0)+128>>8;u=a+11748|0;c[u>>2]=j;m=s-256|0;s=(ba(m,f)|0)+128>>8;f=a+11776|0;c[f>>2]=s;B=(ba(m,z)|0)+128>>8;C=u;D=j;E=A;F=t;G=s;H=f}f=a+11780|0;c[f>>2]=B;s=c[a+12476>>2]|0;t=s<<6;A=-60-t|0;j=c[a+116>>2]|0;u=j<<6;z=-4-t+u|0;if((E|0)<(A|0)){I=A}else{I=(E|0)>(z|0)?z:E}c[F>>2]=I;E=c[a+12480>>2]|0;t=E<<6;m=-60-t|0;w=c[a+120>>2]|0;x=w<<6;v=-4-t+x|0;if((D|0)<(m|0)){J=m}else{J=(D|0)>(v|0)?v:D}c[C>>2]=J;if((G|0)<(A|0)){K=A}else{K=(G|0)>(z|0)?z:G}c[H>>2]=K;if((B|0)<(m|0)){L=m}else{L=(B|0)>(v|0)?v:B}c[f>>2]=L;if(r){r=c[a+9148>>2]|0;b[r+(q<<2)>>1]=I;b[r+(q<<2)+2>>1]=J;r=c[a+9152>>2]|0;b[r+(q<<2)>>1]=K;b[r+(q<<2)+2>>1]=L;i=h;return}r=J&65535;J=I&65535;if((g-1|0)>>>0<2>>>0){I=q-2|0;B=c[a+9148>>2]|0;v=B+(I<<2)|0;G=q-(p<<1)|0;z=((s|0)==(j-1|0)?-2:2)+G|0;A=B+(z<<2)|0;D=(s|0)==0;if(D){b[B+(I<<2)+2>>1]=0;b[v>>1]=0}do{if((c[a+14084>>2]|0)==0){y=b[B+(G<<2)>>1]|0;M=y<<16>>16;if((j|0)==1){N=b[B+(G<<2)+2>>1]|0;O=M;P=s;break}Q=b[A>>1]|0;R=Q<<16>>16;S=b[v>>1]|0;T=S<<16>>16;do{if(y<<16>>16>Q<<16>>16){if(!(S<<16>>16>Q<<16>>16)){U=R;break}U=(T|0)>(M|0)?M:T}else{if(!(Q<<16>>16>S<<16>>16)){U=R;break}U=(T|0)>(M|0)?T:M}}while(0);M=b[B+(G<<2)+2>>1]|0;T=M<<16>>16;R=b[B+(z<<2)+2>>1]|0;S=R<<16>>16;Q=b[B+(I<<2)+2>>1]|0;y=Q<<16>>16;if(M<<16>>16>R<<16>>16){if(!(Q<<16>>16>R<<16>>16)){N=S;O=U;P=s;break}N=(y|0)>(T|0)?T:y;O=U;P=s;break}else{if(!(R<<16>>16>Q<<16>>16)){N=S;O=U;P=s;break}N=(y|0)>(T|0)?y:T;O=U;P=s;break}}else{if(D){N=0;O=0;P=0;break}N=b[B+(I<<2)+2>>1]|0;O=b[v>>1]|0;P=s}}while(0);if((c[a+15660>>2]|0)<3){v=P<<5;I=E<<5;B=(j<<5)-4|0;D=(w<<5)-4|0;U=(v+O|0)<-28?-28-v|0:O;z=(I+N|0)<-28?-28-I|0:N;V=(z+I|0)>(D|0)?D-I|0:z;W=(U+v|0)>(B|0)?B-v|0:U}else{U=P<<6;P=u-4|0;v=x-4|0;B=(U+O|0)<-60?-60-U|0:O;O=(t+N|0)<-60?m:N;V=(O+t|0)>(v|0)?v-t|0:O;W=(B+U|0)>(P|0)?P-U|0:B}B=(W+k+(c[d>>2]|0)&(k<<1)-1)-k|0;c[F>>2]=B;F=(V+l+(c[e>>2]|0)&(l<<1)-1)-l|0;c[C>>2]=F;X=B&65535;Y=F&65535}else{X=J;Y=r}if((g|0)==2|(g|0)==0){g=q-2|0;r=c[a+9152>>2]|0;J=r+(g<<2)|0;F=q-(p<<1)|0;p=((s|0)==(j-1|0)?-2:2)+F|0;B=r+(p<<2)|0;C=(s|0)==0;if(C){b[r+(g<<2)+2>>1]=0;b[J>>1]=0}do{if((c[a+14084>>2]|0)==0){e=b[r+(F<<2)>>1]|0;V=e<<16>>16;if((j|0)==1){Z=b[r+(F<<2)+2>>1]|0;_=V;$=s;break}d=b[B>>1]|0;W=d<<16>>16;U=b[J>>1]|0;P=U<<16>>16;do{if(e<<16>>16>d<<16>>16){if(!(U<<16>>16>d<<16>>16)){aa=W;break}aa=(P|0)>(V|0)?V:P}else{if(!(d<<16>>16>U<<16>>16)){aa=W;break}aa=(P|0)>(V|0)?P:V}}while(0);V=b[r+(F<<2)+2>>1]|0;P=V<<16>>16;W=b[r+(p<<2)+2>>1]|0;U=W<<16>>16;d=b[r+(g<<2)+2>>1]|0;e=d<<16>>16;if(V<<16>>16>W<<16>>16){if(!(d<<16>>16>W<<16>>16)){Z=U;_=aa;$=s;break}Z=(e|0)>(P|0)?P:e;_=aa;$=s;break}else{if(!(W<<16>>16>d<<16>>16)){Z=U;_=aa;$=s;break}Z=(e|0)>(P|0)?e:P;_=aa;$=s;break}}else{if(C){Z=0;_=0;$=0;break}Z=b[r+(g<<2)+2>>1]|0;_=b[J>>1]|0;$=s}}while(0);if((c[a+15660>>2]|0)<3){s=$<<5;J=E<<5;E=(j<<5)-4|0;j=(w<<5)-4|0;w=(s+_|0)<-28?-28-s|0:_;g=(J+Z|0)<-28?-28-J|0:Z;ca=(g+J|0)>(j|0)?j-J|0:g;da=(w+s|0)>(E|0)?E-s|0:w}else{w=$<<6;$=u-4|0;u=x-4|0;x=(w+_|0)<-60?-60-w|0:_;_=(t+Z|0)<-60?m:Z;ca=(_+t|0)>(u|0)?u-t|0:_;da=(x+w|0)>($|0)?$-w|0:x}x=(da+k+(c[n>>2]|0)&(k<<1)-1)-k|0;c[H>>2]=x;H=(ca+l+(c[o>>2]|0)&(l<<1)-1)-l|0;c[f>>2]=H;ea=r;fa=x&65535;ga=H&65535}else{ea=c[a+9152>>2]|0;fa=K&65535;ga=L&65535}L=c[a+9148>>2]|0;b[L+(q<<2)>>1]=X;b[L+(q<<2)+2>>1]=Y;b[ea+(q<<2)>>1]=fa;b[ea+(q<<2)+2>>1]=ga;i=h;return}function t2a(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;m=i;i=i+40|0;n=m|0;o=m+8|0;p=m+16|0;q=m+24|0;r=m+32|0;s=f|0;t=f+14120|0;c[n>>2]=0;c[o>>2]=0;u=f+124|0;v=(ba(c[u>>2]|0,c[f+12480>>2]|0)|0)+(c[f+12476>>2]|0)|0;w=c[f+16044>>2]|0;x=c[f+16048>>2]|0;y=c[f+176>>2]|0;me[c[f+10092>>2]&511](g);if((k|0)<1){z=0}else{z=(k|0)>31?31:k}k=f+168|0;c[k>>2]=d[(c[f+9888>>2]|0)+z|0]|0;A=f+172|0;c[A>>2]=d[(c[f+9892>>2]|0)+z|0]|0;B=(h|0)<4;C=c[f+14072>>2]|0;if(B){D=c[6482460+(C*20|0)>>2]|0;E=f+14128|0;F=c[E>>2]|0;G=c[f+14136>>2]|0;H=c[t>>2]|0;I=H+(F>>>3)|0;J=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(F&7)>>>23;I=b[D+(J<<2)>>1]|0;K=b[D+(J<<2)+2>>1]|0;J=K<<16>>16;do{if(K<<16>>16<0){L=F+9|0;M=G>>>0>L>>>0?L:G;L=H+(M>>>3)|0;N=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>((J+32|0)>>>0))+I|0;L=b[D+(N<<2)>>1]|0;O=b[D+(N<<2)+2>>1]|0;N=O<<16>>16;if(!(O<<16>>16<0)){P=N;Q=L;R=M;break}O=M-J|0;M=G>>>0>O>>>0?O:G;O=H+(M>>>3)|0;S=((fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(M&7)>>>((N+32|0)>>>0))+L|0;P=b[D+(S<<2)+2>>1]|0;Q=b[D+(S<<2)>>1]|0;R=M}else{P=J;Q=I;R=F}}while(0);F=P+R|0;R=G>>>0>F>>>0?F:G;c[E>>2]=R;T=Q;U=R;V=G;W=H}else{H=c[6482500+(C*20|0)>>2]|0;C=f+14128|0;G=c[C>>2]|0;R=c[f+14136>>2]|0;Q=c[t>>2]|0;t=Q+(G>>>3)|0;E=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(G&7)>>>23;t=b[H+(E<<2)>>1]|0;F=b[H+(E<<2)+2>>1]|0;E=F<<16>>16;do{if(F<<16>>16<0){P=G+9|0;I=R>>>0>P>>>0?P:R;P=Q+(I>>>3)|0;J=((fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(I&7)>>>((E+32|0)>>>0))+t|0;P=b[H+(J<<2)>>1]|0;D=b[H+(J<<2)+2>>1]|0;J=D<<16>>16;if(!(D<<16>>16<0)){X=J;Y=P;Z=I;break}D=I-E|0;I=R>>>0>D>>>0?D:R;D=Q+(I>>>3)|0;K=((fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(I&7)>>>((J+32|0)>>>0))+P|0;X=b[H+(K<<2)+2>>1]|0;Y=b[H+(K<<2)>>1]|0;Z=I}else{X=E;Y=t;Z=G}}while(0);G=X+Z|0;Z=R>>>0>G>>>0?G:R;c[C>>2]=Z;T=Y;U=Z;V=R;W=Q}if((T|0)<0){yDb(c[f+4>>2]|0,16,2021120,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;i=m;return}do{if((T|0)==0){_=0}else{Q=(z|0)==1;do{if((T|0)==119){if(Q){R=f+14128|0;Z=W+(U>>>3)|0;Y=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(U&7)>>>22;Z=U+10|0;C=V>>>0>Z>>>0?Z:V;c[R>>2]=C;$=Y;aa=C;ca=R;break}R=f+14128|0;C=W+(U>>>3)|0;Y=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(U&7);if((z|0)==2){C=U+9|0;Z=V>>>0>C>>>0?C:V;c[R>>2]=Z;$=Y>>>23;aa=Z;ca=R;break}else{Z=U+8|0;C=V>>>0>Z>>>0?Z:V;c[R>>2]=C;$=Y>>>24;aa=C;ca=R;break}}else{if(Q){R=f+14128|0;C=W+(U>>>3)|0;Y=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(U&7)>>>30;C=U+2|0;Z=V>>>0>C>>>0?C:V;c[R>>2]=Z;$=(Y|T<<2)-3|0;aa=Z;ca=R;break}if((z|0)==2){R=f+14128|0;Z=d[W+(U>>>3)|0]<<(U&7)>>>7;Y=((U|0)<(V|0))+U|0;c[R>>2]=Y;$=(Z&1|T<<1)-1|0;aa=Y;ca=R;break}else{$=T;aa=U;ca=f+14128|0;break}}}while(0);Q=d[W+(aa>>>3)|0]|0;c[ca>>2]=((aa|0)<(V|0))+aa;if((Q&128>>>((aa&7)>>>0)|0)==0){_=$;break}_=-$|0}}while(0);$=(w2a(s,h,w,x,o,n)|0)+_|0;b[c[o>>2]>>1]=$;b[g>>1]=ba(c[(B?k:A)>>2]|0,$)|0;$=(w|0)!=0;if(!$){c[n>>2]=1}w=(x|0)!=0;if(!w){c[n>>2]=0}if($){da=y}else{da=w?y:0}y=c[f+9912>>2]|0;x=c[f+12496+(h<<2)>>2]<<4;A=y+(x<<1)|0;k=f+16072|0;B=(d[k]|0)+(z<<1)|0;o=c[n>>2]|0;n=(o|0)==0;if(n){ea=x-(c[f+12520+(h<<2)>>2]<<4)|0}else{ea=x-16|0}_=y+(ea<<1)|0;s=c[f+9136>>2]|0;aa=a[s+v|0]|0;if(n|w^1|(v|0)==0){fa=0}else{fa=a[s+(v-1)|0]|0}w=(o|0)!=0;do{if(w|$^1){ga=fa}else{o=c[u>>2]|0;if((v|0)<(o|0)){ga=fa;break}ga=a[s+(v-o)|0]|0}}while(0);v=(h|0)==3?aa:n&(h|0)==2?aa:w&(h|0)==1?aa:ga;a:do{if((j|0)==0){ga=A;TGb(ga|0,0,32)|0;w=(da|0)!=0;do{if(n){if(!w){ha=1;break a}UGb(y+((x|8)<<1)|0,y+(ea+8<<1)|0,16)|0;if((v|0)==0|(aa|0)==(v|0)){break}s=d[f+15728|0]|0;if((aa|0)==(s|0)){ia=d[k]|0}else{ia=0}fa=ia+(aa<<1)|0;if((v|0)==(s|0)){ja=d[k]|0}else{ja=0}s=(v<<1)-1+ja|0;if((fa-1|0)<1){i=m;return}else{u=c[1098544+(fa-2<<2)>>2]|0;fa=y+((x|9)<<1)|0;b[fa>>1]=(ba(ba(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|10)<<1)|0;b[fa>>1]=(ba(ba(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|11)<<1)|0;b[fa>>1]=(ba(ba(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|12)<<1)|0;b[fa>>1]=(ba(ba(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|13)<<1)|0;b[fa>>1]=(ba(ba(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|14)<<1)|0;b[fa>>1]=(ba(ba(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|15)<<1)|0;b[fa>>1]=(ba(ba(b[fa>>1]|0,s)|0,u)|0)+131072>>18;ka=99;break}}else{if(!w){ha=1;break a}UGb(ga|0,_|0,16)|0;if((v|0)==0|(aa|0)==(v|0)){break}u=d[f+15728|0]|0;if((aa|0)==(u|0)){la=d[k]|0}else{la=0}s=la+(aa<<1)|0;if((v|0)==(u|0)){ma=d[k]|0}else{ma=0}u=(v<<1)-1+ma|0;if((s-1|0)<1){i=m;return}else{fa=c[1098544+(s-2<<2)>>2]|0;s=y+((x|1)<<1)|0;b[s>>1]=(ba(ba(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|2)<<1)|0;b[s>>1]=(ba(ba(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|3)<<1)|0;b[s>>1]=(ba(ba(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|4)<<1)|0;b[s>>1]=(ba(ba(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|5)<<1)|0;b[s>>1]=(ba(ba(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|6)<<1)|0;b[s>>1]=(ba(ba(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|7)<<1)|0;b[s>>1]=(ba(ba(b[s>>1]|0,u)|0,fa)|0)+131072>>18;ka=99;break}}}while(0);if((ka|0)==99){if(!w){ha=1;break}}if(n){ga=x|8;fa=c[f+15992>>2]|0;u=f+16081|0;s=-z|0;$=1;while(1){o=ba(b[y+(ga+$<<1)>>1]|0,B)|0;V=o&65535;ca=g+($<<fa<<1)|0;b[ca>>1]=V;if(!((a[u]|0)!=0|V<<16>>16==0)){b[ca>>1]=(V<<16>>16<0?s:z)+o}o=$+1|0;if((o|0)<8){$=o}else{ha=63;break}}}else{$=c[f+15988>>2]|0;s=f+16081|0;u=-z|0;fa=1;while(1){ga=ba(b[y+(fa+x<<1)>>1]|0,B)|0;w=ga&65535;o=g+(fa<<$<<1)|0;b[o>>1]=w;if(!((a[s]|0)!=0|w<<16>>16==0)){b[o>>1]=(w<<16>>16<0?u:z)+ga}ga=fa+1|0;if((ga|0)<8){fa=ga}else{ha=63;break}}}}else{c[p>>2]=0;fa=f+19224|0;b:do{if((da|0)==0){if(n){u=1;while(1){v2a(f,p,q,r,l);s=(c[q>>2]|0)+u|0;if((s|0)>63){na=s;break b}$=c[r>>2]&65535;ga=s+1|0;if((c[fa>>2]|0)==0){b[g+(d[f+15730+s|0]<<1)>>1]=$}else{b[g+(d[f+19332+s|0]<<1)>>1]=$}if((c[p>>2]|0)==0){u=ga}else{na=ga;break}}}else{u=1;while(1){v2a(f,p,q,r,l);ga=(c[q>>2]|0)+u|0;if((ga|0)>63){na=ga;break b}$=c[r>>2]&65535;s=ga+1|0;if((c[fa>>2]|0)==0){b[g+(d[f+15730+ga|0]<<1)>>1]=$}else{b[g+(d[f+19332+ga|0]<<1)>>1]=$}if((c[p>>2]|0)==0){u=s}else{na=s;break}}}}else{u=1;while(1){v2a(f,p,q,r,l);s=(c[q>>2]|0)+u|0;if((s|0)>63){na=s;break b}$=c[fa>>2]|0;do{if(($|0)==0){b[g+(d[f+15730+s|0]<<1)>>1]=c[r>>2];oa=s+1|0}else if(($|0)==1){ga=c[r>>2]&65535;w=s+1|0;if(n){b[g+(d[f+15858+s|0]<<1)>>1]=ga;oa=w;break}else{b[g+(d[f+15922+s|0]<<1)>>1]=ga;oa=w;break}}else{b[g+(d[f+19332+s|0]<<1)>>1]=c[r>>2];oa=s+1|0}}while(0);if((c[p>>2]|0)==0){u=oa}else{na=oa;break}}}}while(0);fa=(da|0)!=0;do{if(fa){if((v|0)==0|(aa|0)==(v|0)){if(n){u=c[f+15992>>2]|0;s=g+(1<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+9<<1)>>1]|0);s=g+(2<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+10<<1)>>1]|0);s=g+(3<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+11<<1)>>1]|0);s=g+(4<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+12<<1)>>1]|0);s=g+(5<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+13<<1)>>1]|0);s=g+(6<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+14<<1)>>1]|0);s=g+(7<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+15<<1)>>1]|0);break}else{s=c[f+15988>>2]|0;u=g+(1<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+1<<1)>>1]|0);u=g+(2<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+2<<1)>>1]|0);u=g+(3<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+3<<1)>>1]|0);u=g+(4<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+4<<1)>>1]|0);u=g+(5<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+5<<1)>>1]|0);u=g+(6<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+6<<1)>>1]|0);u=g+(7<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+7<<1)>>1]|0);break}}u=d[f+15728|0]|0;if((aa|0)==(u|0)){pa=d[k]|0}else{pa=0}s=pa+(aa<<1)|0;if((v|0)==(u|0)){qa=d[k]|0}else{qa=0}u=(v<<1)-1+qa|0;if((s-1|0)<1){i=m;return}$=c[1098544+(s-2<<2)>>2]|0;if(n){s=c[f+15992>>2]|0;w=(ba(ba(b[y+(ea+9<<1)>>1]|0,u)|0,$)|0)+131072>>18;ga=g+(1<<s<<1)|0;b[ga>>1]=w+(e[ga>>1]|0);ga=(ba(ba(b[y+(ea+10<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(2<<s<<1)|0;b[w>>1]=ga+(e[w>>1]|0);w=(ba(ba(b[y+(ea+11<<1)>>1]|0,u)|0,$)|0)+131072>>18;ga=g+(3<<s<<1)|0;b[ga>>1]=w+(e[ga>>1]|0);ga=(ba(ba(b[y+(ea+12<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(4<<s<<1)|0;b[w>>1]=ga+(e[w>>1]|0);w=(ba(ba(b[y+(ea+13<<1)>>1]|0,u)|0,$)|0)+131072>>18;ga=g+(5<<s<<1)|0;b[ga>>1]=w+(e[ga>>1]|0);ga=(ba(ba(b[y+(ea+14<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(6<<s<<1)|0;b[w>>1]=ga+(e[w>>1]|0);w=(ba(ba(b[y+(ea+15<<1)>>1]|0,u)|0,$)|0)+131072>>18;ga=g+(7<<s<<1)|0;b[ga>>1]=w+(e[ga>>1]|0);break}else{ga=c[f+15988>>2]|0;w=(ba(ba(b[y+(ea+1<<1)>>1]|0,u)|0,$)|0)+131072>>18;s=g+(1<<ga<<1)|0;b[s>>1]=w+(e[s>>1]|0);s=(ba(ba(b[y+(ea+2<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(2<<ga<<1)|0;b[w>>1]=s+(e[w>>1]|0);w=(ba(ba(b[y+(ea+3<<1)>>1]|0,u)|0,$)|0)+131072>>18;s=g+(3<<ga<<1)|0;b[s>>1]=w+(e[s>>1]|0);s=(ba(ba(b[y+(ea+4<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(4<<ga<<1)|0;b[w>>1]=s+(e[w>>1]|0);w=(ba(ba(b[y+(ea+5<<1)>>1]|0,u)|0,$)|0)+131072>>18;s=g+(5<<ga<<1)|0;b[s>>1]=w+(e[s>>1]|0);s=(ba(ba(b[y+(ea+6<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(6<<ga<<1)|0;b[w>>1]=s+(e[w>>1]|0);w=(ba(ba(b[y+(ea+7<<1)>>1]|0,u)|0,$)|0)+131072>>18;$=g+(7<<ga<<1)|0;b[$>>1]=w+(e[$>>1]|0);break}}}while(0);$=c[f+15988>>2]|0;w=c[f+15992>>2]|0;b[y+((x|1)<<1)>>1]=b[g+(1<<$<<1)>>1]|0;b[y+((x|9)<<1)>>1]=b[g+(1<<w<<1)>>1]|0;b[y+((x|2)<<1)>>1]=b[g+(2<<$<<1)>>1]|0;b[y+((x|10)<<1)>>1]=b[g+(2<<w<<1)>>1]|0;b[y+((x|3)<<1)>>1]=b[g+(3<<$<<1)>>1]|0;b[y+((x|11)<<1)>>1]=b[g+(3<<w<<1)>>1]|0;b[y+((x|4)<<1)>>1]=b[g+(4<<$<<1)>>1]|0;b[y+((x|12)<<1)>>1]=b[g+(4<<w<<1)>>1]|0;b[y+((x|5)<<1)>>1]=b[g+(5<<$<<1)>>1]|0;b[y+((x|13)<<1)>>1]=b[g+(5<<w<<1)>>1]|0;b[y+((x|6)<<1)>>1]=b[g+(6<<$<<1)>>1]|0;b[y+((x|14)<<1)>>1]=b[g+(6<<w<<1)>>1]|0;b[y+((x|7)<<1)>>1]=b[g+(7<<$<<1)>>1]|0;b[y+((x|15)<<1)>>1]=b[g+(7<<w<<1)>>1]|0;w=f+16081|0;$=-z|0;ga=1;do{u=g+(ga<<1)|0;s=b[u>>1]|0;do{if(!(s<<16>>16==0)){o=ba(s<<16>>16,B)|0;V=o&65535;b[u>>1]=V;if((a[w]|0)!=0){break}b[u>>1]=(V<<16>>16<0?$:z)+o}}while(0);ga=ga+1|0;}while((ga|0)<64);ha=fa?63:na}}while(0);c[f+180+(h<<2)>>2]=ha;i=m;return}function u2a(e,f,g,h,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;p=i;i=i+24|0;q=p|0;r=p+8|0;s=p+16|0;t=e+14120|0;me[c[e+10092>>2]&511](f);u=(j|0)==-1;if(u){v=c[e+16088>>2]|0;w=c[5254516+(v*20|0)>>2]|0;x=e+14128|0;y=c[x>>2]|0;z=c[e+14136>>2]|0;A=(c[t>>2]|0)+(y>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7)>>>27;A=b[w+(B<<2)>>1]|0;C=(b[w+(B<<2)+2>>1]|0)+y|0;c[x>>2]=z>>>0>C>>>0?C:z;D=c[1094568+(v<<5)+(A<<2)>>2]|0}else{D=j&7}a:do{if((D|0)==0){E=0;F=0}else if((D|0)==7){A=c[5254580+((c[e+16088>>2]|0)*20|0)>>2]|0;v=e+14128|0;z=c[v>>2]|0;C=c[e+14136>>2]|0;x=(c[t>>2]|0)+(z>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7)>>>26;x=b[A+(y<<2)>>1]|0;B=(b[A+(y<<2)+2>>1]|0)+z|0;c[v>>2]=C>>>0>B>>>0?B:C;E=7;F=-2-x|0}else{do{if((a[e+16020|0]|0)==0){if((k|0)==0&((u|(j&8|0)==0)^1)){break}if((c[e+15608>>2]|k|0)!=0){E=D;F=0;break a}}}while(0);x=e+14128|0;C=c[x>>2]|0;B=c[t>>2]|0;v=d[B+(C>>>3)|0]|0;z=c[e+14136>>2]|0;y=((C|0)<(z|0))+C|0;c[x>>2]=y;if((v&128>>>((C&7)>>>0)|0)==0){G=0}else{C=d[B+(y>>>3)|0]<<(y&7)>>>7;c[x>>2]=((y|0)<(z|0))+y;G=(C&1)+1|0}C=(D-1|0)>>>0<2>>>0?3:D;E=(C-4|0)>>>0<2>>>0?6:C;F=(G|0)==0?0:G^3}}while(0);if((d[e+15728|0]|0)==(h|0)){H=d[e+16072|0]|0}else{H=0}G=H+(h<<1)|0;b:do{if((E-1|0)>>>0<2>>>0){I=2-((E|0)==2)|0;J=41}else{do{if((E-4|0)>>>0<2>>>0){K=2-((E|0)==5)|0}else{if((E|0)==7){H=F&15;D=e+16036|0;t=e+15360|0;k=m<<1;j=e+15344|0;u=e+19224|0;C=e+16081|0;y=-h|0;z=0;do{x=1<<3-z&F;c[q>>2]=x;B=z<<2&4;v=z&2;A=B|v<<4;c:do{if((x|0)==0){w=0;while(1){v2a(e,q,r,s,c[D>>2]|0);L=(c[r>>2]|0)+w|0;if((L|0)>15){M=L;break c}N=L+1|0;O=ba(c[s>>2]|0,G)|0;P=O&65535;Q=f+((d[((c[u>>2]|0)==0?1094808:1100096)+L|0]|0)+A<<1)|0;b[Q>>1]=P;if((a[C]|0)==0){b[Q>>1]=(P<<16>>16<0?y:h)+O}if((c[q>>2]|0)==0){w=N}else{M=N;break}}}else{M=0}}while(0);do{if((x|n|0)==0){if((M|0)==1){w=l+(B+(ba(k,v)|0))|0;Xe[c[t>>2]&4095](w,m,f+(A<<1)|0);break}else{w=l+(B+(ba(k,v)|0))|0;Xe[c[j>>2]&4095](w,m,f+(A<<1)|0);break}}}while(0);z=z+1|0;}while((z|0)<4);R=H^15;S=7;break b}else if((E|0)==6){K=F;break}else if((E|0)==3){I=F;J=41;break b}else if((E|0)==0){c[q>>2]=0;z=e+16036|0;j=e+19224|0;k=e+16081|0;t=-h|0;y=0;while(1){v2a(e,q,r,s,c[z>>2]|0);C=(c[r>>2]|0)+y|0;if((C|0)>63){T=C;break}u=C+1|0;if((c[j>>2]|0)==0){U=e+15730+C|0}else{U=e+19332+C|0}C=ba(c[s>>2]|0,G)|0;D=C&65535;A=f+(d[U]<<1)|0;b[A>>1]=D;if((a[k]|0)==0){b[A>>1]=(D<<16>>16<0?t:h)+C}if((c[q>>2]|0)==0){y=u}else{T=u;break}}if((n|0)!=0){R=15;S=0;break b}if((T|0)==1){Xe[c[e+15348>>2]&4095](l,m,f);R=15;S=0;break b}else{me[c[e+15332>>2]&511](f);Xe[c[e+10072>>2]&4095](f,l,m);R=15;S=0;break b}}else{R=0;S=E;break b}}}while(0);y=(K*5|0)&15;t=e+16036|0;k=e+15356|0;j=e+15340|0;z=e+19224|0;H=e+16e3|0;u=e+16081|0;C=-h|0;D=K&2;c[q>>2]=D;d:do{if((D|0)==0){A=0;while(1){v2a(e,q,r,s,c[t>>2]|0);v=(c[r>>2]|0)+A|0;if((v|0)>31){V=v;break d}B=v+1|0;if((c[z>>2]|0)==0){W=(c[H>>2]|0)+v|0}else{W=1100064+v|0}v=ba(c[s>>2]|0,G)|0;x=v&65535;w=f+(d[W]<<1)|0;b[w>>1]=x;if((a[u]|0)==0){b[w>>1]=(x<<16>>16<0?C:h)+v}if((c[q>>2]|0)==0){A=B}else{V=B;break}}}else{V=0}}while(0);do{if((D|n|0)==0){if((V|0)==1){Xe[c[k>>2]&4095](l,m,f);break}else{Xe[c[j>>2]&4095](l,m,f);break}}}while(0);D=K&1;c[q>>2]=D;e:do{if((D|0)==0){A=0;while(1){v2a(e,q,r,s,c[t>>2]|0);B=(c[r>>2]|0)+A|0;if((B|0)>31){X=B;break e}v=B+1|0;if((c[z>>2]|0)==0){Y=(c[H>>2]|0)+B|0}else{Y=1100064+B|0}B=ba(c[s>>2]|0,G)|0;x=B&65535;w=f+((d[Y]|0)+4<<1)|0;b[w>>1]=x;if((a[u]|0)==0){b[w>>1]=(x<<16>>16<0?C:h)+B}if((c[q>>2]|0)==0){A=v}else{X=v;break}}}else{X=0}}while(0);do{if((D|n|0)==0){if((X|0)==1){Xe[c[k>>2]&4095](l+4|0,m,f+8|0);break}else{Xe[c[j>>2]&4095](l+4|0,m,f+8|0);break}}}while(0);R=y^15;S=6}}while(0);if((J|0)==41){J=((I&2)*6|0)&12|-(I&1)&3;X=e+16036|0;Y=e+15352|0;K=m<<2;V=e+15336|0;W=e+19224|0;E=e+15996|0;T=e+16081|0;U=-h|0;F=0;do{M=1<<1-F&I;c[q>>2]=M;j=F<<5;f:do{if((M|0)==0){k=0;while(1){v2a(e,q,r,s,c[X>>2]|0);D=(c[r>>2]|0)+k|0;if((D|0)>31){Z=D;break f}C=D+1|0;if((c[W>>2]|0)==0){_=(c[E>>2]|0)+D|0}else{_=1100032+D|0}D=ba(c[s>>2]|0,G)|0;u=D&65535;H=f+((d[_]|0)+j<<1)|0;b[H>>1]=u;if((a[T]|0)==0){b[H>>1]=(u<<16>>16<0?U:h)+D}if((c[q>>2]|0)==0){k=C}else{Z=C;break}}}else{Z=0}}while(0);do{if((M|n|0)==0){if((Z|0)==1){y=l+(ba(K,F)|0)|0;Xe[c[Y>>2]&4095](y,m,f+(j<<1)|0);break}else{y=l+(ba(K,F)|0)|0;Xe[c[V>>2]&4095](y,m,f+(j<<1)|0);break}}}while(0);F=F+1|0;}while((F|0)<2);R=J^15;S=3}if((o|0)==0){i=p;return R|0}c[o>>2]=c[o>>2]|S<<(g<<2);i=p;return R|0}function v2a(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=c[5387860+(i*20|0)>>2]|0;k=e+14128|0;l=c[k>>2]|0;m=c[e+14136>>2]|0;n=c[e+14120>>2]|0;o=n+(l>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>23;o=b[j+(p<<2)>>1]|0;q=b[j+(p<<2)+2>>1]|0;p=q<<16>>16;do{if(q<<16>>16<0){r=l+9|0;s=m>>>0>r>>>0?r:m;r=n+(s>>>3)|0;t=((fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((p+32|0)>>>0))+o|0;r=b[j+(t<<2)>>1]|0;u=b[j+(t<<2)+2>>1]|0;t=u<<16>>16;if(!(u<<16>>16<0)){v=t;w=r;x=s;break}u=s-p|0;s=m>>>0>u>>>0?u:m;u=n+(s>>>3)|0;y=((fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(s&7)>>>((t+32|0)>>>0))+r|0;v=b[j+(y<<2)+2>>1]|0;w=b[j+(y<<2)>>1]|0;x=s}else{v=p;w=o;x=l}}while(0);l=v+x|0;x=m>>>0>l>>>0?l:m;c[k>>2]=x;if((w|0)!=((c[1100112+(i<<2)>>2]|0)-1|0)){l=d[143736+(i*370|0)+(w<<1)|0]|0;v=d[143736+(i*370|0)+(w<<1)+1|0]|0;if((w|0)<(c[143704+(i<<2)>>2]|0)){z=((c[e+14132>>2]|0)-x|0)>>>31}else{z=1}w=d[n+(x>>>3)|0]|0;c[k>>2]=((x|0)<(m|0))+x;A=z;B=(w&128>>>((x&7)>>>0)|0)==0?v:-v|0;C=l;c[f>>2]=A;c[g>>2]=C;c[h>>2]=B;return}l=d[n+(x>>>3)|0]|0;v=((x|0)<(m|0))+x|0;c[k>>2]=v;do{if((l&128>>>((x&7)>>>0)|0)==0){w=d[n+(v>>>3)|0]<<(v&7)>>>7;z=((v|0)<(m|0))+v|0;c[k>>2]=z;o=w&1;if((o|0)!=0){D=2-o|0;E=z;break}o=d[n+(z>>>3)|0]<<(z&7)>>>7;w=((z|0)<(m|0))+z|0;c[k>>2]=w;z=o&1;o=e+14100|0;p=c[o>>2]|0;if((p|0)==0){do{if((d[e+15728|0]|0)>>>0<8>>>0){F=26}else{if((a[e+16004|0]|0)==0){G=0;H=w}else{F=26;break}while(1){if((G|0)>=6){I=H;break}q=d[n+(H>>>3)|0]|0;s=((H|0)<(m|0))+H|0;c[k>>2]=s;if((q&128>>>((H&7)>>>0)|0)==0){G=G+1|0;H=s}else{I=s;break}}s=G+2|0;c[o>>2]=s;J=I;K=s}}while(0);do{if((F|0)==26){s=n+(w>>>3)|0;q=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7)>>>29;s=w+3|0;y=m>>>0>s>>>0?s:m;c[k>>2]=y;c[o>>2]=q;if((q|0)!=0){J=y;K=q;break}q=n+(y>>>3)|0;s=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(y&7)>>>30;q=y+2|0;y=m>>>0>q>>>0?q:m;c[k>>2]=y;q=s|8;c[o>>2]=q;J=y;K=q}}while(0);o=n+(J>>>3)|0;q=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(J&7)>>>30;o=J+2|0;y=m>>>0>o>>>0?o:m;c[k>>2]=y;o=q+3|0;c[e+14104>>2]=o;L=y;M=K;N=o}else{L=w;M=p;N=c[e+14104>>2]|0}o=n+(L>>>3)|0;y=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(L&7)>>>((32-N|0)>>>0);o=L+N|0;q=m>>>0>o>>>0?o:m;c[k>>2]=q;o=d[n+(q>>>3)|0]|0;s=((q|0)<(m|0))+q|0;c[k>>2]=s;r=n+(s>>>3)|0;t=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((32-M|0)>>>0);r=s+M|0;c[k>>2]=m>>>0>r>>>0?r:m;A=z;B=(o&128>>>((q&7)>>>0)|0)==0?t:-t|0;C=y;c[f>>2]=A;c[g>>2]=C;c[h>>2]=B;return}else{D=0;E=v}}while(0);v=n+(E>>>3)|0;M=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(E&7)>>>23;v=b[j+(M<<2)>>1]|0;N=b[j+(M<<2)+2>>1]|0;M=N<<16>>16;do{if(N<<16>>16<0){L=E+9|0;e=m>>>0>L>>>0?L:m;L=n+(e>>>3)|0;K=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(e&7)>>>((M+32|0)>>>0))+v|0;L=b[j+(K<<2)>>1]|0;J=b[j+(K<<2)+2>>1]|0;K=J<<16>>16;if(!(J<<16>>16<0)){O=K;P=L;Q=e;break}J=e-M|0;e=m>>>0>J>>>0?J:m;J=n+(e>>>3)|0;F=((fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(e&7)>>>((K+32|0)>>>0))+L|0;O=b[j+(F<<2)+2>>1]|0;P=b[j+(F<<2)>>1]|0;Q=e}else{O=M;P=v;Q=E}}while(0);E=O+Q|0;Q=m>>>0>E>>>0?E:m;c[k>>2]=Q;E=d[143736+(i*370|0)+(P<<1)|0]|0;O=d[143736+(i*370|0)+(P<<1)+1|0]|0;v=(P|0)>=(c[143704+(i<<2)>>2]|0);P=v&1;do{if((D|0)==0){if(v){R=(d[143352+(i*44|0)+E|0]|0)+O|0;S=E;break}else{R=(d[147288+(i*31|0)+E|0]|0)+O|0;S=E;break}}else{if(v){R=O;S=E+1+(d[143272+(i*10|0)+O|0]|0)|0;break}else{R=O;S=E+1+(d[146832+(i*57|0)+O|0]|0)|0;break}}}while(0);O=d[n+(Q>>>3)|0]|0;c[k>>2]=((Q|0)<(m|0))+Q;if((O&128>>>((Q&7)>>>0)|0)==0){A=P;B=R;C=S;c[f>>2]=A;c[g>>2]=C;c[h>>2]=B;return}A=P;B=-R|0;C=S;c[f>>2]=A;c[g>>2]=C;c[h>>2]=B;return}function w2a(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=c[e+124>>2]|0;l=(ba(k,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;m=c[e+12520+(f<<2)>>2]|0;n=c[e+9876>>2]|0;o=c[e+12496+(f<<2)>>2]|0;p=n+(o<<1)|0;q=b[n+(o-1<<1)>>1]|0;r=b[n+(o+~m<<1)>>1]|0;s=b[n+(o-m<<1)>>1]|0;m=c[e+9136>>2]|0;o=a[m+l|0]|0;n=c[e+9888>>2]|0;e=(d[n+(o<<24>>24)|0]|0)-1|0;if((e|0)<0){t=0;return t|0}u=(h|0)!=0;do{if(u){if((f|0)==3|(f|0)==1){v=q;break}h=a[m+(l-1)|0]|0;if(h<<24>>24==0|h<<24>>24==o<<24>>24){v=q;break}w=ba(d[n+(h<<24>>24)|0]|0,q)|0;v=(ba(w,c[1098544+(e<<2)>>2]|0)|0)+131072>>18}else{v=q}}while(0);do{if((g|0)==0){c[j>>2]=1;x=u?v:0}else{do{if((f-2|0)>>>0>1>>>0){q=a[m+(l-k)|0]|0;if(q<<24>>24==0|q<<24>>24==o<<24>>24){y=s;break}w=ba(d[n+(q<<24>>24)|0]|0,s)|0;y=(ba(w,c[1098544+(e<<2)>>2]|0)|0)+131072>>18}else{y=s}}while(0);do{if((f|0)==3|u^1){z=13}else{w=a[m+(l+(((f|0)!=1)<<31>>31)-((f|0)==2?0:k))|0]|0;if(w<<24>>24==0|w<<24>>24==o<<24>>24){z=13;break}q=ba(d[n+(w<<24>>24)|0]|0,r)|0;w=(ba(q,c[1098544+(e<<2)>>2]|0)|0)+131072>>18;if(u){A=w}else{z=17}}}while(0);if((z|0)==13){if(u){A=r}else{z=17}}if((z|0)==17){c[j>>2]=0;x=y;break}w=y-A|0;q=A-v|0;if((((w|0)>-1?w:-w|0)|0)>(((q|0)>-1?q:-q|0)|0)){c[j>>2]=0;x=y;break}else{c[j>>2]=1;x=v;break}}}while(0);c[i>>2]=p;t=x;return t|0}function x2a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;g=i;h=e+19428|0;j=c[h>>2]|0;k=c[e+140>>2]>>j;l=(j|0)==0;do{if(l){m=4}else{if((c[e+19460+(f<<2)>>2]|0)!=1){break}if((c[e+19456>>2]|0)==1){m=4}}}while(0);do{if((m|0)==4){if((c[e+952>>2]|0)!=0){break}i=g;return}}while(0);j=c[e+11744+(f<<5)>>2]|0;n=c[e+11744+(f<<5)+4>>2]|0;if((c[e+9992>>2]|0)==2){o=j&65535;p=c[e+19468>>2]|0;q=c[e+9152>>2]|0;r=n&65535;s=p+(c[e+12496>>2]|0)|0;b[q+(s<<2)>>1]=o;b[q+(s<<2)+2>>1]=r;s=p+(c[e+12500>>2]|0)|0;b[q+(s<<2)>>1]=o;b[q+(s<<2)+2>>1]=r;s=p+(c[e+12504>>2]|0)|0;b[q+(s<<2)>>1]=o;b[q+(s<<2)+2>>1]=r;s=p+(c[e+12508>>2]|0)|0;b[q+(s<<2)>>1]=o;b[q+(s<<2)+2>>1]=r}r=j&3;s=((r|0)==3)+j>>1;q=((n&3|0)==3)+n>>1;o=c[e+12476>>2]|0;p=c[e+19600>>2]|0;b[p+(o<<2)>>1]=s;b[p+(o<<2)+2>>1]=q;do{if(l){t=q;u=n}else{p=c[e+19456>>2]|0;if((p|0)==(c[e+19460+(f<<2)>>2]|0)){t=q;u=n;break}v=p<<2;t=q-2+v|0;u=n-2+v|0}}while(0);do{if((c[e+15680>>2]|0)==0){w=t;x=s}else{if((c[e+19224>>2]|0)==1){w=t;x=s;break}n=s&1;q=t&1;w=((t|0)<0?q:-q|0)+t|0;x=((s|0)<0?n:-n|0)+s|0}}while(0);a:do{if((f|0)==0){do{if(!l){if((c[e+19456>>2]|0)==(c[e+19460>>2]|0)){break}if((c[e+19436>>2]|0)==0){break}y=e+7624|0;z=e+7628|0;A=e+7632|0;B=c[e+19204>>2]|0;C=c[e+19196>>2]|0;D=c[e+19192>>2]|0;break a}}while(0);y=e+952|0;z=e+956|0;A=e+960|0;B=e+19200|0;C=e+16632|0;D=e+16120|0}else{y=e+3176|0;z=e+3180|0;A=e+3184|0;B=e+19208|0;C=e+18680|0;D=e+18168|0}}while(0);s=c[y>>2]|0;y=c[z>>2]|0;z=c[A>>2]|0;A=c[B>>2]|0;if((s|0)==0|(y|0)==0){yDb(c[e+4>>2]|0,16,2017248,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;i=g;return}B=(o<<4)+(j>>2)|0;t=c[e+12480>>2]|0;n=(t<<4)+(u>>2)|0;q=(o<<3)+(x>>2)|0;o=(t<<3)+(w>>2)|0;if((c[e+15660>>2]|0)==3){t=c[e+4>>2]|0;v=c[t+128>>2]|0;if((B|0)<-17){E=-17}else{E=(B|0)>(v|0)?v:B}p=c[t+132>>2]|0;t=p+1|0;if((n|0)<-18){F=-18}else{F=(n|0)>(t|0)?t:n}t=v>>1;if((q|0)<-8){G=-8}else{G=(q|0)>(t|0)?t:q}H=G;I=F;J=E;K=p>>1}else{p=c[e+116>>2]|0;E=p<<4;if((B|0)<-16){L=-16}else{L=(B|0)>(E|0)?E:B}B=c[e+120>>2]|0;E=B<<4;if((n|0)<-16){M=-16}else{M=(n|0)>(E|0)?E:n}n=p<<3;if((q|0)<-8){N=-8}else{N=(q|0)>(n|0)?n:q}H=N;I=M;J=L;K=B<<3}if((o|0)<-8){O=-8}else{O=(o|0)>(K|0)?K:o}o=e+148|0;K=c[o>>2]|0;B=(ba(K,I)|0)+J|0;L=s+B|0;M=e+152|0;N=(ba(c[M>>2]|0,O)|0)+H|0;q=y+N|0;n=z+N|0;do{if(l){P=L;Q=q;R=n}else{if((c[e+19460+(f<<2)>>2]|0)==0){P=L;Q=q;R=n;break}p=c[e+9856>>2]|0;P=s+((c[p+32>>2]|0)+B)|0;Q=y+((c[p+36>>2]|0)+N)|0;R=z+((c[p+40>>2]|0)+N)|0}}while(0);N=e+60|0;if((c[N>>2]&8192|0)==0){S=Q;T=R}else{R=(c[e+9944>>2]|0)+(K*18|0)|0;S=R;T=R}R=e+19220|0;Q=(A|0)==0;A=c[e+136>>2]|0;do{if((a[R]|0)==0&Q){if((A|0)<22|(k|0)<22){m=48;break}z=c[e+14116>>2]|0;if((J-z|0)>>>0>(-16-r+A+(z*-3|0)|0)>>>0){m=48;break}if((I-1|0)>>>0>(k-19-(u&3)|0)>>>0){m=48}else{U=P;V=S;W=T;X=z;Y=K}}else{m=48}}while(0);if((m|0)==48){m=e+9944|0;z=c[m>>2]|0;y=K*19|0;B=z+y|0;s=e+14116|0;n=c[s>>2]|0;q=P+(ba(n,~K)|0)|0;P=e+11540|0;L=(n<<1)+17|0;l=e+136|0;Ne[c[P>>2]&127](z,q,K,K,L,L,J-n|0,I-n|0,A,k);A=c[m>>2]|0;m=c[M>>2]|0;n=k>>1;Ne[c[P>>2]&127](B,S,m,m,9,9,H,O,c[l>>2]>>1,n);m=z+(y+16)|0;y=c[M>>2]|0;Ne[c[P>>2]&127](m,T,y,y,9,9,H,O,c[l>>2]>>1,n);if((a[R]|0)!=0){R=c[s>>2]|0;if(((R<<1)+17|0)>0){n=0;l=A;H=R;while(1){if(((H<<1)+17|0)>0){R=0;while(1){y=l+R|0;a[y]=(((d[y]|0)+384|0)>>>1)+128;y=R+1|0;T=c[s>>2]|0;if((y|0)<((T<<1)+17|0)){R=y}else{Z=T;break}}}else{Z=H}R=n+1|0;if((R|0)<((Z<<1)+17|0)){n=R;l=l+(c[o>>2]|0)|0;H=Z}else{_=0;$=B;aa=m;break}}}else{_=0;$=B;aa=m}while(1){Z=0;do{H=$+Z|0;a[H]=(((d[H]|0)+384|0)>>>1)+128;H=aa+Z|0;a[H]=(((d[H]|0)+384|0)>>>1)+128;Z=Z+1|0;}while((Z|0)<9);Z=c[M>>2]|0;H=_+1|0;if((H|0)<9){_=H;$=$+Z|0;aa=aa+Z|0}else{break}}}b:do{if(!Q){aa=c[s>>2]|0;$=e+19460+(f<<2)|0;c:do{if(((aa<<1)+17|0)>0){_=0;Z=A;H=aa;while(1){if((c[h>>2]|0)==0){ca=_+I-H&1}else{ca=c[$>>2]|0}if(((H<<1)+17|0)>0){l=0;while(1){n=Z+l|0;a[n]=a[(d[n]|0)+(D+(ca<<8))|0]|0;n=l+1|0;R=c[s>>2]|0;if((n|0)<((R<<1)+17|0)){l=n}else{da=R;break}}}else{da=H}l=_+1|0;if((l|0)>=((da<<1)+17|0)){break c}_=l;Z=Z+(c[o>>2]|0)|0;H=da}}}while(0);aa=0;H=B;Z=m;while(1){if((c[h>>2]|0)==0){ea=aa+O&1}else{ea=c[$>>2]|0}a[H]=a[(d[H]|0)+(C+(ea<<8))|0]|0;a[Z]=a[(d[Z]|0)+(C+(ea<<8))|0]|0;_=H+1|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+1|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+2|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+2|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+3|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+3|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+4|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+4|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+5|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+5|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+6|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+6|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+7|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+7|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+8|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+8|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=c[M>>2]|0;l=aa+1|0;if((l|0)>=9){break b}aa=l;H=H+_|0;Z=Z+_|0}}}while(0);ea=c[s>>2]|0;s=c[o>>2]|0;U=A+(ba(s+1|0,ea)|0)|0;V=B;W=m;X=ea;Y=s}do{if((X|0)==0){s=u&2|j>>>1&1;if((c[e+19216>>2]|0)==0){cf[c[e+11332+(s<<2)>>2]&1023](c[e+12544>>2]|0,U,Y,16);break}else{cf[c[e+11460+(s<<2)>>2]&1023](c[e+12544>>2]|0,U,Y,16);break}}else{s=e+15404+((u<<2&12|r)<<2)|0;ea=e+12544|0;m=e+19216|0;cf[c[s>>2]&1023](c[ea>>2]|0,U,Y,c[m>>2]|0);cf[c[s>>2]&1023]((c[ea>>2]|0)+8|0,U+8|0,c[o>>2]|0,c[m>>2]|0);B=c[o>>2]|0;A=B<<3;cf[c[s>>2]&1023]((c[ea>>2]|0)+A|0,U+A|0,B,c[m>>2]|0);B=c[o>>2]|0;cf[c[s>>2]&1023]((c[ea>>2]|0)+((B<<3)+8)|0,U+(A+8)|0,B,c[m>>2]|0)}}while(0);if((c[N>>2]&8192|0)!=0){i=g;return}N=x<<1&6;x=w<<1&6;if((c[e+19216>>2]|0)==0){w=e+15300|0;Se[c[w>>2]&511](c[e+12548>>2]|0,V,c[M>>2]|0,8,N,x);Se[c[w>>2]&511](c[e+12552>>2]|0,W,c[M>>2]|0,8,N,x);i=g;return}else{w=e+15532|0;Se[c[w>>2]&511](c[e+12548>>2]|0,V,c[M>>2]|0,8,N,x);Se[c[w>>2]&511](c[e+12552>>2]|0,W,c[M>>2]|0,8,N,x);i=g;return}}function y2a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=b+19428|0;f=c[e>>2]|0;g=c[b+140>>2]>>f;h=c[b+19208>>2]|0;i=(f|0)==0;do{if(i){if((c[b+3176>>2]|0)!=0){break}return}}while(0);f=c[b+11776>>2]|0;j=c[b+11780>>2]|0;k=f&3;l=((k|0)==3)+f>>1;m=((j&3|0)==3)+j>>1;if(i){n=j;o=m}else{p=c[b+19456>>2]|0;if((p|0)==(c[b+19464>>2]|0)){q=j;r=p<<2}else{s=p<<2;q=j-2+s|0;r=s}n=q;o=m-2+r|0}if((c[b+15680>>2]|0)==0){t=l;u=o}else{r=l&1;m=o&1;t=((l|0)<0?-r|0:r)+l|0;u=((o|0)<0?-m|0:m)+o|0}o=c[b+3176>>2]|0;m=c[b+3180>>2]|0;l=c[b+3184>>2]|0;r=c[b+12476>>2]|0;q=(r<<4)+(f>>2)|0;s=c[b+12480>>2]|0;j=(s<<4)+(n>>2)|0;p=(r<<3)+(t>>2)|0;r=(s<<3)+(u>>2)|0;if((c[b+15660>>2]|0)==3){s=c[b+4>>2]|0;v=c[s+128>>2]|0;if((q|0)<-17){w=-17}else{w=(q|0)>(v|0)?v:q}x=c[s+132>>2]|0;s=x+1|0;if((j|0)<-18){y=-18}else{y=(j|0)>(s|0)?s:j}s=v>>1;if((p|0)<-8){z=-8}else{z=(p|0)>(s|0)?s:p}A=w;B=y;C=z;D=x>>1}else{x=c[b+116>>2]|0;z=x<<4;if((q|0)<-16){E=-16}else{E=(q|0)>(z|0)?z:q}q=c[b+120>>2]|0;z=q<<4;if((j|0)<-16){F=-16}else{F=(j|0)>(z|0)?z:j}j=x<<3;if((p|0)<-8){G=-8}else{G=(p|0)>(j|0)?j:p}A=E;B=F;C=G;D=q<<3}if((r|0)<-8){H=-8}else{H=(r|0)>(D|0)?D:r}r=b+148|0;D=c[r>>2]|0;q=(ba(D,B)|0)+A|0;G=o+q|0;F=b+152|0;E=(ba(c[F>>2]|0,H)|0)+C|0;p=m+E|0;j=l+E|0;do{if(i){I=G;J=p;K=j}else{if((c[b+19464>>2]|0)==0){I=G;J=p;K=j;break}x=c[b+9856>>2]|0;I=o+((c[x+32>>2]|0)+q)|0;J=m+((c[x+36>>2]|0)+E)|0;K=l+((c[x+40>>2]|0)+E)|0}}while(0);E=b+60|0;if((c[E>>2]&8192|0)==0){L=J;M=K}else{K=(c[b+9944>>2]|0)+(D*18|0)|0;L=K;M=K}K=b+19220|0;J=c[b+136>>2]|0;do{if((a[K]|0)==0){if(!((g|0)>21&(J|0)>21&(h|0)==0)){N=37;break}if((A-1|0)>>>0>(-19-k+J|0)>>>0){N=37;break}if((B-1|0)>>>0>(g-19-(n&3)|0)>>>0){N=37;break}O=I;P=L;Q=M;R=D;S=c[b+14116>>2]|0}else{N=37}}while(0);if((N|0)==37){N=b+9944|0;l=c[N>>2]|0;m=D*19|0;q=l+m|0;o=b+14116|0;j=c[o>>2]|0;p=I+(ba(j,~D)|0)|0;I=b+11540|0;G=(j<<1)+17|0;i=b+136|0;Ne[c[I>>2]&127](l,p,D,D,G,G,A-j|0,B-j|0,J,g);J=c[N>>2]|0;N=c[F>>2]|0;j=g>>1;Ne[c[I>>2]&127](q,L,N,N,9,9,C,H,c[i>>2]>>1,j);N=l+(m+16)|0;m=c[F>>2]|0;Ne[c[I>>2]&127](N,M,m,m,9,9,C,H,c[i>>2]>>1,j);if((a[K]|0)!=0){K=c[o>>2]|0;if(((K<<1)+17|0)>0){j=0;i=J;C=K;while(1){if(((C<<1)+17|0)>0){K=0;while(1){m=i+K|0;a[m]=(((d[m]|0)+384|0)>>>1)+128;m=K+1|0;M=c[o>>2]|0;if((m|0)<((M<<1)+17|0)){K=m}else{T=M;break}}}else{T=C}K=j+1|0;if((K|0)<((T<<1)+17|0)){j=K;i=i+(c[r>>2]|0)|0;C=T}else{U=0;V=q;W=N;break}}}else{U=0;V=q;W=N}while(1){T=0;do{C=V+T|0;a[C]=(((d[C]|0)+384|0)>>>1)+128;C=W+T|0;a[C]=(((d[C]|0)+384|0)>>>1)+128;T=T+1|0;}while((T|0)<9);T=c[F>>2]|0;C=U+1|0;if((C|0)<9){U=C;V=V+T|0;W=W+T|0}else{break}}}a:do{if((h|0)!=0){W=c[o>>2]|0;V=b+19464|0;b:do{if(((W<<1)+17|0)>0){U=0;T=J;C=W;while(1){if((c[e>>2]|0)==0){X=U+B-C&1}else{X=c[V>>2]|0}if(((C<<1)+17|0)>0){i=0;while(1){j=T+i|0;a[j]=a[(d[j]|0)+(b+18168+(X<<8))|0]|0;j=i+1|0;K=c[o>>2]|0;if((j|0)<((K<<1)+17|0)){i=j}else{Y=K;break}}}else{Y=C}i=U+1|0;if((i|0)>=((Y<<1)+17|0)){break b}U=i;T=T+(c[r>>2]|0)|0;C=Y}}}while(0);W=0;C=q;T=N;while(1){if((c[e>>2]|0)==0){Z=W+H&1}else{Z=c[V>>2]|0}a[C]=a[(d[C]|0)+(b+18680+(Z<<8))|0]|0;a[T]=a[(d[T]|0)+(b+18680+(Z<<8))|0]|0;U=C+1|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+1|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+2|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+2|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+3|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+3|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+4|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+4|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+5|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+5|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+6|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+6|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+7|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+7|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+8|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+8|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=c[F>>2]|0;i=W+1|0;if((i|0)>=9){break a}W=i;C=C+U|0;T=T+U|0}}}while(0);Z=c[o>>2]|0;o=c[r>>2]|0;O=J+(ba(o+1|0,Z)|0)|0;P=q;Q=N;R=o;S=Z}do{if((S|0)==0){Z=n&2|f>>>1&1;if((c[b+19216>>2]|0)==0){cf[c[b+11396+(Z<<2)>>2]&1023](c[b+12544>>2]|0,O,R,16);break}else{cf[c[b+11524+(Z<<2)>>2]&1023](c[b+12544>>2]|0,O,R,16);break}}else{Z=b+15468+((n<<2&12|k)<<2)|0;o=b+12544|0;N=b+19216|0;cf[c[Z>>2]&1023](c[o>>2]|0,O,R,c[N>>2]|0);cf[c[Z>>2]&1023]((c[o>>2]|0)+8|0,O+8|0,c[r>>2]|0,c[N>>2]|0);q=c[r>>2]|0;J=q<<3;cf[c[Z>>2]&1023]((c[o>>2]|0)+J|0,O+J|0,q,c[N>>2]|0);q=c[r>>2]|0;cf[c[Z>>2]&1023]((c[o>>2]|0)+((q<<3)+8)|0,O+(J+8)|0,q,c[N>>2]|0)}}while(0);if((c[E>>2]&8192|0)!=0){return}E=t<<1&6;t=u<<1&6;if((c[b+19216>>2]|0)==0){u=b+15316|0;Se[c[u>>2]&511](c[b+12548>>2]|0,P,c[F>>2]|0,8,E,t);Se[c[u>>2]&511](c[b+12552>>2]|0,Q,c[F>>2]|0,8,E,t);return}else{u=b+15544|0;Se[c[u>>2]&511](c[b+12548>>2]|0,P,c[F>>2]|0,8,E,t);Se[c[u>>2]&511](c[b+12552>>2]|0,Q,c[F>>2]|0,8,E,t);return}}function z2a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;j=i;i=i+64|0;k=j|0;l=e+19224|0;m=c[l>>2]|0;if((m|0)==1){n=d[(c[e+19400>>2]|0)+(c[e+12496+(f<<2)>>2]|0)|0]|0}else{n=0}o=e+19428|0;p=c[o>>2]|0;q=c[e+140>>2]>>p;r=(p|0)==0;do{if(r){s=6}else{if((c[e+19460+(g<<2)>>2]|0)!=1){break}if((c[e+19456>>2]|0)==1){s=6}}}while(0);do{if((s|0)==6){if((c[e+952>>2]|0)!=0){break}i=j;return}}while(0);p=c[e+11744+(g<<5)+(f<<3)>>2]|0;t=c[e+11744+(g<<5)+(f<<3)+4>>2]|0;a:do{if((g|0)==0){do{if(!r){if((c[e+19456>>2]|0)==(c[e+19460>>2]|0)){break}if((c[e+19436>>2]|0)==0){break}u=e+7624|0;v=c[e+19204>>2]|0;w=c[e+19192>>2]|0;break a}}while(0);u=e+952|0;v=e+19200|0;w=e+16120|0}else{u=e+3176|0;v=e+19208|0;w=e+18168|0}}while(0);x=c[u>>2]|0;u=c[v>>2]|0;if((x|0)==0){yDb(c[e+4>>2]|0,16,2017248,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;i=j;return}do{if(r){z=t}else{v=c[e+19456>>2]|0;if((v|0)==(c[e+19460+(g<<2)>>2]|0)){z=t;break}z=t-2+(v<<2)|0}}while(0);t=e+9992|0;if((f|0)!=3|(c[t>>2]|0)!=2|r){A=m}else{m=e+19468|0;r=c[m>>2]|0;v=c[e+19408>>2]|0;B=r+(c[e+12496>>2]|0)|0;C=d[v+B|0]|0;c[k+(C<<5)>>2]=c[e+11744>>2];c[k+(C<<5)+4>>2]=c[e+11748>>2];D=1-C|0;E=e+12500|0;F=a[v+(r+(c[E>>2]|0))|0]|0;G=F&255;H=F<<24>>24!=0?C:D;c[k+(G<<5)+(H<<3)>>2]=c[e+11752>>2];c[k+(G<<5)+(H<<3)+4>>2]=c[e+11756>>2];H=G+C|0;C=D+1-G|0;G=e+12504|0;D=a[v+(r+(c[G>>2]|0))|0]|0;F=D&255;I=D<<24>>24!=0?H:C;c[k+(F<<5)+(I<<3)>>2]=c[e+11760>>2];c[k+(F<<5)+(I<<3)+4>>2]=c[e+11764>>2];I=F+H|0;H=C+1-F|0;F=e+12508|0;C=a[v+(r+(c[F>>2]|0))|0]|0;r=C&255;v=C<<24>>24!=0?I:H;c[k+(r<<5)+(v<<3)>>2]=c[e+11768>>2];c[k+(r<<5)+(v<<3)+4>>2]=c[e+11772>>2];v=r+I|0;I=H+1-r|0;r=(v|0)>(I|0);H=r&1;C=r?v:I;do{if((C|0)==2){J=(((c[k+(H<<5)+12>>2]|0)+(c[k+(H<<5)+4>>2]|0)|0)/2|0)&65535;K=(((c[k+(H<<5)+8>>2]|0)+(c[k+(H<<5)>>2]|0)|0)/2|0)&65535}else if((C|0)==3){I=c[k+(H<<5)>>2]|0;v=c[k+(H<<5)+8>>2]|0;D=c[k+(H<<5)+16>>2]|0;do{if((I|0)>(v|0)){if((D|0)<=(v|0)){L=v&65535;break}L=((D|0)>(I|0)?I:D)&65535}else{if((v|0)<=(D|0)){L=v&65535;break}L=((D|0)>(I|0)?D:I)&65535}}while(0);I=c[k+(H<<5)+4>>2]|0;D=c[k+(H<<5)+12>>2]|0;v=c[k+(H<<5)+20>>2]|0;if((I|0)>(D|0)){if((v|0)<=(D|0)){J=D&65535;K=L;break}J=((v|0)>(I|0)?I:v)&65535;K=L;break}else{if((D|0)<=(v|0)){J=D&65535;K=L;break}J=((v|0)>(I|0)?v:I)&65535;K=L;break}}else if((C|0)==4){I=c[k+(H<<5)>>2]|0;v=c[k+(H<<5)+8>>2]|0;D=c[k+(H<<5)+16>>2]|0;M=c[k+(H<<5)+24>>2]|0;N=(D|0)<(M|0);do{if((I|0)<(v|0)){if(N){O=((v|0)>(M|0)?M:v)+((I|0)>(D|0)?I:D)|0;break}else{O=((I|0)>(M|0)?I:M)+((v|0)>(D|0)?D:v)|0;break}}else{if(N){O=((I|0)>(M|0)?M:I)+((v|0)>(D|0)?v:D)|0;break}else{O=((v|0)>(M|0)?v:M)+((I|0)>(D|0)?D:I)|0;break}}}while(0);I=(O|0)/2|0;D=c[k+(H<<5)+4>>2]|0;M=c[k+(H<<5)+12>>2]|0;v=c[k+(H<<5)+20>>2]|0;N=c[k+(H<<5)+28>>2]|0;P=(v|0)<(N|0);do{if((D|0)<(M|0)){if(P){Q=((M|0)>(N|0)?N:M)+((D|0)>(v|0)?D:v)|0;break}else{Q=((D|0)>(N|0)?D:N)+((M|0)>(v|0)?v:M)|0;break}}else{if(P){Q=((D|0)>(N|0)?N:D)+((M|0)>(v|0)?M:v)|0;break}else{Q=((M|0)>(N|0)?M:N)+((D|0)>(v|0)?v:D)|0;break}}}while(0);J=((Q|0)/2|0)&65535;K=I&65535}else{yDb(0,0,2287080,(y=i,i=i+24|0,c[y>>2]=1994616,c[y+8>>2]=2255584,c[y+16>>2]=624,y)|0);i=y;Cd()}}while(0);y=c[e+9152>>2]|0;b[y+(B<<2)>>1]=K;b[y+(B<<2)+2>>1]=J;J=r&1;r=e+19412|0;a[(c[r>>2]|0)+B|0]=J;a[(c[r>>2]|0)+((c[m>>2]|0)+(c[E>>2]|0))|0]=J;a[(c[r>>2]|0)+((c[m>>2]|0)+(c[G>>2]|0))|0]=J;a[(c[r>>2]|0)+((c[m>>2]|0)+(c[F>>2]|0))|0]=J;A=c[l>>2]|0}l=(A|0)==1;do{if(l){J=c[e+4>>2]|0;F=c[J+128>>2]|0;m=c[J+132>>2]>>1;if((c[t>>2]|0)==2){J=(c[e+19468>>2]|0)+(c[e+12496+(f<<2)>>2]|0)|0;r=c[e+9152>>2]|0;b[r+(J<<2)>>1]=p;b[r+(J<<2)+2>>1]=z}J=(c[e+12476>>2]<<4)+(p>>2)|0;r=(c[e+12480>>2]<<3)+(z>>3)|0;do{if((J|0)<-17){R=p-68-(J<<2)|0}else{if((J|0)<=(F|0)){R=p;break}R=p-(J-F<<2)|0}}while(0);do{if((r|0)<-18){S=z-144-(r<<3)|0}else{if((r|0)<=(m+1|0)){S=z;break}S=z+8-(r-m<<3)|0}}while(0);if((A|0)!=1|(n|0)==0){T=S;U=R;s=64;break}if((f|0)>1){V=c[e+148>>2]|0}else{V=0}W=V+(f<<3&8)|0;X=S;Y=R}else{T=z;U=p;s=64}}while(0);if((s|0)==64){W=(ba(f<<2&8,c[e+148>>2]|0)|0)+(f<<3&8)|0;X=T;Y=U}U=(c[e+12476>>2]<<4|f<<3&8)+(Y>>2)|0;T=(n|0)!=0;p=c[e+12480>>2]<<4;if(T){Z=(p|(f|0)>1)+(X>>2)|0}else{Z=(p|f<<2&8)+(X>>2)|0}do{if((c[e+15660>>2]|0)==3){f=c[e+4>>2]|0;p=c[f+128>>2]|0;if((U|0)<-17){_=-17}else{_=(U|0)>(p|0)?p:U}if(!l){p=(c[f+132>>2]|0)+1|0;if((Z|0)<-18){$=_;aa=-18;break}$=_;aa=(Z|0)>(p|0)?p:Z;break}p=c[f+132>>2]|0;if((Z&1|0)==0){if((Z|0)<-18){$=_;aa=-18;break}$=_;aa=(Z|0)>(p|0)?p:Z;break}else{f=p+1|0;if((Z|0)<-17){$=_;aa=-17;break}$=_;aa=(Z|0)>(f|0)?f:Z;break}}else{f=c[e+116>>2]<<4;if((U|0)<-16){ca=-16}else{ca=(U|0)>(f|0)?f:U}f=c[e+120>>2]<<4;if((Z|0)<-16){$=ca;aa=-16;break}$=ca;aa=(Z|0)>(f|0)?f:Z}}while(0);Z=e+148|0;ca=c[Z>>2]|0;U=(ba(ca,aa)|0)+$|0;_=x+U|0;do{if((c[o>>2]|0)==0){da=_}else{if((c[e+19460+(g<<2)>>2]|0)==0){da=_;break}da=x+((c[(c[e+9856>>2]|0)+32>>2]|0)+U)|0}}while(0);if(T){T=aa&1;ea=(((T|0)!=0&(aa|0)<4)<<31>>31)+aa|0;fa=q-1+T|0}else{ea=aa;fa=q}q=e+19220|0;aa=(u|0)==0;u=c[e+136>>2]|0;do{if((a[q]|0)==0&aa){if((u|0)<13|(fa|0)<23){s=92;break}T=c[e+14116>>2]|0;U=T<<1;if(($-T|0)>>>0>(-8-(Y&3)+u-U|0)>>>0){s=92;break}if((ea-(T<<n)|0)>>>0>(fa-(X&3)-(U+8<<n)|0)>>>0){s=92}else{ga=da;ha=T;ia=ca}}else{s=92}}while(0);if((s|0)==92){s=e+14116|0;T=c[s>>2]|0;U=da+(ba((ca<<n)+1|0,-T|0)|0)|0;da=e+9944|0;x=(T<<1)+9|0;Ne[c[e+11540>>2]&127](c[da>>2]|0,U,ca,ca,x,x<<n,$-T|0,ea-(T<<n)|0,u,fa);fa=c[da>>2]|0;do{if((a[q]|0)!=0){da=c[s>>2]|0;if(((da<<1)+9|0)>0){ja=0;ka=fa;la=da}else{break}while(1){if(((la<<1)+9|0)>0){da=0;while(1){u=ka+da|0;a[u]=(((d[u]|0)+384|0)>>>1)+128;u=da+1|0;T=c[s>>2]|0;if((u|0)<((T<<1)+9|0)){da=u}else{ma=T;break}}}else{ma=la}da=ja+1|0;if((da|0)<((ma<<1)+9|0)){ja=da;ka=ka+(c[Z>>2]<<n)|0;la=ma}else{break}}}}while(0);ma=c[s>>2]|0;b:do{if(aa){na=ma}else{if(((ma<<1)+9|0)<=0){na=ma;break}la=e+19460+(g<<2)|0;ka=0;ja=fa;q=ma;while(1){if((c[o>>2]|0)==0){oa=(ka<<n)+ea-(q<<n)&1}else{oa=c[la>>2]|0}if(((q<<1)+9|0)>0){da=0;while(1){T=ja+da|0;a[T]=a[(d[T]|0)+(w+(oa<<8))|0]|0;T=da+1|0;u=c[s>>2]|0;if((T|0)<((u<<1)+9|0)){da=T}else{pa=u;break}}}else{pa=q}da=ka+1|0;if((da|0)>=((pa<<1)+9|0)){na=pa;break b}ka=da;ja=ja+(c[Z>>2]<<n)|0;q=pa}}}while(0);pa=c[Z>>2]|0;ga=fa+(ba((pa<<n)+1|0,na)|0)|0;ha=na;ia=pa}if((ha|0)==0){ha=Y>>>1&1|X&2;if((c[e+19216>>2]|0)==0){cf[c[e+11348+(ha<<2)>>2]&1023]((c[e+12544>>2]|0)+W|0,ga,ia,8);i=j;return}else{cf[c[e+11476+(ha<<2)>>2]&1023]((c[e+12544>>2]|0)+W|0,ga,ia,8);i=j;return}}else{ha=X<<2&12|Y&3;if((h|0)==0){cf[c[e+15404+(ha<<2)>>2]&1023]((c[e+12544>>2]|0)+W|0,ga,ia<<n,c[e+19216>>2]|0);i=j;return}else{cf[c[e+15468+(ha<<2)>>2]&1023]((c[e+12544>>2]|0)+W|0,ga,ia<<n,c[e+19216>>2]|0);i=j;return}}}function A2a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;h=i;i=i+32|0;j=h|0;k=h+16|0;l=a[(c[b+19400>>2]|0)+(c[b+12496>>2]|0)|0]|0;m=l&255;n=l<<24>>24!=0;l=n?1:4;o=b+140|0;p=c[o>>2]>>1;if((c[b+60>>2]&8192|0)!=0){i=h;return}q=c[b+11744+(e<<5)>>2]|0;c[j>>2]=((q&3|0)==3)+q>>1;q=c[b+11744+(e<<5)+4>>2]|0;if(n){c[k>>2]=(c[143208+((q&15)<<2)>>2]|0)+(q>>4<<3)}else{c[k>>2]=((q&3|0)==3)+q>>1}q=c[b+11744+(e<<5)+8>>2]|0;c[j+4>>2]=((q&3|0)==3)+q>>1;q=c[b+11744+(e<<5)+12>>2]|0;if(n){c[k+4>>2]=(c[143208+((q&15)<<2)>>2]|0)+(q>>4<<3)}else{c[k+4>>2]=((q&3|0)==3)+q>>1}q=c[b+11744+(f<<5)+16>>2]|0;c[j+8>>2]=((q&3|0)==3)+q>>1;q=c[b+11744+(f<<5)+20>>2]|0;if(n){c[k+8>>2]=(c[143208+((q&15)<<2)>>2]|0)+(q>>4<<3)}else{c[k+8>>2]=((q&3|0)==3)+q>>1}q=c[b+11744+(f<<5)+24>>2]|0;c[j+12>>2]=((q&3|0)==3)+q>>1;q=c[b+11744+(f<<5)+28>>2]|0;if(n){c[k+12>>2]=(c[143208+((q&15)<<2)>>2]|0)+(q>>4<<3)}else{c[k+12>>2]=((q&3|0)==3)+q>>1}q=b+152|0;r=b+12476|0;s=b+12480|0;t=b+4|0;u=(e|0)==0;e=b+956|0;v=b+960|0;w=b+16632|0;x=b+19200|0;y=b+11540|0;z=b+9944|0;A=5<<m;B=b+136|0;C=(g|0)==0;g=b+19216|0;D=b+15536|0;E=b+12548|0;F=b+12552|0;G=b+15304|0;H=b+15548|0;I=b+15320|0;J=b+3180|0;K=b+3184|0;L=b+18680|0;M=b+19208|0;b=(f|0)==0;f=0;N=p;while(1){p=f<<2&4;O=(f&2|0)!=0;if(O){P=ba(c[q>>2]|0,l)|0}else{P=0}Q=P+p|0;R=j+(f<<2)|0;S=c[R>>2]|0;T=(c[r>>2]<<3|p)+(S>>2)|0;p=k+(f<<2)|0;U=c[p>>2]|0;V=(c[s>>2]<<3|(O?l:0))+(U>>2)|0;O=c[t>>2]|0;W=c[O+128>>2]>>1;if((T|0)<-8){X=-8}else{X=(T|0)>(W|0)?W:T}T=c[O+132>>2]>>1;if((V|0)<-8){Y=-8}else{Y=(V|0)>(T|0)?T:V}if((f|0)<2){if(u){Z=15}else{_=J;$=K;aa=L;ca=M}}else{if(b){Z=15}else{_=J;$=K;aa=L;ca=M}}if((Z|0)==15){Z=0;_=e;$=v;aa=w;ca=x}V=c[_>>2]|0;T=c[ca>>2]|0;if((V|0)==0){Z=34;break}O=c[q>>2]|0;W=(ba(O,Y)|0)+X|0;da=V+W|0;V=(c[$>>2]|0)+W|0;c[R>>2]=S<<1&6;c[p>>2]=U<<1&6;if(n){U=Y&1;if((U|0)==0){ea=(c[o>>2]>>1)-1|0}else{ea=N}fa=(((U|0)!=0&(Y|0)<2)<<31>>31)+Y|0;ga=ea}else{fa=Y;ga=N}U=(T|0)!=0;T=c[B>>2]|0;do{if(U|(T|0)<10|(ga|0)<(A|0)){Z=24}else{if(X>>>0>((T>>1)-5|0)>>>0){Z=24;break}if(fa>>>0>(ga-A|0)>>>0){Z=24}else{ha=da;ia=V}}}while(0);do{if((Z|0)==24){Z=0;Ne[c[y>>2]&127](c[z>>2]|0,da,O,O,5,A,X,fa,T>>1,ga);S=c[q>>2]|0;Ne[c[y>>2]&127]((c[z>>2]|0)+16|0,V,S,S,5,A,X,fa,c[B>>2]>>1,ga);S=c[z>>2]|0;W=S+16|0;if(U){ja=0;ka=S;la=W}else{ha=S;ia=W;break}while(1){ma=(ja<<m)+fa&1;a[ka]=a[(d[ka]|0)+(aa+(ma<<8))|0]|0;a[la]=a[(d[la]|0)+(aa+(ma<<8))|0]|0;na=ka+1|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=la+1|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=ka+2|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=la+2|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=ka+3|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=la+3|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=ka+4|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=la+4|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;ma=c[q>>2]<<m;na=ja+1|0;if((na|0)<5){ja=na;ka=ka+ma|0;la=la+ma|0}else{ha=S;ia=W;break}}}}while(0);U=(c[g>>2]|0)!=0;do{if(C){if(U){V=c[R>>2]|0;T=c[p>>2]|0;Se[c[D>>2]&511]((c[E>>2]|0)+Q|0,ha,c[q>>2]<<m,4,V,T);Se[c[D>>2]&511]((c[F>>2]|0)+Q|0,ia,c[q>>2]<<m,4,V,T);break}else{T=c[R>>2]|0;V=c[p>>2]|0;Se[c[G>>2]&511]((c[E>>2]|0)+Q|0,ha,c[q>>2]<<m,4,T,V);Se[c[G>>2]&511]((c[F>>2]|0)+Q|0,ia,c[q>>2]<<m,4,T,V);break}}else{if(U){V=c[R>>2]|0;T=c[p>>2]|0;Se[c[H>>2]&511]((c[E>>2]|0)+Q|0,ha,c[q>>2]<<m,4,V,T);Se[c[H>>2]&511]((c[F>>2]|0)+Q|0,ia,c[q>>2]<<m,4,V,T);break}else{T=c[R>>2]|0;V=c[p>>2]|0;Se[c[I>>2]&511]((c[E>>2]|0)+Q|0,ha,c[q>>2]<<m,4,T,V);Se[c[I>>2]&511]((c[F>>2]|0)+Q|0,ia,c[q>>2]<<m,4,T,V);break}}}while(0);Q=f+1|0;if((Q|0)<4){f=Q;N=ga}else{Z=34;break}}if((Z|0)==34){i=h;return}}function B2a(d,e,f,g,h,i,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;l=c[d+128>>2]|0;m=c[d+12496+(e<<2)>>2]|0;if((c[d+12488>>2]|0)!=0){n=d+9148|0;o=c[n>>2]|0;b[o+(m<<2)>>1]=0;c[d+11744+(e<<3)>>2]=0;b[o+(m<<2)+2>>1]=0;c[d+11744+(e<<3)+4>>2]=0;o=c[d+9152>>2]|0;b[o+(m<<2)>>1]=0;b[o+(m<<2)+2>>1]=0;if((h|0)!=1){return}p=m+1|0;q=c[n>>2]|0;b[q+(p<<2)>>1]=0;b[q+(p<<2)+2>>1]=0;n=m+l|0;b[q+(n<<2)>>1]=0;b[q+(n<<2)+2>>1]=0;r=n+1|0;b[q+(r<<2)>>1]=0;b[q+(r<<2)+2>>1]=0;q=c[d+12476>>2]|0;s=c[d+19600>>2]|0;b[s+(q<<2)+2>>1]=0;b[s+(q<<2)>>1]=0;b[o+(p<<2)>>1]=0;b[o+(p<<2)+2>>1]=0;b[o+(n<<2)>>1]=0;b[o+(n<<2)+2>>1]=0;b[o+(r<<2)>>1]=0;b[o+(r<<2)+2>>1]=0;return}if((e|0)==0){t=1}else{t=(e|0)==1?1:-1}r=c[d+12476>>2]|0;if((r|0)==0){if((e|0)==3|(e|0)==1){u=8}else{v=0;w=0;x=0;y=0}}else{u=8}do{if((u|0)==8){o=c[d+19400>>2]|0;n=m-1|0;do{if((a[o+m|0]|0)==0){if((a[o+n|0]|0)==0){u=10;break}p=c[d+9148+(k<<2)>>2]|0;q=(ba(t,l)|0)+n|0;z=(b[p+(n<<2)+2>>1]|0)+1+(b[p+(q<<2)+2>>1]|0)>>1;A=(b[p+(n<<2)>>1]|0)+1+(b[p+(q<<2)>>1]|0)>>1}else{u=10}}while(0);if((u|0)==10){o=c[d+9148+(k<<2)>>2]|0;z=b[o+(n<<2)+2>>1]|0;A=b[o+(n<<2)>>1]|0}if((e&1|0)!=0){v=z;w=A;x=1;y=r;break}o=(a[(c[d+19592>>2]|0)+(r-1)|0]|0)==0;v=o?z:0;w=o?A:0;x=o&1;y=r}}while(0);do{if(e>>>0<2>>>0){u=16}else{if((a[(c[d+19400>>2]|0)+m|0]|0)!=0){u=16;break}r=c[d+12500>>2]|0;A=c[d+9148+(k<<2)>>2]|0;z=c[d+12496>>2]|0;B=1;C=1;D=b[A+(z<<2)>>1]|0;E=b[A+(z<<2)+2>>1]|0;F=b[A+(r<<2)>>1]|0;G=b[A+(r<<2)+2>>1]|0}}while(0);do{if((u|0)==16){if((c[d+14084>>2]|0)!=0){B=0;C=0;D=0;E=0;F=0;G=0;break}r=c[d+124>>2]|0;A=c[d+19592>>2]|0;do{if((a[A+(y-r)|0]|0)==0){z=e|2;t=c[d+12496+(z<<2)>>2]|0;o=l<<1;q=c[d+19400>>2]|0;p=(a[q+(t-o)|0]|0)==0;if(p){H=z;I=t}else{t=(a[q+m|0]|0)==0?z:e&3;H=t;I=c[d+12496+(t<<2)>>2]|0}t=I-o|0;z=c[d+9148+(k<<2)>>2]|0;s=b[z+(t<<2)>>1]|0;J=b[z+(t<<2)+2>>1]|0;if(p){K=1;L=s;M=J;break}if((a[q+m|0]|0)!=0){K=1;L=s;M=J;break}q=(c[d+12496+((H^2)<<2)>>2]|0)-o|0;K=1;L=s+1+(b[z+(q<<2)>>1]|0)>>1;M=J+1+(b[z+(q<<2)+2>>1]|0)>>1}else{K=0;L=0;M=0}}while(0);n=c[d+116>>2]|0;if((n|0)<=1){B=0;C=K;D=0;E=0;F=L;G=M;break}if((a[A+(y+1-r)|0]|0)!=0){B=0;C=K;D=0;E=0;F=L;G=M;break}q=c[d+12504>>2]|0;z=l<<1;J=c[d+19400>>2]|0;s=(a[J+(q-z+2)|0]|0)==0;if(s){N=0;O=q}else{q=(a[J+m|0]|0)==0?2:e&2;N=q^2;O=c[d+12496+(q<<2)>>2]|0}q=O-z+2|0;o=c[d+9148+(k<<2)>>2]|0;p=b[o+(q<<2)>>1]|0;t=b[o+(q<<2)+2>>1]|0;do{if(s){P=p;Q=t}else{if((a[J+m|0]|0)!=0){P=p;Q=t;break}q=(c[d+12496+(N<<2)>>2]|0)-z+2|0;P=p+1+(b[o+(q<<2)>>1]|0)>>1;Q=t+1+(b[o+(q<<2)+2>>1]|0)>>1}}while(0);if((y|0)!=(n-1|0)){B=1;C=K;D=P;E=Q;F=L;G=M;break}if((a[A+(y-1-r)|0]|0)!=0){B=0;C=K;D=P;E=Q;F=L;G=M;break}t=c[d+12508>>2]|0;p=(a[J+(t-z-2)|0]|0)==0;if(p){R=t}else{R=c[d+12496+(((a[J+m|0]|0)==0?3:e|1)<<2)>>2]|0}t=R-z-2|0;s=b[o+(t<<2)>>1]|0;q=b[o+(t<<2)+2>>1]|0;if(p){B=1;C=K;D=s;E=q;F=L;G=M;break}if((a[J+m|0]|0)!=0){B=1;C=K;D=s;E=q;F=L;G=M;break}p=(c[d+12500>>2]|0)-z-2|0;B=1;C=K;D=s+1+(b[o+(p<<2)>>1]|0)>>1;E=q+1+(b[o+(p<<2)+2>>1]|0)>>1;F=L;G=M}}while(0);M=C+x+B|0;do{if((y|0)==0){if((e|0)==3|(e|0)==1){S=v;T=w;break}S=0;T=0}else{S=v;T=w}}while(0);w=(a[(c[d+19400>>2]|0)+m|0]|0)==0;do{if((c[d+14084>>2]|0)==0){if(w){U=G;V=F;W=E;X=D;u=45}else{Y=G;Z=F;_=E;$=D;u=60}}else{if(!w){Y=0;Z=0;_=0;$=0;u=60;break}v=(e&2|0)==0;U=v?0:G;V=v?0:F;W=v?0:E;X=v?0:D;u=45}}while(0);do{if((u|0)==45){if((c[d+116>>2]|0)==1){aa=U;ca=V;break}if((M|0)<=1){if((M|0)==0){aa=0;ca=0;break}if((x|0)!=0){aa=S;ca=T;break}D=(C|0)==0;aa=D?W:U;ca=D?X:V;break}do{if((T|0)>(V|0)){if((X|0)<=(V|0)){da=V;break}da=(X|0)>(T|0)?T:X}else{if((V|0)<=(X|0)){da=V;break}da=(X|0)>(T|0)?X:T}}while(0);if((S|0)>(U|0)){if((W|0)<=(U|0)){aa=U;ca=da;break}aa=(W|0)>(S|0)?S:W;ca=da;break}else{if((U|0)<=(W|0)){aa=U;ca=da;break}aa=(W|0)>(S|0)?W:S;ca=da;break}}else if((u|0)==60){o=(x|0)!=0;if(o){ea=S>>>2&1}else{ea=0}z=(C|0)!=0;if(z){fa=Y>>>2&1}else{fa=0}if((B|0)==0){ga=0}else{ga=_>>>2&1}J=fa+ea+ga|0;r=M-J|0;if((M|0)==2){A=(ea|0)!=0;if((r|0)<(J|0)){n=A&o;aa=n?S:Y;ca=n?T:Z;break}if(!(A|o^1)){aa=S;ca=T;break}A=(fa|0)!=0|z^1;aa=A?_:Y;ca=A?$:Z;break}else if((M|0)==1){if(o){aa=S;ca=T;break}aa=z?Y:_;ca=z?Z:$;break}else if((M|0)==3){if(!((r|0)==3|(J|0)==3)){z=(ea|0)!=0;if((r|0)<(J|0)){aa=z?S:Y;ca=z?T:Z;break}else{aa=z?Y:S;ca=z?Z:T;break}}do{if((T|0)>(Z|0)){if(($|0)<=(Z|0)){ha=Z;break}ha=($|0)>(T|0)?T:$}else{if((Z|0)<=($|0)){ha=Z;break}ha=($|0)>(T|0)?$:T}}while(0);if((S|0)>(Y|0)){if((_|0)<=(Y|0)){aa=Y;ca=ha;break}aa=(_|0)>(S|0)?S:_;ca=ha;break}else{if((Y|0)<=(_|0)){aa=Y;ca=ha;break}aa=(_|0)>(S|0)?_:S;ca=ha;break}}else{aa=0;ca=0;break}}}while(0);ha=(i+f+ca&(i<<1)+65535)-i&65535;i=d+9148+(k<<2)|0;b[(c[i>>2]|0)+(m<<2)>>1]=ha;ca=ha<<16>>16;c[d+11744+(k<<5)+(e<<3)>>2]=ca;ha=(j+g+aa&(j<<1)+65535)-j&65535;b[(c[i>>2]|0)+(m<<2)+2>>1]=ha;j=ha<<16>>16;c[d+11744+(k<<5)+(e<<3)+4>>2]=j;if((h|0)==2){ha=c[i>>2]|0;aa=m+1|0;b[ha+(aa<<2)>>1]=b[ha+(m<<2)>>1]|0;b[ha+(aa<<2)+2>>1]=b[ha+(m<<2)+2>>1]|0;ha=e+1|0;c[d+11744+(k<<5)+(ha<<3)>>2]=ca;c[d+11744+(k<<5)+(ha<<3)+4>>2]=j;return}else if((h|0)==1){h=c[i>>2]|0;i=h+(m<<2)|0;j=b[i>>1]|0;ha=m+1|0;b[h+(ha<<2)>>1]=j;k=h+(m<<2)+2|0;d=b[k>>1]|0;b[h+(ha<<2)+2>>1]=d;ha=m+l|0;b[h+(ha<<2)>>1]=j;b[h+(ha<<2)+2>>1]=d;d=ha+1|0;b[h+(d<<2)>>1]=b[i>>1]|0;b[h+(d<<2)+2>>1]=b[k>>1]|0;return}else{return}}function C2a(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;k=c[e+19480>>2]|0;if((k|0)==0){l=e+15720|0;m=e+15724|0;n=e+16056|0;E2a(e,f,c[g+4>>2]|0,c[h+4>>2]|0,i,c[l>>2]|0,c[m>>2]|0,c[n>>2]|0,c[j+4>>2]|0,1);if((f|0)!=3&(i|0)==0){return}E2a(e,0,c[g>>2]|0,c[h>>2]|0,1,c[l>>2]|0,c[m>>2]|0,c[n>>2]|0,0,0);return}else if((k|0)==2){n=e+15720|0;m=e+15724|0;l=e+16056|0;E2a(e,0,c[g>>2]|0,c[h>>2]|0,1,c[n>>2]|0,c[m>>2]|0,c[l>>2]|0,c[j>>2]|0,0);E2a(e,0,c[g+4>>2]|0,c[h+4>>2]|0,1,c[n>>2]|0,c[m>>2]|0,c[l>>2]|0,c[j+4>>2]|0,1);return}else if((k|0)==3){k=ba(c[e+12480>>2]|0,c[e+124>>2]|0)|0;if((c[(c[e+4712>>2]|0)+((c[e+12476>>2]|0)+k+(c[e+19472>>2]|0)<<2)>>2]|0)==1){c[e+11748>>2]=0;c[e+11744>>2]=0;c[e+11780>>2]=0;c[e+11776>>2]=0;o=0;p=0;q=0;r=0;s=0;t=e+19468|0}else{k=e+19468|0;l=c[k>>2]|0;m=l+(c[e+12496>>2]|0)|0;n=c[e+4704>>2]|0;u=b[n+(m<<2)>>1]|0;v=b[e+16070>>1]|0;w=ba(v,u)|0;if((c[e+13924>>2]|0)==0){x=w+255>>9<<1;c[e+11744>>2]=x;y=b[n+(m<<2)+2>>1]|0;z=(ba(v,y)|0)+255>>9<<1;c[e+11748>>2]=z;A=v-256|0;B=(ba(A,u)|0)+255>>9<<1;c[e+11776>>2]=B;C=(ba(A,y)|0)+255>>9<<1;D=z&65535;E=x&65535;F=B&65535}else{B=w+128>>8;c[e+11744>>2]=B;w=b[n+(m<<2)+2>>1]|0;n=(ba(v,w)|0)+128>>8;c[e+11748>>2]=n;x=v-256|0;v=(ba(x,u)|0)+128>>8;c[e+11776>>2]=v;C=(ba(x,w)|0)+128>>8;D=n&65535;E=B&65535;F=v&65535}c[e+11780>>2]=C;v=c[e+19420>>2]|0;o=((d[v+((c[e+12500>>2]|0)+l)|0]|0)+(d[v+m|0]|0)+(d[v+((c[e+12504>>2]|0)+l)|0]|0)+(d[v+((c[e+12508>>2]|0)+l)|0]|0)|0)>2|0;p=E;q=D;r=F;s=C&65535;t=k}k=c[e+19456>>2]^o;c[e+19464>>2]=k;c[e+19460>>2]=k;k=e+11744|0;C=e+9148|0;F=e+11748|0;D=e+11776|0;E=e+9152|0;l=e+11780|0;v=o&255;o=e+19408|0;m=e+19412|0;B=0;n=p;p=q;q=r;r=s;while(1){s=e+12496+(B<<2)|0;w=(c[t>>2]|0)+(c[s>>2]|0)|0;x=c[C>>2]|0;b[x+(w<<2)>>1]=n;b[x+(w<<2)+2>>1]=p;x=c[E>>2]|0;b[x+(w<<2)>>1]=q;b[x+(w<<2)+2>>1]=r;a[(c[o>>2]|0)+w|0]=v;a[(c[m>>2]|0)+((c[t>>2]|0)+(c[s>>2]|0))|0]=v;s=B+1|0;if((s|0)>=4){break}B=s;n=c[k>>2]&65535;p=c[F>>2]&65535;q=c[D>>2]&65535;r=c[l>>2]&65535}return}else{l=e+15720|0;r=e+15724|0;D=e+16056|0;E2a(e,f,c[g>>2]|0,c[h>>2]|0,i,c[l>>2]|0,c[r>>2]|0,c[D>>2]|0,c[j>>2]|0,0);if((f|0)!=3&(i|0)==0){return}E2a(e,0,c[g+4>>2]|0,c[h+4>>2]|0,1,c[l>>2]|0,c[r>>2]|0,c[D>>2]|0,0,1);return}}function D2a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;g=i;i=i+64|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=c[e+19456>>2]|0;n=e+19428|0;o=c[n>>2]|0;p=c[e+140>>2]>>o;q=(o|0)==0;do{if(q){if((c[e+952>>2]|0)!=0){break}i=g;return}}while(0);if((c[e+60>>2]&8192|0)!=0){i=g;return}r=e+19468|0;s=e+19408+(f<<2)|0;t=c[e+11744+(f<<5)>>2]|0;c[h>>2]=t;u=c[e+11744+(f<<5)+4>>2]|0;c[j>>2]=u;v=c[e+12496>>2]|0;w=c[e+16056>>2]|0;x=a[w+v|0]|0;c[k>>2]=x&255;if(q){y=0}else{z=d[(c[s>>2]|0)+((c[r>>2]|0)+v)|0]|0;c[l>>2]=z;y=z}z=c[e+11744+(f<<5)+8>>2]|0;c[h+4>>2]=z;A=c[e+11744+(f<<5)+12>>2]|0;c[j+4>>2]=A;B=c[e+12500>>2]|0;C=a[w+B|0]|0;c[k+4>>2]=C&255;if(q){D=0}else{E=d[(c[s>>2]|0)+((c[r>>2]|0)+B)|0]|0;c[l+4>>2]=E;D=E}E=c[e+11744+(f<<5)+16>>2]|0;c[h+8>>2]=E;B=c[e+11744+(f<<5)+20>>2]|0;c[j+8>>2]=B;F=c[e+12504>>2]|0;G=a[w+F|0]|0;c[k+8>>2]=G&255;if(q){H=0}else{I=d[(c[s>>2]|0)+((c[r>>2]|0)+F)|0]|0;c[l+8>>2]=I;H=I}I=c[e+11744+(f<<5)+24>>2]|0;c[h+12>>2]=I;F=c[e+11744+(f<<5)+28>>2]|0;c[j+12>>2]=F;J=c[e+12508>>2]|0;K=a[w+J|0]|0;c[k+12>>2]=K&255;do{if(q){L=8}else{w=d[(c[s>>2]|0)+((c[r>>2]|0)+J)|0]|0;c[l+12>>2]=w;if((c[e+19444>>2]|0)==0){L=8;break}M=(D+y+H+w|0)>2;N=M&1;O=((w|0)!=(N|0))<<3|(y|0)!=(N|0)|((H|0)!=(N|0))<<2|((D|0)!=(N|0))<<1;do{if((O|0)==0){N=(E|0)<(I|0);do{if((t|0)<(z|0)){if(N){P=((z|0)>(I|0)?I:z)+((t|0)>(E|0)?t:E)|0;break}else{P=((t|0)>(I|0)?t:I)+((z|0)>(E|0)?E:z)|0;break}}else{if(N){P=((t|0)>(I|0)?I:t)+((z|0)>(E|0)?z:E)|0;break}else{P=((z|0)>(I|0)?z:I)+((t|0)>(E|0)?E:t)|0;break}}}while(0);N=(P|0)/2|0;w=(B|0)<(F|0);do{if((u|0)<(A|0)){if(w){Q=((A|0)>(F|0)?F:A)+((u|0)>(B|0)?u:B)|0;break}else{Q=((u|0)>(F|0)?u:F)+((A|0)>(B|0)?B:A)|0;break}}else{if(w){Q=((u|0)>(F|0)?F:u)+((A|0)>(B|0)?A:B)|0;break}else{Q=((A|0)>(F|0)?A:F)+((u|0)>(B|0)?B:u)|0;break}}}while(0);R=(Q|0)/2|0;S=N}else{if((278>>>(O>>>0)&1|0)==0){if((5736>>>(O>>>0)&1|0)==0){R=0;S=0;break}else{T=0}while(1){if((T|0)>=3){U=0;break}if((c[l+(T<<2)>>2]|0)==0){U=T;break}else{T=T+1|0}}N=U;while(1){w=N+1|0;if((w|0)>=4){V=0;break}if((c[l+(w<<2)>>2]|0)==0){V=w;break}else{N=w}}R=((c[j+(V<<2)>>2]|0)+(c[j+(U<<2)>>2]|0)|0)/2|0;S=((c[h+(V<<2)>>2]|0)+(c[h+(U<<2)>>2]|0)|0)/2|0;break}if((O|0)==4){do{if((t|0)>(z|0)){if((I|0)<=(z|0)){W=z;break}W=(I|0)>(t|0)?t:I}else{if((z|0)<=(I|0)){W=z;break}W=(I|0)>(t|0)?I:t}}while(0);if((u|0)>(A|0)){if((F|0)<=(A|0)){R=A;S=W;break}R=(F|0)>(u|0)?u:F;S=W;break}else{if((A|0)<=(F|0)){R=A;S=W;break}R=(F|0)>(u|0)?F:u;S=W;break}}else if((O|0)==8){do{if((t|0)>(z|0)){if((E|0)<=(z|0)){X=z;break}X=(E|0)>(t|0)?t:E}else{if((z|0)<=(E|0)){X=z;break}X=(E|0)>(t|0)?E:t}}while(0);if((u|0)>(A|0)){if((B|0)<=(A|0)){R=A;S=X;break}R=(B|0)>(u|0)?u:B;S=X;break}else{if((A|0)<=(B|0)){R=A;S=X;break}R=(B|0)>(u|0)?B:u;S=X;break}}else if((O|0)==2){do{if((t|0)>(E|0)){if((I|0)<=(E|0)){Y=E;break}Y=(I|0)>(t|0)?t:I}else{if((E|0)<=(I|0)){Y=E;break}Y=(I|0)>(t|0)?I:t}}while(0);if((u|0)>(B|0)){if((F|0)<=(B|0)){R=B;S=Y;break}R=(F|0)>(u|0)?u:F;S=Y;break}else{if((B|0)<=(F|0)){R=B;S=Y;break}R=(F|0)>(u|0)?F:u;S=Y;break}}else if((O|0)==1){do{if((z|0)>(E|0)){if((I|0)<=(E|0)){Z=E;break}Z=(I|0)>(z|0)?z:I}else{if((E|0)<=(I|0)){Z=E;break}Z=(I|0)>(z|0)?I:z}}while(0);if((A|0)>(B|0)){if((F|0)<=(B|0)){R=B;S=Z;break}R=(F|0)>(A|0)?A:F;S=Z;break}else{if((B|0)<=(F|0)){R=B;S=Z;break}R=(F|0)>(A|0)?F:A;S=Z;break}}else{R=0;S=0;break}}}while(0);if(!M){_=m;$=R;aa=S;break}_=(m|0)==0|0;$=R;aa=S}}while(0);if((L|0)==8){S=(G<<24>>24!=0)<<2|(K<<24>>24!=0)<<3|(C<<24>>24!=0)<<1|x<<24>>24!=0;do{if((S|0)==0){x=(E|0)<(I|0);do{if((t|0)<(z|0)){if(x){ca=((z|0)>(I|0)?I:z)+((t|0)>(E|0)?t:E)|0;break}else{ca=((t|0)>(I|0)?t:I)+((z|0)>(E|0)?E:z)|0;break}}else{if(x){ca=((t|0)>(I|0)?I:t)+((z|0)>(E|0)?z:E)|0;break}else{ca=((z|0)>(I|0)?z:I)+((t|0)>(E|0)?E:t)|0;break}}}while(0);x=(ca|0)/2|0;M=(B|0)<(F|0);do{if((u|0)<(A|0)){if(M){da=((A|0)>(F|0)?F:A)+((u|0)>(B|0)?u:B)|0;break}else{da=((u|0)>(F|0)?u:F)+((A|0)>(B|0)?B:A)|0;break}}else{if(M){da=((u|0)>(F|0)?F:u)+((A|0)>(B|0)?A:B)|0;break}else{da=((A|0)>(F|0)?A:F)+((u|0)>(B|0)?B:u)|0;break}}}while(0);ea=(da|0)/2|0;fa=x}else{if((278>>>(S>>>0)&1|0)==0){if((5736>>>(S>>>0)&1|0)==0){M=(c[r>>2]|0)+v|0;C=c[e+9152>>2]|0;b[C+(M<<2)>>1]=0;b[C+(M<<2)+2>>1]=0;M=c[e+12476>>2]|0;C=c[e+19600>>2]|0;b[C+(M<<2)+2>>1]=0;b[C+(M<<2)>>1]=0;i=g;return}else{ga=0}while(1){if((ga|0)>=3){ha=0;break}if((c[k+(ga<<2)>>2]|0)==0){ha=ga;break}else{ga=ga+1|0}}x=ha;while(1){M=x+1|0;if((M|0)>=4){ia=0;break}if((c[k+(M<<2)>>2]|0)==0){ia=M;break}else{x=M}}ea=((c[j+(ia<<2)>>2]|0)+(c[j+(ha<<2)>>2]|0)|0)/2|0;fa=((c[h+(ia<<2)>>2]|0)+(c[h+(ha<<2)>>2]|0)|0)/2|0;break}if((S|0)==4){do{if((t|0)>(z|0)){if((I|0)<=(z|0)){ja=z;break}ja=(I|0)>(t|0)?t:I}else{if((z|0)<=(I|0)){ja=z;break}ja=(I|0)>(t|0)?I:t}}while(0);if((u|0)>(A|0)){if((F|0)<=(A|0)){ea=A;fa=ja;break}ea=(F|0)>(u|0)?u:F;fa=ja;break}else{if((A|0)<=(F|0)){ea=A;fa=ja;break}ea=(F|0)>(u|0)?F:u;fa=ja;break}}else if((S|0)==2){do{if((t|0)>(E|0)){if((I|0)<=(E|0)){ka=E;break}ka=(I|0)>(t|0)?t:I}else{if((E|0)<=(I|0)){ka=E;break}ka=(I|0)>(t|0)?I:t}}while(0);if((u|0)>(B|0)){if((F|0)<=(B|0)){ea=B;fa=ka;break}ea=(F|0)>(u|0)?u:F;fa=ka;break}else{if((B|0)<=(F|0)){ea=B;fa=ka;break}ea=(F|0)>(u|0)?F:u;fa=ka;break}}else if((S|0)==1){do{if((z|0)>(E|0)){if((I|0)<=(E|0)){la=E;break}la=(I|0)>(z|0)?z:I}else{if((E|0)<=(I|0)){la=E;break}la=(I|0)>(z|0)?I:z}}while(0);if((A|0)>(B|0)){if((F|0)<=(B|0)){ea=B;fa=la;break}ea=(F|0)>(A|0)?A:F;fa=la;break}else{if((B|0)<=(F|0)){ea=B;fa=la;break}ea=(F|0)>(A|0)?F:A;fa=la;break}}else if((S|0)==8){do{if((t|0)>(z|0)){if((E|0)<=(z|0)){ma=z;break}ma=(E|0)>(t|0)?t:E}else{if((z|0)<=(E|0)){ma=z;break}ma=(E|0)>(t|0)?E:t}}while(0);if((u|0)>(A|0)){if((B|0)<=(A|0)){ea=A;fa=ma;break}ea=(B|0)>(u|0)?u:B;fa=ma;break}else{if((A|0)<=(B|0)){ea=A;fa=ma;break}ea=(B|0)>(u|0)?B:u;fa=ma;break}}else{ea=0;fa=0;break}}}while(0);_=c[e+19448>>2]|0;$=ea;aa=fa}do{if((o|0)!=0&(_|0)==1&(m|0)==1){if((c[e+952>>2]|0)!=0){break}i=g;return}}while(0);o=(c[r>>2]|0)+v|0;v=c[e+9152>>2]|0;b[v+(o<<2)>>1]=aa;b[v+(o<<2)+2>>1]=$;o=((aa&3|0)==3)+aa>>1;aa=(($&3|0)==3)+$>>1;$=c[e+12476>>2]|0;v=c[e+19600>>2]|0;b[v+($<<2)>>1]=o;b[v+($<<2)+2>>1]=aa;if((c[e+15680>>2]|0)==0){na=aa;oa=o}else{v=o&1;r=aa&1;na=((aa|0)<0?r:-r|0)+aa|0;oa=((o|0)<0?v:-v|0)+o|0}o=(m|0)==(_|0);if(o){pa=na}else{pa=(-(_<<2)|2)+na|0}na=($<<3)+(oa>>2)|0;$=(c[e+12480>>2]<<3)+(pa>>2)|0;if((c[e+15660>>2]|0)==3){m=c[e+4>>2]|0;v=c[m+128>>2]>>1;if((na|0)<-8){qa=-8}else{qa=(na|0)>(v|0)?v:na}ra=qa;sa=c[m+132>>2]>>1}else{m=c[e+116>>2]<<3;if((na|0)<-8){ta=-8}else{ta=(na|0)>(m|0)?m:na}ra=ta;sa=c[e+120>>2]<<3}if(($|0)<-8){ua=-8}else{ua=($|0)>(sa|0)?sa:$}a:do{if((f|0)==0){do{if(!(q|o)){if((c[e+19436>>2]|0)==0){break}va=e+7628|0;wa=c[e+19204>>2]|0;xa=c[e+19196>>2]|0;ya=e+7632|0;break a}}while(0);va=e+956|0;wa=e+19200|0;xa=e+16632|0;ya=e+960|0}else{va=e+3180|0;wa=e+19208|0;xa=e+18680|0;ya=e+3184|0}}while(0);o=c[va>>2]|0;va=c[wa>>2]|0;if((o|0)==0){yDb(c[e+4>>2]|0,16,2017248,(wa=i,i=i+1|0,i=i+7&-8,c[wa>>2]=0,wa)|0);i=wa;i=g;return}wa=e+152|0;f=c[wa>>2]|0;$=(ba(f,ua)|0)+ra|0;if(q|(_|0)==0){za=$;Aa=$}else{q=c[e+9856>>2]|0;za=(c[q+36>>2]|0)+$|0;Aa=(c[q+40>>2]|0)+$|0}$=o+za|0;za=(c[ya>>2]|0)+Aa|0;Aa=e+19220|0;ya=(va|0)==0;va=c[e+136>>2]|0;do{if((a[Aa]|0)==0&ya){if((va|0)<18|(p|0)<18){L=171;break}if(ra>>>0>((va>>1)-9|0)>>>0){L=171;break}if(ua>>>0>((p>>1)-9|0)>>>0){L=171}else{Ba=$;Ca=za}}else{L=171}}while(0);do{if((L|0)==171){o=e+11540|0;q=e+9944|0;sa=p>>1;Ne[c[o>>2]&127](c[q>>2]|0,$,f,f,9,9,ra,ua,va>>1,sa);ta=c[wa>>2]|0;Ne[c[o>>2]&127]((c[q>>2]|0)+16|0,za,ta,ta,9,9,ra,ua,c[e+136>>2]>>1,sa);sa=c[q>>2]|0;q=sa+16|0;if((a[Aa]|0)!=0){ta=0;o=sa;na=q;while(1){m=0;do{qa=o+m|0;a[qa]=(((d[qa]|0)+384|0)>>>1)+128;qa=na+m|0;a[qa]=(((d[qa]|0)+384|0)>>>1)+128;m=m+1|0;}while((m|0)<9);m=c[wa>>2]|0;qa=ta+1|0;if((qa|0)<9){ta=qa;o=o+m|0;na=na+m|0}else{break}}}if(ya){Ba=sa;Ca=q;break}else{Da=0;Ea=sa;Fa=q}while(1){if((c[n>>2]|0)==0){Ga=Da+ua&1}else{Ga=_}a[Ea]=a[(d[Ea]|0)+(xa+(Ga<<8))|0]|0;a[Fa]=a[(d[Fa]|0)+(xa+(Ga<<8))|0]|0;na=Ea+1|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+1|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+2|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+2|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+3|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+3|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+4|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+4|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+5|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+5|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+6|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+6|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+7|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+7|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+8|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+8|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=c[wa>>2]|0;o=Da+1|0;if((o|0)<9){Da=o;Ea=Ea+na|0;Fa=Fa+na|0}else{Ba=sa;Ca=q;break}}}}while(0);Fa=oa<<1&6;oa=pa<<1&6;if((c[e+19216>>2]|0)==0){pa=e+15300|0;Se[c[pa>>2]&511](c[e+12548>>2]|0,Ba,c[wa>>2]|0,8,Fa,oa);Se[c[pa>>2]&511](c[e+12552>>2]|0,Ca,c[wa>>2]|0,8,Fa,oa);i=g;return}else{pa=e+15532|0;Se[c[pa>>2]&511](c[e+12548>>2]|0,Ba,c[wa>>2]|0,8,Fa,oa);Se[c[pa>>2]&511](c[e+12552>>2]|0,Ca,c[wa>>2]|0,8,Fa,oa);i=g;return}}function E2a(f,g,h,i,j,k,l,m,n,o){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0;p=a[f+15708|0]|0;if((p<<24>>24|0)==3){q=1}else if((p<<24>>24|0)==4){if((a[f+15709|0]|0)==3){q=1}else{r=3}}else{r=3}if((r|0)==3){q=0}p=1-(c[f+13924>>2]|0)|0;s=h<<p;h=i<<p;i=c[f+128>>2]|0;t=c[f+12496+(g<<2)>>2]|0;if((c[f+12488>>2]|0)!=0){u=f+19468|0;v=(c[u>>2]|0)+t|0;w=f+9148|0;x=c[w>>2]|0;b[x+(v<<2)>>1]=0;c[f+11744+(g<<3)>>2]=0;b[x+(v<<2)+2>>1]=0;c[f+11744+(g<<3)+4>>2]=0;v=c[u>>2]|0;u=v+t|0;x=c[f+9152>>2]|0;b[x+(u<<2)>>1]=0;b[x+(u<<2)+2>>1]=0;if((j|0)==0){return}u=v+(t+1)|0;y=c[w>>2]|0;b[y+(u<<2)>>1]=0;b[y+(u<<2)+2>>1]=0;w=t+i|0;z=v+w|0;b[y+(z<<2)>>1]=0;b[y+(z<<2)+2>>1]=0;A=v+(w+1)|0;b[y+(A<<2)>>1]=0;b[y+(A<<2)+2>>1]=0;y=c[f+12476>>2]|0;v=c[f+19600>>2]|0;b[v+(y<<2)+2>>1]=0;b[v+(y<<2)>>1]=0;b[x+(u<<2)>>1]=0;b[x+(u<<2)+2>>1]=0;b[x+(w<<2)>>1]=0;b[x+(z<<2)+2>>1]=0;b[x+(A<<2)>>1]=0;b[x+(A<<2)+2>>1]=0;return}A=t-1|0;x=f+19468|0;z=c[x>>2]|0;w=z+A|0;u=f+9148+(o<<2)|0;y=c[u>>2]|0;v=y+(w<<2)|0;B=t-i|0;C=z+B|0;D=y+(C<<2)|0;E=(j|0)!=0;do{if(E){j=(c[f+12476>>2]|0)==((c[f+116>>2]|0)-1|0);if((c[f+19428>>2]|0)==0|(q|0)==0){F=j?-1:2;break}else{F=j?-2:2;break}}else{if((g|0)==3){F=-1;break}else if((g|0)==2){F=1;break}else if((g|0)==0){F=(c[f+12476>>2]|0)>0?-1:1;break}else if((g|0)==1){F=(c[f+12476>>2]|0)==((c[f+116>>2]|0)-1|0)?-1:1;break}else{F=0;break}}}while(0);q=F+B|0;F=q+z|0;j=y+(F<<2)|0;G=(g|0)==2;H=(g|0)==3;I=(c[f+14084>>2]|0)==0|G|H;if(I){J=(c[f+116>>2]|0)>1}else{J=0}K=f+12476|0;L=(c[K>>2]|0)!=0;M=(g|0)==1;N=f+19428|0;O=(c[N>>2]|0)==0;do{if(O){P=L|M|H;Q=J;R=I;r=26}else{if(I){S=(a[m+B|0]|0)==0}else{S=0}if(J){T=(a[m+q|0]|0)==0}else{T=0}if(!L){if(!((g|0)==3|(g|0)==1)){P=0;Q=T;R=S;r=26;break}}U=(a[m+A|0]|0)==0;if(S){V=T;W=U;r=27}else{X=T;Y=U;r=28}}}while(0);if((r|0)==26){if(R){V=Q;W=P;r=27}else{X=Q;Y=P;r=28}}do{if((r|0)==27){P=c[f+19408+(o<<2)>>2]|0;Q=d[P+C|0]|0;R=1-Q|0;T=b[D>>1]|0;S=b[y+(C<<2)+2>>1]|0;if(V){Z=W;_=1;$=R;aa=Q;ca=S;da=T;ea=P;r=30}else{fa=R;ga=W;ha=1;ia=Q;ja=S;ka=T;r=31}}else if((r|0)==28){if(!X){fa=0;ga=Y;ha=0;ia=0;ja=0;ka=0;r=31;break}Z=Y;_=0;$=0;aa=0;ca=0;da=0;ea=c[f+19408+(o<<2)>>2]|0;r=30}}while(0);do{if((r|0)==30){Y=d[ea+F|0]|0;X=Y+aa|0;W=1-Y+$|0;V=b[j>>1]|0;C=b[y+(F<<2)+2>>1]|0;if(Z){la=da;ma=ca;na=aa;oa=_;pa=1;qa=W;ra=X;sa=Y;ta=C;ua=V;va=ea;r=33}else{wa=0;xa=0;ya=0;za=X;Aa=W;Ba=da;Ca=ca;Da=aa;Ea=_;Fa=1;Ga=0;Ha=Y;Ia=C;Ja=V}}else if((r|0)==31){if(!ga){wa=0;xa=0;ya=0;za=ia;Aa=fa;Ba=ka;Ca=ja;Da=ia;Ea=ha;Fa=0;Ga=0;Ha=0;Ia=0;Ja=0;break}la=ka;ma=ja;na=ia;oa=ha;pa=0;qa=fa;ra=ia;sa=0;ta=0;ua=0;va=c[f+19408+(o<<2)>>2]|0;r=33}}while(0);if((r|0)==33){ia=d[va+w|0]|0;wa=b[v>>1]|0;xa=b[y+(w<<2)+2>>1]|0;ya=ia;za=ia+ra|0;Aa=qa+1-ia|0;Ba=la;Ca=ma;Da=na;Ea=oa;Fa=pa;Ga=1;Ha=sa;Ia=ta;Ja=ua}do{if(O){r=136}else{if((c[f+19444>>2]|0)==0){Ka=1-(c[f+19448>>2]|0)|0}else{Ka=(Aa|0)>(za|0)?n:1-n|0}if((Ka|0)==0){r=136;break}if(Ea&(Da|0)==0){ua=Ba<<16>>16>>p;ta=(c[f+9992>>2]|0)==3;sa=c[f+19436>>2]|0;do{if(ta){if(!((sa|0)==0&(o|0)==1)){La=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=52;break}pa=c[f+19488>>2]|0;oa=(pa|0)>3?3:pa;pa=e[1099888+(oa<<1)>>1]|0;na=e[1099856+(oa<<1)>>1]|0;ma=e[1099864+(oa<<1)>>1]|0;la=(ua|0)>-1?ua:-ua|0;do{if((la|0)>255){Ma=ua}else{if((la|0)<(e[1099872+(oa<<1)>>1]|0)){Ma=(ba(na,ua)|0)>>8;break}ia=(ba(ma,ua)|0)>>8;if((ua|0)<0){Ma=ia-pa|0;break}else{Ma=ia+pa|0;break}}}while(0);pa=c[f+15720>>2]|0;ma=-pa|0;na=pa-1|0;if((Ma|0)<(ma|0)){Na=ma;break}Na=(Ma|0)>(na|0)?na:Ma}else{na=c[f+19440>>2]|0;La=(na|0)>3?3:na;r=52}}while(0);if((r|0)==52){Na=(ba(e[1098432+((sa^o)*56|0)+(La<<1)>>1]|0,ua)|0)>>8}na=Na<<p&65535;ma=Ca<<16>>16>>p;a:do{if(ta){if(!((sa|0)==0&(o|0)==1)){Oa=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=69;break}pa=c[f+19488>>2]|0;oa=(pa|0)>3?3:pa;pa=e[1099896+(oa<<1)>>1]|0;la=e[1099856+(oa<<1)>>1]|0;ia=e[1099864+(oa<<1)>>1]|0;qa=(ma|0)>-1?ma:-ma|0;do{if((qa|0)>63){Pa=ma}else{if((qa|0)<(e[1099880+(oa<<1)>>1]|0)){Pa=(ba(la,ma)|0)>>8;break}ra=(ba(ia,ma)|0)>>8;if((ma|0)<0){Pa=ra-pa|0;break}else{Pa=ra+pa|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19464>>2]|0)!=0){break}pa=c[f+15724>>2]|0;ia=((pa|0)/-2|0)+1|0;la=(pa|0)/2|0;if((Pa|0)<(ia|0)){Qa=ia;break a}Qa=(Pa|0)>(la|0)?la:Pa;break a}}while(0);la=c[f+15724>>2]|0;ia=(la|0)/-2|0;pa=((la|0)/2|0)-1|0;if((Pa|0)<(ia|0)){Qa=ia;break}Qa=(Pa|0)>(pa|0)?pa:Pa}else{pa=c[f+19440>>2]|0;Oa=(pa|0)>3?3:pa;r=69}}while(0);if((r|0)==69){Qa=(ba(e[1098432+((sa^o)*56|0)+(Oa<<1)>>1]|0,ma)|0)>>8}Ra=na;Sa=Qa<<p&65535}else{Ra=Ba;Sa=Ca}if(Fa&(Ha|0)==0){ta=Ja<<16>>16>>p;ua=(c[f+9992>>2]|0)==3;pa=c[f+19436>>2]|0;do{if(ua){if(!((pa|0)==0&(o|0)==1)){Ta=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=84;break}ia=c[f+19488>>2]|0;la=(ia|0)>3?3:ia;ia=e[1099888+(la<<1)>>1]|0;oa=e[1099856+(la<<1)>>1]|0;qa=e[1099864+(la<<1)>>1]|0;ra=(ta|0)>-1?ta:-ta|0;do{if((ra|0)>255){Ua=ta}else{if((ra|0)<(e[1099872+(la<<1)>>1]|0)){Ua=(ba(oa,ta)|0)>>8;break}w=(ba(qa,ta)|0)>>8;if((ta|0)<0){Ua=w-ia|0;break}else{Ua=w+ia|0;break}}}while(0);ia=c[f+15720>>2]|0;qa=-ia|0;oa=ia-1|0;if((Ua|0)<(qa|0)){Va=qa;break}Va=(Ua|0)>(oa|0)?oa:Ua}else{oa=c[f+19440>>2]|0;Ta=(oa|0)>3?3:oa;r=84}}while(0);if((r|0)==84){Va=(ba(e[1098432+((pa^o)*56|0)+(Ta<<1)>>1]|0,ta)|0)>>8}na=Va<<p&65535;ma=Ia<<16>>16>>p;b:do{if(ua){if(!((pa|0)==0&(o|0)==1)){Wa=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=101;break}sa=c[f+19488>>2]|0;oa=(sa|0)>3?3:sa;sa=e[1099896+(oa<<1)>>1]|0;qa=e[1099856+(oa<<1)>>1]|0;ia=e[1099864+(oa<<1)>>1]|0;la=(ma|0)>-1?ma:-ma|0;do{if((la|0)>63){Xa=ma}else{if((la|0)<(e[1099880+(oa<<1)>>1]|0)){Xa=(ba(qa,ma)|0)>>8;break}ra=(ba(ia,ma)|0)>>8;if((ma|0)<0){Xa=ra-sa|0;break}else{Xa=ra+sa|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19464>>2]|0)!=0){break}sa=c[f+15724>>2]|0;ia=((sa|0)/-2|0)+1|0;qa=(sa|0)/2|0;if((Xa|0)<(ia|0)){Ya=ia;break b}Ya=(Xa|0)>(qa|0)?qa:Xa;break b}}while(0);qa=c[f+15724>>2]|0;ia=(qa|0)/-2|0;sa=((qa|0)/2|0)-1|0;if((Xa|0)<(ia|0)){Ya=ia;break}Ya=(Xa|0)>(sa|0)?sa:Xa}else{sa=c[f+19440>>2]|0;Wa=(sa|0)>3?3:sa;r=101}}while(0);if((r|0)==101){Ya=(ba(e[1098432+((pa^o)*56|0)+(Wa<<1)>>1]|0,ma)|0)>>8}Za=na;_a=Ya<<p&65535}else{Za=Ja;_a=Ia}if(Ga&(ya|0)==0){ua=wa<<16>>16>>p;ta=(c[f+9992>>2]|0)==3;sa=c[f+19436>>2]|0;do{if(ta){if(!((sa|0)==0&(o|0)==1)){$a=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=116;break}ia=c[f+19488>>2]|0;qa=(ia|0)>3?3:ia;ia=e[1099888+(qa<<1)>>1]|0;oa=e[1099856+(qa<<1)>>1]|0;la=e[1099864+(qa<<1)>>1]|0;ra=(ua|0)>-1?ua:-ua|0;do{if((ra|0)>255){ab=ua}else{if((ra|0)<(e[1099872+(qa<<1)>>1]|0)){ab=(ba(oa,ua)|0)>>8;break}w=(ba(la,ua)|0)>>8;if((ua|0)<0){ab=w-ia|0;break}else{ab=w+ia|0;break}}}while(0);ia=c[f+15720>>2]|0;la=-ia|0;oa=ia-1|0;if((ab|0)<(la|0)){bb=la;break}bb=(ab|0)>(oa|0)?oa:ab}else{oa=c[f+19440>>2]|0;$a=(oa|0)>3?3:oa;r=116}}while(0);if((r|0)==116){bb=(ba(e[1098432+((sa^o)*56|0)+($a<<1)>>1]|0,ua)|0)>>8}na=bb<<p&65535;ma=xa<<16>>16>>p;c:do{if(ta){if(!((sa|0)==0&(o|0)==1)){cb=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=133;break}pa=c[f+19488>>2]|0;oa=(pa|0)>3?3:pa;pa=e[1099896+(oa<<1)>>1]|0;la=e[1099856+(oa<<1)>>1]|0;ia=e[1099864+(oa<<1)>>1]|0;qa=(ma|0)>-1?ma:-ma|0;do{if((qa|0)>63){db=ma}else{if((qa|0)<(e[1099880+(oa<<1)>>1]|0)){db=(ba(la,ma)|0)>>8;break}ra=(ba(ia,ma)|0)>>8;if((ma|0)<0){db=ra-pa|0;break}else{db=ra+pa|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19464>>2]|0)!=0){break}pa=c[f+15724>>2]|0;ia=((pa|0)/-2|0)+1|0;la=(pa|0)/2|0;if((db|0)<(ia|0)){eb=ia;break c}eb=(db|0)>(la|0)?la:db;break c}}while(0);la=c[f+15724>>2]|0;ia=(la|0)/-2|0;pa=((la|0)/2|0)-1|0;if((db|0)<(ia|0)){eb=ia;break}eb=(db|0)>(pa|0)?pa:db}else{pa=c[f+19440>>2]|0;cb=(pa|0)>3?3:pa;r=133}}while(0);if((r|0)==133){eb=(ba(e[1098432+((sa^o)*56|0)+(cb<<1)>>1]|0,ma)|0)>>8}fb=na;gb=eb<<p&65535}else{fb=wa;gb=xa}a[(c[f+19408+(o<<2)>>2]|0)+(z+t)|0]=1;c[f+19460+(o<<2)>>2]=(c[f+19456>>2]|0)==0;hb=fb;ib=gb;jb=Za;kb=_a;lb=Ra;mb=Sa}}while(0);if((r|0)==136){if((Da|0)==0|Ea^1){nb=Ba;ob=Ca}else{Da=Ba<<16>>16>>p;Ba=(c[f+9992>>2]|0)==3;Sa=c[f+19436>>2]|0;do{if(Ba){Ra=(o|0)==0;_a=f+19488|0;if((Sa|0)!=0|Ra){pb=Ra?f+19484|0:_a;r=141;break}else{Ra=c[_a>>2]|0;qb=(ba(e[1099848+(((Ra|0)>3?3:Ra)<<1)>>1]|0,Da)|0)>>8<<p&65535;rb=Ca<<16>>16>>p;r=151;break}}else{pb=f+19440|0;r=141}}while(0);do{if((r|0)==141){Ra=Sa^o;_a=c[pb>>2]|0;Za=(_a|0)>3?3:_a;_a=e[1098440+(Ra*56|0)+(Za<<1)>>1]|0;gb=e[1098448+(Ra*56|0)+(Za<<1)>>1]|0;fb=e[1098472+(Ra*56|0)+(Za<<1)>>1]|0;eb=(Da|0)>-1?Da:-Da|0;do{if((eb|0)>255){sb=Da}else{if((eb|0)<(e[1098456+(Ra*56|0)+(Za<<1)>>1]|0)){sb=(ba(_a,Da)|0)>>8;break}cb=(ba(gb,Da)|0)>>8;if((Da|0)<0){sb=cb-fb|0;break}else{sb=cb+fb|0;break}}}while(0);fb=c[f+15720>>2]|0;gb=-fb|0;_a=fb-1|0;if((sb|0)<(gb|0)){tb=gb}else{tb=(sb|0)>(_a|0)?_a:sb}_a=tb<<p&65535;gb=Ca<<16>>16>>p;if(Ba){qb=_a;rb=gb;r=151;break}ub=f+19440|0;vb=_a;wb=gb;r=154}}while(0);do{if((r|0)==151){Ba=(o|0)==0;Ca=f+19488|0;if((Sa|0)!=0|Ba){ub=Ba?f+19484|0:Ca;vb=qb;wb=rb;r=154;break}else{Ba=c[Ca>>2]|0;xb=(ba(e[1099848+(((Ba|0)>3?3:Ba)<<1)>>1]|0,rb)|0)>>8;yb=qb;break}}}while(0);d:do{if((r|0)==154){qb=Sa^o;rb=c[ub>>2]|0;Ba=(rb|0)>3?3:rb;rb=e[1098440+(qb*56|0)+(Ba<<1)>>1]|0;Ca=e[1098448+(qb*56|0)+(Ba<<1)>>1]|0;tb=e[1098480+(qb*56|0)+(Ba<<1)>>1]|0;sb=(wb|0)>-1?wb:-wb|0;do{if((sb|0)>63){zb=wb}else{if((sb|0)<(e[1098464+(qb*56|0)+(Ba<<1)>>1]|0)){zb=(ba(rb,wb)|0)>>8;break}Da=(ba(Ca,wb)|0)>>8;if((wb|0)<0){zb=Da-tb|0;break}else{zb=Da+tb|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19460+(o<<2)>>2]|0)!=0){break}tb=c[f+15724>>2]|0;Ca=((tb|0)/-2|0)+1|0;rb=(tb|0)/2|0;if((zb|0)<(Ca|0)){xb=Ca;yb=vb;break d}xb=(zb|0)>(rb|0)?rb:zb;yb=vb;break d}}while(0);rb=c[f+15724>>2]|0;Ca=(rb|0)/-2|0;tb=((rb|0)/2|0)-1|0;if((zb|0)<(Ca|0)){xb=Ca;yb=vb;break}xb=(zb|0)>(tb|0)?tb:zb;yb=vb}}while(0);nb=yb;ob=xb<<p&65535}if((Ha|0)==0|Fa^1){Ab=Ja;Bb=Ia}else{Ha=Ja<<16>>16>>p;Ja=(c[f+9992>>2]|0)==3;xb=c[f+19436>>2]|0;do{if(Ja){yb=(o|0)==0;vb=f+19488|0;if((xb|0)!=0|yb){Cb=yb?f+19484|0:vb;r=173;break}else{yb=c[vb>>2]|0;Db=(ba(e[1099848+(((yb|0)>3?3:yb)<<1)>>1]|0,Ha)|0)>>8<<p&65535;Eb=Ia<<16>>16>>p;r=183;break}}else{Cb=f+19440|0;r=173}}while(0);do{if((r|0)==173){yb=xb^o;vb=c[Cb>>2]|0;zb=(vb|0)>3?3:vb;vb=e[1098440+(yb*56|0)+(zb<<1)>>1]|0;wb=e[1098448+(yb*56|0)+(zb<<1)>>1]|0;ub=e[1098472+(yb*56|0)+(zb<<1)>>1]|0;Sa=(Ha|0)>-1?Ha:-Ha|0;do{if((Sa|0)>255){Fb=Ha}else{if((Sa|0)<(e[1098456+(yb*56|0)+(zb<<1)>>1]|0)){Fb=(ba(vb,Ha)|0)>>8;break}tb=(ba(wb,Ha)|0)>>8;if((Ha|0)<0){Fb=tb-ub|0;break}else{Fb=tb+ub|0;break}}}while(0);ub=c[f+15720>>2]|0;wb=-ub|0;vb=ub-1|0;if((Fb|0)<(wb|0)){Gb=wb}else{Gb=(Fb|0)>(vb|0)?vb:Fb}vb=Gb<<p&65535;wb=Ia<<16>>16>>p;if(Ja){Db=vb;Eb=wb;r=183;break}Hb=f+19440|0;Ib=vb;Jb=wb;r=186}}while(0);do{if((r|0)==183){Ja=(o|0)==0;Ia=f+19488|0;if((xb|0)!=0|Ja){Hb=Ja?f+19484|0:Ia;Ib=Db;Jb=Eb;r=186;break}else{Ja=c[Ia>>2]|0;Kb=(ba(e[1099848+(((Ja|0)>3?3:Ja)<<1)>>1]|0,Eb)|0)>>8;Lb=Db;break}}}while(0);e:do{if((r|0)==186){Db=xb^o;Eb=c[Hb>>2]|0;Ja=(Eb|0)>3?3:Eb;Eb=e[1098440+(Db*56|0)+(Ja<<1)>>1]|0;Ia=e[1098448+(Db*56|0)+(Ja<<1)>>1]|0;Gb=e[1098480+(Db*56|0)+(Ja<<1)>>1]|0;Fb=(Jb|0)>-1?Jb:-Jb|0;do{if((Fb|0)>63){Mb=Jb}else{if((Fb|0)<(e[1098464+(Db*56|0)+(Ja<<1)>>1]|0)){Mb=(ba(Eb,Jb)|0)>>8;break}Ha=(ba(Ia,Jb)|0)>>8;if((Jb|0)<0){Mb=Ha-Gb|0;break}else{Mb=Ha+Gb|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19460+(o<<2)>>2]|0)!=0){break}Gb=c[f+15724>>2]|0;Ia=((Gb|0)/-2|0)+1|0;Eb=(Gb|0)/2|0;if((Mb|0)<(Ia|0)){Kb=Ia;Lb=Ib;break e}Kb=(Mb|0)>(Eb|0)?Eb:Mb;Lb=Ib;break e}}while(0);Eb=c[f+15724>>2]|0;Ia=(Eb|0)/-2|0;Gb=((Eb|0)/2|0)-1|0;if((Mb|0)<(Ia|0)){Kb=Ia;Lb=Ib;break}Kb=(Mb|0)>(Gb|0)?Gb:Mb;Lb=Ib}}while(0);Ab=Lb;Bb=Kb<<p&65535}if((ya|0)==0|Ga^1){Nb=wa;Ob=xa}else{ya=wa<<16>>16>>p;wa=(c[f+9992>>2]|0)==3;Kb=c[f+19436>>2]|0;do{if(wa){Lb=(o|0)==0;Ib=f+19488|0;if((Kb|0)!=0|Lb){Pb=Lb?f+19484|0:Ib;r=205;break}else{Lb=c[Ib>>2]|0;Qb=(ba(e[1099848+(((Lb|0)>3?3:Lb)<<1)>>1]|0,ya)|0)>>8<<p&65535;Rb=xa<<16>>16>>p;r=215;break}}else{Pb=f+19440|0;r=205}}while(0);do{if((r|0)==205){Lb=Kb^o;Ib=c[Pb>>2]|0;Mb=(Ib|0)>3?3:Ib;Ib=e[1098440+(Lb*56|0)+(Mb<<1)>>1]|0;Jb=e[1098448+(Lb*56|0)+(Mb<<1)>>1]|0;Hb=e[1098472+(Lb*56|0)+(Mb<<1)>>1]|0;xb=(ya|0)>-1?ya:-ya|0;do{if((xb|0)>255){Sb=ya}else{if((xb|0)<(e[1098456+(Lb*56|0)+(Mb<<1)>>1]|0)){Sb=(ba(Ib,ya)|0)>>8;break}Gb=(ba(Jb,ya)|0)>>8;if((ya|0)<0){Sb=Gb-Hb|0;break}else{Sb=Gb+Hb|0;break}}}while(0);Hb=c[f+15720>>2]|0;Jb=-Hb|0;Ib=Hb-1|0;if((Sb|0)<(Jb|0)){Tb=Jb}else{Tb=(Sb|0)>(Ib|0)?Ib:Sb}Ib=Tb<<p&65535;Jb=xa<<16>>16>>p;if(wa){Qb=Ib;Rb=Jb;r=215;break}Ub=f+19440|0;Vb=Ib;Wb=Jb;r=218}}while(0);do{if((r|0)==215){wa=(o|0)==0;xa=f+19488|0;if((Kb|0)!=0|wa){Ub=wa?f+19484|0:xa;Vb=Qb;Wb=Rb;r=218;break}else{wa=c[xa>>2]|0;Xb=(ba(e[1099848+(((wa|0)>3?3:wa)<<1)>>1]|0,Rb)|0)>>8;Yb=Qb;break}}}while(0);f:do{if((r|0)==218){Qb=Kb^o;Rb=c[Ub>>2]|0;wa=(Rb|0)>3?3:Rb;Rb=e[1098440+(Qb*56|0)+(wa<<1)>>1]|0;xa=e[1098448+(Qb*56|0)+(wa<<1)>>1]|0;Tb=e[1098480+(Qb*56|0)+(wa<<1)>>1]|0;Sb=(Wb|0)>-1?Wb:-Wb|0;do{if((Sb|0)>63){Zb=Wb}else{if((Sb|0)<(e[1098464+(Qb*56|0)+(wa<<1)>>1]|0)){Zb=(ba(Rb,Wb)|0)>>8;break}ya=(ba(xa,Wb)|0)>>8;if((Wb|0)<0){Zb=ya-Tb|0;break}else{Zb=ya+Tb|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19460+(o<<2)>>2]|0)!=0){break}Tb=c[f+15724>>2]|0;xa=((Tb|0)/-2|0)+1|0;Rb=(Tb|0)/2|0;if((Zb|0)<(xa|0)){Xb=xa;Yb=Vb;break f}Xb=(Zb|0)>(Rb|0)?Rb:Zb;Yb=Vb;break f}}while(0);Rb=c[f+15724>>2]|0;xa=(Rb|0)/-2|0;Tb=((Rb|0)/2|0)-1|0;if((Zb|0)<(xa|0)){Xb=xa;Yb=Vb;break}Xb=(Zb|0)>(Tb|0)?Tb:Zb;Yb=Vb}}while(0);Nb=Yb;Ob=Xb<<p&65535}a[(c[f+19408+(o<<2)>>2]|0)+(z+t)|0]=0;c[f+19460+(o<<2)>>2]=c[f+19456>>2];hb=Nb;ib=Ob;jb=Ab;kb=Bb;lb=nb;mb=ob}do{if(Ea){_b=lb<<16>>16;$b=mb<<16>>16}else{if(Ga){_b=hb<<16>>16;$b=ib<<16>>16;break}if(!Fa){_b=0;$b=0;break}_b=jb<<16>>16;$b=kb<<16>>16}}while(0);do{if((za+Aa|0)>1){Fa=lb<<16>>16;ob=jb<<16>>16;nb=hb<<16>>16;do{if(lb<<16>>16>jb<<16>>16){if(!(hb<<16>>16>jb<<16>>16)){ac=ob;break}ac=(nb|0)>(Fa|0)?Fa:nb}else{if(!(jb<<16>>16>hb<<16>>16)){ac=ob;break}ac=(nb|0)>(Fa|0)?nb:Fa}}while(0);Fa=mb<<16>>16;nb=kb<<16>>16;ob=ib<<16>>16;if(mb<<16>>16>kb<<16>>16){if(!(ib<<16>>16>kb<<16>>16)){bc=ac;cc=nb;break}bc=ac;cc=(ob|0)>(Fa|0)?Fa:ob;break}else{if(!(kb<<16>>16>ib<<16>>16)){bc=ac;cc=nb;break}bc=ac;cc=(ob|0)>(Fa|0)?ob:Fa;break}}else{bc=_b;cc=$b}}while(0);$b=(c[N>>2]|0)==0;if($b){if(M){dc=32}else{dc=H?32:0}M=dc|c[K>>2]<<6;if(G){ec=32}else{ec=H?32:0}H=ec|c[f+12480>>2]<<6;ec=(c[f+116>>2]<<6)-4|0;G=(c[f+120>>2]<<6)-4|0;K=M+bc|0;if(E){fc=(K|0)<-60?-60-M|0:bc;gc=(H+cc|0)<-60?-60-H|0:cc}else{fc=(K|0)<-28?-28-M|0:bc;gc=(H+cc|0)<-28?-28-H|0:cc}K=(fc+M|0)>(ec|0)?ec-M|0:fc;fc=(gc+H|0)>(G|0)?G-H|0:gc;if(Ea&Ga){hc=fc;ic=K;r=260}else{jc=K;kc=fc;r=274}}else{if((c[f+9992>>2]|0)==3|Ea^1|Ga^1){lc=cc;mc=bc;r=275}else{hc=cc;ic=bc;r=260}}do{if((r|0)==260){if((a[m+B|0]|0)==0){bc=ic-(lb<<16>>16)|0;cc=hc-(mb<<16>>16)|0;nc=((cc|0)>-1?cc:-cc|0)+((bc|0)>-1?bc:-bc|0)|0}else{nc=((hc|0)>-1?hc:-hc|0)+((ic|0)>-1?ic:-ic|0)|0}if((nc|0)>32){bc=f+14128|0;cc=c[bc>>2]|0;Ga=d[(c[f+14120>>2]|0)+(cc>>>3)|0]|0;c[bc>>2]=((cc|0)<(c[f+14136>>2]|0))+cc;if((Ga&128>>>((cc&7)>>>0)|0)==0){jc=hb<<16>>16;kc=ib<<16>>16;r=274;break}else{jc=lb<<16>>16;kc=mb<<16>>16;r=274;break}}if((a[m+A|0]|0)==0){cc=ic-(hb<<16>>16)|0;Ga=hc-(ib<<16>>16)|0;oc=((Ga|0)>-1?Ga:-Ga|0)+((cc|0)>-1?cc:-cc|0)|0}else{oc=((hc|0)>-1?hc:-hc|0)+((ic|0)>-1?ic:-ic|0)|0}if((oc|0)<=32){jc=ic;kc=hc;r=274;break}cc=f+14128|0;Ga=c[cc>>2]|0;bc=d[(c[f+14120>>2]|0)+(Ga>>>3)|0]|0;c[cc>>2]=((Ga|0)<(c[f+14136>>2]|0))+Ga;if((bc&128>>>((Ga&7)>>>0)|0)==0){jc=hb<<16>>16;kc=ib<<16>>16;r=274;break}else{jc=lb<<16>>16;kc=mb<<16>>16;r=274;break}}}while(0);if((r|0)==274){if($b){pc=0;qc=l;rc=kc;sc=jc}else{lc=kc;mc=jc;r=275}}do{if((r|0)==275){jc=l>>((c[f+19444>>2]|0)!=0);if((c[f+19456>>2]|0)==0){pc=0;qc=jc;rc=lc;sc=mc;break}pc=(c[f+19460+(o<<2)>>2]|0)==0|0;qc=jc;rc=lc;sc=mc}}while(0);mc=(s+k+sc&(k<<1)+65535)-k&65535;k=(c[x>>2]|0)+t|0;b[(c[u>>2]|0)+(k<<2)>>1]=mc;c[f+11744+(o<<5)+(g<<3)>>2]=mc<<16>>16;mc=pc-qc+(rc+h+qc-pc&(qc<<1)+65535)&65535;b[(c[u>>2]|0)+(k<<2)+2>>1]=mc;c[f+11744+(o<<5)+(g<<3)+4>>2]=mc<<16>>16;if(!E){return}E=c[x>>2]|0;mc=E+t|0;g=c[u>>2]|0;u=g+(mc<<2)|0;k=E+(t+1)|0;b[g+(k<<2)>>1]=b[u>>1]|0;qc=g+(mc<<2)+2|0;b[g+(k<<2)+2>>1]=b[qc>>1]|0;pc=t+i|0;i=E+pc|0;b[g+(i<<2)>>1]=b[u>>1]|0;b[g+(i<<2)+2>>1]=b[qc>>1]|0;i=pc+1|0;h=E+i|0;b[g+(h<<2)>>1]=b[u>>1]|0;b[g+(h<<2)+2>>1]=b[qc>>1]|0;qc=f+19408+(o<<2)|0;o=c[qc>>2]|0;a[o+k|0]=a[o+mc|0]|0;mc=c[x>>2]|0;o=c[qc>>2]|0;k=a[o+(mc+t)|0]|0;a[o+(mc+i)|0]=k;a[(c[qc>>2]|0)+((c[x>>2]|0)+pc)|0]=k;return}function F2a(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=a+12476|0;f=a+124|0;g=a+19584|0;h=a+19592|0;i=a+152|0;j=a+148|0;k=a+12480|0;l=a+812|0;m=a+19600|0;n=a+15380|0;o=a+15728|0;p=a+15388|0;q=a+128|0;r=a+9148|0;s=a+16028|0;t=a+12544|0;u=0;v=c[e>>2]|0;do{w=c[f>>2]|0;x=v-w|0;y=c[g>>2]|0;z=c[y+(x<<2)>>2]|0;A=u<<2;B=z>>A;C=c[h>>2]|0;D=d[C+x|0]|0;E=(u|0)>3;F=c[(E?i:j)>>2]|0;if(E){G=c[a+12544+(u-3<<2)>>2]|0}else{G=(c[t>>2]|0)+((ba(F,(A&8)-8|0)|0)+(u<<3&8))|0}H=(u|0)<2;a:do{if((c[k>>2]|0)!=(c[l>>2]|0)|H){if(E){I=w;J=(c[m>>2]|0)+(x<<2)|0;K=(c[y+(v<<2)>>2]|0)>>>(A>>>0);L=(d[C+v|0]|0)>>>(A>>>0)}else{if(H){M=A+8|0;N=D>>>(M>>>0);O=z>>M}else{M=A-8|0;N=(d[C+v|0]|0)>>>(M>>>0);O=(c[y+(v<<2)>>2]|0)>>>(M>>>0)}M=c[q>>2]|0;I=M;J=(c[r>>2]|0)+((c[a+12496+(u<<2)>>2]|0)-(M<<1)<<2)|0;K=O;L=N}do{if((L&1|0)==0){if((D&1<<A|0)!=0){break}if((b[J>>1]|0)!=(b[J+(I<<2)>>1]|0)){break}if((b[J+2>>1]|0)!=(b[J+(I<<2)+2>>1]|0)){break}M=(K>>>2|B)&3;if((M|0)==0){break a}else if((M|0)==3){Xe[c[p>>2]&4095](G,F,d[o]|0);break a}P=c[n>>2]|0;if((M|0)==1){Xe[P&4095](G+4|0,F,d[o]|0);break a}else{Xe[P&4095](G,F,d[o]|0);break a}}}while(0);Xe[c[p>>2]&4095](G,F,d[o]|0)}}while(0);D=F<<2;y=G+(-D|0)|0;C=c[(c[s>>2]|0)+((c[e>>2]|0)-(c[f>>2]|0)<<2)>>2]>>A&15;do{if((C|0)==7|(C|0)==3){z=(B>>>2|B)&3;if((z|0)==3){Xe[c[p>>2]&4095](y,F,d[o]|0);break}else if((z|0)==0){break}H=c[n>>2]|0;if((z|0)==1){Xe[H&4095](G+(4-D)|0,F,d[o]|0);break}else{Xe[H&4095](y,F,d[o]|0);break}}}while(0);u=u+1|0;v=c[e>>2]|0}while((u|0)<6);if((v|0)==0){return}u=a+116|0;G=a+15384|0;n=a+15392|0;p=0;K=v;do{v=c[f>>2]|0;I=K-1-v|0;J=c[g>>2]|0;L=c[J+(I<<2)>>2]|0;N=p<<2;O=L>>N;l=c[h>>2]|0;k=d[l+I|0]|0;I=(p|0)>3;F=c[(I?i:j)>>2]|0;if(I){Q=(c[a+12544+(p-3<<2)>>2]|0)+(-(F<<3)|0)|0}else{Q=(c[t>>2]|0)+((p<<3&8)-8+(ba(F,N&8|-16)|0))|0}if((K|0)==(c[u>>2]|0)){if((p&5|0)==0){R=36}}else{R=36}b:do{if((R|0)==36){R=0;if(I){y=K-v|0;S=(c[m>>2]|0)+(y-1<<2)|0;T=(c[J+(y<<2)>>2]|0)>>>(N>>>0);U=(d[l+y|0]|0)>>>(N>>>0)}else{if((p&1|0)==0){y=N+4|0;V=k>>>(y>>>0);W=L>>y}else{y=K-v|0;D=N-4|0;V=(d[l+y|0]|0)>>>(D>>>0);W=(c[J+(y<<2)>>2]|0)>>>(D>>>0)}S=(c[r>>2]|0)+((c[a+12496+(p<<2)>>2]|0)-2-(c[q>>2]<<1)<<2)|0;T=W;U=V}do{if((k&1<<N|0)==0){if((U&1|0)!=0){break}if((b[S>>1]|0)!=(b[S+4>>1]|0)){break}if((b[S+2>>1]|0)!=(b[S+6>>1]|0)){break}D=(T>>>1|O)&5;if((D|0)==5){Xe[c[n>>2]&4095](Q,F,d[o]|0);break b}else if((D|0)==0){break b}y=c[G>>2]|0;if((D|0)==1){Xe[y&4095](Q+(F<<2)|0,F,d[o]|0);break b}else{Xe[y&4095](Q,F,d[o]|0);break b}}}while(0);Xe[c[n>>2]&4095](Q,F,d[o]|0)}}while(0);k=Q-4|0;do{if(((c[(c[s>>2]|0)+((c[e>>2]|0)-1-(c[f>>2]|0)<<2)>>2]>>N&15)-6|0)>>>0<2>>>0){J=(O>>>1|O)&5;if((J|0)==0){break}else if((J|0)==5){Xe[c[n>>2]&4095](k,F,d[o]|0);break}l=c[G>>2]|0;if((J|0)==1){Xe[l&4095](Q+((F<<2)-4)|0,F,d[o]|0);break}else{Xe[l&4095](k,F,d[o]|0);break}}}while(0);p=p+1|0;K=c[e>>2]|0}while((p|0)<6);if((K|0)!=((c[u>>2]|0)-1|0)){return}p=K+1|0;c[e>>2]=p;K=8>>>((c[(c[a+4>>2]|0)+800>>2]|0)>>>0);Q=a+12496|0;c[Q>>2]=(c[Q>>2]|0)+2;Q=a+12500|0;c[Q>>2]=(c[Q>>2]|0)+2;Q=a+12504|0;c[Q>>2]=(c[Q>>2]|0)+2;Q=a+12508|0;c[Q>>2]=(c[Q>>2]|0)+2;Q=a+12512|0;c[Q>>2]=(c[Q>>2]|0)+1;Q=a+12516|0;c[Q>>2]=(c[Q>>2]|0)+1;c[t>>2]=(c[t>>2]|0)+(K<<1);Q=a+12548|0;c[Q>>2]=(c[Q>>2]|0)+K;Q=a+12552|0;c[Q>>2]=(c[Q>>2]|0)+K;K=0;Q=p;while(1){p=c[f>>2]|0;T=Q-1-p|0;S=c[g>>2]|0;U=c[S+(T<<2)>>2]|0;V=K<<2;W=U>>V;F=c[h>>2]|0;k=d[F+T|0]|0;T=(K|0)>3;O=c[(T?i:j)>>2]|0;if(T){X=(c[a+12544+(K-3<<2)>>2]|0)+(-(O<<3)|0)|0}else{X=(c[t>>2]|0)+((K<<3&8)-8+(ba(O,V&8|-16)|0))|0}if((Q|0)==(c[u>>2]|0)){if((K&5|0)==0){R=66}}else{R=66}c:do{if((R|0)==66){R=0;if(T){N=Q-p|0;Y=(c[m>>2]|0)+(N-1<<2)|0;Z=(c[S+(N<<2)>>2]|0)>>>(V>>>0);_=(d[F+N|0]|0)>>>(V>>>0)}else{if((K&1|0)==0){N=V+4|0;$=k>>>(N>>>0);aa=U>>N}else{N=Q-p|0;l=V-4|0;$=(d[F+N|0]|0)>>>(l>>>0);aa=(c[S+(N<<2)>>2]|0)>>>(l>>>0)}Y=(c[r>>2]|0)+((c[a+12496+(K<<2)>>2]|0)-2-(c[q>>2]<<1)<<2)|0;Z=aa;_=$}do{if((k&1<<V|0)==0){if((_&1|0)!=0){break}if((b[Y>>1]|0)!=(b[Y+4>>1]|0)){break}if((b[Y+2>>1]|0)!=(b[Y+6>>1]|0)){break}l=(Z>>>1|W)&5;if((l|0)==5){Xe[c[n>>2]&4095](X,O,d[o]|0);break c}else if((l|0)==0){break c}N=c[G>>2]|0;if((l|0)==1){Xe[N&4095](X+(O<<2)|0,O,d[o]|0);break c}else{Xe[N&4095](X,O,d[o]|0);break c}}}while(0);Xe[c[n>>2]&4095](X,O,d[o]|0)}}while(0);k=X-4|0;do{if(((c[(c[s>>2]|0)+((c[e>>2]|0)-1-(c[f>>2]|0)<<2)>>2]>>V&15)-6|0)>>>0<2>>>0){S=(W>>>1|W)&5;if((S|0)==0){break}else if((S|0)==5){Xe[c[n>>2]&4095](k,O,d[o]|0);break}F=c[G>>2]|0;if((S|0)==1){Xe[F&4095](X+((O<<2)-4)|0,O,d[o]|0);break}else{Xe[F&4095](k,O,d[o]|0);break}}}while(0);O=K+1|0;if((O|0)>=6){break}K=O;Q=c[e>>2]|0}return}function G2a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;do{if((c[a+14084>>2]|0)==0){b=a+12476|0;e=c[b>>2]|0;if((e|0)==0){f=0;g=0}else{if((c[a+19224>>2]|0)==1){h=e-1+(ba((c[a+12480>>2]|0)-1|0,c[a+124>>2]|0)|0)|0;i=d[(c[a+19324>>2]|0)+h|0]|0}else{i=0}h=a+148|0;e=c[h>>2]|0;j=e<<i;k=16-i>>((i|0)==0);l=a+10068|0;m=a+19572|0;n=a+19556|0;o=a+12544|0;Xe[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)|0,(c[o>>2]|0)+(-16-(e<<4))|0,j);Xe[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+128|0,(c[o>>2]|0)+(-8-(c[h>>2]<<4))|0,j);e=(c[o>>2]|0)+(-16-(ba(c[h>>2]|0,k)|0))|0;Xe[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+256|0,e,j);e=(c[o>>2]|0)+(-8-(ba(c[h>>2]|0,k)|0))|0;Xe[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+384|0,e,j);j=a+152|0;e=c[j>>2]|0;Xe[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+512|0,(c[a+12548>>2]|0)+(-8-(e<<3))|0,e);e=c[j>>2]|0;Xe[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+640|0,(c[a+12552>>2]|0)+(-8-(e<<3))|0,e);f=i;g=c[b>>2]|0}if((g|0)!=((c[a+116>>2]|0)-1|0)){break}if((c[a+19224>>2]|0)==1){b=(ba((c[a+12480>>2]|0)-1|0,c[a+124>>2]|0)|0)+g|0;p=d[(c[a+19324>>2]|0)+b|0]|0}else{p=f}b=a+148|0;e=c[b>>2]|0;m=e<<p;n=(p|0)!=0?15:8;l=a+10068|0;j=a+19576|0;k=a+19556|0;h=a+12544|0;Xe[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)|0,(c[h>>2]|0)+(-(e<<4)|0)|0,m);Xe[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+128|0,(c[h>>2]|0)+(-(c[b>>2]<<4)|8)|0,m);e=(c[h>>2]|0)+(ba(c[b>>2]|0,-n|0)|0)|0;Xe[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+256|0,e,m);e=(c[h>>2]|0)+(8-(ba(c[b>>2]|0,n)|0))|0;Xe[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+384|0,e,m);m=a+152|0;e=c[m>>2]|0;Xe[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+512|0,(c[a+12548>>2]|0)+(-(e<<3)|0)|0,e);e=c[m>>2]|0;Xe[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+640|0,(c[a+12552>>2]|0)+(-(e<<3)|0)|0,e)}}while(0);p=a+19572|0;f=(c[p>>2]|0)+1|0;c[p>>2]=f;g=c[a+19560>>2]|0;if((f|0)<(g|0)){q=a+19576|0;r=c[q>>2]|0;s=r+1|0;t=(s|0)<(g|0);u=t?s:0;c[q>>2]=u;v=a+19568|0;w=c[v>>2]|0;x=w+1|0;y=(x|0)<(g|0);z=y?x:0;c[v>>2]=z;A=a+19564|0;B=c[A>>2]|0;C=B+1|0;D=(C|0)<(g|0);E=D?C:0;c[A>>2]=E;return}c[p>>2]=0;q=a+19576|0;r=c[q>>2]|0;s=r+1|0;t=(s|0)<(g|0);u=t?s:0;c[q>>2]=u;v=a+19568|0;w=c[v>>2]|0;x=w+1|0;y=(x|0)<(g|0);z=y?x:0;c[v>>2]=z;A=a+19564|0;B=c[A>>2]|0;C=B+1|0;D=(C|0)<(g|0);E=D?C:0;c[A>>2]=E;return}function H2a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((c[a+14084>>2]|0)!=0){return}d=a+12476|0;if((c[d>>2]|0)==0){e=0}else{f=a+15396|0;do{if((c[a+12480>>2]|0)<((c[a+808>>2]|0)+2|0)){g=a+12544|0;h=a+148|0}else{i=a+12544|0;j=a+148|0;k=c[j>>2]|0;Xe[c[f>>2]&4095]((c[i>>2]|0)+(-16-(k<<4))|0,k,b);k=a+15400|0;if((c[d>>2]|0)>1){l=c[j>>2]|0;Xe[c[k>>2]&4095]((c[i>>2]|0)+(-16-(l<<5))|0,l,b)}l=c[j>>2]|0;Xe[c[k>>2]&4095]((c[i>>2]|0)+(-8-(l<<5))|0,l,b);l=a+15388|0;k=a+152|0;m=a+15392|0;n=a+12548|0;o=c[k>>2]|0;Xe[c[l>>2]&4095]((c[n>>2]|0)+(-8-(o<<3))|0,o,b);if((c[d>>2]|0)>1){o=c[k>>2]|0;Xe[c[m>>2]&4095]((c[n>>2]|0)+(-8-(o<<4))|0,o,b)}o=a+12552|0;n=c[k>>2]|0;Xe[c[l>>2]&4095]((c[o>>2]|0)+(-8-(n<<3))|0,n,b);if((c[d>>2]|0)<=1){g=i;h=j;break}n=c[k>>2]|0;Xe[c[m>>2]&4095]((c[o>>2]|0)+(-8-(n<<4))|0,n,b);g=i;h=j}}while(0);j=c[h>>2]|0;Xe[c[f>>2]&4095]((c[g>>2]|0)+(-16-(j<<3))|0,j,b);e=c[d>>2]|0}j=a+116|0;g=a+12480|0;if((e|0)==((c[j>>2]|0)-1|0)){e=a+15396|0;do{if((c[g>>2]|0)<((c[a+808>>2]|0)+2|0)){p=a+12544|0;q=a+148|0}else{f=a+12544|0;h=a+148|0;i=c[h>>2]|0;Xe[c[e>>2]&4095]((c[f>>2]|0)+(-(i<<4)|0)|0,i,b);i=a+15400|0;if((c[d>>2]|0)!=0){n=c[h>>2]|0;Xe[c[i>>2]&4095]((c[f>>2]|0)+(-(n<<5)|0)|0,n,b)}n=c[h>>2]|0;Xe[c[i>>2]&4095]((c[f>>2]|0)+(-(n<<5)|8)|0,n,b);n=a+15388|0;i=a+152|0;o=a+15392|0;m=a+12548|0;k=c[i>>2]|0;Xe[c[n>>2]&4095]((c[m>>2]|0)+(-(k<<3)|0)|0,k,b);if((c[d>>2]|0)>1){k=c[i>>2]|0;Xe[c[o>>2]&4095]((c[m>>2]|0)+(-(k<<4)|0)|0,k,b)}k=a+12552|0;m=c[i>>2]|0;Xe[c[n>>2]&4095]((c[k>>2]|0)+(-(m<<3)|0)|0,m,b);if((c[d>>2]|0)<=1){p=f;q=h;break}m=c[i>>2]|0;Xe[c[o>>2]&4095]((c[k>>2]|0)+(-(m<<4)|0)|0,m,b);p=f;q=h}}while(0);h=c[q>>2]|0;Xe[c[e>>2]&4095]((c[p>>2]|0)+(-(h<<3)|0)|0,h,b)}if((c[g>>2]|0)!=(c[a+812>>2]|0)){return}g=c[d>>2]|0;do{if((g|0)==0){r=0}else{h=a+15400|0;if((g|0)>1){p=a+12544|0;e=a+148|0;q=c[e>>2]|0;Xe[c[h>>2]&4095]((c[p>>2]|0)+(-16-(q<<4))|0,q,b);s=p;t=e}else{s=a+12544|0;t=a+148|0}e=c[t>>2]|0;Xe[c[h>>2]&4095]((c[s>>2]|0)+(-8-(e<<4))|0,e,b);e=c[d>>2]|0;if((e|0)<=1){r=e;break}e=a+15392|0;h=a+152|0;p=c[h>>2]|0;Xe[c[e>>2]&4095]((c[a+12548>>2]|0)+(-8-(p<<3))|0,p,b);p=c[h>>2]|0;Xe[c[e>>2]&4095]((c[a+12552>>2]|0)+(-8-(p<<3))|0,p,b);r=c[d>>2]|0}}while(0);if((r|0)!=((c[j>>2]|0)-1|0)){return}j=a+15400|0;if((r|0)==0){u=a+12544|0;v=a+148|0}else{r=a+12544|0;s=a+148|0;t=c[s>>2]|0;Xe[c[j>>2]&4095]((c[r>>2]|0)+(-(t<<4)|0)|0,t,b);u=r;v=s}s=c[v>>2]|0;Xe[c[j>>2]&4095]((c[u>>2]|0)+(-(s<<4)|8)|0,s,b);if((c[d>>2]|0)==0){return}d=a+15392|0;s=a+152|0;u=c[s>>2]|0;Xe[c[d>>2]&4095]((c[a+12548>>2]|0)+(-(u<<3)|0)|0,u,b);u=c[s>>2]|0;Xe[c[d>>2]&4095]((c[a+12552>>2]|0)+(-(u<<3)|0)|0,u,b);return}function I2a(a){a=a|0;c[a>>2]=144;c[a+8>>2]=2260;c[a+4>>2]=1210;c[a+12>>2]=766;c[a+16>>2]=1328;c[a+24>>2]=1684;c[a+20>>2]=1230;c[a+28>>2]=1380;c[a+36>>2]=430;c[a+32>>2]=302;c[a+44>>2]=148;c[a+40>>2]=136;c[a+48>>2]=126;c[a+52>>2]=418;c[a+56>>2]=562;c[a+60>>2]=1626;c[a+64>>2]=2108;c[a+68>>2]=2082;c[a+72>>2]=420;c[a+76>>2]=212;c[a+80>>2]=692;c[a+84>>2]=862;c[a+88>>2]=674;c[a+92>>2]=118;c[a+96>>2]=156;c[a+100>>2]=468;c[a+104>>2]=428;c[a+108>>2]=676;c[a+112>>2]=368;c[a+116>>2]=248;c[a+120>>2]=298;c[a+124>>2]=314;c[a+128>>2]=228;c[a+132>>2]=384;c[a+136>>2]=588;c[a+140>>2]=490;c[a+144>>2]=708;c[a+148>>2]=130;c[a+152>>2]=182;c[a+156>>2]=382;c[a+160>>2]=844;c[a+164>>2]=466;c[a+168>>2]=734;c[a+172>>2]=750;c[a+176>>2]=56;c[a+180>>2]=796;c[a+184>>2]=624;c[a+188>>2]=596;c[a+192>>2]=170;c[a+196>>2]=670;c[a+200>>2]=266;c[a+212>>2]=114;c[a+204>>2]=126;c[a+216>>2]=66;c[a+224>>2]=476;c[a+228>>2]=246;c[a+232>>2]=264;c[a+236>>2]=276;c[a+240>>2]=148;return}function J2a(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=i;i=i+128|0;d=c|0;e=0;f=a;g=d;while(1){h=b[f>>1]|0;j=b[f+64>>1]|0;k=((j+h|0)*12|0)+4|0;l=((h-j|0)*12|0)+4|0;j=b[f+32>>1]|0;h=b[f+96>>1]|0;m=(h*6|0)+(j<<4)|0;n=(j*6|0)-(h<<4)|0;h=m+k|0;j=n+l|0;o=l-n|0;n=k-m|0;m=b[f+16>>1]|0;k=b[f+48>>1]|0;l=b[f+80>>1]|0;p=b[f+112>>1]|0;q=(k*15|0)+(m<<4)+(l*9|0)+(p<<2)|0;r=(m*15|0)-(k<<2)-(l<<4)+(p*-9|0)|0;s=(m*9|0)-(k<<4)+(l<<2)+(p*15|0)|0;t=(k*-9|0)+(m<<2)+(l*15|0)-(p<<4)|0;b[g>>1]=(q+h|0)>>>3;b[g+2>>1]=(r+j|0)>>>3;b[g+4>>1]=(s+o|0)>>>3;b[g+6>>1]=(t+n|0)>>>3;b[g+8>>1]=(n-t|0)>>>3;b[g+10>>1]=(o-s|0)>>>3;b[g+12>>1]=(j-r|0)>>>3;b[g+14>>1]=(h-q|0)>>>3;q=e+1|0;if((q|0)<8){e=q;f=f+2|0;g=g+16|0}else{u=0;v=d;w=a;break}}while(1){a=b[v>>1]|0;d=b[v+64>>1]|0;g=((d+a|0)*12|0)+64|0;f=((a-d|0)*12|0)+64|0;d=b[v+32>>1]|0;a=b[v+96>>1]|0;e=(a*6|0)+(d<<4)|0;q=(d*6|0)-(a<<4)|0;a=e+g|0;d=q+f|0;h=f-q|0;q=g-e|0;e=b[v+16>>1]|0;g=b[v+48>>1]|0;f=b[v+80>>1]|0;r=b[v+112>>1]|0;j=(g*15|0)+(e<<4)+(f*9|0)+(r<<2)|0;s=(e*15|0)-(g<<2)-(f<<4)+(r*-9|0)|0;o=(e*9|0)-(g<<4)+(f<<2)+(r*15|0)|0;t=(g*-9|0)+(e<<2)+(f*15|0)-(r<<4)|0;b[w>>1]=(j+a|0)>>>7;b[w+16>>1]=(s+d|0)>>>7;b[w+32>>1]=(o+h|0)>>>7;b[w+48>>1]=(t+q|0)>>>7;b[w+64>>1]=((q|1)-t|0)>>>7;b[w+80>>1]=((h|1)-o|0)>>>7;b[w+96>>1]=((d|1)-s|0)>>>7;b[w+112>>1]=((a|1)-j|0)>>>7;j=u+1|0;if((j|0)<8){u=j;v=v+2|0;w=w+2|0}else{break}}i=c;return}function K2a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=0;h=f;while(1){i=b[h>>1]|0;j=h+4|0;k=b[j>>1]|0;l=((k+i|0)*17|0)+4|0;m=((i-k|0)*17|0)+4|0;k=h+2|0;i=b[k>>1]|0;n=h+6|0;o=b[n>>1]|0;p=(o*10|0)+(i*22|0)|0;q=(o*22|0)+(i*-10|0)|0;b[h>>1]=(p+l|0)>>>3;b[k>>1]=(m-q|0)>>>3;b[j>>1]=(q+m|0)>>>3;b[n>>1]=(l-p|0)>>>3;p=g+1|0;if((p|0)<8){g=p;h=h+16|0}else{break}}h=e<<1;g=e*3|0;p=e<<2;l=e*5|0;n=e*6|0;m=e*7|0;q=0;j=c;c=f;while(1){f=b[c>>1]|0;k=b[c+64>>1]|0;i=((k+f|0)*12|0)+64|0;o=((f-k|0)*12|0)+64|0;k=b[c+32>>1]|0;f=b[c+96>>1]|0;r=(f*6|0)+(k<<4)|0;s=(k*6|0)-(f<<4)|0;f=r+i|0;k=s+o|0;t=o-s|0;s=i-r|0;r=b[c+16>>1]|0;i=b[c+48>>1]|0;o=b[c+80>>1]|0;u=b[c+112>>1]|0;v=(i*15|0)+(r<<4)+(o*9|0)+(u<<2)|0;w=(r*15|0)-(i<<2)-(o<<4)+(u*-9|0)|0;x=(r*9|0)-(i<<4)+(o<<2)+(u*15|0)|0;y=(i*-9|0)+(r<<2)+(o*15|0)-(u<<4)|0;u=(v+f>>7)+(d[j]|0)|0;if(u>>>0>255>>>0){z=-u>>31&255}else{z=u&255}a[j]=z;u=j+e|0;o=(d[u]|0)+(w+k>>7)|0;if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}a[u]=A;u=j+h|0;o=(d[u]|0)+(x+t>>7)|0;if(o>>>0>255>>>0){B=-o>>31&255}else{B=o&255}a[u]=B;u=j+g|0;o=(d[u]|0)+(y+s>>7)|0;if(o>>>0>255>>>0){C=-o>>31&255}else{C=o&255}a[u]=C;u=j+p|0;o=(d[u]|0)+((s|1)-y>>7)|0;if(o>>>0>255>>>0){D=-o>>31&255}else{D=o&255}a[u]=D;u=j+l|0;o=(d[u]|0)+((t|1)-x>>7)|0;if(o>>>0>255>>>0){E=-o>>31&255}else{E=o&255}a[u]=E;u=j+n|0;o=(d[u]|0)+((k|1)-w>>7)|0;if(o>>>0>255>>>0){F=-o>>31&255}else{F=o&255}a[u]=F;u=j+m|0;o=(d[u]|0)+((f|1)-v>>7)|0;if(o>>>0>255>>>0){G=-o>>31&255}else{G=o&255}a[u]=G;u=q+1|0;if((u|0)<4){q=u;j=j+1|0;c=c+2|0}else{break}}return}function L2a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=0;h=f;while(1){i=b[h>>1]|0;j=h+8|0;k=b[j>>1]|0;l=((k+i|0)*12|0)+4|0;m=((i-k|0)*12|0)+4|0;k=h+4|0;i=b[k>>1]|0;n=h+12|0;o=b[n>>1]|0;p=(o*6|0)+(i<<4)|0;q=(i*6|0)-(o<<4)|0;o=p+l|0;i=q+m|0;r=m-q|0;q=l-p|0;p=h+2|0;l=b[p>>1]|0;m=h+6|0;s=b[m>>1]|0;t=h+10|0;u=b[t>>1]|0;v=h+14|0;w=b[v>>1]|0;x=(s*15|0)+(l<<4)+(u*9|0)+(w<<2)|0;y=(l*15|0)-(s<<2)-(u<<4)+(w*-9|0)|0;z=(l*9|0)-(s<<4)+(u<<2)+(w*15|0)|0;A=(s*-9|0)+(l<<2)+(u*15|0)-(w<<4)|0;b[h>>1]=(x+o|0)>>>3;b[p>>1]=(y+i|0)>>>3;b[k>>1]=(z+r|0)>>>3;b[m>>1]=(A+q|0)>>>3;b[j>>1]=(q-A|0)>>>3;b[t>>1]=(r-z|0)>>>3;b[n>>1]=(i-y|0)>>>3;b[v>>1]=(o-x|0)>>>3;x=g+1|0;if((x|0)<4){g=x;h=h+16|0}else{break}}h=e<<1;g=e*3|0;x=0;o=c;c=f;while(1){f=b[c>>1]|0;v=b[c+32>>1]|0;y=((v+f|0)*17|0)+64|0;i=((f-v|0)*17|0)+64|0;v=b[c+16>>1]|0;f=b[c+48>>1]|0;n=(f*10|0)+(v*22|0)|0;z=(f*22|0)+(v*-10|0)|0;v=(n+y>>7)+(d[o]|0)|0;if(v>>>0>255>>>0){B=-v>>31&255}else{B=v&255}a[o]=B;v=o+e|0;f=(d[v]|0)+(i-z>>7)|0;if(f>>>0>255>>>0){C=-f>>31&255}else{C=f&255}a[v]=C;v=o+h|0;f=(d[v]|0)+(z+i>>7)|0;if(f>>>0>255>>>0){D=-f>>31&255}else{D=f&255}a[v]=D;v=o+g|0;f=(d[v]|0)+(y-n>>7)|0;if(f>>>0>255>>>0){E=-f>>31&255}else{E=f&255}a[v]=E;v=x+1|0;if((v|0)<8){x=v;o=o+1|0;c=c+2|0}else{break}}return}function M2a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=0;h=f;while(1){i=b[h>>1]|0;j=h+4|0;k=b[j>>1]|0;l=((k+i|0)*17|0)+4|0;m=((i-k|0)*17|0)+4|0;k=h+2|0;i=b[k>>1]|0;n=h+6|0;o=b[n>>1]|0;p=(o*10|0)+(i*22|0)|0;q=(o*22|0)+(i*-10|0)|0;b[h>>1]=(p+l|0)>>>3;b[k>>1]=(m-q|0)>>>3;b[j>>1]=(q+m|0)>>>3;b[n>>1]=(l-p|0)>>>3;p=g+1|0;if((p|0)<4){g=p;h=h+16|0}else{break}}h=e<<1;g=e*3|0;p=c;c=0;l=f;while(1){f=b[l>>1]|0;n=b[l+32>>1]|0;m=((n+f|0)*17|0)+64|0;q=((f-n|0)*17|0)+64|0;n=b[l+16>>1]|0;f=b[l+48>>1]|0;j=(f*10|0)+(n*22|0)|0;k=(f*22|0)+(n*-10|0)|0;n=(j+m>>7)+(d[p]|0)|0;if(n>>>0>255>>>0){r=-n>>31&255}else{r=n&255}a[p]=r;n=p+e|0;f=(d[n]|0)+(q-k>>7)|0;if(f>>>0>255>>>0){s=-f>>31&255}else{s=f&255}a[n]=s;n=p+h|0;f=(d[n]|0)+(k+q>>7)|0;if(f>>>0>255>>>0){t=-f>>31&255}else{t=f&255}a[n]=t;n=p+g|0;f=(d[n]|0)+(m-j>>7)|0;if(f>>>0>255>>>0){u=-f>>31&255}else{u=f&255}a[n]=u;n=c+1|0;if((n|0)<4){p=p+1|0;c=n;l=l+2|0}else{break}}return}function N2a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=((((b[f>>1]|0)*3|0)+1>>1)*3|0)+16>>5;f=c;c=0;while(1){h=(d[f]|0)+g|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[f]=i;h=f+1|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=f+2|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=f+3|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=f+4|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[h]=n;h=f+5|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[h]=o;h=f+6|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[h]=p;h=f+7|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[h]=q;h=c+1|0;if((h|0)<8){f=f+e|0;c=h}else{break}}return}function O2a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=((((b[f>>1]|0)*17|0)+4>>3)*12|0)+64>>7;f=c;c=0;while(1){h=(d[f]|0)+g|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[f]=i;h=f+1|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=f+2|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=f+3|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=c+1|0;if((h|0)<8){f=f+e|0;c=h}else{break}}return}function P2a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=((((b[f>>1]|0)*3|0)+1>>1)*17|0)+64>>7;f=c;c=0;while(1){h=(d[f]|0)+g|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[f]=i;h=f+1|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=f+2|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=f+3|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=f+4|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[h]=n;h=f+5|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[h]=o;h=f+6|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[h]=p;h=f+7|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[h]=q;h=c+1|0;if((h|0)<4){f=f+e|0;c=h}else{break}}return}function Q2a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=((((b[f>>1]|0)*17|0)+4>>3)*17|0)+64>>7;f=c;c=0;while(1){h=(d[f]|0)+g|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[f]=i;h=f+1|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=f+2|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=f+3|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=c+1|0;if((h|0)<4){f=f+e|0;c=h}else{break}}return}function R2a(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=0;f=b;b=1;while(1){g=f-2|0;h=d[g]|0;i=f-1|0;j=d[i]|0;k=d[f]|0;l=f+1|0;m=d[l]|0;n=h-m|0;o=b+3+n>>3;p=4-b+j-k+n>>3;a[g]=h-o;h=j-p|0;if(h>>>0>255>>>0){q=-h>>31&255}else{q=h&255}a[i]=q;i=p+k|0;if(i>>>0>255>>>0){r=-i>>31&255}else{r=i&255}a[f]=r;a[l]=o+m;m=e+1|0;if((m|0)<8){e=m;f=f+c|0;b=b^1}else{break}}return}function S2a(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=c*-2|0;f=-c|0;g=0;h=b;b=1;while(1){i=h+e|0;j=d[i]|0;k=h+f|0;l=d[k]|0;m=d[h]|0;n=h+c|0;o=d[n]|0;p=j-o|0;q=b+3+p>>3;r=4-b+l-m+p>>3;a[i]=j-q;j=l-r|0;if(j>>>0>255>>>0){s=-j>>31&255}else{s=j&255}a[k]=s;k=r+m|0;if(k>>>0>255>>>0){t=-k>>31&255}else{t=k&255}a[h]=t;a[n]=q+o;o=g+1|0;if((o|0)<8){g=o;h=h+1|0;b=b^1}else{break}}return}function T2a(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=0;e=c;c=a;a=4;f=3;while(1){g=c+12|0;h=b[g>>1]|0;i=c+14|0;j=b[i>>1]|0;k=b[e>>1]|0;l=e+2|0;m=b[l>>1]|0;n=h-m|0;o=j-k+n|0;b[g>>1]=((h<<3)+a-n|0)>>>3;b[i>>1]=((j<<3)+f-o|0)>>>3;b[e>>1]=((k<<3)+a+o|0)>>>3;b[l>>1]=(n+f+(m<<3)|0)>>>3;m=d+1|0;if((m|0)<8){d=m;e=e+16|0;c=c+16|0;a=7-a|0;f=7-f|0}else{break}}return}function U2a(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=0;e=c;c=a;a=4;f=3;while(1){g=c+96|0;h=b[g>>1]|0;i=c+112|0;j=b[i>>1]|0;k=b[e>>1]|0;l=e+16|0;m=b[l>>1]|0;n=h-m|0;o=j-k+n|0;b[g>>1]=((h<<3)+a-n|0)>>>3;b[i>>1]=((j<<3)+f-o|0)>>>3;b[e>>1]=((k<<3)+a+o|0)>>>3;b[l>>1]=(n+f+(m<<3)|0)>>>3;m=d+1|0;if((m|0)<8){d=m;e=e+2|0;c=c+2|0;a=7-a|0;f=7-f|0}else{break}}return}function V2a(a,b,c){a=a|0;b=b|0;c=c|0;O3a(a,1,b,4,c);return}function W2a(a,b,c){a=a|0;b=b|0;c=c|0;O3a(a,b,1,4,c);return}function X2a(a,b,c){a=a|0;b=b|0;c=c|0;O3a(a,1,b,8,c);return}function Y2a(a,b,c){a=a|0;b=b|0;c=c|0;O3a(a,b,1,8,c);return}function Z2a(a,b,c){a=a|0;b=b|0;c=c|0;O3a(a,1,b,16,c);return}function _2a(a,b,c){a=a|0;b=b|0;c=c|0;O3a(a,b,1,16,c);return}function $2a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(e+4)|0;c[a+(e+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=e<<1;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;e=b+g|0;c[a+h>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=b+(g+4)|0;c[a+(h+4)>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function a3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=32-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=b+1|0;j=g+((d[f+(b-1)|0]|0)*-4|0)+((d[f+b|0]|0)*53|0)+((d[f+i|0]|0)*18|0)+((d[f+(b+2)|0]|0)*-3|0)>>6;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h+b|0]=k;if((i|0)<8){b=i}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function b3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=8-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=b+1|0;j=g-(d[f+(b-1)|0]|0)-(d[f+(b+2)|0]|0)+(((d[f+i|0]|0)+(d[f+b|0]|0)|0)*9|0)>>4;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h+b|0]=k;if((i|0)<8){b=i}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function c3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=32-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=b+1|0;j=g+((d[f+(b-1)|0]|0)*-3|0)+((d[f+b|0]|0)*18|0)+((d[f+i|0]|0)*53|0)-((d[f+(b+2)|0]|0)<<2)>>6;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h+b|0]=k;if((i|0)<8){b=i}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function d3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=e<<1;h=f+31|0;f=c;c=0;i=b;while(1){b=0;do{j=h+((d[f+(b-e)|0]|0)*-4|0)+((d[f+b|0]|0)*53|0)+((d[f+(b+e)|0]|0)*18|0)+((d[f+(b+g)|0]|0)*-3|0)>>6;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i+b|0]=k;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function e3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-4|0)+((l<<16>>16)*53|0)+((k<<16>>16)*18|0)+((p<<16>>16)*-3|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function f3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n-(m<<16>>16)-(p<<16>>16)+(((k<<16>>16)+(l<<16>>16)|0)*9|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function g3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-3|0)+((l<<16>>16)*18|0)+((k<<16>>16)*53|0)-(p<<16>>16<<2)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function h3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=e<<1;h=f+7|0;f=c;c=0;i=b;while(1){b=0;do{j=h-(d[f+(b-e)|0]|0)-(d[f+(b+g)|0]|0)+(((d[f+(b+e)|0]|0)+(d[f+b|0]|0)|0)*9|0)>>4;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i+b|0]=k;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function i3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l-(d[m+(o-f)|0]|0)-(d[m+(o+k)|0]|0)+(((d[m+(o+f)|0]|0)+(d[m+o|0]|0)|0)*9|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-4|0)+((l<<16>>16)*53|0)+((k<<16>>16)*18|0)+((p<<16>>16)*-3|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function j3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=e-1|0;e=0;m=j|0;while(1){n=0;do{b[m+(n<<1)>>1]=(g-(d[l+(n-f)|0]|0)-(d[l+(n+k)|0]|0)+(((d[l+(n+f)|0]|0)+(d[l+n|0]|0)|0)*9|0)|0)>>>1;n=n+1|0;}while((n|0)<11);n=e+1|0;if((n|0)<8){l=l+f|0;e=n;m=m+22|0}else{break}}m=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;l=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){n=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=m-(l<<16>>16)-(p<<16>>16)+(((k<<16>>16)+(n<<16>>16)|0)*9|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;l=n;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function k3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l-(d[m+(o-f)|0]|0)-(d[m+(o+k)|0]|0)+(((d[m+(o+f)|0]|0)+(d[m+o|0]|0)|0)*9|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-3|0)+((l<<16>>16)*18|0)+((k<<16>>16)*53|0)-(p<<16>>16<<2)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function l3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=e<<1;h=f+31|0;f=c;c=0;i=b;while(1){b=0;do{j=h+((d[f+(b-e)|0]|0)*-3|0)+((d[f+b|0]|0)*18|0)+((d[f+(b+e)|0]|0)*53|0)-((d[f+(b+g)|0]|0)<<2)>>6;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i+b|0]=k;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function m3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-4|0)+((l<<16>>16)*53|0)+((k<<16>>16)*18|0)+((p<<16>>16)*-3|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function n3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n-(m<<16>>16)-(p<<16>>16)+(((k<<16>>16)+(l<<16>>16)|0)*9|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function o3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-3|0)+((l<<16>>16)*18|0)+((k<<16>>16)*53|0)-(p<<16>>16<<2)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function p3a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=f;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[g>>2]=(j|h)-((j^h)>>>1&2139062143);h=b+4|0;j=c[h>>2]|0;g=f+4|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[h>>2]=(i|j)-((i^j)>>>1&2139062143);j=a+1|0;if((j|0)<8){f=f+e|0;b=b+e|0;a=j}else{break}}return}function q3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=32-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=h+b|0;j=b+1|0;k=g+((d[f+(b-1)|0]|0)*-4|0)+((d[f+b|0]|0)*53|0)+((d[f+j|0]|0)*18|0)+((d[f+(b+2)|0]|0)*-3|0)>>6;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i]=((d[i]|0)+1+(l&255)|0)>>>1;if((j|0)<8){b=j}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function r3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=8-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=h+b|0;j=b+1|0;k=g-(d[f+(b-1)|0]|0)-(d[f+(b+2)|0]|0)+(((d[f+j|0]|0)+(d[f+b|0]|0)|0)*9|0)>>4;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i]=((d[i]|0)+1+(l&255)|0)>>>1;if((j|0)<8){b=j}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function s3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=32-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=h+b|0;j=b+1|0;k=g+((d[f+(b-1)|0]|0)*-3|0)+((d[f+b|0]|0)*18|0)+((d[f+j|0]|0)*53|0)-((d[f+(b+2)|0]|0)<<2)>>6;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i]=((d[i]|0)+1+(l&255)|0)>>>1;if((j|0)<8){b=j}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function t3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e<<1;h=f+31|0;f=c;c=0;i=b;while(1){b=0;do{j=i+b|0;k=h+((d[f+(b-e)|0]|0)*-4|0)+((d[f+b|0]|0)*53|0)+((d[f+(b+e)|0]|0)*18|0)+((d[f+(b+g)|0]|0)*-3|0)>>6;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=((d[j]|0)+1+(l&255)|0)>>>1;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function u3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-4|0)+((o<<16>>16)*53|0)+((k<<16>>16)*18|0)+((q<<16>>16)*-3|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function v3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n-(m<<16>>16)-(q<<16>>16)+(((k<<16>>16)+(o<<16>>16)|0)*9|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function w3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-3|0)+((o<<16>>16)*18|0)+((k<<16>>16)*53|0)-(q<<16>>16<<2)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function x3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e<<1;h=f+7|0;f=c;c=0;i=b;while(1){b=0;do{j=i+b|0;k=h-(d[f+(b-e)|0]|0)-(d[f+(b+g)|0]|0)+(((d[f+(b+e)|0]|0)+(d[f+b|0]|0)|0)*9|0)>>4;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=((d[j]|0)+1+(l&255)|0)>>>1;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function y3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l-(d[m+(o-f)|0]|0)-(d[m+(o+k)|0]|0)+(((d[m+(o+f)|0]|0)+(d[m+o|0]|0)|0)*9|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-4|0)+((o<<16>>16)*53|0)+((k<<16>>16)*18|0)+((q<<16>>16)*-3|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function z3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=e-1|0;e=0;m=j|0;while(1){n=0;do{b[m+(n<<1)>>1]=(g-(d[l+(n-f)|0]|0)-(d[l+(n+k)|0]|0)+(((d[l+(n+f)|0]|0)+(d[l+n|0]|0)|0)*9|0)|0)>>>1;n=n+1|0;}while((n|0)<11);n=e+1|0;if((n|0)<8){l=l+f|0;e=n;m=m+22|0}else{break}}m=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;l=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){n=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=m-(l<<16>>16)-(q<<16>>16)+(((k<<16>>16)+(o<<16>>16)|0)*9|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[n]=((d[n]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;l=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function A3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l-(d[m+(o-f)|0]|0)-(d[m+(o+k)|0]|0)+(((d[m+(o+f)|0]|0)+(d[m+o|0]|0)|0)*9|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-3|0)+((o<<16>>16)*18|0)+((k<<16>>16)*53|0)-(q<<16>>16<<2)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function B3a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e<<1;h=f+31|0;f=c;c=0;i=b;while(1){b=0;do{j=i+b|0;k=h+((d[f+(b-e)|0]|0)*-3|0)+((d[f+b|0]|0)*18|0)+((d[f+(b+e)|0]|0)*53|0)-((d[f+(b+g)|0]|0)<<2)>>6;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=((d[j]|0)+1+(l&255)|0)>>>1;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function C3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-4|0)+((o<<16>>16)*53|0)+((k<<16>>16)*18|0)+((q<<16>>16)*-3|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function D3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n-(m<<16>>16)-(q<<16>>16)+(((k<<16>>16)+(o<<16>>16)|0)*9|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function E3a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-3|0)+((o<<16>>16)*18|0)+((k<<16>>16)*53|0)-(q<<16>>16<<2)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function F3a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=e+5|0;p=e+6|0;q=e+7|0;r=e+8|0;s=c;c=b;b=0;while(1){t=ba(d[s]|0,k)|0;u=s+1|0;v=ba(d[u]|0,l)|0;w=s+e|0;x=ba(d[w]|0,j)|0;y=s+g|0;a[c]=(t+28+v+x+(ba(d[y]|0,i)|0)|0)>>>6;x=ba(d[u]|0,k)|0;u=s+2|0;v=ba(d[u]|0,l)|0;t=ba(d[y]|0,j)|0;y=s+h|0;a[c+1|0]=(x+28+v+t+(ba(d[y]|0,i)|0)|0)>>>6;t=ba(d[u]|0,k)|0;u=s+3|0;v=ba(d[u]|0,l)|0;x=ba(d[y]|0,j)|0;y=s+m|0;a[c+2|0]=(t+28+v+x+(ba(d[y]|0,i)|0)|0)>>>6;x=ba(d[u]|0,k)|0;u=s+4|0;v=ba(d[u]|0,l)|0;t=ba(d[y]|0,j)|0;y=s+n|0;a[c+3|0]=(x+28+v+t+(ba(d[y]|0,i)|0)|0)>>>6;t=ba(d[u]|0,k)|0;u=s+5|0;v=ba(d[u]|0,l)|0;x=ba(d[y]|0,j)|0;y=s+o|0;a[c+4|0]=(t+28+v+x+(ba(d[y]|0,i)|0)|0)>>>6;x=ba(d[u]|0,k)|0;u=s+6|0;v=ba(d[u]|0,l)|0;t=ba(d[y]|0,j)|0;y=s+p|0;a[c+5|0]=(x+28+v+t+(ba(d[y]|0,i)|0)|0)>>>6;t=ba(d[u]|0,k)|0;u=s+7|0;v=ba(d[u]|0,l)|0;x=ba(d[y]|0,j)|0;y=s+q|0;a[c+6|0]=(t+28+v+x+(ba(d[y]|0,i)|0)|0)>>>6;x=ba(d[u]|0,k)|0;u=ba(d[s+8|0]|0,l)|0;v=ba(d[y]|0,j)|0;a[c+7|0]=(x+28+u+v+(ba(d[s+r|0]|0,i)|0)|0)>>>6;v=b+1|0;if((v|0)<(f|0)){s=w;c=c+e|0;b=v}else{break}}return}function G3a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=e+5|0;p=e+6|0;q=e+7|0;r=e+8|0;s=c;c=b;b=0;while(1){t=ba(d[s]|0,k)|0;u=s+1|0;v=ba(d[u]|0,l)|0;w=s+e|0;x=ba(d[w]|0,j)|0;y=s+g|0;a[c]=((d[c]|0)+1+((t+28+v+x+(ba(d[y]|0,i)|0)|0)>>>6)|0)>>>1;x=c+1|0;v=ba(d[u]|0,k)|0;u=s+2|0;t=ba(d[u]|0,l)|0;z=ba(d[y]|0,j)|0;y=s+h|0;a[x]=((d[x]|0)+1+((v+28+t+z+(ba(d[y]|0,i)|0)|0)>>>6)|0)>>>1;z=c+2|0;t=ba(d[u]|0,k)|0;u=s+3|0;v=ba(d[u]|0,l)|0;x=ba(d[y]|0,j)|0;y=s+m|0;a[z]=((d[z]|0)+1+((t+28+v+x+(ba(d[y]|0,i)|0)|0)>>>6)|0)>>>1;x=c+3|0;v=ba(d[u]|0,k)|0;u=s+4|0;t=ba(d[u]|0,l)|0;z=ba(d[y]|0,j)|0;y=s+n|0;a[x]=((d[x]|0)+1+((v+28+t+z+(ba(d[y]|0,i)|0)|0)>>>6)|0)>>>1;z=c+4|0;t=ba(d[u]|0,k)|0;u=s+5|0;v=ba(d[u]|0,l)|0;x=ba(d[y]|0,j)|0;y=s+o|0;a[z]=((d[z]|0)+1+((t+28+v+x+(ba(d[y]|0,i)|0)|0)>>>6)|0)>>>1;x=c+5|0;v=ba(d[u]|0,k)|0;u=s+6|0;t=ba(d[u]|0,l)|0;z=ba(d[y]|0,j)|0;y=s+p|0;a[x]=((d[x]|0)+1+((v+28+t+z+(ba(d[y]|0,i)|0)|0)>>>6)|0)>>>1;z=c+6|0;t=ba(d[u]|0,k)|0;u=s+7|0;v=ba(d[u]|0,l)|0;x=ba(d[y]|0,j)|0;y=s+q|0;a[z]=((d[z]|0)+1+((t+28+v+x+(ba(d[y]|0,i)|0)|0)>>>6)|0)>>>1;x=c+7|0;v=ba(d[u]|0,k)|0;u=ba(d[s+8|0]|0,l)|0;t=ba(d[y]|0,j)|0;a[x]=((d[x]|0)+1+((v+28+u+t+(ba(d[s+r|0]|0,i)|0)|0)>>>6)|0)>>>1;t=b+1|0;if((t|0)<(f|0)){s=w;c=c+e|0;b=t}else{break}}return}function H3a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=c;c=b;b=0;while(1){p=ba(d[o]|0,k)|0;q=o+1|0;r=ba(d[q]|0,l)|0;s=o+e|0;t=ba(d[s]|0,j)|0;u=o+g|0;a[c]=(p+28+r+t+(ba(d[u]|0,i)|0)|0)>>>6;t=ba(d[q]|0,k)|0;q=o+2|0;r=ba(d[q]|0,l)|0;p=ba(d[u]|0,j)|0;u=o+h|0;a[c+1|0]=(t+28+r+p+(ba(d[u]|0,i)|0)|0)>>>6;p=ba(d[q]|0,k)|0;q=o+3|0;r=ba(d[q]|0,l)|0;t=ba(d[u]|0,j)|0;u=o+m|0;a[c+2|0]=(p+28+r+t+(ba(d[u]|0,i)|0)|0)>>>6;t=ba(d[q]|0,k)|0;q=ba(d[o+4|0]|0,l)|0;r=ba(d[u]|0,j)|0;a[c+3|0]=(t+28+q+r+(ba(d[o+n|0]|0,i)|0)|0)>>>6;r=b+1|0;if((r|0)<(f|0)){o=s;c=c+e|0;b=r}else{break}}return}function I3a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=c;c=b;b=0;while(1){p=ba(d[o]|0,k)|0;q=o+1|0;r=ba(d[q]|0,l)|0;s=o+e|0;t=ba(d[s]|0,j)|0;u=o+g|0;a[c]=((d[c]|0)+1+((p+28+r+t+(ba(d[u]|0,i)|0)|0)>>>6)|0)>>>1;t=c+1|0;r=ba(d[q]|0,k)|0;q=o+2|0;p=ba(d[q]|0,l)|0;v=ba(d[u]|0,j)|0;u=o+h|0;a[t]=((d[t]|0)+1+((r+28+p+v+(ba(d[u]|0,i)|0)|0)>>>6)|0)>>>1;v=c+2|0;p=ba(d[q]|0,k)|0;q=o+3|0;r=ba(d[q]|0,l)|0;t=ba(d[u]|0,j)|0;u=o+m|0;a[v]=((d[v]|0)+1+((p+28+r+t+(ba(d[u]|0,i)|0)|0)>>>6)|0)>>>1;t=c+3|0;r=ba(d[q]|0,k)|0;q=ba(d[o+4|0]|0,l)|0;p=ba(d[u]|0,j)|0;a[t]=((d[t]|0)+1+((r+28+q+p+(ba(d[o+n|0]|0,i)|0)|0)>>>6)|0)>>>1;p=b+1|0;if((p|0)<(f|0)){o=s;c=c+e|0;b=p}else{break}}return}function J3a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)==0){return}else{h=g;i=e;j=b}while(1){b=h-1|0;e=i>>16;g=d[c+e|0]|0;a[j]=((ba((d[c+(e+1)|0]|0)-g|0,i&65535)|0)>>>16)+g;if((b|0)==0){break}else{h=b;i=i+f|0;j=j+1|0}}return}function K3a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=e;i=c;j=b;k=g}while(1){g=k-1|0;b=d[i]|0;a[j]=((ba((d[h]|0)-b|0,f)|0)>>>16)+b;if((g|0)==0){break}else{h=h+1|0;i=i+1|0;j=j+1|0;k=g}}return}function L3a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=e;i=c;j=b;k=g}while(1){g=k-1|0;b=d[i]|0;a[j]=((ba((d[h]|0)-b|0,f)|0)>>>16)+b;if((g|0)==0){break}else{h=h+1|0;i=i+1|0;j=j+1|0;k=g}}return}function M3a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;if((i|0)==0){return}else{j=g;k=e;l=c;m=b;n=i}while(1){i=n-1|0;b=d[l]|0;c=((ba((d[k]|0)-b|0,f)|0)>>16)+b|0;a[m]=((ba((d[j]|0)-c|0,h)|0)>>>16)+c;if((i|0)==0){break}else{j=j+1|0;k=k+1|0;l=l+1|0;m=m+1|0;n=i}}return}function N3a(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0;if((k|0)==0){return}else{l=h;m=g;n=e;o=c;p=b;q=k}while(1){k=q-1|0;b=d[o]|0;c=((ba((d[n]|0)-b|0,f)|0)>>16)+b|0;b=d[m]|0;a[p]=((ba(b-c+((ba((d[l]|0)-b|0,i)|0)>>16)|0,j)|0)>>>16)+c;if((k|0)==0){break}else{l=l+1|0;m=m+1|0;n=n+1|0;o=o+1|0;p=p+1|0;q=k}}return}function O3a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;if((f|0)<=0){return}h=c<<1;i=e*-2|0;j=i+h|0;k=h+e|0;l=-e|0;m=h-e|0;n=e*-4|0;o=n+h|0;p=e*-3|0;q=p+h|0;r=e*3|0;s=r+h|0;t=e<<1;u=t+h|0;v=i+c|0;w=e+c|0;x=c-e|0;y=n+c|0;z=p+c|0;A=r+c|0;B=t+c|0;C=c*3|0;D=i+C|0;E=C+e|0;F=C-e|0;G=n+C|0;H=p+C|0;I=w*3|0;J=t+C|0;K=c<<2;L=0;M=b;while(1){b=M+h|0;N=d[M+j|0]|0;O=d[M+k|0]|0;P=M+m|0;Q=d[P]|0;R=d[b]|0;S=Q-R|0;T=(N-O<<1)+4+(S*-5|0)|0;U=T>>31;V=(T>>3^U)-U|0;do{if((V|0)<(g|0)){T=((d[M+o|0]|0)-Q<<1)+4+(((d[M+q|0]|0)-N|0)*-5|0)>>3;W=(T|0)>-1?T:-T|0;T=(R-(d[M+s|0]|0)<<1)+4+((O-(d[M+u|0]|0)|0)*-5|0)>>3;X=(T|0)>-1?T:-T|0;if(!((W|0)<(V|0)|(X|0)<(V|0))){break}T=S>>31;Y=(T^S)-T>>1;if((Y|0)==0){break}Z=(((W|0)>(X|0)?X:W)-V|0)*5|0;W=Z>>31;X=(W^Z)-W>>3;if((W^U|0)==(T|0)){W=(((X|0)>(Y|0)?Y:X)^T)-T|0;T=Q-W|0;if(T>>>0>255>>>0){_=-T>>31&255}else{_=T&255}a[P]=_;T=(d[b]|0)+W|0;if(T>>>0>255>>>0){$=-T>>31&255}else{$=T&255}a[b]=$}T=d[M+i|0]|0;W=d[M+e|0]|0;X=M+l|0;Y=d[X]|0;Z=d[M]|0;aa=Y-Z|0;ba=(T-W<<1)+4+(aa*-5|0)|0;ca=ba>>31;da=(ba>>3^ca)-ca|0;do{if((da|0)<(g|0)){ba=((d[M+n|0]|0)-Y<<1)+4+(((d[M+p|0]|0)-T|0)*-5|0)>>3;ea=(ba|0)>-1?ba:-ba|0;ba=(Z-(d[M+r|0]|0)<<1)+4+((W-(d[M+t|0]|0)|0)*-5|0)>>3;fa=(ba|0)>-1?ba:-ba|0;if(!((ea|0)<(da|0)|(fa|0)<(da|0))){break}ba=aa>>31;ga=(ba^aa)-ba>>1;if((ga|0)==0){break}ha=(((ea|0)>(fa|0)?fa:ea)-da|0)*5|0;ea=ha>>31;fa=(ea^ha)-ea>>3;if((ea^ca|0)!=(ba|0)){break}ea=(((fa|0)>(ga|0)?ga:fa)^ba)-ba|0;ba=Y-ea|0;if(ba>>>0>255>>>0){ia=-ba>>31&255}else{ia=ba&255}a[X]=ia;ba=(d[M]|0)+ea|0;if(ba>>>0>255>>>0){ja=-ba>>31&255}else{ja=ba&255}a[M]=ja}}while(0);X=M+c|0;Y=d[M+v|0]|0;ca=d[M+w|0]|0;da=M+x|0;aa=d[da]|0;W=d[X]|0;Z=aa-W|0;T=(Y-ca<<1)+4+(Z*-5|0)|0;ba=T>>31;ea=(T>>3^ba)-ba|0;do{if((ea|0)<(g|0)){T=((d[M+y|0]|0)-aa<<1)+4+(((d[M+z|0]|0)-Y|0)*-5|0)>>3;fa=(T|0)>-1?T:-T|0;T=(W-(d[M+A|0]|0)<<1)+4+((ca-(d[M+B|0]|0)|0)*-5|0)>>3;ga=(T|0)>-1?T:-T|0;if(!((fa|0)<(ea|0)|(ga|0)<(ea|0))){break}T=Z>>31;ha=(T^Z)-T>>1;if((ha|0)==0){break}ka=(((fa|0)>(ga|0)?ga:fa)-ea|0)*5|0;fa=ka>>31;ga=(fa^ka)-fa>>3;if((fa^ba|0)!=(T|0)){break}fa=(((ga|0)>(ha|0)?ha:ga)^T)-T|0;T=aa-fa|0;if(T>>>0>255>>>0){la=-T>>31&255}else{la=T&255}a[da]=la;T=(d[X]|0)+fa|0;if(T>>>0>255>>>0){ma=-T>>31&255}else{ma=T&255}a[X]=ma}}while(0);X=M+C|0;da=d[M+D|0]|0;aa=d[M+E|0]|0;ba=M+F|0;ea=d[ba]|0;Z=d[X]|0;ca=ea-Z|0;W=(da-aa<<1)+4+(ca*-5|0)|0;Y=W>>31;T=(W>>3^Y)-Y|0;if((T|0)>=(g|0)){break}W=((d[M+G|0]|0)-ea<<1)+4+(((d[M+H|0]|0)-da|0)*-5|0)>>3;da=(W|0)>-1?W:-W|0;W=(Z-(d[M+I|0]|0)<<1)+4+((aa-(d[M+J|0]|0)|0)*-5|0)>>3;aa=(W|0)>-1?W:-W|0;if(!((da|0)<(T|0)|(aa|0)<(T|0))){break}W=ca>>31;Z=(W^ca)-W>>1;if((Z|0)==0){break}ca=(((da|0)>(aa|0)?aa:da)-T|0)*5|0;T=ca>>31;da=(T^ca)-T>>3;if((T^Y|0)!=(W|0)){break}Y=(((da|0)>(Z|0)?Z:da)^W)-W|0;W=ea-Y|0;if(W>>>0>255>>>0){na=-W>>31&255}else{na=W&255}a[ba]=na;ba=(d[X]|0)+Y|0;if(ba>>>0>255>>>0){oa=-ba>>31&255}else{oa=ba&255}a[X]=oa}}while(0);b=L+4|0;if((b|0)<(f|0)){L=b;M=M+K|0}else{break}}return}function P3a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;c[a+140>>2]=6;d=c[a+120>>2]|0;e=c[a+124>>2]|0;do{if((d&7|0)==0){if((e&3|0)==0){f=0}else{break}i=b;return f|0}}while(0);DDb(a,1935736,(a=i,i=i+16|0,c[a>>2]=d,c[a+8>>2]=e,a)|0);i=a;f=-1094995529;i=b;return f|0}function Q3a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;h=i;j=c[b+60>>2]|0;k=g+24|0;l=c[k>>2]|0;m=c[g+28>>2]|0;g=b+124|0;n=c[g>>2]|0;o=b+120|0;p=n+32+((ba(n*5|0,c[o>>2]|0)|0)/8|0)|0;if((m|0)<(p|0)){yDb(b,16,2178872,(q=i,i=i+16|0,c[q>>2]=m,c[q+8>>2]=p,q)|0);i=q;r=-22;i=h;return r|0}p=_$a(b,e,0)|0;if((p|0)<0){r=p;i=h;return r|0}c[e+88>>2]=1;c[e+84>>2]=1;p=j;c[j>>2]=d[l]|0;c[j+4>>2]=d[l+2|0]|0;c[j+8>>2]=d[l+4|0]|0;c[j+12>>2]=d[l+6|0]|0;c[j+16>>2]=d[l+8|0]|0;c[j+20>>2]=d[l+10|0]|0;c[j+24>>2]=d[l+12|0]|0;c[j+28>>2]=d[l+14|0]|0;c[j+32>>2]=d[l+16|0]|0;c[j+36>>2]=d[l+18|0]|0;c[j+40>>2]=d[l+20|0]|0;c[j+44>>2]=d[l+22|0]|0;c[j+48>>2]=d[l+24|0]|0;c[j+52>>2]=d[l+26|0]|0;c[j+56>>2]=d[l+28|0]|0;c[j+60>>2]=d[l+30|0]|0;b=l+32|0;a:do{if((c[g>>2]|0)>0){n=e+32|0;s=e;t=e+36|0;u=e+4|0;v=e+40|0;w=e+8|0;x=l+m|0;y=j+64|0;z=y;A=b;B=0;b:while(1){C=ba(c[n>>2]|0,B)|0;D=(c[s>>2]|0)+C|0;C=B&3;c:do{if((C|0)==0){E=B>>2;F=ba(c[t>>2]|0,E)|0;G=(c[u>>2]|0)+F|0;F=ba(c[v>>2]|0,E)|0;E=(c[w>>2]|0)+F|0;if((x-A|0)<((c[o>>2]|0)+4|0)){H=9;break b}F=A+4|0;I=d[A]|0;c[y>>2]=I;c[j+68>>2]=d[A+1|0]|0;c[j+72>>2]=d[A+2|0]|0;c[j+76>>2]=d[A+3|0]|0;if((c[o>>2]|0)<=0){J=F;break}K=F;F=0;L=I-(c[p+((a[A+6|0]&15)<<2)>>2]|0)|0;I=D;M=G;G=E;while(1){E=K+2|0;N=(c[p+((a[E]&15)<<2)>>2]|0)+L|0;a[I]=N;O=(c[p+((d[E]|0)>>>4<<2)>>2]|0)+N|0;a[I+1|0]=O;N=(c[p+((a[K]&15)<<2)>>2]|0)+O|0;a[I+2|0]=N;O=(c[p+((d[K]|0)>>>4<<2)>>2]|0)+N|0;a[I+3|0]=O;a[M]=a[K+3|0]|0;a[G]=a[K+1|0]|0;N=K+4|0;E=F+4|0;if((E|0)<(c[o>>2]|0)){K=N;F=E;L=O;I=I+4|0;M=M+1|0;G=G+1|0}else{J=N;break}}}else{G=c[o>>2]|0;if((x-A|0)<((G|0)/2|0|0)){H=13;break b}if((G|0)<=0){J=A;break}G=a[A+2|0]|0;M=A;I=8;L=(c[z+(C<<2)>>2]|0)-(c[p+((G&15)<<2)>>2]|0)|0;F=D;K=G;while(1){G=(c[p+((K&15)<<2)>>2]|0)+L|0;a[F]=G;N=(c[p+((d[M+2|0]|0)>>>4<<2)>>2]|0)+G|0;a[F+1|0]=N;G=M+3|0;O=(c[p+((a[G]&15)<<2)>>2]|0)+N|0;a[F+2|0]=O;N=(c[p+((d[G]|0)>>>4<<2)>>2]|0)+O|0;a[F+3|0]=N;O=(c[p+((a[M]&15)<<2)>>2]|0)+N|0;a[F+4|0]=O;N=(c[p+((d[M]|0)>>>4<<2)>>2]|0)+O|0;a[F+5|0]=N;O=M+1|0;G=(c[p+((a[O]&15)<<2)>>2]|0)+N|0;a[F+6|0]=G;N=(c[p+((d[O]|0)>>>4<<2)>>2]|0)+G|0;a[F+7|0]=N;G=M+4|0;if((I|0)>=(c[o>>2]|0)){J=G;break c}O=a[M+6|0]|0;M=G;I=I+8|0;L=N;F=F+8|0;K=O}}}while(0);D=B+1|0;if((D|0)<(c[g>>2]|0)){A=J;B=D}else{P=J;break a}}if((H|0)==9){yDb(0,0,2102608,(q=i,i=i+24|0,c[q>>2]=2046488,c[q+8>>2]=2000912,c[q+16>>2]=81,q)|0);i=q;Cd();return 0}else if((H|0)==13){yDb(0,0,2102608,(q=i,i=i+24|0,c[q>>2]=1963872,c[q+8>>2]=2000912,c[q+16>>2]=100,q)|0);i=q;Cd();return 0}}else{P=b}}while(0);c[f>>2]=1;r=P-(c[k>>2]|0)|0;i=h;return r|0}function R3a(b,c,d,e,f,g,h,i,j,k){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((j|0)==0|(k|0)==0){return}do{if((i|0)<(k|0)){if((i|0)>(-g|0)){l=c;m=i;break}n=1-g|0;l=c+(ba(n-i|0,e)|0)|0;m=n}else{n=k-1|0;l=c+(ba(n-i|0,e)|0)|0;m=n}}while(0);do{if((h|0)<(j|0)){if((h|0)>(-f|0)){o=l;p=h;break}i=1-f|0;o=l+(i-h)|0;p=i}else{i=j-1|0;o=l+(i-h)|0;p=i}}while(0);h=(m|0)>0;l=h?0:-m|0;i=(p|0)>0;c=i?0:-p|0;n=k-m|0;q=(n|0)<(g|0)?n:g;n=j-p|0;j=(n|0)<(f|0);r=j?n:f;n=r-c|0;s=o+(c+(ba(l,e)|0))|0;t=b+c|0;if((l|0)>0){u=(h?m:0)-m|0;v=(i?p:0)+(ba(u,d)|0)-p|0;w=0;x=t;while(1){UGb(x|0,s|0,n)|0;y=w+1|0;if((y|0)<(l|0)){w=y;x=x+d|0}else{break}}z=u;A=b+v|0}else{z=0;A=t}if((z|0)<(q|0)){t=m-1-k|0;k=~g;v=(t|0)>(k|0)?t:k;k=ba(~z-v|0,d)|0;t=(i?p:0)+(ba((h?m-1|0:-1)-m-z-v|0,e)|0)-p|0;p=z;m=s;h=A;while(1){UGb(h|0,m|0,n)|0;i=p+1|0;if((i|0)<(q|0)){p=i;m=m+e|0;h=h+d|0}else{break}}B=~v;C=o+t|0;D=A+k|0}else{B=z;C=s;D=A}A=C+(-e|0)|0;if((B|0)<(g|0)){e=ba(g-B|0,d)|0;C=B;B=D;while(1){UGb(B|0,A|0,n)|0;s=C+1|0;if((s|0)<(g|0)){C=s;B=B+d|0}else{break}}E=D+e|0}else{E=D}D=E+(-((ba(g,d)|0)+c|0)|0)|0;E=g-1|0;if((g|0)==0){return}g=r-1|0;if((c|0)<=0){if(j){F=D;G=E}else{return}while(1){e=F+g|0;B=r;do{a[F+B|0]=a[e]|0;B=B+1|0;}while((B|0)<(f|0));if((G|0)==0){break}else{F=F+d|0;G=G-1|0}}return}if(j){H=D;I=E}else{j=D;D=E;while(1){E=j+c|0;G=0;do{a[j+G|0]=a[E]|0;G=G+1|0;}while((G|0)<(c|0));if((D|0)==0){break}else{j=j+d|0;D=D-1|0}}return}while(1){D=H+c|0;j=0;do{a[H+j|0]=a[D]|0;j=j+1|0;}while((j|0)<(c|0));j=H+g|0;D=r;do{a[H+D|0]=a[j]|0;D=D+1|0;}while((D|0)<(f|0));if((I|0)==0){break}else{H=H+d|0;I=I-1|0}}return}function S3a(a,c,d,e,f,g,h,i,j,k){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((j|0)==0|(k|0)==0){return}do{if((i|0)<(k|0)){if((i|0)>(-g|0)){l=c;m=i;break}n=1-g|0;l=c+(ba(n-i|0,e)|0)|0;m=n}else{n=k-1|0;l=c+(ba(n-i|0,e)|0)|0;m=n}}while(0);do{if((h|0)<(j|0)){if((h|0)>(-f|0)){o=l;p=h;break}i=1-f|0;o=l+(i-h<<1)|0;p=i}else{i=j-1|0;o=l+(i-h<<1)|0;p=i}}while(0);h=(m|0)>0;l=h?0:-m|0;i=(p|0)>0;c=i?0:-p|0;n=k-m|0;q=(n|0)<(g|0)?n:g;n=j-p|0;j=(n|0)<(f|0);r=j?n:f;n=r-c|0;s=c<<1;t=o+(s+(ba(l,e)|0))|0;u=a+s|0;if((l|0)>0){v=n<<1;w=(h?m:0)-m|0;x=ba(w,d)|0;y=x+((i?p:0)-p<<1)|0;x=0;z=u;while(1){UGb(z|0,t|0,v)|0;A=x+1|0;if((A|0)<(l|0)){x=A;z=z+d|0}else{break}}B=w;C=a+y|0}else{B=0;C=u}if((B|0)<(q|0)){u=n<<1;y=m-1-k|0;k=~g;a=(y|0)>(k|0)?y:k;k=ba(~B-a|0,d)|0;y=ba((h?m-1|0:-1)-m-B-a|0,e)|0;m=y+((i?p:0)-p<<1)|0;p=B;i=t;y=C;while(1){UGb(y|0,i|0,u)|0;h=p+1|0;if((h|0)<(q|0)){p=h;i=i+e|0;y=y+d|0}else{break}}D=~a;E=o+m|0;F=C+k|0}else{D=B;E=t;F=C}C=E+(-e|0)|0;if((D|0)<(g|0)){e=n<<1;n=ba(g-D|0,d)|0;E=D;D=F;while(1){UGb(D|0,C|0,e)|0;t=E+1|0;if((t|0)<(g|0)){E=t;D=D+d|0}else{break}}G=F+n|0}else{G=F}F=G+(-((ba(g,d)|0)+s|0)|0)|0;s=g-1|0;if((g|0)==0){return}g=r-1|0;if((c|0)>0){H=F;I=s}else{G=F;F=s;while(1){s=G;if(j){n=s+(g<<1)|0;D=r;do{b[s+(D<<1)>>1]=b[n>>1]|0;D=D+1|0;}while((D|0)<(f|0))}if((F|0)==0){break}else{G=G+d|0;F=F-1|0}}return}while(1){F=H;G=F+(c<<1)|0;D=0;do{b[F+(D<<1)>>1]=b[G>>1]|0;D=D+1|0;}while((D|0)<(c|0));if(j){D=F+(g<<1)|0;G=r;do{b[F+(G<<1)>>1]=b[D>>1]|0;G=G+1|0;}while((G|0)<(f|0))}if((I|0)==0){break}else{H=H+d|0;I=I-1|0}}return}function T3a(a,b){a=a|0;b=b|0;c[a+4>>2]=848;c[a>>2]=(b|0)<9?48:60;return}function U3a(a,b,c){a=a|0;b=b|0;c=c|0;return}function V3a(d){d=d|0;var e=0,f=0,g=0,h=0;c[d+420>>2]=1;if(a[562280]|0){return 0}else{e=0}do{d=(e&32|0)==0;f=e;g=0;while(1){h=b[1269584+(g<<1)>>1]|0;b[4617856+(f<<1)>>1]=((e&1|0)==0?0:h>>>5)+(((e&2|0)==0?0:h>>>4)+(((e&4|0)==0?0:h>>>3)+(((e&8|0)==0?0:h>>2)+(((e&16|0)==0?0:h>>1)+(d?0:h)))));h=g+1|0;if(h>>>0<89>>>0){f=f+64|0;g=h}else{break}}e=e+1|0;}while((e|0)<64);a[562280]=1;return 0}function W3a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=g;o=j+28|0;p=c[o>>2]|0;if((p|0)<13){q=-1094995529;i=k;return q|0}r=c[j+24>>2]|0;j=p>>>0>268435455>>>0?-8:p<<3;s=j>>>0>2147483639>>>0|(r|0)==0;t=s?0:r;r=s?8:j+8|0;if(s){q=s?-1094995529:0;i=k;return q|0}s=t;j=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)&-65536;s=r>>>0>16>>>0?16:r;u=t+(s>>>3)|0;v=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)>>>16;u=s+16|0;s=r>>>0>u>>>0?u:r;u=v|j;if((u|0)==-1){j=-s|0;v=r-s|0;if((j|0)>32){w=j}else{w=(v|0)<32?v:32}v=w+s|0;w=t+(v>>>3)|0;j=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)&-65536;w=v+16|0;v=r>>>0>w>>>0?w:r;w=t+(v>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)>>>16;w=v+16|0;y=x|j;z=r>>>0>w>>>0?w:r}else{y=u;z=s}if(y>>>0>p<<1>>>0){q=-1094995529;i=k;return q|0}p=t+(z>>>3)|0;s=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(z&7)>>24;p=z+8|0;z=r>>>0>p>>>0?p:r;p=s>>>7;u=(p&1)+1|0;a[m|0]=p^s;c[f+416>>2]=u;s=(u|0)==2;p=f+448|0;c[p>>2]=s?3:4;c[p+4>>2]=s?0:0;s=t+(z>>>3)|0;p=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(z&7)>>>16;s=z+16|0;z=r>>>0>s>>>0?s:r;b[l>>1]=p;if(u>>>0>1>>>0){p=t+(z>>>3)|0;s=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(z&7)>>>24;p=z+8|0;w=r>>>0>p>>>0?p:r;a[m+1|0]=s;s=t+(w>>>3)|0;p=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7)>>>16;s=w+16|0;b[l+2>>1]=p;A=r>>>0>s>>>0?s:r}else{A=z}c[g+76>>2]=y;z=_$a(f,n,0)|0;if((z|0)<0){q=z;i=k;return q|0}z=g;if((y|0)!=0){g=A;A=0;while(1){n=g;f=(c[z>>2]|0)+(A<<1)|0;s=a[m+A|0]|0;p=b[l+(A<<1)>>1]|0;w=0;while(1){if((s|0)<0){B=0}else{B=(s|0)>88?88:s}j=d[435928+B|0]|0;x=t+(n>>>3)|0;v=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(n&7)>>>((32-j|0)>>>0);x=j+n|0;C=r>>>0>x>>>0?x:r;x=j-1|0;D=1<<x;E=(v&D|0)==0;F=E?0:D;G=F^v;if((G|0)==(D-1|0)){D=t+(C>>>3)|0;H=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>16;D=C+16|0;I=H;J=r>>>0>D>>>0?D:r}else{D=G<<7-j|B<<6;if((D|0)<0){K=0}else{K=(D|0)>5785?5785:D}D=e[4617856+(K<<1)>>1]|0;if((v|0)==(F|0)){L=D}else{L=(b[1269584+(B<<1)>>1]>>x)+D|0}D=(E?L:-L|0)+p|0;if((D+32768|0)>>>0>65535>>>0){M=(D>>31^32767)&65535}else{M=D&65535}I=M<<16>>16;J=C}b[f>>1]=I;C=w+1|0;if(C>>>0<y>>>0){n=J;f=f+(u<<1)|0;s=(a[(c[431496+(j-2<<2)>>2]|0)+G|0]|0)+B|0;p=I;w=C}else{break}}w=A+1|0;if((w|0)<(u|0)){g=J;A=w}else{break}}}c[h>>2]=1;q=c[o>>2]|0;i=k;return q|0}function X3a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b+60|0;g=c[f>>2]|0;c[g>>2]=b;c[b+140>>2]=11;if((c[b+100>>2]|0)!=816){yDb(b,16,2190944,(h=i,i=i+8|0,c[h>>2]=816,h)|0);i=h;j=-1094995529;i=e;return j|0}h=c[b+96>>2]|0;b=h+800|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[g+1044>>2]=k;do{if((k|0)!=0){b=WDb(k)|0;c[g+1040>>2]=b;if((b|0)==0){j=-12}else{break}i=e;return j|0}}while(0);k=g+16|0;b=0;l=0;while(1){m=(a[h+(b+29)|0]<<2&255)<<8|(a[h+(b+28)|0]<<2&255)<<16|a[h+(b+30)|0]<<2&255;c[k+(l<<2)>>2]=m|m>>>6&197379|-16777216;m=l+1|0;if((m|0)<256){b=b+3|0;l=m}else{break}}l=ICb()|0;c[g+4>>2]=l;if((l|0)!=0){j=0;i=e;return j|0}l=c[f>>2]|0;JCb(l+4|0);$Db(l+1040|0);c[l+1044>>2]=0;j=-12;i=e;return j|0}function Y3a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0;h=i;i=i+4096|0;j=h|0;k=c[g+28>>2]|0;l=c[b+60>>2]|0;m=e;n=l+8|0;c[n>>2]=c[g+24>>2];g=l+12|0;c[g>>2]=k;if((k|0)<16){o=-1094995529;i=h;return o|0}p=_$a(b,m,1)|0;if((p|0)<0){o=p;i=h;return o|0}p=c[n>>2]|0;b=p+6|0;q=(d[b]|d[b+1|0]<<8)<<16>>16;b=q&65535;r=p+8|0;s=(d[r]|d[r+1|0]<<8)<<16>>16;r=s&65535;t=p+10|0;u=((d[t]|d[t+1|0]<<8)<<16>>16&65535)-b+1|0;t=p+12|0;v=((d[t]|d[t+1|0]<<8)<<16>>16&65535)-r+1|0;t=l;w=c[t>>2]|0;y=w+120|0;do{if((u|0)==(c[y>>2]|0)){if((v|0)!=(c[w+124>>2]|0)){break}if((s|q)<<16>>16==0){break}c[l+1048>>2]=b;c[l+1052>>2]=r}}while(0);q=c[l+1048>>2]|0;s=b-q|0;z=c[l+1052>>2]|0;A=r-z|0;do{if((s|u|0)>=0){B=c[y>>2]|0;if((s|0)>=(B|0)|(u|0)>(B|0)|(s+u|0)>(B|0)){break}do{if((A|v|0)>=0){C=c[w+124>>2]|0;if((A|0)>=(C|0)|(v|0)>(C|0)|(A+v|0)>(C|0)){break}D=l+4|0;E=c[c[D>>2]>>2]|0;do{if((E|0)==0){F=p}else{if((b|0)==(q|0)&(r|0)==(z|0)&(u|0)==(B|0)&(v|0)==(C|0)){F=p;break}UGb(c[e>>2]|0,E|0,ba(c[e+32>>2]|0,C)|0)|0;F=c[n>>2]|0}}while(0);C=F+16|0;E=c[g>>2]|0;if(!((E-16|0)>-1)){yDb(0,0,1935704,(G=i,i=i+24|0,c[G>>2]=2207912,c[G+8>>2]=2199584,c[G+16>>2]=135,G)|0);i=G;Cd();return 0}H=F+E|0;if((a[F+15|0]&2)==0){I=C;J=E}else{E=H;K=C;C=E-K|0;L=F+(C>>>0>2>>>0?18:C+16|0)|0;C=l+16|0;if(!((E-L|0)>>>0>767>>>0)){yDb(c[t>>2]|0,16,2241120,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;o=-1094995529;i=h;return o|0}M=K-1-E|0;E=783-M|0;K=L;L=0;while(1){N=d[K+1|0]<<10&64512|d[K]<<18|d[K+2|0]<<2&252;c[C+(L<<2)>>2]=N|N>>>6&197379|-16777216;N=L+1|0;if((N|0)<256){K=K+3|0;L=N}else{break}}I=F+(M>>>0>4294967293>>>0?E:786)|0;J=c[g>>2]|0}a:do{if((J|0)!=0){L=H;if((H|0)==(I|0)){o=-1094995529;i=h;return o|0}K=I+1|0;C=a[I]|0;do{if(C<<24>>24>-1){O=C;P=K;Q=H}else{N=c[l+1044>>2]|0;if((N|0)==0){yDb(c[t>>2]|0,16,2229e3,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;o=-1094995529;i=h;return o|0}R=L-K|0;S=l+1040|0;T=c[S>>2]|0;if(!((R|0)>-1)){yDb(0,0,1935704,(G=i,i=i+24|0,c[G>>2]=2207912,c[G+8>>2]=2199584,c[G+16>>2]=135,G)|0);i=G;Cd();return 0}U=I+(R+1)|0;V=U;if((R|0)<4){W=0;X=K}else{R=K;W=d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0;X=I+5|0}TGb(j|0,32,4096)|0;R=V-X|0;if(R>>>0<4>>>0){o=-1094995529;i=h;return o|0}if((R|0)<4){Y=100;Z=4078;_=X}else{R=X;$=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)==1450709556;Y=$?18:100;Z=$?273:4078;_=$?X+4|0:X}b:do{if((W|0)==0|(U|0)==(_|0)){aa=T}else{$=T+N|0;R=_;ca=T;da=Z;ea=W;c:while(1){fa=R+1|0;ga=a[R]|0;if(ga<<24>>24==-1&ea>>>0>8>>>0){if(($-ca|0)<8){o=-1094995529;ha=118;break}if((V-fa|0)>>>0<8>>>0){o=-1094995529;ha=118;break}ia=a[fa]|0;a[ca]=ia;a[j+da|0]=ia;ia=a[R+2|0]|0;a[ca+1|0]=ia;a[j+(da+1&4095)|0]=ia;ia=a[R+3|0]|0;a[ca+2|0]=ia;a[j+(da+2&4095)|0]=ia;ia=a[R+4|0]|0;a[ca+3|0]=ia;a[j+(da+3&4095)|0]=ia;ia=a[R+5|0]|0;a[ca+4|0]=ia;a[j+(da+4&4095)|0]=ia;ia=a[R+6|0]|0;a[ca+5|0]=ia;a[j+(da+5&4095)|0]=ia;ia=a[R+7|0]|0;a[ca+6|0]=ia;a[j+(da+6&4095)|0]=ia;ia=a[R+8|0]|0;a[ca+7|0]=ia;a[j+(da+7&4095)|0]=ia;ja=ea-8|0;ka=da+8&4095;la=ca+8|0;ma=R+9|0}else{if((ea|0)==0){aa=ca;break b}else{na=fa;oa=ca;pa=da;qa=ea;ra=ga;sa=0}while(1){if((ra&1)==0){if((V-na|0)<1){ta=0;ua=na}else{ta=d[na]|0;ua=na+1|0}do{if((V-ua|0)<1){va=3;wa=ua;xa=ta}else{ga=d[ua]|0;fa=ga<<4&3840|ta;ia=ua+1|0;ya=(ga&15)+3|0;if((ya|0)!=(Y|0)){va=ya;wa=ia;xa=fa;break}if((V-ia|0)<1){va=18;wa=ia;xa=fa;break}va=(d[ia]|0)+18|0;wa=ua+2|0;xa=fa}}while(0);if(($-oa|0)>>>0<va>>>0){o=-1094995529;ha=118;break c}else{za=oa;Aa=pa;Ba=xa;Ca=0}while(1){fa=a[j+(Ba&4095)|0]|0;a[za]=fa;a[j+Aa|0]=fa;Da=Aa+1&4095;fa=Ca+1|0;if(fa>>>0<va>>>0){za=za+1|0;Aa=Da;Ba=Ba+1|0;Ca=fa}else{break}}Ea=qa-va|0;Fa=Da;Ga=oa+(va>>>0>1>>>0?va:1)|0;Ha=wa}else{if(($-oa|0)<1|(U|0)==(na|0)){o=-1094995529;ha=118;break c}fa=a[na]|0;a[oa]=fa;a[j+pa|0]=fa;Ea=qa-1|0;Fa=pa+1&4095;Ga=oa+1|0;Ha=na+1|0}fa=sa+1|0;if(fa>>>0>7>>>0|(Ea|0)==0){ja=Ea;ka=Fa;la=Ga;ma=Ha;break}else{na=Ha;oa=Ga;pa=Fa;qa=Ea;ra=(ra&255)>>>1;sa=fa}}}if((ja|0)==0|(U|0)==(ma|0)){aa=la;break b}else{R=ma;ca=la;da=ka;ea=ja}}if((ha|0)==118){i=h;return o|0}}}while(0);U=aa-T|0;if((U|0)<0){o=U;i=h;return o|0}else{V=c[S>>2]|0;O=C&127;P=V;Q=V+U|0;break}}}while(0);C=e+32|0;K=(ba(c[C>>2]|0,A)|0)+s|0;L=(c[e>>2]|0)+K|0;K=c[D>>2]|0;U=(ba(c[K+32>>2]|0,A)|0)+s|0;V=(c[K>>2]|0)+U|0;U=O&255;if((U|0)==1){if((v|0)<=0){break}K=Q;N=P;ea=V;da=L;ca=0;d:while(1){R=0;$=N;while(1){do{if((K-$|0)<1){Ia=$;Ja=0;ha=72}else{fa=$+1|0;ia=d[$]|0;if((ia&128|0)==0){Ia=fa;Ja=ia;ha=72;break}ya=ia&127;ia=ya+1|0;ga=ia+R|0;if((ga|0)>(u|0)){o=-1094995529;ha=118;break d}if((K-fa|0)>>>0<ia>>>0){o=-1094995529;ha=118;break d}UGb(da+R|0,fa|0,ia)|0;Ka=ga;La=$+(ya+2)|0}}while(0);if((ha|0)==72){ha=0;if((R+1+Ja|0)>(u|0)){o=-1094995529;ha=118;break d}if((c[c[D>>2]>>2]|0)==0){o=-1094995529;ha=118;break d}ya=Ja+1|0;UGb(da+R|0,ea+R|0,ya)|0;Ka=ya+R|0;La=Ia}if((Ka|0)<(u|0)){R=Ka;$=La}else{break}}if((Ka|0)>(u|0)){ha=77;break}$=ca+1|0;if(($|0)<(v|0)){N=La;ea=ea+(c[(c[D>>2]|0)+32>>2]|0)|0;da=da+(c[C>>2]|0)|0;ca=$}else{break a}}if((ha|0)==77){yDb(c[t>>2]|0,16,2217232,(G=i,i=i+16|0,c[G>>2]=Ka,c[G+8>>2]=u,G)|0);i=G;o=-1094995529;i=h;return o|0}else if((ha|0)==118){i=h;return o|0}}else if((U|0)==2){if((v|0)<=0){break}ca=Q;da=P;ea=L;N=0;while(1){K=ca-da|0;$=K>>>0>u>>>0?u:K;UGb(ea|0,da|0,$)|0;K=N+1|0;if((K|0)<(v|0)){da=da+$|0;ea=ea+(c[C>>2]|0)|0;N=K}else{break}}}else if((U|0)==3){if((v|0)<=0){break}N=Q;ea=P;da=V;ca=L;K=0;e:while(1){$=ca+u|0;R=0;S=ea;while(1){f:do{if((N-S|0)<1){Ma=S;Na=0;ha=109}else{T=S+1|0;ya=d[S]|0;if((ya&128|0)==0){Ma=T;Na=ya;ha=109;break}ga=(ya&127)+1|0;ia=N-T|0;do{if((ia|0)>=1){if(!((a[T]|0)==-1)){break}fa=ga&255;Oa=S+2|0;Pa=ca+R|0;Qa=Oa;Ra=N-Qa|0;if(!((Ra|0)>-1)){ha=86;break e}Sa=S+(Ra+2)|0;do{if((ya&1|0)==0){if((Q|0)==(Oa|0)){Ta=0;break}a[Pa]=a[Oa]|0;Ua=ca+(R+1)|0;Va=1;Wa=S+3|0;ha=90}else{Ua=Pa;Va=0;Wa=Oa;ha=90}}while(0);do{if((ha|0)==90){ha=0;Oa=Sa;Pa=Ua;Xa=Va;Ya=Wa;g:while(1){if((Sa|0)==(Ya|0)){Za=Sa;ha=106;break}_a=Ya+1|0;$a=a[Ya]|0;ab=$a&255;do{if((ab&128|0)==0){bb=ab<<1;cb=_a;if(($-Pa|0)<(bb|0)){ha=99;break g}db=Oa-cb|0;if(db>>>0<2>>>0){ha=99;break g}if((db|0)<2){eb=0;fb=_a}else{db=_a;eb=(d[db]|d[db+1|0]<<8)<<16>>16;fb=Ya+3|0}if($a<<24>>24==0){gb=Pa;hb=bb;ib=fb;break}else{jb=0;kb=Pa}while(1){db=kb;x=eb;a[db]=x;x=x>>8;a[db+1|0]=x;db=jb+1|0;if((db|0)<(ab|0)){jb=db;kb=kb+2|0}else{break}}gb=Pa+(($a&255)>>>0>1>>>0?bb:2)|0;hb=bb;ib=fb}else{db=ab<<1&254;lb=_a;if(($-Pa|0)<(db|0)){ha=95;break g}if((Oa-lb|0)>>>0<db>>>0){ha=95;break g}UGb(Pa|0,_a|0,db)|0;gb=Pa+db|0;hb=db;ib=Ya+(db|1)|0}}while(0);_a=hb+Xa|0;if((_a|0)<(fa|0)){Pa=gb;Xa=_a;Ya=ib}else{Za=ib;ha=106;break}}if((ha|0)==95){ha=0;Ta=lb-Qa|0;break}else if((ha|0)==99){ha=0;Ta=cb-Qa|0;break}else if((ha|0)==106){ha=0;Ta=Za-Qa|0;break}}}while(0);Qa=Ta&255;mb=fa;nb=S+((Ra>>>0>Qa>>>0?Qa:Ra)+2)|0;break f}}while(0);ya=ga&255;Qa=ia>>>0>ya>>>0?ya:ia;UGb(ca+R|0,T|0,Qa)|0;mb=ya;nb=S+(Qa+1)|0}}while(0);if((ha|0)==109){ha=0;if((R+1+Na|0)>(u|0)){o=-1094995529;ha=118;break e}if((c[c[D>>2]>>2]|0)==0){o=-1094995529;ha=118;break e}Qa=Na+1|0;UGb(ca+R|0,da+R|0,Qa)|0;mb=Qa;nb=Ma}ob=mb+R|0;if((ob|0)<(u|0)){R=ob;S=nb}else{break}}if((ob|0)>(u|0)){ha=114;break}S=K+1|0;if((S|0)<(v|0)){ea=nb;da=da+(c[(c[D>>2]|0)+32>>2]|0)|0;ca=ca+(c[C>>2]|0)|0;K=S}else{break a}}if((ha|0)==86){yDb(0,0,1935704,(G=i,i=i+24|0,c[G>>2]=2207912,c[G+8>>2]=2199584,c[G+16>>2]=135,G)|0);i=G;Cd();return 0}else if((ha|0)==114){yDb(c[t>>2]|0,16,2217232,(G=i,i=i+16|0,c[G>>2]=ob,c[G+8>>2]=u,G)|0);i=G;o=-1094995529;i=h;return o|0}else if((ha|0)==118){i=h;return o|0}}else{break}}}while(0);UGb(c[e+4>>2]|0,l+16|0,1024)|0;KCb(c[D>>2]|0);H=MCb(c[D>>2]|0,m)|0;if((H|0)<0){o=H;i=h;return o|0}c[f>>2]=1;o=k;i=h;return o|0}}while(0);yDb(w,16,2255552,(G=i,i=i+16|0,c[G>>2]=s,c[G+8>>2]=u,G)|0);i=G;o=-1094995529;i=h;return o|0}}while(0);yDb(w,16,2270880,(G=i,i=i+16|0,c[G>>2]=s,c[G+8>>2]=u,G)|0);i=G;o=-1094995529;i=h;return o|0}function Z3a(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);$Db(b+1040|0);c[b+1044>>2]=0;return 0}function _3a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+60>>2]|0;e=a+416|0;f=c[e>>2]|0;if((f-1|0)>>>0>1>>>0){yDb(a,16,2329272,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}j=a+432|0;k=c[j>>2]|0;do{if((k|0)>=1){if(((k|0)%(f|0)|0|0)!=0){break}l=(f|0)==1;m=a+448|0;c[m>>2]=l?4:3;c[m+4>>2]=l?0:0;l=a+792|0;m=(c[l>>2]|0)==16|0;c[a+420>>2]=m;n=BFb(m)|0;c[d>>2]=n;c[d+4>>2]=(c[e>>2]&-((n|0)==2|0))+(c[j>>2]|0);n=c[l>>2]|0;l=c[j>>2]|0;m=c[a+412>>2]|0;yDb(a,48,2287008,(g=i,i=i+32|0,c[g>>2]=c[e>>2],c[g+8>>2]=n,c[g+16>>2]=l,c[g+24>>2]=m,g)|0);i=g;h=0;i=b;return h|0}}while(0);yDb(a,16,2304832,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}function $3a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=i;i=i+8|0;l=k|0;m=g;n=c[j+24>>2]|0;o=j+28|0;j=c[o>>2]|0;p=c[f+60>>2]|0;if((j|0)<16){yDb(f,24,2046456,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[h>>2]=0;r=j;i=k;return r|0}s=a[n+6|0]|0;if(s<<24>>24==0|(s&255)>>>0>3>>>0){yDb(f,16,2000888,(q=i,i=i+8|0,c[q>>2]=s&255,q)|0);i=q;r=-22;i=k;return r|0}t=n+16|0;u=j-16|0;do{if((s<<24>>24|0)==3){v=t;w=0;x=1}else if((s<<24>>24|0)==2){if((u|0)>=4){y=t;z=fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=z-(z>>>1&1431655765)|0;z=(y>>>2&858993459)+(y&858993459)|0;y=(z>>>4)+z&252645135;z=(y>>>8)+y|0;v=n+20|0;w=j-20|0;x=(z>>>16)+z&63;break}yDb(f,16,1963848,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-22;i=k;return r|0}else{v=t;w=u;x=0}}while(0);u=p+4|0;t=c[u>>2]|0;j=(w|0)/(t|0)|0;w=ba(j,t)|0;t=f+432|0;n=ba(j+x|0,c[t>>2]|0)|0;s=f+416|0;z=g+76|0;c[z>>2]=(n|0)/(c[s>>2]|0)|0;n=_$a(f,m,0)|0;if((n|0)<0){r=n;i=k;return r|0}n=c[g>>2]|0;g=n;do{if((x|0)==0){A=g;B=n}else{m=ba(c[t>>2]|0,x)|0;if((m|0)>(ba(c[s>>2]|0,c[z>>2]|0)|0)){yDb(0,0,1935704,(q=i,i=i+24|0,c[q>>2]=1912384,c[q+8>>2]=1891888,c[q+16>>2]=626,q)|0);i=q;Cd();return 0}if((c[p>>2]|0)==2){TGb(n|0,0,m<<1|0)|0;A=g+(m<<1)|0;B=n;break}else{TGb(n|0,-128|0,m|0)|0;A=g;B=n+m|0;break}}}while(0);do{if((j|0)>0){if(((c[s>>2]|0)>1&w|0)!=0){yDb(0,0,1935704,(q=i,i=i+24|0,c[q>>2]=2349408,c[q+8>>2]=1891888,c[q+16>>2]=640,q)|0);i=q;Cd();return 0}n=v+w|0;g=c[u>>2]|0;if((w|0)<(g|0)){break}z=p;x=B;m=A;f=v;y=g;while(1){if((c[z>>2]|0)==2){g=c[s>>2]|0;C=f+y|0;D=g-1|0;if((g|0)>0){E=0;F=f;G=m;while(1){H=F;I=(d[H]|d[H+1|0]<<8)<<16>>16;c[l+(E<<2)>>2]=I<<16>>16;b[G>>1]=I;I=E+1|0;if((I|0)<(g|0)){E=I;F=F+2|0;G=G+2|0}else{break}}J=f+(g<<1)|0;K=m+(g<<1)|0}else{J=f;K=m}if(J>>>0<C>>>0){G=0;F=J;E=K;while(1){I=F+1|0;H=d[F]|0;if((H&128|0)==0){L=l+(G<<2)|0;M=(c[L>>2]|0)+(e[132904+(H<<1)>>1]|0)|0;c[L>>2]=M;N=M}else{M=l+(G<<2)|0;L=(c[M>>2]|0)-(e[132904+((H&127)<<1)>>1]|0)|0;c[M>>2]=L;N=L}if((N+32768|0)>>>0>65535>>>0){O=(N>>31^32767)&65535}else{O=N&65535}c[l+(G<<2)>>2]=O<<16>>16;b[E>>1]=O;if(I>>>0<C>>>0){G=G^D;F=I;E=E+2|0}else{break}}}P=m+(c[t>>2]<<1)|0;Q=x;R=y}else{UGb(x|0,f|0,y)|0;P=m;Q=x+(c[t>>2]|0)|0;R=c[u>>2]|0}E=f+R|0;if((n-E|0)<(R|0)){break}else{x=Q;m=P;f=E;y=R}}}}while(0);c[h>>2]=1;r=c[o>>2]|0;i=k;return r|0}function a4a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;c[d+788>>2]=c[a+120>>2];c[d+792>>2]=c[a+124>>2];e=c[a+792>>2]|0;c[d+8>>2]=e;c[d+12>>2]=(e|0)/8|0;if((e|0)==16){c[a+140>>2]=46}else if((e|0)==8){c[a+140>>2]=11}else if((e|0)==32){c[a+140>>2]=30}else{yDb(a,16,2270848,(a=i,i=i+8|0,c[a>>2]=e,a)|0);i=a;f=-1094995529;i=b;return f|0}a=ICb()|0;c[d+4>>2]=a;f=(a|0)==0?-12:0;i=b;return f|0}function b4a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=c[e+60>>2]|0;m=h+4|0;n=$$a(e,c[m>>2]|0)|0;if((n|0)<0){o=n;i=j;return o|0}if(!((l|0)>-1)){yDb(0,0,2329240,(p=i,i=i+24|0,c[p>>2]=2304816,c[p+8>>2]=2286984,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}n=h+796|0;c[n>>2]=k;c[h+804>>2]=k;q=k+l|0;r=h+800|0;c[r>>2]=q;s=c[m>>2]|0;c[s+84>>2]=0;c[s+88>>2]=2;t=h+840|0;u=t;v=c[u>>2]|0;do{if((v|0)==0){w=q;x=k}else{y=h+808|0;z=c[y>>2]|0;A=c[h+788>>2]|0;B=c[h+816>>2]|0;C=c[h+812>>2]|0;D=c[h+792>>2]|0;E=c[h+820>>2]|0;G=(B|0)<0;H=((A|0)<(B+z|0)?A-B|0:z)+(G?B:0)|0;A=(E|0)<0;I=((D|0)<(E+C|0)?D-E|0:C)+(A?E:0)|0;if(!((H|0)>0&(I|0)>0)){w=q;x=k;break}C=h+12|0;D=c[C>>2]|0;J=(ba(c[s+32>>2]|0,A?0:E)|0)+(ba(D,G?0:B)|0)|0;B=(c[s>>2]|0)+J|0;J=0;G=v;E=z;z=D;while(1){UGb(B|0,G+(ba(ba(E,J)|0,z)|0)|0,ba(z,H)|0)|0;D=J+1|0;if((D|0)>=(I|0)){break}B=B+(c[(c[m>>2]|0)+32>>2]|0)|0;J=D;G=c[u>>2]|0;E=c[y>>2]|0;z=c[C>>2]|0}w=c[r>>2]|0;x=c[n>>2]|0}}while(0);v=w;s=v-x|0;k=s>>>0>2>>>0?2:s;s=x+k|0;c[n>>2]=s;a:do{if((v-s|0)>=2){q=x+(k+2)|0;c[n>>2]=q;C=s;z=(d[C]|d[C+1|0]<<8)<<16>>16;if(z<<16>>16==0){break}C=h+12|0;y=e;E=h+808|0;G=h+812|0;J=h+824|0;B=h+828|0;I=h+832|0;H=h+836|0;D=I;A=h+16|0;K=H;L=h+816|0;M=h+820|0;N=h+8|0;O=h+788|0;P=h+792|0;Q=(de(z|0)|0)&65535;z=q;q=w;b:while(1){R=Q-1|0;S=q;T=S-z|0;if(T>>>0<12>>>0){U=14;break}if((T|0)<2){V=0;W=z}else{T=z+2|0;c[n>>2]=T;X=z;V=(de((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535;W=T}if((S-W|0)<2){Y=0;Z=W}else{T=W+2|0;c[n>>2]=T;X=W;Y=(de((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535;Z=T}if((S-Z|0)<2){_=0;$=Z}else{T=Z+2|0;c[n>>2]=T;X=Z;_=(de((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535;$=T}if((S-$|0)<2){aa=0;ca=$}else{T=$+2|0;c[n>>2]=T;X=$;aa=(de((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535;ca=T}do{if((S-ca|0)<4){T=c[m>>2]|0;X=c[C>>2]|0;da=ba(X,V)|0;ea=c[T+32>>2]|0;fa=X;ga=ea;ha=(c[T>>2]|0)+((ba(ea,Y)|0)+da)|0;ia=S-ca|0;U=109}else{da=ca+4|0;c[n>>2]=da;ea=ca;ja=fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0;ea=c[m>>2]|0;T=c[C>>2]|0;X=ba(T,V)|0;ka=c[ea+32>>2]|0;la=(c[ea>>2]|0)+((ba(ka,Y)|0)+X)|0;ma=S-da|0;if((ja|0)==1464686186){c[n>>2]=ca+(ma>>>0>2>>>0?6:ma+4|0);break}else if((ja|0)==1464686181){c[n>>2]=ca+(ma>>>0>2>>>0?6:ma+4|0);break}else if((ja|0)==1464686182){c[L>>2]=V-(c[J>>2]|0);c[M>>2]=Y-(c[B>>2]|0);break}else if((ja|0)==1464686180){X=gHb(aa,0,_,0)|0;na=gHb(X,F,T,(T|0)<0|0?-1:0)|0;X=F;oa=0;if((X|0)>(oa|0)|(X|0)==(oa|0)&na>>>0>1073741821>>>0){U=27;break b}pa=(ba(ba(_<<1,aa)|0,T)|0)+2|0;if((ma|0)<(pa|0)){U=29;break b}c[n>>2]=ca+(ma>>>0>2>>>0?6:ma+4|0);c[E>>2]=_;c[G>>2]=aa;c[J>>2]=V;c[B>>2]=Y;if(V>>>0>_>>>0|Y>>>0>aa>>>0){yDb(y,16,2000808,(p=i,i=i+32|0,c[p>>2]=V,c[p+8>>2]=Y,c[p+16>>2]=_,c[p+24>>2]=aa,p)|0);i=p;c[B>>2]=0;c[J>>2]=0;qa=c[E>>2]|0;ra=c[G>>2]|0;sa=c[C>>2]|0}else{qa=_;ra=aa;sa=T}na=ba(ra,qa)|0;if((na|0)>=(2147483647/(sa|0)|0|0)){U=33;break b}oa=ba(na,sa)|0;na=_Db(I,oa)|0;if((na|0)<0){ta=na;U=37;break b}na=_Db(H,oa)|0;if((na|0)<0){ta=na;U=37;break b}na=_Db(t,oa)|0;if((na|0)<0){ta=na;U=37;break b}na=c[C>>2]|0;oa=c[D>>2]|0;X=c[G>>2]|0;if((X|0)<=0){break}ua=na<<1;va=c[E>>2]|0;wa=0;xa=oa;ya=oa;za=oa;oa=va;Aa=X;X=va;while(1){if((oa|0)>0){va=1;Ba=xa;Ca=ya;Da=za;while(1){c:do{switch((c[A>>2]|0)+ua|0){case 5:{Ea=c[n>>2]|0;if(((c[r>>2]|0)-Ea|0)<2){Fa=0;break c}c[n>>2]=Ea+2;Ga=Ea;Fa=(de((d[Ga]|d[Ga+1|0]<<8)<<16>>16|0)|0)&65535;break};case 4:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<2){Fa=0;break c}c[n>>2]=Ga+2;Ea=Ga;Fa=(d[Ea]|d[Ea+1|0]<<8)<<16>>16&65535;break};case 8:{Ea=c[n>>2]|0;if(((c[r>>2]|0)-Ea|0)<4){Fa=0;break c}c[n>>2]=Ea+4;Ga=Ea;Fa=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0;break};case 2:case 3:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<1){Fa=0;break c}c[n>>2]=Ga+1;Fa=d[Ga]|0;break};case 9:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<4){Fa=0;break c}c[n>>2]=Ga+4;Ea=Ga;Fa=fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0;break};default:{Fa=0}}}while(0);if((na|0)==1){a[Ba]=Fa;Ha=Da;Ia=Ba+1|0;Ja=Ca}else if((na|0)==2){b[Ca>>1]=Fa;Ha=Da;Ia=Ba;Ja=Ca+2|0}else if((na|0)==4){c[Da>>2]=Fa;Ha=Da+4|0;Ia=Ba;Ja=Ca}else{Ha=Da;Ia=Ba;Ja=Ca}Ka=c[E>>2]|0;if((va|0)>=(Ka|0)){break}va=va+1|0;Ba=Ia;Ca=Ja;Da=Ha}La=Ia;Ma=Ja;Na=Ha;Oa=Ka;Pa=c[G>>2]|0;Qa=Ka}else{La=xa;Ma=ya;Na=za;Oa=oa;Pa=Aa;Qa=X}Da=wa+1|0;if((Da|0)<(Pa|0)){wa=Da;xa=La;ya=Ma;za=Na;oa=Oa;Aa=Pa;X=Qa}else{break}}X=c[K>>2]|0;if((Pa|0)<=0){break}Aa=(na|0)==1;oa=0;za=X;ya=X;xa=X;X=Qa;wa=Pa;while(1){if((X|0)>0){d:do{if(Aa){Da=1;Ca=za;while(1){e:do{switch((c[A>>2]|0)+ua|0){case 9:{Ba=c[n>>2]|0;if(((c[r>>2]|0)-Ba|0)<4){Ra=0;break e}c[n>>2]=Ba+4;va=Ba;Ra=(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)>>>24&255;break};case 5:{va=c[n>>2]|0;if(((c[r>>2]|0)-va|0)<2){Ra=0;break e}c[n>>2]=va+2;Ba=va;Ra=((d[Ba]|d[Ba+1|0]<<8)<<16>>16&65535)>>>8&255;break};case 4:{Ba=c[n>>2]|0;if(((c[r>>2]|0)-Ba|0)<2){Ra=0;break e}c[n>>2]=Ba+2;va=Ba;Ra=(d[va]|d[va+1|0]<<8)<<16>>16&255;break};case 8:{va=c[n>>2]|0;if(((c[r>>2]|0)-va|0)<4){Ra=0;break e}c[n>>2]=va+4;Ba=va;Ra=(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24)&255;break};case 2:case 3:{Ba=c[n>>2]|0;if(((c[r>>2]|0)-Ba|0)<1){Ra=0;break e}c[n>>2]=Ba+1;Ra=a[Ba]|0;break};default:{Ra=0}}}while(0);Ba=Ca+1|0;a[Ca]=Ra;va=c[E>>2]|0;if((Da|0)>=(va|0)){Sa=Ba;Ta=ya;Ua=xa;Va=va;break d}Da=Da+1|0;Ca=Ba}}else{Ca=1;Da=ya;Ba=xa;va=X;while(1){f:do{switch((c[A>>2]|0)+ua|0){case 5:{Ea=c[n>>2]|0;if(((c[r>>2]|0)-Ea|0)<2){Wa=0;break f}c[n>>2]=Ea+2;Ga=Ea;Wa=(de((d[Ga]|d[Ga+1|0]<<8)<<16>>16|0)|0)&65535;break};case 4:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<2){Wa=0;break f}c[n>>2]=Ga+2;Ea=Ga;Wa=(d[Ea]|d[Ea+1|0]<<8)<<16>>16&65535;break};case 8:{Ea=c[n>>2]|0;if(((c[r>>2]|0)-Ea|0)<4){Wa=0;break f}c[n>>2]=Ea+4;Ga=Ea;Wa=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0;break};case 2:case 3:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<1){Wa=0;break f}c[n>>2]=Ga+1;Wa=d[Ga]|0;break};case 9:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<4){Wa=0;break f}c[n>>2]=Ga+4;Ea=Ga;Wa=fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0;break};default:{Wa=0}}}while(0);if((na|0)==4){c[Ba>>2]=Wa;Xa=Ba+4|0;Ya=Da;Za=c[E>>2]|0}else if((na|0)==2){b[Da>>1]=Wa;Xa=Ba;Ya=Da+2|0;Za=va}else{Xa=Ba;Ya=Da;Za=va}if((Ca|0)>=(Za|0)){Sa=za;Ta=Ya;Ua=Xa;Va=Za;break d}Ca=Ca+1|0;Da=Ya;Ba=Xa;va=Za}}}while(0);_a=Sa;$a=Ta;ab=Ua;bb=Va;cb=c[G>>2]|0}else{_a=za;$a=ya;ab=xa;bb=X;cb=wa}va=oa+1|0;if((va|0)<(cb|0)){oa=va;za=_a;ya=$a;xa=ab;X=bb;wa=cb}else{break}}}else if((ja|0)==5){db=c[O>>2]|0;if((_+V|0)>(db|0)){U=137;break b}wa=c[P>>2]|0;if((aa+Y|0)>(wa|0)){eb=wa;U=139;break b}if((aa|0)==0){break}wa=(_|0)==0;X=ka<<4;xa=T<<1;ya=T<<4;za=0;oa=0;na=0;ua=la;Aa=16;while(1){va=na+16|0;Ba=aa-na|0;Da=(va|0)>(aa|0)?Ba:Aa;g:do{if(wa){fb=za;gb=oa}else{Ca=(Da|0)>0;Ea=ba(Da,T)|0;Ga=c[n>>2]|0;hb=c[r>>2]|0;if((hb|0)==(Ga|0)){U=144;break b}else{ib=16;jb=ua;kb=0;lb=oa;mb=za;nb=Ga;ob=hb}while(1){hb=kb+16|0;Ga=_-kb|0;pb=(hb|0)>(_|0)?Ga:ib;qb=ob;h:do{if((qb-nb|0)<1){rb=0;sb=mb;tb=0;ub=lb;vb=nb;U=197}else{wb=nb+1|0;c[n>>2]=wb;xb=d[nb]|0;if((xb&1|0)!=0){if((qb-wb|0)>>>0<(ba(Ea,pb)|0)>>>0){U=148;break b}if(!Ca){yb=lb;zb=mb;break}Ab=(pb|0)>0;Bb=(c[A>>2]|0)+xa|0;Cb=0;Db=jb;while(1){i:do{if(Ab){Eb=Db;Fb=Db;Gb=0;while(1){j:do{switch(Bb|0){case 4:{Hb=c[n>>2]|0;if(((c[r>>2]|0)-Hb|0)<2){Ib=0;break j}c[n>>2]=Hb+2;Jb=Hb;Ib=(d[Jb]|d[Jb+1|0]<<8)<<16>>16&65535;break};case 5:{Jb=c[n>>2]|0;if(((c[r>>2]|0)-Jb|0)<2){Ib=0;break j}c[n>>2]=Jb+2;Hb=Jb;Ib=(de((d[Hb]|d[Hb+1|0]<<8)<<16>>16|0)|0)&65535;break};case 2:case 3:{Hb=c[n>>2]|0;if(((c[r>>2]|0)-Hb|0)<1){Ib=0;break j}c[n>>2]=Hb+1;Ib=d[Hb]|0;break};case 8:{Hb=c[n>>2]|0;if(((c[r>>2]|0)-Hb|0)<4){Ib=0;break j}c[n>>2]=Hb+4;Jb=Hb;Ib=d[Jb]|d[Jb+1|0]<<8|d[Jb+2|0]<<16|d[Jb+3|0]<<24|0;break};case 9:{Jb=c[n>>2]|0;if(((c[r>>2]|0)-Jb|0)<4){Ib=0;break j}c[n>>2]=Jb+4;Hb=Jb;Ib=fe(d[Hb]|d[Hb+1|0]<<8|d[Hb+2|0]<<16|d[Hb+3|0]<<24|0)|0;break};default:{Ib=0}}}while(0);if((T|0)==2){b[Eb+(Gb<<1)>>1]=Ib}else if((T|0)==4){c[Fb+(Gb<<2)>>2]=Ib}else if((T|0)==1){a[Db+Gb|0]=Ib}Gb=Gb+1|0;if((Gb|0)>=(pb|0)){break i}}}}while(0);Gb=Cb+1|0;if((Gb|0)<(Da|0)){Cb=Gb;Db=Db+ka|0}else{yb=lb;zb=mb;break h}}}k:do{if((xb&2|0)==0){Kb=mb;Lb=wb}else{switch((c[A>>2]|0)+xa|0){case 2:case 3:{if((qb-wb|0)<1){Kb=0;Lb=wb;break k}Db=nb+2|0;c[n>>2]=Db;Kb=d[wb]|0;Lb=Db;break k;break};case 4:{if((qb-wb|0)<2){Kb=0;Lb=wb;break k}Db=nb+3|0;c[n>>2]=Db;Cb=wb;Kb=(d[Cb]|d[Cb+1|0]<<8)<<16>>16&65535;Lb=Db;break k;break};case 5:{if((qb-wb|0)<2){Kb=0;Lb=wb;break k}Db=nb+3|0;c[n>>2]=Db;Cb=wb;Kb=(de((d[Cb]|d[Cb+1|0]<<8)<<16>>16|0)|0)&65535;Lb=Db;break k;break};case 9:{if((qb-wb|0)<4){Kb=0;Lb=wb;break k}Db=nb+5|0;c[n>>2]=Db;Cb=wb;Kb=fe(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0;Lb=Db;break k;break};case 8:{if((qb-wb|0)<4){Kb=0;Lb=wb;break k}Db=nb+5|0;c[n>>2]=Db;Cb=wb;Kb=d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0;Lb=Db;break k;break};default:{Kb=0;Lb=wb;break k}}}}while(0);l:do{if((xb&4|0)==0){Mb=lb;Nb=Lb}else{switch((c[A>>2]|0)+xa|0){case 2:case 3:{if((qb-Lb|0)<1){Mb=0;Nb=Lb;break l}wb=Lb+1|0;c[n>>2]=wb;Mb=d[Lb]|0;Nb=wb;break l;break};case 8:{if((qb-Lb|0)<4){Mb=0;Nb=Lb;break l}wb=Lb+4|0;c[n>>2]=wb;Db=Lb;Mb=d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0;Nb=wb;break l;break};case 9:{if((qb-Lb|0)<4){Mb=0;Nb=Lb;break l}wb=Lb+4|0;c[n>>2]=wb;Db=Lb;Mb=fe(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)|0;Nb=wb;break l;break};case 4:{if((qb-Lb|0)<2){Mb=0;Nb=Lb;break l}wb=Lb+2|0;c[n>>2]=wb;Db=Lb;Mb=(d[Db]|d[Db+1|0]<<8)<<16>>16&65535;Nb=wb;break l;break};case 5:{if((qb-Lb|0)<2){Mb=0;Nb=Lb;break l}wb=Lb+2|0;c[n>>2]=wb;Db=Lb;Mb=(de((d[Db]|d[Db+1|0]<<8)<<16>>16|0)|0)&65535;Nb=wb;break l;break};default:{Mb=0;Nb=Lb;break l}}}}while(0);if((xb&8|0)==0){rb=0;sb=Kb;tb=xb;ub=Mb;vb=Nb;U=197;break}if((qb-Nb|0)<1){rb=0;sb=Kb;tb=xb;ub=Mb;vb=Nb;U=197;break}wb=Nb+1|0;c[n>>2]=wb;rb=d[Nb]|0;sb=Kb;tb=xb;ub=Mb;vb=wb;U=197}}while(0);do{if((U|0)==197){U=0;qb=tb&16;wb=(qb|0)==0;Db=qb>>>4;do{if((T|0)==4){if(Ca&(pb|0)>0){Ob=0;Pb=jb}else{Qb=vb;Rb=ob;break}while(1){qb=Pb;Cb=0;do{c[qb+(Cb<<2)>>2]=sb;Cb=Cb+1|0;}while((Cb|0)<(pb|0));Cb=Ob+1|0;if((Cb|0)<(Da|0)){Ob=Cb;Pb=Pb+ka|0}else{Qb=vb;Rb=ob;break}}}else if((T|0)==1){if(!Ca){Qb=vb;Rb=ob;break}Cb=sb&255;qb=0;Bb=jb;while(1){TGb(Bb|0,Cb|0,pb|0)|0;Ab=qb+1|0;if((Ab|0)<(Da|0)){qb=Ab;Bb=Bb+ka|0}else{break}}Qb=c[n>>2]|0;Rb=c[r>>2]|0}else if((T|0)==2){if(!Ca){Qb=vb;Rb=ob;break}Bb=sb&65535;if((pb|0)>0){Sb=0;Tb=jb}else{Qb=vb;Rb=ob;break}while(1){qb=0;Cb=Tb;while(1){b[Cb>>1]=Bb;Ab=qb+1|0;if((Ab|0)<(pb|0)){qb=Ab;Cb=Cb+2|0}else{break}}Cb=Sb+1|0;if((Cb|0)<(Da|0)){Sb=Cb;Tb=Tb+ka|0}else{Qb=vb;Rb=ob;break}}}else{Qb=vb;Rb=ob}}while(0);if((Rb-Qb|0)>>>0<(ba((T&-Db)+2|0,rb)|0)>>>0){U=213;break b}if((rb|0)==0){yb=ub;zb=sb;break}else{Ub=ub;Vb=0}while(1){m:do{if(wb){Wb=Ub}else{switch((c[A>>2]|0)+xa|0){case 8:{xb=c[n>>2]|0;if(((c[r>>2]|0)-xb|0)<4){Wb=0;break m}c[n>>2]=xb+4;Bb=xb;Wb=d[Bb]|d[Bb+1|0]<<8|d[Bb+2|0]<<16|d[Bb+3|0]<<24|0;break m;break};case 2:case 3:{Bb=c[n>>2]|0;if(((c[r>>2]|0)-Bb|0)<1){Wb=0;break m}c[n>>2]=Bb+1;Wb=d[Bb]|0;break m;break};case 9:{Bb=c[n>>2]|0;if(((c[r>>2]|0)-Bb|0)<4){Wb=0;break m}c[n>>2]=Bb+4;xb=Bb;Wb=fe(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0;break m;break};case 4:{xb=c[n>>2]|0;if(((c[r>>2]|0)-xb|0)<2){Wb=0;break m}c[n>>2]=xb+2;Bb=xb;Wb=(d[Bb]|d[Bb+1|0]<<8)<<16>>16&65535;break m;break};case 5:{Bb=c[n>>2]|0;if(((c[r>>2]|0)-Bb|0)<2){Wb=0;break m}c[n>>2]=Bb+2;xb=Bb;Wb=(de((d[xb]|d[xb+1|0]<<8)<<16>>16|0)|0)&65535;break m;break};default:{Wb=0;break m}}}}while(0);xb=c[n>>2]|0;Bb=c[r>>2]|0;if((Bb-xb|0)<1){Xb=0;Yb=xb}else{Cb=xb+1|0;c[n>>2]=Cb;Xb=d[xb]|0;Yb=Cb}if((Bb-Yb|0)<1){Zb=0}else{c[n>>2]=Yb+1;Zb=d[Yb]|0}Bb=Xb>>>4;Cb=Zb>>>4;if((Bb+1+Cb|0)>(Ga|0)){U=232;break b}xb=Xb&15;qb=Zb&15;if((xb+1+qb|0)>(Ba|0)){U=232;break b}Ab=Cb+1|0;Cb=qb+1|0;qb=jb+((ba(xb,ka)|0)+(ba(Bb,T)|0))|0;if((T|0)==4){Bb=0;xb=qb;while(1){Gb=xb;Fb=0;do{c[Gb+(Fb<<2)>>2]=Wb;Fb=Fb+1|0;}while((Fb|0)<(Ab|0));Fb=Bb+1|0;if((Fb|0)<(Cb|0)){Bb=Fb;xb=xb+ka|0}else{break}}}else if((T|0)==2){xb=Wb&65535;Bb=0;Fb=qb;while(1){Gb=0;Eb=Fb;while(1){b[Eb>>1]=xb;Hb=Gb+1|0;if((Hb|0)<(Ab|0)){Gb=Hb;Eb=Eb+2|0}else{break}}Eb=Bb+1|0;if((Eb|0)<(Cb|0)){Bb=Eb;Fb=Fb+ka|0}else{break}}}else if((T|0)==1){Fb=Wb&255;Bb=0;xb=qb;while(1){TGb(xb|0,Fb|0,Ab|0)|0;Eb=Bb+1|0;if((Eb|0)<(Cb|0)){Bb=Eb;xb=xb+ka|0}else{break}}}xb=Vb+1|0;if((xb|0)<(rb|0)){Ub=Wb;Vb=xb}else{yb=Wb;zb=sb;break}}}}while(0);if((hb|0)>=(_|0)){fb=zb;gb=yb;break g}Ga=c[n>>2]|0;wb=c[r>>2]|0;if((wb|0)==(Ga|0)){U=144;break b}else{ib=pb;jb=jb+ya|0;kb=hb;lb=yb;mb=zb;nb=Ga;ob=wb}}}}while(0);if((va|0)<(aa|0)){za=fb;oa=gb;na=va;ua=ua+X|0;Aa=Da}else{break}}}else if((ja|0)==1464686185){c[ea+84>>2]=1;c[ea+88>>2]=1;if((ma|0)<1){_b=0;$b=da}else{Aa=ca+5|0;c[n>>2]=Aa;_b=d[da]|0;$b=Aa}Aa=c[N>>2]|0;if((_b|0)==(Aa|0)){ac=q;bc=$b}else{yDb(y,32,1963792,(p=i,i=i+16|0,c[p>>2]=Aa,c[p+8>>2]=_b,p)|0);i=p;ac=c[r>>2]|0;bc=c[n>>2]|0}Aa=ac;X=Aa-bc|0;ua=X>>>0>1>>>0?1:X;X=bc+ua|0;c[n>>2]=X;if((Aa-X|0)<1){c[A>>2]=0;cc=X}else{na=bc+(ua+1)|0;c[n>>2]=na;ua=a[X]|0;dc=ua&255;c[A>>2]=dc;if((ua&255)>>>0>1>>>0){U=106;break b}else{cc=na}}na=Aa-cc|0;c[n>>2]=cc+(na>>>0>13>>>0?13:na);break}else if((ja|0)==0){fa=T;ga=ka;ha=la;ia=ma;U=109;break}else if((ja|0)==1464686183){c[n>>2]=ca+(ma>>>0>10>>>0?14:ma+4|0);break}else if((ja|0)==1464686184){c[n>>2]=ca+(ma>>>0>4>>>0?8:ma+4|0);break}else{U=247;break b}}}while(0);do{if((U|0)==109){U=0;ec=c[O>>2]|0;if((_+V|0)>(ec|0)){U=110;break b}S=c[P>>2]|0;if((aa+Y|0)>(S|0)){fc=S;U=112;break b}gc=ba(ba(aa,_)|0,fa)|0;if((ia|0)<(gc|0)){U=114;break b}if((aa|0)==0){break}S=(_|0)==0;na=(c[A>>2]|0)+(fa<<1)|0;Aa=0;ua=ha;while(1){n:do{if(!S){X=ua;oa=ua;za=0;while(1){o:do{switch(na|0){case 2:case 3:{ya=c[n>>2]|0;if(((c[r>>2]|0)-ya|0)<1){hc=0;break o}c[n>>2]=ya+1;hc=d[ya]|0;break};case 5:{ya=c[n>>2]|0;if(((c[r>>2]|0)-ya|0)<2){hc=0;break o}c[n>>2]=ya+2;xa=ya;hc=(de((d[xa]|d[xa+1|0]<<8)<<16>>16|0)|0)&65535;break};case 9:{xa=c[n>>2]|0;if(((c[r>>2]|0)-xa|0)<4){hc=0;break o}c[n>>2]=xa+4;ya=xa;hc=fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0;break};case 8:{ya=c[n>>2]|0;if(((c[r>>2]|0)-ya|0)<4){hc=0;break o}c[n>>2]=ya+4;xa=ya;hc=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;break};case 4:{xa=c[n>>2]|0;if(((c[r>>2]|0)-xa|0)<2){hc=0;break o}c[n>>2]=xa+2;ya=xa;hc=(d[ya]|d[ya+1|0]<<8)<<16>>16&65535;break};default:{hc=0}}}while(0);if((fa|0)==1){a[ua+za|0]=hc}else if((fa|0)==2){b[X+(za<<1)>>1]=hc}else if((fa|0)==4){c[oa+(za<<2)>>2]=hc}za=za+1|0;if((za|0)>=(_|0)){break n}}}}while(0);Da=Aa+1|0;if((Da|0)<(aa|0)){Aa=Da;ua=ua+ga|0}else{break}}}}while(0);if((R|0)==0){break a}Q=R;z=c[n>>2]|0;q=c[r>>2]|0}if((U|0)==14){yDb(y,16,2178824,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1;i=j;return o|0}else if((U|0)==27){yDb(y,16,2102536,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==29){yDb(y,16,2046392,(p=i,i=i+16|0,c[p>>2]=pa,c[p+8>>2]=ma,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==33){$Db(I);$Db(H);$Db(t);c[G>>2]=0;c[E>>2]=0;c[B>>2]=0;c[J>>2]=0;o=-22;i=j;return o|0}else if((U|0)==37){$Db(I);$Db(H);$Db(t);c[G>>2]=0;c[E>>2]=0;c[B>>2]=0;c[J>>2]=0;o=ta;i=j;return o|0}else if((U|0)==106){yDb(y,32,1935664,(p=i,i=i+8|0,c[p>>2]=dc,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==110){fc=c[P>>2]|0;U=112}else if((U|0)==114){yDb(y,16,2046392,(p=i,i=i+16|0,c[p>>2]=gc,c[p+8>>2]=ia,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==137){eb=c[P>>2]|0;U=139}else if((U|0)==144){yDb(c[h>>2]|0,16,2178824,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==148){yDb(c[h>>2]|0,16,2178824,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==213){yDb(c[h>>2]|0,16,2178824,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==232){yDb(c[h>>2]|0,16,2349376,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==247){yDb(y,16,1891856,(p=i,i=i+8|0,c[p>>2]=ja,p)|0);i=p;break}if((U|0)==112){yDb(y,16,1912336,(p=i,i=i+48|0,c[p>>2]=_,c[p+8>>2]=aa,c[p+16>>2]=V,c[p+24>>2]=Y,c[p+32>>2]=ec,c[p+40>>2]=fc,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==139){yDb(y,16,1912336,(p=i,i=i+48|0,c[p>>2]=_,c[p+8>>2]=aa,c[p+16>>2]=V,c[p+24>>2]=Y,c[p+32>>2]=db,c[p+40>>2]=eb,p)|0);i=p;o=-1094995529;i=j;return o|0}}}while(0);p=c[u>>2]|0;do{if((p|0)!=0){eb=h+808|0;db=c[eb>>2]|0;Y=h+788|0;V=c[Y>>2]|0;aa=h+816|0;_=c[aa>>2]|0;U=h+812|0;fc=c[U>>2]|0;ec=h+792|0;ja=c[ec>>2]|0;ia=h+820|0;gc=c[ia>>2]|0;dc=(_|0)<0;ta=((V|0)<(_+db|0)?V-_|0:db)+(dc?_:0)|0;V=(gc|0)<0;t=((ja|0)<(gc+fc|0)?ja-gc|0:fc)+(V?gc:0)|0;if(!((ta|0)>0&(t|0)>0)){break}fc=c[m>>2]|0;ja=h+12|0;ma=c[ja>>2]|0;pa=(ba(c[fc+32>>2]|0,V?0:gc)|0)+(ba(ma,dc?0:_)|0)|0;_=(c[fc>>2]|0)+pa|0;pa=0;fc=p;dc=db;db=ma;while(1){UGb(fc+(ba(ba(dc,pa)|0,db)|0)|0,_|0,ba(db,ta)|0)|0;ic=c[m>>2]|0;jc=c[ic+32>>2]|0;ma=pa+1|0;if((ma|0)>=(t|0)){break}_=_+jc|0;pa=ma;fc=c[u>>2]|0;dc=c[eb>>2]|0;db=c[ja>>2]|0}db=c[eb>>2]|0;dc=c[Y>>2]|0;fc=c[aa>>2]|0;pa=c[U>>2]|0;_=c[ec>>2]|0;t=c[ia>>2]|0;ta=(fc|0)<0;y=((dc|0)<(fc+db|0)?dc-fc|0:db)+(ta?fc:0)|0;dc=(t|0)<0;P=((_|0)<(t+pa|0)?_-t|0:pa)+(dc?t:0)|0;if((y|0)<1|(P|0)<1){break}pa=c[ja>>2]|0;_=(c[ic>>2]|0)+((ba(pa,ta?0:fc)|0)+(ba(dc?0:t,jc)|0))|0;if((pa|0)==4){if((P|0)<=0){break}t=(y|0)>0;dc=0;fc=c[h+832>>2]|0;ta=c[h+836>>2]|0;J=_;B=db;while(1){E=J;if(t){G=0;do{H=E+(G<<2)|0;c[H>>2]=c[fc+(G<<2)>>2]&c[H>>2]^c[ta+(G<<2)>>2];G=G+1|0;}while((G|0)<(y|0));kc=c[eb>>2]|0}else{kc=B}G=dc+1|0;if((G|0)<(P|0)){dc=G;fc=fc+(kc<<2)|0;ta=ta+(kc<<2)|0;J=J+jc|0;B=kc}else{break}}}else if((pa|0)==1){if((P|0)<=0){break}B=(y|0)>0;J=0;ta=c[h+832>>2]|0;fc=c[h+836>>2]|0;dc=_;t=db;while(1){if(B){ja=0;do{ia=dc+ja|0;a[ia]=a[ta+ja|0]&a[ia]^a[fc+ja|0];ja=ja+1|0;}while((ja|0)<(y|0));lc=c[eb>>2]|0}else{lc=t}ja=J+1|0;if((ja|0)<(P|0)){J=ja;ta=ta+lc|0;fc=fc+lc|0;dc=dc+jc|0;t=lc}else{break}}}else if((pa|0)==2){if((P|0)<=0){break}t=(y|0)>0;dc=0;fc=c[h+832>>2]|0;ta=c[h+836>>2]|0;J=_;while(1){eb=J;if(t){B=0;do{ja=eb+(B<<1)|0;b[ja>>1]=b[fc+(B<<1)>>1]&b[ja>>1]^b[ta+(B<<1)>>1];B=B+1|0;}while((B|0)<(y|0))}B=dc+1|0;if((B|0)<(P|0)){dc=B;fc=fc+(db<<1)|0;ta=ta+(db<<1)|0;J=J+jc|0}else{break}}}else{break}}}while(0);c[g>>2]=1;g=MCb(f,c[m>>2]|0)|0;o=(g|0)<0?g:l;i=j;return o|0}function c4a(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);$Db(b+832|0);$Db(b+836|0);$Db(b+840|0);return 0}function d4a(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+32|0;g=f|0;h=f+16|0;c[e>>2]=b;c[e+4>>2]=1;j=g|0;k=h|0;l=Bdb(c[b+96>>2]|0,c[b+100>>2]|0,30,j,k)|0;if((l|0)<0){yDb(b,16,2201096,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=l;i=f;return n|0}l=c[j>>2]|0;if((c[k>>2]|0)<30){yDb(b,16,2329184,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((a[l]|0)!=1){yDb(b,16,2304784,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((PGb(l+1|0,2000800,6)|0)!=0){yDb(b,16,2286944,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((a[l+29|0]&1)==0){yDb(b,16,2270808,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}k=l+28|0;c[e+12>>2]=1<<(a[k]&15);c[e+16>>2]=1<<((d[k]|0)>>>4);k=c[g+8>>2]|0;g=c[h+8>>2]|0;if((g|0)<7){yDb(b,16,2102504,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((a[k]|0)!=5){yDb(b,16,2046352,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((PGb(k+1|0,2000800,6)|0)!=0){yDb(b,16,1963744,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}h=WDb(g)|0;if((h|0)==0){yDb(b,16,1935648,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-12;i=f;return n|0}if((g|0)>0){l=g-1|0;j=0;do{a[h+j|0]=a[k+(l-j)|0]|0;j=j+1|0;}while((j|0)<(g|0))}j=g<<3;g=j>>>0>2147483639>>>0;l=g?0:h;k=g?0:j;j=k+8|0;g=0;while(1){if((k-g|0)<=97){o=27;break}p=((g|0)<(j|0))+g|0;if((d[l+(g>>>3)|0]&128>>>((g&7)>>>0)|0)==0){g=p}else{o=25;break}}a:do{if((o|0)==25){if((p|0)==0){o=27;break}do{if((k-p|0)>96){g=p;q=1;r=0;s=0;while(1){t=l+(g>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(g&7);t=g+8|0;v=j>>>0>t>>>0?t:j;if(u>>>0>1073741823>>>0){w=r;x=s;break}u=l+(v>>>3)|0;t=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=v+16|0;y=j>>>0>u>>>0?u:j;if((t&-65536>>>((v&7)>>>0)|0)!=0){w=r;x=s;break}v=l+(y>>>3)|0;t=y+16|0;if(((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)&-65536>>>((y&7)>>>0)|0)!=0){w=r;x=s;break}y=(j>>>0>t>>>0?t:j)+1|0;t=j>>>0>y>>>0?y:j;if((q|0)>64){w=r;x=s;break}y=l+(t>>>3)|0;v=(((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(t&7)>>>26)+1|0)==(q|0);y=v?1:r;u=v?q:s;if((k-t|0)>96){g=t;q=q+1|0;r=y;s=u}else{w=y;x=u;break}}if((w|0)==0){break}do{if((x|0)>2){s=b;DDb(s,1891784,(m=i,i=i+8|0,c[m>>2]=x,m)|0);i=m;if((x|0)<=63){break}yDb(s,16,2349344,(m=i,i=i+8|0,c[m>>2]=x,m)|0);i=m;break a}}while(0);c[e+280>>2]=x;s=x-1|0;r=s>>>0>65535>>>0;q=r?s>>>16:s;g=r?16:0;if((q&65280|0)==0){z=g;A=q}else{z=g|8;A=q>>>8}q=(2<<z+1+(d[1191992+A|0]|0))-2|0;c[e+284>>2]=q;c[e+288>>2]=(q|1)+1;if((p|0)<0){B=0}else{B=(j|0)<(p|0)?j:p}if((x|0)>0){q=B;g=s;while(1){s=-q|0;r=j-q|0;if((s|0)>40){C=s}else{C=(r|0)<40?r:40}r=C+q|0;c[e+24+(g<<2)>>2]=d[l+(r>>>3)|0]<<(r&7)>>>7&1;if((g|0)>0){q=((r|0)<(j|0))+r|0;g=g-1|0}else{break}}}ZDb(h);c[e+8>>2]=1;c[e+20>>2]=c[e+12+(c[e+24>>2]<<2)>>2];n=0;i=f;return n|0}}while(0);yDb(b,16,1912312,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}}while(0);if((o|0)==27){yDb(b,16,1912312,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}ZDb(h);n=-1094995529;i=f;return n|0}function e4a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;if(!((c[b+8>>2]|0)!=0&(e|0)>0)){h=0;i=g;return h|0}e=b+20|0;j=c[e>>2]|0;k=a[d]|0;d=k&255;if((d&1|0)!=0){do{if((f|0)!=0){if((k<<24>>24|0)==3){l=c[f>>2]|2}else if((k<<24>>24|0)==1){l=c[f>>2]|1}else{break}c[f>>2]=l;h=0;i=g;return h|0}}while(0);yDb(c[b>>2]|0,16,2311920,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=g;return h|0}l=c[b+280>>2]|0;if((l|0)==1){n=0}else{n=(c[b+284>>2]&d)>>>1}if((n|0)>=(l|0)){yDb(c[b>>2]|0,16,2178800,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=g;return h|0}m=c[b+24+(n<<2)>>2]|0;if((m|0)==0){o=j}else{o=c[b+12+(((d&c[b+288>>2]|0)!=0)<<2)>>2]|0}d=c[b+12+(m<<2)>>2]|0;c[e>>2]=d;h=d+o>>2;i=g;return h|0}function f4a(a){a=a|0;if((c[a+8>>2]|0)==0){return}c[a+20>>2]=c[a+12>>2];return}function g4a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0,i=0.0,j=0;if((c|0)>0){d=0}else{return}do{e=a+(d<<2)|0;f=+g[e>>2];h=b+(d<<2)|0;i=+g[h>>2];j=i>0.0;do{if(f>0.0){if(j){g[h>>2]=f-i;break}else{g[h>>2]=f;g[e>>2]=i+ +g[e>>2];break}}else{if(j){g[h>>2]=f+i;break}else{g[h>>2]=f;g[e>>2]=+g[e>>2]-i;break}}}while(0);d=d+1|0;}while((d|0)<(c|0));return}function h4a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+32|0;f=e|0;g=e+16|0;h=c[b+60>>2]|0;j=h;k=c[b+96>>2]|0;l=c[b+100>>2]|0;c[h>>2]=b;q4a(h+24|0);fCb(h+28|0,c[b+88>>2]&8388608);iba(h+64|0,b);c[b+420>>2]=8;if((l|0)==0){yDb(b,16,1983504,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}o=f|0;p=g|0;q=Bdb(k,l,30,o,p)|0;if((q|0)<0){yDb(b,16,1980664,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=q;i=e;return n|0}q=c[o>>2]|0;o=c[p>>2]<<3;p=o>>>0>2147483639>>>0|(q|0)==0;l=p?0:q;q=p?0:o;o=h+4|0;c[o>>2]=l;p=h+16|0;c[p>>2]=q;k=q+8|0;r=h+20|0;c[r>>2]=k;s=h+8|0;c[s>>2]=l+(q>>3);q=h+12|0;c[q>>2]=0;t=l;l=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24)&255;c[q>>2]=k>>>0>8>>>0?8:k;if((l|0)!=1){yDb(b,16,1977880,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}l=m4a(j)|0;if((l|0)!=0){yDb(b,16,2178776,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;l4a(j);n=l;i=e;return n|0}l=c[f+8>>2]|0;f=c[g+8>>2]<<3;g=f>>>0>2147483639>>>0|(l|0)==0;k=g?0:l;l=g?0:f;c[o>>2]=k;c[p>>2]=l;p=l+8|0;c[r>>2]=p;c[s>>2]=k+(l>>3);c[q>>2]=0;l=k;k=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)&255;c[q>>2]=p>>>0>8>>>0?8:p;if((k|0)!=5){yDb(b,16,1975320,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;l4a(j);n=-1094995529;i=e;return n|0}k=n4a(j)|0;if((k|0)!=0){yDb(b,16,2046328,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;l4a(j);n=k;i=e;return n|0}k=h+220|0;j=a[k]|0;if((j&255)>>>0>8>>>0){m=b+448|0;c[m>>2]=0;c[m+4>>2]=0}else{m=1088792+((j&255)-1<<3)|0;j=c[m+4>>2]|0;p=b+448|0;c[p>>2]=c[m>>2];c[p+4>>2]=j}c[b+416>>2]=d[k]|0;c[b+412>>2]=c[h+224>>2];n=0;i=e;return n|0}function i4a(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0;l=i;i=i+1792|0;m=l|0;n=l+256|0;o=l+512|0;p=l+768|0;q=c[k+24>>2]|0;r=c[k+28>>2]|0;k=c[f+60>>2]|0;s=k;t=h;u=k+4|0;v=a[q]|0;w=(r|0)>7;if(v<<24>>24==1&w){x=q+1|0;y=(r<<3)-8|0;z=y>>>0>2147483639>>>0|(x|0)==0;A=z?0:x;x=z?0:y;c[u>>2]=A;c[k+16>>2]=x;c[k+20>>2]=x+8;c[k+8>>2]=A+(x>>3);c[k+12>>2]=0;l4a(s);x=m4a(s)|0;if((x|0)!=0){yDb(f,16,2178776,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;l4a(s);C=x;i=l;return C|0}x=k+220|0;A=a[x]|0;if((A&255)>>>0>8>>>0){y=f+448|0;c[y>>2]=0;c[y+4>>2]=0}else{y=1088792+((A&255)-1<<3)|0;A=c[y+4>>2]|0;z=f+448|0;c[z>>2]=c[y>>2];c[z+4>>2]=A}c[f+416>>2]=d[x]|0;c[f+412>>2]=c[k+224>>2];C=r;i=l;return C|0}if(v<<24>>24==3&w){yDb(f,48,2102472,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=r;i=l;return C|0}x=c[k+300>>2]|0;do{if(v<<24>>24==5&w){if((x|0)==0){break}if((c[k+292>>2]|0)!=0){D=17;break}A=q+1|0;z=(r<<3)-8|0;y=z>>>0>2147483639>>>0|(A|0)==0;E=y?0:A;A=y?0:z;c[u>>2]=E;c[k+16>>2]=A;c[k+20>>2]=A+8;c[k+8>>2]=E+(A>>3);c[k+12>>2]=0;A=n4a(s)|0;if((A|0)==0){C=r;i=l;return C|0}yDb(f,16,2046328,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;l4a(s);C=A;i=l;return C|0}else{if((x|0)!=0){D=17}}}while(0);do{if((D|0)==17){x=k+300|0;w=k+292|0;if((c[w>>2]|0)==0){break}v=k+244|0;A=h+76|0;c[A>>2]=(c[v>>2]|0)>>>1;E=_$a(f,t,0)|0;if((E|0)<0){C=E;i=l;return C|0}E=k+220|0;z=a[E]|0;do{if((z&255)>>>0>8>>>0){y=c[h+64>>2]|0;G=z&255;H=0;while(1){c[p+(H<<2)>>2]=c[y+(H<<2)>>2];I=H+1|0;if((I|0)<(G|0)){H=I}else{J=z;break}}}else{if(z<<24>>24==0){J=0;break}H=z&255;G=c[h+64>>2]|0;y=0;while(1){c[p+(d[1088864+(H-1<<3)+y|0]<<2)>>2]=c[G+(y<<2)>>2];I=y+1|0;if((I|0)<(H|0)){y=I}else{J=z;break}}}}while(0);z=r<<3;y=z>>>0>2147483639>>>0|(q|0)==0;H=y?0:q;G=y?0:z;z=u;c[z>>2]=H;c[k+16>>2]=G;y=G+8|0;I=k+20|0;c[I>>2]=y;c[k+8>>2]=H+(G>>3);G=k+12|0;c[G>>2]=0;K=n|0;L=k+297|0;M=a[L]|0;N=M<<24>>24;O=c[x>>2]|0;P=J&255;Q=a[H]|0;R=(y|0)>0|0;c[G>>2]=R;a:do{if((Q&1)==0){S=a[k+288|0]|0;do{if(S<<24>>24==1){T=0;U=R}else{V=S&255;W=(V<<1)-2|0;X=W>>>0>65535>>>0;Y=X?W>>>16:W;W=X?16:0;if((Y&65280|0)==0){Z=W;_=Y}else{Z=W|8;_=Y>>>8}Y=(d[1191992+_|0]|0)+Z|0;W=H;X=32-Y|0;$=(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)>>>(R>>>0)<<X>>>(X>>>0);X=Y+R|0;Y=y>>>0>X>>>0?X:y;c[G>>2]=Y;if($>>>0<V>>>0){T=$;U=Y;break}yDb(c[k>>2]|0,16,917672,(B=i,i=i+40|0,c[B>>2]=$,c[B+8>>2]=V-1,c[B+16>>2]=1935632,c[B+24>>2]=1912288,c[B+32>>2]=1572,B)|0);i=B;aa=-1094995529;break a}}while(0);a[k+296|0]=T;S=c[w>>2]|0;V=d[S+(T<<3)+6|0]|0;$=c[k+284>>2]|0;Y=$+(V*48|0)|0;X=a[S+(T<<3)|0]|0;S=X&255;W=c[s+240+(S<<2)>>2]|0;ca=W>>>1;if(X<<24>>24==0){da=M<<24>>24<0?0:N}else{ea=H+(U>>>3)|0;fa=(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)>>>((U&7)>>>0);ea=U+2|0;c[G>>2]=y>>>0>ea>>>0?ea:y;da=M<<24>>24<0?fa>>>1&1:N}fa=ca<<2;TGb(O|0,0,ba(fa,P)|0)|0;b:do{if((a[E]|0)==0){ga=0}else{ea=0;do{TGb(c[p+(ea<<2)>>2]|0,0,fa|0)|0;ea=ea+1|0;ha=a[E]|0;}while((ea|0)<(ha&255|0));if(ha<<24>>24==0){ga=0;break}ea=Y|0;ia=$+(V*48|0)+12|0;ja=k+268|0;ka=$+(V*48|0)+16|0;la=0;while(1){if((d[ea]|0)>>>0>1>>>0){ma=(c[ja>>2]|0)+((d[(d[(c[ia>>2]|0)+la|0]|0)+($+(V*48|0)+16)|0]|0)*356|0)|0}else{ma=(c[ja>>2]|0)+((d[ka]|0)*356|0)|0}na=ze[c[ma+4>>2]&511](s,ma+8|0,c[p+(la<<2)>>2]|0)|0;if((na|0)<0){break}a[m+la|0]=na;na=la+1|0;oa=a[E]|0;if((na|0)<(oa&255|0)){la=na}else{ga=oa;break b}}yDb(c[k>>2]|0,16,1891736,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}}while(0);fa=$+(V*48|0)+2|0;la=b[fa>>1]|0;if(!(la<<16>>16==0)){ka=c[$+(V*48|0)+4>>2]|0;ja=c[$+(V*48|0)+8>>2]|0;ia=la&65535;do{ia=ia-1|0;la=m+(d[ka+ia|0]|0)|0;ea=m+(d[ja+ia|0]|0)|0;if((a[ea]&a[la])<<24>>24==0){a[la]=0;a[ea]=0}}while((ia|0)>0)}ia=Y|0;ja=a[ia]|0;c:do{if(ja<<24>>24==0){pa=P}else{ka=k+276|0;ea=k+260|0;la=$+(V*48|0)+12|0;oa=P;na=0;qa=O;ra=0;sa=ja;ta=ga;d:while(1){if(ta<<24>>24==0){ua=0;va=na}else{wa=sa<<24>>24==1;xa=ta&255;ya=0;za=na;Aa=0;while(1){if(wa){D=57}else{if((ra|0)==(d[(c[la>>2]|0)+Aa|0]|0)){D=57}else{Ba=za;Ca=ya}}if((D|0)==57){D=0;a[o+Aa|0]=za;a[n+ya|0]=(a[m+Aa|0]|0)!=0|0;Ba=za+1|0;Ca=ya+1|0}Da=Aa+1|0;if((Da|0)<(xa|0)){ya=Ca;za=Ba;Aa=Da}else{ua=Ca;va=Ba;break}}}Aa=d[$+(V*48|0)+32+ra|0]|0;za=c[ka>>2]|0;if(oa>>>0<ua>>>0){D=60;break}do{if((ua|0)!=0){ya=b[za+(Aa*1052|0)>>1]|0;if((ya<<16>>16|0)==1){xa=za+(Aa*1052|0)+17|0;wa=a[(c[ea>>2]|0)+(d[xa]<<5)|0]|0;Da=wa&255;Ea=za+(Aa*1052|0)+1048|0;Fa=c[Ea>>2]|0;Ga=ba(ua-1|0,ca)|0;Ha=za+(Aa*1052|0)+1044|0;Ia=b[Ha>>1]|0;Ja=Ia&65535;if(((c[za+(Aa*1052|0)+8>>2]|0)+Ga|0)>>>0>(ba(oa,ca)|0)>>>0){D=131;break d}Ga=za+(Aa*1052|0)+1042|0;Ka=za+(Aa*1052|0)+4|0;La=Ia<<16>>16==0;Ia=za+(Aa*1052|0)+16|0;Ma=wa<<24>>24!=0;wa=za+(Aa*1052|0)+12|0;Na=-Da|0;Oa=0;do{if(!La){Pa=(Oa|0)==0;Qa=c[Ka>>2]|0;Ra=0;while(1){e:do{if(Pa){Sa=Ra-1+(d[(c[ea>>2]|0)+(d[xa]<<5)|0]|0)|0;Ta=(Sa|0)<(Ra|0);Ua=c[1199552+(d[Ia]<<2)>>2]|0;Va=0;Wa=0;Xa=0;while(1){f:do{if((a[n+Wa|0]|0)==0){Ya=d[xa]|0;Za=c[ea>>2]|0;_a=c[Za+(Ya<<5)+8>>2]|0;$a=c[Za+(Ya<<5)+28>>2]|0;Ya=c[G>>2]|0;Za=c[I>>2]|0;ab=c[z>>2]|0;bb=ab+(Ya>>>3)|0;cb=32-$a|0;db=(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)>>>((Ya&7)>>>0)<<cb>>>(cb>>>0);cb=b[_a+(db<<2)>>1]|0;bb=b[_a+(db<<2)+2>>1]|0;db=bb<<16>>16;do{if(bb<<16>>16<0){eb=Ya+$a|0;fb=Za>>>0>eb>>>0?eb:Za;eb=ab+(fb>>>3)|0;gb=db+32|0;hb=((d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)>>>((fb&7)>>>0)<<gb>>>(gb>>>0))+cb|0;gb=b[_a+(hb<<2)>>1]|0;eb=b[_a+(hb<<2)+2>>1]|0;hb=eb<<16>>16;if(!(eb<<16>>16<0)){ib=hb;jb=gb;kb=fb;break}eb=fb-db|0;fb=Za>>>0>eb>>>0?eb:Za;eb=ab+(fb>>>3)|0;lb=hb+32|0;hb=((d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)>>>((fb&7)>>>0)<<lb>>>(lb>>>0))+gb|0;ib=b[_a+(hb<<2)+2>>1]|0;jb=b[_a+(hb<<2)>>1]|0;kb=fb}else{ib=db;jb=cb;kb=Ya}}while(0);Ya=ib+kb|0;c[G>>2]=Za>>>0>Ya>>>0?Ya:Za;if((jb|0)<0){aa=jb;break a}Ya=a[Ia]|0;if(!((Ya&255)>>>0>1>>>0)){D=144;break d}if(jb>>>0<65537>>>0){if(Ta){break}else{mb=Sa;nb=jb}while(1){gHb(nb,0,Ua,Va)|0;cb=F;if((mb|0)<(e[Ha>>1]|0)){db=nb-(ba(d[Ia]|0,cb)|0)&255;a[(c[Ea>>2]|0)+(mb+Xa)|0]=db}db=mb-1|0;if((db|0)<(Ra|0)){break f}else{mb=db;nb=cb}}}if(Ta){break}else{ob=Sa;pb=jb;qb=Ya}while(1){Za=qb&255;cb=(pb>>>0)/(Za>>>0)|0;if((ob|0)<(e[Ha>>1]|0)){db=pb-(ba(cb,Za)|0)&255;a[(c[Ea>>2]|0)+(ob+Xa)|0]=db}db=ob-1|0;if((db|0)<(Ra|0)){break f}ob=db;pb=cb;qb=a[Ia]|0}}}while(0);Ya=Wa+1|0;if(!(Ya>>>0<ua>>>0)){break e}Wa=Ya;Xa=(e[Ha>>1]|0)+Xa|0}}}while(0);if(Ma&(Ra|0)<(Ja|0)){Xa=Qa;Wa=Ra;Sa=0;do{Ta=0;Va=0;while(1){do{if((a[n+Va|0]|0)==0){Ua=b[za+(Aa*1052|0)+18+(d[Fa+(Ta+Wa)|0]<<4)+(Oa<<1)>>1]|0;if(!(Ua<<16>>16>-1)){break}Ya=Ua<<16>>16;Ua=c[ea>>2]|0;cb=c[Ua+(Ya<<5)+24>>2]|0;if((cb|0)==0){break}db=a[Ua+(Ya<<5)|0]|0;Za=db&255;_a=c[wa>>2]|0;gHb(_a<<1|0>>>31,0<<1|_a>>>31,c[1199552+(Za<<1<<2)>>2]|0,0)|0;_a=F;ab=c[Ua+(Ya<<5)+8>>2]|0;$a=c[Ua+(Ya<<5)+28>>2]|0;if((_a|0)==0){break}Ya=(ba(Va,ca)|0)+Xa|0;Ua=32-$a|0;bb=db<<24>>24==0;db=c[I>>2]|0;fb=c[z>>2]|0;hb=Ya;Ya=0;gb=c[G>>2]|0;while(1){lb=fb+(gb>>>3)|0;eb=(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)>>>((gb&7)>>>0)<<Ua>>>(Ua>>>0);lb=b[ab+(eb<<2)>>1]|0;rb=b[ab+(eb<<2)+2>>1]|0;eb=rb<<16>>16;do{if(rb<<16>>16<0){sb=gb+$a|0;tb=db>>>0>sb>>>0?sb:db;sb=fb+(tb>>>3)|0;ub=eb+32|0;vb=((d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)>>>((tb&7)>>>0)<<ub>>>(ub>>>0))+lb|0;ub=b[ab+(vb<<2)>>1]|0;sb=b[ab+(vb<<2)+2>>1]|0;vb=sb<<16>>16;if(!(sb<<16>>16<0)){wb=vb;xb=ub;yb=tb;break}sb=tb-eb|0;tb=db>>>0>sb>>>0?sb:db;sb=fb+(tb>>>3)|0;zb=vb+32|0;vb=((d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)>>>((tb&7)>>>0)<<zb>>>(zb>>>0))+ub|0;wb=b[ab+(vb<<2)+2>>1]|0;xb=b[ab+(vb<<2)>>1]|0;yb=tb}else{wb=eb;xb=lb;yb=gb}}while(0);lb=wb+yb|0;eb=db>>>0>lb>>>0?lb:db;c[G>>2]=eb;lb=ba(xb,Za)|0;if(bb){Ab=hb}else{rb=hb;tb=0;while(1){vb=qa+(rb<<2)|0;g[vb>>2]=+g[cb+(tb+lb<<2)>>2]+ +g[vb>>2];vb=tb+1|0;if(vb>>>0<Za>>>0){rb=rb+1|0;tb=vb}else{break}}Ab=hb+Za|0}tb=Ya+1|0;if(tb>>>0<_a>>>0){hb=Ab;Ya=tb;gb=eb}else{break}}}}while(0);gb=Va+1|0;if(!(gb>>>0<ua>>>0)){break}Ta=Ta+Ja|0;Va=gb}Wa=Wa+1|0;Xa=(c[wa>>2]|0)+Xa|0;Sa=Sa+1|0;}while(Sa>>>0<Da>>>0&(Wa|0)<(Ja|0));Wa=Ra-Ja|0;Bb=Xa;Cb=Ra-(Wa>>>0<Na>>>0?Na:Wa)|0}else{Bb=Qa;Cb=Ra}if((Cb|0)<(Ja|0)){Qa=Bb;Ra=Cb}else{break}}}Oa=Oa+1|0;}while(!(Oa>>>0>(d[Ga]|0)>>>0))}else if((ya<<16>>16|0)==0){Ga=za+(Aa*1052|0)+17|0;Oa=a[(c[ea>>2]|0)+(d[Ga]<<5)|0]|0;Ja=Oa&255;Na=za+(Aa*1052|0)+1048|0;Da=c[Na>>2]|0;wa=ba(ua-1|0,ca)|0;Fa=za+(Aa*1052|0)+1044|0;Ma=b[Fa>>1]|0;Ha=Ma&65535;if(((c[za+(Aa*1052|0)+8>>2]|0)+wa|0)>>>0>(ba(oa,ca)|0)>>>0){D=177;break d}wa=za+(Aa*1052|0)+1042|0;Ia=za+(Aa*1052|0)+4|0;Ea=Ma<<16>>16==0;Ma=za+(Aa*1052|0)+16|0;xa=Oa<<24>>24!=0;Oa=za+(Aa*1052|0)+12|0;Ka=-Ja|0;La=0;do{if(!Ea){Ra=(La|0)==0;Qa=c[Ia>>2]|0;Pa=0;while(1){g:do{if(Ra){Wa=Pa-1+(d[(c[ea>>2]|0)+(d[Ga]<<5)|0]|0)|0;Sa=(Wa|0)<(Pa|0);Va=c[1199552+(d[Ma]<<2)>>2]|0;Ta=0;gb=0;Ya=0;while(1){h:do{if((a[n+gb|0]|0)==0){hb=d[Ga]|0;_a=c[ea>>2]|0;Za=c[_a+(hb<<5)+8>>2]|0;cb=c[_a+(hb<<5)+28>>2]|0;hb=c[G>>2]|0;_a=c[I>>2]|0;bb=c[z>>2]|0;db=bb+(hb>>>3)|0;ab=32-cb|0;fb=(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)>>>((hb&7)>>>0)<<ab>>>(ab>>>0);ab=b[Za+(fb<<2)>>1]|0;db=b[Za+(fb<<2)+2>>1]|0;fb=db<<16>>16;do{if(db<<16>>16<0){$a=hb+cb|0;Ua=_a>>>0>$a>>>0?$a:_a;$a=bb+(Ua>>>3)|0;tb=fb+32|0;rb=((d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)>>>((Ua&7)>>>0)<<tb>>>(tb>>>0))+ab|0;tb=b[Za+(rb<<2)>>1]|0;$a=b[Za+(rb<<2)+2>>1]|0;rb=$a<<16>>16;if(!($a<<16>>16<0)){Db=rb;Eb=tb;Fb=Ua;break}$a=Ua-fb|0;Ua=_a>>>0>$a>>>0?$a:_a;$a=bb+(Ua>>>3)|0;lb=rb+32|0;rb=((d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)>>>((Ua&7)>>>0)<<lb>>>(lb>>>0))+tb|0;Db=b[Za+(rb<<2)+2>>1]|0;Eb=b[Za+(rb<<2)>>1]|0;Fb=Ua}else{Db=fb;Eb=ab;Fb=hb}}while(0);hb=Db+Fb|0;c[G>>2]=_a>>>0>hb>>>0?hb:_a;if((Eb|0)<0){aa=Eb;break a}hb=a[Ma]|0;if(!((hb&255)>>>0>1>>>0)){D=190;break d}if(Eb>>>0<65537>>>0){if(Sa){break}else{Gb=Wa;Hb=Eb}while(1){gHb(Hb,0,Va,Ta)|0;ab=F;if((Gb|0)<(e[Fa>>1]|0)){fb=Hb-(ba(d[Ma]|0,ab)|0)&255;a[(c[Na>>2]|0)+(Gb+Ya)|0]=fb}fb=Gb-1|0;if((fb|0)<(Pa|0)){break h}else{Gb=fb;Hb=ab}}}if(Sa){break}else{Ib=Wa;Jb=Eb;Kb=hb}while(1){_a=Kb&255;ab=(Jb>>>0)/(_a>>>0)|0;if((Ib|0)<(e[Fa>>1]|0)){fb=Jb-(ba(ab,_a)|0)&255;a[(c[Na>>2]|0)+(Ib+Ya)|0]=fb}fb=Ib-1|0;if((fb|0)<(Pa|0)){break h}Ib=fb;Jb=ab;Kb=a[Ma]|0}}}while(0);hb=gb+1|0;if(!(hb>>>0<ua>>>0)){break g}gb=hb;Ya=(e[Fa>>1]|0)+Ya|0}}}while(0);if(xa&(Pa|0)<(Ha|0)){Xa=Qa;Ya=Pa;gb=0;do{Wa=0;Sa=0;while(1){do{if((a[n+Sa|0]|0)==0){Ta=b[za+(Aa*1052|0)+18+(d[Da+(Wa+Ya)|0]<<4)+(La<<1)>>1]|0;if(!(Ta<<16>>16>-1)){break}Va=Ta<<16>>16;Ta=c[ea>>2]|0;hb=c[Ta+(Va<<5)+24>>2]|0;if((hb|0)==0){break}ab=a[Ta+(Va<<5)|0]|0;fb=ab&255;_a=c[Oa>>2]|0;gHb(_a<<1|0>>>31,0<<1|_a>>>31,c[1199552+(fb<<1<<2)>>2]|0,0)|0;_a=F;Za=c[Ta+(Va<<5)+8>>2]|0;bb=c[Ta+(Va<<5)+28>>2]|0;Va=(ba(Sa,ca)|0)+Xa|0;if((_a|0)==0){break}Ta=32-bb|0;cb=ab<<24>>24==0;ab=c[I>>2]|0;db=c[z>>2]|0;Ua=0;rb=c[G>>2]|0;do{tb=db+(rb>>>3)|0;lb=(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)>>>((rb&7)>>>0)<<Ta>>>(Ta>>>0);tb=b[Za+(lb<<2)>>1]|0;$a=b[Za+(lb<<2)+2>>1]|0;lb=$a<<16>>16;do{if($a<<16>>16<0){vb=rb+bb|0;ub=ab>>>0>vb>>>0?vb:ab;vb=db+(ub>>>3)|0;zb=lb+32|0;sb=((d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((ub&7)>>>0)<<zb>>>(zb>>>0))+tb|0;zb=b[Za+(sb<<2)>>1]|0;vb=b[Za+(sb<<2)+2>>1]|0;sb=vb<<16>>16;if(!(vb<<16>>16<0)){Lb=sb;Mb=zb;Nb=ub;break}vb=ub-lb|0;ub=ab>>>0>vb>>>0?vb:ab;vb=db+(ub>>>3)|0;Ob=sb+32|0;sb=((d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((ub&7)>>>0)<<Ob>>>(Ob>>>0))+zb|0;Lb=b[Za+(sb<<2)+2>>1]|0;Mb=b[Za+(sb<<2)>>1]|0;Nb=ub}else{Lb=lb;Mb=tb;Nb=rb}}while(0);tb=Lb+Nb|0;rb=ab>>>0>tb>>>0?tb:ab;c[G>>2]=rb;tb=ba(Mb,fb)|0;if(!cb){lb=Va+Ua|0;$a=0;do{eb=qa+(lb+(ba($a,_a)|0)<<2)|0;g[eb>>2]=+g[hb+($a+tb<<2)>>2]+ +g[eb>>2];$a=$a+1|0;}while($a>>>0<fb>>>0)}Ua=Ua+1|0;}while(Ua>>>0<_a>>>0)}}while(0);_a=Sa+1|0;if(!(_a>>>0<ua>>>0)){break}Wa=Wa+Ha|0;Sa=_a}Ya=Ya+1|0;Xa=(c[Oa>>2]|0)+Xa|0;gb=gb+1|0;}while(gb>>>0<Ja>>>0&(Ya|0)<(Ha|0));Ya=Pa-Ha|0;Pb=Xa;Qb=Pa-(Ya>>>0<Ka>>>0?Ka:Ya)|0}else{Pb=Qa;Qb=Pa}if((Qb|0)<(Ha|0)){Qa=Pb;Pa=Qb}else{break}}}La=La+1|0;}while(!(La>>>0>(d[wa]|0)>>>0))}else if((ya<<16>>16|0)==2){wa=za+(Aa*1052|0)+17|0;La=a[(c[ea>>2]|0)+(d[wa]<<5)|0]|0;Ha=La&255;Ka=za+(Aa*1052|0)+1048|0;Ja=c[Ka>>2]|0;Oa=ba(ua-1|0,ca)|0;Da=za+(Aa*1052|0)+1044|0;xa=b[Da>>1]|0;Fa=xa&65535;Ma=a[K]|0;if(ua>>>0>1>>>0){Na=1;Ga=Ma;while(1){Ia=a[n+Na|0]&Ga;a[K]=Ia;Ea=Na+1|0;if(Ea>>>0<ua>>>0){Na=Ea;Ga=Ia}else{Rb=Ia;break}}}else{Rb=Ma}if(!(Rb<<24>>24==0)){break}if(((((c[za+(Aa*1052|0)+8>>2]|0)>>>0)/(ua>>>0)|0)+Oa|0)>>>0>(ba(oa,ca)|0)>>>0){D=68;break d}Ga=za+(Aa*1052|0)+1042|0;Na=za+(Aa*1052|0)+4|0;ya=xa<<16>>16==0;Ia=za+(Aa*1052|0)+16|0;Ea=La<<24>>24!=0;Pa=za+(Aa*1052|0)+12|0;Qa=1199552+(ua<<1<<2)|0;Ra=-Ha|0;Ya=(ua|0)!=2;gb=0;do{if(!ya){Sa=(gb|0)==0;Wa=c[Na>>2]|0;_a=0;while(1){i:do{if(Sa){Ua=c[ea>>2]|0;fb=d[wa]|0;hb=_a-1+(d[Ua+(fb<<5)|0]|0)|0;Va=(hb|0)<(_a|0);cb=c[1199552+(d[Ia]<<2)>>2]|0;rb=0;if((a[K]|0)!=0){break}ab=c[Ua+(fb<<5)+8>>2]|0;Za=c[Ua+(fb<<5)+28>>2]|0;fb=c[G>>2]|0;Ua=c[I>>2]|0;db=c[z>>2]|0;bb=db+(fb>>>3)|0;Ta=32-Za|0;$a=(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)>>>((fb&7)>>>0)<<Ta>>>(Ta>>>0);Ta=b[ab+($a<<2)>>1]|0;bb=b[ab+($a<<2)+2>>1]|0;$a=bb<<16>>16;do{if(bb<<16>>16<0){tb=fb+Za|0;lb=Ua>>>0>tb>>>0?tb:Ua;tb=db+(lb>>>3)|0;eb=$a+32|0;ub=((d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)>>>((lb&7)>>>0)<<eb>>>(eb>>>0))+Ta|0;eb=b[ab+(ub<<2)>>1]|0;tb=b[ab+(ub<<2)+2>>1]|0;ub=tb<<16>>16;if(!(tb<<16>>16<0)){Sb=ub;Tb=eb;Ub=lb;break}tb=lb-$a|0;lb=Ua>>>0>tb>>>0?tb:Ua;tb=db+(lb>>>3)|0;sb=ub+32|0;ub=((d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)>>>((lb&7)>>>0)<<sb>>>(sb>>>0))+eb|0;Sb=b[ab+(ub<<2)+2>>1]|0;Tb=b[ab+(ub<<2)>>1]|0;Ub=lb}else{Sb=$a;Tb=Ta;Ub=fb}}while(0);fb=Sb+Ub|0;c[G>>2]=Ua>>>0>fb>>>0?fb:Ua;if((Tb|0)<0){aa=Tb;break a}fb=a[Ia]|0;if(!((fb&255)>>>0>1>>>0)){D=80;break d}if(Tb>>>0<65537>>>0){if(Va){break}else{Vb=hb;Wb=Tb}while(1){gHb(Wb,0,cb,rb)|0;Ta=F;if((Vb|0)<(e[Da>>1]|0)){$a=Wb-(ba(d[Ia]|0,Ta)|0)&255;a[(c[Ka>>2]|0)+Vb|0]=$a}$a=Vb-1|0;if(($a|0)<(_a|0)){break i}else{Vb=$a;Wb=Ta}}}if(Va){break}else{Xb=hb;Yb=Tb;Zb=fb}while(1){rb=Zb&255;cb=(Yb>>>0)/(rb>>>0)|0;if((Xb|0)<(e[Da>>1]|0)){Ua=Yb-(ba(cb,rb)|0)&255;a[(c[Ka>>2]|0)+Xb|0]=Ua}Ua=Xb-1|0;if((Ua|0)<(_a|0)){break i}Xb=Ua;Yb=cb;Zb=a[Ia]|0}}}while(0);if(Ea&(_a|0)<(Fa|0)){Xa=Wa;fb=_a;hb=1;while(1){Va=Xa&1;cb=Xa>>1;Ua=Xa;rb=Ua<<1|0>>>31;Ta=((Xa|0)<0|0?-1:0)<<1|Ua>>>31;j:do{if((a[K]|0)==0){Ua=b[za+(Aa*1052|0)+18+(d[Ja+fb|0]<<4)+(gb<<1)>>1]|0;if(!(Ua<<16>>16>-1)){break}$a=Ua<<16>>16;Ua=c[ea>>2]|0;ab=c[Ua+($a<<5)+24>>2]|0;if((ab|0)==0){break}db=a[Ua+($a<<5)|0]|0;Za=db&255;bb=c[Pa>>2]|0;gHb(bb<<1|0>>>31,0<<1|bb>>>31,c[1199552+(Za<<1<<2)>>2]|0,0)|0;bb=F;lb=c[Ua+($a<<5)+8>>2]|0;ub=c[Ua+($a<<5)+28>>2]|0;do{if(!((Va|0)!=0|Ya)){if((Za&1|0)!=0){break}if((db<<24>>24|0)==2){if((bb|0)==0){break j}$a=32-ub|0;Ua=c[I>>2]|0;eb=c[z>>2]|0;sb=0;tb=c[G>>2]|0;while(1){zb=eb+(tb>>>3)|0;Ob=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((tb&7)>>>0)<<$a>>>($a>>>0);zb=b[lb+(Ob<<2)>>1]|0;vb=b[lb+(Ob<<2)+2>>1]|0;Ob=vb<<16>>16;do{if(vb<<16>>16<0){_b=tb+ub|0;$b=Ua>>>0>_b>>>0?_b:Ua;_b=eb+($b>>>3)|0;ac=Ob+32|0;bc=((d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)>>>(($b&7)>>>0)<<ac>>>(ac>>>0))+zb|0;ac=b[lb+(bc<<2)>>1]|0;_b=b[lb+(bc<<2)+2>>1]|0;bc=_b<<16>>16;if(!(_b<<16>>16<0)){cc=bc;dc=ac;ec=$b;break}_b=$b-Ob|0;$b=Ua>>>0>_b>>>0?_b:Ua;_b=eb+($b>>>3)|0;fc=bc+32|0;bc=((d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)>>>(($b&7)>>>0)<<fc>>>(fc>>>0))+ac|0;cc=b[lb+(bc<<2)+2>>1]|0;dc=b[lb+(bc<<2)>>1]|0;ec=$b}else{cc=Ob;dc=zb;ec=tb}}while(0);zb=cc+ec|0;tb=Ua>>>0>zb>>>0?zb:Ua;c[G>>2]=tb;zb=dc<<1;Ob=sb+cb|0;vb=qa+(Ob<<2)|0;g[vb>>2]=+g[ab+(zb<<2)>>2]+ +g[vb>>2];vb=qa+(Ob+ca<<2)|0;g[vb>>2]=+g[ab+((zb|1)<<2)>>2]+ +g[vb>>2];sb=sb+1|0;if(!(sb>>>0<bb>>>0)){break j}}}else if((db<<24>>24|0)==4){if((bb|0)==0){break j}sb=32-ub|0;tb=c[I>>2]|0;Ua=c[z>>2]|0;eb=cb;$a=0;vb=c[G>>2]|0;while(1){zb=Ua+(vb>>>3)|0;Ob=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((vb&7)>>>0)<<sb>>>(sb>>>0);zb=b[lb+(Ob<<2)>>1]|0;$b=b[lb+(Ob<<2)+2>>1]|0;Ob=$b<<16>>16;do{if($b<<16>>16<0){bc=vb+ub|0;ac=tb>>>0>bc>>>0?bc:tb;bc=Ua+(ac>>>3)|0;fc=Ob+32|0;_b=((d[bc]|d[bc+1|0]<<8|d[bc+2|0]<<16|d[bc+3|0]<<24|0)>>>((ac&7)>>>0)<<fc>>>(fc>>>0))+zb|0;fc=b[lb+(_b<<2)>>1]|0;bc=b[lb+(_b<<2)+2>>1]|0;_b=bc<<16>>16;if(!(bc<<16>>16<0)){gc=_b;hc=fc;ic=ac;break}bc=ac-Ob|0;ac=tb>>>0>bc>>>0?bc:tb;bc=Ua+(ac>>>3)|0;jc=_b+32|0;_b=((d[bc]|d[bc+1|0]<<8|d[bc+2|0]<<16|d[bc+3|0]<<24|0)>>>((ac&7)>>>0)<<jc>>>(jc>>>0))+fc|0;gc=b[lb+(_b<<2)+2>>1]|0;hc=b[lb+(_b<<2)>>1]|0;ic=ac}else{gc=Ob;hc=zb;ic=vb}}while(0);zb=gc+ic|0;Ob=tb>>>0>zb>>>0?zb:tb;c[G>>2]=Ob;zb=hc<<2;$b=qa+(eb<<2)|0;g[$b>>2]=+g[ab+(zb<<2)>>2]+ +g[$b>>2];$b=qa+(eb+1<<2)|0;g[$b>>2]=+g[ab+((zb|2)<<2)>>2]+ +g[$b>>2];$b=eb+ca|0;ac=qa+($b<<2)|0;g[ac>>2]=+g[ab+((zb|1)<<2)>>2]+ +g[ac>>2];ac=qa+($b+1<<2)|0;g[ac>>2]=+g[ab+((zb|3)<<2)>>2]+ +g[ac>>2];ac=$a+1|0;if(ac>>>0<bb>>>0){eb=eb+2|0;$a=ac;vb=Ob}else{break j}}}else{if((bb|0)==0){break j}vb=32-ub|0;$a=db<<24>>24==0;eb=c[I>>2]|0;tb=c[z>>2]|0;Ua=cb;sb=0;Ob=c[G>>2]|0;while(1){ac=tb+(Ob>>>3)|0;zb=(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)>>>((Ob&7)>>>0)<<vb>>>(vb>>>0);ac=b[lb+(zb<<2)>>1]|0;$b=b[lb+(zb<<2)+2>>1]|0;zb=$b<<16>>16;do{if($b<<16>>16<0){_b=Ob+ub|0;fc=eb>>>0>_b>>>0?_b:eb;_b=tb+(fc>>>3)|0;jc=zb+32|0;bc=((d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)>>>((fc&7)>>>0)<<jc>>>(jc>>>0))+ac|0;jc=b[lb+(bc<<2)>>1]|0;_b=b[lb+(bc<<2)+2>>1]|0;bc=_b<<16>>16;if(!(_b<<16>>16<0)){kc=bc;lc=jc;mc=fc;break}_b=fc-zb|0;fc=eb>>>0>_b>>>0?_b:eb;_b=tb+(fc>>>3)|0;nc=bc+32|0;bc=((d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)>>>((fc&7)>>>0)<<nc>>>(nc>>>0))+jc|0;kc=b[lb+(bc<<2)+2>>1]|0;lc=b[lb+(bc<<2)>>1]|0;mc=fc}else{kc=zb;lc=ac;mc=Ob}}while(0);ac=kc+mc|0;zb=eb>>>0>ac>>>0?ac:eb;c[G>>2]=zb;ac=ba(lc,Za)|0;if($a){oc=Ua}else{$b=Ua;fc=0;while(1){bc=fc+ac|0;jc=qa+($b<<2)|0;g[jc>>2]=+g[ab+(bc<<2)>>2]+ +g[jc>>2];jc=qa+($b+ca<<2)|0;g[jc>>2]=+g[ab+(bc+1<<2)>>2]+ +g[jc>>2];jc=fc+2|0;bc=$b+1|0;if(jc>>>0<Za>>>0){$b=bc;fc=jc}else{oc=bc;break}}}fc=sb+1|0;if(fc>>>0<bb>>>0){Ua=oc;sb=fc;Ob=zb}else{break j}}}}}while(0);gHb(rb,Ta,c[Qa>>2]|0,0)|0;Ob=F;if((bb|0)==0){break}sb=Xa-(ba(Ob,ua)|0)|0;Ua=32-ub|0;$a=db<<24>>24==0;eb=c[I>>2]|0;tb=c[z>>2]|0;vb=0;fc=Ob;Ob=sb;sb=c[G>>2]|0;while(1){$b=tb+(sb>>>3)|0;ac=(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)>>>((sb&7)>>>0)<<Ua>>>(Ua>>>0);$b=b[lb+(ac<<2)>>1]|0;bc=b[lb+(ac<<2)+2>>1]|0;ac=bc<<16>>16;do{if(bc<<16>>16<0){jc=sb+ub|0;nc=eb>>>0>jc>>>0?jc:eb;jc=tb+(nc>>>3)|0;_b=ac+32|0;pc=((d[jc]|d[jc+1|0]<<8|d[jc+2|0]<<16|d[jc+3|0]<<24|0)>>>((nc&7)>>>0)<<_b>>>(_b>>>0))+$b|0;_b=b[lb+(pc<<2)>>1]|0;jc=b[lb+(pc<<2)+2>>1]|0;pc=jc<<16>>16;if(!(jc<<16>>16<0)){qc=pc;rc=_b;sc=nc;break}jc=nc-ac|0;nc=eb>>>0>jc>>>0?jc:eb;jc=tb+(nc>>>3)|0;tc=pc+32|0;pc=((d[jc]|d[jc+1|0]<<8|d[jc+2|0]<<16|d[jc+3|0]<<24|0)>>>((nc&7)>>>0)<<tc>>>(tc>>>0))+_b|0;qc=b[lb+(pc<<2)+2>>1]|0;rc=b[lb+(pc<<2)>>1]|0;sc=nc}else{qc=ac;rc=$b;sc=sb}}while(0);$b=qc+sc|0;ac=eb>>>0>$b>>>0?$b:eb;c[G>>2]=ac;$b=ba(rc,Za)|0;if($a){uc=fc;vc=Ob}else{bc=0;nc=fc;pc=Ob;while(1){_b=qa+((ba(pc,ca)|0)+nc<<2)|0;g[_b>>2]=+g[ab+(bc+$b<<2)>>2]+ +g[_b>>2];_b=pc+1|0;tc=(_b|0)==(ua|0);jc=(tc&1)+nc|0;wc=tc?0:_b;_b=bc+1|0;if(_b>>>0<Za>>>0){bc=_b;nc=jc;pc=wc}else{uc=jc;vc=wc;break}}}pc=vb+1|0;if(pc>>>0<bb>>>0){vb=pc;fc=uc;Ob=vc;sb=ac}else{break}}}}while(0);Ta=fb+1|0;xc=(c[Pa>>2]|0)+Xa|0;if(!(hb>>>0<Ha>>>0&(Ta|0)<(Fa|0))){break}Xa=xc;fb=Ta;hb=hb+1|0}hb=_a-Fa|0;yc=xc;zc=_a-(hb>>>0<Ra>>>0?Ra:hb)|0}else{yc=Wa;zc=_a}if((zc|0)<(Fa|0)){Wa=yc;_a=zc}else{break}}}gb=gb+1|0;}while(!(gb>>>0>(d[Ga]|0)>>>0))}else{D=221;break d}}}while(0);Aa=oa-ua|0;za=ra+1|0;Ga=a[ia]|0;if((za|0)>=(Ga&255|0)){pa=Aa;break c}gb=qa+((ba(ua,ca)|0)<<2)|0;oa=Aa;na=va;qa=gb;ra=za;sa=Ga;ta=a[E]|0}if((D|0)==60){yDb(c[k>>2]|0,16,2349296,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}else if((D|0)==68){yDb(c[k>>2]|0,16,2304752,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}else if((D|0)==80){yDb(0,0,2286912,(B=i,i=i+24|0,c[B>>2]=2270784,c[B+8>>2]=1912288,c[B+16>>2]=1334,B)|0);i=B;Cd();return 0}else if((D|0)==131){yDb(c[k>>2]|0,16,2304752,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}else if((D|0)==144){yDb(0,0,2286912,(B=i,i=i+24|0,c[B>>2]=2270784,c[B+8>>2]=1912288,c[B+16>>2]=1334,B)|0);i=B;Cd();return 0}else if((D|0)==177){yDb(c[k>>2]|0,16,2304752,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}else if((D|0)==190){yDb(0,0,2286912,(B=i,i=i+24|0,c[B>>2]=2270784,c[B+8>>2]=1912288,c[B+16>>2]=1334,B)|0);i=B;Cd();return 0}else if((D|0)==221){yDb(c[k>>2]|0,16,2329136,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}}}while(0);if((pa|0)!=0){aa=-1094995529;break}ia=b[fa>>1]|0;if(!(ia<<16>>16==0)){ja=$+(V*48|0)+4|0;Y=$+(V*48|0)+8|0;ta=k+24|0;sa=ia&65535;do{sa=sa-1|0;ia=c[x>>2]|0;ra=ia+((ba(d[o+(d[(c[ja>>2]|0)+sa|0]|0)|0]|0,W)|0)>>>1<<2)|0;qa=ia+((ba(d[o+(d[(c[Y>>2]|0)+sa|0]|0)|0]|0,W)|0)>>>1<<2)|0;Xe[c[ta>>2]&4095](ra,qa,ca);}while((sa|0)>0)}sa=s+84+(S<<6)|0;ta=a[E]|0;do{if(ta<<24>>24==0){Ac=((c[s+240+(da<<2)>>2]|0)+W|0)>>>2}else{Y=k+28|0;ja=s+84+(S<<6)+44|0;V=ta&255;do{V=V-1|0;$=(c[x>>2]|0)+((ba(d[o+V|0]|0,W)|0)>>>1<<2)|0;fa=c[p+(V<<2)>>2]|0;cf[c[Y>>2]&1023](fa,fa,$,ca);Xe[c[ja>>2]&4095](sa,$,fa);}while((V|0)>0);V=((c[s+240+(da<<2)>>2]|0)+W|0)>>>2;if((a[E]|0)==0){Ac=V;break}ja=k+240|0;Y=k+304|0;fa=s+248+((da&S)<<2)|0;$=(S|0)==(da|0);qa=k+44|0;ra=W>>>2;ia=ra<<2;na=S>>>0>da>>>0;oa=0;while(1){ea=c[ja>>2]|0;ka=c[v>>2]|0;la=c[x>>2]|0;Ga=(ba(d[o+oa|0]|0,W)|0)>>>1;za=la+(Ga<<2)|0;gb=c[Y>>2]|0;Aa=(ba(ka,oa)|0)>>>2;Fa=gb+(Aa<<2)|0;Ra=c[p+(oa<<2)>>2]|0;Ha=c[fa>>2]|0;do{if($){le[c[qa>>2]&1023](Ra,Fa,za,Ha,ra)}else{if(na){Pa=ea>>>2;le[c[qa>>2]&1023](Ra,Fa,za,Ha,Pa);UGb(Ra+(ea>>>1<<2)|0,la+(Ga+Pa<<2)|0,ka-ea&-4)|0;break}else{Pa=(ka-ea|0)>>>2;UGb(Ra|0,Fa|0,Pa<<2)|0;le[c[qa>>2]&1023](Ra+(Pa<<2)|0,gb+(Aa+Pa<<2)|0,za,Ha,ea>>>2);break}}}while(0);UGb(Fa|0,la+(Ga+ra<<2)|0,ia)|0;ea=oa+1|0;if((ea|0)<(d[E]|0)){oa=ea}else{Ac=V;break}}}}while(0);a[L]=X;aa=Ac}else{yDb(c[k>>2]|0,16,1963712,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529}}while(0);if((aa|0)<1){C=aa;i=l;return C|0}L=k+212|0;if((a[L]|0)==0){a[L]=1;c[j>>2]=0;KCb(t);C=r;i=l;return C|0}else{c[A>>2]=aa;c[j>>2]=1;C=r;i=l;return C|0}}}while(0);yDb(f,16,2000760,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=l;return C|0}function j4a(a){a=a|0;l4a(c[a+60>>2]|0);return 0}function k4a(b){b=b|0;var e=0,f=0;e=c[b+60>>2]|0;b=c[e+304>>2]|0;if((b|0)==0){f=e+297|0;a[f]=-1;return}TGb(b|0,0,ba(c[e+244>>2]&-4,d[e+220|0]|0)|0)|0;f=e+297|0;a[f]=-1;return}function l4a(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;$Db(f+300|0);$Db(f+304|0);g=f+276|0;h=c[g>>2]|0;a:do{if((h|0)!=0){i=f+272|0;if((a[i]|0)==0){break}else{j=0;k=h}while(1){ZDb(c[k+(j*1052|0)+1048>>2]|0);l=j+1|0;if((l|0)>=(d[i]|0)){break a}j=l;k=c[g>>2]|0}}}while(0);$Db(g);$Db(f+292|0);bLa(f+84|0);bLa(f+148|0);g=f+260|0;k=c[g>>2]|0;b:do{if((k|0)!=0){j=f+256|0;if((b[j>>1]|0)==0){break}else{m=0;n=k}while(1){ZDb(c[n+(m<<5)+24>>2]|0);Q_((c[g>>2]|0)+(m<<5)+4|0);h=m+1|0;if((h|0)>=(e[j>>1]|0)){break b}m=h;n=c[g>>2]|0}}}while(0);$Db(g);g=f+268|0;n=c[g>>2]|0;c:do{if((n|0)!=0){m=f+264|0;if((a[m]|0)==0){break}else{o=0;p=n}while(1){if((a[p+(o*356|0)|0]|0)==0){ZDb(c[p+(o*356|0)+16>>2]|0);ZDb(c[(c[g>>2]|0)+(o*356|0)+20>>2]|0);ZDb(c[(c[g>>2]|0)+(o*356|0)+36>>2]|0);ZDb(c[(c[g>>2]|0)+(o*356|0)+40>>2]|0)}else{ZDb(c[p+(o*356|0)+352>>2]|0)}k=o+1|0;if((k|0)>=(d[m]|0)){break c}o=k;p=c[g>>2]|0}}}while(0);$Db(g);g=f+284|0;p=c[g>>2]|0;if((p|0)==0){q=g;$Db(q);return}o=f+280|0;if((a[o]|0)==0){q=g;$Db(q);return}else{r=0;s=p}while(1){ZDb(c[s+(r*48|0)+4>>2]|0);ZDb(c[(c[g>>2]|0)+(r*48|0)+8>>2]|0);ZDb(c[(c[g>>2]|0)+(r*48|0)+12>>2]|0);p=r+1|0;if((p|0)>=(d[o]|0)){break}r=p;s=c[g>>2]|0}q=g;$Db(q);return}function m4a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;f=b+12|0;g=c[f>>2]|0;h=c[b+20>>2]|0;j=c[b+4>>2]|0;k=j+(g>>>3)|0;l=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((g&7)>>>0)&255;k=g+8|0;g=h>>>0>k>>>0?k:h;c[f>>2]=g;do{if((l|0)==118){k=j+(g>>>3)|0;m=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((g&7)>>>0)&255;k=g+8|0;n=h>>>0>k>>>0?k:h;c[f>>2]=n;if((m|0)!=111){break}m=j+(n>>>3)|0;k=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&255;m=n+8|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;if((k|0)!=114){break}k=j+(n>>>3)|0;m=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((n&7)>>>0)&255;k=n+8|0;n=h>>>0>k>>>0?k:h;c[f>>2]=n;if((m|0)!=98){break}m=j+(n>>>3)|0;k=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&255;m=n+8|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;if((k|0)!=105){break}k=j+(n>>>3)|0;m=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((n&7)>>>0)&255;k=n+8|0;n=h>>>0>k>>>0?k:h;c[f>>2]=n;if((m|0)!=115){break}m=j+(n>>>3)|0;k=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&65535;m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=j+(n>>>3)|0;o=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0);m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;c[b+216>>2]=o<<16|k;k=j+(n>>>3)|0;o=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((n&7)>>>0);k=n+8|0;n=h>>>0>k>>>0?k:h;c[f>>2]=n;k=b+220|0;a[k]=o;if((o&255|0)==0){yDb(c[b>>2]|0,16,1998504,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}m=j+(n>>>3)|0;r=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&65535;m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=j+(n>>>3)|0;s=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0);m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=s<<16|r;c[b+224>>2]=m;if((m|0)==0){yDb(c[b>>2]|0,16,1994592,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}m=j+(n>>>3)|0;r=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&65535;m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=j+(n>>>3)|0;s=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0);m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;c[b+228>>2]=s<<16|r;r=j+(n>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((n&7)>>>0)&65535;r=n+16|0;n=h>>>0>r>>>0?r:h;c[f>>2]=n;r=j+(n>>>3)|0;m=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((n&7)>>>0);r=n+16|0;n=h>>>0>r>>>0?r:h;c[f>>2]=n;c[b+232>>2]=m<<16|s;s=j+(n>>>3)|0;m=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((n&7)>>>0)&65535;s=n+16|0;n=h>>>0>s>>>0?s:h;c[f>>2]=n;s=j+(n>>>3)|0;r=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((n&7)>>>0);s=n+16|0;n=h>>>0>s>>>0?s:h;c[f>>2]=n;c[b+236>>2]=r<<16|m;m=j+(n>>>3)|0;r=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&15;m=n+4|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=j+(n>>>3)|0;s=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&15;m=n+4|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=r-6|0;do{if(!(m>>>0>7>>>0)){t=s-6|0;if(t>>>0>7>>>0|s>>>0<r>>>0){break}c[b+240>>2]=1<<r;u=1<<s;v=b+244|0;c[v>>2]=u;c[b+248>>2]=c[1087488+(m<<2)>>2];c[b+252>>2]=c[1087488+(t<<2)>>2];t=d[j+(n>>>3)|0]|0;c[f>>2]=((n|0)<(h|0))+n;if((t&1<<(n&7)|0)==0){yDb(c[b>>2]|0,16,1987752,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}t=b+300|0;c[t>>2]=WDb(ba(u>>>1<<2,o&255)|0)|0;u=cEb(ba(c[v>>2]&-4,d[k]|0)|0)|0;c[b+304>>2]=u;if((c[t>>2]|0)==0|(u|0)==0){q=-12;i=e;return q|0}a[b+297|0]=-1;aLa(b+84|0,r,1,-1.0)|0;aLa(b+148|0,s,1,-1.0)|0;q=0;i=e;return q|0}}while(0);yDb(c[b>>2]|0,16,1991272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}}while(0);yDb(c[b>>2]|0,16,2008792,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}function n4a(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0.0,va=0.0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0;h=i;i=i+64|0;j=h|0;k=f+12|0;l=c[k>>2]|0;m=f+20|0;n=c[m>>2]|0;o=f+4|0;p=c[o>>2]|0;q=p+(l>>>3)|0;r=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((l&7)>>>0)&255;q=l+8|0;l=n>>>0>q>>>0?q:n;c[k>>2]=l;do{if((r|0)==118){q=p+(l>>>3)|0;s=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((l&7)>>>0)&255;q=l+8|0;t=n>>>0>q>>>0?q:n;c[k>>2]=t;if((s|0)!=111){break}s=p+(t>>>3)|0;q=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((t&7)>>>0)&255;s=t+8|0;t=n>>>0>s>>>0?s:n;c[k>>2]=t;if((q|0)!=114){break}q=p+(t>>>3)|0;s=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((t&7)>>>0)&255;q=t+8|0;t=n>>>0>q>>>0?q:n;c[k>>2]=t;if((s|0)!=98){break}s=p+(t>>>3)|0;q=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((t&7)>>>0)&255;s=t+8|0;t=n>>>0>s>>>0?s:n;c[k>>2]=t;if((q|0)!=105){break}q=p+(t>>>3)|0;s=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((t&7)>>>0)&255;q=t+8|0;t=n>>>0>q>>>0?q:n;c[k>>2]=t;if((s|0)!=115){break}s=p+(t>>>3)|0;q=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((t&7)>>>0)&255;s=t+8|0;c[k>>2]=n>>>0>s>>>0?s:n;s=q+1|0;q=f+256|0;b[q>>1]=s;t=f+260|0;c[t>>2]=cEb(s<<5&2097120)|0;s=cEb(65536)|0;u=cEb(262144)|0;v=u;w=WDb(131072)|0;x=w;do{if((c[t>>2]|0)==0|(s|0)==0|(u|0)==0|(w|0)==0){y=-12;z=75}else{A=0;a:while(1){if(!(A>>>0<(e[q>>1]|0)>>>0)){z=74;break}B=c[t>>2]|0;C=c[k>>2]|0;D=c[m>>2]|0;E=c[o>>2]|0;F=E+(C>>>3)|0;G=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((C&7)>>>0)&16777215;F=C+24|0;C=D>>>0>F>>>0?F:D;c[k>>2]=C;if((G|0)!=5653314){z=11;break}G=E+(C>>>3)|0;E=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((C&7)>>>0);G=C+16|0;c[k>>2]=D>>>0>G>>>0?G:D;D=B+(A<<5)|0;a[D]=E;H=E&255;if(H>>>0>16>>>0|(H|0)==0){z=13;break}E=c[k>>2]|0;G=c[m>>2]|0;C=c[o>>2]|0;F=C+(E>>>3)|0;I=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((E&7)>>>0)&16777215;F=E+24|0;E=G>>>0>F>>>0?F:G;c[k>>2]=E;if(I>>>0>65536>>>0){z=15;break}F=d[C+(E>>>3)|0]|0;J=((E|0)<(G|0))+E|0;c[k>>2]=J;K=C+(J>>>3)|0;b:do{if((F&1<<(E&7)|0)==0){L=d[K]|0;M=((J|0)<(G|0))+J|0;c[k>>2]=M;N=(I|0)==0;if((L&1<<(J&7)|0)==0){if(N){O=0;Q=M;break}else{R=0;S=M}while(1){L=C+(S>>>3)|0;T=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((S&7)>>>0)&31;L=S+5|0;U=G>>>0>L>>>0?L:G;c[k>>2]=U;a[s+R|0]=T+1;T=R+1|0;if(T>>>0<I>>>0){R=T;S=U}else{O=I;Q=U;break b}}}if(N){O=0;Q=M;break}else{V=0;W=0;X=M}while(1){U=d[C+(X>>>3)|0]|0;T=((X|0)<(G|0))+X|0;c[k>>2]=T;if((U&1<<(X&7)|0)==0){a[s+V|0]=0;Z=W;_=T}else{U=C+(T>>>3)|0;L=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((T&7)>>>0)&31;U=T+5|0;T=G>>>0>U>>>0?U:G;c[k>>2]=T;a[s+V|0]=L+1;Z=W+1|0;_=T}T=V+1|0;if(T>>>0<I>>>0){V=T;W=Z;X=_}else{O=Z;Q=_;break}}}else{M=K;N=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((J&7)>>>0)&31;M=J+5|0;T=G>>>0>M>>>0?M:G;c[k>>2]=T;M=N+1|0;if((I|0)!=0&M>>>0<33>>>0){$=0;aa=M;ca=T}else{O=I;Q=T;break}while(1){T=I-$|0;M=T<<1;N=M>>>0>65535>>>0;L=N?T>>>15&65535:M;M=N?16:0;if((L&65280|0)==0){da=M;ea=L}else{da=M|8;ea=L>>>8}L=(d[1191992+ea|0]|0)+da|0;M=C+(ca>>>3)|0;N=32-L|0;T=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((ca&7)>>>0)<<N>>>(N>>>0);N=L+ca|0;fa=G>>>0>N>>>0?N:G;c[k>>2]=fa;ga=T+$|0;if($>>>0<ga>>>0){T=aa&255;N=$;do{if(N>>>0<I>>>0){a[s+N|0]=T}N=N+1|0;}while(N>>>0<ga>>>0)}N=aa+1|0;if(ga>>>0<I>>>0&N>>>0<33>>>0){$=ga;aa=N;ca=fa}else{break}}if(ga>>>0>I>>>0){z=35;break a}else{O=I;Q=fa}}}while(0);J=C+(Q>>>3)|0;K=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((Q&7)>>>0);J=Q+4|0;c[k>>2]=G>>>0>J>>>0?J:G;a[B+(A<<5)+1|0]=K&15;J=K&15;if((J|0)==1){K=Zob(I,d[D]|0)|0;E=c[k>>2]|0;F=c[m>>2]|0;N=c[o>>2]|0;T=N+(E>>>3)|0;L=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((E&7)>>>0)&65535;T=E+16|0;E=F>>>0>T>>>0?T:F;c[k>>2]=E;T=N+(E>>>3)|0;N=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((E&7)>>>0);T=E+16|0;c[k>>2]=F>>>0>T>>>0?T:F;F=N<<16|L;ha=+((F&2097151)>>>0>>>0);if((F|0)<0){ia=-0.0-ha}else{ia=ha}ha=+sGb(ia,(N>>>5&1023)-788|0);N=c[k>>2]|0;F=c[m>>2]|0;L=c[o>>2]|0;T=L+(N>>>3)|0;E=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((N&7)>>>0)&65535;T=N+16|0;N=F>>>0>T>>>0?T:F;c[k>>2]=N;T=L+(N>>>3)|0;L=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((N&7)>>>0);T=N+16|0;c[k>>2]=F>>>0>T>>>0?T:F;F=L<<16|E;ja=+((F&2097151)>>>0>>>0);if((F|0)<0){ka=-0.0-ja}else{ka=ja}ja=+sGb(ka,(L>>>5&1023)-788|0);L=c[k>>2]|0;F=c[m>>2]|0;E=c[o>>2]|0;T=E+(L>>>3)|0;N=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((L&7)>>>0)&15;T=L+4|0;L=F>>>0>T>>>0?T:F;c[k>>2]=L;T=N+1|0;M=L&7;U=d[E+(L>>>3)|0]|0;la=((L|0)<(F|0))+L|0;c[k>>2]=la;if((K|0)!=0){L=N^31;N=0;ma=la;do{la=E+(ma>>>3)|0;na=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ma&7)>>>0)<<L>>>(L>>>0);la=T+ma|0;ma=F>>>0>la>>>0?la:F;c[k>>2]=ma;b[x+(N<<1)>>1]=na;N=N+1|0;}while(N>>>0<K>>>0)}if((O|0)==0){oa=0}else{oa=cEb(ba(O<<2,d[D]|0)|0)|0}N=B+(A<<5)+24|0;c[N>>2]=oa;if((I|0)==0){pa=0}else{if((U&1<<M|0)==0){ma=0;F=0;while(1){T=a[D]|0;L=T&255;E=s+ma|0;G=a[E]|0;if(G<<24>>24==0){qa=F}else{if(T<<24>>24==0){ra=G}else{G=ba(L,F)|0;T=c[N>>2]|0;C=0;na=ma;while(1){g[T+(C+G<<2)>>2]=ha+ja*+(e[x+(((na>>>0)%(K>>>0)|0)<<1)>>1]|0)+0.0;la=C+1|0;if(la>>>0<L>>>0){C=la;na=(na>>>0)/(K>>>0)|0}else{break}}ra=a[E]|0}a[s+F|0]=ra;qa=F+1|0}na=ma+1|0;if(na>>>0<I>>>0){ma=na;F=qa}else{pa=qa;break}}}else{F=0;ma=0;while(1){M=a[D]|0;U=M&255;na=s+F|0;C=a[na]|0;if(C<<24>>24==0){sa=ma}else{if(M<<24>>24==0){ta=C}else{C=ba(U,ma)|0;M=c[N>>2]|0;L=0;ua=0.0;G=F;while(1){va=ua+(ha+ja*+(e[x+(((G>>>0)%(K>>>0)|0)<<1)>>1]|0));g[M+(L+C<<2)>>2]=va;T=L+1|0;if(T>>>0<U>>>0){L=T;ua=va;G=(G>>>0)/(K>>>0)|0}else{break}}ta=a[na]|0}a[s+ma|0]=ta;sa=ma+1|0}G=F+1|0;if(G>>>0<I>>>0){F=G;ma=sa}else{pa=sa;break}}}}if((pa|0)==(O|0)){wa=O}else{z=63;break}}else{if(J>>>0>1>>>0){z=65;break}else{wa=I}}if((_ob(s,v,wa)|0)!=0){z=67;break}ma=B+(A<<5)+2|0;a[ma]=0;if((wa|0)==0){xa=0}else{F=0;K=0;while(1){N=a[s+F|0]|0;if((N&255)>>>0<(K&255)>>>0){ya=K}else{a[ma]=N;ya=N}N=F+1|0;if(N>>>0<wa>>>0){F=N;K=ya}else{xa=ya;break}}}K=(xa&255)>>>0>24>>>0?11:8;c[B+(A<<5)+28>>2]=K;a[ma]=(((xa&255)-1+K|0)>>>0)/(K>>>0)|0;za=N_(B+(A<<5)+4|0,K,wa,s,1,1,u,4,4,0,0,0,2)|0;if((za|0)==0){A=A+1|0}else{z=73;break}}if((z|0)==11){yDb(c[f>>2]|0,16,2039040,(Aa=i,i=i+8|0,c[Aa>>2]=A,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==13){yDb(c[f>>2]|0,16,2035984,(Aa=i,i=i+16|0,c[Aa>>2]=A,c[Aa+8>>2]=H,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==15){yDb(c[f>>2]|0,16,2032080,(Aa=i,i=i+16|0,c[Aa>>2]=A,c[Aa+8>>2]=I,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==35){yDb(c[f>>2]|0,16,2028e3,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==63){yDb(c[f>>2]|0,16,2024352,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==65){yDb(c[f>>2]|0,16,2021080,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==67){yDb(c[f>>2]|0,16,2017176,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==73){yDb(c[f>>2]|0,16,2013288,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=za;z=75;break}else if((z|0)==74){ZDb(s);ZDb(u);ZDb(w);break}}}while(0);do{if((z|0)==75){ZDb(s);ZDb(u);ZDb(w);if((y|0)==0){break}yDb(c[f>>2]|0,16,2241064,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=y;i=h;return Ba|0}}while(0);w=c[k>>2]|0;u=c[m>>2]|0;s=c[o>>2]|0;v=s+(w>>>3)|0;x=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((w&7)>>>0)&63;v=w+6|0;w=u>>>0>v>>>0?v:u;c[k>>2]=w;v=x+1|0;x=0;K=w;while(1){w=s+(K>>>3)|0;Ca=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;Da=K&7;if(!(x>>>0<v>>>0)){break}w=K+16|0;F=u>>>0>w>>>0?w:u;c[k>>2]=F;if((Ca&65535<<Da|0)==0){x=x+1|0;K=F}else{z=80;break}}if((z|0)==80){x=f|0;yDb(c[x>>2]|0,16,2043856,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;yDb(c[x>>2]|0,16,2228936,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=-1094995529;i=h;return Ba|0}x=K+6|0;c[k>>2]=u>>>0>x>>>0?x:u;x=(Ca>>>(Da>>>0)&63)+1|0;v=f+264|0;a[v]=x;s=cEb((x&255)*356|0)|0;x=s;F=f+268|0;c[F>>2]=x;c:do{if((s|0)==0){Ea=-12;Fa=f|0}else{d:do{if((a[v]|0)!=0){w=f+244|0;J=f|0;N=0;D=x;e:while(1){G=c[k>>2]|0;L=c[m>>2]|0;U=(c[o>>2]|0)+(G>>>3)|0;C=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((G&7)>>>0);U=G+16|0;c[k>>2]=L>>>0>U>>>0?U:L;a[D+(N*356|0)|0]=C;L=C&255;if((L|0)==0){c[D+(N*356|0)+4>>2]=290;C=c[k>>2]|0;U=c[m>>2]|0;G=(c[o>>2]|0)+(C>>>3)|0;M=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((C&7)>>>0);G=C+8|0;c[k>>2]=U>>>0>G>>>0?G:U;U=M&255;M=D+(N*356|0)+8|0;a[M]=U;if(U<<24>>24==0){z=114;break}U=c[k>>2]|0;G=c[m>>2]|0;C=c[o>>2]|0;E=C+(U>>>3)|0;T=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((U&7)>>>0);E=U+16|0;U=G>>>0>E>>>0?E:G;c[k>>2]=U;E=T&65535;b[D+(N*356|0)+10>>1]=E;if(E<<16>>16==0){z=116;break}E=C+(U>>>3)|0;T=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((U&7)>>>0);E=U+16|0;U=G>>>0>E>>>0?E:G;c[k>>2]=U;E=T&65535;b[D+(N*356|0)+12>>1]=E;if(E<<16>>16==0){z=118;break}E=C+(U>>>3)|0;C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((U&7)>>>0);E=U+6|0;c[k>>2]=G>>>0>E>>>0?E:G;a[D+(N*356|0)+32|0]=C&63;C=c[k>>2]|0;G=c[m>>2]|0;E=(c[o>>2]|0)+(C>>>3)|0;U=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((C&7)>>>0);E=C+8|0;c[k>>2]=G>>>0>E>>>0?E:G;a[D+(N*356|0)+33|0]=U;U=c[k>>2]|0;G=c[m>>2]|0;E=(c[o>>2]|0)+(U>>>3)|0;C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((U&7)>>>0)&15;E=U+4|0;c[k>>2]=G>>>0>E>>>0?E:G;G=C+1|0;C=D+(N*356|0)+34|0;a[C]=G;E=WDb(G&255)|0;G=D+(N*356|0)+36|0;c[G>>2]=E;if((E|0)==0){Ea=-12;Fa=J;break c}if((a[C]|0)==0){Ga=1}else{E=0;U=0;do{T=c[k>>2]|0;la=c[m>>2]|0;Ha=(c[o>>2]|0)+(T>>>3)|0;Ia=(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)>>>((T&7)>>>0);Ja=Ia&255;Ha=T+8|0;c[k>>2]=la>>>0>Ha>>>0?Ha:la;Ka=e[q>>1]|0;if(!(Ja>>>0<Ka>>>0)){z=122;break e}a[(c[G>>2]|0)+U|0]=Ia;Ia=d[(c[t>>2]|0)+(Ja<<5)|0]|0;E=Ia>>>0>E>>>0?Ia:E;U=U+1|0;}while((U|0)<(d[C]|0));Ga=E+1|0}C=c[F>>2]|0;U=C+(N*356|0)+16|0;G=C+(N*356|0)+24|0;na=C+(N*356|0)+10|0;Ia=C+(N*356|0)+12|0;C=0;do{la=(c[f+240+(C<<2)>>2]|0)>>>1;Ha=WDb((la<<2)+4|0)|0;T=Ha;c[U+(C<<2)>>2]=T;if((Ha|0)==0){Ea=-12;Fa=J;break c}if((la|0)!=0){Ha=e[na>>1]|0;ja=+(la|0)*2.0;La=e[Ia>>1]|0;ha=+(Ha|0)*.5;ua=+(La|0)/(ha*9999999747378752.0e-20+(+Y(ha*.0007399999885819852)*13.100000381469727+ +Y(ha*ha*1.8499999754340024e-8)*2.240000009536743));Ma=La-1|0;La=0;do{ha=+(ba(La,Ha)|0)/ja;Na=~~+P(ua*(ha*9999999747378752.0e-20+(+Y(ha*.0007399999885819852)*13.100000381469727+ +Y(ha*ha*1.8499999754340024e-8)*2.240000009536743)));c[T+(La<<2)>>2]=(Ma|0)<(Na|0)?Ma:Na;La=La+1|0;}while((La|0)<(la|0))}c[T+(la<<2)>>2]=-1;c[G+(C<<2)>>2]=la;C=C+1|0;}while((C|0)<2);C=WDb((d[M]|0)+Ga<<2)|0;c[D+(N*356|0)+40>>2]=C;if((C|0)==0){Ea=-12;Fa=J;break c}}else if((L|0)==1){c[D+(N*356|0)+4>>2]=18;C=c[k>>2]|0;G=c[m>>2]|0;Ia=(c[o>>2]|0)+(C>>>3)|0;na=(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)>>>((C&7)>>>0);Ia=C+5|0;c[k>>2]=G>>>0>Ia>>>0?Ia:G;G=na&31;na=D+(N*356|0)+8|0;a[na]=G;if(G<<24>>24==0){Oa=-1}else{G=-1;Ia=0;while(1){C=c[k>>2]|0;U=c[m>>2]|0;E=(c[o>>2]|0)+(C>>>3)|0;La=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((C&7)>>>0);E=C+4|0;c[k>>2]=U>>>0>E>>>0?E:U;a[D+(N*356|0)+9+Ia|0]=La&15;U=La&15;La=(U|0)>(G|0)?U:G;U=Ia+1|0;if((U|0)<(d[na]|0)){G=La;Ia=U}else{Oa=La;break}}}Ia=c[k>>2]|0;G=c[m>>2]|0;L=(c[o>>2]|0)+(Ia>>>3)|0;M=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((Ia&7)>>>0);if((Oa|0)<0){Pa=Ia;Qa=G;Ra=M}else{L=0;La=Ia;Ia=G;G=M;while(1){M=La+3|0;c[k>>2]=Ia>>>0>M>>>0?M:Ia;a[D+(N*356|0)+41+L|0]=(G&7)+1;M=c[k>>2]|0;U=c[m>>2]|0;E=(c[o>>2]|0)+(M>>>3)|0;C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((M&7)>>>0);E=M+2|0;c[k>>2]=U>>>0>E>>>0?E:U;U=C&3;C=D+(N*356|0)+57+L|0;a[C]=U;if(U<<24>>24==0){Sa=0}else{U=c[k>>2]|0;E=c[m>>2]|0;M=(c[o>>2]|0)+(U>>>3)|0;Ma=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((U&7)>>>0);M=U+8|0;c[k>>2]=E>>>0>M>>>0?M:E;a[D+(N*356|0)+73+L|0]=Ma;Ta=Ma&255;Ua=e[q>>1]|0;if(!(Ta>>>0<Ua>>>0)){z=93;break e}Sa=d[C]|0}Ma=c[k>>2]|0;E=c[m>>2]|0;M=c[o>>2]|0;if((1<<Sa|0)>0){U=0;Ha=Ma;while(1){Na=M+(Ha>>>3)|0;Va=(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)>>>((Ha&7)>>>0)&255;Na=Ha+8|0;Wa=E>>>0>Na>>>0?Na:E;c[k>>2]=Wa;Na=Va+65535&65535;Xa=Na<<16>>16;if(!(Na<<16>>16==-1)){Ya=e[q>>1]|0;if((Xa|0)>=(Ya|0)){z=96;break e}}b[D+(N*356|0)+90+(L<<4)+(U<<1)>>1]=Na;Na=U+1|0;if((Na|0)<(1<<d[C]|0)){U=Na;Ha=Wa}else{Za=Wa;break}}}else{Za=Ma}Ha=L+1|0;U=M+(Za>>>3)|0;C=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((Za&7)>>>0);if((Ha|0)>(Oa|0)){Pa=Za;Qa=E;Ra=C;break}else{L=Ha;La=Za;Ia=E;G=C}}}G=Pa+2|0;c[k>>2]=Qa>>>0>G>>>0?G:Qa;a[D+(N*356|0)+346|0]=(Ra&3)+1;G=D+(N*356|0)+348|0;b[G>>1]=2;Ia=a[na]|0;if(Ia<<24>>24==0){_a=16}else{La=Ia&255;Ia=0;L=2;do{L=(d[(d[D+(N*356|0)+9+Ia|0]|0)+(D+(N*356|0)+41)|0]|0)+L&65535;b[G>>1]=L;Ia=Ia+1|0;}while((Ia|0)<(La|0));_a=(L&65535)<<3}La=cEb(_a)|0;Ia=La;c[D+(N*356|0)+352>>2]=Ia;if((La|0)==0){Ea=-12;Fa=J;break c}C=c[k>>2]|0;Ha=c[m>>2]|0;U=c[o>>2]|0;la=U+(C>>>3)|0;T=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((C&7)>>>0)&15;la=C+4|0;C=Ha>>>0>la>>>0?la:Ha;c[k>>2]=C;$a=1<<T;ab=(c[w>>2]|0)>>>1;if($a>>>0>ab>>>0){z=105;break}b[La>>1]=0;b[La+8>>1]=$a;La=a[na]|0;if(!(La<<24>>24==0)){la=32-T|0;Wa=0;Na=2;Va=La;La=C;while(1){C=D+(N*356|0)+9+Wa|0;if((a[(d[C]|0)+(D+(N*356|0)+41)|0]|0)==0){bb=Na;cb=Va;db=La}else{eb=0;fb=Na;gb=La;do{hb=U+(gb>>>3)|0;ib=(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)>>>((gb&7)>>>0)<<la>>>(la>>>0);hb=gb+T|0;gb=Ha>>>0>hb>>>0?hb:Ha;c[k>>2]=gb;b[Ia+(fb<<3)>>1]=ib;eb=eb+1|0;fb=fb+1|0;}while((eb|0)<(d[(d[C]|0)+(D+(N*356|0)+41)|0]|0));bb=fb;cb=a[na]|0;db=gb}C=Wa+1|0;if((C|0)<(cb&255|0)){Wa=C;Na=bb;Va=cb;La=db}else{break}}}if(($ob(c[J>>2]|0,Ia,e[G>>1]|0)|0)!=0){Ea=-1094995529;Fa=J;break c}}else{z=132;break}La=N+1|0;if((La|0)>=(d[v]|0)){break d}N=La;D=c[F>>2]|0}if((z|0)==93){yDb(c[J>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=Ta,c[Aa+8>>2]=Ua-1,c[Aa+16>>2]=2092824,c[Aa+24>>2]=1912288,c[Aa+32>>2]=543,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==96){yDb(c[J>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=Xa,c[Aa+8>>2]=Ya-1,c[Aa+16>>2]=2087576,c[Aa+24>>2]=1912288,c[Aa+32>>2]=551,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==105){yDb(c[J>>2]|0,16,2082912,(Aa=i,i=i+16|0,c[Aa>>2]=$a,c[Aa+8>>2]=ab,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==114){yDb(c[J>>2]|0,16,2077232,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==116){yDb(c[J>>2]|0,16,2072448,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==118){yDb(c[J>>2]|0,16,2067848,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==122){yDb(c[J>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=Ja,c[Aa+8>>2]=Ka-1,c[Aa+16>>2]=2063432,c[Aa+24>>2]=1912288,c[Aa+32>>2]=630,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==132){yDb(c[J>>2]|0,16,2059768,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}}}while(0);A=c[k>>2]|0;D=c[m>>2]|0;N=(c[o>>2]|0)+(A>>>3)|0;w=(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)>>>((A&7)>>>0)&63;N=A+6|0;c[k>>2]=D>>>0>N>>>0?N:D;D=w+1|0;w=f+272|0;a[w]=D;N=cEb((D&255)*1052|0)|0;D=N;A=f+276|0;c[A>>2]=D;f:do{if((N|0)==0){jb=-12}else{g:do{if((a[w]|0)!=0){B=f+220|0;ma=f+244|0;La=0;Va=D;h:while(1){Na=c[k>>2]|0;Wa=c[m>>2]|0;na=c[o>>2]|0;Ha=na+(Na>>>3)|0;kb=(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)>>>((Na&7)>>>0);Ha=Na+16|0;Na=Wa>>>0>Ha>>>0?Ha:Wa;c[k>>2]=Na;Ha=kb&65535;b[Va+(La*1052|0)>>1]=Ha;T=na+(Na>>>3)|0;la=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((Na&7)>>>0)&16777215;T=Na+24|0;c[k>>2]=Wa>>>0>T>>>0?T:Wa;Wa=Va+(La*1052|0)+4|0;c[Wa>>2]=la;la=c[k>>2]|0;T=c[m>>2]|0;Na=na+(la>>>3)|0;U=(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)>>>((la&7)>>>0)&16777215;Na=la+24|0;c[k>>2]=T>>>0>Na>>>0?Na:T;T=Va+(La*1052|0)+8|0;c[T>>2]=U;U=c[k>>2]|0;Na=c[m>>2]|0;la=na+(U>>>3)|0;L=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((U&7)>>>0)&16777215;la=U+24|0;c[k>>2]=Na>>>0>la>>>0?la:Na;lb=L+1|0;L=Va+(La*1052|0)+12|0;c[L>>2]=lb;mb=c[Wa>>2]|0;nb=c[T>>2]|0;if(mb>>>0>nb>>>0){z=140;break}if(Ha<<16>>16==2){ob=d[B]|0}else{ob=1}Ha=c[ma>>2]|0;if(nb>>>0>(ba(Ha,ob)|0)>>>1>>>0){pb=Ha;break}if((((nb-mb|0)>>>0)/(lb>>>0)|0)>>>0>1048576>>>0){pb=Ha;break}Ha=c[k>>2]|0;Na=c[m>>2]|0;la=na+(Ha>>>3)|0;na=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((Ha&7)>>>0)&63;la=Ha+6|0;c[k>>2]=Na>>>0>la>>>0?la:Na;Na=Va+(La*1052|0)+16|0;a[Na]=na+1;na=c[k>>2]|0;la=c[m>>2]|0;Ha=(c[o>>2]|0)+(na>>>3)|0;U=(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)>>>((na&7)>>>0);Ha=na+8|0;c[k>>2]=la>>>0>Ha>>>0?Ha:la;a[Va+(La*1052|0)+17|0]=U;qb=U&255;rb=e[q>>1]|0;if(!(qb>>>0<rb>>>0)){z=147;break}U=(((c[T>>2]|0)-(c[Wa>>2]|0)|0)>>>0)/((c[L>>2]|0)>>>0)|0;b[Va+(La*1052|0)+1044>>1]=U;L=WDb(ba(d[B]|0,U&65535)|0)|0;c[Va+(La*1052|0)+1048>>2]=L;if((L|0)==0){jb=-12;break f}do{if((a[Na]|0)==0){a[Va+(La*1052|0)+1042|0]=0}else{L=c[m>>2]|0;U=c[o>>2]|0;Wa=0;T=c[k>>2]|0;while(1){la=U+(T>>>3)|0;Ha=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((T&7)>>>0)&7;la=T+3|0;na=L>>>0>la>>>0?la:L;c[k>>2]=na;la=d[U+(na>>>3)|0]|0;C=((na|0)<(L|0))+na|0;c[k>>2]=C;if((1<<(na&7)&la|0)==0){sb=0;tb=C}else{la=U+(C>>>3)|0;na=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((C&7)>>>0);la=C+5|0;C=L>>>0>la>>>0?la:L;c[k>>2]=C;sb=na<<3&248;tb=C}a[j+Wa|0]=sb|Ha;Ha=Wa+1|0;ub=a[Na]|0;if(Ha>>>0<(ub&255)>>>0){Wa=Ha;T=tb}else{break}}T=Va+(La*1052|0)+1042|0;a[T]=0;if(ub<<24>>24==0){break}else{vb=0}do{Wa=d[j+vb|0]|0;L=0;do{do{if((1<<L&Wa|0)==0){b[Va+(La*1052|0)+18+(vb<<4)+(L<<1)>>1]=-1}else{U=c[k>>2]|0;Ha=c[m>>2]|0;C=(c[o>>2]|0)+(U>>>3)|0;na=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((U&7)>>>0);C=U+8|0;c[k>>2]=Ha>>>0>C>>>0?C:Ha;wb=na&255;b[Va+(La*1052|0)+18+(vb<<4)+(L<<1)>>1]=wb;xb=b[q>>1]|0;if(!((wb&65535)>>>0<(xb&65535)>>>0)){z=159;break h}if(!(L>>>0>(d[T]|0)>>>0)){break}a[T]=L}}while(0);L=L+1|0;}while(L>>>0<8>>>0);vb=vb+1|0;}while(vb>>>0<(d[Na]|0)>>>0)}}while(0);Na=La+1|0;if(!(Na>>>0<(d[w]|0)>>>0)){break g}La=Na;Va=c[A>>2]|0}if((z|0)==140){pb=c[ma>>2]|0}else if((z|0)==147){yDb(c[f>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=qb,c[Aa+8>>2]=rb-1,c[Aa+16>>2]=2113384,c[Aa+24>>2]=1912288,c[Aa+32>>2]=714,Aa)|0);i=Aa;jb=-1094995529;break f}else if((z|0)==159){yDb(c[f>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=wb&65535,c[Aa+8>>2]=(xb&65535)-1,c[Aa+16>>2]=2099168,c[Aa+24>>2]=1912288,c[Aa+32>>2]=742,Aa)|0);i=Aa;jb=-1094995529;break f}yDb(c[f>>2]|0,16,2119488,(Aa=i,i=i+40|0,c[Aa>>2]=kb&65535,c[Aa+8>>2]=mb,c[Aa+16>>2]=nb,c[Aa+24>>2]=lb,c[Aa+32>>2]=pb>>>1,Aa)|0);i=Aa;jb=-1094995529;break f}}while(0);J=c[k>>2]|0;Va=c[m>>2]|0;La=(c[o>>2]|0)+(J>>>3)|0;B=(d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0)>>>((J&7)>>>0)&63;La=J+6|0;c[k>>2]=Va>>>0>La>>>0?La:Va;Va=B+1|0;B=f+280|0;a[B]=Va;La=cEb((Va&255)*48|0)|0;Va=La;J=f+284|0;c[J>>2]=Va;i:do{if((La|0)==0){yb=-12}else{j:do{if((a[B]|0)!=0){G=f+220|0;Ia=c[k>>2]|0;Na=c[m>>2]|0;gb=c[o>>2]|0;fb=gb+(Ia>>>3)|0;T=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;fb=Ia+16|0;L=Na>>>0>fb>>>0?fb:Na;c[k>>2]=L;k:do{if((T&65535<<(Ia&7)|0)==0){fb=Va;Wa=0;na=Va;Ha=Na;C=gb;U=L;l:while(1){la=d[C+(U>>>3)|0]|0;eb=((U|0)<(Ha|0))+U|0;c[k>>2]=eb;if((la&1<<(U&7)|0)==0){a[na|0]=1}else{la=C+(eb>>>3)|0;E=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((eb&7)>>>0)&15;la=eb+4|0;c[k>>2]=Ha>>>0>la>>>0?la:Ha;a[na|0]=E+1}E=c[k>>2]|0;la=c[o>>2]|0;eb=d[la+(E>>>3)|0]|0;M=c[m>>2]|0;Ma=((E|0)<(M|0))+E|0;c[k>>2]=Ma;if((eb&1<<(E&7)|0)==0){b[fb+(Wa*48|0)+2>>1]=0;zb=Ma;Ab=M;Bb=la}else{E=la+(Ma>>>3)|0;la=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((Ma&7)>>>0)&255;E=Ma+8|0;c[k>>2]=M>>>0>E>>>0?E:M;M=la+1|0;la=fb+(Wa*48|0)+2|0;b[la>>1]=M;E=fb+(Wa*48|0)+4|0;c[E>>2]=cEb(M&65535)|0;M=cEb(e[la>>1]|0)|0;Ma=fb+(Wa*48|0)+8|0;c[Ma>>2]=M;if((M|0)==0){yb=-12;break i}if((c[E>>2]|0)==0){yb=-12;break i}else{Cb=0}while(1){if(!(Cb>>>0<(e[la>>1]|0)>>>0)){break}M=(d[G]<<1)-2|0;eb=M>>>0>65535>>>0;ib=eb?M>>>16:M;M=eb?16:0;if((ib&65280|0)==0){Db=M;Eb=ib}else{Db=M|8;Eb=ib>>>8}ib=(d[1191992+Eb|0]|0)+Db|0;M=c[k>>2]|0;eb=c[m>>2]|0;hb=(c[o>>2]|0)+(M>>>3)|0;Fb=32-ib|0;Gb=(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)>>>((M&7)>>>0)<<Fb>>>(Fb>>>0);Fb=ib+M|0;c[k>>2]=eb>>>0>Fb>>>0?Fb:eb;a[(c[E>>2]|0)+Cb|0]=Gb;Hb=a[(c[E>>2]|0)+Cb|0]|0;Gb=a[G]|0;Ib=Gb&255;if(!((Hb&255)>>>0<(Gb&255)>>>0)){z=182;break l}Gb=(Ib<<1)-2|0;eb=Gb>>>0>65535>>>0;Fb=eb?Gb>>>16:Gb;Gb=eb?16:0;if((Fb&65280|0)==0){Jb=Gb;Kb=Fb}else{Jb=Gb|8;Kb=Fb>>>8}Fb=(d[1191992+Kb|0]|0)+Jb|0;Gb=c[k>>2]|0;eb=c[m>>2]|0;M=(c[o>>2]|0)+(Gb>>>3)|0;ib=32-Fb|0;hb=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((Gb&7)>>>0)<<ib>>>(ib>>>0);ib=Fb+Gb|0;c[k>>2]=eb>>>0>ib>>>0?ib:eb;a[(c[Ma>>2]|0)+Cb|0]=hb;Lb=a[(c[Ma>>2]|0)+Cb|0]|0;Mb=a[G]|0;if((Lb&255)>>>0<(Mb&255)>>>0){Cb=Cb+1|0}else{z=186;break l}}zb=c[k>>2]|0;Ab=c[m>>2]|0;Bb=c[o>>2]|0}Ma=Bb+(zb>>>3)|0;E=d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0;Ma=zb+2|0;c[k>>2]=Ab>>>0>Ma>>>0?Ma:Ab;if((3<<(zb&7)&E|0)!=0){z=190;break}E=na|0;m:do{if((d[E]|0)>>>0>1>>>0){Ma=cEb(d[G]|0)|0;la=fb+(Wa*48|0)+12|0;c[la>>2]=Ma;if((Ma|0)==0){yb=-12;break i}if((a[G]|0)==0){Nb=0;break}else{Ob=0;Pb=Ma}while(1){Ma=c[k>>2]|0;hb=c[m>>2]|0;eb=(c[o>>2]|0)+(Ma>>>3)|0;ib=(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)>>>((Ma&7)>>>0);eb=Ma+4|0;c[k>>2]=hb>>>0>eb>>>0?eb:hb;a[Pb+Ob|0]=ib&15;ib=Ob+1|0;if(!(ib>>>0<(d[G]|0)>>>0)){Nb=0;break m}Ob=ib;Pb=c[la>>2]|0}}else{Nb=0}}while(0);while(1){if(!(Nb>>>0<(d[E]|0)>>>0)){break}la=c[m>>2]|0;ib=(c[k>>2]|0)+8|0;hb=la>>>0>ib>>>0?ib:la;c[k>>2]=hb;ib=(c[o>>2]|0)+(hb>>>3)|0;eb=(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)>>>((hb&7)>>>0);ib=hb+8|0;c[k>>2]=la>>>0>ib>>>0?ib:la;a[fb+(Wa*48|0)+16+Nb|0]=eb;Qb=eb&255;Rb=d[v]|0;if(!(Qb>>>0<Rb>>>0)){z=198;break l}eb=c[k>>2]|0;la=c[m>>2]|0;ib=(c[o>>2]|0)+(eb>>>3)|0;hb=(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)>>>((eb&7)>>>0);ib=eb+8|0;c[k>>2]=la>>>0>ib>>>0?ib:la;a[fb+(Wa*48|0)+32+Nb|0]=hb;Sb=hb&255;Tb=d[w]|0;if(!(Sb>>>0<Tb>>>0)){z=201;break l}Nb=Nb+1|0}E=Wa+1|0;if(!(E>>>0<(d[B]|0)>>>0)){break j}hb=c[J>>2]|0;la=c[k>>2]|0;ib=c[m>>2]|0;eb=c[o>>2]|0;Ma=eb+(la>>>3)|0;Gb=d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0;Ma=la+16|0;Fb=ib>>>0>Ma>>>0?Ma:ib;c[k>>2]=Fb;if((Gb&65535<<(la&7)|0)==0){fb=hb;Wa=E;na=hb+(E*48|0)|0;Ha=ib;C=eb;U=Fb}else{break k}}if((z|0)==182){yDb(c[f>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=Hb&255,c[Aa+8>>2]=Ib-1,c[Aa+16>>2]=2150584,c[Aa+24>>2]=1912288,c[Aa+32>>2]=795,Aa)|0);i=Aa;yb=-1094995529;break i}else if((z|0)==186){yDb(c[f>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=Lb&255,c[Aa+8>>2]=(Mb&255)-1,c[Aa+16>>2]=2143616,c[Aa+24>>2]=1912288,c[Aa+32>>2]=796,Aa)|0);i=Aa;yb=-1094995529;break i}else if((z|0)==190){yDb(c[f>>2]|0,16,2138184,(Aa=i,i=i+8|0,c[Aa>>2]=Wa,Aa)|0);i=Aa;yb=-1094995529;break i}else if((z|0)==198){yDb(c[f>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=Qb,c[Aa+8>>2]=Rb-1,c[Aa+16>>2]=2131512,c[Aa+24>>2]=1912288,c[Aa+32>>2]=822,Aa)|0);i=Aa;yb=-1094995529;break i}else if((z|0)==201){yDb(c[f>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=Sb,c[Aa+8>>2]=Tb-1,c[Aa+16>>2]=2125056,c[Aa+24>>2]=1912288,c[Aa+32>>2]=823,Aa)|0);i=Aa;yb=-1094995529;break i}}}while(0);yDb(c[f>>2]|0,16,2157344,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;yb=-1094995529;break i}}while(0);ma=c[k>>2]|0;G=c[m>>2]|0;L=(c[o>>2]|0)+(ma>>>3)|0;gb=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((ma&7)>>>0)&63;L=ma+6|0;c[k>>2]=G>>>0>L>>>0?L:G;G=gb+1|0;gb=f+288|0;a[gb]=G;L=cEb(G<<3&2040)|0;G=f+292|0;c[G>>2]=L;do{if((L|0)==0){Ub=-12;Vb=f|0}else{ma=0;while(1){if(!(ma>>>0<(d[gb]|0)>>>0)){break}Na=c[G>>2]|0;Ia=c[k>>2]|0;T=(d[(c[o>>2]|0)+(Ia>>>3)|0]|0)>>>((Ia&7)>>>0);c[k>>2]=((Ia|0)<(c[m>>2]|0))+Ia;a[Na+(ma<<3)|0]=T&1;T=c[k>>2]|0;Ia=c[m>>2]|0;U=c[o>>2]|0;C=U+(T>>>3)|0;Ha=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((T&7)>>>0);C=T+16|0;T=Ia>>>0>C>>>0?C:Ia;c[k>>2]=T;b[Na+(ma<<3)+2>>1]=Ha;Ha=U+(T>>>3)|0;C=(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)>>>((T&7)>>>0);Ha=T+16|0;T=Ia>>>0>Ha>>>0?Ha:Ia;c[k>>2]=T;b[Na+(ma<<3)+4>>1]=C;C=U+(T>>>3)|0;U=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((T&7)>>>0);C=T+8|0;c[k>>2]=Ia>>>0>C>>>0?C:Ia;a[Na+(ma<<3)+6|0]=U;Wb=U&255;Xb=d[B]|0;if(Wb>>>0<Xb>>>0){ma=ma+1|0}else{z=209;break}}if((z|0)==209){ma=f|0;yDb(c[ma>>2]|0,16,917672,(Aa=i,i=i+40|0,c[Aa>>2]=Wb,c[Aa+8>>2]=Xb-1,c[Aa+16>>2]=2164216,c[Aa+24>>2]=1912288,c[Aa+32>>2]=888,Aa)|0);i=Aa;Ub=-1094995529;Vb=ma;break}ma=c[k>>2]|0;U=d[(c[o>>2]|0)+(ma>>>3)|0]|0;c[k>>2]=((ma|0)<(c[m>>2]|0))+ma;if((U&1<<(ma&7)|0)!=0){Ba=0;i=h;return Ba|0}yDb(c[f>>2]|0,16,2174288,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=-1094995529;i=h;return Ba|0}}while(0);yDb(c[Vb>>2]|0,16,2190872,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=Ub;i=h;return Ba|0}}while(0);yDb(c[f>>2]|0,16,2199528,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=yb;i=h;return Ba|0}}while(0);yDb(c[f>>2]|0,16,2207856,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=jb;i=h;return Ba|0}}while(0);yDb(c[Fa>>2]|0,16,2217184,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=Ea;i=h;return Ba|0}}while(0);yDb(c[f>>2]|0,16,2255488,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=-1094995529;i=h;return Ba|0}function o4a(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;j=i;i=i+2072|0;k=j|0;l=j+520|0;m=j+1040|0;n=g+338|0;o=e[132128+((d[n]|0)-1<<1)>>1]|0;p=f+12|0;q=c[p>>2]|0;r=c[f+4>>2]|0;s=d[r+(q>>>3)|0]|0;t=c[f+20>>2]|0;u=((q|0)<(t|0))+q|0;c[p>>2]=u;if((s&1<<(q&7)|0)==0){v=1;i=j;return v|0}q=(o<<1)-2|0;s=q>>>0>65535>>>0;w=s?q>>>16:q;q=s?16:0;if((w&65280|0)==0){x=q;y=w}else{x=q|8;y=w>>>8}w=(d[1191992+y|0]|0)+x|0;x=r+(u>>>3)|0;y=32-w|0;q=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((u&7)>>>0)<<y>>>(y>>>0);x=w+u|0;u=t>>>0>x>>>0?x:t;c[p>>2]=u;x=q&65535;q=k|0;b[q>>1]=x;s=r+(u>>>3)|0;z=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((u&7)>>>0)<<y>>>(y>>>0);y=u+w|0;w=t>>>0>y>>>0?y:t;c[p>>2]=w;y=z&65535;z=k+2|0;b[z>>1]=y;u=g|0;do{if((a[u]|0)==0){A=x;B=y}else{s=f+260|0;C=0;D=2;E=w;a:while(1){F=d[g+1+C|0]|0;G=a[g+33+F|0]|0;H=G&255;I=a[g+49+F|0]|0;J=I&255;K=(1<<J)-1|0;if(I<<24>>24==0){L=0;M=E}else{I=d[g+65+F|0]|0;N=c[s>>2]|0;O=c[N+(I<<5)+8>>2]|0;P=c[N+(I<<5)+28>>2]|0;I=r+(E>>>3)|0;N=32-P|0;Q=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((E&7)>>>0)<<N>>>(N>>>0);N=b[O+(Q<<2)>>1]|0;I=b[O+(Q<<2)+2>>1]|0;Q=I<<16>>16;do{if(I<<16>>16<0){R=E+P|0;S=t>>>0>R>>>0?R:t;R=r+(S>>>3)|0;T=Q+32|0;U=((d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((S&7)>>>0)<<T>>>(T>>>0))+N|0;T=b[O+(U<<2)>>1]|0;R=b[O+(U<<2)+2>>1]|0;U=R<<16>>16;if(!(R<<16>>16<0)){V=U;W=T;X=S;break}R=S-Q|0;S=t>>>0>R>>>0?R:t;R=r+(S>>>3)|0;Y=U+32|0;U=((d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((S&7)>>>0)<<Y>>>(Y>>>0))+T|0;V=b[O+(U<<2)+2>>1]|0;W=b[O+(U<<2)>>1]|0;X=S}else{V=Q;W=N;X=E}}while(0);N=V+X|0;Q=t>>>0>N>>>0?N:t;c[p>>2]=Q;L=W;M=Q}if(G<<24>>24==0){Z=M}else{Q=0;N=L;O=M;while(1){P=b[g+82+(F<<4)+((N&K)<<1)>>1]|0;I=N>>>(J>>>0);if(P<<16>>16>-1){S=P<<16>>16;P=c[s>>2]|0;U=c[P+(S<<5)+8>>2]|0;T=c[P+(S<<5)+28>>2]|0;S=r+(O>>>3)|0;P=32-T|0;Y=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((O&7)>>>0)<<P>>>(P>>>0);P=b[U+(Y<<2)>>1]|0;S=b[U+(Y<<2)+2>>1]|0;Y=S<<16>>16;do{if(S<<16>>16<0){R=O+T|0;_=t>>>0>R>>>0?R:t;R=r+(_>>>3)|0;$=Y+32|0;aa=((d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((_&7)>>>0)<<$>>>($>>>0))+P|0;$=b[U+(aa<<2)>>1]|0;R=b[U+(aa<<2)+2>>1]|0;aa=R<<16>>16;if(!(R<<16>>16<0)){ca=aa;da=$;ea=_;break}R=_-Y|0;_=t>>>0>R>>>0?R:t;R=r+(_>>>3)|0;fa=aa+32|0;aa=((d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((_&7)>>>0)<<fa>>>(fa>>>0))+$|0;ca=b[U+(aa<<2)+2>>1]|0;da=b[U+(aa<<2)>>1]|0;ea=_}else{ca=Y;da=P;ea=O}}while(0);P=ca+ea|0;Y=t>>>0>P>>>0?P:t;c[p>>2]=Y;if((da|0)<0){v=-1094995529;ga=42;break a}b[k+(Q+D<<1)>>1]=da;ha=Y}else{b[k+(Q+D<<1)>>1]=0;ha=O}Y=Q+1|0;if(Y>>>0<H>>>0){Q=Y;N=I;O=ha}else{Z=ha;break}}}O=C+1|0;if(O>>>0<(d[u]|0)>>>0){C=O;D=H+D|0;E=Z}else{ga=21;break}}if((ga|0)==21){A=b[q>>1]|0;B=b[z>>1]|0;break}else if((ga|0)==42){i=j;return v|0}}}while(0);ga=m|0;c[ga>>2]=1;c[m+4>>2]=1;z=l|0;b[z>>1]=A;b[l+2>>1]=B;B=b[g+340>>1]|0;A=B&65535;q=c[g+344>>2]|0;if((B&65535)>>>0>2>>>0){B=2;do{g=e[q+(B<<3)+4>>1]|0;Z=e[q+(B<<3)+6>>1]|0;u=e[l+(g<<1)>>1]|0;ha=(e[l+(Z<<1)>>1]|0)-u|0;da=e[q+(g<<3)>>1]|0;p=(ba((e[q+(B<<3)>>1]|0)-da|0,(ha|0)>-1?ha:-ha|0)|0)/((e[q+(Z<<3)>>1]|0)-da|0)|0;da=((ha|0)<0?-p|0:p)+u|0;u=b[k+(B<<1)>>1]|0;p=u&65535;ha=o-da|0;do{if(u<<16>>16==0){c[m+(B<<2)>>2]=0;if(da>>>0>65535>>>0){ia=-da>>31&65535}else{ia=da&65535}b[l+(B<<1)>>1]=ia}else{c[m+(g<<2)>>2]=1;c[m+(Z<<2)>>2]=1;c[m+(B<<2)>>2]=1;if(!(p>>>0<(ha>>>0<da>>>0?ha:da)<<1>>>0)){if(ha>>>0>da>>>0){b[l+(B<<1)>>1]=u;break}t=da-p+ha|0;ea=t-1|0;if(ea>>>0>65535>>>0){ja=1-t>>31&65535}else{ja=ea&65535}b[l+(B<<1)>>1]=ja;break}if((p&1|0)==0){ea=(p>>>1)+da|0;if(ea>>>0>65535>>>0){ka=-ea>>31&65535}else{ka=ea&65535}b[l+(B<<1)>>1]=ka;break}else{ea=da-((p+1|0)>>>1)|0;if(ea>>>0>65535>>>0){la=-ea>>31&65535}else{la=ea&65535}b[l+(B<<1)>>1]=la;break}}}while(0);B=B+1|0;}while(B>>>0<A>>>0)}apb(q,A,z,ga,d[n]|0,h,e[q+8>>1]|0);v=0;i=j;return v|0}function p4a(f,h,j){f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0.0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0,Z=0.0,$=0.0,aa=0.0,ca=0.0,da=0;k=i;l=c[h+32>>2]|0;m=d[(c[f+292>>2]|0)+(d[f+296|0]<<3)|0]|0;n=h+24|0;o=a[n]|0;if(o<<24>>24==0){p=1;i=k;return p|0}q=o&255;o=f+12|0;r=c[o>>2]|0;s=f+20|0;t=c[s>>2]|0;u=f+4|0;v=c[u>>2]|0;w=v+(r>>>3)|0;x=32-q|0;y=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((r&7)>>>0)<<x>>>(x>>>0);x=r+q|0;q=t>>>0>x>>>0?x:t;c[o>>2]=q;if((y|0)==0){p=1;i=k;return p|0}x=h+26|0;r=d[x]|0;w=r<<1;z=w&256;A=(z>>>5)+(d[1191992+((z|0)==0?w:r>>>7)|0]|0)|0;r=v+(q>>>3)|0;v=32-A|0;w=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((q&7)>>>0)<<v>>>(v>>>0);v=A+q|0;c[o>>2]=t>>>0>v>>>0?v:t;if(w>>>0<(d[x]|0)>>>0){B=w}else{yDb(c[f>>2]|0,16,2054720,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;B=0}w=d[(c[h+28>>2]|0)+B|0]|0;B=c[f+260>>2]|0;f=a[B+(w<<5)|0]|0;x=a[B+(w<<5)+2|0]|0;t=c[B+(w<<5)+8>>2]|0;v=c[B+(w<<5)+24>>2]|0;q=c[B+(w<<5)+28>>2]|0;if((v|0)==0){p=-1094995529;i=k;return p|0}w=h|0;if((a[w]|0)==0){C=0}else{B=32-q|0;A=(x&255)>>>0>1>>>0;r=(x&255)>>>0>2>>>0;x=f&255;z=f<<24>>24==0;f=c[s>>2]|0;s=c[u>>2]|0;u=0;D=0.0;E=c[o>>2]|0;while(1){F=s+(E>>>3)|0;G=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((E&7)>>>0)<<B>>>(B>>>0);F=b[t+(G<<2)>>1]|0;H=b[t+(G<<2)+2>>1]|0;G=H<<16>>16;do{if(A&H<<16>>16<0){I=E+q|0;J=f>>>0>I>>>0?I:f;I=s+(J>>>3)|0;K=G+32|0;L=((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((J&7)>>>0)<<K>>>(K>>>0))+F|0;K=b[t+(L<<2)>>1]|0;I=b[t+(L<<2)+2>>1]|0;L=I<<16>>16;if(!(r&I<<16>>16<0)){M=L;N=K;O=J;break}I=J-G|0;J=f>>>0>I>>>0?I:f;I=s+(J>>>3)|0;P=L+32|0;L=((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((J&7)>>>0)<<P>>>(P>>>0))+K|0;M=b[t+(L<<2)+2>>1]|0;N=b[t+(L<<2)>>1]|0;O=J}else{M=G;N=F;O=E}}while(0);F=M+O|0;G=f>>>0>F>>>0?F:f;c[o>>2]=G;F=ba(N,x)|0;if(z){Q=0}else{H=0;while(1){g[l+(H+u<<2)>>2]=D+ +g[v+(H+F<<2)>>2];J=H+1|0;if(J>>>0<x>>>0){H=J}else{Q=x;break}}}S=+g[l+(u-1+Q<<2)>>2];H=u+x|0;F=a[w]|0;if(H>>>0<(F&255)>>>0){u=H;D=S;E=G}else{C=F;break}}}E=C&255;D=3.141592653589793/+(e[h+4>>1]|0);if(!(C<<24>>24==0)){u=0;do{w=l+(u<<2)|0;g[w>>2]=+T(+g[w>>2])*2.0;u=u+1|0;}while((u|0)<(E|0))}u=c[h+16+(m<<2)>>2]|0;if((u|0)==0){p=0;i=k;return p|0}w=(C&255)>>>0>1>>>0;x=h+25|0;Q=(C&255)>>>0>3>>>0?E&254:2;C=c[h+8+(m<<2)>>2]|0;m=0;h=c[C>>2]|0;while(1){S=+T(D*+(h|0))*2.0;if(w){v=0;U=.5;V=.5;z=1;while(1){W=V*(+g[l+(v<<2)>>2]-S);X=U*(+g[l+(z<<2)>>2]-S);N=v+2|0;o=N|1;if((o|0)<(E|0)){v=N;U=X;V=W;z=o}else{Y=Q;Z=X;$=W;break}}}else{Y=0;Z=.5;$=.5}if((Y|0)==(E|0)){aa=$*(S+2.0)*$;ca=2.0-S}else{V=$*(S- +g[l+(Y<<2)>>2]);aa=V*V;ca=4.0-S*S}z=d[x]|0;V=+((ba(z,y)|0)>>>0>>>0);U=+_((V/(+R(aa+Z*Z*ca)*+((1<<d[n])-1|0))- +(z|0))*.1151292473077774);z=m;do{g[j+(z<<2)>>2]=U;z=z+1|0;da=c[C+(z<<2)>>2]|0;}while((da|0)==(h|0));if(z>>>0<u>>>0){m=z;h=da}else{p=0;break}}i=k;return p|0}function q4a(a){a=a|0;c[a>>2]=1506;return}function r4a(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0.0,aa=0.0,ca=0,da=0,ea=0.0,fa=0.0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0;h=i;i=i+50024|0;j=h|0;k=h+24|0;l=c[f+60>>2]|0;if((c[f+416>>2]|0)!=2){yDb(f,16,2329072,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=h;return n|0}o=l;c[o>>2]=2;p=l+4|0;c[p>>2]=c[f+412>>2];q=l+12|0;c[q>>2]=11;r=l+8|0;c[r>>2]=11;s=l+176|0;c[s>>2]=29;t=WDb(1276)|0;u=t;v=l+180|0;c[v>>2]=u;a:do{if((t|0)==0){w=-12}else{b:do{if((c[s>>2]|0)>0){y=0;z=u;while(1){A=z+(y*44|0)+12|0;c[A>>2]=c[1414840+(y<<5)>>2];B=c[1414848+(y<<5)>>2]|0;C=z+(y*44|0)|0;c[C>>2]=B;D=z+(y*44|0)+16|0;g[D>>2]=+g[1414860+(y<<5)>>2];E=z+(y*44|0)+20|0;g[E>>2]=+g[1414864+(y<<5)>>2];F=z+(y*44|0)+28|0;c[F>>2]=c[1414856+(y<<5)>>2];G=z+(y*44|0)+24|0;c[G>>2]=0;H=z+(y*44|0)+4|0;c[H>>2]=WDb(B)|0;B=WDb(c[C>>2]<<2)|0;I=z+(y*44|0)+8|0;c[I>>2]=B;J=c[H>>2]|0;if((J|0)==0|(B|0)==0){w=-12;break a}B=c[1414844+(y<<5)>>2]|0;UGb(J|0,c[1414852+(y<<5)>>2]|0,B)|0;TGb((c[H>>2]|0)+B|0,0,(c[C>>2]|0)-B|0)|0;B=c[F>>2]|0;do{if((B|0)==0){c[z+(y*44|0)+32>>2]=0}else{J=c[A>>2]|0;K=c[C>>2]|0;if((B|0)==2){L=ba(K,J)|0}else if((B|0)==1){L=Zob(K,J)|0}else{L=0}J=WDb(L<<2)|0;K=J;c[z+(y*44|0)+32>>2]=K;if((J|0)==0){w=-12;break a}if((L|0)<=0){break}J=c[1414868+(y<<5)>>2]|0;M=0;do{c[K+(M<<2)>>2]=d[J+M|0]|0;M=M+1|0;}while((M|0)<(L|0))}}while(0);_ob(c[H>>2]|0,c[I>>2]|0,c[C>>2]|0)|0;B=c[F>>2]|0;do{if((B|0)==0){c[z+(y*44|0)+36>>2]=0;c[z+(y*44|0)+40>>2]=0}else{M=c[A>>2]|0;J=c[C>>2]|0;if((B|0)==2){N=ba(J,M)|0;O=J;P=M}else if((B|0)==1){K=Zob(J,M)|0;N=K;O=c[C>>2]|0;P=c[A>>2]|0}else{N=0;O=J;P=M}M=z+(y*44|0)+36|0;c[M>>2]=WDb(ba(P<<2,O)|0)|0;J=cEb(c[C>>2]<<2)|0;K=J;c[z+(y*44|0)+40>>2]=K;R=c[M>>2]|0;if((R|0)==0|(J|0)==0){w=-12;break a}J=c[C>>2]|0;if((J|0)<=0){break}M=c[A>>2]|0;S=(M|0)>0;T=z+(y*44|0)+32|0;U=0;do{if(S){V=c[T>>2]|0;W=ba(U,M)|0;X=(c[G>>2]|0)==0;Y=K+(U<<2)|0;if((c[F>>2]|0)==1){if(X){Z=0;_=1;while(1){$=+g[D>>2]+0.0+ +(c[V+((((U|0)/(_|0)|0|0)%(N|0)|0)<<2)>>2]|0)*+g[E>>2];g[R+(Z+W<<2)>>2]=$;aa=+g[Y>>2]+$*$;g[Y>>2]=aa;ca=ba(_,N)|0;da=Z+1|0;if((da|0)<(M|0)){Z=da;_=ca}else{ea=aa;break}}}else{aa=0.0;_=0;Z=1;while(1){$=aa+ +g[D>>2]+ +(c[V+((((U|0)/(Z|0)|0|0)%(N|0)|0)<<2)>>2]|0)*+g[E>>2];g[R+(_+W<<2)>>2]=$;fa=+g[Y>>2]+$*$;g[Y>>2]=fa;ca=ba(Z,N)|0;da=_+1|0;if((da|0)<(M|0)){aa=$;_=da;Z=ca}else{ea=fa;break}}}}else{if(X){Z=0;while(1){_=Z+W|0;aa=+g[D>>2]+0.0+ +(c[V+(_<<2)>>2]|0)*+g[E>>2];g[R+(_<<2)>>2]=aa;fa=+g[Y>>2]+aa*aa;g[Y>>2]=fa;_=Z+1|0;if((_|0)<(M|0)){Z=_}else{ea=fa;break}}}else{fa=0.0;Z=0;while(1){X=Z+W|0;aa=fa+ +g[D>>2]+ +(c[V+(X<<2)>>2]|0)*+g[E>>2];g[R+(X<<2)>>2]=aa;$=+g[Y>>2]+aa*aa;g[Y>>2]=$;X=Z+1|0;if((X|0)<(M|0)){fa=aa;Z=X}else{ea=$;break}}}}}else{ea=+g[K+(U<<2)>>2]}g[K+(U<<2)>>2]=ea*.5;U=U+1|0;}while((U|0)<(J|0))}}while(0);E=y+1|0;if((E|0)>=(c[s>>2]|0)){break b}y=E;z=c[v>>2]|0}}}while(0);z=l+184|0;c[z>>2]=1;y=WDb(32)|0;E=l+188|0;c[E>>2]=y;if((y|0)==0){w=-12;break}D=y;c[D>>2]=8;F=WDb(32)|0;G=y+4|0;c[G>>2]=F;if((F|0)==0){w=-12;break}A=y+8|0;c[A>>2]=0;C=c[D>>2]|0;if((C|0)>0){UGb(F|0,1418056,C<<2)|0;F=0;B=0;do{I=c[1418056+(F<<2)>>2]|0;B=(B|0)>(I|0)?B:I;F=F+1|0;}while((F|0)<(C|0));c[A>>2]=B;ga=B+1|0}else{ga=1}c[A>>2]=ga;C=WDb(ga<<4)|0;F=C;I=y+12|0;c[I>>2]=F;if((C|0)==0){w=-12;break}c:do{if((c[A>>2]|0)>0){C=0;H=F;while(1){c[H+(C<<4)>>2]=c[1049184+(C*28|0)>>2];J=c[1049188+(C*28|0)>>2]|0;c[H+(C<<4)+4>>2]=J;c[H+(C<<4)+8>>2]=c[1049192+(C*28|0)>>2];U=1<<J;J=WDb(U<<2)|0;c[H+(C<<4)+12>>2]=J;if((J|0)==0){w=-12;break a}if((U|0)>0){UGb(J|0,1049196+(C*28|0)|0,U<<2)|0}U=C+1|0;if((U|0)>=(c[A>>2]|0)){break c}C=U;H=c[I>>2]|0}}}while(0);c[y+16>>2]=2;A=y+20|0;c[A>>2]=(c[r>>2]|0)-1;F=y+24|0;c[F>>2]=2;B=c[D>>2]|0;if((B|0)>0){H=c[G>>2]|0;C=c[I>>2]|0;U=0;J=2;do{J=(c[C+(c[H+(U<<2)>>2]<<4)>>2]|0)+J|0;c[F>>2]=J;U=U+1|0;}while((U|0)<(B|0));ha=J<<3}else{ha=16}B=WDb(ha)|0;U=B;c[y+28>>2]=U;if((B|0)==0){w=-12;break}b[B>>1]=0;b[B+8>>1]=1<<c[A>>2];B=c[F>>2]|0;if((B|0)>2){H=2;do{b[U+(H<<3)>>1]=c[1417944+(H-2<<2)>>2];H=H+1|0;}while((H|0)<(B|0))}if(($ob(f,U,B)|0)!=0){w=-558323010;break}H=l+192|0;c[H>>2]=1;F=WDb(32)|0;A=l+196|0;c[A>>2]=F;if((F|0)==0){w=-12;break}y=F;c[y>>2]=2;c[F+4>>2]=0;c[F+8>>2]=1600;c[F+12>>2]=32;J=F+16|0;c[J>>2]=10;c[F+20>>2]=15;C=WDb(80)|0;I=F+24|0;c[I>>2]=C;if((C|0)==0){w=-12;break}UGb(C|0,1417864,80)|0;if((c[y>>2]|0)!=2){yDb(0,0,2102384,(m=i,i=i+24|0,c[m>>2]=2046280,c[m+8>>2]=2000680,c[m+16>>2]=201,m)|0);i=m;Cd();return 0}y=cEb(c[J>>2]<<3)|0;C=y;c[F+28>>2]=C;if((y|0)==0){w=-12;break}y=c[J>>2]|0;if((y|0)>0){J=0;d:while(1){F=0;while(1){if((F|0)>=8){break}if((a[(c[I>>2]|0)+(J<<3)+F|0]|0)==-1){F=F+1|0}else{break}}do{if((F|0)!=8){G=a[(c[I>>2]|0)+(J<<3)+F|0]|0;D=c[v>>2]|0;K=c[D+(G*44|0)+12>>2]|0;if((K|0)<=1){ia=67;break d}if((c[D+(G*44|0)+28>>2]|0)==0){ia=71;break d}M=c[D+(G*44|0)>>2]|0;if((M|0)<=0){break}R=D+(G*44|0)+36|0;T=c[D+(G*44|0)+4>>2]|0;G=C+(J<<3)|0;D=C+(J<<3)+4|0;S=0;do{do{if((a[T+S|0]|0)!=0){Z=ba(S,K)|0;Y=c[R>>2]|0;fa=+Q(+(+g[Y+(Z<<2)>>2]));if(fa>+g[G>>2]){g[G>>2]=fa}fa=+Q(+(+g[Y+(Z+1<<2)>>2]));if(!(fa>+g[D>>2])){break}g[D>>2]=fa}}while(0);S=S+1|0;}while((S|0)<(M|0))}}while(0);F=J+1|0;if((F|0)<(y|0)){J=F}else{ja=0;ia=79;break}}if((ia|0)==67){yd(2270760,2000680,214,2359848);return 0}else if((ia|0)==71){yd(2255472,2000680,215,2359848);return 0}else if((ia|0)==79){while(1){ia=0;J=C+(ja<<3)|0;g[J>>2]=+g[J>>2]+.8;J=C+(ja<<3)+4|0;g[J>>2]=+g[J>>2]+.8;J=ja+1|0;if((J|0)<(y|0)){ja=J;ia=79}else{break}}}}y=l+200|0;c[y>>2]=1;C=WDb(28)|0;J=l+204|0;c[J>>2]=C;if((C|0)==0){w=-12;break}I=C;c[I>>2]=1;B=WDb(c[o>>2]<<2)|0;c[C+4>>2]=B;if((B|0)==0){w=-12;break}U=c[o>>2]|0;if((U|0)>0){TGb(B|0,0,U<<2|0)|0}U=C+8|0;c[U>>2]=WDb(c[I>>2]<<2)|0;B=WDb(c[I>>2]<<2)|0;F=B;c[C+12>>2]=F;M=c[U>>2]|0;if((M|0)==0|(B|0)==0){w=-12;break}if((c[I>>2]|0)>0){B=0;do{c[M+(B<<2)>>2]=0;c[F+(B<<2)>>2]=0;B=B+1|0;}while((B|0)<(c[I>>2]|0))}I=(c[o>>2]|0)==2|0;B=C+16|0;c[B>>2]=I;F=C+20|0;c[F>>2]=WDb(I<<2)|0;I=WDb(c[B>>2]<<2)|0;M=I;c[C+24>>2]=M;U=c[F>>2]|0;if((U|0)==0|(I|0)==0){w=-12;break}if((c[B>>2]|0)!=0){c[U>>2]=0;c[M>>2]=1}M=l+208|0;c[M>>2]=1;U=WDb(8)|0;B=l+212|0;c[B>>2]=U;if((U|0)==0){w=-12;break}c[U>>2]=0;c[U+4>>2]=0;c[l+152>>2]=0;U=l+156|0;c[U>>2]=WDb(c[o>>2]<<2<<c[q>>2]>>>1)|0;I=l+160|0;c[I>>2]=WDb(c[o>>2]<<2<<c[q>>2])|0;F=l+164|0;c[F>>2]=WDb(c[o>>2]<<2<<c[q>>2]>>>1)|0;S=WDb(c[o>>2]<<2<<c[q>>2]>>>1)|0;c[l+168>>2]=S;if((c[U>>2]|0)==0){w=-12;break}if((c[I>>2]|0)==0){w=-12;break}if((c[F>>2]|0)==0|(S|0)==0){w=-12;break}S=c[r>>2]|0;c[l+144>>2]=c[1087488+(S-6<<2)>>2];c[l+148>>2]=c[1087488+((c[q>>2]|0)-6<<2)>>2];F=aLa(l+16|0,S,0,1.0)|0;if((F|0)<0){w=F;break}F=aLa(l+80|0,c[q>>2]|0,0,1.0)|0;S=(F|0)<0;if(S){w=S?F:0;break}c[f+72>>2]=0;if((c[f+88>>2]&2|0)==0){g[l+172>>2]=8.0;ka=8.0}else{fa=+(c[f+80>>2]|0)/118.0;g[l+172>>2]=fa;ka=fa}g[l+172>>2]=ka*ka;F=k;TGb(F|0,0,5e4)|0;S=j+8|0;I=j+12|0;U=j+4|0;D=j|0;c[k>>2]=1919907329;c[k+4>>2]=7563618;G=c[o>>2]|0;c[k+8>>2]=G<<24;c[k+12>>2]=c[p>>2]|G>>>8;c[k+16>>2]=0;c[k+20>>2]=0;G=k+24|0;c[G>>2]=0;R=k+28|0;K=c[q>>2]<<4|c[r>>2];a[R]=K;a[R+1|0]=K>>>8|1;K=f+96|0;R=k;T=G+6-k<<3>>3;G=5e4-T|0;Z=R+T|0;Y=(G|0)<0?0:Z;V=Y;x=1919907331;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=Y+4|0;x=7563618;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;V=Y+8|0;x=0;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;a[Y+12|0]=0;a[Y+13|0]=0;a[Y+14|0]=0;a[Y+15|0]=1;Y=G-16|0;G=T+16|0;V=R+G|0;R=(Y|0)<0;W=R?0:V;X=R?0:Y;c[j+20>>2]=X<<3;c[S>>2]=W;c[j+16>>2]=W+X;X=W;x=1919907333;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=(c[s>>2]|0)-1|0;Y=W+4|0;x=X<<24|7563618;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[I>>2]=W+8;W=X>>>8;X=c[s>>2]|0;c[D>>2]=W;c[U>>2]=32;do{if((X|0)>0){Y=0;R=W;_=32;while(1){ca=c[v>>2]|0;da=5653314<<32-_|R;if((_|0)>24){la=_;ma=da}else{na=c[I>>2]|0;oa=na;x=da;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;c[I>>2]=na+4;la=_+32|0;ma=5653314>>>(_>>>0)}na=la-24|0;c[D>>2]=ma;c[U>>2]=na;oa=ca+(Y*44|0)+12|0;da=c[oa>>2]|0;pa=da<<56-la|ma;if((na|0)>16){qa=na;ra=pa}else{sa=c[I>>2]|0;ta=sa;x=pa;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;c[I>>2]=sa+4;qa=la+8|0;ra=da>>>(na>>>0)}na=qa-16|0;c[D>>2]=ra;c[U>>2]=na;da=ca+(Y*44|0)|0;sa=c[da>>2]|0;ta=sa<<48-qa|ra;if((na|0)>24){ua=na;va=ta;wa=sa}else{pa=c[I>>2]|0;xa=pa;x=ta;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[I>>2]=pa+4;ua=qa+16|0;va=sa>>>(na>>>0);wa=c[da>>2]|0}na=ua-24|0;c[D>>2]=va;c[U>>2]=na;sa=ca+(Y*44|0)+4|0;pa=1;while(1){if((pa|0)>=(wa|0)){break}xa=c[sa>>2]|0;if((d[xa+pa|0]|0)>>>0<(d[xa+(pa-1)|0]|0)>>>0){break}else{pa=pa+1|0}}xa=(pa|0)==(wa|0);ta=xa&1;ya=ta<<56-ua|va;if((na|0)>1){za=na;Aa=ya}else{Ba=c[I>>2]|0;Ca=Ba;x=ya;a[Ca]=x;x=x>>8;a[Ca+1|0]=x;x=x>>8;a[Ca+2|0]=x;x=x>>8;a[Ca+3|0]=x;c[I>>2]=Ba+4;za=ua+8|0;Aa=ta>>>(na>>>0)}ta=za-1|0;c[D>>2]=Aa;c[U>>2]=ta;do{if(xa){Ba=d[c[sa>>2]|0]|0;Ca=Ba-1|0;ya=Ca<<33-za|Aa;if((ta|0)>5){Da=ta;Ea=ya}else{Fa=c[I>>2]|0;Ga=Fa;x=ya;a[Ga]=x;x=x>>8;a[Ga+1|0]=x;x=x>>8;a[Ga+2|0]=x;x=x>>8;a[Ga+3|0]=x;c[I>>2]=Fa+4;Da=za+31|0;Ea=Ca>>>(ta>>>0)}Ca=Da-5|0;c[D>>2]=Ea;c[U>>2]=Ca;Fa=c[da>>2]|0;if((Fa|0)>0){Ha=Ba;Ia=0;Ja=Fa;Ka=Ea;La=Ca}else{Ma=Ea;Na=Ca;break}while(1){Ca=0;while(1){Oa=Ca+Ia|0;if((Oa|0)>=(Ja|0)){break}if((d[(c[sa>>2]|0)+Oa|0]|0)==(Ha|0)){Ca=Ca+1|0}else{break}}Fa=Ja-Ia|0;Ba=Fa<<1;Ga=Ba>>>0>65535>>>0;ya=Ga?Fa>>>15&65535:Ba;Ba=Ga?16:0;if((ya&65280|0)==0){Pa=Ba;Qa=ya}else{Pa=Ba|8;Qa=ya>>>8}ya=(d[1191992+Qa|0]|0)+Pa|0;Ba=Ca<<32-La|Ka;if((La|0)>(ya|0)){Ra=La;Sa=Ba;Ta=Ja}else{Ga=c[I>>2]|0;Fa=Ga;x=Ba;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;c[I>>2]=Ga+4;Ra=La+32|0;Sa=(La|0)==32?0:Ca>>>(La>>>0);Ta=c[da>>2]|0}Ua=Ra-ya|0;if((Oa|0)<(Ta|0)){Ha=Ha+1|0;Ia=Oa;Ja=Ta;Ka=Sa;La=Ua}else{break}}c[D>>2]=Sa;c[U>>2]=Ua;Ma=Sa;Na=Ua}else{ya=c[da>>2]|0;Ga=0;while(1){if((Ga|0)>=(ya|0)){break}if((a[(c[sa>>2]|0)+Ga|0]|0)==0){break}else{Ga=Ga+1|0}}Fa=(Ga|0)==(ya|0);Ba=Fa&1^1;Va=Ba<<33-za|Aa;if((ta|0)>1){Wa=ta;Xa=Va;Ya=ya}else{Za=c[I>>2]|0;_a=Za;x=Va;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;c[I>>2]=Za+4;Wa=za+31|0;Xa=Ba>>>(ta>>>0);Ya=c[da>>2]|0}Ba=Wa-1|0;c[D>>2]=Xa;c[U>>2]=Ba;if((Ya|0)>0){$a=0;ab=Xa;bb=Ba}else{Ma=Xa;Na=Ba;break}while(1){if(Fa){cb=ab;db=bb}else{Ba=(a[(c[sa>>2]|0)+$a|0]|0)!=0|0;Za=Ba<<32-bb|ab;if((bb|0)>1){eb=bb;fb=Za}else{_a=c[I>>2]|0;Va=_a;x=Za;a[Va]=x;x=x>>8;a[Va+1|0]=x;x=x>>8;a[Va+2|0]=x;x=x>>8;a[Va+3|0]=x;c[I>>2]=_a+4;eb=bb+32|0;fb=Ba>>>(bb>>>0)}Ba=eb-1|0;c[D>>2]=fb;c[U>>2]=Ba;cb=fb;db=Ba}Ba=a[(c[sa>>2]|0)+$a|0]|0;if(Ba<<24>>24==0){gb=cb;hb=db}else{_a=(Ba&255)-1|0;Ba=_a<<32-db|cb;if((db|0)>5){ib=db;jb=Ba}else{Va=c[I>>2]|0;Za=Va;x=Ba;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;c[I>>2]=Va+4;ib=db+32|0;jb=_a>>>(db>>>0)}_a=ib-5|0;c[D>>2]=jb;c[U>>2]=_a;gb=jb;hb=_a}_a=$a+1|0;if((_a|0)<(c[da>>2]|0)){$a=_a;ab=gb;bb=hb}else{Ma=gb;Na=hb;break}}}}while(0);sa=ca+(Y*44|0)+28|0;ta=c[sa>>2]|0;xa=ta<<32-Na|Ma;if((Na|0)>4){kb=Na;lb=xa;mb=ta}else{na=c[I>>2]|0;pa=na;x=xa;a[pa]=x;x=x>>8;a[pa+1|0]=x;x=x>>8;a[pa+2|0]=x;x=x>>8;a[pa+3|0]=x;c[I>>2]=na+4;kb=Na+32|0;lb=ta>>>(Na>>>0);mb=c[sa>>2]|0}sa=kb-4|0;c[D>>2]=lb;c[U>>2]=sa;do{if((mb|0)==0){nb=lb;ob=sa}else{ta=c[oa>>2]|0;na=c[da>>2]|0;if((mb|0)==1){pb=Zob(na,ta)|0}else if((mb|0)==2){pb=ba(na,ta)|0}else{pb=0}ta=ca+(Y*44|0)+32|0;na=c[ta>>2]|0;pa=c[na>>2]|0;xa=pa<<1;Fa=xa>>>0>65535>>>0;ya=Fa?pa>>>15&65535:xa;xa=Fa?16:0;if((ya&65280|0)==0){qb=xa;rb=ya}else{qb=xa|8;rb=ya>>>8}ya=(d[1191992+rb|0]|0)+qb|0;if((pb|0)>1){xa=1;Fa=ya;while(1){pa=c[na+(xa<<2)>>2]|0;Ga=pa<<1;_a=Ga>>>0>65535>>>0;Va=_a?pa>>>15&65535:Ga;Ga=_a?16:0;if((Va&65280|0)==0){sb=Ga;tb=Va}else{sb=Ga|8;tb=Va>>>8}Va=(d[1191992+tb|0]|0)+sb|0;Ga=(Fa|0)>(Va|0)?Fa:Va;Va=xa+1|0;if((Va|0)<(pb|0)){xa=Va;Fa=Ga}else{ub=Ga;break}}}else{ub=ya}v4a(j,+g[ca+(Y*44|0)+16>>2]);v4a(j,+g[ca+(Y*44|0)+20>>2]);Fa=ub-1|0;xa=c[U>>2]|0;na=Fa<<32-xa|c[D>>2];if((xa|0)>4){vb=xa;wb=na}else{Ga=c[I>>2]|0;Va=Ga;x=na;a[Va]=x;x=x>>8;a[Va+1|0]=x;x=x>>8;a[Va+2|0]=x;x=x>>8;a[Va+3|0]=x;c[I>>2]=Ga+4;vb=xa+32|0;wb=Fa>>>(xa>>>0)}xa=vb-4|0;c[D>>2]=wb;c[U>>2]=xa;Fa=c[ca+(Y*44|0)+24>>2]|0;Ga=Fa<<36-vb|wb;if((xa|0)>1){xb=xa;yb=Ga}else{Va=c[I>>2]|0;na=Va;x=Ga;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[I>>2]=Va+4;xb=vb+28|0;yb=Fa>>>(xa>>>0)}xa=xb-1|0;c[D>>2]=yb;c[U>>2]=xa;if((pb|0)>0){zb=0;Ab=yb;Bb=xa}else{nb=yb;ob=xa;break}while(1){xa=c[(c[ta>>2]|0)+(zb<<2)>>2]|0;Fa=xa<<32-Bb|Ab;if((Bb|0)>(ub|0)){Cb=Bb;Db=Fa}else{Va=c[I>>2]|0;na=Va;x=Fa;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[I>>2]=Va+4;Cb=Bb+32|0;Db=(Bb|0)==32?0:xa>>>(Bb>>>0)}Eb=Cb-ub|0;xa=zb+1|0;if((xa|0)<(pb|0)){zb=xa;Ab=Db;Bb=Eb}else{break}}c[D>>2]=Db;c[U>>2]=Eb;nb=Db;ob=Eb}}while(0);ca=Y+1|0;if((ca|0)<(c[s>>2]|0)){Y=ca;R=nb;_=ob}else{break}}if((ob|0)>6){Fb=ob;Gb=nb}else{_=c[I>>2]|0;R=_;x=nb;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[I>>2]=_+4;Fb=ob+32|0;Gb=0}_=Fb-6|0;c[D>>2]=Gb;c[U>>2]=_;if((_|0)>16){Hb=_;Ib=Gb;break}_=c[I>>2]|0;R=_;x=Gb;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[I>>2]=_+4;Hb=Fb+26|0;Ib=0}else{c[D>>2]=W;c[U>>2]=26;Hb=26;Ib=W}}while(0);W=Hb-16|0;c[D>>2]=Ib;c[U>>2]=W;X=c[z>>2]|0;C=X-1|0;_=C<<48-Hb|Ib;if((W|0)>6){Jb=W;Kb=_;Lb=X}else{X=c[I>>2]|0;R=X;x=_;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[I>>2]=X+4;Jb=Hb+16|0;Kb=C>>>(W>>>0);Lb=c[z>>2]|0}W=Jb-6|0;c[D>>2]=Kb;c[U>>2]=W;if((Lb|0)>0){C=0;X=Kb;R=W;while(1){_=c[E>>2]|0;Y=1<<32-R|X;if((R|0)>16){Mb=R;Nb=Y}else{ca=c[I>>2]|0;da=ca;x=Y;a[da]=x;x=x>>8;a[da+1|0]=x;x=x>>8;a[da+2|0]=x;x=x>>8;a[da+3|0]=x;c[I>>2]=ca+4;Mb=R+32|0;Nb=1>>>(R>>>0)}ca=Mb-16|0;c[D>>2]=Nb;c[U>>2]=ca;da=_+(C<<5)|0;Y=c[da>>2]|0;oa=Y<<48-Mb|Nb;if((ca|0)>5){Ob=ca;Pb=oa;Qb=Y}else{sa=c[I>>2]|0;ta=sa;x=oa;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;c[I>>2]=sa+4;Ob=Mb+16|0;Pb=Y>>>(ca>>>0);Qb=c[da>>2]|0}ca=Ob-5|0;c[D>>2]=Pb;c[U>>2]=ca;if((Qb|0)>0){Y=_+(C<<5)+4|0;sa=0;ta=Pb;oa=ca;ya=Qb;while(1){xa=c[(c[Y>>2]|0)+(sa<<2)>>2]|0;Va=xa<<32-oa|ta;if((oa|0)>4){Rb=oa;Sb=Va;Tb=ya}else{na=c[I>>2]|0;Fa=na;x=Va;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;c[I>>2]=na+4;Rb=oa+32|0;Sb=xa>>>(oa>>>0);Tb=c[da>>2]|0}Ub=Rb-4|0;xa=sa+1|0;if((xa|0)<(Tb|0)){sa=xa;ta=Sb;oa=Ub;ya=Tb}else{break}}c[D>>2]=Sb;c[U>>2]=Ub;Vb=Sb;Wb=Ub}else{Vb=Pb;Wb=ca}ya=_+(C<<5)+8|0;if((c[ya>>2]|0)>0){oa=_+(C<<5)+12|0;ta=0;sa=Vb;da=Wb;while(1){Y=c[oa>>2]|0;xa=(c[Y+(ta<<4)>>2]|0)-1|0;na=xa<<32-da|sa;if((da|0)>3){Xb=da;Yb=na;Zb=Y}else{Y=c[I>>2]|0;Fa=Y;x=na;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;c[I>>2]=Y+4;Xb=da+32|0;Yb=xa>>>(da>>>0);Zb=c[oa>>2]|0}xa=Xb-3|0;c[D>>2]=Yb;c[U>>2]=xa;Y=c[Zb+(ta<<4)+4>>2]|0;Fa=Y<<35-Xb|Yb;if((xa|0)>2){_b=xa;$b=Fa;ac=Zb}else{na=c[I>>2]|0;Va=na;x=Fa;a[Va]=x;x=x>>8;a[Va+1|0]=x;x=x>>8;a[Va+2|0]=x;x=x>>8;a[Va+3|0]=x;c[I>>2]=na+4;_b=Xb+29|0;$b=Y>>>(xa>>>0);ac=c[oa>>2]|0}xa=_b-2|0;c[D>>2]=$b;c[U>>2]=xa;if((c[ac+(ta<<4)+4>>2]|0)==0){bc=$b;cc=xa;dc=ac;ec=0}else{Y=c[ac+(ta<<4)+8>>2]|0;na=Y<<34-_b|$b;if((xa|0)>8){fc=xa;gc=na;hc=ac}else{Va=c[I>>2]|0;Fa=Va;x=na;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;c[I>>2]=Va+4;fc=_b+30|0;gc=Y>>>(xa>>>0);hc=c[oa>>2]|0}xa=fc-8|0;c[D>>2]=gc;c[U>>2]=xa;bc=gc;cc=xa;dc=hc;ec=c[hc+(ta<<4)+4>>2]|0}xa=1<<ec;if((xa|0)>0){Y=0;Va=bc;Fa=cc;na=dc;while(1){Ga=(c[(c[na+(ta<<4)+12>>2]|0)+(Y<<2)>>2]|0)+1|0;_a=Ga<<32-Fa|Va;if((Fa|0)>8){ic=Fa;jc=_a}else{pa=c[I>>2]|0;Za=pa;x=_a;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;c[I>>2]=pa+4;ic=Fa+32|0;jc=Ga>>>(Fa>>>0)}kc=ic-8|0;Ga=Y+1|0;if((Ga|0)>=(xa|0)){break}Y=Ga;Va=jc;Fa=kc;na=c[oa>>2]|0}c[D>>2]=jc;c[U>>2]=kc;lc=jc;mc=kc}else{lc=bc;mc=cc}na=ta+1|0;if((na|0)<(c[ya>>2]|0)){ta=na;sa=lc;da=mc}else{nc=lc;oc=mc;break}}}else{nc=Vb;oc=Wb}da=(c[_+(C<<5)+16>>2]|0)-1|0;sa=da<<32-oc|nc;if((oc|0)>2){pc=oc;qc=sa}else{ta=c[I>>2]|0;ya=ta;x=sa;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[I>>2]=ta+4;pc=oc+32|0;qc=da>>>(oc>>>0)}da=pc-2|0;c[D>>2]=qc;c[U>>2]=da;ta=_+(C<<5)+20|0;ya=c[ta>>2]|0;sa=ya<<34-pc|qc;if((da|0)>4){rc=da;sc=sa}else{oa=c[I>>2]|0;ca=oa;x=sa;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;c[I>>2]=oa+4;rc=pc+30|0;sc=ya>>>(da>>>0)}da=rc-4|0;c[D>>2]=sc;c[U>>2]=da;ya=_+(C<<5)+24|0;oa=c[ya>>2]|0;if((oa|0)>2){ca=_+(C<<5)+28|0;sa=2;na=sc;Fa=da;Va=oa;while(1){oa=c[ta>>2]|0;Y=e[(c[ca>>2]|0)+(sa<<3)>>1]|0;xa=Y<<32-Fa|na;if((Fa|0)>(oa|0)){tc=Fa;uc=xa;vc=Va}else{Ga=c[I>>2]|0;pa=Ga;x=xa;a[pa]=x;x=x>>8;a[pa+1|0]=x;x=x>>8;a[pa+2|0]=x;x=x>>8;a[pa+3|0]=x;c[I>>2]=Ga+4;tc=Fa+32|0;uc=(Fa|0)==32?0:Y>>>(Fa>>>0);vc=c[ya>>2]|0}wc=tc-oa|0;oa=sa+1|0;if((oa|0)<(vc|0)){sa=oa;na=uc;Fa=wc;Va=vc}else{break}}c[D>>2]=uc;c[U>>2]=wc;xc=uc;yc=wc}else{xc=sc;yc=da}Va=C+1|0;if((Va|0)<(c[z>>2]|0)){C=Va;X=xc;R=yc}else{zc=xc;Ac=yc;break}}}else{zc=Kb;Ac=W}R=c[H>>2]|0;X=R-1|0;C=X<<32-Ac|zc;if((Ac|0)>6){Bc=Ac;Cc=C;Dc=R}else{R=c[I>>2]|0;z=R;x=C;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[I>>2]=R+4;Bc=Ac+32|0;Cc=X>>>(Ac>>>0);Dc=c[H>>2]|0}X=Bc-6|0;c[D>>2]=Cc;c[U>>2]=X;if((Dc|0)>0){R=0;z=Cc;C=X;while(1){E=c[A>>2]|0;Va=c[E+(R<<5)>>2]|0;Fa=Va<<32-C|z;if((C|0)>16){Ec=C;Fc=Fa}else{na=c[I>>2]|0;sa=na;x=Fa;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;c[I>>2]=na+4;Ec=C+32|0;Fc=Va>>>(C>>>0)}Va=Ec-16|0;na=c[E+(R<<5)+4>>2]|0;sa=na<<48-Ec|Fc;if((Va|0)>24){Gc=Va;Hc=sa}else{Fa=c[I>>2]|0;ya=Fa;x=sa;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[I>>2]=Fa+4;Gc=Ec+16|0;Hc=na>>>(Va>>>0)}Va=Gc-24|0;na=c[E+(R<<5)+8>>2]|0;Fa=na<<56-Gc|Hc;if((Va|0)>24){Ic=Va;Jc=Fa}else{ya=c[I>>2]|0;sa=ya;x=Fa;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;c[I>>2]=ya+4;Ic=Gc+8|0;Jc=na>>>(Va>>>0)}Va=Ic-24|0;na=(c[E+(R<<5)+12>>2]|0)-1|0;ya=na<<56-Ic|Jc;if((Va|0)>24){Kc=Va;Lc=ya}else{sa=c[I>>2]|0;Fa=sa;x=ya;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;c[I>>2]=sa+4;Kc=Ic+8|0;Lc=na>>>(Va>>>0)}Va=Kc-24|0;na=E+(R<<5)+16|0;sa=(c[na>>2]|0)-1|0;Fa=sa<<56-Kc|Lc;if((Va|0)>6){Mc=Va;Nc=Fa}else{ya=c[I>>2]|0;ca=ya;x=Fa;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;c[I>>2]=ya+4;Mc=Kc+8|0;Nc=sa>>>(Va>>>0)}Va=Mc-6|0;sa=c[E+(R<<5)+20>>2]|0;ya=sa<<38-Mc|Nc;if((Va|0)>8){Oc=Va;Pc=ya}else{ca=c[I>>2]|0;Fa=ca;x=ya;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;c[I>>2]=ca+4;Oc=Mc+26|0;Pc=sa>>>(Va>>>0)}Va=Oc-8|0;do{if((c[na>>2]|0)>0){sa=E+(R<<5)+24|0;ca=0;Fa=Pc;ya=Va;while(1){ta=c[sa>>2]|0;_=((a[ta+(ca<<3)+1|0]|0)!=-1)<<1|(a[ta+(ca<<3)|0]|0)!=-1|((a[ta+(ca<<3)+2|0]|0)!=-1)<<2;oa=((a[ta+(ca<<3)+3|0]|0)!=-1)<<3|_|((a[ta+(ca<<3)+4|0]|0)!=-1)<<4|((a[ta+(ca<<3)+5|0]|0)!=-1)<<5|((a[ta+(ca<<3)+6|0]|0)!=-1)<<6|((a[ta+(ca<<3)+7|0]|0)!=-1)<<7;ta=_<<32-ya|Fa;if((ya|0)>3){Qc=ya;Rc=ta}else{Y=c[I>>2]|0;Ga=Y;x=ta;a[Ga]=x;x=x>>8;a[Ga+1|0]=x;x=x>>8;a[Ga+2|0]=x;x=x>>8;a[Ga+3|0]=x;c[I>>2]=Y+4;Qc=ya+32|0;Rc=_>>>(ya>>>0)}_=Qc-3|0;Y=(oa|0)>7;Ga=Y&1;ta=Ga<<35-Qc|Rc;if((_|0)>1){Sc=_;Tc=ta}else{pa=c[I>>2]|0;xa=pa;x=ta;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[I>>2]=pa+4;Sc=Qc+29|0;Tc=Ga>>>(_>>>0)}_=Sc-1|0;if(Y){Y=oa>>3;oa=Y<<33-Sc|Tc;if((_|0)>5){Uc=_;Vc=oa}else{Ga=c[I>>2]|0;pa=Ga;x=oa;a[pa]=x;x=x>>8;a[pa+1|0]=x;x=x>>8;a[pa+2|0]=x;x=x>>8;a[pa+3|0]=x;c[I>>2]=Ga+4;Uc=Sc+31|0;Vc=Y>>>(_>>>0)}Wc=Vc;Xc=Uc-5|0}else{Wc=Tc;Xc=_}_=ca+1|0;Yc=c[na>>2]|0;if((_|0)<(Yc|0)){ca=_;Fa=Wc;ya=Xc}else{break}}if((Yc|0)>0){Zc=0;_c=Wc;$c=Xc;ad=Wc;bd=Xc}else{cd=Wc;dd=Xc;break}while(1){ya=0;Fa=_c;ca=$c;_=ad;Y=bd;while(1){Ga=a[(c[sa>>2]|0)+(Zc<<3)+ya|0]|0;if(Ga<<24>>24==-1){ed=Fa;fd=ca;gd=_;hd=Y}else{pa=Ga<<24>>24;Ga=pa<<32-ca|Fa;if((ca|0)>8){id=ca;jd=Ga}else{oa=c[I>>2]|0;xa=oa;x=Ga;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[I>>2]=oa+4;id=ca+32|0;jd=pa>>>(ca>>>0)}pa=id-8|0;ed=jd;fd=pa;gd=jd;hd=pa}pa=ya+1|0;if((pa|0)<8){ya=pa;Fa=ed;ca=fd;_=gd;Y=hd}else{break}}Y=Zc+1|0;if((Y|0)<(c[na>>2]|0)){Zc=Y;_c=ed;$c=fd;ad=gd;bd=hd}else{cd=gd;dd=hd;break}}}else{cd=Pc;dd=Va}}while(0);Va=R+1|0;if((Va|0)<(c[H>>2]|0)){R=Va;z=cd;C=dd}else{break}}c[D>>2]=cd;c[U>>2]=dd;kd=cd;ld=dd}else{kd=Cc;ld=X}C=c[y>>2]|0;z=C-1|0;R=z<<32-ld|kd;if((ld|0)>6){md=ld;nd=R;od=C}else{C=c[I>>2]|0;H=C;x=R;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[I>>2]=C+4;md=ld+32|0;nd=z>>>(ld>>>0);od=c[y>>2]|0}z=md-6|0;c[D>>2]=nd;c[U>>2]=z;if((od|0)>0){C=0;H=nd;R=z;while(1){A=c[J>>2]|0;if((R|0)>16){pd=R;qd=H}else{W=c[I>>2]|0;Va=W;x=H;a[Va]=x;x=x>>8;a[Va+1|0]=x;x=x>>8;a[Va+2|0]=x;x=x>>8;a[Va+3|0]=x;c[I>>2]=W+4;pd=R+32|0;qd=0}W=pd-16|0;Va=A+(C*28|0)|0;na=c[Va>>2]|0;E=(na|0)>1|0;da=E<<48-pd|qd;if((W|0)>1){rd=W;sd=da;td=na}else{na=c[I>>2]|0;sa=na;x=da;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;c[I>>2]=na+4;rd=pd+16|0;sd=E>>>(W>>>0);td=c[Va>>2]|0}W=rd-1|0;if((td|0)>1){E=td-1|0;na=E<<33-rd|sd;if((W|0)>4){ud=W;vd=na}else{sa=c[I>>2]|0;da=sa;x=na;a[da]=x;x=x>>8;a[da+1|0]=x;x=x>>8;a[da+2|0]=x;x=x>>8;a[da+3|0]=x;c[I>>2]=sa+4;ud=rd+31|0;vd=E>>>(W>>>0)}wd=ud-4|0;xd=vd}else{wd=W;xd=sd}W=A+(C*28|0)+16|0;E=c[W>>2]|0;sa=(E|0)!=0|0;da=sa<<32-wd|xd;if((wd|0)>1){zd=wd;Ad=da;Bd=E}else{E=c[I>>2]|0;na=E;x=da;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[I>>2]=E+4;zd=wd+32|0;Ad=sa>>>(wd>>>0);Bd=c[W>>2]|0}sa=zd-1|0;do{if((Bd|0)==0){Dd=sa;Ed=Ad}else{E=Bd-1|0;na=E<<33-zd|Ad;if((sa|0)>8){Fd=sa;Gd=na;Hd=Bd}else{da=c[I>>2]|0;Y=da;x=na;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[I>>2]=da+4;Fd=zd+31|0;Gd=E>>>(sa>>>0);Hd=c[W>>2]|0}E=Fd-8|0;if((Hd|0)<=0){Dd=E;Ed=Gd;break}da=A+(C*28|0)+20|0;Y=A+(C*28|0)+24|0;na=0;_=Gd;ca=E;while(1){E=c[o>>2]|0;Fa=(E<<1)-2|0;ya=Fa>>>0>65535>>>0;pa=ya?Fa>>>16:Fa;Fa=ya?16:0;if((pa&65280|0)==0){Id=Fa;Jd=pa}else{Id=Fa|8;Jd=pa>>>8}pa=(d[1191992+Jd|0]|0)+Id|0;Fa=c[(c[da>>2]|0)+(na<<2)>>2]|0;ya=Fa<<32-ca|_;if((ca|0)>(pa|0)){Kd=ca;Ld=ya;Md=E}else{E=c[I>>2]|0;oa=E;x=ya;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;c[I>>2]=E+4;Kd=ca+32|0;Ld=(ca|0)==32?0:Fa>>>(ca>>>0);Md=c[o>>2]|0}Fa=Kd-pa|0;pa=(Md<<1)-2|0;E=pa>>>0>65535>>>0;oa=E?pa>>>16:pa;pa=E?16:0;if((oa&65280|0)==0){Nd=pa;Od=oa}else{Nd=pa|8;Od=oa>>>8}oa=(d[1191992+Od|0]|0)+Nd|0;pa=c[(c[Y>>2]|0)+(na<<2)>>2]|0;E=pa<<32-Fa|Ld;if((Fa|0)>(oa|0)){Pd=Fa;Qd=E}else{ya=c[I>>2]|0;xa=ya;x=E;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[I>>2]=ya+4;Pd=Fa+32|0;Qd=(Fa|0)==32?0:pa>>>(Fa>>>0)}Fa=Pd-oa|0;oa=na+1|0;if((oa|0)<(c[W>>2]|0)){na=oa;_=Qd;ca=Fa}else{Dd=Fa;Ed=Qd;break}}}}while(0);if((Dd|0)>2){Rd=Dd;Sd=Ed}else{W=c[I>>2]|0;sa=W;x=Ed;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;c[I>>2]=W+4;Rd=Dd+32|0;Sd=0}W=Rd-2|0;sa=c[Va>>2]|0;do{if((sa|0)>1){ca=c[o>>2]|0;if((ca|0)<=0){Td=W;Ud=Sd;ia=280;break}_=A+(C*28|0)+4|0;na=0;Y=Sd;da=W;Fa=ca;while(1){ca=c[(c[_>>2]|0)+(na<<2)>>2]|0;oa=ca<<32-da|Y;if((da|0)>4){Vd=da;Wd=oa;Xd=Fa}else{pa=c[I>>2]|0;ya=pa;x=oa;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[I>>2]=pa+4;Vd=da+32|0;Wd=ca>>>(da>>>0);Xd=c[o>>2]|0}Yd=Vd-4|0;ca=na+1|0;if((ca|0)<(Xd|0)){na=ca;Y=Wd;da=Yd;Fa=Xd}else{break}}Zd=Wd;_d=Yd;$d=c[Va>>2]|0;ia=279}else{Zd=Sd;_d=W;$d=sa;ia=279}}while(0);if((ia|0)==279){ia=0;if(($d|0)>0){Td=_d;Ud=Zd;ia=280}else{ae=Zd;be=_d}}if((ia|0)==280){ia=0;sa=A+(C*28|0)+8|0;W=A+(C*28|0)+12|0;Fa=0;da=Ud;Y=Td;while(1){if((Y|0)>8){ce=Y;de=da}else{na=c[I>>2]|0;_=na;x=da;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;c[I>>2]=na+4;ce=Y+32|0;de=0}na=ce-8|0;_=c[(c[sa>>2]|0)+(Fa<<2)>>2]|0;ca=_<<40-ce|de;if((na|0)>8){ee=na;fe=ca}else{pa=c[I>>2]|0;ya=pa;x=ca;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[I>>2]=pa+4;ee=ce+24|0;fe=_>>>(na>>>0)}na=ee-8|0;_=c[(c[W>>2]|0)+(Fa<<2)>>2]|0;pa=_<<40-ee|fe;if((na|0)>8){ge=na;he=pa}else{ya=c[I>>2]|0;ca=ya;x=pa;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;c[I>>2]=ya+4;ge=ee+24|0;he=_>>>(na>>>0)}na=ge-8|0;_=Fa+1|0;if((_|0)<(c[Va>>2]|0)){Fa=_;da=he;Y=na}else{ae=he;be=na;break}}}Y=C+1|0;if((Y|0)<(c[y>>2]|0)){C=Y;H=ae;R=be}else{break}}c[D>>2]=ae;c[U>>2]=be;ie=ae;je=be}else{ie=nd;je=z}R=c[M>>2]|0;H=R-1|0;C=H<<32-je|ie;if((je|0)>6){ke=je;le=C;me=R}else{R=c[I>>2]|0;y=R;x=C;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[I>>2]=R+4;ke=je+32|0;le=H>>>(je>>>0);me=c[M>>2]|0}H=ke-6|0;c[D>>2]=le;c[U>>2]=H;if((me|0)>0){R=0;y=le;C=H;while(1){J=c[(c[B>>2]|0)+(R<<3)>>2]|0;X=J<<32-C|y;if((C|0)>1){ne=C;oe=X}else{Y=c[I>>2]|0;da=Y;x=X;a[da]=x;x=x>>8;a[da+1|0]=x;x=x>>8;a[da+2|0]=x;x=x>>8;a[da+3|0]=x;c[I>>2]=Y+4;ne=C+32|0;oe=J>>>(C>>>0)}J=ne-1|0;if((J|0)>16){pe=J;qe=oe}else{J=c[I>>2]|0;Y=J;x=oe;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[I>>2]=J+4;pe=ne+31|0;qe=0}J=pe-16|0;if((J|0)>16){re=J;se=qe}else{J=c[I>>2]|0;Y=J;x=qe;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[I>>2]=J+4;re=pe+16|0;se=0}J=re-16|0;Y=c[(c[B>>2]|0)+(R<<3)+4>>2]|0;da=Y<<48-re|se;if((J|0)>8){te=J;ue=da}else{X=c[I>>2]|0;Fa=X;x=da;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;c[I>>2]=X+4;te=re+16|0;ue=Y>>>(J>>>0)}ve=te-8|0;J=R+1|0;if((J|0)<(c[M>>2]|0)){R=J;y=ue;C=ve}else{break}}c[D>>2]=ue;c[U>>2]=ve;we=ue;xe=ve}else{we=le;xe=H}C=1<<32-xe|we;if((xe|0)>1){ye=xe;ze=C}else{y=c[I>>2]|0;R=y;x=C;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[I>>2]=y+4;ye=xe+32|0;ze=1>>>(xe>>>0)}y=ye-1|0;c[D>>2]=ze;c[U>>2]=y;if((y|0)<32){R=c[I>>2]|0;C=ye+7|0;M=(((C|0)>32?ye+6|0:31)-y|0)>>>3;B=M<<3;z=ze&255;J=R;Y=ze;X=y;while(1){a[J]=z;Ae=Y>>>8;y=X+8|0;if((y|0)<32){z=Ae&255;J=J+1|0;Y=Ae;X=y}else{break}}X=R+(M+1)|0;c[I>>2]=X;c[D>>2]=Ae;c[U>>2]=C+B;Be=X}else{Be=c[I>>2]|0}c[U>>2]=32;c[D>>2]=0;X=Be-(c[S>>2]|0)<<3>>3;Y=X+G|0;J=cEb(((Y|0)/255|0)+64+Y|0)|0;c[K>>2]=J;if((J|0)==0){w=-12;break}a[J]=2;Y=(P0a(J+1|0,T)|0)+1|0;z=(P0a(J+Y|0,16)|0)+Y|0;UGb(J+z|0,F|0,T)|0;Y=z+T|0;UGb(J+Y|0,Z|0,16)|0;z=Y+16|0;UGb(J+z|0,V|0,X)|0;Y=J+(z+X)-(c[K>>2]|0)|0;if((Y|0)<0){w=Y;break}c[f+100>>2]=Y;c[f+424>>2]=1<<(c[r>>2]|0)-1;n=0;i=h;return n|0}}while(0);t4a(f)|0;n=w;i=h;return n|0}function s4a(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0.0,za=0.0,Aa=0.0,Ba=0.0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0.0,$b=0.0,ac=0.0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0;l=i;i=i+816|0;m=l|0;n=l+136|0;o=l+272|0;p=l+672|0;q=l+704|0;r=l+712|0;s=l+720|0;t=l+744|0;u=c[f+60>>2]|0;v=(j|0)!=0;if(v){w=c[j+76>>2]|0;y=c[j+64>>2]|0}else{w=0;y=0}z=c[u+144>>2]|0;A=u+8|0;B=c[A>>2]|0;C=B-1|0;D=1<<C;E=+(1<<B|0)*.25;B=u+152|0;G=c[B>>2]|0;if((G|w|0)==0){H=0;i=l;return H|0}I=u;J=c[I>>2]|0;K=(J|0)>0;do{if((G|0)==0){if(!K){L=J;break}M=u+160|0;N=D<<2;O=0;while(1){TGb((c[M>>2]|0)+(O<<C<<1<<2)|0,0,N|0)|0;P=O+1|0;T=c[I>>2]|0;if((P|0)<(T|0)){O=P}else{L=T;break}}}else{if(!K){L=J;break}O=u+160|0;N=u+156|0;M=D<<2;T=0;while(1){P=T<<C;UGb((c[O>>2]|0)+(P<<1<<2)|0,(c[N>>2]|0)+(P<<2)|0,M)|0;P=T+1|0;U=c[I>>2]|0;if((P|0)<(U|0)){T=P}else{L=U;break}}}}while(0);J=(w|0)!=0;K=(L|0)>0;do{if(J){if(!K){V=1;break}G=c[u+160>>2]|0;T=(w|0)>0;M=D-1|0;N=0;while(1){O=(N<<C<<1)+D|0;if(T){U=c[y+(N<<2)>>2]|0;P=0;do{g[G+(O+P<<2)>>2]=+g[U+(P<<2)>>2]/E*+g[z+(M-P<<2)>>2];P=P+1|0;}while((P|0)<(w|0))}P=N+1|0;if((P|0)<(L|0)){N=P}else{W=L;X=16;break}}}else{if(!K){V=0;break}N=u+160|0;M=D<<2;G=0;while(1){TGb((c[N>>2]|0)+((G<<C<<1)+D<<2)|0,0,M|0)|0;T=G+1|0;P=c[I>>2]|0;if((T|0)<(P|0)){G=T}else{W=P;X=16;break}}}}while(0);do{if((X|0)==16){if((W|0)>0){D=u+16|0;K=u+64|0;L=u+168|0;G=u+160|0;M=0;while(1){N=M<<C;Xe[c[K>>2]&4095](D,(c[L>>2]|0)+(N<<2)|0,(c[G>>2]|0)+(N<<1<<2)|0);N=M+1|0;P=c[I>>2]|0;if((N|0)<(P|0)){M=N}else{Y=P;break}}}else{Y=W}if(!J){V=0;break}if((Y|0)<=0){V=1;break}M=c[u+156>>2]|0;G=(w|0)>0;L=0;while(1){D=L<<C;if(G){K=c[y+(L<<2)>>2]|0;P=0;do{g[M+(P+D<<2)>>2]=+g[K+(P<<2)>>2]/E*+g[z+(P<<2)>>2];P=P+1|0;}while((P|0)<(w|0))}P=L+1|0;if((P|0)<(Y|0)){L=P}else{V=1;break}}}}while(0);c[B>>2]=V;V=(c[A>>2]|0)-1|0;A=1<<V;B=r0a(f,h,8192,0)|0;if((B|0)<0){H=B;i=l;return H|0}B=h+28|0;Y=c[B>>2]|0;w=(Y|0)<0;z=w?0:c[h+24>>2]|0;y=w?0:Y;Y=y<<3;w=s+20|0;c[w>>2]=Y;C=s+8|0;c[C>>2]=z;c[s+16>>2]=z+y;y=s+12|0;c[y>>2]=z;J=s+4|0;c[J>>2]=32;W=s|0;c[W>>2]=0;L=c[u+208>>2]|0;M=(L<<1)-2|0;G=M>>>0>65535>>>0;P=G?M>>>16:M;M=G?16:0;if((P&65280|0)==0){Z=M;_=P}else{Z=M|8;_=P>>>8}if((Y|0)<(Z+1+(d[1191992+_|0]|0)|0)){yDb(f,16,2178672,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;H=-22;i=l;return H|0}c[W>>2]=0;c[J>>2]=31;_=(L<<1)-2|0;L=_>>>0>65535>>>0;Z=L?_>>>16:_;_=L?16:0;if((Z&65280|0)==0){aa=_;ca=Z}else{aa=_|8;ca=Z>>>8}Z=(d[1191992+ca|0]|0)+aa|0;if((Z|0)<31){da=31;ea=z}else{aa=z;x=0;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;aa=z+4|0;c[y>>2]=aa;da=63;ea=aa}aa=da-Z|0;c[W>>2]=0;c[J>>2]=aa;Z=c[u+212>>2]|0;da=c[Z+4>>2]|0;z=c[u+204>>2]|0;if((c[Z>>2]|0)==0){fa=aa;ga=ea}else{if((aa|0)>1){ha=aa;ia=ea}else{Z=ea;x=0;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;Z=(c[y>>2]|0)+4|0;c[y>>2]=Z;ha=aa+32|0;ia=Z}Z=ha-1|0;c[W>>2]=0;c[J>>2]=Z;if((Z|0)>1){ja=Z;ka=ia}else{Z=ia;x=0;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;Z=(c[y>>2]|0)+4|0;c[y>>2]=Z;ja=ha+31|0;ka=Z}Z=ja-1|0;c[W>>2]=0;c[J>>2]=Z;fa=Z;ga=ka}ka=c[I>>2]|0;a:do{if((ka|0)>0){Z=z+(da*28|0)+4|0;ja=z+(da*28|0)+8|0;ha=u+188|0;ia=u+168|0;aa=t|0;ea=u+172|0;ca=u+164|0;_=t+2|0;L=m+4|0;Y=m|0;P=u+180|0;M=0;G=fa;K=ga;D=0;b:while(1){N=c[(c[ja>>2]|0)+(c[(c[Z>>2]|0)+(M<<2)>>2]<<2)>>2]|0;T=c[ha>>2]|0;U=M<<V;O=c[ia>>2]|0;la=T+(N<<5)+16|0;ma=c[la>>2]|0;na=255/(ma|0)|0;oa=T+(N<<5)+24|0;pa=c[oa>>2]|0;if((pa|0)>0){qa=c[T+(N<<5)+28>>2]|0;ra=pa-1|0;E=0.0;sa=0;while(1){ta=sa-1|0;ua=b[qa+((e[qa+(((ta|0)>0?ta:0)<<3)+2>>1]|0)<<3)>>1]|0;ta=ua&65535;va=sa+1|0;wa=b[qa+((e[qa+(((va|0)>(ra|0)?ra:va)<<3)+2>>1]|0)<<3)>>1]|0;xa=wa&65535;if((ua&65535)>>>0<(wa&65535)>>>0){wa=ta;ya=0.0;while(1){za=ya+ +Q(+(+g[O+(wa+U<<2)>>2]));ua=wa+1|0;if((ua|0)<(xa|0)){wa=ua;ya=za}else{Aa=za;break}}}else{Aa=0.0}ya=Aa/+(xa-ta|0);g[n+(sa<<2)>>2]=ya;Ba=E+ya;if((va|0)<(pa|0)){E=Ba;sa=va}else{break}}E=Ba/+(pa|0)/+g[ea>>2];sa=0;do{O=e[qa+(sa<<3)+2>>1]|0;ya=+R(E*+g[n+(sa<<2)>>2])*+S(1.25,+(+(e[qa+(O<<3)>>1]|0|0)*.004999999888241291));ra=0;while(1){if((ra|0)>=(na|0)){break}if(+g[1087520+((ba(ra,ma)|0)<<2)>>2]>ya){break}else{ra=ra+1|0}}b[t+(O<<1)>>1]=ra;sa=sa+1|0;}while((sa|0)<(pa|0))}pa=(c[ca>>2]|0)+(U<<2)|0;sa=na+1|0;ma=na<<1;qa=ma>>>0>65535>>>0;va=qa?na>>>15&65535:ma;ma=qa?16:0;if((va&65280|0)==0){Ca=ma;Da=va}else{Ca=ma|8;Da=va>>>8}va=(d[1191992+Da|0]|0)+Ca|0;if(((c[w>>2]|0)-32+G-(K-(c[C>>2]|0)<<3)|0)<(va<<1|1|0)){break}ma=D|1<<32-G;if((G|0)>1){Ea=G;Fa=ma;Ga=K}else{qa=K;x=ma;a[qa]=x;x=x>>8;a[qa+1|0]=x;x=x>>8;a[qa+2|0]=x;x=x>>8;a[qa+3|0]=x;qa=(c[y>>2]|0)+4|0;c[y>>2]=qa;Ea=G+32|0;Fa=1>>>(G>>>0);Ga=qa}qa=Ea-1|0;c[W>>2]=Fa;c[J>>2]=qa;ma=e[aa>>1]|0;ta=ma<<33-Ea|Fa;if((qa|0)>(va|0)){Ha=qa;Ia=ta;Ja=Ga}else{xa=Ga;x=ta;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;xa=(c[y>>2]|0)+4|0;c[y>>2]=xa;Ha=Ea+31|0;Ia=(qa|0)==32?0:ma>>>(qa>>>0);Ja=xa}xa=Ha-va|0;c[W>>2]=Ia;c[J>>2]=xa;qa=e[_>>1]|0;ma=qa<<32-xa|Ia;if((xa|0)>(va|0)){Ka=xa;La=ma;Ma=Ja}else{ta=Ja;x=ma;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;ta=(c[y>>2]|0)+4|0;c[y>>2]=ta;Ka=xa+32|0;La=(xa|0)==32?0:qa>>>(xa>>>0);Ma=ta}ta=Ka-va|0;c[W>>2]=La;c[J>>2]=ta;c[L>>2]=1;c[Y>>2]=1;va=c[oa>>2]|0;if((va|0)>2){xa=c[T+(N<<5)+28>>2]|0;qa=2;do{ma=e[xa+(qa<<3)+4>>1]|0;wa=e[xa+(ma<<3)>>1]|0;ua=e[t+(ma<<1)>>1]|0;Na=e[xa+(qa<<3)+6>>1]|0;Oa=((ba((e[xa+(qa<<3)>>1]|0)-wa|0,(e[t+(Na<<1)>>1]|0)-ua|0)|0)/((e[xa+(Na<<3)>>1]|0)-wa|0)|0)+ua|0;ua=sa-Oa|0;wa=(ua|0)>(Oa|0)?Oa:ua;Pa=e[t+(qa<<1)>>1]|0;do{if((Oa|0)==(Pa|0)){c[m+(qa<<2)>>2]=0}else{Qa=m+(ma<<2)|0;if((c[Qa>>2]|0)==0){c[Qa>>2]=-1}Qa=m+(Na<<2)|0;if((c[Qa>>2]|0)==0){c[Qa>>2]=-1}if((Pa|0)>(Oa|0)){Qa=Pa-Oa|0;if((Qa|0)>(wa|0)){c[m+(qa<<2)>>2]=Pa;break}else{c[m+(qa<<2)>>2]=Qa<<1;break}}else{Qa=Oa-Pa|0;if((Qa|0)>(wa|0)){c[m+(qa<<2)>>2]=ua-1+Qa;break}else{c[m+(qa<<2)>>2]=(Qa<<1)-1;break}}}}while(0);qa=qa+1|0;}while((qa|0)<(va|0))}qa=T+(N<<5)|0;if((c[qa>>2]|0)>0){sa=T+(N<<5)+4|0;xa=T+(N<<5)+12|0;na=2;U=0;ua=ta;wa=Ma;Pa=La;Oa=ta;Na=Ma;ma=La;while(1){ra=c[(c[sa>>2]|0)+(U<<2)>>2]|0;O=c[xa>>2]|0;Qa=O+(ra<<4)|0;Ra=O+(ra<<4)+4|0;Sa=c[Ra>>2]|0;Ta=1<<Sa;if((Sa|0)==0){Ua=0;Va=ua;Wa=wa;Xa=Pa;Ya=Qa|0;Za=Oa;_a=Na;$a=ma}else{ab=c[O+(ra<<4)+8>>2]|0;bb=c[P>>2]|0;cb=Qa|0;Qa=c[cb>>2]|0;if((Qa|0)>0){db=O+(ra<<4)+12|0;eb=0;fb=0;gb=0;while(1){hb=m+(eb+na<<2)|0;ib=0;while(1){if((ib|0)>=(Ta|0)){break}jb=c[(c[db>>2]|0)+(ib<<2)>>2]|0;if((jb|0)==-1){kb=1}else{kb=c[bb+(jb*44|0)>>2]|0}if((c[hb>>2]|0)<(kb|0)){break}else{ib=ib+1|0}}if((ib|0)==(Ta|0)){X=97;break b}hb=ib<<gb|fb;jb=eb+1|0;if((jb|0)<(Qa|0)){eb=jb;fb=hb;gb=gb+Sa|0}else{lb=hb;break}}}else{lb=0}Sa=d[(c[bb+(ab*44|0)+4>>2]|0)+lb|0]|0;if((ua-32+(c[w>>2]|0)-(wa-(c[C>>2]|0)<<3)|0)<(Sa|0)){break b}gb=c[(c[bb+(ab*44|0)+8>>2]|0)+(lb<<2)>>2]|0;fb=gb<<32-ua|Pa;if((ua|0)>(Sa|0)){mb=ua;nb=fb;ob=wa;pb=Na}else{eb=wa;x=fb;a[eb]=x;x=x>>8;a[eb+1|0]=x;x=x>>8;a[eb+2|0]=x;x=x>>8;a[eb+3|0]=x;eb=(c[y>>2]|0)+4|0;c[y>>2]=eb;mb=ua+32|0;nb=(ua|0)==32?0:gb>>>(ua>>>0);ob=eb;pb=eb}eb=mb-Sa|0;c[W>>2]=nb;c[J>>2]=eb;Ua=lb;Va=eb;Wa=ob;Xa=nb;Ya=cb;Za=eb;_a=pb;$a=nb}eb=c[Ya>>2]|0;c:do{if((eb|0)>0){Sa=Ta-1|0;gb=O+(ra<<4)+12|0;fb=1;Qa=Ua;db=na;hb=Va;jb=Wa;qb=Xa;rb=eb;sb=Za;tb=_a;ub=$a;while(1){vb=c[(c[gb>>2]|0)+((Qa&Sa)<<2)>>2]|0;wb=db+1|0;xb=c[m+(db<<2)>>2]|0;yb=Qa>>c[Ra>>2];if((vb|0)==-1){zb=hb;Ab=jb;Bb=qb;Cb=rb;Db=sb;Eb=tb;Fb=ub}else{Gb=(xb|0)==-1?0:xb;xb=c[P>>2]|0;Hb=d[(c[xb+(vb*44|0)+4>>2]|0)+Gb|0]|0;if((hb-32+(c[w>>2]|0)-(jb-(c[C>>2]|0)<<3)|0)<(Hb|0)){break b}Ib=c[(c[xb+(vb*44|0)+8>>2]|0)+(Gb<<2)>>2]|0;Gb=Ib<<32-hb|qb;if((hb|0)>(Hb|0)){Jb=hb;Kb=Gb;Lb=jb;Mb=tb;Nb=rb}else{vb=jb;x=Gb;a[vb]=x;x=x>>8;a[vb+1|0]=x;x=x>>8;a[vb+2|0]=x;x=x>>8;a[vb+3|0]=x;vb=(c[y>>2]|0)+4|0;c[y>>2]=vb;Jb=hb+32|0;Kb=(hb|0)==32?0:Ib>>>(hb>>>0);Lb=vb;Mb=vb;Nb=c[Ya>>2]|0}vb=Jb-Hb|0;c[W>>2]=Kb;c[J>>2]=vb;zb=vb;Ab=Lb;Bb=Kb;Cb=Nb;Db=vb;Eb=Mb;Fb=Kb}if((fb|0)>=(Cb|0)){Ob=wb;Pb=zb;Qb=Ab;Rb=Bb;Sb=Db;Tb=Eb;Ub=Fb;break c}fb=fb+1|0;Qa=yb;db=wb;hb=zb;jb=Ab;qb=Bb;rb=Cb;sb=Db;tb=Eb;ub=Fb}}else{Ob=na;Pb=Va;Qb=Wa;Rb=Xa;Sb=Za;Tb=_a;Ub=$a}}while(0);Ra=U+1|0;if((Ra|0)<(c[qa>>2]|0)){na=Ob;U=Ra;ua=Pb;wa=Qb;Pa=Rb;Oa=Sb;Na=Tb;ma=Ub}else{break}}Vb=c[oa>>2]|0;Wb=Sb;Xb=Tb;Yb=Ub}else{Vb=va;Wb=ta;Xb=Ma;Yb=La}apb(c[T+(N<<5)+28>>2]|0,Vb,aa,Y,c[la>>2]|0,pa,A);ma=M+1|0;Na=c[I>>2]|0;if((ma|0)<(Na|0)){M=ma;G=Wb;K=Xb;D=Yb}else{Zb=Na;break a}}if((X|0)==97){yd(2349248,2000680,821,2359960);return 0}yDb(f,16,2178672,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;H=-22;i=l;return H|0}else{Zb=ka}}while(0);ka=Zb<<V;if((ka|0)>0){Yb=c[u+164>>2]|0;Xb=c[u+168>>2]|0;Wb=0;do{I=Xb+(Wb<<2)|0;g[I>>2]=+g[I>>2]/+g[Yb+(Wb<<2)>>2];Wb=Wb+1|0;}while((Wb|0)<(ka|0))}ka=c[z+(da*28|0)+16>>2]|0;Wb=c[u+168>>2]|0;if((ka|0)>0){Yb=c[z+(da*28|0)+20>>2]|0;Xb=c[z+(da*28|0)+24>>2]|0;I=(A|0)>0;Vb=0;do{La=c[Yb+(Vb<<2)>>2]<<V;Ma=c[Xb+(Vb<<2)>>2]<<V;if(I){Ub=0;do{Tb=Wb+(Ub+Ma<<2)|0;Ba=+g[Tb>>2];Sb=Wb+(Ub+La<<2)|0;Aa=Ba- +g[Sb>>2];g[Tb>>2]=Aa;if(+g[Sb>>2]>0.0){E=-0.0-Aa;g[Tb>>2]=E;_b=E}else{_b=Aa}if(_b<0.0){g[Sb>>2]=Ba}Ub=Ub+1|0;}while((Ub|0)<(A|0))}Vb=Vb+1|0;}while((Vb|0)<(ka|0))}ka=c[(c[z+(da*28|0)+12>>2]|0)+(c[c[z+(da*28|0)+4>>2]>>2]<<2)>>2]|0;da=c[u+196>>2]|0;z=c[da+(ka<<5)+12>>2]|0;Vb=da+(ka<<5)+4|0;I=c[Vb>>2]|0;Xb=((c[da+(ka<<5)+8>>2]|0)-I|0)/(z|0)|0;Yb=da+(ka<<5)|0;Ub=(c[Yb>>2]|0)==2;La=Ub?1:Zb;Ma=da+(ka<<5)+20|0;Sb=u+180|0;Tb=c[(c[Sb>>2]|0)+((c[Ma>>2]|0)*44|0)+12>>2]|0;if(!Ub){yDb(0,0,2102384,($=i,i=i+24|0,c[$>>2]=2046280,c[$+8>>2]=2000680,c[$+16>>2]=881,$)|0);i=$;Cd();return 0}if((Zb|0)!=2){yDb(0,0,2102384,($=i,i=i+24|0,c[$>>2]=1963672,c[$+8>>2]=2000680,c[$+16>>2]=882,$)|0);i=$;Cd();return 0}Zb=(Xb|0)>0;Ub=da+(ka<<5)+16|0;if(Zb){Rb=(c[Ub>>2]|0)-1|0;Qb=(Rb|0)>0;Pb=da+(ka<<5)+28|0;Ob=(z|0)>0;$a=0;do{_a=(ba($a,z)|0)+I|0;Za=_a+z|0;if(Ob){_b=0.0;Ba=0.0;Xa=_a;while(1){_a=(Xa|0)/2|0;Aa=+Q(+(+g[Wb+(_a<<2)>>2]));E=_b>Aa?_b:Aa;Aa=+Q(+(+g[Wb+(_a+A<<2)>>2]));ya=Ba>Aa?Ba:Aa;_a=Xa+2|0;if((_a|0)<(Za|0)){_b=E;Ba=ya;Xa=_a}else{$b=E;ac=ya;break}}}else{$b=0.0;ac=0.0}d:do{if(Qb){Xa=c[Pb>>2]|0;Za=0;while(1){if($b<+g[Xa+(Za<<3)>>2]){if(ac<+g[Xa+(Za<<3)+4>>2]){bc=Za;break d}}_a=Za+1|0;if((_a|0)<(Rb|0)){Za=_a}else{bc=_a;break}}}else{bc=0}}while(0);c[o+($a<<2)>>2]=bc;$a=$a+1|0;}while(($a|0)<(Xb|0))}$a=(La|0)>0;bc=(Tb|0)>0;Rb=da+(ka<<5)+24|0;ka=A<<1;da=(z|0)>0;Pb=p|0;p=$a^1;Qb=0;e:while(1){if(Zb){Ob=(Qb|0)!=0|p;I=0;while(1){if(!Ob){Za=c[C>>2]|0;Xa=(c[w>>2]|0)-32|0;pa=0;do{la=c[Ma>>2]|0;N=c[Sb>>2]|0;if(bc){T=c[Ub>>2]|0;ta=0;va=0;while(1){oa=ba(ta,T)|0;_a=oa+(c[o+(pa*200|0)+(va+I<<2)>>2]|0)|0;oa=va+1|0;if((oa|0)<(Tb|0)){ta=_a;va=oa}else{cc=_a;break}}}else{cc=0}va=c[J>>2]|0;ta=c[y>>2]|0;T=d[(c[N+(la*44|0)+4>>2]|0)+cc|0]|0;if((Xa+va-(ta-Za<<3)|0)<(T|0)){X=178;break e}_a=c[(c[N+(la*44|0)+8>>2]|0)+(cc<<2)>>2]|0;oa=_a<<32-va|c[W>>2];if((va|0)>(T|0)){dc=va;ec=oa}else{Wa=ta;x=oa;a[Wa]=x;x=x>>8;a[Wa+1|0]=x;x=x>>8;a[Wa+2|0]=x;x=x>>8;a[Wa+3|0]=x;c[y>>2]=ta+4;dc=va+32|0;ec=(va|0)==32?0:_a>>>(va>>>0)}c[W>>2]=ec;c[J>>2]=dc-T;pa=pa+1|0;}while((pa|0)<(La|0))}if(bc&(I|0)<(Xb|0)){pa=I;Za=0;while(1){if($a){Xa=ba(pa,z)|0;T=0;do{va=a[(c[Rb>>2]|0)+(c[o+(T*200|0)+(pa<<2)>>2]<<3)+Qb|0]|0;_a=va<<24>>24;ta=c[Sb>>2]|0;Wa=ta+(_a*44|0)|0;oa=c[Vb>>2]|0;Va=(T<<V)+Xa+oa|0;f:do{if(!(va<<24>>24==-1)){Fb=c[Yb>>2]|0;if(!((Fb|0)==0|(Fb|0)==2)){X=158;break e}Eb=ta+(_a*44|0)+12|0;Db=c[Eb>>2]|0;if(((z|0)%(Db|0)|0|0)!=0){X=160;break e}if((Fb|0)==0){if(da){fc=0}else{break}while(1){Fb=Va+fc|0;Cb=u4a(Wa,s,Wb+(Fb<<2)|0)|0;if((Cb|0)==0){X=178;break e}Bb=c[Eb>>2]|0;if((Bb|0)>0){Ab=0;do{zb=Wb+(Ab+Fb<<2)|0;g[zb>>2]=+g[zb>>2]- +g[Cb+(Ab<<2)>>2];Ab=Ab+1|0;}while((Ab|0)<(Bb|0))}fc=Bb+fc|0;if((fc|0)>=(z|0)){break f}}}Ab=oa+Xa|0;if(!da){break}Cb=0;Fb=((Ab|0)%2|0)<<V;zb=(Ab|0)/2|0;Ab=Db;while(1){if((Ab|0)!=0){Kb=Ab;Mb=Fb;Nb=zb;Lb=Pb;while(1){Jb=Kb-1|0;g[Lb>>2]=+g[Wb+(Mb+Nb<<2)>>2];Ya=Mb+A|0;m=(Ya|0)==(ka|0);if((Jb|0)==0){break}else{Kb=Jb;Mb=m?0:Ya;Nb=(m&1)+Nb|0;Lb=Lb+4|0}}}Lb=u4a(Wa,s,Pb)|0;if((Lb|0)==0){X=178;break e}Nb=c[Eb>>2]|0;if((Nb|0)==0){gc=Fb;hc=zb}else{Mb=Fb;Kb=zb;Bb=Nb;m=Lb;while(1){Lb=Bb-1|0;Ya=Wb+(Mb+Kb<<2)|0;g[Ya>>2]=+g[Ya>>2]- +g[m>>2];Ya=Mb+A|0;Jb=(Ya|0)==(ka|0);Ua=Jb?0:Ya;Ya=(Jb&1)+Kb|0;if((Lb|0)==0){gc=Ua;hc=Ya;break}else{Mb=Ua;Kb=Ya;Bb=Lb;m=m+4|0}}}m=Nb+Cb|0;if((m|0)<(z|0)){Cb=m;Fb=gc;zb=hc;Ab=Nb}else{break}}}}while(0);T=T+1|0;}while((T|0)<(La|0))}T=Za+1|0;Xa=pa+1|0;if((T|0)<(Tb|0)&(Xa|0)<(Xb|0)){pa=Xa;Za=T}else{ic=Xa;break}}}else{ic=I}if((ic|0)<(Xb|0)){I=ic}else{break}}}I=Qb+1|0;if((I|0)<8){Qb=I}else{X=179;break}}if((X|0)==158){yd(1935568,2000680,919,2359832);return 0}else if((X|0)==160){yd(1912248,2000680,920,2359832);return 0}else if((X|0)==178){yDb(f,16,2178672,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;H=-22;i=l;return H|0}else if((X|0)==179){X=c[J>>2]|0;if((X|0)<32){$=c[W>>2]|0;Qb=c[y>>2]|0;ic=(((X+8|0)>32?X+7|0:31)-X|0)>>>3;Xb=X+(ic<<3)|0;Tb=ic+1|0;ic=$&255;La=Qb;hc=$;$=X;while(1){a[La]=ic;jc=hc>>>8;X=$+8|0;if((X|0)<32){ic=jc&255;La=La+1|0;hc=jc;$=X}else{break}}$=Qb+Tb|0;c[y>>2]=$;c[W>>2]=jc;c[J>>2]=Xb+8;kc=$}else{kc=c[y>>2]|0}c[J>>2]=32;c[W>>2]=0;c[B>>2]=kc-(c[C>>2]|0)<<3>>3;C=c[f+424>>2]|0;c[q>>2]=1;kc=f+412|0;c[q+4>>2]=c[kc>>2];B=f+104|0;f=KDb(C,(C|0)<0|0?-1:0,q,B)|0;q=h+48|0;c[q>>2]=f;do{if(v){f=j+136|0;C=c[f>>2]|0;W=c[f+4>>2]|0;if((C|0)==0&(W|0)==(-2147483648|0)){f=h+8|0;lc=c[f+4>>2]|0;mc=c[f>>2]|0;break}else{c[r>>2]=1;c[r+4>>2]=c[kc>>2];f=KDb(C,W,r,B)|0;W=F;C=h+8|0;c[C>>2]=f;c[C+4>>2]=W;lc=W;mc=f;break}}else{f=u+216|0;W=c[f>>2]|0;C=c[f+4>>2]|0;f=h+8|0;c[f>>2]=W;c[f+4>>2]=C;lc=C;mc=W}}while(0);if(!((mc|0)==0&(lc|0)==(-2147483648|0))){h=c[q>>2]|0;q=YGb(h,(h|0)<0|0?-1:0,mc,lc)|0;lc=u+216|0;c[lc>>2]=q;c[lc+4>>2]=F}c[k>>2]=1;H=0;i=l;return H|0}return 0}function t4a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[a+60>>2]|0;d=b+180|0;e=d;f=c[e>>2]|0;a:do{if((f|0)!=0){g=b+176|0;if((c[g>>2]|0)>0){h=0;i=f}else{break}while(1){$Db(i+(h*44|0)+4|0);$Db((c[e>>2]|0)+(h*44|0)+8|0);$Db((c[e>>2]|0)+(h*44|0)+32|0);$Db((c[e>>2]|0)+(h*44|0)+36|0);$Db((c[e>>2]|0)+(h*44|0)+40|0);j=h+1|0;if((j|0)>=(c[g>>2]|0)){break a}h=j;i=c[e>>2]|0}}}while(0);$Db(d);d=b+188|0;e=d;i=c[e>>2]|0;b:do{if((i|0)!=0){h=b+184|0;if((c[h>>2]|0)>0){k=0;l=i}else{break}while(1){f=c[l+(k<<5)+12>>2]|0;c:do{if((f|0)==0){m=l}else{if((c[l+(k<<5)+8>>2]|0)>0){n=0;o=f}else{m=l;break}while(1){$Db(o+(n<<4)+12|0);g=n+1|0;j=c[e>>2]|0;if((g|0)>=(c[j+(k<<5)+8>>2]|0)){m=j;break c}n=g;o=c[j+(k<<5)+12>>2]|0}}}while(0);$Db(m+(k<<5)+12|0);$Db((c[e>>2]|0)+(k<<5)+4|0);$Db((c[e>>2]|0)+(k<<5)+28|0);f=k+1|0;if((f|0)>=(c[h>>2]|0)){break b}k=f;l=c[e>>2]|0}}}while(0);$Db(d);d=b+196|0;e=d;l=c[e>>2]|0;d:do{if((l|0)!=0){k=b+192|0;if((c[k>>2]|0)>0){p=0;q=l}else{break}while(1){$Db(q+(p<<5)+24|0);$Db((c[e>>2]|0)+(p<<5)+28|0);m=p+1|0;if((m|0)>=(c[k>>2]|0)){break d}p=m;q=c[e>>2]|0}}}while(0);$Db(d);d=b+204|0;e=d;q=c[e>>2]|0;e:do{if((q|0)!=0){p=b+200|0;if((c[p>>2]|0)>0){r=0;s=q}else{break}while(1){$Db(s+(r*28|0)+4|0);$Db((c[e>>2]|0)+(r*28|0)+8|0);$Db((c[e>>2]|0)+(r*28|0)+12|0);$Db((c[e>>2]|0)+(r*28|0)+20|0);$Db((c[e>>2]|0)+(r*28|0)+24|0);l=r+1|0;if((l|0)>=(c[p>>2]|0)){break e}r=l;s=c[e>>2]|0}}}while(0);$Db(d);$Db(b+212|0);$Db(b+156|0);$Db(b+160|0);$Db(b+164|0);$Db(b+168|0);bLa(b+16|0);bLa(b+80|0);$Db(a+96|0);return 0}function u4a(b,e,f){b=b|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0.0,s=0,t=0.0,u=0.0,v=0,w=0.0,y=0,z=0.0,A=0,B=0,C=0,D=0,E=0,F=0;h=b+36|0;i=c[h>>2]|0;if((i|0)==0){yd(1891712,2000680,852,2359864);return 0}j=c[b>>2]|0;if((j|0)>0){k=c[b+12>>2]|0;l=c[b+4>>2]|0;m=b+40|0;n=0;o=-1;p=3.4028234663852886e+38;while(1){q=ba(k,n)|0;do{if((a[l+n|0]|0)==0){r=p;s=o}else{t=+g[(c[m>>2]|0)+(n<<2)>>2];if((k|0)>0){u=t;v=0;while(1){w=u- +g[i+(v+q<<2)>>2]*+g[f+(v<<2)>>2];y=v+1|0;if((y|0)<(k|0)){u=w;v=y}else{z=w;break}}}else{z=t}if(!(p>z)){r=p;s=o;break}r=z;s=n}}while(0);q=n+1|0;if((q|0)<(j|0)){n=q;o=s;p=r}else{A=s;B=l;break}}}else{A=-1;B=c[b+4>>2]|0}l=e+4|0;s=c[l>>2]|0;o=e+12|0;n=c[o>>2]|0;j=d[B+A|0]|0;if(((c[e+20>>2]|0)-32+s-(n-(c[e+8>>2]|0)<<3)|0)<(j|0)){C=0;return C|0}B=c[(c[b+8>>2]|0)+(A<<2)>>2]|0;k=e|0;e=B<<32-s|c[k>>2];if((s|0)>(j|0)){D=s;E=e;F=i}else{i=n;x=e;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;D=s+32|0;E=(s|0)==32?0:B>>>(s>>>0);F=c[h>>2]|0}c[k>>2]=E;c[l>>2]=D-j;C=F+((ba(c[b+12>>2]|0,A)|0)<<2)|0;return C|0}function v4a(b,d){b=b|0;d=+d;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=~~+sGb(+Qc(+d,f|0),20);h=(c[f>>2]|0)+768|0;c[f>>2]=h;f=(g|0)<0?-g|0:g;j=f&65535;k=(h<<21|g&-2147483648|f)>>>16;f=b|0;g=b+4|0;h=c[g>>2]|0;l=j<<32-h|c[f>>2];if((h|0)>16){m=h;n=l}else{o=b+12|0;p=c[o>>2]|0;x=l;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;m=h+32|0;n=j>>>(h>>>0)}h=m-16|0;c[f>>2]=n;c[g>>2]=h;j=k<<48-m|n;if((h|0)>16){q=h;r=j;s=q-16|0;c[f>>2]=r;c[g>>2]=s;i=e;return}n=b+12|0;b=c[n>>2]|0;x=j;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;q=m+16|0;r=k>>>(h>>>0);s=q-16|0;c[f>>2]=r;c[g>>2]=s;i=e;return}function w4a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=i;i=i+56|0;e=b|0;f=b+24|0;g=b+40|0;h=c[a+60>>2]|0;c[a+140>>2]=0;j=h+4|0;c[j>>2]=1;h=c[a+100>>2]|0;if((h|0)==0){yDb(a,16,2072424,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}if((Bdb(c[a+96>>2]|0,h,42,f|0,g|0)|0)<0){yDb(a,16,2067824,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}h=e|0;m=e+12|0;n=e+16|0;o=e+4|0;p=e+8|0;q=a;r=0;while(1){s=g+(r<<2)|0;t=c[s>>2]|0;if((t|0)>=1){u=c[f+(r<<2)>>2]|0;v=t<<3;t=v>>>0>2147483639>>>0|(u|0)==0;w=t?0:u;u=t?0:v;c[h>>2]=w;c[m>>2]=u;v=u+8|0;c[n>>2]=v;c[o>>2]=w+(u>>3);c[p>>2]=0;u=w;w=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=w&255;t=v>>>0>8>>>0?8:v;c[p>>2]=t;if((w&128|0)==0){yDb(q,16,2063408,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;x=c[p>>2]|0;y=c[n>>2]|0}else{x=t;y=v}v=-x|0;t=y-x|0;if((v|0)>48){z=v}else{z=(t|0)<48?t:48}c[p>>2]=z+x;if((u|0)==130){if((C4a(a,e)|0)==0){A=15}else{l=-1;A=20;break}}else if((u|0)==128){if((B4a(a,e)|0)<0){l=-1;A=20;break}else{A=15}}else if((u|0)!=129){yDb(q,16,2059728,(k=i,i=i+8|0,c[k>>2]=w&127,k)|0);i=k;A=15}do{if((A|0)==15){A=0;w=c[s>>2]<<3;t=c[p>>2]|0;if((w|0)==(t|0)){break}yDb(q,24,2054688,(k=i,i=i+16|0,c[k>>2]=w-t,c[k+8>>2]=u,k)|0);i=k}}while(0);if((c[j>>2]|0)<197120){A=19;break}}u=r+1|0;if((u|0)<3){r=u}else{A=19;break}}if((A|0)==19){l=A4a(a)|0;i=b;return l|0}else if((A|0)==20){i=b;return l|0}return 0}function x4a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,ge=0,he=0,ie=0,je=0;k=i;i=i+616|0;l=k|0;m=k+256|0;n=k+512|0;o=k+528|0;p=k+544|0;q=k+560|0;r=k+592|0;s=c[j+24>>2]|0;t=c[j+28>>2]|0;j=f+60|0;u=c[j>>2]|0;v=u;w=t<<3;x=w>>>0>2147483639>>>0|(s|0)==0;y=x?0:s;s=x?0:w;w=r|0;c[w>>2]=y;x=r+12|0;c[x>>2]=s;z=s+8|0;A=r+16|0;c[A>>2]=z;c[r+4>>2]=y+(s>>3);s=r+8|0;c[s>>2]=0;B=u+4|0;do{if((c[B>>2]|0)==0){C=0}else{D=a[y]|0;E=(z|0)>0;F=E&1;c[s>>2]=F;if(D<<24>>24>-1){C=F;break}D=y;G=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<F>>>25;F=E?8:7;E=z>>>0>F>>>0?F:z;c[s>>2]=E;F=-E|0;D=z-E|0;if((F|0)>48){H=F}else{H=(D|0)<48?D:48}c[s>>2]=H+E;if((c[(c[u>>2]|0)+816>>2]&1|0)!=0){yDb(f,16,2000584,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-1163346256;i=k;return J|0}if((G|0)==0){y4a(f)|0;E=B4a(f,r)|0;if((E|0)<0){y4a(f)|0;J=E;i=k;return J|0}else{J=A4a(f)|0;i=k;return J|0}}else if((G|0)==2){G=C4a(f,r)|0;if((G|0)<0){y4a(f)|0;J=G;i=k;return J|0}else{J=A4a(f)|0;i=k;return J|0}}else{yDb(f,16,1963608,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-1;i=k;return J|0}}}while(0);H=d[y]<<C;c[s>>2]=((C|0)<(z|0))+C;C=u+68|0;c[C>>2]=H>>>7&1^1;H=u+688|0;if((c[H>>2]|0)==0){yDb(f,16,1935488,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-1;i=k;return J|0}if((c[B>>2]|0)==0){z=c[A>>2]|0;G=(c[s>>2]|0)+1|0;c[s>>2]=z>>>0>G>>>0?G:z}z=u+588|0;G=z;E=u+604|0;D=E;c[E>>2]=c[z>>2];c[u+608>>2]=c[u+592>>2];c[u+612>>2]=c[u+596>>2];F=u+600|0;c[F>>2]=0;K=c[s>>2]|0;L=c[A>>2]|0;while(1){M=y+(K>>>3)|0;N=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>26;M=K+6|0;c[s>>2]=L>>>0>M>>>0?M:L;M=c[F>>2]|0;c[F>>2]=M+1;c[G+(M<<2)>>2]=N;if((c[B>>2]|0)<=197119){O=23;break}if((c[F>>2]|0)>=3){break}N=c[s>>2]|0;M=d[y+(N>>>3)|0]|0;P=c[A>>2]|0;Q=((N|0)<(P|0))+N|0;c[s>>2]=Q;if((M&128>>>((N&7)>>>0)|0)==0){O=23;break}else{K=Q;L=P}}do{if((O|0)==23){L=c[F>>2]|0;if((L|0)>=3){break}K=L<<2;TGb(u+(K+588)|0,-1|0,12-K|0)|0}}while(0);K=u;L=c[K>>2]|0;if((c[L+688>>2]&1|0)==0){R=z}else{y=(c[f+428>>2]|0)+1|0;P=z;z=c[P>>2]|0;yDb(L,32,1912216,(I=i,i=i+24|0,c[I>>2]=(c[C>>2]|0)!=0?1891704:9203656,c[I+8>>2]=y,c[I+16>>2]=z,I)|0);i=I;R=P}P=c[R>>2]|0;if((a[u+(P+52892)|0]|0)==0){S=1}else{S=(c[f+848>>2]|0)>=(((c[C>>2]|0)!=0?48:32)|0)|0}z=u+584|0;c[z>>2]=S;S=E;if((P|0)!=(c[S>>2]|0)){E=a[v+52892+P|0]|0;P=E&255;if(!(E<<24>>24>-1)){yDb(0,0,2143584,(I=i,i=i+24|0,c[I>>2]=2138160,c[I+8>>2]=2131488,c[I+16>>2]=407,I)|0);i=I;Cd();return 0}TGb(u+52960|0,0,1024)|0;do{if(E<<24>>24==0){T=P}else{y=0;do{c[v+52960+(127-y<<2)>>2]=-y;c[v+52960+(y+127<<2)>>2]=y;y=y+1|0;}while((y|0)<(P|0));if(!(E<<24>>24>0)){T=P;break}y=-P|0;L=P+1|0;Q=P-(L>>>0>128>>>0?L:128)|0;L=Q>>>0<y>>>0;N=P;M=P;do{c[v+52960+(N+127<<2)>>2]=M;c[v+52960+(127-N<<2)>>2]=-M;N=N+1|0;M=M-1|0;}while((N|0)<128&(M|0)!=0);T=(L?y:Q)+P|0}}while(0);if((T|0)!=0){c[u+53980>>2]=T}T=ba(P,33686018)|0;c[u+53988>>2]=T;c[u+53984>>2]=T}T=c[F>>2]|0;if((T|0)>0){P=0;E=T;while(1){T=c[G+(P<<2)>>2]|0;if((T|0)==(c[D+(P<<2)>>2]|0)){if((c[R>>2]|0)==(c[S>>2]|0)){U=E}else{O=45}}else{O=45}if((O|0)==45){O=0;M=v+588+(P<<2)|0;N=c[v+852+(T<<2)>>2]|0;V=e[v+724+(T<<1)>>1]|0;T=0;do{W=0;do{X=d[v+25684+(T*3|0)+W|0]|0;Y=0;Z=0;while(1){_=v+25690+(T*192|0)+(W<<6)+Z|0;$=a[_]|0;if((Z|0)>=(X|0)){O=49;break}aa=$&255;ca=aa+Y|0;da=Z+1|0;if((c[M>>2]|0)>(ca|0)){Y=ca;Z=da}else{ea=ca;fa=da;ga=aa;break}}if((O|0)==49){O=0;ea=Y;fa=Z+1|0;ga=$&255}X=ea-ga|0;aa=e[v+26074+(T*384|0)+(W<<7)+(Z<<1)>>1]|0;da=e[v+26074+(T*384|0)+(W<<7)+(fa<<1)>>1]|0;ca=0;ha=$;while(1){ia=c[M>>2]|0;ja=ba(ea-ia<<1,d[v+1108+(aa<<6)+ca|0]|0)|0;ka=ha&255;la=(ja-(ba(X-ia<<1,d[v+1108+(da<<6)+ca|0]|0)|0)+ka|0)/(ka<<1|0)|0;ka=(ca|0)!=0;ia=8<<(ka&1^1)+T;ja=((ba(la,ka?N:V)|0)/100|0)<<2;if((ja|0)<(ia|0)){ma=ia&65535}else{ma=(ja|0)>4096?4096:ja&65535}b[v+30080+(P*768|0)+(T*384|0)+(W<<7)+(d[v+72+ca|0]<<1)>>1]=ma;ja=ca+1|0;if((ja|0)>=64){break}ca=ja;ha=a[_]|0}b[v+30080+(P*768|0)+(T*384|0)+(W<<7)>>1]=b[v+30080+(T*384|0)+(W<<7)>>1]|0;W=W+1|0;}while((W|0)<3);T=T+1|0;}while((T|0)<2);U=c[F>>2]|0}T=P+1|0;if((T|0)<(U|0)){P=T;E=U}else{break}}}U=c[C>>2]|0;if((c[f+856>>2]|0)>31&(U|0)==0){J=t;i=k;return J|0}E=u+56|0;P=E;_=E;E=c[_>>2]|0;c[E+88>>2]=(U|0)!=0?1:2;c[E+84>>2]=U;a:do{if((W0a(f,P,1)|0)>=0){U=u+32392|0;if((c[U>>2]|0)==0){E=c[(c[_>>2]|0)+32>>2]|0;c[U>>2]=WDb(((E|0)>-1?E:-E|0)*9|0)|0}do{if((c[C>>2]|0)==0){E=u+32|0;ma=E;ea=E;if((c[c[ea>>2]>>2]|0)!=0){break}yDb(c[K>>2]|0,24,2286872,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;c[(c[ea>>2]|0)+88>>2]=1;if((W0a(f,ma,1)|0)<0){break a}ea=u+44|0;U0a(f,ea);if((T0a(ea,ma)|0)<0){break a}Y0a(ea,2147483647,0)}else{do{if((c[B>>2]|0)==0){ea=c[A>>2]|0;ma=(c[s>>2]|0)+4|0;E=(ea>>>0>ma>>>0?ma:ea)+4|0;ma=ea>>>0>E>>>0?E:ea;c[s>>2]=ma;E=u+12|0;if((c[E>>2]|0)==0){na=E;break}$=(c[w>>2]|0)+(ma>>>3)|0;fa=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ma&7)>>>27;$=ma+5|0;c[s>>2]=ea>>>0>$>>>0?$:ea;c[E>>2]=fa;if((c[f+428>>2]|0)!=0){na=E;break}yDb(c[K>>2]|0,48,2329056,(I=i,i=i+8|0,c[I>>2]=fa,I)|0);i=I;na=E}else{na=u+12|0}}while(0);if((c[na>>2]|0)==0){if((c[B>>2]|0)==0){break}}E=c[s>>2]|0;fa=d[(c[w>>2]|0)+(E>>>3)|0]|0;ea=c[A>>2]|0;$=((E|0)<(ea|0))+E|0;c[s>>2]=$;if((fa&128>>>((E&7)>>>0)|0)==0){oa=$;pa=ea}else{yDb(c[K>>2]|0,16,2304704,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;oa=c[s>>2]|0;pa=c[A>>2]|0}ea=oa+2|0;c[s>>2]=pa>>>0>ea>>>0?ea:pa}}while(0);ea=u+668|0;TGb(c[H>>2]|0,0,c[ea>>2]<<2|0)|0;X0a(f);c[p>>2]=0;c[p+4>>2]=c[u+644>>2];c[p+8>>2]=c[u+648>>2];b:do{if((c[C>>2]|0)==0){$=c[s>>2]|0;E=d[(c[w>>2]|0)+($>>>3)|0]<<($&7)>>>7;fa=(($|0)<(c[A>>2]|0))+$|0;c[s>>2]=fa;$=E&1^1;E=u+616|0;ma=c[E>>2]|0;c:do{if((ma|0)>0){ga=u+30004|0;S=u+652|0;if(((c[x>>2]|0)-fa|0)>0){qa=fa;ra=$;sa=0;ta=0;ua=0}else{va=0;wa=0;xa=$;ya=ma;O=94;break}while(1){if((c[B>>2]|0)!=0&(ua|0)==4129){R=c[w>>2]|0;D=d[R+(qa>>>3)|0]<<(qa&7)>>>7;G=c[A>>2]|0;T=((qa|0)<(G|0))+qa|0;c[s>>2]=T;za=D&1;Aa=T;Ba=G;Ca=R}else{za=ra^1;Aa=qa;Ba=c[A>>2]|0;Ca=c[w>>2]|0}R=c[ga>>2]|0;G=Ca+(Aa>>>3)|0;T=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(Aa&7)>>>26;G=b[R+(T<<2)>>1]|0;D=b[R+(T<<2)+2>>1]|0;T=D<<16>>16;if(D<<16>>16<0){D=Aa+6|0;V=Ba>>>0>D>>>0?D:Ba;D=Ca+(V>>>3)|0;N=((fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(V&7)>>>((T+32|0)>>>0))+G|0;Da=b[R+(N<<2)+2>>1]|0;Ea=b[R+(N<<2)>>1]|0;Fa=V}else{Da=T;Ea=G;Fa=Aa}G=Da+Fa|0;T=Ba>>>0>G>>>0?G:Ba;c[s>>2]=T;G=Ea+1|0;if((G|0)==34){V=Ca+(T>>>3)|0;N=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>20;V=T+12|0;c[s>>2]=Ba>>>0>V>>>0?V:Ba;Ga=N+34|0}else{Ga=G}G=Ga+sa|0;if((G|0)>(c[E>>2]|0)){break}TGb((c[S>>2]|0)+sa|0,za&255|0,Ga|0)|0;N=((za|0)==0?0:Ga)+ta|0;V=c[E>>2]|0;if((G|0)>=(V|0)){va=Ga;wa=N;xa=za;ya=V;O=94;break c}T=c[s>>2]|0;if(((c[x>>2]|0)-T|0)>0){qa=T;ra=za;sa=G;ta=N;ua=Ga}else{va=Ga;wa=N;xa=za;ya=V;O=94;break c}}yDb(c[K>>2]|0,16,2157296,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}else{va=0;wa=0;xa=$;ya=ma;O=94}}while(0);d:do{if((O|0)==94){e:do{if((wa|0)<(ya|0)){ma=c[s>>2]|0;$=d[(c[w>>2]|0)+(ma>>>3)|0]<<(ma&7)>>>7;fa=((ma|0)<(c[A>>2]|0))+ma|0;c[s>>2]=fa;ma=$&1^1;if(((c[E>>2]|0)-wa|0)<=0){Ha=ma;Ia=0;break}$=u+30004|0;S=u+652|0;if(((c[x>>2]|0)-fa|0)>0){Ja=fa;Ka=ma;La=0;Ma=0;Na=0}else{Ha=ma;Ia=0;break}f:while(1){if((c[B>>2]|0)!=0&(Na|0)==4129){ma=c[w>>2]|0;fa=d[ma+(Ja>>>3)|0]<<(Ja&7)>>>7;ga=c[A>>2]|0;V=((Ja|0)<(ga|0))+Ja|0;c[s>>2]=V;Oa=fa&1;Pa=V;Qa=ga;Ra=ma}else{Oa=Ka^1;Pa=Ja;Qa=c[A>>2]|0;Ra=c[w>>2]|0}ma=c[$>>2]|0;ga=Ra+(Pa>>>3)|0;V=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(Pa&7)>>>26;ga=b[ma+(V<<2)>>1]|0;fa=b[ma+(V<<2)+2>>1]|0;V=fa<<16>>16;if(fa<<16>>16<0){fa=Pa+6|0;N=Qa>>>0>fa>>>0?fa:Qa;fa=Ra+(N>>>3)|0;G=((fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(N&7)>>>((V+32|0)>>>0))+ga|0;Sa=b[ma+(G<<2)+2>>1]|0;Ta=b[ma+(G<<2)>>1]|0;Ua=N}else{Sa=V;Ta=ga;Ua=Pa}ga=Sa+Ua|0;V=Qa>>>0>ga>>>0?ga:Qa;c[s>>2]=V;ga=Ta+1|0;if((ga|0)==34){N=Ra+(V>>>3)|0;G=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(V&7)>>>20;N=V+12|0;c[s>>2]=Qa>>>0>N>>>0?N:Qa;Va=G+34|0}else{Va=ga}if((Va|0)>0){ga=Oa<<1&255;G=0;N=Ma;while(1){if((N|0)>=(c[E>>2]|0)){break f}V=(c[S>>2]|0)+N|0;if((a[V]|0)==0){a[V]=ga;Wa=G+1|0}else{Wa=G}V=N+1|0;if((Wa|0)<(Va|0)){G=Wa;N=V}else{Xa=V;break}}}else{Xa=Ma}N=Va+La|0;if((N|0)>=((c[E>>2]|0)-wa|0)){Ha=Oa;Ia=Va;break e}G=c[s>>2]|0;if(((c[x>>2]|0)-G|0)>0){Ja=G;Ka=Oa;La=N;Ma=Xa;Na=Va}else{Ha=Oa;Ia=Va;break e}}yDb(c[K>>2]|0,16,2150536,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break d}else{Ha=xa;Ia=va}}while(0);if((wa|0)==0){Ya=Ha;Za=Ia;break b}S=c[s>>2]|0;$=d[(c[w>>2]|0)+(S>>>3)|0]<<(S&7)>>>7;c[s>>2]=((S|0)<(c[A>>2]|0))+S;Ya=$&1^1;Za=0;break b}}while(0);yDb(c[K>>2]|0,16,2270728,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break a}else{TGb(c[u+652>>2]|0,2,c[u+616>>2]|0)|0;Ya=0;Za=0}}while(0);E=u+28384|0;c[E>>2]=0;$=u+32388|0;TGb(c[$>>2]|0,8,c[u+656>>2]|0)|0;S=u+640|0;N=u+628|0;G=u+32384|0;ga=u+652|0;V=u+30024|0;ma=Za;fa=0;T=Ya;R=0;while(1){D=c[((fa|0)==0?N:S)>>2]|0;M=D+R|0;g:do{if((D|0)>0){Q=v+28388+(fa<<2)|0;y=ma;L=R;W=T;ha=0;while(1){if(((c[x>>2]|0)-(c[s>>2]|0)|0)<=0){_a=y;$a=W;ab=ha;break g}ca=L<<4;da=y;X=0;aa=W;Z=ha;while(1){Y=c[(c[G>>2]|0)+(X+ca<<2)>>2]|0;do{if((Y|0)==-1){bb=Z;cb=aa;db=da}else{ja=a[(c[ga>>2]|0)+L|0]|0;ia=ja&255;do{if(ja<<24>>24==1){if((da|0)!=0){eb=aa;fb=aa;gb=da-1|0;break}ka=aa^1;la=c[V>>2]|0;hb=c[s>>2]|0;ib=c[A>>2]|0;jb=c[w>>2]|0;kb=jb+(hb>>>3)|0;lb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(hb&7)>>>27;kb=b[la+(lb<<2)>>1]|0;mb=b[la+(lb<<2)+2>>1]|0;lb=mb<<16>>16;if(mb<<16>>16<0){mb=hb+5|0;nb=ib>>>0>mb>>>0?mb:ib;mb=jb+(nb>>>3)|0;jb=((fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(nb&7)>>>((lb+32|0)>>>0))+kb|0;ob=b[la+(jb<<2)+2>>1]|0;pb=b[la+(jb<<2)>>1]|0;qb=nb}else{ob=lb;pb=kb;qb=hb}hb=ob+qb|0;c[s>>2]=ib>>>0>hb>>>0?hb:ib;eb=ka;fb=ka;gb=pb}else{eb=ia;fb=aa;gb=da}}while(0);ia=(c[H>>2]|0)+(Y<<2)+2|0;if((eb|0)==0){a[ia]=8;bb=Z;cb=fb;db=gb;break}else{a[ia]=0;c[(c[Q>>2]|0)+(Z<<2)>>2]=Y;bb=Z+1|0;cb=fb;db=gb;break}}}while(0);Y=X+1|0;if((Y|0)<16){da=db;X=Y;aa=cb;Z=bb}else{break}}Z=L+1|0;if((Z|0)<(M|0)){y=db;L=Z;W=cb;ha=bb}else{_a=db;$a=cb;ab=bb;break}}}else{_a=ma;$a=T;ab=0}}while(0);c[E>>2]=(c[E>>2]|0)+ab;M=0;do{c[v+27616+(fa<<8)+(M<<2)>>2]=ab;M=M+1|0;}while((M|0)<64);if((fa|0)<2){M=fa+1|0;c[v+28388+(M<<2)>>2]=(c[v+28388+(fa<<2)>>2]|0)+(ab<<2);rb=M}else{rb=fa+1|0}if((rb|0)>=3){break}ma=_a;fa=rb;T=$a;R=c[p+(rb<<2)>>2]|0}R=q;h:do{if((c[C>>2]|0)==0){T=c[s>>2]|0;fa=c[A>>2]|0;ma=c[w>>2]|0;V=ma+(T>>>3)|0;ga=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;if((ga|0)==0){TGb(R|0,0,32)|0;V=ma+(T>>>3)|0;G=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;c[q+(G<<2)>>2]=0;G=ma+(T>>>3)|0;V=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(T&7)>>>29;G=T+3|0;T=fa>>>0>G>>>0?G:fa;c[s>>2]=T;c[q+(V<<2)>>2]=1;V=ma+(T>>>3)|0;G=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;c[q+(G<<2)>>2]=2;G=ma+(T>>>3)|0;V=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(T&7)>>>29;G=T+3|0;T=fa>>>0>G>>>0?G:fa;c[s>>2]=T;c[q+(V<<2)>>2]=3;V=ma+(T>>>3)|0;G=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;c[q+(G<<2)>>2]=4;G=ma+(T>>>3)|0;V=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(T&7)>>>29;G=T+3|0;T=fa>>>0>G>>>0?G:fa;c[s>>2]=T;c[q+(V<<2)>>2]=5;V=ma+(T>>>3)|0;G=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;c[q+(G<<2)>>2]=6;G=ma+(T>>>3)|0;ma=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(T&7)>>>29;G=T+3|0;c[s>>2]=fa>>>0>G>>>0?G:fa;c[q+(ma<<2)>>2]=7;sb=q|0}else{sb=2363216+(ga-1<<5)|0}ma=u+624|0;fa=c[ma>>2]|0;if((fa|0)<=0){break}G=u+620|0;T=u+660|0;V=u+664|0;S=u+672|0;N=(ga|0)==7;ga=u+28|0;M=u+24|0;D=u+676|0;ha=u+696|0;W=u+700|0;L=u+30044|0;y=0;Q=c[G>>2]|0;Z=fa;i:while(1){if((Q|0)>0){fa=y<<1;aa=0;do{if(((c[x>>2]|0)-(c[s>>2]|0)|0)<1){break i}X=aa<<1;da=0;do{ca=da>>1;Y=ca+X|0;ia=ca+da&1|fa;ca=c[T>>2]|0;ja=(ba(ia,ca)|0)+Y|0;do{if((Y|0)<(ca|0)){if((ia|0)>=(c[V>>2]|0)){break}ka=ia<<1;ib=Y<<1;hb=0;while(1){if((hb|0)>=4){break}kb=(ba(c[S>>2]|0,(hb>>1)+ka|0)|0)+(hb&1|ib)|0;if((a[(c[H>>2]|0)+(kb<<2)+2|0]|0)==8){hb=hb+1|0}else{break}}if((hb|0)==4){a[(c[$>>2]|0)+ja|0]=0;break}if(N){kb=c[s>>2]|0;lb=c[A>>2]|0;nb=(c[w>>2]|0)+(kb>>>3)|0;jb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(kb&7)>>>29;nb=kb+3|0;c[s>>2]=lb>>>0>nb>>>0?nb:lb;tb=jb&255}else{jb=c[L>>2]|0;lb=c[s>>2]|0;nb=c[A>>2]|0;kb=c[w>>2]|0;la=kb+(lb>>>3)|0;mb=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(lb&7)>>>29;la=b[jb+(mb<<2)>>1]|0;ub=b[jb+(mb<<2)+2>>1]|0;mb=ub<<16>>16;do{if(ub<<16>>16<0){vb=lb+3|0;wb=nb>>>0>vb>>>0?vb:nb;vb=kb+(wb>>>3)|0;xb=((fe(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(wb&7)>>>((mb+32|0)>>>0))+la|0;vb=b[jb+(xb<<2)>>1]|0;yb=b[jb+(xb<<2)+2>>1]|0;xb=yb<<16>>16;if(!(yb<<16>>16<0)){zb=xb;Ab=vb;Bb=wb;break}yb=wb-mb|0;wb=nb>>>0>yb>>>0?yb:nb;yb=kb+(wb>>>3)|0;Cb=((fe(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(wb&7)>>>((xb+32|0)>>>0))+vb|0;zb=b[jb+(Cb<<2)+2>>1]|0;Ab=b[jb+(Cb<<2)>>1]|0;Bb=wb}else{zb=mb;Ab=la;Bb=lb}}while(0);lb=zb+Bb|0;c[s>>2]=nb>>>0>lb>>>0?lb:nb;tb=c[sb+(Ab<<2)>>2]&255}a[(c[$>>2]|0)+ja|0]=tb;lb=c[H>>2]|0;la=c[S>>2]|0;mb=lb+((ba(la,ka)|0)+ib<<2)+2|0;if((a[mb]|0)==8){Db=lb;Eb=la}else{a[mb]=tb;Db=c[H>>2]|0;Eb=c[S>>2]|0}mb=ib|1;la=Db+((ba(Eb,ka)|0)+mb<<2)+2|0;if((a[la]|0)==8){Fb=Db;Gb=Eb}else{a[la]=tb;Fb=c[H>>2]|0;Gb=c[S>>2]|0}la=ka|1;lb=Fb+((ba(Gb,la)|0)+ib<<2)+2|0;if((a[lb]|0)==8){Hb=Fb;Ib=Gb}else{a[lb]=tb;Hb=c[H>>2]|0;Ib=c[S>>2]|0}lb=Hb+((ba(Ib,la)|0)+mb<<2)+2|0;if((a[lb]|0)!=8){a[lb]=tb}if((c[ga>>2]|0)!=0){lb=c[H>>2]|0;jb=(ba(c[D>>2]|0,ia)|0)+Y|0;kb=lb+(jb+(c[ha>>2]|0)<<2)+2|0;if((a[kb]|0)!=8){a[kb]=tb}kb=lb+((c[W>>2]|0)+jb<<2)+2|0;if((a[kb]|0)==8){break}a[kb]=tb;break}kb=c[H>>2]|0;jb=ba(c[D>>2]|0,ka)|0;if((c[M>>2]|0)!=0){lb=jb+Y|0;ub=kb+((c[ha>>2]|0)+lb<<2)+2|0;if((a[ub]|0)!=8){a[ub]=tb}ub=kb+((c[W>>2]|0)+lb<<2)+2|0;if((a[ub]|0)!=8){a[ub]=tb}ub=(c[D>>2]|0)+lb|0;lb=kb+(ub+(c[ha>>2]|0)<<2)+2|0;if((a[lb]|0)!=8){a[lb]=tb}lb=kb+((c[W>>2]|0)+ub<<2)+2|0;if((a[lb]|0)==8){break}a[lb]=tb;break}lb=jb+ib|0;jb=kb+((c[ha>>2]|0)+lb<<2)+2|0;if((a[jb]|0)!=8){a[jb]=tb}jb=kb+((c[W>>2]|0)+lb<<2)+2|0;if((a[jb]|0)!=8){a[jb]=tb}jb=c[H>>2]|0;lb=(ba(c[D>>2]|0,ka)|0)+mb|0;kb=jb+(lb+(c[ha>>2]|0)<<2)+2|0;if((a[kb]|0)!=8){a[kb]=tb}kb=jb+((c[W>>2]|0)+lb<<2)+2|0;if((a[kb]|0)!=8){a[kb]=tb}kb=c[H>>2]|0;lb=(ba(c[D>>2]|0,la)|0)+ib|0;jb=kb+(lb+(c[ha>>2]|0)<<2)+2|0;if((a[jb]|0)!=8){a[jb]=tb}jb=kb+((c[W>>2]|0)+lb<<2)+2|0;if((a[jb]|0)!=8){a[jb]=tb}jb=c[H>>2]|0;lb=(ba(c[D>>2]|0,la)|0)+mb|0;mb=jb+(lb+(c[ha>>2]|0)<<2)+2|0;if((a[mb]|0)!=8){a[mb]=tb}mb=jb+((c[W>>2]|0)+lb<<2)+2|0;if((a[mb]|0)==8){break}a[mb]=tb}}while(0);da=da+1|0;}while((da|0)<4);aa=aa+1|0;Jb=c[G>>2]|0;}while((aa|0)<(Jb|0));Kb=Jb;Lb=c[ma>>2]|0}else{Kb=Q;Lb=Z}aa=y+1|0;if((aa|0)<(Lb|0)){y=aa;Q=Kb;Z=Lb}else{break h}}yDb(c[K>>2]|0,16,2255448,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break a}else{if((c[ea>>2]|0)>0){Mb=0}else{break}do{a[(c[H>>2]|0)+(Mb<<2)+2|0]=1;Mb=Mb+1|0;}while((Mb|0)<(c[ea>>2]|0))}}while(0);j:do{if((c[C>>2]|0)==0){ea=c[s>>2]|0;R=a[(c[w>>2]|0)+(ea>>>3)|0]|0;c[s>>2]=((ea|0)<(c[A>>2]|0))+ea;Z=u+624|0;Q=c[Z>>2]|0;if((Q|0)<=0){break}y=u+620|0;ma=u+660|0;G=u+664|0;W=n|0;ha=o|0;D=u+672|0;M=u+716|0;ga=u+28|0;S=u+24|0;L=n+4|0;N=o+4|0;V=n+8|0;T=n+12|0;aa=o+8|0;fa=o+12|0;da=u+676|0;X=u+720|0;Y=(R&255&128>>>((ea&7)>>>0)|0)==0;ea=u+30064|0;R=0;ia=0;ja=0;ca=0;mb=0;lb=c[y>>2]|0;jb=Q;k:while(1){if((lb|0)>0){Q=R<<1;la=0;kb=ia;ub=ja;hb=ca;wb=mb;while(1){if(((c[x>>2]|0)-(c[s>>2]|0)|0)<1){break k}Cb=la<<1;vb=kb;xb=ub;yb=hb;Nb=wb;Ob=0;while(1){Pb=Ob>>1;Qb=Pb+Cb|0;Rb=Pb+Ob&1|Q;Pb=c[ma>>2]|0;Sb=(ba(Pb,Rb)|0)+Qb|0;do{if((Qb|0)<(Pb|0)){if((Rb|0)>=(c[G>>2]|0)){Tb=Nb;Ub=yb;Vb=xb;Wb=vb;break}Xb=c[$>>2]|0;Yb=Xb+Sb|0;Zb=a[Yb]|0;if(Zb<<24>>24==8){Tb=Nb;Ub=yb;Vb=xb;Wb=vb;break}switch(Zb&255|0){case 7:{Zb=Rb<<1;_b=Qb<<1;$b=c[H>>2]|0;ac=vb;bc=xb;cc=0;while(1){do{if((a[$b+((ba(c[D>>2]|0,(cc>>1)+Zb|0)|0)+(cc&1|_b)<<2)+2|0]|0)==8){c[n+(cc<<2)>>2]=0;c[o+(cc<<2)>>2]=0;dc=bc;ec=ac}else{if(!Y){fc=c[s>>2]|0;gc=c[A>>2]|0;hc=c[w>>2]|0;ic=hc+(fc>>>3)|0;jc=(fe(d[ic]|d[ic+1|0]<<8|d[ic+2|0]<<16|d[ic+3|0]<<24|0)|0)<<(fc&7)>>>26;ic=fc+6|0;fc=gc>>>0>ic>>>0?ic:gc;c[s>>2]=fc;ic=a[1049840+jc|0]|0;c[n+(cc<<2)>>2]=ic;jc=hc+(fc>>>3)|0;hc=(fe(d[jc]|d[jc+1|0]<<8|d[jc+2|0]<<16|d[jc+3|0]<<24|0)|0)<<(fc&7)>>>26;jc=fc+6|0;c[s>>2]=gc>>>0>jc>>>0?jc:gc;gc=a[1049840+hc|0]|0;c[o+(cc<<2)>>2]=gc;dc=gc;ec=ic;break}ic=c[ea>>2]|0;gc=c[s>>2]|0;hc=c[A>>2]|0;jc=c[w>>2]|0;fc=jc+(gc>>>3)|0;kc=(fe(d[fc]|d[fc+1|0]<<8|d[fc+2|0]<<16|d[fc+3|0]<<24|0)|0)<<(gc&7)>>>26;fc=b[ic+(kc<<2)>>1]|0;lc=b[ic+(kc<<2)+2>>1]|0;kc=lc<<16>>16;if(lc<<16>>16<0){lc=gc+6|0;mc=hc>>>0>lc>>>0?lc:hc;lc=jc+(mc>>>3)|0;nc=((fe(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(mc&7)>>>((kc+32|0)>>>0))+fc|0;oc=b[ic+(nc<<2)+2>>1]|0;pc=b[ic+(nc<<2)>>1]|0;qc=mc}else{oc=kc;pc=fc;qc=gc}gc=oc+qc|0;fc=hc>>>0>gc>>>0?gc:hc;c[s>>2]=fc;gc=c[676224+(pc<<2)>>2]|0;c[n+(cc<<2)>>2]=gc;kc=jc+(fc>>>3)|0;mc=(fe(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0)<<(fc&7)>>>26;kc=b[ic+(mc<<2)>>1]|0;nc=b[ic+(mc<<2)+2>>1]|0;mc=nc<<16>>16;if(nc<<16>>16<0){nc=fc+6|0;lc=hc>>>0>nc>>>0?nc:hc;nc=jc+(lc>>>3)|0;jc=((fe(d[nc]|d[nc+1|0]<<8|d[nc+2|0]<<16|d[nc+3|0]<<24|0)|0)<<(lc&7)>>>((mc+32|0)>>>0))+kc|0;rc=b[ic+(jc<<2)+2>>1]|0;sc=b[ic+(jc<<2)>>1]|0;tc=lc}else{rc=mc;sc=kc;tc=fc}fc=rc+tc|0;c[s>>2]=hc>>>0>fc>>>0?fc:hc;hc=c[676224+(sc<<2)>>2]|0;c[o+(cc<<2)>>2]=hc;dc=hc;ec=gc}}while(0);gc=cc+1|0;if((gc|0)<4){ac=ec;bc=dc;cc=gc}else{break}}uc=xb;vc=vb;wc=dc;xc=ec;yc=c[W>>2]|0;zc=c[ha>>2]|0;break};case 2:case 6:{if(Y){cc=c[ea>>2]|0;bc=c[s>>2]|0;ac=c[A>>2]|0;_b=c[w>>2]|0;Zb=_b+(bc>>>3)|0;$b=(fe(d[Zb]|d[Zb+1|0]<<8|d[Zb+2|0]<<16|d[Zb+3|0]<<24|0)|0)<<(bc&7)>>>26;Zb=b[cc+($b<<2)>>1]|0;ib=b[cc+($b<<2)+2>>1]|0;$b=ib<<16>>16;if(ib<<16>>16<0){ib=bc+6|0;ka=ac>>>0>ib>>>0?ib:ac;ib=_b+(ka>>>3)|0;nb=((fe(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)|0)<<(ka&7)>>>(($b+32|0)>>>0))+Zb|0;Ac=b[cc+(nb<<2)+2>>1]|0;Bc=b[cc+(nb<<2)>>1]|0;Cc=ka}else{Ac=$b;Bc=Zb;Cc=bc}bc=Ac+Cc|0;Zb=ac>>>0>bc>>>0?bc:ac;c[s>>2]=Zb;bc=c[676224+(Bc<<2)>>2]|0;c[W>>2]=bc;$b=_b+(Zb>>>3)|0;ka=(fe(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(Zb&7)>>>26;$b=b[cc+(ka<<2)>>1]|0;nb=b[cc+(ka<<2)+2>>1]|0;ka=nb<<16>>16;if(nb<<16>>16<0){nb=Zb+6|0;ib=ac>>>0>nb>>>0?nb:ac;nb=_b+(ib>>>3)|0;_b=((fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(ib&7)>>>((ka+32|0)>>>0))+$b|0;Dc=b[cc+(_b<<2)+2>>1]|0;Ec=b[cc+(_b<<2)>>1]|0;Fc=ib}else{Dc=ka;Ec=$b;Fc=Zb}Zb=Dc+Fc|0;c[s>>2]=ac>>>0>Zb>>>0?Zb:ac;Gc=bc;Hc=c[676224+(Ec<<2)>>2]|0}else{bc=c[s>>2]|0;ac=c[A>>2]|0;Zb=c[w>>2]|0;$b=Zb+(bc>>>3)|0;ka=(fe(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(bc&7)>>>26;$b=bc+6|0;bc=ac>>>0>$b>>>0?$b:ac;c[s>>2]=bc;$b=a[1049840+ka|0]|0;c[W>>2]=$b;ka=Zb+(bc>>>3)|0;Zb=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(bc&7)>>>26;ka=bc+6|0;c[s>>2]=ac>>>0>ka>>>0?ka:ac;Gc=$b;Hc=a[1049840+Zb|0]|0}c[ha>>2]=Hc;Zb=(a[Yb]|0)==2;uc=Zb?xb:Nb;vc=Zb?vb:yb;wc=Zb?Hc:xb;xc=Zb?Gc:vb;yc=Gc;zc=Hc;break};case 3:{c[W>>2]=vb;c[ha>>2]=xb;uc=Nb;vc=yb;wc=xb;xc=vb;yc=vb;zc=xb;break};case 4:{c[W>>2]=yb;c[ha>>2]=Nb;uc=xb;vc=vb;wc=Nb;xc=yb;yc=yb;zc=Nb;break};default:{c[W>>2]=0;c[ha>>2]=0;uc=Nb;vc=yb;wc=xb;xc=vb;yc=0;zc=0}}Zb=Rb<<1;$b=Qb<<1;ac=yc&255;ka=zc&255;bc=0;ib=Xb;while(1){_b=(ba((bc>>1)+Zb|0,c[D>>2]|0)|0)+(bc&1|$b)|0;if((a[ib+Sb|0]|0)==7){a[(c[M>>2]|0)+(_b<<1)|0]=c[n+(bc<<2)>>2];a[(c[M>>2]|0)+(_b<<1)+1|0]=c[o+(bc<<2)>>2]}else{a[(c[M>>2]|0)+(_b<<1)|0]=ac;a[(c[M>>2]|0)+(_b<<1)+1|0]=ka}_b=bc+1|0;if((_b|0)>=4){break}bc=_b;ib=c[$>>2]|0}if((c[ga>>2]|0)!=0){if((a[(c[$>>2]|0)+Sb|0]|0)==7){ib=(c[L>>2]|0)+yc+(c[V>>2]|0)+(c[T>>2]|0)|0;bc=((ib|0)>0?2:1)+ib>>2;c[W>>2]=bc;ib=(c[N>>2]|0)+zc+(c[aa>>2]|0)+(c[fa>>2]|0)|0;Xb=((ib|0)>0?2:1)+ib>>2;c[ha>>2]=Xb;Ic=bc;Jc=Xb}else{Ic=yc;Jc=zc}Xb=Ic>>1|Ic&1;c[W>>2]=Xb;bc=Jc>>1|Jc&1;c[ha>>2]=bc;ib=(ba(c[da>>2]|0,Rb)|0)+Qb|0;a[(c[X>>2]|0)+(ib<<1)|0]=Xb;a[(c[X>>2]|0)+(ib<<1)+1|0]=bc;Tb=uc;Ub=vc;Vb=wc;Wb=xc;break}if((c[S>>2]|0)!=0){if((a[(c[$>>2]|0)+Sb|0]|0)==7){bc=(c[L>>2]|0)+yc|0;ib=((bc|0)>0)+bc>>1;c[W>>2]=ib;bc=(c[N>>2]|0)+zc|0;Xb=((bc|0)>0)+bc>>1;c[ha>>2]=Xb;bc=(c[T>>2]|0)+(c[V>>2]|0)|0;Yb=((bc|0)>0)+bc>>1;c[L>>2]=Yb;bc=(c[fa>>2]|0)+(c[aa>>2]|0)|0;_b=((bc|0)>0)+bc>>1;Kc=ib;Lc=Yb;Mc=_b&255;Nc=_b;Oc=Xb&255}else{c[L>>2]=yc;Kc=yc;Lc=yc;Mc=ka;Nc=zc;Oc=ka}c[N>>2]=Nc;Xb=Kc>>1|Kc&1;c[W>>2]=Xb;_b=Lc>>1|Lc&1;c[L>>2]=_b;Yb=(ba(c[da>>2]|0,Zb)|0)+Qb|0;a[(c[X>>2]|0)+(Yb<<1)|0]=Xb;a[(c[X>>2]|0)+(Yb<<1)+1|0]=Oc;Xb=(c[da>>2]|0)+Yb|0;a[(c[X>>2]|0)+(Xb<<1)|0]=_b;a[(c[X>>2]|0)+(Xb<<1)+1|0]=Mc;Tb=uc;Ub=vc;Vb=wc;Wb=xc;break}Xb=(ba(Zb,c[da>>2]|0)|0)+$b|0;a[(c[X>>2]|0)+(Xb<<1)|0]=ac;a[(c[X>>2]|0)+(Xb<<1)+1|0]=ka;Xb=$b|1;_b=(ba(Zb,c[da>>2]|0)|0)+Xb|0;if((a[(c[$>>2]|0)+Sb|0]|0)==7){a[(c[X>>2]|0)+(_b<<1)|0]=c[L>>2];a[(c[X>>2]|0)+(_b<<1)+1|0]=c[N>>2]}else{a[(c[X>>2]|0)+(_b<<1)|0]=ac;a[(c[X>>2]|0)+(_b<<1)+1|0]=ka}_b=Zb|1;Yb=(ba(_b,c[da>>2]|0)|0)+$b|0;if((a[(c[$>>2]|0)+Sb|0]|0)==7){a[(c[X>>2]|0)+(Yb<<1)|0]=c[V>>2];a[(c[X>>2]|0)+(Yb<<1)+1|0]=c[aa>>2]}else{a[(c[X>>2]|0)+(Yb<<1)|0]=ac;a[(c[X>>2]|0)+(Yb<<1)+1|0]=ka}Yb=(ba(_b,c[da>>2]|0)|0)+Xb|0;if((a[(c[$>>2]|0)+Sb|0]|0)==7){a[(c[X>>2]|0)+(Yb<<1)|0]=c[T>>2];a[(c[X>>2]|0)+(Yb<<1)+1|0]=c[fa>>2];Tb=uc;Ub=vc;Vb=wc;Wb=xc;break}else{a[(c[X>>2]|0)+(Yb<<1)|0]=ac;a[(c[X>>2]|0)+(Yb<<1)+1|0]=ka;Tb=uc;Ub=vc;Vb=wc;Wb=xc;break}}else{Tb=Nb;Ub=yb;Vb=xb;Wb=vb}}while(0);Sb=Ob+1|0;if((Sb|0)<4){vb=Wb;xb=Vb;yb=Ub;Nb=Tb;Ob=Sb}else{break}}Ob=la+1|0;Pc=c[y>>2]|0;if((Ob|0)<(Pc|0)){la=Ob;kb=Wb;ub=Vb;hb=Ub;wb=Tb}else{break}}Qc=Wb;Rc=Vb;Sc=Ub;Tc=Tb;Uc=Pc;Vc=c[Z>>2]|0}else{Qc=ia;Rc=ja;Sc=ca;Tc=mb;Uc=lb;Vc=jb}wb=R+1|0;if((wb|0)<(Vc|0)){R=wb;ia=Qc;ja=Rc;ca=Sc;mb=Tc;lb=Uc;jb=Vc}else{break j}}yDb(c[K>>2]|0,16,2241032,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break a}}while(0);$=c[E>>2]|0;l:do{if(((c[F>>2]|0)-1|0)>0&($|0)>0){jb=u+30004|0;lb=u+28388|0;mb=0;ca=$;m:while(1){ja=c[s>>2]|0;ia=d[(c[w>>2]|0)+(ja>>>3)|0]<<(ja&7)>>>7;R=((ja|0)<(c[A>>2]|0))+ja|0;c[s>>2]=R;ja=0;Z=0;y=0;X=ia&1^1;ia=0;fa=R;while(1){if((y|0)==4129){R=c[w>>2]|0;T=d[R+(fa>>>3)|0]<<(fa&7)>>>7;da=c[A>>2]|0;aa=((fa|0)<(da|0))+fa|0;c[s>>2]=aa;Wc=T&1;Xc=aa;Yc=da;Zc=R}else{Wc=X^1;Xc=fa;Yc=c[A>>2]|0;Zc=c[w>>2]|0}R=c[jb>>2]|0;da=Zc+(Xc>>>3)|0;aa=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Xc&7)>>>26;da=b[R+(aa<<2)>>1]|0;T=b[R+(aa<<2)+2>>1]|0;aa=T<<16>>16;if(T<<16>>16<0){T=Xc+6|0;V=Yc>>>0>T>>>0?T:Yc;T=Zc+(V>>>3)|0;N=((fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(V&7)>>>((aa+32|0)>>>0))+da|0;_c=b[R+(N<<2)+2>>1]|0;$c=b[R+(N<<2)>>1]|0;ad=V}else{_c=aa;$c=da;ad=Xc}da=_c+ad|0;aa=Yc>>>0>da>>>0?da:Yc;c[s>>2]=aa;da=$c+1|0;if((da|0)==34){V=Zc+(aa>>>3)|0;N=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(aa&7)>>>20;V=aa+12|0;c[s>>2]=Yc>>>0>V>>>0?V:Yc;bd=N+34|0}else{bd=da}da=bd+Z|0;cd=((Wc|0)==0?bd:0)+ja|0;if((bd|0)>0){N=Wc+mb&255;V=ia;aa=0;while(1){if((V|0)>=(c[E>>2]|0)){break m}R=(c[H>>2]|0)+(c[(c[lb>>2]|0)+(V<<2)>>2]<<2)+3|0;if((d[R]|0)==(mb|0)){a[R]=N;dd=aa+1|0}else{dd=aa}R=V+1|0;if((dd|0)<(bd|0)){V=R;aa=dd}else{ed=R;break}}}else{ed=ia}if((da|0)>=(ca|0)){break}aa=c[s>>2]|0;if(((c[x>>2]|0)-aa|0)>0){ja=cd;Z=da;y=bd;X=Wc;ia=ed;fa=aa}else{break}}ca=ca-cd|0;mb=mb+1|0;if(!((mb|0)<((c[F>>2]|0)-1|0)&(ca|0)>0)){break l}}yDb(c[K>>2]|0,16,2228904,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break a}}while(0);c[u+26844>>2]=c[u+27612>>2];E=c[s>>2]|0;$=c[A>>2]|0;ca=c[w>>2]|0;mb=ca+(E>>>3)|0;lb=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(E&7)>>>28;mb=E+4|0;E=$>>>0>mb>>>0?mb:$;c[s>>2]=E;mb=ca+(E>>>3)|0;ca=d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0;mb=E+4|0;c[s>>2]=$>>>0>mb>>>0?mb:$;$=E4a(v,r,c[v+28400+(lb*20|0)+4>>2]|0,0,0,0)|0;n:do{if(($|0)>=0){lb=(fe(ca|0)|0)<<(E&7)>>>28;F4a(v,0,c[u+672>>2]|0,c[u+680>>2]|0);mb=v+28400+(lb*20|0)+4|0;lb=E4a(v,r,c[mb>>2]|0,0,1,$)|0;if((lb|0)<0){break}jb=E4a(v,r,c[mb>>2]|0,0,2,lb)|0;if((jb|0)<0){break}if((c[(c[K>>2]|0)+88>>2]&8192|0)==0){lb=u+676|0;mb=u+684|0;F4a(v,c[u+696>>2]|0,c[lb>>2]|0,c[mb>>2]|0);F4a(v,c[u+700>>2]|0,c[lb>>2]|0,c[mb>>2]|0)}mb=c[s>>2]|0;lb=c[A>>2]|0;fa=c[w>>2]|0;ia=fa+(mb>>>3)|0;X=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(mb&7)>>>28;ia=mb+4|0;mb=lb>>>0>ia>>>0?ia:lb;c[s>>2]=mb;ia=fa+(mb>>>3)|0;fa=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(mb&7)>>>28;ia=mb+4|0;c[s>>2]=lb>>>0>ia>>>0?ia:lb;lb=v+28720+(X*20|0)|0;ia=v+28720+(fa*20|0)|0;c[l+4>>2]=lb;c[m+4>>2]=ia;c[l+8>>2]=lb;c[m+8>>2]=ia;c[l+12>>2]=lb;c[m+12>>2]=ia;c[l+16>>2]=lb;c[m+16>>2]=ia;c[l+20>>2]=lb;c[m+20>>2]=ia;ia=v+29040+(X*20|0)|0;lb=v+29040+(fa*20|0)|0;c[l+24>>2]=ia;c[m+24>>2]=lb;c[l+28>>2]=ia;c[m+28>>2]=lb;c[l+32>>2]=ia;c[m+32>>2]=lb;c[l+36>>2]=ia;c[m+36>>2]=lb;c[l+40>>2]=ia;c[m+40>>2]=lb;c[l+44>>2]=ia;c[m+44>>2]=lb;c[l+48>>2]=ia;c[m+48>>2]=lb;c[l+52>>2]=ia;c[m+52>>2]=lb;c[l+56>>2]=ia;c[m+56>>2]=lb;lb=v+29360+(X*20|0)|0;ia=v+29360+(fa*20|0)|0;c[l+60>>2]=lb;c[m+60>>2]=ia;c[l+64>>2]=lb;c[m+64>>2]=ia;c[l+68>>2]=lb;c[m+68>>2]=ia;c[l+72>>2]=lb;c[m+72>>2]=ia;c[l+76>>2]=lb;c[m+76>>2]=ia;c[l+80>>2]=lb;c[m+80>>2]=ia;c[l+84>>2]=lb;c[m+84>>2]=ia;c[l+88>>2]=lb;c[m+88>>2]=ia;c[l+92>>2]=lb;c[m+92>>2]=ia;c[l+96>>2]=lb;c[m+96>>2]=ia;c[l+100>>2]=lb;c[m+100>>2]=ia;c[l+104>>2]=lb;c[m+104>>2]=ia;c[l+108>>2]=lb;c[m+108>>2]=ia;ia=v+29680+(X*20|0)|0;X=v+29680+(fa*20|0)|0;fa=28;while(1){c[l+(fa<<2)>>2]=ia;c[m+(fa<<2)>>2]=X;lb=fa+1|0;if((lb|0)<64){fa=lb}else{fd=jb;gd=1;break}}while(1){if((gd|0)>=64){break}jb=E4a(v,r,c[(c[l+(gd<<2)>>2]|0)+4>>2]|0,gd,0,fd)|0;if((jb|0)<0){break n}fa=m+(gd<<2)|0;X=E4a(v,r,c[(c[fa>>2]|0)+4>>2]|0,gd,1,jb)|0;if((X|0)<0){break n}jb=E4a(v,r,c[(c[fa>>2]|0)+4>>2]|0,gd,2,X)|0;if((jb|0)<0){break n}else{fd=jb;gd=gd+1|0}}jb=u+20|0;X=u+576|0;fa=u+704|0;ia=u+28|0;lb=c[jb>>2]|0;if((c[X>>2]|0)==0){c[fa>>2]=ba(c[(c[_>>2]|0)+32>>2]|0,lb-1|0)|0;c[u+708>>2]=ba(c[(c[_>>2]|0)+36>>2]|0,(lb>>((c[ia>>2]|0)!=0))-1|0)|0;c[u+712>>2]=ba(c[(c[_>>2]|0)+40>>2]|0,(lb>>((c[ia>>2]|0)!=0))-1|0)|0}else{c[fa>>2]=0;c[u+708>>2]=0;c[u+712>>2]=0}fa=u+580|0;c[fa>>2]=0;mb=u+636|0;y=c[mb>>2]|0;if((y|0)>0){Z=u+448|0;ja=u+44|0;aa=u+32|0;V=u+16|0;N=u+24|0;R=u+632|0;T=u+620|0;L=u+408|0;W=u+428|0;ha=u+424|0;S=u+420|0;ga=u+416|0;M=u+216|0;D=q|0;ea=q+4|0;Y=q+8|0;G=q+12|0;ma=0;wb=y;while(1){do{if((wb|0)>(ma|0)){y=0;hb=-559038737;ub=-559038737;while(1){kb=c[_>>2]|0;la=c[kb+(y<<2)>>2]|0;Q=c[v+704+(y<<2)>>2]|0;Ob=c[(c[ja>>2]|0)+(y<<2)>>2]|0;Nb=c[(c[aa>>2]|0)+(y<<2)>>2]|0;yb=c[kb+32+(y<<2)>>2]|0;kb=c[V>>2]|0;xb=(y|0)!=0;if(xb){hd=0;id=c[jb>>2]>>((c[ia>>2]|0)!=0);jd=kb>>((c[N>>2]|0)!=0);kd=ma}else{vb=(c[ia>>2]|0)!=0|0;hd=vb;id=c[jb>>2]|0;jd=kb;kd=ma<<vb}vb=xb&1;kb=c[v+716+(vb<<2)>>2]|0;Cb=kd+1+hd|0;Sb=c[(xb?R:T)>>2]|0;xb=c[v+672+(vb<<2)>>2]|0;Qb=c[v+680+(vb<<2)>>2]|0;vb=c[v+692+(y<<2)>>2]|0;Rb=(c[X>>2]|0)==0?-yb|0:yb;if((kd|0)<(Cb|0)){yb=(Sb|0)>0;Pb=Qb-1|0;Yb=(Rb|0)<0;Xb=-(Rb<<3)|0;_b=v+30464+(y<<7)|0;ib=v+30080+(y<<7)|0;bc=Rb+1|0;cc=kd;nb=hb;gc=ub;while(1){if(yb){hc=cc<<2;fc=0;kc=nb;mc=gc;while(1){lc=fc<<2;jc=kc;ic=mc;nc=0;while(1){ld=(d[943024+(nc<<1)|0]|0)+lc|0;md=(d[943025+(nc<<1)|0]|0)+hc|0;nd=(ba(md,xb)|0)+ld|0;od=nd+vb|0;o:do{if((ld|0)<(xb|0)&(md|0)<(Qb|0)){pd=md<<3;qd=ld<<3;rd=(ba(pd,Rb)|0)+qd|0;sd=a[(c[H>>2]|0)+(od<<2)+2|0]|0;if((sd<<24>>24|0)==5|(sd<<24>>24|0)==6){td=Nb}else if((sd<<24>>24|0)==8){ud=rd+Q|0;cf[c[M>>2]&1023](la+ud|0,Ob+ud|0,Rb,8);vd=ic;wd=jc;break}else{td=Ob}ud=rd+Q|0;do{if((sd<<24>>24|0)==5|(sd<<24>>24|0)==1|(sd<<24>>24|0)==0){xd=ic;yd=jc;zd=0;Ad=td+ud|0;Bd=sd;O=315}else{rd=a[kb+(nd<<1)|0]|0;Dd=a[kb+(nd<<1)+1|0]|0;Ed=rd>>1;Fd=Ed+qd|0;Gd=Dd>>1;Hd=Gd+pd|0;Id=Dd<<1&2|rd&1;Jd=td+(Ed+ud+(ba(Gd,Rb)|0))|0;if((Hd|Fd|0)>-1&(Fd+9|0)<(jd|0)&(Hd+9|0)<(id|0)){Kd=Jd;Ld=Id;Md=Dd;Nd=rd;O=316;break}Gd=c[U>>2]|0;if(Yb){Od=Gd+Xb|0}else{Od=Gd}Ne[c[L>>2]&127](Od,Jd,Rb,Rb,9,9,Fd,Hd,jd,id);xd=rd;yd=Dd;zd=Id;Ad=Od;Bd=a[(c[H>>2]|0)+(od<<2)+2|0]|0;O=315}}while(0);if((O|0)==315){O=0;if(Bd<<24>>24==1){Pd=yd;Qd=xd}else{Kd=Ad;Ld=zd;Md=yd;Nd=xd;O=316}}do{if((O|0)==316){O=0;if((Ld|0)==3){pd=Md^Nd;le[c[ga>>2]&1023](la+ud|0,Kd+(pd>>>31)|0,Kd+(bc+(pd>>31))|0,Rb,8);Pd=Md;Qd=Nd;break}else{cf[c[v+344+(Ld<<2)>>2]&1023](la+ud|0,Kd,Rb,8);Pd=Md;Qd=Nd;break}}}while(0);pd=c[H>>2]|0;qd=pd+(od<<2)|0;sd=d[pd+(od<<2)+3|0]|0;if((a[pd+(od<<2)+2|0]|0)==1){pd=0;while(1){Rd=v+26844+(y<<8)+(pd<<2)|0;Sd=c[Rd>>2]|0;Td=b[Sd>>1]|0;Id=Td&3;if((Id|0)==2){Dd=d[v+136+pd|0]|0;b[v+448+(Dd<<1)>>1]=ba(b[v+30080+(sd*768|0)+(y<<7)+(Dd<<1)>>1]|0,Td>>2)|0;c[Rd>>2]=Sd+2;Ud=pd}else if((Id|0)==0){O=321;break}else if((Id|0)==1){c[Rd>>2]=Sd+2;Id=(Td>>>2&127)+pd|0;if((Id|0)>63){O=325;break}Dd=d[v+136+Id|0]|0;b[v+448+(Dd<<1)>>1]=ba(b[v+30080+(sd*768|0)+(y<<7)+(Dd<<1)>>1]|0,Td>>9)|0;Ud=Id}else{break}Id=Ud+1|0;if((Id|0)<64){pd=Id}else{O=329;break}}do{if((O|0)==321){O=0;pd=Td-1|0;if((pd|0)<4){c[Rd>>2]=Sd+2;O=329;break}else{b[Sd>>1]=pd&65535&-4;O=329;break}}else if((O|0)==325){O=0;yDb(c[K>>2]|0,16,2207824,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}}while(0);if((O|0)==329){O=0;b[Z>>1]=ba(b[ib>>1]|0,b[qd>>1]|0)|0}Xe[c[S>>2]&4095](la+ud|0,Rb,Z);vd=Qd;wd=Pd;break}else{Vd=0}while(1){Wd=v+26844+(y<<8)+(Vd<<2)|0;Xd=c[Wd>>2]|0;Yd=b[Xd>>1]|0;pd=Yd&3;if((pd|0)==0){O=332;break}else if((pd|0)==1){c[Wd>>2]=Xd+2;Id=(Yd>>>2&127)+Vd|0;if((Id|0)>63){O=336;break}Dd=d[v+136+Id|0]|0;b[v+448+(Dd<<1)>>1]=ba(b[v+30080+(sd*768|0)+384+(y<<7)+(Dd<<1)>>1]|0,Yd>>9)|0;Zd=Id}else if((pd|0)==2){pd=d[v+136+Vd|0]|0;b[v+448+(pd<<1)>>1]=ba(b[v+30080+(sd*768|0)+384+(y<<7)+(pd<<1)>>1]|0,Yd>>2)|0;c[Wd>>2]=Xd+2;Zd=Vd}else{_d=Vd;O=341;break}pd=Zd+1|0;if((pd|0)<64){Vd=pd}else{$d=Zd;O=340;break}}do{if((O|0)==332){O=0;sd=Yd-1|0;if((sd|0)<4){c[Wd>>2]=Xd+2;$d=Vd;O=340;break}else{b[Xd>>1]=sd&65535&-4;$d=Vd;O=340;break}}else if((O|0)==336){O=0;yDb(c[K>>2]|0,16,2207824,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}}while(0);if((O|0)==340){O=0;b[Z>>1]=ba(b[_b>>1]|0,b[qd>>1]|0)|0;_d=$d;O=341}do{if((O|0)==341){O=0;if((_d|0)!=0){break}Xe[c[W>>2]&4095](la+ud|0,Rb,Z);vd=Qd;wd=Pd;break o}}while(0);Xe[c[ha>>2]&4095](la+ud|0,Rb,Z);vd=Qd;wd=Pd}else{vd=ic;wd=jc}}while(0);od=nc+1|0;if((od|0)<16){jc=wd;ic=vd;nc=od}else{break}}nc=fc+1|0;if((nc|0)<(Sb|0)){fc=nc;kc=wd;mc=vd}else{ae=wd;be=vd;break}}}else{ae=nb;be=gc}if((c[z>>2]|0)==0){mc=cc<<2;kc=mc|3;D4a(v,y,mc-((cc|0)!=0)|0,(kc|0)>(Pb|0)?Pb:kc)}kc=cc+1|0;if((kc|0)<(Cb|0)){cc=kc;nb=ae;gc=be}else{ce=ae;de=be;break}}}else{ce=hb;de=ub}gc=y+1|0;if((gc|0)<3){y=gc;hb=ce;ub=de}else{break}}ub=c[ia>>2]|0;hb=ma+1|0;y=ba(32<<ub,hb)|0;da=c[jb>>2]|0;gc=((y|0)>(da|0)?da:y)-16|0;y=c[K>>2]|0;da=y+148|0;if((c[da>>2]|0)==0){ee=hb;break}nb=c[fa>>2]|0;c[fa>>2]=gc;if((c[X>>2]|0)==0){ge=(c[y+124>>2]|0)-gc|0}else{ge=nb}cc=ge>>ub;ub=c[_>>2]|0;c[D>>2]=ba(c[ub+32>>2]|0,ge)|0;c[ea>>2]=ba(c[ub+36>>2]|0,cc)|0;c[Y>>2]=ba(c[ub+40>>2]|0,cc)|0;TGb(G|0,0,20)|0;Se[c[da>>2]&511](y,ub,D,ge,3,gc-nb|0);ee=hb}else{ee=ma+1|0}}while(0);hb=c[mb>>2]|0;if((ee|0)<(hb|0)){ma=ee;wb=hb}else{break}}he=c[jb>>2]|0}else{he=lb}wb=he>>3;D4a(v,0,wb-1|0,wb);wb=c[jb>>2]>>((c[ia>>2]|0)!=0?4:3);D4a(v,1,wb-1|0,wb);wb=c[jb>>2]>>((c[ia>>2]|0)!=0?4:3);D4a(v,2,wb-1|0,wb);wb=c[K>>2]|0;ma=wb+124|0;mb=c[ma>>2]|0;D=wb+148|0;if((c[D>>2]|0)!=0){G=c[fa>>2]|0;c[fa>>2]=mb;if((c[X>>2]|0)==0){ie=(c[ma>>2]|0)-mb|0}else{ie=G}ma=ie>>c[ia>>2];Y=c[_>>2]|0;ea=q|0;c[ea>>2]=ba(c[Y+32>>2]|0,ie)|0;c[q+4>>2]=ba(c[Y+36>>2]|0,ma)|0;c[q+8>>2]=ba(c[Y+40>>2]|0,ma)|0;TGb(q+12|0,0,20)|0;Se[c[D>>2]&511](wb,Y,ea,ie,3,mb-G|0)}G=MCb(g,c[_>>2]|0)|0;if((G|0)<0){J=G;i=k;return J|0}c[h>>2]=1;G=c[j>>2]|0;mb=G+44|0;U0a(f,mb);ea=G+56|0;Y=T0a(mb,ea)|0;do{if((Y|0)<0){je=Y}else{if((c[G+68>>2]|0)==0){je=Y;break}mb=G+32|0;U0a(f,mb);je=T0a(mb,ea)|0}}while(0);U0a(f,ea);J=(je|0)<0?je:t;i=k;return J|0}}while(0);yDb(c[K>>2]|0,16,2217152,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}}while(0);Y0a(P,2147483647,0);KCb(c[_>>2]|0);J=-1;i=k;return J|0}function y4a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+60|0;d=c[b>>2]|0;$Db(d+652|0);$Db(d+688|0);$Db(d+28388|0);$Db(d+27612|0);$Db(d+32384|0);$Db(d+32388|0);$Db(d+716|0);$Db(d+720|0);$Db(d+32392|0);c[d+8>>2]=0;e=c[b>>2]|0;b=e+32|0;if((c[b>>2]|0)!=0){U0a(a,b)}b=e+44|0;if((c[b>>2]|0)!=0){U0a(a,b)}b=e+56|0;if((c[b>>2]|0)!=0){U0a(a,b)}JCb(d+56|0);JCb(d+44|0);JCb(d+32|0);if((c[c[a+64>>2]>>2]|0)!=0){return 0}a=d+28400|0;b=d+28720|0;e=d+29040|0;f=d+29360|0;g=d+29680|0;h=0;do{Q_(a+(h*20|0)|0);Q_(b+(h*20|0)|0);Q_(e+(h*20|0)|0);Q_(f+(h*20|0)|0);Q_(g+(h*20|0)|0);h=h+1|0;}while((h|0)<16);Q_(d+3e4|0);Q_(d+30020|0);Q_(d+30040|0);Q_(d+30060|0);return 0}function z4a(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;d=b+32|0;if((c[d>>2]|0)!=0){U0a(a,d)}d=b+44|0;if((c[d>>2]|0)!=0){U0a(a,d)}d=b+56|0;if((c[d>>2]|0)==0){return}U0a(a,d);return}function A4a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;g=e+60|0;h=c[g>>2]|0;j=h+56|0;c[j>>2]=ICb()|0;k=h+44|0;c[k>>2]=ICb()|0;l=ICb()|0;m=h+32|0;c[m>>2]=l;do{if((c[j>>2]|0)!=0){if((c[k>>2]|0)==0|(l|0)==0){break}c[(c[e+64>>2]|0)+4>>2]=1;c[h+12>>2]=(c[e+52>>2]|0)!=808669270;c[h>>2]=e;n=h+16|0;c[n>>2]=(c[e+120>>2]|0)+15&-16;o=h+20|0;c[o>>2]=(c[e+124>>2]|0)+15&-16;if((c[e+48>>2]|0)!=31){c[e+140>>2]=0}c[e+400>>2]=2;p=e+88|0;BFa(h+200|0,c[p>>2]|8388608);T3a(h+408|0,8);H4a(h+416|0,c[p>>2]|0);p=0;do{a[h+(p+72)|0]=p<<3&56|p>>>3;q=a[1075976+p|0]|0;a[h+(p+136)|0]=q<<3&56|(q&255)>>>3;p=p+1|0;}while((p|0)<64);TGb(h+588|0,-1|0,12)|0;p=h+24|0;q=h+28|0;_Ga(c[e+140>>2]|0,p,q);r=c[n>>2]|0;s=(r+31|0)/32|0;c[h+620>>2]=s;t=c[o>>2]|0;u=(t+31|0)/32|0;c[h+624>>2]=u;v=ba(s,u)|0;c[h+628>>2]=v;u=c[p>>2]|0;p=c[q>>2]|0;q=((r>>u)+31|0)/32|0;c[h+632>>2]=q;s=((t>>p)+31|0)/32|0;c[h+636>>2]=s;w=ba(q,s)|0;c[h+640>>2]=w;c[h+616>>2]=(w<<1)+v;c[h+644>>2]=v;c[h+648>>2]=w+v;v=(r+15|0)/16|0;c[h+660>>2]=v;w=(t+15|0)/16|0;c[h+664>>2]=w;c[h+656>>2]=ba(v,w)|0;w=(r|0)/8|0;c[h+672>>2]=w;r=(t|0)/8|0;c[h+680>>2]=r;t=w>>u;c[h+676>>2]=t;u=r>>p;c[h+684>>2]=u;p=ba(r,w)|0;w=ba(t,u)|0;c[h+668>>2]=(w<<1)+p;c[h+696>>2]=p;c[h+700>>2]=w+p;a:do{if((c[h+8>>2]|0)==0){p=h+724|0;w=h+852|0;u=0;do{b[p+(u<<1)>>1]=b[131744+(u<<1)>>1]|0;c[w+(u<<2)>>2]=c[131872+(u<<2)>>2];a[h+(u+1108)|0]=b[131296+(u<<1)>>1];a[h+(u+1172)|0]=b[131424+(u<<1)>>1];a[h+(u+1236)|0]=b[131552+(u<<1)>>1];a[h+(u+52892)|0]=a[131680+u|0]|0;u=u+1|0;}while((u|0)<64);a[h+25684|0]=1;a[h+25690|0]=63;b[h+26076>>1]=0;b[h+26074>>1]=0;a[h+25685|0]=1;a[h+25754|0]=63;b[h+26204>>1]=1;b[h+26202>>1]=1;a[h+25686|0]=1;a[h+25818|0]=63;b[h+26332>>1]=1;b[h+26330>>1]=1;a[h+25687|0]=1;a[h+25882|0]=63;b[h+26460>>1]=2;b[h+26458>>1]=2;a[h+25688|0]=1;a[h+25946|0]=63;b[h+26588>>1]=2;b[h+26586>>1]=2;a[h+25689|0]=1;a[h+26010|0]=63;b[h+26716>>1]=2;b[h+26714>>1]=2;u=h+28400|0;w=h+28720|0;p=h+29040|0;t=h+29360|0;r=h+29680|0;v=0;do{N_(u+(v*20|0)|0,11,32,1407986+(v<<7)|0,4,2,1407984+(v<<7)|0,4,2,0,0,0,0)|0;N_(w+(v*20|0)|0,11,32,1868714+(v<<7)|0,4,2,1868712+(v<<7)|0,4,2,0,0,0,0)|0;N_(p+(v*20|0)|0,11,32,1866666+(v<<7)|0,4,2,1866664+(v<<7)|0,4,2,0,0,0,0)|0;N_(t+(v*20|0)|0,11,32,1864618+(v<<7)|0,4,2,1864616+(v<<7)|0,4,2,0,0,0,0)|0;N_(r+(v*20|0)|0,11,32,1862570+(v<<7)|0,4,2,1862568+(v<<7)|0,4,2,0,0,0,0)|0;v=v+1|0;}while((v|0)<16)}else{v=h+28400|0;r=h+32412|0;t=h+28720|0;p=h+29040|0;w=h+29360|0;u=h+29680|0;s=0;while(1){if((s|0)>=16){break a}if((N_(v+(s*20|0)|0,11,32,r+(s<<8)+4|0,8,4,r+(s<<8)|0,8,4,0,0,0,0)|0)<0){break}q=s+16|0;if((N_(t+(s*20|0)|0,11,32,r+(q<<8)+4|0,8,4,r+(q<<8)|0,8,4,0,0,0,0)|0)<0){break}q=s+32|0;if((N_(p+(s*20|0)|0,11,32,r+(q<<8)+4|0,8,4,r+(q<<8)|0,8,4,0,0,0,0)|0)<0){break}q=s+48|0;if((N_(w+(s*20|0)|0,11,32,r+(q<<8)+4|0,8,4,r+(q<<8)|0,8,4,0,0,0,0)|0)<0){break}q=s+64|0;if((N_(u+(s*20|0)|0,11,32,r+(q<<8)+4|0,8,4,r+(q<<8)|0,8,4,0,0,0,0)|0)<0){break}else{s=s+1|0}}yDb(e,8,2046256,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;x=-1;i=f;return x|0}}while(0);N_(h+3e4|0,6,34,429282,4,2,429280,4,2,0,0,0,0)|0;N_(h+30020|0,5,30,1047362,4,2,1047360,4,2,0,0,0,0)|0;N_(h+30040|0,3,8,676953,2,1,676952,2,1,0,0,0,0)|0;N_(h+30060|0,6,63,676097,2,1,676096,2,1,0,0,0,0)|0;o=c[g>>2]|0;n=o;s=c[o+672>>2]|0;r=c[o+680>>2]|0;u=c[o+676>>2]|0;w=c[o+684>>2]|0;p=o+616|0;t=o+652|0;c[t>>2]=cEb(c[p>>2]|0)|0;v=o+668|0;q=o+688|0;c[q>>2]=cEb(c[v>>2]<<2)|0;y=o+28388|0;c[y>>2]=cEb(c[v>>2]<<2)|0;z=o+27612|0;c[z>>2]=cEb(c[v>>2]<<7)|0;v=o+716|0;c[v>>2]=cEb(ba(s<<1,r)|0)|0;r=o+720|0;c[r>>2]=cEb(ba(u<<1,w)|0)|0;w=o+32384|0;c[w>>2]=cEb(c[p>>2]<<6)|0;p=cEb((c[o+656>>2]|0)+1|0)|0;c[o+32388>>2]=p;do{if((c[t>>2]|0)!=0){if((c[q>>2]|0)==0){break}if((c[z>>2]|0)==0){break}if((c[y>>2]|0)==0){break}u=c[w>>2]|0;if((u|0)==0|(p|0)==0){break}if((c[v>>2]|0)==0){break}if((c[r>>2]|0)==0){break}s=o+632|0;A=o+620|0;B=o+636|0;C=o+624|0;D=0;E=0;while(1){F=(E|0)!=0;G=c[(F?s:A)>>2]|0;H=c[(F?B:C)>>2]|0;I=F&1;F=c[n+672+(I<<2)>>2]|0;J=c[n+680+(I<<2)>>2]|0;do{if((H|0)>0){I=n+692+(E<<2)|0;if((G|0)<=0){K=D;break}L=G<<4;M=D;N=0;while(1){O=N<<2;P=M;Q=0;while(1){R=Q<<2;S=P;T=0;while(1){U=(d[943024+(T<<1)|0]|0)+R|0;V=(d[943025+(T<<1)|0]|0)+O|0;if((U|0)<(F|0)&(V|0)<(J|0)){c[u+(S<<2)>>2]=(ba(V,F)|0)+U+(c[I>>2]|0)}else{c[u+(S<<2)>>2]=-1}U=T+1|0;if((U|0)<16){S=S+1|0;T=U}else{break}}T=Q+1|0;if((T|0)<(G|0)){P=P+16|0;Q=T}else{break}}Q=N+1|0;if((Q|0)<(H|0)){M=M+L|0;N=Q}else{break}}K=(ba(L,H)|0)+D|0}else{K=D}}while(0);H=E+1|0;if((H|0)<3){D=K;E=H}else{x=0;break}}i=f;return x|0}}while(0);y4a(e)|0;x=-1;i=f;return x|0}}while(0);JCb(j);JCb(k);JCb(m);x=-12;i=f;return x|0}function B4a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;f=c[a+60>>2]|0;g=b+8|0;h=c[g>>2]|0;j=b+16|0;k=c[j>>2]|0;l=b|0;b=(c[l>>2]|0)+(h>>>3)|0;m=(fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(h&7)>>>8;b=h+24|0;c[g>>2]=k>>>0>b>>>0?b:k;k=f+4|0;c[k>>2]=m;b=a;yDb(b,48,2092792,(h=i,i=i+8|0,c[h>>2]=m,h)|0);i=h;if((c[k>>2]|0)<197120){c[f+576>>2]=1;yDb(b,48,2087528,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}m=c[g>>2]|0;n=c[j>>2]|0;o=c[l>>2]|0;p=o+(m>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>16;p=m+16|0;c[g>>2]=n>>>0>p>>>0?p:n;n=q<<4;q=f+16|0;c[q>>2]=n;p=c[g>>2]|0;m=c[j>>2]|0;r=o+(p>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(p&7)>>>16;r=p+16|0;c[g>>2]=m>>>0>r>>>0?r:m;m=s<<4;s=f+20|0;c[s>>2]=m;f=c[g>>2]|0;r=c[j>>2]|0;if((c[k>>2]|0)>197119){p=o+(f>>>3)|0;t=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(f&7)>>>8;p=f+24|0;u=r>>>0>p>>>0?p:r;c[g>>2]=u;p=o+(u>>>3)|0;v=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(u&7)>>>8;p=u+24|0;u=r>>>0>p>>>0?p:r;c[g>>2]=u;p=o+(u>>>3)|0;w=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(u&7)>>>24;p=u+8|0;u=r>>>0>p>>>0?p:r;c[g>>2]=u;p=o+(u>>>3)|0;x=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(u&7)>>>24;p=u+8|0;u=r>>>0>p>>>0?p:r;c[g>>2]=u;y=t;z=v;A=w;B=x;C=u}else{y=n;z=m;A=0;B=0;C=f}f=o+(C>>>3)|0;m=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(C&7);f=C+16|0;C=r>>>0>f>>>0?f:r;c[g>>2]=C;f=o+(C>>>3)|0;n=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(C&7)>>>16;f=C+16|0;C=r>>>0>f>>>0?f:r;c[g>>2]=C;f=n|m&-65536;n=o+(C>>>3)|0;u=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7);n=C+16|0;C=r>>>0>n>>>0?n:r;c[g>>2]=C;n=o+(C>>>3)|0;x=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7)>>>16;n=C+16|0;C=r>>>0>n>>>0?n:r;c[g>>2]=C;n=x|u&-65536;do{if((f|0)==0|(n|0)==0){D=C;E=r;F=o}else{if((u|m|0)>=0){iFb(a+104|0,a+108|0,n,(n|0)<0|0?-1:0,f,(f|0)<0|0?-1:0,1073741824,0)|0;D=c[g>>2]|0;E=c[j>>2]|0;F=c[l>>2]|0;break}yDb(b,16,2082888,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;G=-1094995529;i=e;return G|0}}while(0);f=F+(D>>>3)|0;n=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(D&7)>>>8;f=D+24|0;D=E>>>0>f>>>0?f:E;c[g>>2]=D;f=F+(D>>>3)|0;F=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(D&7)>>>8;f=D+24|0;c[g>>2]=E>>>0>f>>>0?f:E;if(!((n|0)==0|(F|0)==0)){iFb(a+224|0,a+228|0,n,0,F,0,1073741824,0)|0}F=c[g>>2]|0;n=c[j>>2]|0;if((c[k>>2]|0)<197120){j=F+5|0;E=n>>>0>j>>>0?j:n;c[g>>2]=E;H=E}else{H=F}F=c[l>>2]|0;l=F+(H>>>3)|0;E=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(H&7)>>>24;l=H+8|0;H=(n>>>0>l>>>0?l:n)+24|0;l=(n>>>0>H>>>0?H:n)+6|0;H=n>>>0>l>>>0?l:n;c[g>>2]=H;do{if((c[k>>2]|0)>197119){l=H+5|0;j=n>>>0>l>>>0?l:n;c[g>>2]=j;l=F+(j>>>3)|0;f=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(j&7)>>>30;l=j+2|0;j=n>>>0>l>>>0?l:n;c[g>>2]=j;c[a+140>>2]=c[187376+(f<<2)>>2];if((f|0)!=1){f=j+3|0;c[g>>2]=n>>>0>f>>>0?f:n;break}yDb(b,16,2077208,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;G=-1094995529;i=e;return G|0}}while(0);h=c[q>>2]|0;q=c[s>>2]|0;do{if((y|0)<=(h|0)&(y|0)>(h-16|0)){if(!((z|0)<=(q|0)&(z|0)>(q-16|0)&(A|0)==0&(B|0)==(q-z|0))){I=20;break}J=V$a(a,y,z)|0}else{I=20}}while(0);if((I|0)==20){J=V$a(a,h,q)|0}if((J|0)<0){G=J;i=e;return G|0}do{if((E|0)==1){c[a+384>>2]=4}else if((E|0)==2){c[a+384>>2]=5}else{if((E-1|0)>>>0<2>>>0){break}else{G=0}i=e;return G|0}}while(0);c[a+392>>2]=5;c[a+388>>2]=1;G=0;i=e;return G|0}function C4a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;g=i;h=c[e+60>>2]|0;j=h+4|0;k=f+8|0;do{if((c[j>>2]|0)>197119){l=c[k>>2]|0;m=f+16|0;n=c[m>>2]|0;o=f|0;p=c[o>>2]|0;q=p+(l>>>3)|0;r=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(l&7)>>>29;q=l+3|0;l=n>>>0>q>>>0?q:n;c[k>>2]=l;a:do{if((r|0)!=0){q=32-r|0;s=0;t=l;u=n;v=p;while(1){w=v+(t>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(t&7)>>>(q>>>0);w=t+r|0;c[k>>2]=u>>>0>w>>>0?w:u;a[h+(s+52892)|0]=x;x=s+1|0;if((x|0)>=64){break a}s=x;t=c[k>>2]|0;u=c[m>>2]|0;v=c[o>>2]|0}}}while(0);if((c[j>>2]|0)<=197119){y=16;z=m;A=o;break}r=c[k>>2]|0;p=c[m>>2]|0;n=(c[o>>2]|0)+(r>>>3)|0;l=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(r&7)>>>28;n=r+4|0;c[k>>2]=p>>>0>n>>>0?n:p;y=l+1|0;z=m;A=o}else{y=16;z=f+16|0;A=f|0}}while(0);l=32-y|0;p=h+852|0;n=c[A>>2]|0;r=0;do{v=c[k>>2]|0;u=c[z>>2]|0;t=n+(v>>>3)|0;s=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>(l>>>0);t=v+y|0;c[k>>2]=u>>>0>t>>>0?t:u;c[p+(r<<2)>>2]=s;r=r+1|0;}while((r|0)<64);r=c[k>>2]|0;p=c[z>>2]|0;if((c[j>>2]|0)>197119){y=n+(r>>>3)|0;l=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(r&7)>>>28;y=r+4|0;s=p>>>0>y>>>0?y:p;c[k>>2]=s;B=l+1|0;C=s}else{B=16;C=r}r=32-B|0;s=h+724|0;l=0;y=C;do{C=n+(y>>>3)|0;u=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(y&7)>>>(r>>>0);C=y+B|0;y=p>>>0>C>>>0?C:p;c[k>>2]=y;b[s+(l<<1)>>1]=u;l=l+1|0;}while((l|0)<64);do{if((c[j>>2]|0)>197119){l=n+(y>>>3)|0;s=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(y&7)>>>23;l=y+9|0;c[k>>2]=p>>>0>l>>>0?l:p;l=s+1|0;if(!(l>>>0>384>>>0)){if(1){D=l;E=17;break}else{F=0;break}}yDb(e,16,2125016,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-1;i=g;return H|0}else{D=3;E=17}}while(0);if((E|0)==17){p=h+1108|0;y=0;while(1){n=0;do{j=c[k>>2]|0;l=c[z>>2]|0;s=(c[A>>2]|0)+(j>>>3)|0;B=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(j&7)>>>24;s=j+8|0;c[k>>2]=l>>>0>s>>>0?s:l;a[p+(y<<6)+n|0]=B;n=n+1|0;}while((n|0)<64);n=y+1|0;if((n|0)<(D|0)){y=n}else{F=D;break}}}D=h+25684|0;y=h+25690|0;p=h+26074|0;n=F-1|0;o=n>>>0>65535>>>0;m=o?n>>>16:n;n=o?16:0;o=(m&65280|0)==0;B=m>>>8;l=n|8;s=0;b:while(1){j=(s|0)!=0;r=(s*3|0)-1|0;u=0;do{do{if(j|(u|0)>0){C=c[k>>2]|0;t=c[A>>2]|0;v=d[t+(C>>>3)|0]|0;q=c[z>>2]|0;x=((C|0)<(q|0))+C|0;c[k>>2]=x;if((v&128>>>((C&7)>>>0)|0)!=0){E=27;break}if(j){C=d[t+(x>>>3)|0]|0;c[k>>2]=((x|0)<(q|0))+x;if((C&128>>>((x&7)>>>0)|0)==0){E=35}else{I=u;J=0}}else{E=35}if((E|0)==35){E=0;I=(u+2|0)%3|0;J=(r+u|0)/3|0}a[D+(s*3|0)+u|0]=a[D+(J*3|0)+I|0]|0;UGb(y+(s*192|0)+(u<<6)|0,y+(J*192|0)+(I<<6)|0,64)|0;UGb(p+(s*384|0)+(u<<7)|0,p+(J*384|0)+(I<<7)|0,128)|0}else{E=27}}while(0);if((E|0)==27){E=0;c:do{if(o){x=0;C=0;while(1){q=(d[1191992+m|0]|0)+n|0;t=c[k>>2]|0;v=c[z>>2]|0;w=c[A>>2]|0;K=w+(t>>>3)|0;L=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(t&7)>>>((31-q|0)>>>0);K=t+1+q|0;q=v>>>0>K>>>0?K:v;c[k>>2]=q;if((L|0)>=(F|0)){E=38;break b}b[p+(s*384|0)+(u<<7)+(C<<1)>>1]=L;if((x|0)>62){M=x;N=C&255;break c}L=63-x|0;K=L>>>0>65535>>>0;t=K?L>>>16:L;L=K?16:0;if((t&65280|0)==0){O=L;P=t}else{O=L|8;P=t>>>8}t=(d[1191992+P|0]|0)+O|0;L=w+(q>>>3)|0;w=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(q&7)>>>((31-t|0)>>>0);L=q+1+t|0;c[k>>2]=v>>>0>L>>>0?L:v;v=w+1|0;a[y+(s*192|0)+(u<<6)+C|0]=v;x=v+x|0;C=C+1|0}}else{C=0;x=0;while(1){v=(d[1191992+B|0]|0)+l|0;w=c[k>>2]|0;L=c[z>>2]|0;t=c[A>>2]|0;q=t+(w>>>3)|0;K=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(w&7)>>>((31-v|0)>>>0);q=w+1+v|0;v=L>>>0>q>>>0?q:L;c[k>>2]=v;if((K|0)>=(F|0)){E=38;break b}b[p+(s*384|0)+(u<<7)+(x<<1)>>1]=K;if((C|0)>62){M=C;N=x&255;break c}K=63-C|0;q=K>>>0>65535>>>0;w=q?K>>>16:K;K=q?16:0;if((w&65280|0)==0){Q=K;R=w}else{Q=K|8;R=w>>>8}w=(d[1191992+R|0]|0)+Q|0;K=t+(v>>>3)|0;t=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(v&7)>>>((31-w|0)>>>0);K=v+1+w|0;c[k>>2]=L>>>0>K>>>0?K:L;L=t+1|0;a[y+(s*192|0)+(u<<6)+x|0]=L;C=L+C|0;x=x+1|0}}}while(0);if((M|0)>63){E=44;break b}a[D+(s*3|0)+u|0]=N}u=u+1|0;}while((u|0)<3);u=s+1|0;if((u|0)<2){s=u}else{E=48;break}}if((E|0)==38){yDb(e,16,2119456,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-1;i=g;return H|0}else if((E|0)==44){yDb(e,16,2113360,(G=i,i=i+8|0,c[G>>2]=M,G)|0);i=G;H=-1;i=g;return H|0}else if((E|0)==48){G=h+32396|0;c[G>>2]=0;M=h+32404|0;s=h+32408|0;N=h+32400|0;while(1){c[M>>2]=0;c[s>>2]=1;D=c[k>>2]|0;y=d[(c[A>>2]|0)+(D>>>3)|0]|0;c[k>>2]=((D|0)<(c[z>>2]|0))+D;if((y&128>>>((D&7)>>>0)|0)==0){c[N>>2]=0;if((G4a(e,f)|0)!=0){H=-1;E=54;break}c[N>>2]=1;if((G4a(e,f)|0)!=0){H=-1;E=54;break}}D=(c[G>>2]|0)+1|0;c[G>>2]=D;if((D|0)>=80){E=53;break}}if((E|0)==53){c[h+8>>2]=1;H=0;i=g;return H|0}else if((E|0)==54){i=g;return H|0}}return 0}function D4a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=b+53468|0;h=(d|0)!=0|0;i=c[b+672+(h<<2)>>2]|0;j=c[b+56>>2]|0;k=c[j+32+(d<<2)>>2]|0;l=(c[b+576>>2]|0)==0?-k|0:k;if((e|0)>=(f|0)){return}k=ba(e<<3,l)|0;m=ba(i,e)|0;n=(i|0)>0;o=l<<3;p=b+688|0;q=b+436|0;r=b+432|0;s=i-1|0;t=(c[b+680+(h<<2)>>2]|0)-1|0;h=e;e=(c[b+692+(d<<2)>>2]|0)+m|0;m=(c[j+(d<<2)>>2]|0)+(k+(c[b+704+(d<<2)>>2]|0))|0;while(1){if(n){d=(h|0)>0;b=(h|0)<(t|0);k=0;j=e;while(1){do{if((a[(c[p>>2]|0)+(j<<2)+2|0]|0)!=8){if((k|0)>0){Xe[c[q>>2]&4095](m+(k<<3)|0,l,g)}if(d){Xe[c[r>>2]&4095](m+(k<<3)|0,l,g)}do{if((k|0)<(s|0)){if((a[(c[p>>2]|0)+(j+1<<2)+2|0]|0)!=8){break}Xe[c[q>>2]&4095](m+((k<<3)+8)|0,l,g)}}while(0);if(!b){break}if((a[(c[p>>2]|0)+(j+i<<2)+2|0]|0)!=8){break}Xe[c[r>>2]&4095](m+(k+l<<3)|0,l,g)}}while(0);u=k+1|0;if((u|0)>=(i|0)){break}k=u;j=j+1|0}v=i+e|0}else{v=e}j=h+1|0;if((j|0)<(f|0)){h=j;e=v;m=m+o|0}else{break}}return}function E4a(a,e,f,g,h,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;k=i;l=a+27616+(h<<8)+(g<<2)|0;m=c[l>>2]|0;n=c[a+26844+(h<<8)+(g<<2)>>2]|0;o=c[a+28388+(h<<2)>>2]|0;p=c[a+688>>2]|0;if((m|0)<0){yDb(c[a>>2]|0,16,2199480,(q=i,i=i+8|0,c[q>>2]=g,q)|0);i=q}r=(m|0)<(j|0);s=r?m:j;t=r?j-m|0:0;if((s|0)==0){u=0;v=0}else{b[n>>1]=s<<2;u=1;v=s}a:do{if((v|0)<(m|0)){s=e+8|0;j=e+12|0;r=e+16|0;w=e|0;x=(g|0)==0;y=a|0;z=64-g|0;A=g+1|0;B=v;C=v;D=u;E=t;b:while(1){F=C;G=D;while(1){H=c[s>>2]|0;if(((c[j>>2]|0)-H|0)<=0){I=G;J=B;K=E;break a}L=c[r>>2]|0;M=c[w>>2]|0;N=M+(H>>>3)|0;O=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(H&7)>>>21;N=b[f+(O<<2)>>1]|0;P=b[f+(O<<2)+2>>1]|0;O=P<<16>>16;do{if(P<<16>>16<0){Q=H+11|0;R=L>>>0>Q>>>0?Q:L;Q=M+(R>>>3)|0;S=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(R&7)>>>((O+32|0)>>>0))+N|0;Q=b[f+(S<<2)>>1]|0;T=b[f+(S<<2)+2>>1]|0;S=T<<16>>16;if(!(T<<16>>16<0)){U=S;V=Q;W=R;break}T=R-O|0;R=L>>>0>T>>>0?T:L;T=M+(R>>>3)|0;X=((fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(R&7)>>>((S+32|0)>>>0))+Q|0;U=b[f+(X<<2)+2>>1]|0;V=b[f+(X<<2)>>1]|0;W=R}else{U=O;V=N;W=H}}while(0);H=U+W|0;Y=L>>>0>H>>>0?H:L;c[s>>2]=Y;if(V>>>0<7>>>0){break}if(!((V|0)>-1)){break b}H=c[1429592+(V<<2)>>2]|0;if((V-13|0)>>>0<19>>>0){N=M+(Y>>>3)|0;O=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Y&7)>>>((32-H|0)>>>0);N=H+Y|0;P=L>>>0>N>>>0?N:L;c[s>>2]=P;Z=O;_=P}else{Z=H;_=Y}H=b[(c[1426888+(V<<2)>>2]|0)+(Z<<1)>>1]|0;P=c[296+(V<<2)>>2]|0;if((-1342176896>>>(V>>>0)&1|0)==0){$=P}else{O=c[168+(V<<2)>>2]|0;N=M+(_>>>3)|0;R=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(_&7)>>>((32-O|0)>>>0);N=_+O|0;c[s>>2]=L>>>0>N>>>0?N:L;$=R+P|0}if(($|0)==0){if(x){b[p+(c[o+(F<<2)>>2]<<2)>>1]=H}b[n+(G<<1)>>1]=H<<2|2}else{b[n+(G<<1)>>1]=($<<2)+(H<<16>>16<<9)|1}H=G+1|0;if(($+g|0)>64){yDb(c[y>>2]|0,48,2190824,(q=i,i=i+16|0,c[q>>2]=$,c[q+8>>2]=z,q)|0);i=q;aa=z}else{aa=$}P=aa+g|0;if((A|0)<=(P|0)){R=A;do{N=a+27616+(h<<8)+(R<<2)|0;c[N>>2]=(c[N>>2]|0)-1;R=R+1|0;}while((R|0)<=(P|0))}P=F+1|0;if((P|0)<(m|0)){F=P;G=H}else{I=H;J=B;K=E;break a}}P=c[1341848+(V<<2)>>2]|0;if((V-3|0)>>>0<4>>>0){R=c[1341816+(V<<2)>>2]|0;N=M+(Y>>>3)|0;O=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Y&7)>>>((32-R|0)>>>0);N=R+Y|0;c[s>>2]=L>>>0>N>>>0?N:L;ba=O+P|0}else{ba=P}ca=m-F|0;if((ba|0)>(ca|0)){da=16;break}b[n+(G<<1)>>1]=ba<<2;P=ba+F|0;O=G+1|0;N=ba+B|0;if((P|0)<(m|0)){B=N;C=P;D=O;E=0}else{I=O;J=N;K=0;break a}}if((da|0)==16){b[n+(G<<1)>>1]=ca<<2;I=G+1|0;J=ca+B|0;K=ba-ca|0;break}yDb(c[y>>2]|0,16,2174264,(q=i,i=i+8|0,c[q>>2]=V,q)|0);i=q;ea=-1;i=k;return ea|0}else{I=u;J=v;K=t}}while(0);if((J|0)>(c[l>>2]|0)){yDb(c[a>>2]|0,16,2164184,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}do{if((J|0)!=0){q=g+1|0;if((q|0)<64){fa=q}else{break}do{q=a+27616+(h<<8)+(fa<<2)|0;c[q>>2]=(c[q>>2]|0)-J;fa=fa+1|0;}while((fa|0)<64)}}while(0);if((h|0)<2){c[a+26844+(h+1<<8)+(g<<2)>>2]=n+(I<<1);ea=K;i=k;return ea|0}if((g|0)>=63){ea=K;i=k;return ea|0}c[a+26844+(g+1<<2)>>2]=n+(I<<1);ea=K;i=k;return ea|0}function F4a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;k=i;i=i+8|0;l=k|0;b[l+4>>1]=0;b[l+2>>1]=0;b[l>>1]=0;if((j|0)<=0){i=k;return}m=(h|0)>0;n=f+688|0;f=0;o=0;p=0;q=0;r=g;g=0;while(1){if(m){s=(g|0)==0;t=c[n>>2]|0;u=f;v=o;w=p;x=q;y=r;z=0;while(1){A=a[t+(y<<2)+2|0]|0;if(A<<24>>24==8){B=x;C=w;D=v;E=u}else{F=a[548120+(A&255)|0]|0;A=F&255;G=(z|0)!=0;if(G){H=y-1|0;I=(a[548120+(d[t+(H<<2)+2|0]|0)|0]|0)==F<<24>>24|0;J=b[t+(H<<2)>>1]|0}else{I=0;J=x}do{if(s){K=I;L=w;M=v;N=u}else{H=y-h|0;O=b[t+(H<<2)>>1]|0;P=(a[548120+(d[t+(H<<2)+2|0]|0)|0]|0)==F<<24>>24?I|4:I;if(G){Q=H-1|0;R=(a[548120+(d[t+(Q<<2)+2|0]|0)|0]|0)==F<<24>>24?P|8:P;S=b[t+(Q<<2)>>1]|0}else{R=P;S=u}if((z+1|0)>=(h|0)){K=R;L=w;M=O;N=S;break}P=H+1|0;K=(a[548120+(d[t+(P<<2)+2|0]|0)|0]|0)==F<<24>>24?R|2:R;L=b[t+(P<<2)>>1]|0;M=O;N=S}}while(0);do{if((K|0)==0){T=b[l+(A<<1)>>1]|0}else{F=ba(c[547864+(K<<4)>>2]|0,N)|0;G=(ba(c[547868+(K<<4)>>2]|0,M)|0)+F|0;F=G+(ba(c[547872+(K<<4)>>2]|0,L)|0)|0;G=(F+(ba(c[547876+(K<<4)>>2]|0,J)|0)|0)/128|0;if(!((K|0)==15|(K|0)==13)){T=G;break}F=G-M|0;if((((F|0)>-1?F:-F|0)|0)>128){T=M;break}F=G-J|0;if((((F|0)>-1?F:-F|0)|0)>128){T=J;break}F=G-N|0;T=(((F|0)>-1?F:-F|0)|0)>128?N:G}}while(0);G=t+(y<<2)|0;F=(e[G>>1]|0)+T&65535;b[G>>1]=F;b[l+(A<<1)>>1]=F;B=J;C=L;D=M;E=N}F=z+1|0;if((F|0)<(h|0)){u=E;v=D;w=C;x=B;y=y+1|0;z=F}else{break}}U=E;V=D;W=C;X=B;Y=r+h|0}else{U=f;V=o;W=p;X=q;Y=r}z=g+1|0;if((z|0)<(j|0)){f=U;o=V;p=W;q=X;r=Y;g=z}else{break}}i=k;return}function G4a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[a+60>>2]|0;g=b+8|0;h=c[g>>2]|0;j=c[b>>2]|0;k=d[j+(h>>>3)|0]|0;l=c[b+16>>2]|0;m=((h|0)<(l|0))+h|0;c[g>>2]=m;if((k&128>>>((h&7)>>>0)|0)!=0){h=f+32404|0;if((c[h>>2]|0)>31){yDb(a,16,2099144,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=e;return o|0}else{k=j+(m>>>3)|0;j=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(m&7)>>>27;k=m+5|0;c[g>>2]=l>>>0>k>>>0?k:l;l=f+32396|0;k=f+32412|0;c[k+(c[l>>2]<<8)+(j<<3)>>2]=c[f+32400>>2];c[k+(c[l>>2]<<8)+(j<<3)+4>>2]=c[f+32408>>2];c[h>>2]=(c[h>>2]|0)+1;o=0;i=e;return o|0}}h=f+32408|0;j=c[h>>2]|0;if((j|0)>31){yDb(a,16,2099144,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=e;return o|0}c[h>>2]=j+1;j=f+32400|0;c[j>>2]=c[j>>2]<<1;if((G4a(a,b)|0)!=0){o=-1;i=e;return o|0}c[j>>2]=c[j>>2]|1;if((G4a(a,b)|0)!=0){o=-1;i=e;return o|0}c[j>>2]=(c[j>>2]|0)>>>1;c[h>>2]=(c[h>>2]|0)-1;o=0;i=e;return o|0}function H4a(a,b){a=a|0;b=b|0;c[a>>2]=18;c[a+4>>2]=2270;c[a+8>>2]=1750;c[a+12>>2]=164;c[a+16>>2]=390;c[a+20>>2]=52;return}function I4a(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=0}else{return}do{i=ba(h,f)|0;j=b+i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=e+i|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+i>>2]=((l^k)>>>1&2139062143)+(l&k);k=i+4|0;i=b+k|0;l=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=e+k|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+k>>2]=((j^l)>>>1&2139062143)+(j&l);h=h+1|0;}while((h|0)<(g|0));return}function J4a(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=e;g=0;while(1){h=b[f>>1]|0;i=h<<16>>16;j=f+16|0;k=b[j>>1]|0;l=k<<16>>16;m=f+32|0;n=b[m>>1]|0;o=n<<16>>16;p=f+48|0;q=b[p>>1]|0;r=q<<16>>16;s=f+64|0;t=b[s>>1]|0;u=t<<16>>16;v=f+80|0;w=b[v>>1]|0;x=w<<16>>16;y=f+96|0;z=b[y>>1]|0;A=z<<16>>16;B=f+112|0;C=b[B>>1]|0;D=C<<16>>16;if(!((k|h|n|q|t|w|z|C)<<16>>16==0)){C=((D*12785|0)>>16)+((l*64277|0)>>16)|0;z=((l*12785|0)>>16)-((D*64277|0)>>16)|0;D=((x*36410|0)>>16)+((r*54491|0)>>16)|0;l=((x*54491|0)>>16)-((r*36410|0)>>16)|0;r=((C-D|0)*46341|0)>>16;x=((z-l|0)*46341|0)>>16;w=C+D|0;D=z+l|0;l=((u+i|0)*46341|0)>>16;z=((i-u|0)*46341|0)>>16;u=((A*25080|0)>>16)+((o*60547|0)>>16)|0;i=((o*25080|0)>>16)-((A*60547|0)>>16)|0;A=l-u|0;o=u+l|0;l=r+z|0;u=x-i|0;C=z-r|0;r=x+i|0;b[f>>1]=w+o;b[B>>1]=o-w;b[j>>1]=l+r;b[m>>1]=l-r;b[p>>1]=D+A;b[s>>1]=A-D;b[v>>1]=C+u;b[y>>1]=C-u}u=g+1|0;if((u|0)<8){f=f+2|0;g=u}else{break}}g=d*7|0;f=d*6|0;u=d*5|0;C=d<<2;y=d*3|0;v=d<<1;D=e;A=0;s=c;while(1){c=b[D+2>>1]|0;p=c<<16>>16;r=b[D+4>>1]|0;l=b[D+6>>1]|0;m=l<<16>>16;j=b[D+8>>1]|0;w=j<<16>>16;o=b[D+10>>1]|0;B=o<<16>>16;i=b[D+12>>1]|0;x=b[D+14>>1]|0;z=x<<16>>16;if((r|c|l|j|o|i|x)<<16>>16==0){x=((b[D>>1]|0)*46341|0)+524288>>20;o=x+128|0;if(o>>>0>255>>>0){E=-128-x>>31&255}else{E=o&255}a[s+g|0]=E;a[s+f|0]=E;a[s+u|0]=E;a[s+C|0]=E;a[s+y|0]=E;a[s+v|0]=E;a[s+d|0]=E;a[s]=E}else{o=((z*12785|0)>>16)+((p*64277|0)>>16)|0;x=((p*12785|0)>>16)-((z*64277|0)>>16)|0;z=((B*36410|0)>>16)+((m*54491|0)>>16)|0;p=((B*54491|0)>>16)-((m*36410|0)>>16)|0;m=((o-z|0)*46341|0)>>16;B=((x-p|0)*46341|0)>>16;j=o+z|0;z=x+p|0;p=b[D>>1]|0;x=(((p+w|0)*46341|0)>>16)+2056|0;o=(((p-w|0)*46341|0)>>16)+2056|0;w=r<<16>>16;r=i<<16>>16;i=((r*25080|0)>>16)+((w*60547|0)>>16)|0;p=((w*25080|0)>>16)-((r*60547|0)>>16)|0;r=x-i|0;w=x+i|0;i=o+m|0;x=B-p|0;l=o-m|0;m=B+p|0;p=w+j>>4;if(p>>>0>255>>>0){F=-p>>31&255}else{F=p&255}a[s]=F;p=w-j>>4;if(p>>>0>255>>>0){G=-p>>31&255}else{G=p&255}a[s+g|0]=G;p=i+m>>4;if(p>>>0>255>>>0){H=-p>>31&255}else{H=p&255}a[s+d|0]=H;p=i-m>>4;if(p>>>0>255>>>0){I=-p>>31&255}else{I=p&255}a[s+v|0]=I;p=r+z>>4;if(p>>>0>255>>>0){J=-p>>31&255}else{J=p&255}a[s+y|0]=J;p=r-z>>4;if(p>>>0>255>>>0){K=-p>>31&255}else{K=p&255}a[s+C|0]=K;p=l+x>>4;if(p>>>0>255>>>0){L=-p>>31&255}else{L=p&255}a[s+u|0]=L;p=l-x>>4;if(p>>>0>255>>>0){M=-p>>31&255}else{M=p&255}a[s+f|0]=M}p=A+1|0;if((p|0)<8){D=D+16|0;A=p;s=s+1|0}else{break}}TGb(e|0,0,128)|0;return}function K4a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=f;h=0;while(1){i=b[g>>1]|0;j=i<<16>>16;k=g+16|0;l=b[k>>1]|0;m=l<<16>>16;n=g+32|0;o=b[n>>1]|0;p=o<<16>>16;q=g+48|0;r=b[q>>1]|0;s=r<<16>>16;t=g+64|0;u=b[t>>1]|0;v=u<<16>>16;w=g+80|0;x=b[w>>1]|0;y=x<<16>>16;z=g+96|0;A=b[z>>1]|0;B=A<<16>>16;C=g+112|0;D=b[C>>1]|0;E=D<<16>>16;if(!((l|i|o|r|u|x|A|D)<<16>>16==0)){D=((E*12785|0)>>16)+((m*64277|0)>>16)|0;A=((m*12785|0)>>16)-((E*64277|0)>>16)|0;E=((y*36410|0)>>16)+((s*54491|0)>>16)|0;m=((y*54491|0)>>16)-((s*36410|0)>>16)|0;s=((D-E|0)*46341|0)>>16;y=((A-m|0)*46341|0)>>16;x=D+E|0;E=A+m|0;m=((v+j|0)*46341|0)>>16;A=((j-v|0)*46341|0)>>16;v=((B*25080|0)>>16)+((p*60547|0)>>16)|0;j=((p*25080|0)>>16)-((B*60547|0)>>16)|0;B=m-v|0;p=v+m|0;m=s+A|0;v=y-j|0;D=A-s|0;s=y+j|0;b[g>>1]=x+p;b[C>>1]=p-x;b[k>>1]=m+s;b[n>>1]=m-s;b[q>>1]=E+B;b[t>>1]=B-E;b[w>>1]=D+v;b[z>>1]=D-v}v=h+1|0;if((v|0)<8){g=g+2|0;h=v}else{break}}h=e*7|0;g=e*6|0;v=e*5|0;D=e<<2;z=e*3|0;w=e<<1;E=f;B=0;t=c;while(1){c=b[E+2>>1]|0;q=c<<16>>16;s=b[E+4>>1]|0;m=b[E+6>>1]|0;n=m<<16>>16;k=b[E+8>>1]|0;x=k<<16>>16;p=b[E+10>>1]|0;C=p<<16>>16;j=b[E+12>>1]|0;y=b[E+14>>1]|0;A=y<<16>>16;do{if((s|c|m|k|p|j|y)<<16>>16==0){u=b[E>>1]|0;if(u<<16>>16==0){break}r=((u<<16>>16)*46341|0)+524288>>20;u=(d[t]|0)+r|0;if(u>>>0>255>>>0){F=-u>>31&255}else{F=u&255}a[t]=F;u=t+e|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){G=-o>>31&255}else{G=o&255}a[u]=G;u=t+w|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){H=-o>>31&255}else{H=o&255}a[u]=H;u=t+z|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){I=-o>>31&255}else{I=o&255}a[u]=I;u=t+D|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){J=-o>>31&255}else{J=o&255}a[u]=J;u=t+v|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){K=-o>>31&255}else{K=o&255}a[u]=K;u=t+g|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){L=-o>>31&255}else{L=o&255}a[u]=L;u=t+h|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){M=-o>>31&255}else{M=o&255}a[u]=M}else{u=((A*12785|0)>>16)+((q*64277|0)>>16)|0;o=((q*12785|0)>>16)-((A*64277|0)>>16)|0;r=((C*36410|0)>>16)+((n*54491|0)>>16)|0;i=((C*54491|0)>>16)-((n*36410|0)>>16)|0;l=((u-r|0)*46341|0)>>16;N=((o-i|0)*46341|0)>>16;O=u+r|0;r=o+i|0;i=b[E>>1]|0;o=(((i+x|0)*46341|0)>>16)+8|0;u=(((i-x|0)*46341|0)>>16)+8|0;i=s<<16>>16;P=j<<16>>16;Q=((P*25080|0)>>16)+((i*60547|0)>>16)|0;R=((i*25080|0)>>16)-((P*60547|0)>>16)|0;P=o-Q|0;i=o+Q|0;Q=u+l|0;o=N-R|0;S=u-l|0;l=N+R|0;R=(i+O>>4)+(d[t]|0)|0;if(R>>>0>255>>>0){T=-R>>31&255}else{T=R&255}a[t]=T;R=t+h|0;N=(d[R]|0)+(i-O>>4)|0;if(N>>>0>255>>>0){U=-N>>31&255}else{U=N&255}a[R]=U;R=t+e|0;N=(d[R]|0)+(Q+l>>4)|0;if(N>>>0>255>>>0){V=-N>>31&255}else{V=N&255}a[R]=V;R=t+w|0;N=(d[R]|0)+(Q-l>>4)|0;if(N>>>0>255>>>0){W=-N>>31&255}else{W=N&255}a[R]=W;R=t+z|0;N=(d[R]|0)+(P+r>>4)|0;if(N>>>0>255>>>0){X=-N>>31&255}else{X=N&255}a[R]=X;R=t+D|0;N=(d[R]|0)+(P-r>>4)|0;if(N>>>0>255>>>0){Y=-N>>31&255}else{Y=N&255}a[R]=Y;R=t+v|0;N=(d[R]|0)+(S+o>>4)|0;if(N>>>0>255>>>0){Z=-N>>31&255}else{Z=N&255}a[R]=Z;R=t+g|0;N=(d[R]|0)+(S-o>>4)|0;if(N>>>0>255>>>0){_=-N>>31&255}else{_=N&255}a[R]=_}}while(0);j=B+1|0;if((j|0)<8){E=E+16|0;B=j;t=t+1|0}else{break}}TGb(f|0,0,128)|0;return}function L4a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=(b[f>>1]|0)+15>>5;h=0;i=c;while(1){c=(d[i]|0)+g|0;if(c>>>0>255>>>0){j=-c>>31&255}else{j=c&255}a[i]=j;c=i+1|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[c]=l;c=i+2|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){m=-k>>31&255}else{m=k&255}a[c]=m;c=i+3|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){n=-k>>31&255}else{n=k&255}a[c]=n;c=i+4|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){o=-k>>31&255}else{o=k&255}a[c]=o;c=i+5|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){p=-k>>31&255}else{p=k&255}a[c]=p;c=i+6|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){q=-k>>31&255}else{q=k&255}a[c]=q;c=i+7|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){r=-k>>31&255}else{r=k&255}a[c]=r;c=h+1|0;if((c|0)<8){h=c;i=i+e|0}else{break}}b[f>>1]=0;return}function M4a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=-e|0;h=b+8|0;i=g<<1;j=b;do{b=j+g|0;k=d[b]|0;l=c[f+((d[j+i|0]|0)+4-(d[j+e|0]|0)+(((d[j]|0)-k|0)*3|0)>>3<<2)>>2]|0;m=k+l|0;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[b]=n;b=(d[j]|0)-l|0;if(b>>>0>255>>>0){o=-b>>31&255}else{o=b&255}a[j]=o;j=j+1|0;}while(j>>>0<h>>>0);return}function N4a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=e<<3;h=b+g|0;if((g|0)==0){return}else{i=b}do{b=d[i]|0;g=i-1|0;j=d[g]|0;k=c[f+((d[i-2|0]|0)+4-(d[i+1|0]|0)+((b-j|0)*3|0)>>3<<2)>>2]|0;l=j+k|0;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[g]=m;g=b-k|0;if(g>>>0>255>>>0){n=-g>>31&255}else{n=g&255}a[i]=n;i=i+e|0;}while((i|0)!=(h|0));return}function O4a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=Y4a(a,1,0)|0;if((d|0)<0){e=d;return e|0}c[b+1728>>2]=131224;c[b+1732>>2]=238;c[b+1740>>2]=122;c[b+1744>>2]=246;c[b+1748>>2]=372;c[b+1752>>2]=1206;c[b+1756>>2]=314;e=0;return e|0}function P4a(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;g=c[e+1764>>2]|0;h=e+376|0;i=e+380|0;j=e+392|0;k=e+384|0;l=e+388|0;e=a[1085592]|0;m=e<<24>>24>0;n=f|0;o=f+2|0;f=0;p=c[h>>2]|0;q=c[i>>2]|0;r=c[j>>2]|0;while(1){s=a[g+130+f|0]|0;t=d[1086680+p|0]|0;u=p<<t;c[h>>2]=u;v=r<<t;w=q+t|0;do{if((w|0)>-1){t=c[k>>2]|0;if(!(t>>>0<(c[l>>2]|0)>>>0)){x=v;y=w;break}c[k>>2]=t+2;z=t;x=((de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<w|v;y=w-16|0}else{x=v;y=w}}while(0);c[i>>2]=y;w=((ba(u-1|0,s&255)|0)>>8)+1|0;v=w<<16;z=x>>>0>=v>>>0;t=z?u-w|0:w;c[h>>2]=t;w=x-(z?v:0)|0;c[j>>2]=w;if(z){z=a[g+128+f|0]|0;v=d[1086680+t|0]|0;A=t<<v;c[h>>2]=A;B=w<<v;C=y+v|0;do{if((C|0)>-1){v=c[k>>2]|0;if(!(v>>>0<(c[l>>2]|0)>>>0)){D=B;E=C;break}c[k>>2]=v+2;F=v;D=((de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<C|B;E=C-16|0}else{D=B;E=C}}while(0);c[i>>2]=E;C=((ba(A-1|0,z&255)|0)>>8)+1|0;B=C<<16;u=D>>>0>=B>>>0;s=u&1;F=u?A-C|0:C;c[h>>2]=F;C=D-(u?B:0)|0;c[j>>2]=C;B=a[g+132+(f<<1)|0]|0;u=d[1086680+F|0]|0;v=F<<u;c[h>>2]=v;F=C<<u;C=E+u|0;do{if((C|0)>-1){u=c[k>>2]|0;if(!(u>>>0<(c[l>>2]|0)>>>0)){G=F;H=C;break}c[k>>2]=u+2;I=u;G=((de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)<<C|F;H=C-16|0}else{G=F;H=C}}while(0);c[i>>2]=H;C=((ba(v-1|0,B&255)|0)>>8)+1|0;F=C<<16;A=G>>>0>=F>>>0;z=A&1;I=A?v-C|0:C;c[h>>2]=I;C=G-(A?F:0)|0;c[j>>2]=C;F=a[g+132+(f<<1)+1|0]|0;A=d[1086680+I|0]|0;u=I<<A;c[h>>2]=u;I=C<<A;C=H+A|0;do{if((C|0)>-1){A=c[k>>2]|0;if(!(A>>>0<(c[l>>2]|0)>>>0)){J=I;K=C;break}c[k>>2]=A+2;L=A;J=((de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<C|I;K=C-16|0}else{J=I;K=C}}while(0);c[i>>2]=K;C=((ba(u-1|0,F&255)|0)>>8)+1|0;I=C<<16;v=J>>>0>=I>>>0;B=v?u-C|0:C;c[h>>2]=B;C=J-(v?I:0)|0;c[j>>2]=C;I=(v&1)<<1|z;if(m){v=1085592;L=1085592;A=B;M=K;N=C;while(1){O=a[(a[v+1|0]|0)+(g+136+(f*7|0))|0]|0;P=d[1086680+A|0]|0;Q=A<<P;c[h>>2]=Q;R=N<<P;S=P+M|0;do{if((S|0)>-1){P=c[k>>2]|0;if(!(P>>>0<(c[l>>2]|0)>>>0)){T=R;U=S;break}c[k>>2]=P+2;V=P;T=((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<S|R;U=S-16|0}else{T=R;U=S}}while(0);c[i>>2]=U;S=((ba(Q-1|0,O&255)|0)>>8)+1|0;R=S<<16;V=T>>>0>=R>>>0;P=V?Q-S|0:S;c[h>>2]=P;S=T-(V?R:0)|0;c[j>>2]=S;if(V){W=v+(a[L]<<1)|0}else{W=v+2|0}V=W|0;R=a[V]|0;if(R<<24>>24>0){v=W;L=V;A=P;M=U;N=S}else{X=R;Y=P;Z=U;_=S;break}}}else{X=e;Y=B;Z=K;_=C}$=((I|-(X<<24>>24)<<2)^-s)+s&65535;aa=Y;ca=Z;da=_}else{$=0;aa=t;ca=y;da=w}if((f|0)==0){b[n>>1]=$;f=f+1|0;p=aa;q=ca;r=da;continue}else{b[o>>1]=$;N=f+1|0;if((N|0)<2){f=N;p=aa;q=ca;r=da;continue}else{break}}}return}function Q4a(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;g=c[f+1764>>2]|0;h=f+500|0;i=f+376|0;j=f+380|0;k=f+392|0;l=f+384|0;m=f+388|0;n=a[1086656]|0;o=n<<24>>24>0;p=f+498|0;q=0;r=0;do{r=(q|0)>3?1:r;s=a[1087256+q|0]|0;t=s&255;u=f+1436+(t<<6)|0;v=f+552+(q<<2)|0;w=1;x=g+166+(r*11|0)|0;y=g+1124+(r*180|0)+(((d[(c[h>>2]|0)+((c[v>>2]|0)*12|0)|0]|0)+((d[u]|0)*6|0)|0)*5|0)|0;z=0;while(1){A=a[y]|0;B=c[i>>2]|0;C=d[1086680+B|0]|0;D=c[j>>2]|0;E=c[k>>2]|0;F=B<<C;c[i>>2]=F;B=E<<C;E=D+C|0;do{if((E|0)>-1){C=c[l>>2]|0;if(!(C>>>0<(c[m>>2]|0)>>>0)){G=B;H=E;break}c[l>>2]=C+2;D=C;G=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<E|B;H=E-16|0}else{G=B;H=E}}while(0);c[j>>2]=H;E=((ba(F-1|0,A&255)|0)>>8)+1|0;B=E<<16;D=G>>>0>=B>>>0;C=D?F-E|0:E;c[i>>2]=C;E=G-(D?B:0)|0;c[k>>2]=E;if(D){D=a[y+2|0]|0;B=d[1086680+C|0]|0;I=C<<B;c[i>>2]=I;J=E<<B;K=H+B|0;do{if((K|0)>-1){B=c[l>>2]|0;if(!(B>>>0<(c[m>>2]|0)>>>0)){L=J;M=K;break}c[l>>2]=B+2;N=B;L=((de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<K|J;M=K-16|0}else{L=J;M=K}}while(0);c[j>>2]=M;K=((ba(I-1|0,D&255)|0)>>8)+1|0;J=K<<16;F=L>>>0>=J>>>0;A=F?I-K|0:K;c[i>>2]=A;K=L-(F?J:0)|0;c[k>>2]=K;do{if(F){J=a[y+3|0]|0;N=d[1086680+A|0]|0;B=A<<N;c[i>>2]=B;O=K<<N;P=M+N|0;do{if((P|0)>-1){N=c[l>>2]|0;if(!(N>>>0<(c[m>>2]|0)>>>0)){Q=O;R=P;break}c[l>>2]=N+2;S=N;Q=((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)<<P|O;R=P-16|0}else{Q=O;R=P}}while(0);c[j>>2]=R;P=((ba(B-1|0,J&255)|0)>>8)+1|0;O=P<<16;S=Q>>>0>=O>>>0;N=S?B-P|0:P;c[i>>2]=N;P=Q-(S?O:0)|0;c[k>>2]=P;if(!S){S=a[y+4|0]|0;O=d[1086680+N|0]|0;T=N<<O;c[i>>2]=T;N=P<<O;P=R+O|0;do{if((P|0)>-1){O=c[l>>2]|0;if(!(O>>>0<(c[m>>2]|0)>>>0)){U=N;V=P;break}c[l>>2]=O+2;W=O;U=((de((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<P|N;V=P-16|0}else{U=N;V=P}}while(0);c[j>>2]=V;P=((ba(T-1|0,S&255)|0)>>8)+1|0;N=P<<16;B=U>>>0>=N>>>0;J=B?T-P|0:P;c[i>>2]=J;P=U-(B?N:0)|0;c[k>>2]=P;if(B){B=a[x+5|0]|0;N=d[1086680+J|0]|0;W=J<<N;c[i>>2]=W;J=P<<N;P=V+N|0;do{if((P|0)>-1){N=c[l>>2]|0;if(!(N>>>0<(c[m>>2]|0)>>>0)){X=J;Y=P;break}c[l>>2]=N+2;O=N;X=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<P|J;Y=P-16|0}else{X=J;Y=P}}while(0);c[j>>2]=Y;P=((ba(W-1|0,B&255)|0)>>8)+1|0;J=P<<16;T=X>>>0>=J>>>0;c[i>>2]=T?W-P|0:P;c[k>>2]=X-(T?J:0);a[f+1436+((s&255)<<6)+z|0]=3;Z=T?4:3}else{a[f+1436+((s&255)<<6)+z|0]=2;Z=2}T=c[i>>2]|0;J=d[1086680+T|0]|0;P=c[j>>2]|0;S=c[k>>2]|0;O=T<<J;c[i>>2]=O;T=S<<J;S=P+J|0;do{if((S|0)>-1){J=c[l>>2]|0;if(!(J>>>0<(c[m>>2]|0)>>>0)){_=T;$=S;break}c[l>>2]=J+2;P=J;_=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<S|T;$=S-16|0}else{_=T;$=S}}while(0);c[j>>2]=$;S=O+1>>1;T=S<<16;W=_>>>0>=T>>>0;if(W){c[i>>2]=O-S;aa=_-T|0}else{c[i>>2]=S;aa=_}c[k>>2]=aa;ca=2;da=Z;ea=W;break}a[f+1436+((s&255)<<6)+z|0]=4;W=c[i>>2]|0;S=c[j>>2]|0;T=c[k>>2]|0;if(o){B=1086656;P=1086656;J=W;N=S;fa=T;while(1){ga=a[x+(a[B+1|0]|0)|0]|0;ha=d[1086680+J|0]|0;ia=J<<ha;c[i>>2]=ia;ja=fa<<ha;ka=ha+N|0;do{if((ka|0)>-1){ha=c[l>>2]|0;if(!(ha>>>0<(c[m>>2]|0)>>>0)){la=ja;ma=ka;break}c[l>>2]=ha+2;na=ha;la=((de((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ka|ja;ma=ka-16|0}else{la=ja;ma=ka}}while(0);c[j>>2]=ma;ka=((ba(ia-1|0,ga&255)|0)>>8)+1|0;ja=ka<<16;na=la>>>0>=ja>>>0;ha=na?ia-ka|0:ka;c[i>>2]=ha;ka=la-(na?ja:0)|0;c[k>>2]=ka;if(na){oa=B+(a[P]<<1)|0}else{oa=B+2|0}na=oa|0;ja=a[na]|0;if(ja<<24>>24>0){B=oa;P=na;J=ha;N=ma;fa=ka}else{pa=ja;qa=ha;ra=ma;sa=ka;break}}}else{pa=n;qa=W;ra=S;sa=T}fa=pa<<24>>24;N=-fa|0;J=d[1086680+qa|0]|0;P=qa<<J;c[i>>2]=P;B=sa<<J;O=ra+J|0;do{if((O|0)>-1){J=c[l>>2]|0;if(!(J>>>0<(c[m>>2]|0)>>>0)){ta=B;ua=O;break}c[l>>2]=J+2;ka=J;ta=((de((d[ka]|d[ka+1|0]<<8)<<16>>16|0)|0)&65535)<<O|B;ua=O-16|0}else{ta=B;ua=O}}while(0);c[j>>2]=ua;O=P+1>>1;B=O<<16;T=ta>>>0>=B>>>0;if(T){S=P-O|0;c[i>>2]=S;va=ta-B|0;wa=S}else{c[i>>2]=O;va=ta;wa=O}c[k>>2]=va;O=d[1087208+N|0]|0;S=d[1087216+(5-fa)|0]|0;B=wa;W=ua;ka=va;while(1){J=a[1087136+(N*11|0)+O|0]|0;ha=d[1086680+B|0]|0;ja=B<<ha;c[i>>2]=ja;na=ka<<ha;xa=W+ha|0;do{if((xa|0)>-1){ha=c[l>>2]|0;if(!(ha>>>0<(c[m>>2]|0)>>>0)){ya=na;za=xa;break}c[l>>2]=ha+2;Aa=ha;ya=((de((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<xa|na;za=xa-16|0}else{ya=na;za=xa}}while(0);c[j>>2]=za;xa=((ba(ja-1|0,J&255)|0)>>8)+1|0;na=xa<<16;ia=ya>>>0>=na>>>0;ga=ia?ja-xa|0:xa;c[i>>2]=ga;xa=ya-(ia?na:0)|0;c[k>>2]=xa;na=((ia&1)<<O)+S|0;if((O|0)>0){O=O-1|0;S=na;B=ga;W=za;ka=xa}else{ca=2;da=na;ea=T;break}}}else{a[f+1436+((s&255)<<6)+z|0]=1;T=c[i>>2]|0;ka=d[1086680+T|0]|0;W=c[j>>2]|0;B=c[k>>2]|0;S=T<<ka;c[i>>2]=S;T=B<<ka;B=W+ka|0;do{if((B|0)>-1){ka=c[l>>2]|0;if(!(ka>>>0<(c[m>>2]|0)>>>0)){Ba=T;Ca=B;break}c[l>>2]=ka+2;W=ka;Ba=((de((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<B|T;Ca=B-16|0}else{Ba=T;Ca=B}}while(0);c[j>>2]=Ca;B=S+1>>1;T=B<<16;W=Ba>>>0>=T>>>0;if(W){c[i>>2]=S-B;Da=Ba-T|0}else{c[i>>2]=B;Da=Ba}c[k>>2]=Da;ca=1;da=1;ea=W}}while(0);K=ea&1;A=(da^-K)+K|0;if((z|0)==0){Ea=A&65535}else{Ea=(ba(e[p>>1]|0,A)|0)&65535}b[f+608+(q<<7)+(d[f+288+z|0]<<1)>>1]=Ea;Fa=ca}else{if((w|0)!=0){A=a[y+1|0]|0;K=d[1086680+C|0]|0;F=C<<K;c[i>>2]=F;I=E<<K;D=H+K|0;do{if((D|0)>-1){K=c[l>>2]|0;if(!(K>>>0<(c[m>>2]|0)>>>0)){Ga=I;Ha=D;break}c[l>>2]=K+2;W=K;Ga=((de((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<D|I;Ha=D-16|0}else{Ga=I;Ha=D}}while(0);c[j>>2]=Ha;D=((ba(F-1|0,A&255)|0)>>8)+1|0;I=D<<16;E=Ga>>>0>=I>>>0;c[i>>2]=E?F-D|0:D;c[k>>2]=Ga-(E?I:0);if(!E){Ia=z;break}}a[f+1436+(t<<6)+z|0]=0;Fa=0}E=z+1|0;if((E|0)>63){Ia=E;break}I=d[131232+E|0]|0;D=g+188+(r*198|0)+(Fa*66|0)+(I*11|0)|0;if(z>>>0>22>>>0){w=Fa;x=D;y=D;z=E;continue}w=Fa;x=D;y=g+584+(r*270|0)+(Fa*90|0)+(I*30|0)+((d[f+1436+(t<<6)+E|0]|0)*5|0)|0;z=E}z=f+1692+t|0;y=a[z]|0;x=(y&255)>>>0>24>>>0?24:y&255;a[z]=Ia;if((Ia|0)<(x|0)){TGb(Ia+(t<<6)+(f+1436)|0,5,x+1-Ia|0)|0}a[(c[h>>2]|0)+((c[v>>2]|0)*12|0)|0]=a[u]|0;q=q+1|0;}while((q|0)<6);return}function R4a(b){b=b|0;var d=0;d=c[b+1764>>2]|0;a[d+128|0]=-128;a[d+130|0]=-128;a[d+132|0]=85;a[d+133|0]=-128;a[d+129|0]=-128;a[d+131|0]=-128;a[d+134|0]=85;a[d+135|0]=-128;UGb(d+1812|0,1087008,60)|0;TGb(d+136|0,-128|0,14)|0;return}function S4a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;e=c[b+1764>>2]|0;f=b+376|0;g=b+380|0;h=b+392|0;i=b+384|0;j=b+388|0;b=0;while(1){k=a[128976+(b*11|0)|0]|0;l=c[f>>2]|0;m=d[1086680+l|0]|0;n=c[g>>2]|0;o=c[h>>2]|0;p=l<<m;c[f>>2]=p;l=o<<m;o=n+m|0;do{if((o|0)>-1){m=c[i>>2]|0;if(!(m>>>0<(c[j>>2]|0)>>>0)){q=l;r=o;break}c[i>>2]=m+2;n=m;q=((de((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<o|l;r=o-16|0}else{q=l;r=o}}while(0);c[g>>2]=r;o=((ba(p-1|0,k&255)|0)>>8)+1|0;l=o<<16;n=q>>>0>=l>>>0;m=n?p-o|0:o;c[f>>2]=m;o=q-(n?l:0)|0;c[h>>2]=o;if(n){n=7;l=0;s=m;t=r;u=o;while(1){v=n-1|0;w=l<<1;x=d[1086680+s|0]|0;y=s<<x;c[f>>2]=y;z=u<<x;A=x+t|0;do{if((A|0)>-1){x=c[i>>2]|0;if(!(x>>>0<(c[j>>2]|0)>>>0)){B=z;C=A;break}c[i>>2]=x+2;D=x;B=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<A|z;C=A-16|0}else{B=z;C=A}}while(0);c[g>>2]=C;A=y+1>>1;z=A<<16;D=B>>>0>=z>>>0;if(D){x=y-A|0;c[f>>2]=x;E=B-z|0;F=x}else{c[f>>2]=A;E=B;F=A}c[h>>2]=E;G=D&1|w;if((v|0)==0){break}else{n=v;l=G;s=F;t=C;u=E}}u=G<<1;a[e+130+b|0]=(u|0)==0|u;H=c[f>>2]|0;I=c[g>>2]|0;J=c[h>>2]|0}else{H=m;I=r;J=o}u=a[128977+(b*11|0)|0]|0;t=d[1086680+H|0]|0;s=H<<t;c[f>>2]=s;l=J<<t;n=I+t|0;do{if((n|0)>-1){t=c[i>>2]|0;if(!(t>>>0<(c[j>>2]|0)>>>0)){K=l;L=n;break}c[i>>2]=t+2;p=t;K=((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)<<n|l;L=n-16|0}else{K=l;L=n}}while(0);c[g>>2]=L;n=((ba(s-1|0,u&255)|0)>>8)+1|0;l=n<<16;o=K>>>0>=l>>>0;m=o?s-n|0:n;c[f>>2]=m;n=K-(o?l:0)|0;c[h>>2]=n;if(o){o=7;l=0;p=m;t=L;k=n;while(1){D=o-1|0;A=l<<1;x=d[1086680+p|0]|0;z=p<<x;c[f>>2]=z;M=k<<x;N=x+t|0;do{if((N|0)>-1){x=c[i>>2]|0;if(!(x>>>0<(c[j>>2]|0)>>>0)){O=M;P=N;break}c[i>>2]=x+2;Q=x;O=((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<N|M;P=N-16|0}else{O=M;P=N}}while(0);c[g>>2]=P;N=z+1>>1;M=N<<16;v=O>>>0>=M>>>0;if(v){w=z-N|0;c[f>>2]=w;R=O-M|0;S=w}else{c[f>>2]=N;R=O;S=N}c[h>>2]=R;T=v&1|A;if((D|0)==0){break}else{o=D;l=T;p=S;t=P;k=R}}k=T<<1;a[e+128+b|0]=(k|0)==0|k;U=c[f>>2]|0;V=c[g>>2]|0;W=c[h>>2]|0}else{U=m;V=L;W=n}k=a[128978+(b*11|0)|0]|0;t=d[1086680+U|0]|0;p=U<<t;c[f>>2]=p;l=W<<t;o=V+t|0;do{if((o|0)>-1){t=c[i>>2]|0;if(!(t>>>0<(c[j>>2]|0)>>>0)){X=l;Y=o;break}c[i>>2]=t+2;s=t;X=((de((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<o|l;Y=o-16|0}else{X=l;Y=o}}while(0);c[g>>2]=Y;o=((ba(p-1|0,k&255)|0)>>8)+1|0;l=o<<16;n=X>>>0>=l>>>0;m=n?p-o|0:o;c[f>>2]=m;o=X-(n?l:0)|0;c[h>>2]=o;if(n){n=7;l=0;s=m;t=Y;u=o;while(1){v=n-1|0;N=l<<1;w=d[1086680+s|0]|0;M=s<<w;c[f>>2]=M;y=u<<w;Q=w+t|0;do{if((Q|0)>-1){w=c[i>>2]|0;if(!(w>>>0<(c[j>>2]|0)>>>0)){Z=y;_=Q;break}c[i>>2]=w+2;x=w;Z=((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<Q|y;_=Q-16|0}else{Z=y;_=Q}}while(0);c[g>>2]=_;Q=M+1>>1;y=Q<<16;D=Z>>>0>=y>>>0;if(D){A=M-Q|0;c[f>>2]=A;$=Z-y|0;aa=A}else{c[f>>2]=Q;$=Z;aa=Q}c[h>>2]=$;ca=D&1|N;if((v|0)==0){break}else{n=v;l=ca;s=aa;t=_;u=$}}u=ca<<1;a[e+132+(b<<1)|0]=(u|0)==0|u;da=c[f>>2]|0;ea=c[g>>2]|0;fa=c[h>>2]|0}else{da=m;ea=Y;fa=o}u=a[128979+(b*11|0)|0]|0;t=d[1086680+da|0]|0;s=da<<t;c[f>>2]=s;l=fa<<t;n=ea+t|0;do{if((n|0)>-1){t=c[i>>2]|0;if(!(t>>>0<(c[j>>2]|0)>>>0)){ga=l;ha=n;break}c[i>>2]=t+2;p=t;ga=((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)<<n|l;ha=n-16|0}else{ga=l;ha=n}}while(0);c[g>>2]=ha;n=((ba(s-1|0,u&255)|0)>>8)+1|0;l=n<<16;o=ga>>>0>=l>>>0;m=o?s-n|0:n;c[f>>2]=m;n=ga-(o?l:0)|0;c[h>>2]=n;if(o){o=7;l=0;p=m;m=ha;t=n;while(1){n=o-1|0;k=l<<1;D=d[1086680+p|0]|0;Q=p<<D;c[f>>2]=Q;A=t<<D;y=D+m|0;do{if((y|0)>-1){D=c[i>>2]|0;if(!(D>>>0<(c[j>>2]|0)>>>0)){ia=A;ja=y;break}c[i>>2]=D+2;z=D;ia=((de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<y|A;ja=y-16|0}else{ia=A;ja=y}}while(0);c[g>>2]=ja;y=Q+1>>1;A=y<<16;v=ia>>>0>=A>>>0;if(v){N=Q-y|0;c[f>>2]=N;ka=ia-A|0;la=N}else{c[f>>2]=y;ka=ia;la=y}c[h>>2]=ka;ma=v&1|k;if((n|0)==0){break}else{o=n;l=ma;p=la;m=ja;t=ka}}t=ma<<1;a[e+132+(b<<1)+1|0]=(t|0)==0|t}t=b+1|0;if((t|0)<2){b=t}else{na=0;break}}do{b=0;do{ma=a[b+4+(128976+(na*11|0))|0]|0;ka=c[f>>2]|0;ja=d[1086680+ka|0]|0;la=c[g>>2]|0;ia=c[h>>2]|0;ha=ka<<ja;c[f>>2]=ha;ka=ia<<ja;ia=la+ja|0;do{if((ia|0)>-1){ja=c[i>>2]|0;if(!(ja>>>0<(c[j>>2]|0)>>>0)){oa=ka;pa=ia;break}c[i>>2]=ja+2;la=ja;oa=((de((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535)<<ia|ka;pa=ia-16|0}else{oa=ka;pa=ia}}while(0);c[g>>2]=pa;ia=((ba(ha-1|0,ma&255)|0)>>8)+1|0;ka=ia<<16;n=oa>>>0>=ka>>>0;k=n?ha-ia|0:ia;c[f>>2]=k;ia=oa-(n?ka:0)|0;c[h>>2]=ia;if(n){n=7;ka=0;Q=k;k=pa;la=ia;while(1){ia=n-1|0;ja=ka<<1;ga=d[1086680+Q|0]|0;ea=Q<<ga;c[f>>2]=ea;fa=la<<ga;da=ga+k|0;do{if((da|0)>-1){ga=c[i>>2]|0;if(!(ga>>>0<(c[j>>2]|0)>>>0)){qa=fa;ra=da;break}c[i>>2]=ga+2;Y=ga;qa=((de((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<da|fa;ra=da-16|0}else{qa=fa;ra=da}}while(0);c[g>>2]=ra;da=ea+1>>1;fa=da<<16;Y=qa>>>0>=fa>>>0;if(Y){ga=ea-da|0;c[f>>2]=ga;sa=qa-fa|0;ta=ga}else{c[f>>2]=da;sa=qa;ta=da}c[h>>2]=sa;ua=Y&1|ja;if((ia|0)==0){break}else{n=ia;ka=ua;Q=ta;k=ra;la=sa}}la=ua<<1;a[e+136+(na*7|0)+b|0]=(la|0)==0|la}b=b+1|0;}while((b|0)<7);na=na+1|0;}while((na|0)<2);return}function T4a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;f=i;i=i+16|0;g=f|0;h=c[e+1764>>2]|0;TGb(g|0,-128|0,11)|0;j=e+376|0;k=e+380|0;l=e+392|0;m=e+384|0;n=e+388|0;o=e+352|0;e=0;while(1){p=0;do{q=a[130480+(e*11|0)+p|0]|0;r=c[j>>2]|0;s=d[1086680+r|0]|0;t=c[k>>2]|0;u=c[l>>2]|0;v=r<<s;c[j>>2]=v;r=u<<s;u=t+s|0;do{if((u|0)>-1){s=c[m>>2]|0;if(!(s>>>0<(c[n>>2]|0)>>>0)){w=r;x=u;break}c[m>>2]=s+2;t=s;w=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<u|r;x=u-16|0}else{w=r;x=u}}while(0);c[k>>2]=x;u=((ba(v-1|0,q&255)|0)>>8)+1|0;r=u<<16;t=w>>>0>=r>>>0;s=t?v-u|0:u;c[j>>2]=s;u=w-(t?r:0)|0;c[l>>2]=u;do{if(t){r=7;y=0;z=s;A=x;B=u;while(1){C=r-1|0;D=y<<1;E=d[1086680+z|0]|0;F=z<<E;c[j>>2]=F;G=B<<E;H=E+A|0;do{if((H|0)>-1){E=c[m>>2]|0;if(!(E>>>0<(c[n>>2]|0)>>>0)){I=G;J=H;break}c[m>>2]=E+2;K=E;I=((de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535)<<H|G;J=H-16|0}else{I=G;J=H}}while(0);c[k>>2]=J;H=F+1>>1;G=H<<16;K=I>>>0>=G>>>0;if(K){E=F-H|0;c[j>>2]=E;L=I-G|0;M=E}else{c[j>>2]=H;L=I;M=H}c[l>>2]=L;N=K&1|D;if((C|0)==0){break}else{r=C;y=N;z=M;A=J;B=L}}B=N<<1;A=((B|0)==0|B)&255;a[g+p|0]=A;a[h+166+(e*11|0)+p|0]=A}else{if((c[(c[o>>2]|0)+84>>2]|0)==0){break}a[h+166+(e*11|0)+p|0]=a[g+p|0]|0}}while(0);p=p+1|0;}while((p|0)<11);p=e+1|0;if((p|0)<2){e=p}else{O=0;break}}while(1){e=0;do{N=0;do{L=0;do{J=a[129e3+(O*132|0)+(e*66|0)+(N*11|0)+L|0]|0;M=c[j>>2]|0;I=d[1086680+M|0]|0;x=c[k>>2]|0;w=c[l>>2]|0;p=M<<I;c[j>>2]=p;M=w<<I;w=x+I|0;do{if((w|0)>-1){I=c[m>>2]|0;if(!(I>>>0<(c[n>>2]|0)>>>0)){P=M;Q=w;break}c[m>>2]=I+2;x=I;P=((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<w|M;Q=w-16|0}else{P=M;Q=w}}while(0);c[k>>2]=Q;w=((ba(p-1|0,J&255)|0)>>8)+1|0;M=w<<16;C=P>>>0>=M>>>0;D=C?p-w|0:w;c[j>>2]=D;w=P-(C?M:0)|0;c[l>>2]=w;do{if(C){M=7;F=0;x=D;I=Q;u=w;while(1){s=M-1|0;t=F<<1;v=d[1086680+x|0]|0;q=x<<v;c[j>>2]=q;A=u<<v;B=v+I|0;do{if((B|0)>-1){v=c[m>>2]|0;if(!(v>>>0<(c[n>>2]|0)>>>0)){R=A;S=B;break}c[m>>2]=v+2;z=v;R=((de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<B|A;S=B-16|0}else{R=A;S=B}}while(0);c[k>>2]=S;B=q+1>>1;A=B<<16;z=R>>>0>=A>>>0;if(z){v=q-B|0;c[j>>2]=v;T=R-A|0;U=v}else{c[j>>2]=B;T=R;U=B}c[l>>2]=T;V=z&1|t;if((s|0)==0){break}else{M=s;F=V;x=U;I=S;u=T}}u=V<<1;I=((u|0)==0|u)&255;a[g+L|0]=I;a[h+188+(e*198|0)+(O*66|0)+(N*11|0)+L|0]=I}else{if((c[(c[o>>2]|0)+84>>2]|0)==0){break}a[h+188+(e*198|0)+(O*66|0)+(N*11|0)+L|0]=a[g+L|0]|0}}while(0);L=L+1|0;}while((L|0)<11);N=N+1|0;}while((N|0)<6);e=e+1|0;}while((e|0)<2);e=O+1|0;if((e|0)<3){O=e}else{W=0;break}}while(1){O=0;do{g=(ba(b[130504+(O<<2)>>1]|0,d[h+166+(W*11|0)|0]|0)|0)+128>>8;o=g+(b[130506+(O<<2)>>1]|0)|0;if((o|0)<1){X=1}else{X=(o|0)>254?-2:o&255}a[h+1124+(W*180|0)+(O*5|0)|0]=X;o=(ba(b[130648+(O<<2)>>1]|0,d[h+166+(W*11|0)+1|0]|0)|0)+128>>8;g=o+(b[130650+(O<<2)>>1]|0)|0;if((g|0)<1){Y=1}else{Y=(g|0)>254?-2:g&255}a[h+1124+(W*180|0)+(O*5|0)+1|0]=Y;g=(ba(b[130792+(O<<2)>>1]|0,d[h+166+(W*11|0)+2|0]|0)|0)+128>>8;o=g+(b[130794+(O<<2)>>1]|0)|0;if((o|0)<1){Z=1}else{Z=(o|0)>254?-2:o&255}a[h+1124+(W*180|0)+(O*5|0)+2|0]=Z;o=(ba(b[130936+(O<<2)>>1]|0,d[h+166+(W*11|0)+3|0]|0)|0)+128>>8;g=o+(b[130938+(O<<2)>>1]|0)|0;if((g|0)<1){_=1}else{_=(g|0)>254?-2:g&255}a[h+1124+(W*180|0)+(O*5|0)+3|0]=_;g=(ba(b[131080+(O<<2)>>1]|0,d[h+166+(W*11|0)+4|0]|0)|0)+128>>8;o=g+(b[131082+(O<<2)>>1]|0)|0;if((o|0)<1){$=1}else{$=(o|0)>254?-2:o&255}a[h+1124+(W*180|0)+(O*5|0)+4|0]=$;O=O+1|0;}while((O|0)<36);O=W+1|0;if((O|0)<2){W=O}else{aa=0;break}}do{W=0;do{$=0;do{_=0;do{Z=(ba(b[129400+(aa*360|0)+($*120|0)+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)|0]|0)|0)+128>>8;Y=Z+(b[129400+(aa*360|0)+($*120|0)+(_<<2)+2>>1]|0)|0;if((Y|0)<1){ca=1}else{ca=(Y|0)>254?-2:Y&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)|0]=ca;Y=(ba(b[129400+(aa*360|0)+($*120|0)+24+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)+1|0]|0)|0)+128>>8;Z=Y+(b[129400+(aa*360|0)+($*120|0)+24+(_<<2)+2>>1]|0)|0;if((Z|0)<1){da=1}else{da=(Z|0)>254?-2:Z&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)+1|0]=da;Z=(ba(b[129400+(aa*360|0)+($*120|0)+48+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)+2|0]|0)|0)+128>>8;Y=Z+(b[129400+(aa*360|0)+($*120|0)+48+(_<<2)+2>>1]|0)|0;if((Y|0)<1){ea=1}else{ea=(Y|0)>254?-2:Y&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)+2|0]=ea;Y=(ba(b[129400+(aa*360|0)+($*120|0)+72+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)+3|0]|0)|0)+128>>8;Z=Y+(b[129400+(aa*360|0)+($*120|0)+72+(_<<2)+2>>1]|0)|0;if((Z|0)<1){fa=1}else{fa=(Z|0)>254?-2:Z&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)+3|0]=fa;Z=(ba(b[129400+(aa*360|0)+($*120|0)+96+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)+4|0]|0)|0)+128>>8;Y=Z+(b[129400+(aa*360|0)+($*120|0)+96+(_<<2)+2>>1]|0)|0;if((Y|0)<1){ga=1}else{ga=(Y|0)>254?-2:Y&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)+4|0]=ga;_=_+1|0;}while((_|0)<6);$=$+1|0;}while(($|0)<3);W=W+1|0;}while((W|0)<2);aa=aa+1|0;}while((aa|0)<3);i=f;return 0}function U4a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;f=i;g=a+376|0;g5a(g,b,e);e=g|0;g=c[e>>2]|0;b=d[1086680+g|0]|0;h=a+380|0;j=c[h>>2]|0;k=a+392|0;l=c[k>>2]|0;m=g<<b;c[e>>2]=m;g=l<<b;l=j+b|0;do{if((l|0)>-1){b=a+384|0;j=c[b>>2]|0;if(!(j>>>0<(c[a+388>>2]|0)>>>0)){n=g;o=l;break}c[b>>2]=j+2;b=j;n=((de((d[b]|d[b+1|0]<<8)<<16>>16|0)|0)&65535)<<l|g;o=l-16|0}else{n=g;o=l}}while(0);c[h>>2]=o;o=m+1>>1;l=o<<16;g=n>>>0>=l>>>0;if(g){c[e>>2]=m-o;p=n-l|0}else{c[e>>2]=o;p=n}c[k>>2]=p;p=a+352|0;c[(c[p>>2]|0)+84>>2]=g&1^1;g=c[e>>2]|0;n=d[1086680+g|0]|0;o=c[h>>2]|0;l=c[k>>2]|0;m=g<<n;c[e>>2]=m;g=l<<n;l=o+n|0;do{if((l|0)>-1){n=a+384|0;o=c[n>>2]|0;if(!(o>>>0<(c[a+388>>2]|0)>>>0)){q=g;r=l;break}c[n>>2]=o+2;n=o;q=((de((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<l|g;r=l-16|0}else{q=g;r=l}}while(0);c[h>>2]=r;l=m+1>>1;g=l<<16;if(q>>>0<g>>>0){c[e>>2]=l;s=q;t=l}else{n=m-l|0;c[e>>2]=n;s=q-g|0;t=n}c[k>>2]=s;n=a+384|0;g=a+388|0;q=6;l=0;m=t;t=r;r=s;while(1){s=q-1|0;o=l<<1;b=d[1086680+m|0]|0;j=m<<b;c[e>>2]=j;u=r<<b;v=b+t|0;do{if((v|0)>-1){b=c[n>>2]|0;if(!(b>>>0<(c[g>>2]|0)>>>0)){w=u;x=v;break}c[n>>2]=b+2;y=b;w=((de((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535)<<v|u;x=v-16|0}else{w=u;x=v}}while(0);c[h>>2]=x;v=j+1>>1;u=v<<16;y=w>>>0>=u>>>0;if(y){b=j-v|0;c[e>>2]=b;z=w-u|0;A=b}else{c[e>>2]=v;z=w;A=v}c[k>>2]=z;B=y&1|o;if((s|0)==0){break}else{q=s;l=B;m=A;t=x;r=z}}V4a(a,B);a:do{if((c[(c[p>>2]|0)+84>>2]|0)==0){if((c[a+600>>2]|0)==0){C=-1094995529}else{break}i=f;return C|0}else{B=8;z=c[e>>2]|0;r=c[h>>2]|0;x=c[k>>2]|0;while(1){t=B-1|0;A=d[1086680+z|0]|0;m=z<<A;c[e>>2]=m;l=x<<A;q=A+r|0;do{if((q|0)>-1){A=c[n>>2]|0;if(!(A>>>0<(c[g>>2]|0)>>>0)){D=l;E=q;break}c[n>>2]=A+2;w=A;D=((de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<q|l;E=q-16|0}else{D=l;E=q}}while(0);c[h>>2]=E;q=m+1>>1;l=q<<16;if(D>>>0<l>>>0){c[e>>2]=q;F=D;G=q}else{w=m-q|0;c[e>>2]=w;F=D-l|0;G=w}c[k>>2]=F;if((t|0)==0){H=5;I=0;J=G;K=E;L=F;break}else{B=t;z=G;r=E;x=F}}while(1){x=H-1|0;r=I<<1;z=d[1086680+J|0]|0;B=J<<z;c[e>>2]=B;s=L<<z;o=z+K|0;do{if((o|0)>-1){z=c[n>>2]|0;if(!(z>>>0<(c[g>>2]|0)>>>0)){M=s;N=o;break}c[n>>2]=z+2;j=z;M=((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)<<o|s;N=o-16|0}else{M=s;N=o}}while(0);c[h>>2]=N;o=B+1>>1;s=o<<16;t=M>>>0>=s>>>0;if(t){m=B-o|0;c[e>>2]=m;O=M-s|0;P=m}else{c[e>>2]=o;O=M;P=o}c[k>>2]=O;Q=t&1|r;if((x|0)==0){break}else{H=x;I=Q;J=P;K=N;L=O}}if((Q|0)>5){C=-1094995529;i=f;return C|0}t=d[1086680+P|0]|0;o=P<<t;c[e>>2]=o;m=O<<t;s=t+N|0;do{if((s|0)>-1){t=c[n>>2]|0;if(!(t>>>0<(c[g>>2]|0)>>>0)){R=m;S=s;break}c[n>>2]=t+2;j=t;R=((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)<<s|m;S=s-16|0}else{R=m;S=s}}while(0);c[h>>2]=S;s=o+1>>1;m=s<<16;if(R>>>0<m>>>0){c[e>>2]=s;T=R;U=s}else{j=o-s|0;c[e>>2]=j;T=R-m|0;U=j}c[k>>2]=T;j=d[1086680+U|0]|0;m=U<<j;c[e>>2]=m;s=T<<j;t=j+S|0;do{if((t|0)>-1){j=c[n>>2]|0;if(!(j>>>0<(c[g>>2]|0)>>>0)){V=s;W=t;break}c[n>>2]=j+2;z=j;V=((de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<t|s;W=t-16|0}else{V=s;W=t}}while(0);c[h>>2]=W;t=m+1>>1;s=t<<16;if(V>>>0<s>>>0){c[e>>2]=t;X=V;Y=t}else{o=m-t|0;c[e>>2]=o;X=V-s|0;Y=o}c[k>>2]=X;o=d[1086680+Y|0]|0;s=Y<<o;c[e>>2]=s;t=X<<o;z=W+o|0;do{if((z|0)>-1){o=c[n>>2]|0;if(!(o>>>0<(c[g>>2]|0)>>>0)){Z=t;_=z;break}c[n>>2]=o+2;j=o;Z=((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)<<z|t;_=z-16|0}else{Z=t;_=z}}while(0);c[h>>2]=_;z=s+1>>1;t=z<<16;if(!(Z>>>0<t>>>0)){c[e>>2]=s-z;c[k>>2]=Z-t;yDb(c[a>>2]|0,16,2178632,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;C=-1163346256;i=f;return C|0}c[e>>2]=z;c[k>>2]=Z;t=8;m=0;j=z;z=_;o=Z;while(1){w=t-1|0;l=m<<1;q=d[1086680+j|0]|0;A=j<<q;c[e>>2]=A;y=o<<q;v=q+z|0;do{if((v|0)>-1){q=c[n>>2]|0;if(!(q>>>0<(c[g>>2]|0)>>>0)){aa=y;ba=v;break}c[n>>2]=q+2;b=q;aa=((de((d[b]|d[b+1|0]<<8)<<16>>16|0)|0)&65535)<<v|y;ba=v-16|0}else{aa=y;ba=v}}while(0);c[h>>2]=ba;v=A+1>>1;y=v<<16;x=aa>>>0>=y>>>0;if(x){r=A-v|0;c[e>>2]=r;ca=aa-y|0;da=r}else{c[e>>2]=v;ca=aa;da=v}c[k>>2]=ca;ea=x&1|l;if((w|0)==0){fa=8;ga=0;ha=da;ia=ba;ja=ca;break}else{t=w;m=ea;j=da;z=ba;o=ca}}while(1){o=fa-1|0;z=ga<<1;j=d[1086680+ha|0]|0;m=ha<<j;c[e>>2]=m;t=ja<<j;s=j+ia|0;do{if((s|0)>-1){j=c[n>>2]|0;if(!(j>>>0<(c[g>>2]|0)>>>0)){ka=t;la=s;break}c[n>>2]=j+2;x=j;ka=((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<s|t;la=s-16|0}else{ka=t;la=s}}while(0);c[h>>2]=la;s=m+1>>1;t=s<<16;w=ka>>>0>=t>>>0;if(w){l=m-s|0;c[e>>2]=l;ma=ka-t|0;na=l}else{c[e>>2]=s;ma=ka;na=s}c[k>>2]=ma;oa=w&1|z;if((o|0)==0){break}else{fa=o;ga=oa;ha=na;ia=la;ja=ma}}if((ea|0)==0|(oa|0)==0){yDb(c[a>>2]|0,16,2102352,($=i,i=i+16|0,c[$>>2]=oa<<4,c[$+8>>2]=ea<<4,$)|0);i=$;C=-1094995529;i=f;return C|0}else{pa=8;qa=na;ra=la;sa=ma}while(1){w=pa-1|0;s=d[1086680+qa|0]|0;l=qa<<s;c[e>>2]=l;t=sa<<s;A=s+ra|0;do{if((A|0)>-1){s=c[n>>2]|0;if(!(s>>>0<(c[g>>2]|0)>>>0)){ta=t;ua=A;break}c[n>>2]=s+2;x=s;ta=((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<A|t;ua=A-16|0}else{ta=t;ua=A}}while(0);c[h>>2]=ua;A=l+1>>1;t=A<<16;if(ta>>>0<t>>>0){c[e>>2]=A;va=ta;wa=A}else{o=l-A|0;c[e>>2]=o;va=ta-t|0;wa=o}c[k>>2]=va;if((w|0)==0){xa=8;ya=wa;za=ua;Aa=va;break}else{pa=w;qa=wa;ra=ua;sa=va}}while(1){o=xa-1|0;t=d[1086680+ya|0]|0;A=ya<<t;c[e>>2]=A;z=Aa<<t;m=t+za|0;do{if((m|0)>-1){t=c[n>>2]|0;if(!(t>>>0<(c[g>>2]|0)>>>0)){Ba=z;Ca=m;break}c[n>>2]=t+2;x=t;Ba=((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<m|z;Ca=m-16|0}else{Ba=z;Ca=m}}while(0);c[h>>2]=Ca;m=A+1>>1;z=m<<16;if(Ba>>>0<z>>>0){c[e>>2]=m;Da=Ba;Ea=m}else{w=A-m|0;c[e>>2]=w;Da=Ba-z|0;Ea=w}c[k>>2]=Da;if((o|0)==0){break}else{xa=o;ya=Ea;za=Ca;Aa=Da}}w=d[1086680+Ea|0]|0;z=Ea<<w;c[e>>2]=z;m=Da<<w;l=w+Ca|0;do{if((l|0)>-1){w=c[n>>2]|0;if(!(w>>>0<(c[g>>2]|0)>>>0)){Fa=m;Ga=l;break}c[n>>2]=w+2;x=w;Fa=((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<l|m;Ga=l-16|0}else{Fa=m;Ga=l}}while(0);c[h>>2]=Ga;l=z+1>>1;m=l<<16;if(Fa>>>0<m>>>0){c[e>>2]=l;Ha=Fa;Ia=l}else{x=z-l|0;c[e>>2]=x;Ha=Fa-m|0;Ia=x}c[k>>2]=Ha;x=d[1086680+Ia|0]|0;m=Ia<<x;c[e>>2]=m;l=Ha<<x;w=x+Ga|0;do{if((w|0)>-1){x=c[n>>2]|0;if(!(x>>>0<(c[g>>2]|0)>>>0)){Ja=l;Ka=w;break}c[n>>2]=x+2;t=x;Ja=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<w|l;Ka=w-16|0}else{Ja=l;Ka=w}}while(0);c[h>>2]=Ka;w=m+1>>1;l=w<<16;if(Ja>>>0<l>>>0){c[e>>2]=w;La=Ja}else{c[e>>2]=m-w;La=Ja-l|0}c[k>>2]=La;do{if((c[a+600>>2]|0)==0){Ma=c[a>>2]|0;Na=oa<<4}else{l=oa<<4;w=c[a>>2]|0;if((l|0)!=(c[w+128>>2]|0)){Ma=w;Na=l;break}if((ea<<4|0)==(c[w+132>>2]|0)){break a}else{Ma=w;Na=l}}}while(0);m=V$a(Ma,Na,ea<<4)|0;C=(m|0)<0?m:1;i=f;return C|0}}while(0);C=0;i=f;return C|0}function V4a(a,e){a=a|0;e=e|0;c[a+492>>2]=e;b[a+496>>1]=(d[1087072+e|0]|0)<<2;b[a+498>>1]=(d[1087280+e|0]|0)<<2;return}function W4a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;h=c[f+24>>2]|0;j=c[a+60>>2]|0;k=j;l=j+352|0;m=c[l>>2]|0;n=f+28|0;f=c[n>>2]|0;do{if((c[j+1696>>2]|0)==0){o=f;p=0;q=h}else{if((f|0)<3){r=-1;i=g;return r|0}s=(d[h+1|0]|0)<<8|(d[h]|0)<<16|(d[h+2|0]|0);t=f-3|0;if((t|0)<(s|0)){r=-1}else{o=t;p=s;q=h+3|0;break}i=g;return r|0}}while(0);h=ze[c[j+1756>>2]&511](k,q,o)|0;if((h|0)<0){r=h;i=g;return r|0}f=(h|0)==1;do{if(f){h=j+1760|0;KCb(c[l>>2]|0);s=c[h>>2]|0;if((s|0)!=0){KCb(c[s+352>>2]|0)}KCb(c[j+356>>2]|0);s=c[h>>2]|0;if((s|0)!=0){KCb(c[s+356>>2]|0)}KCb(c[j+360>>2]|0);s=c[h>>2]|0;if((s|0)!=0){KCb(c[s+360>>2]|0)}KCb(c[j+364>>2]|0);s=c[h>>2]|0;if((s|0)==0){break}KCb(c[s+364>>2]|0)}}while(0);if((_$a(a,m,1)|0)<0){r=-1;i=g;return r|0}l=a+140|0;do{if((c[l>>2]|0)==35){s=j+1760|0;KCb(c[(c[s>>2]|0)+352>>2]|0);h=MCb(c[(c[s>>2]|0)+352>>2]|0,m)|0;if((h|0)>=0){break}KCb(m);r=h;i=g;return r|0}}while(0);a:do{if(f){h=k;while(1){u=c[h>>2]|0;s=c[h+352>>2]|0;t=s+32|0;v=c[t>>2]|0;w=u+128|0;x=c[w>>2]|0;c[h+440>>2]=x;c[h+428>>2]=x;x=(c[w>>2]|0)/2|0;c[h+436>>2]=x;c[h+432>>2]=x;x=u+132|0;y=c[x>>2]|0;c[h+456>>2]=y;c[h+444>>2]=y;y=(c[x>>2]|0)/2|0;c[h+452>>2]=y;c[h+448>>2]=y;y=h+1700|0;z=c[y>>2]|0;c[h+1712>>2]=ba(c[t>>2]|0,z)|0;c[h+1716>>2]=ba(c[s+36>>2]|0,z)|0;c[h+1720>>2]=ba(c[s+40>>2]|0,z)|0;c[h+1724>>2]=ba(c[s+44>>2]|0,z)|0;z=(c[w>>2]|0)+15|0;w=(z|0)/16|0;s=h+460|0;c[s>>2]=w;t=(c[x>>2]|0)+15|0;x=h+464|0;c[x>>2]=(t|0)/16|0;if((z|0)>16015|(t|0)>16015){A=15;break}t=h+500|0;bEb(t,(w<<2)+6|0,12)|0;w=h+600|0;bEb(w,ba(c[x>>2]|0,c[s>>2]|0)|0,8)|0;s=h+368|0;ZDb(c[s>>2]|0);x=WDb(v<<4)|0;c[s>>2]=x;s=h+372|0;c[s>>2]=x;if((c[t>>2]|0)==0){break}if((c[w>>2]|0)==0|(x|0)==0){break}if((c[y>>2]|0)<0){c[s>>2]=x+(v*15|0)}h=c[h+1760>>2]|0;if((h|0)==0){break a}}if((A|0)==15){V$a(u,0,0)|0;yDb(u,16,2311600,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}KCb(m);r=-1;i=g;return r|0}}while(0);u=c[l>>2]|0;do{if((u|0)==35){A=a+120|0;k=c[A>>2]|0;f=a+124|0;h=c[f>>2]|0;v=a+128|0;x=c[v>>2]|0;s=a+132|0;y=c[s>>2]|0;w=c[j+1760>>2]|0;t=ze[c[w+1756>>2]&511](w,q+p|0,o-p|0)|0;if((t|0)==1){yDb(a,16,2198400,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;c[A>>2]=k;c[f>>2]=h;c[v>>2]=x;c[s>>2]=y}else if((t|0)==0){C=c[l>>2]|0;break}KCb(m);r=-1;i=g;return r|0}else{C=u}}while(0);Pe[c[a+828>>2]&255](a,534,0,0,(C|0)==35?2:1)|0;C=MCb(b,m)|0;if((C|0)<0){r=C;i=g;return r|0}c[e>>2]=1;r=c[n>>2]|0;i=g;return r|0}function X4a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0;j=i;i=i+64|0;g=j|0;k=j+16|0;l=j+24|0;m=c[f+60>>2]|0;f=(h|0)==1;h=f&1;if(f){n=c[m+1760>>2]|0}else{n=m}m=n+352|0;o=c[m>>2]|0;p=o+84|0;q=o+88|0;do{if((c[p>>2]|0)==0){c[q>>2]=2;r=c[n+1764>>2]|0;s=n+376|0;t=n+380|0;u=n+392|0;v=n+384|0;w=n+388|0;y=a[1086584]|0;z=y<<24>>24>0;A=0;do{B=c[s>>2]|0;C=d[1086680+B|0]|0;D=c[t>>2]|0;E=c[u>>2]|0;F=B<<C;c[s>>2]=F;B=E<<C;E=D+C|0;do{if((E|0)>-1){C=c[v>>2]|0;if(!(C>>>0<(c[w>>2]|0)>>>0)){G=B;H=E;break}c[v>>2]=C+2;D=C;G=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<E|B;H=E-16|0}else{G=B;H=E}}while(0);c[t>>2]=H;E=((F*174|0)-174>>8)+1|0;B=E<<16;D=G>>>0>=B>>>0;C=D?F-E|0:E;c[s>>2]=C;E=G-(D?B:0)|0;c[u>>2]=E;if(D){D=4;B=0;I=C;J=H;K=E;while(1){L=D-1|0;M=B<<1;N=d[1086680+I|0]|0;O=I<<N;c[s>>2]=O;P=K<<N;Q=N+J|0;do{if((Q|0)>-1){N=c[v>>2]|0;if(!(N>>>0<(c[w>>2]|0)>>>0)){R=P;S=Q;break}c[v>>2]=N+2;T=N;R=((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<Q|P;S=Q-16|0}else{R=P;S=Q}}while(0);c[t>>2]=S;Q=O+1>>1;P=Q<<16;T=R>>>0>=P>>>0;if(T){N=O-Q|0;c[s>>2]=N;U=R-P|0;V=N}else{c[s>>2]=Q;U=R;V=Q}c[u>>2]=U;W=T&1|M;if((L|0)==0){break}else{D=L;B=W;I=V;J=S;K=U}}UGb(r+1812+(A*20|0)|0,1085624+(W*60|0)+(A*20|0)|0,20)|0;X=c[s>>2]|0;Y=c[t>>2]|0;Z=c[u>>2]|0}else{X=C;Y=H;Z=E}K=d[1086680+X|0]|0;J=X<<K;c[s>>2]=J;I=Z<<K;B=K+Y|0;do{if((B|0)>-1){K=c[v>>2]|0;if(!(K>>>0<(c[w>>2]|0)>>>0)){_=I;$=B;break}c[v>>2]=K+2;D=K;_=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<B|I;$=B-16|0}else{_=I;$=B}}while(0);c[t>>2]=$;B=((J*254|0)-254>>8)+1|0;I=B<<16;E=_>>>0>=I>>>0;c[s>>2]=E?J-B|0:B;c[u>>2]=_-(E?I:0);if(E){E=0;do{I=0;do{B=c[s>>2]|0;C=d[1086680+B|0]|0;D=c[t>>2]|0;K=c[u>>2]|0;F=B<<C;c[s>>2]=F;B=K<<C;K=D+C|0;do{if((K|0)>-1){C=c[v>>2]|0;if(!(C>>>0<(c[w>>2]|0)>>>0)){aa=B;ca=K;break}c[v>>2]=C+2;D=C;aa=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<K|B;ca=K-16|0}else{aa=B;ca=K}}while(0);c[t>>2]=ca;K=((F*205|0)-205>>8)+1|0;B=K<<16;D=aa>>>0>=B>>>0;C=D?F-K|0:K;c[s>>2]=C;K=aa-(D?B:0)|0;c[u>>2]=K;if(D){D=d[1086680+C|0]|0;B=C<<D;c[s>>2]=B;C=K<<D;K=D+ca|0;do{if((K|0)>-1){D=c[v>>2]|0;if(!(D>>>0<(c[w>>2]|0)>>>0)){da=C;ea=K;break}c[v>>2]=D+2;T=D;da=((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<K|C;ea=K-16|0}else{da=C;ea=K}}while(0);c[t>>2]=ea;K=B+1>>1;C=K<<16;F=da>>>0>=C>>>0;T=F&1;if(F){F=B-K|0;c[s>>2]=F;fa=da-C|0;ga=F}else{c[s>>2]=K;fa=da;ga=K}c[u>>2]=fa;if(z){K=1086584;F=1086584;C=ga;D=ea;Q=fa;while(1){N=a[1086936+(a[K+1|0]|0)|0]|0;P=d[1086680+C|0]|0;ha=C<<P;c[s>>2]=ha;ia=Q<<P;ja=P+D|0;do{if((ja|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){ka=ia;la=ja;break}c[v>>2]=P+2;ma=P;ka=((de((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<ja|ia;la=ja-16|0}else{ka=ia;la=ja}}while(0);c[t>>2]=la;ja=((ba(ha-1|0,N&255)|0)>>8)+1|0;ia=ja<<16;ma=ka>>>0>=ia>>>0;P=ma?ha-ja|0:ja;c[s>>2]=P;ja=ka-(ma?ia:0)|0;c[u>>2]=ja;if(ma){na=K+(a[F]<<1)|0}else{na=K+2|0}ma=na|0;ia=a[ma]|0;if(ia<<24>>24>0){K=na;F=ma;C=P;D=la;Q=ja}else{oa=ia;pa=P;qa=la;ra=ja;break}}}else{oa=y;pa=ga;qa=ea;ra=fa}Q=-(oa<<24>>24)|0;if(oa<<24>>24==0){D=7;C=0;F=pa;K=qa;B=ra;while(1){ja=D-1|0;P=C<<1;ia=d[1086680+F|0]|0;ma=F<<ia;c[s>>2]=ma;sa=B<<ia;ta=ia+K|0;do{if((ta|0)>-1){ia=c[v>>2]|0;if(!(ia>>>0<(c[w>>2]|0)>>>0)){ua=sa;va=ta;break}c[v>>2]=ia+2;wa=ia;ua=((de((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)<<ta|sa;va=ta-16|0}else{ua=sa;va=ta}}while(0);c[t>>2]=va;ta=ma+1>>1;sa=ta<<16;ha=ua>>>0>=sa>>>0;if(ha){N=ma-ta|0;c[s>>2]=N;xa=ua-sa|0;ya=N}else{c[s>>2]=ta;xa=ua;ya=ta}c[u>>2]=xa;za=ha&1|P;if((ja|0)==0){break}else{D=ja;C=za;F=ya;K=va;B=xa}}Aa=za<<2}else{Aa=Q}B=r+1812+(A*20|0)+(E<<1)+I|0;a[B]=(Aa^-T)+T+(d[B]|0)}I=I+1|0;}while((I|0)<2);E=E+1|0;}while((E|0)<10)}A=A+1|0;}while((A|0)<3);A=l|0;u=l+8|0;s=l+12|0;t=l+16|0;v=l+4|0;w=l+28|0;y=l+20|0;z=l+24|0;E=l+32|0;J=l+36|0;I=0;do{L=a[r+1812+(I*20|0)+1|0]|0;c[A>>2]=(L&255)*100|0;c[v>>2]=(d[r+1812+(I*20|0)+3|0]|0)*100|0;c[u>>2]=(d[r+1812+(I*20|0)+5|0]|0)*100|0;c[s>>2]=(d[r+1812+(I*20|0)+7|0]|0)*100|0;c[t>>2]=(d[r+1812+(I*20|0)+9|0]|0)*100|0;c[y>>2]=(d[r+1812+(I*20|0)+11|0]|0)*100|0;c[z>>2]=(d[r+1812+(I*20|0)+13|0]|0)*100|0;c[w>>2]=(d[r+1812+(I*20|0)+15|0]|0)*100|0;c[E>>2]=(d[r+1812+(I*20|0)+17|0]|0)*100|0;c[J>>2]=(d[r+1812+(I*20|0)+19|0]|0)*100|0;M=0;O=L;while(1){L=d[r+1812+(I*20|0)+(M<<1)|0]|0;a[r+1512+(I*100|0)+(M*10|0)|0]=255-(((L*255|0)>>>0)/(((O&255)+1+L|0)>>>0)|0);L=l+(M<<2)|0;c[L>>2]=0;B=c[A>>2]|0;K=(c[u>>2]|0)+B|0;F=c[s>>2]|0;C=(c[t>>2]|0)+F|0;D=C+K|0;ha=c[v>>2]|0;ta=(c[w>>2]|0)+ha|0;N=c[y>>2]|0;sa=(c[z>>2]|0)+N|0;wa=c[E>>2]|0;ia=(c[J>>2]|0)+wa|0;Ba=ia+sa|0;Ca=Ba+ta|0;Da=D+1|0;a[r+1512+(I*100|0)+(M*10|0)+1|0]=((D*255|0|0)/(Ca+Da|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+2|0]=((K*255|0|0)/(Da|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+3|0]=((ta*255|0|0)/(Ca+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+4|0]=((B*255|0|0)/(K+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+5|0]=((F*255|0|0)/(C+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+6|0]=((ha*255|0|0)/(ta+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+7|0]=((sa*255|0|0)/(Ba+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+8|0]=((N*255|0|0)/(sa+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+9|0]=((wa*255|0|0)/(ia+1|0)|0)+1;c[L>>2]=(d[r+1812+(I*20|0)+(M<<1)+1|0]|0)*100|0;L=M+1|0;if((L|0)>=10){break}M=L;O=a[r+1812+(I*20|0)+(L<<1)+1|0]|0}I=I+1|0;}while((I|0)<3);me[c[n+1748>>2]&511](n);c[n+596>>2]=0}else{c[q>>2]=1;me[c[n+1744>>2]&511](n);I=n+464|0;r=n+460|0;if((ba(c[r>>2]|0,c[I>>2]|0)|0)<=0){break}J=n+600|0;E=0;do{a[(c[J>>2]|0)+(E<<3)|0]=1;E=E+1|0;}while((E|0)<(ba(c[r>>2]|0,c[I>>2]|0)|0))}}while(0);a:do{if((re[c[n+1752>>2]&4095](n)|0)==0){TGb(n+576|0,0,18)|0;b[n+582>>1]=128;b[n+588>>1]=128;q=n+460|0;l=c[q>>2]|0;Aa=n+500|0;if(((l<<2)+6|0)>0){za=0;while(1){c[(c[Aa>>2]|0)+(za*12|0)+4>>2]=-1;xa=c[Aa>>2]|0;b[xa+(za*12|0)+8>>1]=0;a[xa+(za*12|0)|0]=0;xa=za+1|0;va=c[q>>2]|0;if((xa|0)<((va<<2)+6|0)){za=xa}else{Ea=va;break}}}else{Ea=l}c[(c[Aa>>2]|0)+(((Ea<<1)+2|0)*12|0)+4>>2]=0;c[(c[Aa>>2]|0)+((((c[q>>2]|0)*3|0)+4|0)*12|0)+4>>2]=0;za=c[o+32>>2]|0;va=c[o+36>>2]|0;xa=n+1700|0;ya=c[xa>>2]|0;ua=ya>>31&7;ra=n+464|0;qa=c[ra>>2]|0;if((qa|0)<=0){break}pa=n+1436|0;oa=n+1692|0;fa=n+552|0;ea=n+556|0;ga=n+560|0;la=n+564|0;na=n+568|0;ka=n+572|0;da=n+1704|0;ca=za<<3;aa=n+1708|0;_=n+468|0;$=n+472|0;Y=n+476|0;Z=n+480|0;X=n+484|0;H=n+488|0;W=k;U=n+596|0;S=n+1764|0;V=n+376|0;R=n+380|0;G=n+392|0;I=n+384|0;r=n+388|0;E=n+600|0;J=n+1376|0;z=J;y=n+1380|0;w=y;v=n+1384|0;t=v;s=n+1388|0;u=s;A=n+1392|0;O=n+1396|0;M=n+1400|0;L=n+1404|0;ia=n+1732|0;wa=M;sa=L;N=g|0;Ba=n+1376|0;ta=n+1378|0;ha=g+4|0;C=n+1380|0;F=n+1382|0;K=g+8|0;B=n+1384|0;Ca=n+1386|0;Da=g+12|0;D=n+1388|0;Fa=n+1390|0;Ga=n|0;Ha=n+1396|0;Ia=n+1392|0;Ja=n+1398|0;Ka=n+1394|0;La=a[1086616]|0;Ma=La<<24>>24>0;Na=n+1740|0;Oa=n+288|0;Pa=n+496|0;Qa=-h&6;Ra=6-(h<<1)|0;Sa=n+256|0;Ta=n+1120|0;Ua=n+1248|0;Va=n+52|0;Wa=n+260|0;Xa=n+1728|0;Ya=n+1416|0;Za=n+244|0;_a=n+372|0;$a=n+492|0;ab=n+280|0;bb=n+276|0;cb=n+1736|0;db=n+252|0;eb=n+1420|0;fb=n+36|0;gb=0;hb=qa;qa=ya;while(1){if((qa|0)<0){ib=hb+~gb|0}else{ib=gb}c[n+508>>2]=-1;b[n+512>>1]=0;a[n+504|0]=0;c[n+520>>2]=-1;b[n+524>>1]=0;a[n+516|0]=0;c[n+532>>2]=-1;b[n+536>>1]=0;a[n+528|0]=0;c[n+544>>2]=-1;b[n+548>>1]=0;a[n+540|0]=0;TGb(pa|0,0,256)|0;x=404232216;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;c[fa>>2]=1;c[ea>>2]=2;c[ga>>2]=1;c[la>>2]=2;ya=c[q>>2]|0;c[na>>2]=(ya<<1)+3;c[ka>>2]=(ya*3|0)+5;ya=ba(ib<<4|ua,za)|0;c[n+468+(c[da>>2]<<2)>>2]=ya;c[n+468+(c[aa>>2]<<2)>>2]=(c[n+468+(c[da>>2]<<2)>>2]|0)+ca;c[$>>2]=(c[_>>2]|0)+8;c[Z>>2]=(c[Y>>2]|0)+8;ya=ba(ib<<3|ua,va)|0;c[X>>2]=ya;c[H>>2]=ya;if((c[q>>2]|0)>0){ya=gb<<4;jb=0;do{if((c[(c[m>>2]|0)+84>>2]|0)==0){c[k>>2]=0;kb=a5a(n,gb,jb,1)|0;lb=c[U>>2]|0;mb=c[S>>2]|0;nb=a[mb+1512+(kb*100|0)+(lb*10|0)|0]|0;ob=c[V>>2]|0;pb=d[1086680+ob|0]|0;qb=c[R>>2]|0;rb=c[G>>2]|0;sb=ob<<pb;c[V>>2]=sb;ob=rb<<pb;rb=qb+pb|0;do{if((rb|0)>-1){pb=c[I>>2]|0;if(!(pb>>>0<(c[r>>2]|0)>>>0)){tb=ob;ub=rb;break}c[I>>2]=pb+2;qb=pb;tb=((de((d[qb]|d[qb+1|0]<<8)<<16>>16|0)|0)&65535)<<rb|ob;ub=rb-16|0}else{tb=ob;ub=rb}}while(0);c[R>>2]=ub;rb=((ba(sb-1|0,nb&255)|0)>>8)+1|0;ob=rb<<16;qb=tb>>>0>=ob>>>0;pb=qb?sb-rb|0:rb;c[V>>2]=pb;rb=tb-(qb?ob:0)|0;c[G>>2]=rb;if(qb){vb=lb}else{if(Ma){qb=1086616;ob=1086616;wb=pb;pb=ub;xb=rb;while(1){rb=a[(a[qb+1|0]|0)+(mb+1512+(kb*100|0)+(lb*10|0))|0]|0;yb=d[1086680+wb|0]|0;zb=wb<<yb;c[V>>2]=zb;Ab=xb<<yb;Bb=yb+pb|0;do{if((Bb|0)>-1){yb=c[I>>2]|0;if(!(yb>>>0<(c[r>>2]|0)>>>0)){Cb=Ab;Db=Bb;break}c[I>>2]=yb+2;Eb=yb;Cb=((de((d[Eb]|d[Eb+1|0]<<8)<<16>>16|0)|0)&65535)<<Bb|Ab;Db=Bb-16|0}else{Cb=Ab;Db=Bb}}while(0);c[R>>2]=Db;Bb=((ba(zb-1|0,rb&255)|0)>>8)+1|0;Ab=Bb<<16;T=Cb>>>0>=Ab>>>0;Q=T?zb-Bb|0:Bb;c[V>>2]=Q;Bb=Cb-(T?Ab:0)|0;c[G>>2]=Bb;if(T){Fb=qb+(a[ob]<<1)|0}else{Fb=qb+2|0}T=Fb|0;Ab=a[T]|0;if(Ab<<24>>24>0){qb=Fb;ob=T;wb=Q;pb=Db;xb=Bb}else{Gb=Ab;break}}}else{Gb=La}vb=-(Gb<<24>>24)|0}c[U>>2]=vb;xb=(ba(c[q>>2]|0,gb)|0)+jb|0;a[(c[E>>2]|0)+(xb<<3)|0]=vb;b:do{switch(c[U>>2]|0){case 7:{xb=0;pb=c[V>>2]|0;wb=c[R>>2]|0;ob=c[G>>2]|0;while(1){qb=d[1086680+pb|0]|0;lb=pb<<qb;c[V>>2]=lb;kb=ob<<qb;mb=qb+wb|0;do{if((mb|0)>-1){qb=c[I>>2]|0;if(!(qb>>>0<(c[r>>2]|0)>>>0)){Hb=kb;Ib=mb;break}c[I>>2]=qb+2;sb=qb;Hb=((de((d[sb]|d[sb+1|0]<<8)<<16>>16|0)|0)&65535)<<mb|kb;Ib=mb-16|0}else{Hb=kb;Ib=mb}}while(0);c[R>>2]=Ib;mb=lb+1>>1;kb=mb<<16;ja=Hb>>>0>=kb>>>0;if(ja){P=lb-mb|0;c[V>>2]=P;Jb=Hb-kb|0;Kb=P}else{c[V>>2]=mb;Jb=Hb;Kb=mb}c[G>>2]=Jb;mb=(ja&1)<<1;ja=d[1086680+Kb|0]|0;P=Kb<<ja;c[V>>2]=P;kb=Jb<<ja;ma=ja+Ib|0;do{if((ma|0)>-1){ja=c[I>>2]|0;if(!(ja>>>0<(c[r>>2]|0)>>>0)){Lb=kb;Mb=ma;break}c[I>>2]=ja+2;sb=ja;Lb=((de((d[sb]|d[sb+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|kb;Mb=ma-16|0}else{Lb=kb;Mb=ma}}while(0);c[R>>2]=Mb;ma=P+1>>1;kb=ma<<16;lb=Lb>>>0>=kb>>>0;if(lb){sb=P-ma|0;c[V>>2]=sb;Nb=Lb-kb|0;Ob=sb}else{c[V>>2]=ma;Nb=Lb;Ob=ma}c[G>>2]=Nb;ma=lb&1|mb;c[g+(xb<<2)>>2]=(ma|0)==0?0:ma+1|0;ma=xb+1|0;if((ma|0)<4){xb=ma;pb=Ob;wb=Mb;ob=Nb}else{break}}ob=c[N>>2]|0;if((ob|0)==0){b[Ba>>1]=0;b[ta>>1]=0}else if((ob|0)==2){ne[c[ia>>2]&1023](n,J)}else if((ob|0)==3){c[z>>2]=c[wa>>2]}else if((ob|0)==4){c[z>>2]=c[sa>>2]}ob=e[Ba>>1]|0;wb=e[ta>>1]|0;pb=c[ha>>2]|0;if((pb|0)==3){c[w>>2]=c[wa>>2]}else if((pb|0)==2){ne[c[ia>>2]&1023](n,y)}else if((pb|0)==0){b[C>>1]=0;b[F>>1]=0}else if((pb|0)==4){c[w>>2]=c[sa>>2]}pb=(e[C>>1]|0)+ob|0;ob=(e[F>>1]|0)+wb|0;wb=c[K>>2]|0;if((wb|0)==4){c[t>>2]=c[sa>>2]}else if((wb|0)==3){c[t>>2]=c[wa>>2]}else if((wb|0)==2){ne[c[ia>>2]&1023](n,v)}else if((wb|0)==0){b[B>>1]=0;b[Ca>>1]=0}wb=e[B>>1]|0;xb=e[Ca>>1]|0;zb=c[Da>>2]|0;if((zb|0)==0){b[D>>1]=0;b[Fa>>1]=0}else if((zb|0)==4){c[u>>2]=c[sa>>2]}else if((zb|0)==3){c[u>>2]=c[wa>>2]}else if((zb|0)==2){ne[c[ia>>2]&1023](n,s)}zb=(e[D>>1]<<16)+(pb+wb<<16)|0;wb=zb>>16;pb=(e[Fa>>1]<<16)+(ob+xb<<16)|0;xb=pb>>16;ob=(ba(c[q>>2]|0,gb)|0)+jb|0;c[(c[E>>2]|0)+(ob<<3)+4>>2]=c[u>>2];if((c[(c[(c[Ga>>2]|0)+12>>2]|0)+12>>2]|0)==91){ob=(((zb|0)>0?2:1)+wb|0)>>>2&65535;b[Ha>>1]=ob;b[Ia>>1]=ob;ob=(((pb|0)>0?2:1)+xb|0)>>>2&65535;b[Ja>>1]=ob;b[Ka>>1]=ob;break b}else{b[Ha>>1]=(wb|0)/4|0;b[Ja>>1]=(xb|0)/4|0;c[A>>2]=c[O>>2];break b}break};case 9:{a5a(n,gb,jb,2)|0;Pb=L;Qb=129;break};case 2:{ne[c[ia>>2]&1023](n,W);Pb=W;Qb=129;break};case 6:{a5a(n,gb,jb,2)|0;ne[c[ia>>2]&1023](n,W);Pb=W;Qb=129;break};case 3:{Pb=M;Qb=129;break};case 4:{Pb=L;Qb=129;break};case 8:{a5a(n,gb,jb,2)|0;Pb=M;Qb=129;break};default:{Pb=W;Qb=129}}}while(0);if((Qb|0)==129){Qb=0;xb=(ba(c[q>>2]|0,gb)|0)+jb|0;wb=Pb;c[(c[E>>2]|0)+(xb<<3)+4>>2]=c[wb>>2];xb=c[wb>>2]|0;c[z>>2]=xb;c[w>>2]=xb;c[t>>2]=xb;c[u>>2]=xb;c[A>>2]=xb;c[O>>2]=xb}Rb=c[U>>2]|0}else{Rb=1}xb=c[1085552+(Rb<<2)>>2]|0;me[c[Na>>2]&511](n);wb=d[Oa]|0;ob=0;do{pb=c[n+552+(ob<<2)>>2]|0;zb=c[Aa>>2]|0;rb=d[1087256+ob|0]|0;ma=n+504+(rb*12|0)+4|0;if((c[ma>>2]|0)==(xb|0)){Sb=b[n+504+(rb*12|0)+8>>1]|0;Tb=1}else{Sb=0;Tb=0}lb=zb+(pb*12|0)+4|0;if((c[lb>>2]|0)==(xb|0)){Ub=(b[zb+(pb*12|0)+8>>1]|0)+Sb|0;Vb=Tb+1|0}else{Ub=Sb;Vb=Tb}do{if((c[(c[(c[Ga>>2]|0)+12>>2]|0)+12>>2]|0)==91){sb=pb-1|0;if((Vb|0)>=2){Wb=Ub;Xb=Vb;break}if((c[zb+(sb*12|0)+4>>2]|0)==(xb|0)){Yb=(b[zb+(sb*12|0)+8>>1]|0)+Ub|0;Zb=Vb+1|0}else{Yb=Ub;Zb=Vb}if((Zb|0)>=2){Wb=Yb;Xb=Zb;break}sb=pb+1|0;if((c[zb+(sb*12|0)+4>>2]|0)!=(xb|0)){Wb=Yb;Xb=Zb;break}Wb=(b[zb+(sb*12|0)+8>>1]|0)+Yb|0;Xb=Zb+1|0}else{Wb=Ub;Xb=Vb}}while(0);if((Xb|0)==0){_b=b[n+576+((d[1087264+ob|0]|0)*6|0)+(xb<<1)>>1]|0}else if((Xb|0)==2){_b=(Wb|0)/2|0}else{_b=Wb}sb=n+608+(ob<<7)+(wb<<1)|0;kb=(e[sb>>1]|0)+_b&65535;b[sb>>1]=kb;b[n+576+((d[1087264+ob|0]|0)*6|0)+(xb<<1)>>1]=kb;b[zb+(pb*12|0)+8>>1]=b[sb>>1]|0;c[lb>>2]=xb;b[n+504+(rb*12|0)+8>>1]=b[sb>>1]|0;c[ma>>2]=xb;b[sb>>1]=ba(b[sb>>1]|0,b[Pa>>1]|0)|0;ob=ob+1|0;}while((ob|0)<6);ob=c[m>>2]|0;wb=c[n+352+(xb<<2)>>2]|0;c:do{if((Rb|0)==1){$b=0;Qb=151}else{if((c[wb>>2]|0)==0){break}switch(Rb|0){case 2:case 3:case 4:case 6:case 7:case 8:case 9:{break};case 1:{$b=0;Qb=151;break c;break};case 0:case 5:{sb=0;while(1){kb=d[1087264+(sb+Qa)|0]|0;ja=c[n+468+(sb<<2)>>2]|0;qb=ob+(kb<<2)|0;nb=n+1712+(kb<<2)|0;cf[c[Va>>2]&1023]((c[qb>>2]|0)+ja|0,(c[wb+(kb<<2)>>2]|0)+ja|0,c[nb>>2]|0,8);Xe[c[Wa>>2]&4095]((c[qb>>2]|0)+ja|0,c[nb>>2]|0,n+608+(sb<<7)|0);nb=sb+1|0;if((nb|0)<(Ra|0)){sb=nb}else{Qb=185;break c}}break};default:{Qb=185;break c}}sb=jb<<4;ma=0;while(1){if((ma|0)==1){ac=8;Qb=155}else{rb=(ma|0)==3?8:0;if((ma|0)==2){bc=8;cc=rb}else{ac=rb;Qb=155}}if((Qb|0)==155){Qb=0;bc=(ma|0)==3?8:0;cc=ac}rb=d[1087264+(ma+Qa)|0]|0;lb=c[wb+(rb<<2)>>2]|0;pb=n+1712+(rb<<2)|0;zb=c[pb>>2]|0;nb=cc|sb;ja=bc|ya;qb=c[m>>2]|0;kb=n+468+(ma<<2)|0;Ab=c[kb>>2]|0;Bb=(c[qb+(rb<<2)>>2]|0)+Ab|0;Q=d[(c[Xa>>2]|0)+ma|0]|0;T=Q-1|0;Eb=c[Ya>>2]|0;yb=c[(c[Ga>>2]|0)+848>>2]|0;do{if((yb|0)>47){Qb=159}else{if((yb|0)<=31){dc=Eb;break}if((c[qb+84>>2]|0)==0){Qb=159}else{dc=Eb}}}while(0);if((Qb|0)==159){Qb=0;dc=0}Eb=n+1376+(ma<<2)|0;qb=Eb|0;yb=(b[qb>>1]|0)/(Q|0)|0;mb=n+1376+(ma<<2)+2|0;P=(b[mb>>1]|0)/(Q|0)|0;if((ma|0)>3){ec=(nb|0)/2|0;fc=(ja|0)/2|0}else{ec=nb;fc=ja}gc=yb-2|0;hc=ec+gc|0;ic=P-2|0;jc=fc+ic|0;do{if((hc|0)<0){kc=c[n+428+(rb<<2)>>2]|0;Qb=166}else{lc=c[n+428+(rb<<2)>>2]|0;if((hc+12|0)>=(lc|0)|(jc|0)<0){kc=lc;Qb=166;break}if((jc+12|0)>=(c[n+444+(rb<<2)>>2]|0)){kc=lc;Qb=166;break}if((dc|0)==0){mc=yb+Ab+(ba(P,zb)|0)|0;nc=lb;break}else{lc=lb+(gc+Ab+(ba(ic,zb)|0))|0;cf[c[fb>>2]&1023](c[_a>>2]|0,lc,zb,12);Qb=170;break}}}while(0);if((Qb|0)==166){Qb=0;ja=lb+(gc+Ab+(ba(ic,zb)|0))|0;Ne[c[Za>>2]&127](c[_a>>2]|0,ja,zb,zb,12,12,hc,jc,kc,c[n+444+(rb<<2)>>2]|0);Qb=170}do{if((Qb|0)==170){Qb=0;ja=c[_a>>2]|0;nb=(zb<<1)+2|0;if((dc|0)==0){mc=nb;nc=ja;break}Q=yb&7;lc=P&7;oc=d[1086944+(c[$a>>2]|0)|0]|0;if((Q|0)!=0){Xe[c[bb>>2]&4095](ja+(10-Q)|0,zb,oc)}if((lc|0)==0){mc=nb;nc=ja;break}Q=ja+(ba(10-lc|0,zb)|0)|0;Xe[c[ab>>2]&4095](Q,zb,oc);mc=nb;nc=ja}}while(0);P=b[qb>>1]|0;if((P<<16>>16&T|0)==0){pc=0}else{pc=P<<16>>16>0?1:-1}P=b[mb>>1]|0;if((P<<16>>16&T|0)==0){qc=pc}else{qc=(P<<16>>16>0?zb:-zb|0)+pc|0}do{if((qc|0)==0){cf[c[Va>>2]&1023](Bb,nc+mc|0,zb,8)}else{P=c[cb>>2]|0;if((P|0)==0){le[c[db>>2]&1023](Bb,nc+mc|0,nc+(qc+mc)|0,zb,8);break}else{Ne[P&127](n,Bb,nc,mc,qc+mc|0,zb,Eb,T,c[eb>>2]|0,(ma|0)<4|0);break}}}while(0);Xe[c[Wa>>2]&4095]((c[ob+(rb<<2)>>2]|0)+(c[kb>>2]|0)|0,c[pb>>2]|0,n+608+(ma<<7)|0);T=ma+1|0;if((T|0)<(Ra|0)){ma=T}else{Qb=185;break}}}}while(0);if((Qb|0)==151){while(1){Qb=0;wb=d[1087264+($b+Qa)|0]|0;Xe[c[Sa>>2]&4095]((c[ob+(wb<<2)>>2]|0)+(c[n+468+($b<<2)>>2]|0)|0,c[n+1712+(wb<<2)>>2]|0,n+608+($b<<7)|0);wb=$b+1|0;if((wb|0)<(Ra|0)){$b=wb;Qb=151}else{Qb=185;break}}}do{if((Qb|0)==185){Qb=0;if(!f){break}b[Ta>>1]=0;b[Ua>>1]=0}}while(0);c[fa>>2]=(c[fa>>2]|0)+2;c[_>>2]=(c[_>>2]|0)+16;c[ea>>2]=(c[ea>>2]|0)+2;c[$>>2]=(c[$>>2]|0)+16;c[ga>>2]=(c[ga>>2]|0)+2;c[Y>>2]=(c[Y>>2]|0)+16;c[la>>2]=(c[la>>2]|0)+2;c[Z>>2]=(c[Z>>2]|0)+16;c[na>>2]=(c[na>>2]|0)+1;c[X>>2]=(c[X>>2]|0)+8;c[ka>>2]=(c[ka>>2]|0)+1;c[H>>2]=(c[H>>2]|0)+8;jb=jb+1|0;}while((jb|0)<(c[q>>2]|0))}jb=gb+1|0;ya=c[ra>>2]|0;if((jb|0)>=(ya|0)){break a}gb=jb;hb=ya;qa=c[xa>>2]|0}}}while(0);if((c[p>>2]|0)==0){if((c[n+424>>2]|0)!=0){Qb=192}}else{Qb=192}do{if((Qb|0)==192){p=n+360|0;KCb(c[p>>2]|0);f=MCb(c[p>>2]|0,o)|0;if((f|0)<0){rc=f}else{break}i=j;return rc|0}}while(0);o=n+356|0;KCb(c[o>>2]|0);n=c[o>>2]|0;c[o>>2]=c[m>>2];c[m>>2]=n;rc=0;i=j;return rc|0}function Y4a(a,b,d){a=a|0;b=b|0;d=d|0;return Z4a(a,c[a+60>>2]|0,b,d)|0}function Z4a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c[d>>2]=b;g=b+140|0;c[g>>2]=(f|0)!=0?35:0;if((c[b+944>>2]|0)!=0){c[g>>2]=0}pea(d+4|0,8);g=b+88|0;BFa(d+36|0,c[g>>2]|0);T3a(d+244|0,8);H4a(d+252|0,c[g>>2]|0);b5a(d+276|0,c[(c[b+12>>2]|0)+12>>2]|0);g=0;while(1){h=a[1075976+g|0]|0;a[d+288+g|0]=h<<3&56|(h&255)>>>3;h=g+1|0;if((h|0)<64){g=h}else{i=0;break}}while(1){if(!(i>>>0<4>>>0)){break}g=ICb()|0;c[d+352+(i<<2)>>2]=g;if((g|0)==0){j=7;break}else{i=i+1|0}}if((j|0)==7){j=c[b+60>>2]|0;$Db(j+500|0);$Db(j+600|0);$Db(j+368|0);JCb(j+352|0);JCb(j+356|0);JCb(j+360|0);JCb(j+364|0);k=-12;return k|0}c[d+368>>2]=0;c[d+500>>2]=0;c[d+600>>2]=0;c[d+492>>2]=-1;c[d+1416>>2]=1;c[d+424>>2]=0;c[d+1736>>2]=0;c[d+1696>>2]=f;c[d+1764>>2]=d+1768;f=d+1700|0;if((e|0)==0){c[f>>2]=1;c[d+1704>>2]=0;c[d+1708>>2]=2;k=0;return k|0}else{c[f>>2]=-1;c[d+1704>>2]=2;c[d+1708>>2]=0;k=0;return k|0}return 0}function _4a(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+500|0);$Db(b+600|0);$Db(b+368|0);JCb(b+352|0);JCb(b+356|0);JCb(b+360|0);JCb(b+364|0);return 0}function $4a(a){a=a|0;$Db(a+500|0);$Db(a+600|0);$Db(a+368|0);JCb(a+352|0);JCb(a+356|0);JCb(a+360|0);JCb(a+364|0);return 0}function a5a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=i;i=i+8|0;k=j|0;l=k;c[k>>2]=0;c[k+4>>2]=0;m=e+460|0;n=e+464|0;o=e+600|0;p=k;q=k+2|0;r=e+1408|0;s=0;t=0;a:while(1){u=(a[1087233+(s<<1)|0]|0)+f|0;v=(a[1087232+(s<<1)|0]|0)+g<<16;w=v>>16;do{if((v|0)<0){x=t}else{y=c[m>>2]|0;if((w|0)>=(y|0)){x=t;break}z=u<<16;A=z>>16;if((z|0)<0){x=t;break}if((A|0)>=(c[n>>2]|0)){x=t;break}z=(ba(y,A)|0)+w|0;A=c[o>>2]|0;if((c[1085552+(d[A+(z<<3)|0]<<2)>>2]|0)!=(h|0)){x=t;break}y=b[A+(z<<3)+4>>1]|0;if(y<<16>>16==(b[p>>1]|0)){if((b[A+(z<<3)+6>>1]|0)==(b[q>>1]|0)){x=t;break}}if(y<<16>>16==0){if((b[A+(z<<3)+6>>1]|0)==0){x=t;break}}c[l+(t<<2)>>2]=c[A+(z<<3)+4>>2];if((t|0)>0){B=-1;C=14;break a}c[r>>2]=s;x=t+1|0}}while(0);w=s+1|0;if((w|0)<12){s=w;t=x}else{B=x;C=14;break}}if((C|0)==14){c[e+1400>>2]=c[k>>2];c[e+1404>>2]=c[l+4>>2];i=j;return B+1|0}return 0}function b5a(a,b){a=a|0;b=b|0;var d=0;d=a|0;if((b|0)==91){c[d>>2]=490;c[a+4>>2]=872;return}else{c[d>>2]=320;c[a+4>>2]=1284;c[a+8>>2]=408;return}}function c5a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=e<<1;g=0;h=b;while(1){b=d[h]|0;i=h-1|0;j=d[i]|0;k=(d[h-2|0]|0)+4-(d[h+1|0]|0)+((b-j|0)*3|0)|0;l=k>>31;m=(l^k>>3)-l|0;k=(m&-((m|0)<(f|0)|0))-e|0;m=k>>31;n=l+e+m-(m^k)^l;l=n+j|0;if(l>>>0>255>>>0){o=-l>>31&255}else{o=l&255}a[i]=o;i=b-n|0;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[h]=p;i=g+1|0;if((i|0)<12){g=i;h=h+c|0}else{break}}return}function d5a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=-(c<<1)|0;g=-c|0;h=e<<1;i=0;j=b;while(1){b=j+g|0;k=d[b]|0;l=(d[j+f|0]|0)+4-(d[j+c|0]|0)+(((d[j]|0)-k|0)*3|0)|0;m=l>>31;n=(m^l>>3)-m|0;l=(n&-((n|0)<(h|0)|0))-e|0;n=l>>31;o=m+e+n-(n^l)^m;m=o+k|0;if(m>>>0>255>>>0){p=-m>>31&255}else{p=m&255}a[b]=p;b=(d[j]|0)-o|0;if(b>>>0>255>>>0){q=-b>>31&255}else{q=b&255}a[j]=q;b=i+1|0;if((b|0)<12){i=b;j=j+1|0}else{break}}return}function e5a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=~e;g=e-1|0;h=e<<1;e=0;i=b;while(1){b=d[i]|0;j=i-1|0;k=d[j]|0;l=(d[i-2|0]|0)+4-(d[i+1|0]|0)+((b-k|0)*3|0)|0;m=l>>3;n=l>>31;l=(n^m)-n|0;if((l+f|0)>>>0<g>>>0){o=n+h-l^n}else{o=m}m=k+o|0;if(m>>>0>255>>>0){p=-m>>31&255}else{p=m&255}a[j]=p;j=b-o|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[i]=q;j=e+1|0;if((j|0)<12){e=j;i=i+c|0}else{break}}return}function f5a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=-(c<<1)|0;g=-c|0;h=~e;i=e-1|0;j=e<<1;e=0;k=b;while(1){b=k+g|0;l=d[b]|0;m=(d[k+f|0]|0)+4-(d[k+c|0]|0)+(((d[k]|0)-l|0)*3|0)|0;n=m>>3;o=m>>31;m=(o^n)-o|0;if((m+h|0)>>>0<i>>>0){p=o+j-m^o}else{p=n}n=l+p|0;if(n>>>0>255>>>0){q=-n>>31&255}else{q=n&255}a[b]=q;b=(d[k]|0)-p|0;if(b>>>0>255>>>0){r=-b>>31&255}else{r=b&255}a[k]=r;b=e+1|0;if((b|0)<12){e=b;k=k+1|0}else{break}}return}function g5a(a,b,e){a=a|0;b=b|0;e=e|0;c[a>>2]=255;c[a+4>>2]=-16;c[a+12>>2]=b+e;c[a+8>>2]=b+3;c[a+16>>2]=(d[b+1|0]|0)<<8|(d[b]|0)<<16|(d[b+2|0]|0);return}function h5a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+60>>2]|0;d=c[(c[a+12>>2]|0)+12>>2]|0;e=Y4a(a,(d|0)==92|0,(d|0)==107|0)|0;if((e|0)<0){f=e;return f|0}c[b+1416>>2]=0;c[b+1728>>2]=127752;c[b+1732>>2]=92;c[b+1736>>2]=38;c[b+1744>>2]=174;c[b+1748>>2]=166;c[b+1752>>2]=422;c[b+1756>>2]=40;e=b+1696|0;if((c[e>>2]|0)==0){f=0;return f|0}d=cEb(4480)|0;g=b+1760|0;c[g>>2]=d;Z4a(a,d,(c[b+1700>>2]|0)==-1|0,c[e>>2]|0)|0;e=c[g>>2]|0;c[e+1416>>2]=0;c[e+1728>>2]=127752;c[e+1732>>2]=92;c[e+1736>>2]=38;c[e+1744>>2]=174;c[e+1748>>2]=166;c[e+1752>>2]=422;c[e+1756>>2]=40;f=0;return f|0}function i5a(a){a=a|0;var b=0;b=c[a+60>>2]|0;_4a(a)|0;j5a(b);a=b+1760|0;b=c[a>>2]|0;if((b|0)==0){return 0}$4a(b)|0;j5a(c[a>>2]|0);ZDb(c[a>>2]|0);return 0}function j5a(a){a=a|0;Q_(a+3664|0);Q_(a+3704|0);Q_(a+3744|0);Q_(a+3764|0);Q_(a+3784|0);Q_(a+3804|0);Q_(a+3824|0);Q_(a+3844|0);Q_(a+3864|0);Q_(a+3884|0);Q_(a+3904|0);Q_(a+3924|0);Q_(a+3944|0);Q_(a+3964|0);Q_(a+3984|0);Q_(a+4004|0);Q_(a+4024|0);Q_(a+4044|0);Q_(a+4064|0);Q_(a+4084|0);Q_(a+3684|0);Q_(a+3724|0);Q_(a+4104|0);Q_(a+4124|0);Q_(a+4144|0);Q_(a+4164|0);Q_(a+4184|0);Q_(a+4204|0);Q_(a+4224|0);Q_(a+4244|0);Q_(a+4264|0);Q_(a+4284|0);Q_(a+4304|0);Q_(a+4324|0);Q_(a+4344|0);Q_(a+4364|0);Q_(a+4384|0);Q_(a+4404|0);Q_(a+4424|0);Q_(a+4444|0);return}function k5a(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;g=c[e+1764>>2]|0;h=f|0;b[h>>1]=0;i=f+2|0;b[i>>1]=0;if((c[e+1408>>2]|0)<2){j=c[e+1400>>2]|0;c[f>>2]=j;k=j&65535;l=j>>>16&65535}else{k=0;l=0}j=e+376|0;f=e+380|0;m=e+392|0;n=e+384|0;o=e+388|0;e=a[1085592]|0;p=e<<24>>24>0;q=0;r=c[j>>2]|0;s=c[f>>2]|0;t=c[m>>2]|0;u=k;k=l;while(1){l=a[g+130+q|0]|0;v=d[1086680+r|0]|0;w=r<<v;c[j>>2]=w;x=t<<v;y=s+v|0;do{if((y|0)>-1){v=c[n>>2]|0;if(!(v>>>0<(c[o>>2]|0)>>>0)){z=x;A=y;break}c[n>>2]=v+2;B=v;z=((de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)<<y|x;A=y-16|0}else{z=x;A=y}}while(0);c[f>>2]=A;y=((ba(w-1|0,l&255)|0)>>8)+1|0;x=y<<16;B=z>>>0>=x>>>0;v=B?w-y|0:y;c[j>>2]=v;y=z-(B?x:0)|0;c[m>>2]=y;do{if(B){x=0;C=0;D=v;E=A;F=y;while(1){G=d[127416+x|0]|0;H=a[g+150+(q<<3)+G|0]|0;I=d[1086680+D|0]|0;J=D<<I;c[j>>2]=J;K=F<<I;L=E+I|0;do{if((L|0)>-1){I=c[n>>2]|0;if(!(I>>>0<(c[o>>2]|0)>>>0)){M=K;N=L;break}c[n>>2]=I+2;O=I;M=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<L|K;N=L-16|0}else{M=K;N=L}}while(0);c[f>>2]=N;L=((ba(J-1|0,H&255)|0)>>8)+1|0;K=L<<16;O=M>>>0>=K>>>0;P=O?J-L|0:L;c[j>>2]=P;Q=M-(O?K:0)|0;c[m>>2]=Q;R=(O&1)<<G|C;O=x+1|0;if(O>>>0<7>>>0){x=O;C=R;D=P;E=N;F=Q}else{break}}if((R&240|0)==0){S=R|8;T=P;U=N;V=Q;W=28;break}F=a[g+150+(q<<3)+3|0]|0;E=d[1086680+P|0]|0;D=P<<E;c[j>>2]=D;C=Q<<E;x=N+E|0;do{if((x|0)>-1){E=c[n>>2]|0;if(!(E>>>0<(c[o>>2]|0)>>>0)){X=C;Y=x;break}c[n>>2]=E+2;O=E;X=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<x|C;Y=x-16|0}else{X=C;Y=x}}while(0);c[f>>2]=Y;x=((ba(D-1|0,F&255)|0)>>8)+1|0;C=x<<16;O=X>>>0>=C>>>0;E=O?D-x|0:x;c[j>>2]=E;x=X-(O?C:0)|0;c[m>>2]=x;Z=(O&1)<<3|R;_=E;$=Y;aa=x;W=27}else{if(p){x=1085592;E=1085592;O=v;C=A;K=y;while(1){L=a[(a[x+1|0]|0)+(g+136+(q*7|0))|0]|0;I=d[1086680+O|0]|0;ca=O<<I;c[j>>2]=ca;da=K<<I;ea=I+C|0;do{if((ea|0)>-1){I=c[n>>2]|0;if(!(I>>>0<(c[o>>2]|0)>>>0)){fa=da;ga=ea;break}c[n>>2]=I+2;ha=I;fa=((de((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535)<<ea|da;ga=ea-16|0}else{fa=da;ga=ea}}while(0);c[f>>2]=ga;ea=((ba(ca-1|0,L&255)|0)>>8)+1|0;da=ea<<16;G=fa>>>0>=da>>>0;J=G?ca-ea|0:ea;c[j>>2]=J;ea=fa-(G?da:0)|0;c[m>>2]=ea;if(G){ia=x+(a[E]<<1)|0}else{ia=x+2|0}G=ia|0;da=a[G]|0;if(da<<24>>24>0){x=ia;E=G;O=J;C=ga;K=ea}else{ja=da;ka=J;la=ga;ma=ea;break}}}else{ja=e;ka=v;la=A;ma=y}Z=-(ja<<24>>24)|0;_=ka;$=la;aa=ma;W=27}}while(0);if((W|0)==27){W=0;if((Z|0)==0){na=0;oa=_;pa=$;qa=aa}else{S=Z;T=_;U=$;V=aa;W=28}}if((W|0)==28){W=0;y=a[g+128+q|0]|0;v=d[1086680+T|0]|0;B=T<<v;c[j>>2]=B;w=V<<v;l=U+v|0;do{if((l|0)>-1){v=c[n>>2]|0;if(!(v>>>0<(c[o>>2]|0)>>>0)){ra=w;sa=l;break}c[n>>2]=v+2;K=v;ra=((de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535)<<l|w;sa=l-16|0}else{ra=w;sa=l}}while(0);c[f>>2]=sa;l=((ba(B-1|0,y&255)|0)>>8)+1|0;w=l<<16;K=ra>>>0>=w>>>0;v=K?B-l|0:l;c[j>>2]=v;l=ra-(K?w:0)|0;c[m>>2]=l;na=K?-S|0:S;oa=v;pa=sa;qa=l}if((q|0)==0){l=(u&65535)+na&65535;b[h>>1]=l;q=q+1|0;r=oa;s=pa;t=qa;u=l;k=k;continue}else{l=(k&65535)+na&65535;b[i>>1]=l;v=q+1|0;if((v|0)<2){q=v;r=oa;s=pa;t=qa;u=u;k=l;continue}else{break}}}return}function l5a(e,f,g,h,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;p=i;q=l;l=i;i=i+4|0;i=i+7&-8;c[l>>2]=c[q>>2];q=b[l>>1]|0;r=q<<16>>16;s=r&m;t=b[l+2>>1]|0;l=t<<16>>16;u=l&m;do{if((o|0)==0){v=u;w=s;x=0}else{m=s<<1;y=u<<1;z=c[e+1424>>2]|0;if((z|0)!=2){v=y;w=m;x=z;break}z=c[e+1428>>2]|0;if((z|0)!=0){if(((q<<16>>16>-1?r:-r|0)|0)>(z|0)){v=y;w=m;x=0;break}if(((t<<16>>16>-1?l:-l|0)|0)>(z|0)){v=y;w=m;x=0;break}}z=c[e+1432>>2]|0;if((z|0)==0){v=y;w=m;x=2;break}A=k<<1;B=d[g+h|0]|0;C=ba(B,B)|0;D=h+2|0;E=d[g+D|0]|0;F=(ba(E,E)|0)+C|0;C=h+4|0;G=d[g+C|0]|0;H=F+(ba(G,G)|0)|0;F=h+6|0;I=d[g+F|0]|0;J=H+(ba(I,I)|0)|0;H=d[g+(A+h)|0]|0;K=J+(ba(H,H)|0)|0;J=d[g+(D+A)|0]|0;L=K+(ba(J,J)|0)|0;K=d[g+(C+A)|0]|0;M=L+(ba(K,K)|0)|0;L=d[g+(F+A)|0]|0;N=M+(ba(L,L)|0)|0;M=k<<2;O=d[g+(M+h)|0]|0;P=N+(ba(O,O)|0)|0;N=d[g+((M|2)+h)|0]|0;Q=P+(ba(N,N)|0)|0;P=d[g+(C+M)|0]|0;R=Q+(ba(P,P)|0)|0;Q=d[g+(F+M)|0]|0;S=R+(ba(Q,Q)|0)|0;R=M+A|0;A=d[g+(R+h)|0]|0;M=S+(ba(A,A)|0)|0;S=d[g+(D+R)|0]|0;D=M+(ba(S,S)|0)|0;M=d[g+(C+R)|0]|0;C=D+(ba(M,M)|0)|0;D=d[g+(F+R)|0]|0;R=E+B+G+I+H+J+K+L+O+N+P+Q+A+S+M+D|0;M=((C+(ba(D,D)|0)<<4)-(ba(R,R)|0)>>8|0)<(z|0);v=y;w=m;x=M?0:2}}while(0);l=(v|0)!=0;if(l){if((ba(c[e+1700>>2]|0,j-h|0)|0)<0){T=11}else{U=h}}else{if((h|0)>(j|0)){T=11}else{U=h}}if((T|0)==11){U=j}if((x|0)==0){if((w|0)==0|l^1){Se[c[e+4>>2]&511](f,g+U|0,k,8,w,v);i=p;return}else{x=(c[e+372>>2]|0)+16|0;j=e+4|0;Se[c[j>>2]&511](x,g+(((t^q)<<16>>16>>31)+U)|0,k,9,w,0);Se[c[j>>2]&511](f,x,k,8,0,v);i=p;return}}if(!l){l=b[127888+(n<<6)+(w<<3)>>1]|0;x=b[127888+(n<<6)+(w<<3)+2>>1]|0;j=b[127888+(n<<6)+(w<<3)+4>>1]|0;T=b[127888+(n<<6)+(w<<3)+6>>1]|0;h=g+U|0;r=f;u=0;while(1){s=0;while(1){o=ba(l,d[h+(s-1)|0]|0)|0;M=ba(x,d[h+s|0]|0)|0;m=s+1|0;y=ba(j,d[h+m|0]|0)|0;z=o+64+M+y+(ba(T,d[h+(s+2)|0]|0)|0)>>7;if(z>>>0>255>>>0){V=-z>>31&255}else{V=z&255}a[r+s|0]=V;if((m|0)<8){s=m}else{break}}s=u+1|0;if((s|0)<8){h=h+k|0;r=r+k|0;u=s}else{break}}i=p;return}if((w|0)!=0){le[c[e+284>>2]&1023](f,g+(((t^q)<<16>>16>>31)+U)|0,k,127888+(n<<6)+(w<<3)|0,127888+(n<<6)+(v<<3)|0);i=p;return}w=k<<1;q=b[127888+(n<<6)+(v<<3)>>1]|0;t=b[127888+(n<<6)+(v<<3)+2>>1]|0;e=b[127888+(n<<6)+(v<<3)+4>>1]|0;u=b[127888+(n<<6)+(v<<3)+6>>1]|0;v=g+U|0;U=f;f=0;while(1){g=0;do{n=ba(q,d[v+(g-k)|0]|0)|0;r=ba(t,d[v+g|0]|0)|0;h=ba(e,d[v+(g+k)|0]|0)|0;V=n+64+r+h+(ba(u,d[v+(g+w)|0]|0)|0)>>7;if(V>>>0>255>>>0){W=-V>>31&255}else{W=V&255}a[U+g|0]=W;g=g+1|0;}while((g|0)<8);g=f+1|0;if((g|0)<8){v=v+k|0;U=U+k|0;f=g}else{break}}i=p;return}function m5a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+1764|0;b=c[e>>2]|0;a[b+130|0]=-94;a[b+131|0]=-92;a[b+128|0]=-128;a[b+129|0]=-128;UGb(b+1812|0,1087008,60)|0;UGb(b+150|0,127528,16)|0;UGb(b+136|0,127512,14)|0;UGb(b+1484|0,127480,28)|0;UGb(b|0,127544,64)|0;a[(c[e>>2]|0)+64|0]=0;b=0;f=1;while(1){g=1;h=f;while(1){i=c[e>>2]|0;if((d[i+g|0]|0|0)==(b|0)){a[i+64+h|0]=g;j=h+1|0}else{j=h}i=g+1|0;if((i|0)<64){g=i;h=j}else{break}}h=b+1|0;if((h|0)<16){b=h;f=j}else{break}}return}function n5a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;e=c[b+1764>>2]|0;f=b+376|0;g=b+380|0;h=b+392|0;i=b+384|0;j=b+388|0;b=0;while(1){k=a[126920+(b<<1)|0]|0;l=c[f>>2]|0;m=d[1086680+l|0]|0;n=c[g>>2]|0;o=c[h>>2]|0;p=l<<m;c[f>>2]=p;l=o<<m;o=n+m|0;do{if((o|0)>-1){m=c[i>>2]|0;if(!(m>>>0<(c[j>>2]|0)>>>0)){q=l;r=o;break}c[i>>2]=m+2;n=m;q=((de((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<o|l;r=o-16|0}else{q=l;r=o}}while(0);c[g>>2]=r;o=((ba(p-1|0,k&255)|0)>>8)+1|0;l=o<<16;n=q>>>0>=l>>>0;m=n?p-o|0:o;c[f>>2]=m;o=q-(n?l:0)|0;c[h>>2]=o;if(n){n=7;l=0;s=m;t=r;u=o;while(1){v=n-1|0;w=l<<1;x=d[1086680+s|0]|0;y=s<<x;c[f>>2]=y;z=u<<x;A=x+t|0;do{if((A|0)>-1){x=c[i>>2]|0;if(!(x>>>0<(c[j>>2]|0)>>>0)){B=z;C=A;break}c[i>>2]=x+2;D=x;B=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<A|z;C=A-16|0}else{B=z;C=A}}while(0);c[g>>2]=C;A=y+1>>1;z=A<<16;D=B>>>0>=z>>>0;if(D){x=y-A|0;c[f>>2]=x;E=B-z|0;F=x}else{c[f>>2]=A;E=B;F=A}c[h>>2]=E;G=D&1|w;if((v|0)==0){break}else{n=v;l=G;s=F;t=C;u=E}}u=G<<1;a[e+130+b|0]=(u|0)==0|u;H=c[f>>2]|0;I=c[g>>2]|0;J=c[h>>2]|0}else{H=m;I=r;J=o}u=a[126921+(b<<1)|0]|0;t=d[1086680+H|0]|0;s=H<<t;c[f>>2]=s;l=J<<t;n=I+t|0;do{if((n|0)>-1){t=c[i>>2]|0;if(!(t>>>0<(c[j>>2]|0)>>>0)){K=l;L=n;break}c[i>>2]=t+2;p=t;K=((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)<<n|l;L=n-16|0}else{K=l;L=n}}while(0);c[g>>2]=L;n=((ba(s-1|0,u&255)|0)>>8)+1|0;l=n<<16;o=K>>>0>=l>>>0;m=o?s-n|0:n;c[f>>2]=m;n=K-(o?l:0)|0;c[h>>2]=n;if(o){o=7;l=0;p=m;m=L;t=n;while(1){n=o-1|0;k=l<<1;D=d[1086680+p|0]|0;A=p<<D;c[f>>2]=A;x=t<<D;z=D+m|0;do{if((z|0)>-1){D=c[i>>2]|0;if(!(D>>>0<(c[j>>2]|0)>>>0)){M=x;N=z;break}c[i>>2]=D+2;O=D;M=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<z|x;N=z-16|0}else{M=x;N=z}}while(0);c[g>>2]=N;z=A+1>>1;x=z<<16;v=M>>>0>=x>>>0;if(v){w=A-z|0;c[f>>2]=w;P=M-x|0;Q=w}else{c[f>>2]=z;P=M;Q=z}c[h>>2]=P;R=v&1|k;if((n|0)==0){break}else{o=n;l=R;p=Q;m=N;t=P}}t=R<<1;a[e+128+b|0]=(t|0)==0|t}t=b+1|0;if((t|0)<2){b=t}else{S=0;break}}while(1){b=0;do{R=a[127360+(S*7|0)+b|0]|0;P=c[f>>2]|0;N=d[1086680+P|0]|0;Q=c[g>>2]|0;M=c[h>>2]|0;L=P<<N;c[f>>2]=L;P=M<<N;M=Q+N|0;do{if((M|0)>-1){N=c[i>>2]|0;if(!(N>>>0<(c[j>>2]|0)>>>0)){T=P;U=M;break}c[i>>2]=N+2;Q=N;T=((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<M|P;U=M-16|0}else{T=P;U=M}}while(0);c[g>>2]=U;M=((ba(L-1|0,R&255)|0)>>8)+1|0;P=M<<16;n=T>>>0>=P>>>0;k=n?L-M|0:M;c[f>>2]=k;M=T-(n?P:0)|0;c[h>>2]=M;if(n){n=7;P=0;A=k;k=U;Q=M;while(1){M=n-1|0;N=P<<1;K=d[1086680+A|0]|0;I=A<<K;c[f>>2]=I;J=Q<<K;H=K+k|0;do{if((H|0)>-1){K=c[i>>2]|0;if(!(K>>>0<(c[j>>2]|0)>>>0)){V=J;W=H;break}c[i>>2]=K+2;r=K;V=((de((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535)<<H|J;W=H-16|0}else{V=J;W=H}}while(0);c[g>>2]=W;H=I+1>>1;J=H<<16;r=V>>>0>=J>>>0;if(r){K=I-H|0;c[f>>2]=K;X=V-J|0;Y=K}else{c[f>>2]=H;X=V;Y=H}c[h>>2]=X;Z=r&1|N;if((M|0)==0){break}else{n=M;P=Z;A=Y;k=W;Q=X}}Q=Z<<1;a[e+136+(S*7|0)+b|0]=(Q|0)==0|Q}b=b+1|0;}while((b|0)<7);b=S+1|0;if((b|0)<2){S=b}else{_=0;break}}do{S=0;do{Z=a[127464+(_<<3)+S|0]|0;X=c[f>>2]|0;W=d[1086680+X|0]|0;Y=c[g>>2]|0;V=c[h>>2]|0;U=X<<W;c[f>>2]=U;X=V<<W;V=Y+W|0;do{if((V|0)>-1){W=c[i>>2]|0;if(!(W>>>0<(c[j>>2]|0)>>>0)){$=X;aa=V;break}c[i>>2]=W+2;Y=W;$=((de((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<V|X;aa=V-16|0}else{$=X;aa=V}}while(0);c[g>>2]=aa;V=((ba(U-1|0,Z&255)|0)>>8)+1|0;X=V<<16;Y=$>>>0>=X>>>0;W=Y?U-V|0:V;c[f>>2]=W;V=$-(Y?X:0)|0;c[h>>2]=V;if(Y){Y=7;X=0;T=W;W=aa;b=V;while(1){V=Y-1|0;Q=X<<1;k=d[1086680+T|0]|0;A=T<<k;c[f>>2]=A;P=b<<k;n=k+W|0;do{if((n|0)>-1){k=c[i>>2]|0;if(!(k>>>0<(c[j>>2]|0)>>>0)){ca=P;da=n;break}c[i>>2]=k+2;L=k;ca=((de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<n|P;da=n-16|0}else{ca=P;da=n}}while(0);c[g>>2]=da;n=A+1>>1;P=n<<16;M=ca>>>0>=P>>>0;if(M){N=A-n|0;c[f>>2]=N;ea=ca-P|0;fa=N}else{c[f>>2]=n;ea=ca;fa=n}c[h>>2]=ea;ga=M&1|Q;if((V|0)==0){break}else{Y=V;X=ga;T=fa;W=da;b=ea}}b=ga<<1;a[e+150+(_<<3)+S|0]=(b|0)==0|b}S=S+1|0;}while((S|0)<8);_=_+1|0;}while((_|0)<2);return}function o5a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;e=i;i=i+240|0;f=e|0;g=e+192|0;h=b+1764|0;j=c[h>>2]|0;TGb(g|0,-128|0,44)|0;k=b+376|0;l=b+380|0;m=b+392|0;n=b+384|0;o=b+388|0;p=b+352|0;q=0;do{r=0;do{s=a[127608+(q*11|0)+r|0]|0;t=c[k>>2]|0;u=d[1086680+t|0]|0;v=c[l>>2]|0;w=c[m>>2]|0;x=t<<u;c[k>>2]=x;t=w<<u;w=v+u|0;do{if((w|0)>-1){u=c[n>>2]|0;if(!(u>>>0<(c[o>>2]|0)>>>0)){y=t;z=w;break}c[n>>2]=u+2;v=u;y=((de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)<<w|t;z=w-16|0}else{y=t;z=w}}while(0);c[l>>2]=z;w=((ba(x-1|0,s&255)|0)>>8)+1|0;t=w<<16;v=y>>>0>=t>>>0;u=v?x-w|0:w;c[k>>2]=u;w=y-(v?t:0)|0;c[m>>2]=w;do{if(v){t=7;A=0;B=u;C=z;D=w;while(1){E=t-1|0;F=A<<1;G=d[1086680+B|0]|0;H=B<<G;c[k>>2]=H;I=D<<G;J=G+C|0;do{if((J|0)>-1){G=c[n>>2]|0;if(!(G>>>0<(c[o>>2]|0)>>>0)){K=I;L=J;break}c[n>>2]=G+2;M=G;K=((de((d[M]|d[M+1|0]<<8)<<16>>16|0)|0)&65535)<<J|I;L=J-16|0}else{K=I;L=J}}while(0);c[l>>2]=L;J=H+1>>1;I=J<<16;M=K>>>0>=I>>>0;if(M){G=H-J|0;c[k>>2]=G;N=K-I|0;O=G}else{c[k>>2]=J;N=K;O=J}c[m>>2]=N;P=M&1|F;if((E|0)==0){break}else{t=E;A=P;B=O;C=L;D=N}}D=P<<1;C=(D|0)==0|D;c[g+(r<<2)>>2]=C;a[j+166+(q*11|0)+r|0]=C}else{if((c[(c[p>>2]|0)+84>>2]|0)==0){break}a[j+166+(q*11|0)+r|0]=c[g+(r<<2)>>2]}}while(0);r=r+1|0;}while((r|0)<11);q=q+1|0;}while((q|0)<2);q=c[k>>2]|0;P=d[1086680+q|0]|0;N=c[l>>2]|0;L=c[m>>2]|0;O=q<<P;c[k>>2]=O;q=L<<P;L=N+P|0;do{if((L|0)>-1){P=c[n>>2]|0;if(!(P>>>0<(c[o>>2]|0)>>>0)){Q=q;R=L;break}c[n>>2]=P+2;N=P;Q=((de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<L|q;R=L-16|0}else{Q=q;R=L}}while(0);c[l>>2]=R;L=O+1>>1;q=L<<16;if(Q>>>0<q>>>0){c[k>>2]=L;c[m>>2]=Q;S=0}else{N=O-L|0;c[k>>2]=N;L=Q-q|0;c[m>>2]=L;q=1;Q=N;N=R;R=L;while(1){L=a[127760+q|0]|0;O=d[1086680+Q|0]|0;P=Q<<O;c[k>>2]=P;K=R<<O;z=N+O|0;do{if((z|0)>-1){O=c[n>>2]|0;if(!(O>>>0<(c[o>>2]|0)>>>0)){T=K;U=z;break}c[n>>2]=O+2;y=O;T=((de((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535)<<z|K;U=z-16|0}else{T=K;U=z}}while(0);c[l>>2]=U;z=((ba(P-1|0,L&255)|0)>>8)+1|0;K=z<<16;y=T>>>0>=K>>>0;O=y?P-z|0:z;c[k>>2]=O;z=T-(y?K:0)|0;c[m>>2]=z;if(y){y=4;K=0;r=O;O=U;w=z;while(1){z=y-1|0;u=K<<1;v=d[1086680+r|0]|0;x=r<<v;c[k>>2]=x;s=w<<v;C=v+O|0;do{if((C|0)>-1){v=c[n>>2]|0;if(!(v>>>0<(c[o>>2]|0)>>>0)){V=s;W=C;break}c[n>>2]=v+2;D=v;V=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<C|s;W=C-16|0}else{V=s;W=C}}while(0);c[l>>2]=W;C=x+1>>1;s=C<<16;D=V>>>0>=s>>>0;if(D){v=x-C|0;c[k>>2]=v;X=V-s|0;Y=v}else{c[k>>2]=C;X=V;Y=C}c[m>>2]=X;Z=D&1|u;if((z|0)==0){break}else{y=z;K=Z;r=Y;O=W;w=X}}a[j+q|0]=Z}w=q+1|0;if((w|0)>=64){break}q=w;Q=c[k>>2]|0;N=c[l>>2]|0;R=c[m>>2]|0}a[(c[h>>2]|0)+64|0]=0;R=0;N=1;while(1){Q=1;q=N;while(1){Z=c[h>>2]|0;if((d[Z+Q|0]|0|0)==(R|0)){a[Z+64+q|0]=Q;_=q+1|0}else{_=q}Z=Q+1|0;if((Z|0)<64){Q=Z;q=_}else{break}}q=R+1|0;if((q|0)<16){R=q;N=_}else{S=0;break}}}while(1){_=0;do{N=a[126928+(S*14|0)+_|0]|0;R=c[k>>2]|0;h=d[1086680+R|0]|0;q=c[l>>2]|0;Q=c[m>>2]|0;Z=R<<h;c[k>>2]=Z;R=Q<<h;Q=q+h|0;do{if((Q|0)>-1){h=c[n>>2]|0;if(!(h>>>0<(c[o>>2]|0)>>>0)){$=R;aa=Q;break}c[n>>2]=h+2;q=h;$=((de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<Q|R;aa=Q-16|0}else{$=R;aa=Q}}while(0);c[l>>2]=aa;Q=((ba(Z-1|0,N&255)|0)>>8)+1|0;R=Q<<16;z=$>>>0>=R>>>0;u=z?Z-Q|0:Q;c[k>>2]=u;Q=$-(z?R:0)|0;c[m>>2]=Q;if(z){z=7;R=0;x=u;u=aa;q=Q;while(1){Q=z-1|0;h=R<<1;X=d[1086680+x|0]|0;W=x<<X;c[k>>2]=W;Y=q<<X;V=X+u|0;do{if((V|0)>-1){X=c[n>>2]|0;if(!(X>>>0<(c[o>>2]|0)>>>0)){ca=Y;da=V;break}c[n>>2]=X+2;U=X;ca=((de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)<<V|Y;da=V-16|0}else{ca=Y;da=V}}while(0);c[l>>2]=da;V=W+1>>1;Y=V<<16;U=ca>>>0>=Y>>>0;if(U){X=W-V|0;c[k>>2]=X;ea=ca-Y|0;fa=X}else{c[k>>2]=V;ea=ca;fa=V}c[m>>2]=ea;ga=U&1|h;if((Q|0)==0){break}else{z=Q;R=ga;x=fa;u=da;q=ea}}q=ga<<1;a[j+1484+(S*14|0)+_|0]=(q|0)==0|q}_=_+1|0;}while((_|0)<14);_=S+1|0;if((_|0)<2){S=_}else{ha=0;break}}do{S=0;do{ga=0;do{ea=0;do{da=a[126960+(ha*132|0)+(S*66|0)+(ga*11|0)+ea|0]|0;fa=c[k>>2]|0;ca=d[1086680+fa|0]|0;aa=c[l>>2]|0;$=c[m>>2]|0;_=fa<<ca;c[k>>2]=_;fa=$<<ca;$=aa+ca|0;do{if(($|0)>-1){ca=c[n>>2]|0;if(!(ca>>>0<(c[o>>2]|0)>>>0)){ia=fa;ja=$;break}c[n>>2]=ca+2;aa=ca;ia=((de((d[aa]|d[aa+1|0]<<8)<<16>>16|0)|0)&65535)<<$|fa;ja=$-16|0}else{ia=fa;ja=$}}while(0);c[l>>2]=ja;$=((ba(_-1|0,da&255)|0)>>8)+1|0;fa=$<<16;E=ia>>>0>=fa>>>0;F=E?_-$|0:$;c[k>>2]=F;$=ia-(E?fa:0)|0;c[m>>2]=$;do{if(E){fa=7;H=0;aa=F;ca=ja;q=$;while(1){u=fa-1|0;x=H<<1;R=d[1086680+aa|0]|0;z=aa<<R;c[k>>2]=z;Z=q<<R;N=R+ca|0;do{if((N|0)>-1){R=c[n>>2]|0;if(!(R>>>0<(c[o>>2]|0)>>>0)){ka=Z;la=N;break}c[n>>2]=R+2;U=R;ka=((de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)<<N|Z;la=N-16|0}else{ka=Z;la=N}}while(0);c[l>>2]=la;N=z+1>>1;Z=N<<16;U=ka>>>0>=Z>>>0;if(U){R=z-N|0;c[k>>2]=R;ma=ka-Z|0;na=R}else{c[k>>2]=N;ma=ka;na=N}c[m>>2]=ma;oa=U&1|x;if((u|0)==0){break}else{fa=u;H=oa;aa=na;ca=la;q=ma}}q=oa<<1;ca=(q|0)==0|q;c[g+(ea<<2)>>2]=ca;a[j+188+(S*198|0)+(ha*66|0)+(ga*11|0)+ea|0]=ca}else{if((c[(c[p>>2]|0)+84>>2]|0)==0){break}a[j+188+(S*198|0)+(ha*66|0)+(ga*11|0)+ea|0]=c[g+(ea<<2)>>2]}}while(0);ea=ea+1|0;}while((ea|0)<11);ga=ga+1|0;}while((ga|0)<6);S=S+1|0;}while((S|0)<2);ha=ha+1|0;}while((ha|0)<3);if((c[b+3640>>2]|0)==0){ha=0;while(1){g=0;do{p=(ba(d[j+166+(ha*11|0)|0]|0,c[127632+(g*40|0)>>2]|0)|0)+128>>8;oa=p+(c[127636+(g*40|0)>>2]|0)|0;if((oa|0)<1){pa=1}else{pa=(oa|0)>255?-1:oa&255}a[j+1124+(ha*180|0)+(g*5|0)|0]=pa;oa=(ba(d[j+166+(ha*11|0)+1|0]|0,c[127640+(g*40|0)>>2]|0)|0)+128>>8;p=oa+(c[127644+(g*40|0)>>2]|0)|0;if((p|0)<1){qa=1}else{qa=(p|0)>255?-1:p&255}a[j+1124+(ha*180|0)+(g*5|0)+1|0]=qa;p=(ba(d[j+166+(ha*11|0)+2|0]|0,c[127648+(g*40|0)>>2]|0)|0)+128>>8;oa=p+(c[127652+(g*40|0)>>2]|0)|0;if((oa|0)<1){ra=1}else{ra=(oa|0)>255?-1:oa&255}a[j+1124+(ha*180|0)+(g*5|0)+2|0]=ra;oa=(ba(d[j+166+(ha*11|0)+3|0]|0,c[127656+(g*40|0)>>2]|0)|0)+128>>8;p=oa+(c[127660+(g*40|0)>>2]|0)|0;if((p|0)<1){sa=1}else{sa=(p|0)>255?-1:p&255}a[j+1124+(ha*180|0)+(g*5|0)+3|0]=sa;p=(ba(d[j+166+(ha*11|0)+4|0]|0,c[127664+(g*40|0)>>2]|0)|0)+128>>8;oa=p+(c[127668+(g*40|0)>>2]|0)|0;if((oa|0)<1){ta=1}else{ta=(oa|0)>255?-1:oa&255}a[j+1124+(ha*180|0)+(g*5|0)+4|0]=ta;g=g+1|0;}while((g|0)<3);g=ha+1|0;if((g|0)<2){ha=g}else{ua=0;break}}i=e;return ua|0}ha=f+100|0;ta=b|0;sa=f|0;ra=f+76|0;qa=0;a:while(1){c[ha>>2]=256;pa=0;do{g=c[f+(pa+12<<3)+4>>2]|0;oa=d[j+166+(qa*11|0)+pa|0]|0;p=(ba(oa,g)|0)>>>8;ma=(ba(oa^255,g)|0)>>>8;g=pa<<1;c[f+((d[127440+g|0]|0)<<3)+4>>2]=((p|0)==0)+p;c[f+((d[127440+(g|1)|0]|0)<<3)+4>>2]=((ma|0)==0)+ma;pa=pa+1|0;}while(pa>>>0<11>>>0);pa=b+3664+(qa*20|0)|0;Q_(pa);if((tGa(c[ta>>2]|0,pa,12,10,sa,36,1)|0)!=0){ua=-1;va=102;break}c[ra>>2]=256;pa=0;do{ma=c[f+(pa+9<<3)+4>>2]|0;g=d[j+1484+(qa*14|0)+pa|0]|0;p=(ba(g,ma)|0)>>>8;oa=(ba(g^255,ma)|0)>>>8;ma=pa<<1;c[f+((d[127424+ma|0]|0)<<3)+4>>2]=((p|0)==0)+p;c[f+((d[127424+(ma|1)|0]|0)<<3)+4>>2]=((oa|0)==0)+oa;pa=pa+1|0;}while(pa>>>0<8>>>0);pa=b+3704+(qa*20|0)|0;Q_(pa);if((tGa(c[ta>>2]|0,pa,9,10,sa,36,1)|0)==0){wa=0}else{ua=-1;va=102;break}do{pa=0;while(1){if((pa|0)>=6){break}c[ha>>2]=256;oa=0;do{ma=c[f+(oa+12<<3)+4>>2]|0;p=d[j+188+(qa*198|0)+(wa*66|0)+(pa*11|0)+oa|0]|0;g=(ba(p,ma)|0)>>>8;la=(ba(p^255,ma)|0)>>>8;ma=oa<<1;c[f+((d[127440+ma|0]|0)<<3)+4>>2]=((g|0)==0)+g;c[f+((d[127440+(ma|1)|0]|0)<<3)+4>>2]=((la|0)==0)+la;oa=oa+1|0;}while(oa>>>0<11>>>0);oa=b+3744+(qa*360|0)+(wa*120|0)+(pa*20|0)|0;Q_(oa);if((tGa(c[ta>>2]|0,oa,12,10,sa,36,1)|0)==0){pa=pa+1|0}else{ua=-1;va=102;break a}}wa=wa+1|0;}while((wa|0)<3);pa=qa+1|0;if((pa|0)<2){qa=pa}else{va=96;break}}if((va|0)==96){TGb(b+4464|0,0,16)|0;ua=0;i=e;return ua|0}else if((va|0)==102){i=e;return ua|0}return 0}function p5a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0;g=i;h=b+376|0;j=d[e]|0;k=j&1;l=b+352|0;c[(c[l>>2]|0)+84>>2]=j>>>7^1;V4a(b,(d[e]|0)>>>1&63);do{if((c[(c[l>>2]|0)+84>>2]|0)==0){j=b+420|0;if((c[j>>2]|0)==0){m=-1094995529;i=g;return m|0}n=c[b>>2]|0;if((c[n+128>>2]|0)==0){m=-1094995529;i=g;return m|0}if((c[n+132>>2]|0)==0){m=-1094995529;i=g;return m|0}if((k|0)==0){if((c[b+1412>>2]|0)==0){o=33}else{p=e;q=f;r=0}}else{o=33}if((o|0)==33){n=e+1|0;p=e+2|0;q=f-2|0;r=((de((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)-2|0}g5a(h,p+1|0,q-1|0);n=h|0;s=c[n>>2]|0;t=d[1086680+s|0]|0;u=b+380|0;v=c[u>>2]|0;w=b+392|0;x=c[w>>2]|0;y=s<<t;c[n>>2]=y;s=x<<t;x=v+t|0;do{if((x|0)>-1){t=b+384|0;v=c[t>>2]|0;if(!(v>>>0<(c[b+388>>2]|0)>>>0)){z=s;A=x;break}c[t>>2]=v+2;t=v;z=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<x|s;A=x-16|0}else{z=s;A=x}}while(0);c[u>>2]=A;x=y+1>>1;s=x<<16;t=z>>>0>=s>>>0;if(t){v=y-x|0;c[n>>2]=v;B=z-s|0;C=v}else{c[n>>2]=x;B=z;C=x}c[w>>2]=B;c[b+424>>2]=t&1;if((c[b+1412>>2]|0)==0){D=r;E=q;F=0;G=p;H=C;I=A;J=B;K=n;L=u;M=w;break}t=d[1086680+C|0]|0;x=C<<t;c[n>>2]=x;v=B<<t;s=A+t|0;do{if((s|0)>-1){t=b+384|0;N=c[t>>2]|0;if(!(N>>>0<(c[b+388>>2]|0)>>>0)){O=v;P=s;break}c[t>>2]=N+2;t=N;O=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<s|v;P=s-16|0}else{O=v;P=s}}while(0);c[u>>2]=P;s=x+1>>1;v=s<<16;y=O>>>0>=v>>>0;t=y&1;if(y){y=x-s|0;N=O-v|0;c[w>>2]=N;c[b+1416>>2]=t;v=d[1086680+y|0]|0;Q=y<<v;c[n>>2]=Q;y=N<<v;N=P+v|0;do{if((N|0)>-1){v=b+384|0;R=c[v>>2]|0;if(!(R>>>0<(c[b+388>>2]|0)>>>0)){S=y;T=N;break}c[v>>2]=R+2;v=R;S=((de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)<<N|y;T=N-16|0}else{S=y;T=N}}while(0);c[u>>2]=T;N=Q+1>>1;y=N<<16;if(S>>>0<y>>>0){c[n>>2]=N;U=S;V=N}else{x=Q-N|0;c[n>>2]=x;U=S-y|0;V=x}c[w>>2]=U;W=V;X=T;Y=U}else{c[n>>2]=s;c[w>>2]=O;c[b+1416>>2]=t;W=s;X=P;Y=O}x=c[j>>2]|0;if((x|0)<=7){D=r;E=q;F=0;G=p;H=W;I=X;J=Y;K=n;L=u;M=w;break}y=d[1086680+W|0]|0;N=W<<y;c[n>>2]=N;v=Y<<y;R=X+y|0;do{if((R|0)>-1){y=b+384|0;Z=c[y>>2]|0;if(!(Z>>>0<(c[b+388>>2]|0)>>>0)){_=v;$=R;break}c[y>>2]=Z+2;y=Z;_=((de((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535)<<R|v;$=R-16|0}else{_=v;$=R}}while(0);c[u>>2]=$;R=N+1>>1;v=R<<16;j=_>>>0>=v>>>0;if(j){s=N-R|0;c[n>>2]=s;aa=_-v|0;ba=s}else{c[n>>2]=R;aa=_;ba=R}c[w>>2]=aa;ca=p;da=0;ea=q;fa=j&1;ga=r;ha=0;ia=ba;ja=$;ka=aa;la=x;o=61}else{j=e+1|0;R=a[j]|0;s=R&255;v=s>>>3;if((R&255)>>>0>71>>>0){m=-1094995529;i=g;return m|0}t=s&6;s=b+1412|0;c[s>>2]=t;if(!((a[j]&1)==0)){EDb(c[b>>2]|0,1963568,(ma=i,i=i+1|0,i=i+7&-8,c[ma>>2]=0,ma)|0);i=ma;m=-1163346256;i=g;return m|0}if((k|0)!=0|(t|0)==0){t=e+2|0;j=t;na=t;oa=f-2|0;pa=((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)-2|0}else{na=e;oa=f;pa=0}j=a[na+2|0]|0;t=j&255;Q=a[na+3|0]|0;y=Q&255;if(j<<24>>24==0|Q<<24>>24==0){yDb(c[b>>2]|0,16,1935464,(ma=i,i=i+16|0,c[ma>>2]=y<<4,c[ma+8>>2]=t<<4,ma)|0);i=ma;m=-1094995529;i=g;return m|0}do{if((c[b+600>>2]|0)==0){qa=c[b>>2]|0;o=13}else{Q=c[b>>2]|0;if((y<<4|0)!=(c[Q+128>>2]|0)){qa=Q;o=13;break}if((t<<4|0)==(c[Q+132>>2]|0)){ra=0}else{qa=Q;o=13}}}while(0);a:do{if((o|0)==13){x=b|0;do{if((c[qa+100>>2]|0)==0){w=y<<4;if(((c[qa+120>>2]|0)+15&-16|0)!=(w|0)){sa=w;break}n=t<<4;if(((c[qa+124>>2]|0)+15&-16|0)!=(n|0)){sa=w;break}c[qa+128>>2]=w;c[qa+132>>2]=n;ra=1;break a}else{sa=y<<4}}while(0);n=V$a(qa,sa,t<<4)|0;if((n|0)<0){m=n;i=g;return m|0}n=c[x>>2]|0;if((c[n+100>>2]|0)!=1){ra=1;break}w=c[n+96>>2]|0;N=n+120|0;c[N>>2]=(c[N>>2]|0)-((d[w]|0)>>>4);N=n+124|0;c[N>>2]=(c[N>>2]|0)-(a[w]&15);ra=1}}while(0);g5a(h,na+6|0,oa-6|0);t=h|0;y=b+380|0;w=b+392|0;N=b+384|0;n=b+388|0;u=c[t>>2]|0;Q=c[y>>2]|0;j=c[w>>2]|0;Z=d[1086680+u|0]|0;ta=u<<Z;c[t>>2]=ta;u=j<<Z;j=Z+Q|0;do{if((j|0)>-1){Q=c[N>>2]|0;if(!(Q>>>0<(c[n>>2]|0)>>>0)){ua=u;va=j;break}c[N>>2]=Q+2;Z=Q;ua=((de((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0)&65535)<<j|u;va=j-16|0}else{ua=u;va=j}}while(0);c[y>>2]=va;j=ta+1>>1;u=j<<16;if(ua>>>0<u>>>0){c[t>>2]=j;wa=ua;xa=j}else{Z=ta-j|0;c[t>>2]=Z;wa=ua-u|0;xa=Z}c[w>>2]=wa;Z=d[1086680+xa|0]|0;u=xa<<Z;c[t>>2]=u;j=wa<<Z;Q=Z+va|0;do{if((Q|0)>-1){Z=c[N>>2]|0;if(!(Z>>>0<(c[n>>2]|0)>>>0)){ya=j;za=Q;break}c[N>>2]=Z+2;Aa=Z;ya=((de((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<Q|j;za=Q-16|0}else{ya=j;za=Q}}while(0);c[y>>2]=za;Q=u+1>>1;j=Q<<16;if(ya>>>0<j>>>0){c[t>>2]=Q;Ba=ya;Ca=Q}else{N=u-Q|0;c[t>>2]=N;Ba=ya-j|0;Ca=N}c[w>>2]=Ba;N=c[s>>2]|0;c[b+420>>2]=v;c[b+424>>2]=0;ca=na;da=ra;ea=oa;fa=N;ga=pa;ha=(R&255)>>>0<64>>>0?5:0;ia=Ca;ja=za;ka=Ba;la=v;o=61}}while(0);do{if((o|0)==61){Ba=h|0;if((fa|0)==0){D=ga;E=ea;F=da;G=ca;H=ia;I=ja;J=ka;K=Ba;L=b+380|0;M=b+392|0;break}za=d[1086680+ia|0]|0;Ca=b+380|0;pa=b+392|0;oa=ia<<za;c[Ba>>2]=oa;ra=ka<<za;na=ja+za|0;do{if((na|0)>-1){za=b+384|0;ya=c[za>>2]|0;if(!(ya>>>0<(c[b+388>>2]|0)>>>0)){Da=ra;Ea=na;break}c[za>>2]=ya+2;za=ya;Da=((de((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<na|ra;Ea=na-16|0}else{Da=ra;Ea=na}}while(0);c[Ca>>2]=Ea;na=oa+1>>1;ra=na<<16;do{if(Da>>>0<ra>>>0){c[pa>>2]=Da;v=d[1086680+na|0]|0;R=na<<v;c[Ba>>2]=R;s=Da<<v;w=Ea+v|0;do{if((w|0)>-1){v=b+384|0;t=c[v>>2]|0;if(!(t>>>0<(c[b+388>>2]|0)>>>0)){Fa=s;Ga=w;break}c[v>>2]=t+2;v=t;Fa=((de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)<<w|s;Ga=w-16|0}else{Fa=s;Ga=w}}while(0);c[Ca>>2]=Ga;w=R+1>>1;s=w<<16;if(Fa>>>0<s>>>0){c[Ba>>2]=w;c[pa>>2]=Fa;c[b+1424>>2]=0;Ha=w;Ia=Ga;Ja=Fa;break}else{x=R-w|0;c[Ba>>2]=x;w=Fa-s|0;c[pa>>2]=w;c[b+1424>>2]=1;Ha=x;Ia=Ga;Ja=w;break}}else{w=oa-na|0;c[Ba>>2]=w;x=Da-ra|0;c[pa>>2]=x;c[b+1424>>2]=2;s=b+384|0;v=b+388|0;t=5;u=0;y=w;w=Ea;za=x;while(1){x=t-1|0;ya=u<<1;va=d[1086680+y|0]|0;wa=y<<va;c[Ba>>2]=wa;xa=za<<va;ua=va+w|0;do{if((ua|0)>-1){va=c[s>>2]|0;if(!(va>>>0<(c[v>>2]|0)>>>0)){Ka=xa;La=ua;break}c[s>>2]=va+2;sa=va;Ka=((de((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<ua|xa;La=ua-16|0}else{Ka=xa;La=ua}}while(0);c[Ca>>2]=La;ua=wa+1>>1;xa=ua<<16;sa=Ka>>>0>=xa>>>0;if(sa){va=wa-ua|0;c[Ba>>2]=va;Ma=Ka-xa|0;Na=va}else{c[Ba>>2]=ua;Ma=Ka;Na=ua}c[pa>>2]=Ma;Oa=sa&1|ya;if((x|0)==0){break}else{t=x;u=Oa;y=Na;w=La;za=Ma}}c[b+1432>>2]=Oa<<ha;za=d[1086680+Na|0]|0;w=Na<<za;c[Ba>>2]=w;y=Ma<<za;u=za+La|0;do{if((u|0)>-1){za=c[s>>2]|0;if(!(za>>>0<(c[v>>2]|0)>>>0)){Pa=y;Qa=u;break}c[s>>2]=za+2;t=za;Pa=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<u|y;Qa=u-16|0}else{Pa=y;Qa=u}}while(0);c[Ca>>2]=Qa;u=w+1>>1;y=u<<16;t=Pa>>>0>=y>>>0;if(t){za=w-u|0;c[Ba>>2]=za;Ra=Pa-y|0;Sa=za}else{c[Ba>>2]=u;Ra=Pa;Sa=u}c[pa>>2]=Ra;u=(t&1)<<1;t=d[1086680+Sa|0]|0;za=Sa<<t;c[Ba>>2]=za;y=Ra<<t;R=t+Qa|0;do{if((R|0)>-1){t=c[s>>2]|0;if(!(t>>>0<(c[v>>2]|0)>>>0)){Ta=y;Ua=R;break}c[s>>2]=t+2;sa=t;Ta=((de((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<R|y;Ua=R-16|0}else{Ta=y;Ua=R}}while(0);c[Ca>>2]=Ua;R=za+1>>1;y=R<<16;w=Ta>>>0>=y>>>0;if(w){sa=za-R|0;c[Ba>>2]=sa;Va=Ta-y|0;Wa=sa}else{c[Ba>>2]=R;Va=Ta;Wa=R}c[pa>>2]=Va;R=(w&1|u)<<1;w=d[1086680+Wa|0]|0;sa=Wa<<w;c[Ba>>2]=sa;y=Va<<w;t=w+Ua|0;do{if((t|0)>-1){w=c[s>>2]|0;if(!(w>>>0<(c[v>>2]|0)>>>0)){Xa=y;Ya=t;break}c[s>>2]=w+2;ua=w;Xa=((de((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535)<<t|y;Ya=t-16|0}else{Xa=y;Ya=t}}while(0);c[Ca>>2]=Ya;t=sa+1>>1;y=t<<16;s=Xa>>>0>=y>>>0;if(s){v=sa-t|0;c[Ba>>2]=v;Za=Xa-y|0;_a=v}else{c[Ba>>2]=t;Za=Xa;_a=t}c[pa>>2]=Za;c[b+1428>>2]=2<<(s&1|R);Ha=_a;Ia=Ya;Ja=Za}}while(0);if((la|0)<=7){c[b+1420>>2]=16;D=ga;E=ea;F=da;G=ca;H=Ha;I=Ia;J=Ja;K=Ba;L=Ca;M=pa;break}ra=b+384|0;na=b+388|0;oa=4;s=0;t=Ha;v=Ia;y=Ja;while(1){u=oa-1|0;za=s<<1;ua=d[1086680+t|0]|0;w=t<<ua;c[Ba>>2]=w;va=y<<ua;xa=ua+v|0;do{if((xa|0)>-1){ua=c[ra>>2]|0;if(!(ua>>>0<(c[na>>2]|0)>>>0)){$a=va;ab=xa;break}c[ra>>2]=ua+2;qa=ua;$a=((de((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<xa|va;ab=xa-16|0}else{$a=va;ab=xa}}while(0);c[Ca>>2]=ab;xa=w+1>>1;va=xa<<16;R=$a>>>0>=va>>>0;if(R){sa=w-xa|0;c[Ba>>2]=sa;bb=$a-va|0;cb=sa}else{c[Ba>>2]=xa;bb=$a;cb=xa}c[pa>>2]=bb;db=R&1|za;if((u|0)==0){break}else{oa=u;s=db;t=cb;v=ab;y=bb}}c[b+1420>>2]=db;D=ga;E=ea;F=da;G=ca;H=cb;I=ab;J=bb;K=Ba;L=Ca;M=pa}}while(0);bb=d[1086680+H|0]|0;ab=H<<bb;c[K>>2]=ab;H=J<<bb;J=I+bb|0;do{if((J|0)>-1){bb=b+384|0;I=c[bb>>2]|0;if(!(I>>>0<(c[b+388>>2]|0)>>>0)){eb=H;fb=J;break}c[bb>>2]=I+2;bb=I;eb=((de((d[bb]|d[bb+1|0]<<8)<<16>>16|0)|0)&65535)<<J|H;fb=J-16|0}else{eb=H;fb=J}}while(0);c[L>>2]=fb;fb=ab+1>>1;L=fb<<16;J=eb>>>0>=L>>>0;if(J){c[K>>2]=ab-fb;gb=eb-L|0}else{c[K>>2]=fb;gb=eb}c[M>>2]=gb;c[b+3640>>2]=J&1;gb=b+1740|0;c[gb>>2]=268;if((D|0)==0){c[b+416>>2]=h;m=F;i=g;return m|0}h=G+D|0;G=E-D|0;if((G|0)<0){if((c[(c[l>>2]|0)+84>>2]|0)==0){m=-1094995529;i=g;return m|0}V$a(c[b>>2]|0,0,0)|0;m=-1094995529;i=g;return m|0}if(J){c[gb>>2]=292;gb=G<<3;J=gb>>>0>2147483639>>>0|(h|0)==0;l=J?0:h;D=J?0:gb;c[b+3644>>2]=l;c[b+3656>>2]=D;c[b+3660>>2]=D+8;c[b+3648>>2]=l+(D>>3);c[b+3652>>2]=0;m=F;i=g;return m|0}else{D=b+396|0;g5a(D,h,G);c[b+416>>2]=D;m=F;i=g;return m|0}return 0}function q5a(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0;g=c[f+416>>2]|0;h=c[f+1764>>2]|0;i=f+500|0;j=g|0;k=g+4|0;l=g+16|0;m=g+8|0;n=g+12|0;g=a[1086656]|0;o=g<<24>>24>0;p=f+498|0;q=0;r=0;do{r=(q|0)>3?1:r;s=f+504+((d[1087256+q|0]|0)*12|0)|0;t=f+552+(q<<2)|0;u=1;v=1;w=h+166+(r*11|0)|0;x=h+1124+(r*180|0)+(((d[(c[i>>2]|0)+((c[t>>2]|0)*12|0)|0]|0)+(d[s]|0)|0)*5|0)|0;y=0;a:while(1){do{if((y|0)>1&(v|0)==0){z=c[j>>2]|0;A=c[k>>2]|0;B=c[l>>2]|0;C=9}else{D=a[x]|0;E=c[j>>2]|0;F=d[1086680+E|0]|0;G=c[k>>2]|0;H=c[l>>2]|0;I=E<<F;c[j>>2]=I;E=H<<F;H=G+F|0;do{if((H|0)>-1){F=c[m>>2]|0;if(!(F>>>0<(c[n>>2]|0)>>>0)){J=E;K=H;break}c[m>>2]=F+2;G=F;J=((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)<<H|E;K=H-16|0}else{J=E;K=H}}while(0);c[k>>2]=K;H=((ba(I-1|0,D&255)|0)>>8)+1|0;E=H<<16;G=J>>>0>=E>>>0;F=G?I-H|0:H;c[j>>2]=F;H=J-(G?E:0)|0;c[l>>2]=H;if(G){z=F;A=K;B=H;C=9;break}if((y|0)<=0){L=u;M=0;break}G=a[x+1|0]|0;E=d[1086680+F|0]|0;N=F<<E;c[j>>2]=N;F=H<<E;H=K+E|0;do{if((H|0)>-1){E=c[m>>2]|0;if(!(E>>>0<(c[n>>2]|0)>>>0)){O=F;P=H;break}c[m>>2]=E+2;Q=E;O=((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<H|F;P=H-16|0}else{O=F;P=H}}while(0);c[k>>2]=P;H=((ba(N-1|0,G&255)|0)>>8)+1|0;F=H<<16;I=O>>>0>=F>>>0;D=I?N-H|0:H;c[j>>2]=D;H=O-(I?F:0)|0;c[l>>2]=H;if(!I){break a}I=(y|0)>5|0;F=127376;Q=127376;E=D;D=P;R=H;while(1){H=a[(a[F+1|0]|0)+(h+1484+(I*14|0))|0]|0;S=d[1086680+E|0]|0;T=E<<S;c[j>>2]=T;U=R<<S;V=S+D|0;do{if((V|0)>-1){S=c[m>>2]|0;if(!(S>>>0<(c[n>>2]|0)>>>0)){W=U;X=V;break}c[m>>2]=S+2;Y=S;W=((de((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<V|U;X=V-16|0}else{W=U;X=V}}while(0);c[k>>2]=X;V=((ba(T-1|0,H&255)|0)>>8)+1|0;U=V<<16;Y=W>>>0>=U>>>0;Z=Y?T-V|0:V;c[j>>2]=Z;_=W-(Y?U:0)|0;c[l>>2]=_;if(Y){$=F+(a[Q]<<1)|0}else{$=F+2|0}Y=$|0;aa=a[Y]|0;if(aa<<24>>24>0){F=$;Q=Y;E=Z;D=X;R=_}else{break}}if(aa<<24>>24==0){ca=0;da=9;ea=Z;fa=X;ga=_}else{L=-(aa<<24>>24)|0;M=0;break}while(1){R=a[ca+8+(h+1484+(I*14|0))|0]|0;D=d[1086680+ea|0]|0;E=ea<<D;c[j>>2]=E;Q=ga<<D;F=fa+D|0;do{if((F|0)>-1){D=c[m>>2]|0;if(!(D>>>0<(c[n>>2]|0)>>>0)){ha=Q;ia=F;break}c[m>>2]=D+2;N=D;ha=((de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<F|Q;ia=F-16|0}else{ha=Q;ia=F}}while(0);c[k>>2]=ia;F=((ba(E-1|0,R&255)|0)>>8)+1|0;Q=F<<16;T=ha>>>0>=Q>>>0;H=T?E-F|0:F;c[j>>2]=H;F=ha-(T?Q:0)|0;c[l>>2]=F;Q=((T&1)<<ca)+da|0;T=ca+1|0;if((T|0)<6){ca=T;da=Q;ea=H;fa=ia;ga=F}else{L=Q;M=0;break}}}}while(0);if((C|0)==9){C=0;I=a[x+2|0]|0;Q=d[1086680+z|0]|0;F=z<<Q;c[j>>2]=F;H=B<<Q;T=A+Q|0;do{if((T|0)>-1){Q=c[m>>2]|0;if(!(Q>>>0<(c[n>>2]|0)>>>0)){ja=H;ka=T;break}c[m>>2]=Q+2;N=Q;ja=((de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<T|H;ka=T-16|0}else{ja=H;ka=T}}while(0);c[k>>2]=ka;T=((ba(F-1|0,I&255)|0)>>8)+1|0;H=T<<16;N=ja>>>0>=H>>>0;Q=N?F-T|0:T;c[j>>2]=Q;T=ja-(N?H:0)|0;c[l>>2]=T;do{if(N){H=a[x+3|0]|0;D=d[1086680+Q|0]|0;G=Q<<D;c[j>>2]=G;Y=T<<D;U=ka+D|0;do{if((U|0)>-1){D=c[m>>2]|0;if(!(D>>>0<(c[n>>2]|0)>>>0)){la=Y;ma=U;break}c[m>>2]=D+2;V=D;la=((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<U|Y;ma=U-16|0}else{la=Y;ma=U}}while(0);c[k>>2]=ma;U=((ba(G-1|0,H&255)|0)>>8)+1|0;Y=U<<16;V=la>>>0>=Y>>>0;D=V?G-U|0:U;c[j>>2]=D;U=la-(V?Y:0)|0;c[l>>2]=U;if(!V){V=a[x+4|0]|0;Y=d[1086680+D|0]|0;S=D<<Y;c[j>>2]=S;na=U<<Y;oa=ma+Y|0;do{if((oa|0)>-1){Y=c[m>>2]|0;if(!(Y>>>0<(c[n>>2]|0)>>>0)){pa=na;qa=oa;break}c[m>>2]=Y+2;ra=Y;pa=((de((d[ra]|d[ra+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|na;qa=oa-16|0}else{pa=na;qa=oa}}while(0);c[k>>2]=qa;oa=((ba(S-1|0,V&255)|0)>>8)+1|0;na=oa<<16;G=pa>>>0>=na>>>0;H=G?S-oa|0:oa;c[j>>2]=H;oa=pa-(G?na:0)|0;c[l>>2]=oa;if(!G){sa=2;ta=2;ua=H;va=qa;wa=oa;break}G=a[w+5|0]|0;na=d[1086680+H|0]|0;ra=H<<na;c[j>>2]=ra;H=oa<<na;oa=qa+na|0;do{if((oa|0)>-1){na=c[m>>2]|0;if(!(na>>>0<(c[n>>2]|0)>>>0)){xa=H;ya=oa;break}c[m>>2]=na+2;Y=na;xa=((de((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|H;ya=oa-16|0}else{xa=H;ya=oa}}while(0);c[k>>2]=ya;oa=((ba(ra-1|0,G&255)|0)>>8)+1|0;H=oa<<16;S=xa>>>0>=H>>>0;V=S?ra-oa|0:oa;c[j>>2]=V;oa=xa-(S?H:0)|0;c[l>>2]=oa;sa=2;ta=S?4:3;ua=V;va=ya;wa=oa;break}if(o){oa=1086656;V=1086656;S=D;H=ma;Y=U;while(1){na=a[w+(a[oa+1|0]|0)|0]|0;za=d[1086680+S|0]|0;Aa=S<<za;c[j>>2]=Aa;Ba=Y<<za;Ca=za+H|0;do{if((Ca|0)>-1){za=c[m>>2]|0;if(!(za>>>0<(c[n>>2]|0)>>>0)){Da=Ba;Ea=Ca;break}c[m>>2]=za+2;Fa=za;Da=((de((d[Fa]|d[Fa+1|0]<<8)<<16>>16|0)|0)&65535)<<Ca|Ba;Ea=Ca-16|0}else{Da=Ba;Ea=Ca}}while(0);c[k>>2]=Ea;Ca=((ba(Aa-1|0,na&255)|0)>>8)+1|0;Ba=Ca<<16;E=Da>>>0>=Ba>>>0;R=E?Aa-Ca|0:Ca;c[j>>2]=R;Ca=Da-(E?Ba:0)|0;c[l>>2]=Ca;if(E){Ga=oa+(a[V]<<1)|0}else{Ga=oa+2|0}E=Ga|0;Ba=a[E]|0;if(Ba<<24>>24>0){oa=Ga;V=E;S=R;H=Ea;Y=Ca}else{Ha=Ba;Ia=R;Ja=Ea;Ka=Ca;break}}}else{Ha=g;Ia=D;Ja=ma;Ka=U}Y=Ha<<24>>24;H=-Y|0;S=d[1087216+(5-Y)|0]|0;Y=d[1087208+H|0]|0;V=Ia;oa=Ja;ra=Ka;while(1){G=a[1087136+(H*11|0)+Y|0]|0;Ca=d[1086680+V|0]|0;R=V<<Ca;c[j>>2]=R;Ba=ra<<Ca;E=oa+Ca|0;do{if((E|0)>-1){Ca=c[m>>2]|0;if(!(Ca>>>0<(c[n>>2]|0)>>>0)){La=Ba;Ma=E;break}c[m>>2]=Ca+2;Fa=Ca;La=((de((d[Fa]|d[Fa+1|0]<<8)<<16>>16|0)|0)&65535)<<E|Ba;Ma=E-16|0}else{La=Ba;Ma=E}}while(0);c[k>>2]=Ma;E=((ba(R-1|0,G&255)|0)>>8)+1|0;Ba=E<<16;Aa=La>>>0>=Ba>>>0;na=Aa?R-E|0:E;c[j>>2]=na;E=La-(Aa?Ba:0)|0;c[l>>2]=E;Ba=((Aa&1)<<Y)+S|0;if((Y|0)>0){S=Ba;Y=Y-1|0;V=na;oa=Ma;ra=E}else{sa=2;ta=Ba;ua=na;va=Ma;wa=E;break}}}else{sa=1;ta=1;ua=Q;va=ka;wa=T}}while(0);T=d[1086680+ua|0]|0;Q=ua<<T;c[j>>2]=Q;N=wa<<T;F=va+T|0;do{if((F|0)>-1){T=c[m>>2]|0;if(!(T>>>0<(c[n>>2]|0)>>>0)){Na=N;Oa=F;break}c[m>>2]=T+2;I=T;Na=((de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)<<F|N;Oa=F-16|0}else{Na=N;Oa=F}}while(0);c[k>>2]=Oa;F=Q+1>>1;N=F<<16;I=Na>>>0>=N>>>0;T=I&1;if(I){c[j>>2]=Q-F;Pa=Na-N|0}else{c[j>>2]=F;Pa=Na}c[l>>2]=Pa;F=(ta^-T)+T|0;if((y|0)==0){Qa=F&65535}else{Qa=(ba(e[p>>1]|0,F)|0)&65535}b[f+608+(q<<7)+(d[(d[h+64+y|0]|0)+(f+288)|0]<<1)>>1]=Qa;L=1;M=sa}F=L+y|0;if((F|0)>63){break}T=h+188+(r*198|0)+(M*66|0)+((d[127824+F|0]|0)*11|0)|0;u=L;v=M;w=T;x=T;y=F}y=(b[f+608+(q<<7)>>1]|0)!=0|0;a[(c[i>>2]|0)+((c[t>>2]|0)*12|0)|0]=y;a[s]=y;q=q+1|0;}while((q|0)<6);return}function r5a(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[a+1764>>2]|0;g=a+3652|0;h=a+3656|0;i=a+3660|0;j=a+3644|0;k=a+498|0;l=0;m=0;a:while(1){n=(l|0)>3?1:m;o=a+4464+(n<<2)|0;p=a+3664+(n*20|0)|0;q=0;r=0;b:while(1){do{if((r|0)<2){s=a+4464+(r<<3)+(n<<2)|0;t=c[s>>2]|0;if((t|0)==0){u=6;break}c[s>>2]=t-1;if((r|0)==0){v=1;w=q}else{break b}}else{u=6}}while(0);do{if((u|0)==6){u=0;t=c[g>>2]|0;if(((c[h>>2]|0)-t|0)<1){u=36;break a}s=c[p+4>>2]|0;x=c[i>>2]|0;y=c[j>>2]|0;z=y+(t>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>22;z=b[s+(A<<2)>>1]|0;B=b[s+(A<<2)+2>>1]|0;A=B<<16>>16;do{if(B<<16>>16<0){C=t+10|0;D=x>>>0>C>>>0?C:x;C=y+(D>>>3)|0;E=((fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(D&7)>>>((A+32|0)>>>0))+z|0;C=b[s+(E<<2)>>1]|0;F=b[s+(E<<2)+2>>1]|0;E=F<<16>>16;if(!(F<<16>>16<0)){G=E;H=C;I=D;break}F=D-A|0;D=x>>>0>F>>>0?F:x;F=y+(D>>>3)|0;J=((fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(D&7)>>>((E+32|0)>>>0))+C|0;G=b[s+(J<<2)+2>>1]|0;H=b[s+(J<<2)>>1]|0;I=D}else{G=A;H=z;I=t}}while(0);t=G+I|0;K=x>>>0>t>>>0?t:x;c[g>>2]=K;if((H|0)==11){u=21;break b}else if((H|0)!=0){t=d[1087216+H|0]|0;if((H|0)>4){z=(H|0)<10?H-4|0:11;A=y+(K>>>3)|0;s=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(K&7)>>>((32-z|0)>>>0);A=K+z|0;z=x>>>0>A>>>0?A:x;c[g>>2]=z;L=s+t|0;M=z}else{L=t;M=K}t=d[y+(M>>>3)|0]<<(M&7)>>>7;c[g>>2]=((M|0)<(x|0))+M;z=t&1;t=(L^-z)+z|0;if((r|0)==0){N=t&65535}else{N=(ba(e[k>>1]|0,t)|0)&65535}b[a+608+(l<<7)+(d[(d[f+64+r|0]|0)+(a+288)|0]<<1)>>1]=N;v=1;w=(L|0)>1?2:1;break}if((r|0)==0){t=y+(K>>>3)|0;z=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(K&7)>>>30;t=K+2|0;s=x>>>0>t>>>0?t:x;c[g>>2]=s;if((z|0)==2){t=y+(s>>>3)|0;A=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(s&7)>>>30;t=s+2|0;c[g>>2]=x>>>0>t>>>0?t:x;O=A+2|0}else if((z|0)==3){A=d[y+(s>>>3)|0]<<(s&7)>>>7;t=((s|0)<(x|0))+s|0;c[g>>2]=t;s=A<<2&4;A=s|2;B=y+(t>>>3)|0;D=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>((32-A|0)>>>0);B=A+t|0;c[g>>2]=x>>>0>B>>>0?B:x;O=s+6+D|0}else{O=z}c[o>>2]=O;v=1;w=0;break}z=c[a+3704+(((r|0)>5|0)*20|0)+4>>2]|0;D=y+(K>>>3)|0;s=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(K&7)>>>22;D=b[z+(s<<2)>>1]|0;B=b[z+(s<<2)+2>>1]|0;s=B<<16>>16;do{if(B<<16>>16<0){t=K+10|0;A=x>>>0>t>>>0?t:x;t=y+(A>>>3)|0;J=((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(A&7)>>>((s+32|0)>>>0))+D|0;t=b[z+(J<<2)>>1]|0;C=b[z+(J<<2)+2>>1]|0;J=C<<16>>16;if(!(C<<16>>16<0)){P=J;Q=t;R=A;break}C=A-s|0;A=x>>>0>C>>>0?C:x;C=y+(A>>>3)|0;E=((fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(A&7)>>>((J+32|0)>>>0))+t|0;P=b[z+(E<<2)+2>>1]|0;Q=b[z+(E<<2)>>1]|0;R=A}else{P=s;Q=D;R=K}}while(0);D=P+R|0;s=x>>>0>D>>>0?D:x;c[g>>2]=s;D=Q+1|0;if((D|0)<=8){v=D;w=0;break}z=y+(s>>>3)|0;B=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(s&7)>>>26;z=s+6|0;c[g>>2]=x>>>0>z>>>0?z:x;v=B+D|0;w=0}}while(0);D=v+r|0;if((D|0)>63){break}if((D-22|0)>>>0<42>>>0){S=3}else{S=d[127824+D|0]|0}p=a+3744+(n*360|0)+(w*120|0)+(S*20|0)|0;q=w;r=D}do{if((u|0)==21){u=0;if((r|0)!=1){break}q=y+(K>>>3)|0;p=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(K&7)>>>30;q=K+2|0;o=x>>>0>q>>>0?q:x;c[g>>2]=o;if((p|0)==2){q=y+(o>>>3)|0;D=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(o&7)>>>30;q=o+2|0;c[g>>2]=x>>>0>q>>>0?q:x;T=D+2|0}else if((p|0)==3){D=d[y+(o>>>3)|0]<<(o&7)>>>7;q=((o|0)<(x|0))+o|0;c[g>>2]=q;o=D<<2&4;D=o|2;B=y+(q>>>3)|0;z=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(q&7)>>>((32-D|0)>>>0);B=D+q|0;c[g>>2]=x>>>0>B>>>0?B:x;T=o+6+z|0}else{T=p}c[a+4472+(n<<2)>>2]=T}}while(0);r=l+1|0;if((r|0)<6){l=r;m=n}else{u=36;break}}if((u|0)==36){return}}function s5a(a,d){a=a|0;d=d|0;return((c[a+4>>2]|0)-(c[d+4>>2]|0)<<4)+(b[d>>1]|0)-(b[a>>1]|0)|0}function t5a(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=i;i=i+352|0;k=j|0;l=b[g>>1]|0;m=b[g+2>>1]|0;n=b[g+4>>1]|0;o=b[g+6>>1]|0;g=e+(-f|0)|0;e=0;p=k|0;while(1){q=0;r=a[g-1|0]|0;s=a[g]|0;t=a[g+1|0]|0;while(1){u=ba(l,r&255)|0;v=ba(m,s&255)|0;w=q+1|0;x=ba(n,t&255)|0;y=a[g+(q+2)|0]|0;z=u+64+v+x+(ba(o,y&255)|0)>>7;if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}c[p+(q<<2)>>2]=A&255;if((w|0)<8){q=w;r=s;s=t;t=y}else{break}}t=e+1|0;if((t|0)<11){g=g+f|0;e=t;p=p+32|0}else{break}}p=h+2|0;e=h+4|0;g=h+6|0;A=d;d=0;o=k+32|0;while(1){k=0;do{n=ba(b[h>>1]|0,c[o+(k-8<<2)>>2]|0)|0;m=ba(b[p>>1]|0,c[o+(k<<2)>>2]|0)|0;l=ba(b[e>>1]|0,c[o+(k+8<<2)>>2]|0)|0;t=n+64+m+l+(ba(b[g>>1]|0,c[o+(k+16<<2)>>2]|0)|0)>>7;if(t>>>0>255>>>0){B=-t>>31&255}else{B=t&255}a[A+k|0]=B;k=k+1|0;}while((k|0)<8);k=d+1|0;if((k|0)<8){A=A+f|0;d=k;o=o+32|0}else{break}}i=j;return}function u5a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0;k=i;i=i+24|0;l=k|0;m=k+16|0;n=f+60|0;o=c[n>>2]|0;p=o;q=c[j+24>>2]|0;r=j+28|0;j=c[r>>2]|0;s=o+188|0;t=s;u=o+4|0;v=c[u>>2]|0;w=c[v+120>>2]|0;y=c[v+124>>2]|0;z=o+60|0;a[z]=a[q]&1^1;A=(d[q]|0)>>>1&7;B=o+63|0;a[B]=A;C=o+4540|0;c[C>>2]=((d[q]|0)>>>4&1^1)&255;D=(d[q+1|0]<<8|d[q+2|0]<<16|d[q])>>>5;E=q+3|0;F=j-3|0;if((A&255)>>>0>3>>>0){yDb(v,24,2046224,(G=i,i=i+8|0,c[G>>2]=A&255,G)|0);i=G;H=a[B]|0}else{H=A}A=o+5240|0;if(H<<24>>24==0){UGb(A|0,o+4796|0,108)|0}else{UGb(A|0,o+4904|0,108)|0}A=a[z]|0;a:do{if((D|0)>(((A&255)*-7|0)+F|0)){yDb(c[u>>2]|0,16,2000496,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;I=-1094995529}else{if(A<<24>>24==0){J=y;K=w;L=E;M=F}else{H=d[q+4|0]<<8|d[q+5|0]<<16|d[E];if((H|0)!=2752925){yDb(c[u>>2]|0,16,1963536,(G=i,i=i+8|0,c[G>>2]=H,G)|0);i=G;I=-1094995529;break}H=q+6|0;B=(d[H]|d[H+1|0]<<8)<<16>>16&16383;H=q+8|0;v=(d[H]|d[H+1|0]<<8)<<16>>16&16383;H=q+10|0;N=j-10|0;if((d[q+7|0]|0)>>>0>63>>>0){O=13}else{if((d[q+9|0]|0)>>>0>63>>>0){O=13}}if((O|0)==13){DDb(c[u>>2]|0,1935448,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G}c[o+4552>>2]=0;c[o+4548>>2]=0;P=0;do{UGb(p+222+(P*528|0)|0,124016+(P*264|0)|0,33)|0;UGb(p+222+(P*528|0)+33|0,124049+(P*264|0)|0,33)|0;UGb(p+222+(P*528|0)+66|0,124082+(P*264|0)|0,33)|0;UGb(p+222+(P*528|0)+99|0,124115+(P*264|0)|0,33)|0;Q=124214+(P*264|0)|0;UGb(p+222+(P*528|0)+132|0,Q|0,33)|0;UGb(p+222+(P*528|0)+165|0,124148+(P*264|0)|0,33)|0;UGb(p+222+(P*528|0)+198|0,124181+(P*264|0)|0,33)|0;UGb(p+222+(P*528|0)+231|0,Q|0,33)|0;UGb(p+222+(P*528|0)+264|0,Q|0,33)|0;UGb(p+222+(P*528|0)+297|0,Q|0,33)|0;UGb(p+222+(P*528|0)+330|0,Q|0,33)|0;UGb(p+222+(P*528|0)+363|0,Q|0,33)|0;UGb(p+222+(P*528|0)+396|0,Q|0,33)|0;UGb(p+222+(P*528|0)+429|0,Q|0,33)|0;UGb(p+222+(P*528|0)+462|0,Q|0,33)|0;UGb(p+222+(P*528|0)+495|0,124247+(P*264|0)|0,33)|0;P=P+1|0;}while((P|0)<4);P=o+215|0;x=629954160;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;P=o+219|0;a[P]=a[125104]|0;a[P+1|0]=a[125105]|0;a[P+2|0]=a[125106]|0;UGb(o+2334|0,126128,38)|0;TGb(o+88|0,0,11)|0;TGb(o+164|0,0,13)|0;J=v;K=B;L=H;M=N}g5a(t,L,D);P=M-D|0;Q=s;R=c[Q>>2]|0;if((a[z]|0)==0){S=R;T=c[o+192>>2]|0;U=c[o+204>>2]|0}else{V=d[1086680+R|0]|0;W=o+192|0;X=c[W>>2]|0;Y=o+204|0;Z=c[Y>>2]|0;_=R<<V;c[Q>>2]=_;R=Z<<V;Z=X+V|0;do{if((Z|0)>-1){V=o+196|0;X=c[V>>2]|0;if(!(X>>>0<(c[o+200>>2]|0)>>>0)){$=R;aa=Z;break}c[V>>2]=X+2;V=X;$=((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<Z|R;aa=Z-16|0}else{$=R;aa=Z}}while(0);c[W>>2]=aa;Z=((_<<7)-128>>8)+1|0;R=Z<<16;N=$>>>0>=R>>>0;H=N?_-Z|0:Z;c[Q>>2]=H;Z=$-(N?R:0)|0;c[Y>>2]=Z;if(N){yDb(c[u>>2]|0,24,1912176,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;ca=c[Q>>2]|0;da=c[W>>2]|0;ea=c[Y>>2]|0}else{ca=H;da=aa;ea=Z}Z=d[1086680+ca|0]|0;H=ca<<Z;c[Q>>2]=H;N=ea<<Z;R=Z+da|0;do{if((R|0)>-1){Z=o+196|0;B=c[Z>>2]|0;if(!(B>>>0<(c[o+200>>2]|0)>>>0)){fa=N;ga=R;break}c[Z>>2]=B+2;Z=B;fa=((de((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0)&65535)<<R|N;ga=R-16|0}else{fa=N;ga=R}}while(0);c[W>>2]=ga;R=((H<<7)-128>>8)+1|0;N=R<<16;_=fa>>>0>=N>>>0;Z=_?H-R|0:R;c[Q>>2]=Z;R=fa-(_?N:0)|0;c[Y>>2]=R;S=Z;T=ga;U=R}R=d[1086680+S|0]|0;Z=o+192|0;N=o+204|0;_=S<<R;c[Q>>2]=_;B=U<<R;v=R+T|0;do{if((v|0)>-1){R=o+196|0;V=c[R>>2]|0;if(!(V>>>0<(c[o+200>>2]|0)>>>0)){ha=B;ia=v;break}c[R>>2]=V+2;R=V;ha=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<v|B;ia=v-16|0}else{ha=B;ia=v}}while(0);c[Z>>2]=ia;v=((_<<7)-128>>8)+1|0;B=v<<16;Y=ha>>>0>=B>>>0;H=Y?_-v|0:v;c[Q>>2]=H;v=ha-(Y?B:0)|0;c[N>>2]=v;B=o+88|0;a[B]=Y&1;do{if(Y){W=d[1086680+H|0]|0;R=H<<W;c[Q>>2]=R;V=v<<W;X=W+ia|0;do{if((X|0)>-1){W=o+196|0;ja=c[W>>2]|0;if(!(ja>>>0<(c[o+200>>2]|0)>>>0)){ka=V;la=X;break}c[W>>2]=ja+2;W=ja;ka=((de((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<X|V;la=X-16|0}else{ka=V;la=X}}while(0);c[Z>>2]=la;X=((R<<7)-128>>8)+1|0;V=X<<16;W=ka>>>0>=V>>>0;ja=W?R-X|0:X;X=ka-(W?V:0)|0;c[N>>2]=X;V=W&1;W=o+90|0;a[W]=V;ma=d[1086680+ja|0]|0;na=ja<<ma;c[Q>>2]=na;ja=X<<ma;X=ma+la|0;do{if((X|0)>-1){ma=o+196|0;oa=c[ma>>2]|0;if(!(oa>>>0<(c[o+200>>2]|0)>>>0)){pa=ja;qa=X;break}c[ma>>2]=oa+2;ma=oa;pa=((de((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<X|ja;qa=X-16|0}else{pa=ja;qa=X}}while(0);c[Z>>2]=qa;X=((na<<7)-128>>8)+1|0;ja=X<<16;R=pa>>>0>=ja>>>0;ma=R?na-X|0:X;c[Q>>2]=ma;X=pa-(R?ja:0)|0;c[N>>2]=X;if(R){R=d[1086680+ma|0]|0;ja=ma<<R;c[Q>>2]=ja;ma=X<<R;X=R+qa|0;do{if((X|0)>-1){R=o+196|0;oa=c[R>>2]|0;if(!(oa>>>0<(c[o+200>>2]|0)>>>0)){ra=ma;sa=X;break}c[R>>2]=oa+2;R=oa;ra=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<X|ma;sa=X-16|0}else{ra=ma;sa=X}}while(0);c[Z>>2]=sa;X=((ja<<7)-128>>8)+1|0;ma=X<<16;na=ra>>>0>=ma>>>0;c[Q>>2]=na?ja-X|0:X;c[N>>2]=ra-(na?ma:0);a[o+89|0]=na&1;a[o+91|0]=D5a(t,7)|0;a[o+92|0]=D5a(t,7)|0;a[o+93|0]=D5a(t,7)|0;a[o+94|0]=D5a(t,7)|0;a[o+95|0]=D5a(t,6)|0;a[o+96|0]=D5a(t,6)|0;a[o+97|0]=D5a(t,6)|0;a[o+98|0]=D5a(t,6)|0;ta=a[W]|0}else{ta=V}if(ta<<24>>24==0){break}na=o+196|0;ma=o+200|0;X=0;do{R=c[Q>>2]|0;oa=d[1086680+R|0]|0;ua=c[Z>>2]|0;va=c[N>>2]|0;wa=R<<oa;c[Q>>2]=wa;R=va<<oa;va=ua+oa|0;do{if((va|0)>-1){oa=c[na>>2]|0;if(!(oa>>>0<(c[ma>>2]|0)>>>0)){xa=R;ya=va;break}c[na>>2]=oa+2;ua=oa;xa=((de((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535)<<va|R;ya=va-16|0}else{xa=R;ya=va}}while(0);c[Z>>2]=ya;va=((wa<<7)-128>>8)+1|0;R=va<<16;ua=xa>>>0>=R>>>0;oa=ua?wa-va|0:va;c[Q>>2]=oa;va=xa-(ua?R:0)|0;c[N>>2]=va;if(ua){ua=8;R=0;za=oa;oa=ya;Aa=va;while(1){va=ua-1|0;Ba=R<<1;Ca=d[1086680+za|0]|0;Da=za<<Ca;c[Q>>2]=Da;Ea=Aa<<Ca;Fa=Ca+oa|0;do{if((Fa|0)>-1){Ca=c[na>>2]|0;if(!(Ca>>>0<(c[ma>>2]|0)>>>0)){Ga=Ea;Ha=Fa;break}c[na>>2]=Ca+2;Ia=Ca;Ga=((de((d[Ia]|d[Ia+1|0]<<8)<<16>>16|0)|0)&65535)<<Fa|Ea;Ha=Fa-16|0}else{Ga=Ea;Ha=Fa}}while(0);c[Z>>2]=Ha;Fa=((Da<<7)-128>>8)+1|0;Ea=Fa<<16;Ia=Ga>>>0>=Ea>>>0;Ca=Ia?Da-Fa|0:Fa;c[Q>>2]=Ca;Fa=Ga-(Ia?Ea:0)|0;c[N>>2]=Fa;Ja=Ia&1|Ba;if((va|0)==0){break}else{ua=va;R=Ja;za=Ca;oa=Ha;Aa=Fa}}Ka=Ja&255}else{Ka=-1}a[p+208+X|0]=Ka;X=X+1|0;}while((X|0)<3)}else{a[o+90|0]=0}}while(0);v=c[Q>>2]|0;H=d[1086680+v|0]|0;Y=c[Z>>2]|0;_=c[N>>2]|0;X=v<<H;c[Q>>2]=X;v=_<<H;_=Y+H|0;H=o+196|0;do{if((_|0)>-1){Y=c[H>>2]|0;na=o+200|0;if(!(Y>>>0<(c[na>>2]|0)>>>0)){La=v;Ma=_;Na=na;break}c[H>>2]=Y+2;ma=Y;La=((de((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<_|v;Ma=_-16|0;Na=na}else{La=v;Ma=_;Na=o+200|0}}while(0);c[Z>>2]=Ma;_=((X<<7)-128>>8)+1|0;v=_<<16;na=La>>>0>=v>>>0;ma=na?X-_|0:_;c[Q>>2]=ma;_=La-(na?v:0)|0;c[N>>2]=_;a[o+99|0]=na&1;na=6;v=0;Y=ma;ma=Ma;V=_;while(1){_=na-1|0;W=v<<1;ja=d[1086680+Y|0]|0;Aa=Y<<ja;c[Q>>2]=Aa;oa=V<<ja;za=ja+ma|0;do{if((za|0)>-1){ja=c[H>>2]|0;if(!(ja>>>0<(c[Na>>2]|0)>>>0)){Oa=oa;Pa=za;break}c[H>>2]=ja+2;R=ja;Oa=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<za|oa;Pa=za-16|0}else{Oa=oa;Pa=za}}while(0);c[Z>>2]=Pa;za=((Aa<<7)-128>>8)+1|0;oa=za<<16;R=Oa>>>0>=oa>>>0;Qa=R?Aa-za|0:za;c[Q>>2]=Qa;Ra=Oa-(R?oa:0)|0;c[N>>2]=Ra;Sa=R&1|W;if((_|0)==0){break}else{na=_;v=Sa;Y=Qa;ma=Pa;V=Ra}}V=o+100|0;a[V]=Sa;ma=d[1086680+Qa|0]|0;Y=Qa<<ma;c[Q>>2]=Y;v=Ra<<ma;na=ma+Pa|0;do{if((na|0)>-1){ma=c[H>>2]|0;if(!(ma>>>0<(c[Na>>2]|0)>>>0)){Ta=v;Ua=na;break}c[H>>2]=ma+2;X=ma;Ta=((de((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535)<<na|v;Ua=na-16|0}else{Ta=v;Ua=na}}while(0);c[Z>>2]=Ua;na=((Y<<7)-128>>8)+1|0;v=na<<16;X=Ta>>>0>=v>>>0;ma=X?Y-na|0:na;na=Ta-(X?v:0)|0;c[N>>2]=na;v=(X&1)<<1;X=d[1086680+ma|0]|0;R=ma<<X;c[Q>>2]=R;ma=na<<X;na=X+Ua|0;do{if((na|0)>-1){X=c[H>>2]|0;if(!(X>>>0<(c[Na>>2]|0)>>>0)){Va=ma;Wa=na;break}c[H>>2]=X+2;oa=X;Va=((de((d[oa]|d[oa+1|0]<<8)<<16>>16|0)|0)&65535)<<na|ma;Wa=na-16|0}else{Va=ma;Wa=na}}while(0);c[Z>>2]=Wa;na=((R<<7)-128>>8)+1|0;ma=na<<16;Y=Va>>>0>=ma>>>0;oa=Y?R-na|0:na;na=Va-(Y?ma:0)|0;c[N>>2]=na;ma=(Y&1|v)<<1;Y=d[1086680+oa|0]|0;X=oa<<Y;c[Q>>2]=X;oa=na<<Y;na=Y+Wa|0;do{if((na|0)>-1){Y=c[H>>2]|0;if(!(Y>>>0<(c[Na>>2]|0)>>>0)){Xa=oa;Ya=na;break}c[H>>2]=Y+2;za=Y;Xa=((de((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<na|oa;Ya=na-16|0}else{Xa=oa;Ya=na}}while(0);c[Z>>2]=Ya;na=((X<<7)-128>>8)+1|0;oa=na<<16;v=Xa>>>0>=oa>>>0;R=v?X-na|0:na;na=Xa-(v?oa:0)|0;c[N>>2]=na;a[o+101|0]=v&1|ma;v=d[1086680+R|0]|0;oa=R<<v;c[Q>>2]=oa;R=na<<v;na=v+Ya|0;do{if((na|0)>-1){v=c[H>>2]|0;if(!(v>>>0<(c[Na>>2]|0)>>>0)){Za=R;_a=na;break}c[H>>2]=v+2;za=v;Za=((de((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<na|R;_a=na-16|0}else{Za=R;_a=na}}while(0);c[Z>>2]=_a;na=((oa<<7)-128>>8)+1|0;R=na<<16;ma=Za>>>0>=R>>>0;X=ma?oa-na|0:na;c[Q>>2]=X;na=Za-(ma?R:0)|0;c[N>>2]=na;a[o+164|0]=ma&1;do{if(ma){R=d[1086680+X|0]|0;za=X<<R;c[Q>>2]=za;v=na<<R;Y=R+_a|0;do{if((Y|0)>-1){R=c[H>>2]|0;if(!(R>>>0<(c[Na>>2]|0)>>>0)){$a=v;ab=Y;break}c[H>>2]=R+2;ja=R;$a=((de((d[ja]|d[ja+1|0]<<8)<<16>>16|0)|0)&65535)<<Y|v;ab=Y-16|0}else{$a=v;ab=Y}}while(0);c[Z>>2]=ab;Y=((za<<7)-128>>8)+1|0;v=Y<<16;_=$a>>>0>=v>>>0;W=_?za-Y|0:Y;c[Q>>2]=W;Y=$a-(_?v:0)|0;c[N>>2]=Y;if(_){bb=0;cb=W;db=ab;eb=Y}else{fb=W;gb=ab;hb=Y;break}while(1){Y=d[1086680+cb|0]|0;W=cb<<Y;c[Q>>2]=W;_=eb<<Y;v=Y+db|0;do{if((v|0)>-1){Y=c[H>>2]|0;if(!(Y>>>0<(c[Na>>2]|0)>>>0)){ib=_;jb=v;break}c[H>>2]=Y+2;Aa=Y;ib=((de((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<v|_;jb=v-16|0}else{ib=_;jb=v}}while(0);c[Z>>2]=jb;v=((W<<7)-128>>8)+1|0;_=v<<16;Aa=ib>>>0>=_>>>0;Y=Aa?W-v|0:v;c[Q>>2]=Y;v=ib-(Aa?_:0)|0;c[N>>2]=v;do{if(Aa){_=6;ja=0;R=Y;ua=jb;wa=v;while(1){Fa=_-1|0;Ca=ja<<1;Ia=d[1086680+R|0]|0;Ea=R<<Ia;c[Q>>2]=Ea;kb=wa<<Ia;lb=Ia+ua|0;do{if((lb|0)>-1){Ia=c[H>>2]|0;if(!(Ia>>>0<(c[Na>>2]|0)>>>0)){mb=kb;nb=lb;break}c[H>>2]=Ia+2;ob=Ia;mb=((de((d[ob]|d[ob+1|0]<<8)<<16>>16|0)|0)&65535)<<lb|kb;nb=lb-16|0}else{mb=kb;nb=lb}}while(0);c[Z>>2]=nb;lb=((Ea<<7)-128>>8)+1|0;kb=lb<<16;ob=mb>>>0>=kb>>>0;Ia=ob?Ea-lb|0:lb;c[Q>>2]=Ia;lb=mb-(ob?kb:0)|0;c[N>>2]=lb;pb=ob&1|Ca;if((Fa|0)==0){break}else{_=Fa;ja=pb;R=Ia;ua=nb;wa=lb}}wa=p+173+bb|0;a[wa]=pb;ua=c[Q>>2]|0;R=d[1086680+ua|0]|0;ja=c[Z>>2]|0;_=c[N>>2]|0;va=ua<<R;c[Q>>2]=va;ua=_<<R;_=ja+R|0;do{if((_|0)>-1){R=c[H>>2]|0;if(!(R>>>0<(c[Na>>2]|0)>>>0)){qb=ua;rb=_;break}c[H>>2]=R+2;ja=R;qb=((de((d[ja]|d[ja+1|0]<<8)<<16>>16|0)|0)&65535)<<_|ua;rb=_-16|0}else{qb=ua;rb=_}}while(0);c[Z>>2]=rb;_=((va<<7)-128>>8)+1|0;ua=_<<16;ja=qb>>>0>=ua>>>0;c[Q>>2]=ja?va-_|0:_;c[N>>2]=qb-(ja?ua:0);if(!ja){break}a[wa]=-(a[wa]|0)}}while(0);v=bb+1|0;if((v|0)>=4){sb=4;break}bb=v;cb=c[Q>>2]|0;db=c[Z>>2]|0;eb=c[N>>2]|0}do{za=c[Q>>2]|0;v=d[1086680+za|0]|0;Y=c[Z>>2]|0;Aa=c[N>>2]|0;W=za<<v;c[Q>>2]=W;za=Aa<<v;Aa=Y+v|0;do{if((Aa|0)>-1){v=c[H>>2]|0;if(!(v>>>0<(c[Na>>2]|0)>>>0)){tb=za;ub=Aa;break}c[H>>2]=v+2;Y=v;tb=((de((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<Aa|za;ub=Aa-16|0}else{tb=za;ub=Aa}}while(0);c[Z>>2]=ub;Aa=((W<<7)-128>>8)+1|0;za=Aa<<16;Y=tb>>>0>=za>>>0;v=Y?W-Aa|0:Aa;c[Q>>2]=v;Aa=tb-(Y?za:0)|0;c[N>>2]=Aa;do{if(Y){za=6;ja=0;ua=v;_=ub;R=Aa;while(1){Ba=za-1|0;Da=ja<<1;lb=d[1086680+ua|0]|0;Ia=ua<<lb;c[Q>>2]=Ia;ob=R<<lb;kb=lb+_|0;do{if((kb|0)>-1){lb=c[H>>2]|0;if(!(lb>>>0<(c[Na>>2]|0)>>>0)){vb=ob;wb=kb;break}c[H>>2]=lb+2;xb=lb;vb=((de((d[xb]|d[xb+1|0]<<8)<<16>>16|0)|0)&65535)<<kb|ob;wb=kb-16|0}else{vb=ob;wb=kb}}while(0);c[Z>>2]=wb;kb=((Ia<<7)-128>>8)+1|0;ob=kb<<16;Fa=vb>>>0>=ob>>>0;Ca=Fa?Ia-kb|0:kb;c[Q>>2]=Ca;kb=vb-(Fa?ob:0)|0;c[N>>2]=kb;yb=Fa&1|Da;if((Ba|0)==0){break}else{za=Ba;ja=yb;ua=Ca;_=wb;R=kb}}R=p+165+sb|0;a[R]=yb;_=c[Q>>2]|0;ua=d[1086680+_|0]|0;ja=c[Z>>2]|0;za=c[N>>2]|0;wa=_<<ua;c[Q>>2]=wa;_=za<<ua;za=ja+ua|0;do{if((za|0)>-1){ua=c[H>>2]|0;if(!(ua>>>0<(c[Na>>2]|0)>>>0)){zb=_;Ab=za;break}c[H>>2]=ua+2;ja=ua;zb=((de((d[ja]|d[ja+1|0]<<8)<<16>>16|0)|0)&65535)<<za|_;Ab=za-16|0}else{zb=_;Ab=za}}while(0);c[Z>>2]=Ab;za=((wa<<7)-128>>8)+1|0;_=za<<16;ja=zb>>>0>=_>>>0;c[Q>>2]=ja?wa-za|0:za;c[N>>2]=zb-(ja?_:0);if(!ja){break}a[R]=-(a[R]|0)}}while(0);sb=sb+1|0;}while((sb|0)<8);fb=c[Q>>2]|0;gb=c[Z>>2]|0;hb=c[N>>2]|0}else{fb=X;gb=_a;hb=na}}while(0);na=d[1086680+fb|0]|0;X=fb<<na;c[Q>>2]=X;ma=hb<<na;oa=na+gb|0;do{if((oa|0)>-1){na=c[H>>2]|0;if(!(na>>>0<(c[Na>>2]|0)>>>0)){Bb=ma;Cb=oa;break}c[H>>2]=na+2;Aa=na;Bb=((de((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|ma;Cb=oa-16|0}else{Bb=ma;Cb=oa}}while(0);c[Z>>2]=Cb;oa=((X<<7)-128>>8)+1|0;ma=oa<<16;Aa=Bb>>>0>=ma>>>0;na=Aa?X-oa|0:oa;oa=Bb-(Aa?ma:0)|0;c[N>>2]=oa;ma=(Aa&1)<<1;Aa=d[1086680+na|0]|0;v=na<<Aa;c[Q>>2]=v;na=oa<<Aa;oa=Aa+Cb|0;do{if((oa|0)>-1){Aa=c[H>>2]|0;if(!(Aa>>>0<(c[Na>>2]|0)>>>0)){Db=na;Eb=oa;break}c[H>>2]=Aa+2;Y=Aa;Db=((de((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|na;Eb=oa-16|0}else{Db=na;Eb=oa}}while(0);c[Z>>2]=Eb;oa=((v<<7)-128>>8)+1|0;na=oa<<16;X=Db>>>0>=na>>>0;c[Q>>2]=X?v-oa|0:oa;c[N>>2]=Db-(X?na:0);na=X&1|ma;X=1<<na;oa=o+4560|0;c[oa>>2]=X;Y=3<<na;na=3-Y+P|0;b:do{if((na|0)>=0){Aa=L+(D-3+Y)|0;if((X-1|0)>0){W=D+2|0;ja=D+1|0;_=na;za=Aa;ua=0;while(1){va=ua*3|0;kb=d[L+(ja+va)|0]<<8|d[L+(W+va)|0]<<16|d[L+(va+D)|0];va=_-kb|0;if((va|0)<0){break b}g5a(p+4564+(ua*20|0)|0,za,kb);Ca=za+kb|0;kb=ua+1|0;if((kb|0)<((c[oa>>2]|0)-1|0)){_=va;za=Ca;ua=kb}else{Fb=va;Gb=Ca;Hb=kb;break}}}else{Fb=na;Gb=Aa;Hb=0}g5a(p+4564+(Hb*20|0)|0,Gb,Fb);ua=o+4536|0;za=(c[ua>>2]|0)==0;_=c[u>>2]|0;W=(K|0)==(c[_+120>>2]|0);do{if(W&(za^1)){if((J|0)!=(c[_+124>>2]|0)){O=123;break}if(((K+15|0)/16|0|0)!=(e[o+48>>1]|0)){O=123;break}if(((J+15|0)/16|0|0)!=(e[o+50>>1]|0)){O=123}}else{if(W){O=123}else{O=127}}}while(0);do{if((O|0)==123){W=o+48|0;if(((K+15|0)/16|0|0)==(e[W>>1]|0)){if(!(((J+15|0)/16|0|0)==(e[o+50>>1]|0)|za)){O=127;break}}else{if(!za){O=127;break}}if((c[_+124>>2]|0)==(J|0)){Ib=_;Jb=W;O=129}else{O=127}}}while(0);if((O|0)==127){x5a(c[_+60>>2]|0,1);za=V$a(c[u>>2]|0,K,J)|0;if((za|0)<0){I=za;break a}Ib=c[u>>2]|0;Jb=o+48|0;O=129}if((O|0)==129){za=((c[Ib+128>>2]|0)+15|0)/16|0;b[Jb>>1]=za;W=((c[Ib+132>>2]|0)+15|0)/16|0;b[o+50>>1]=W;do{if((c[_+816>>2]|0)==2){Aa=c[oa>>2]|0;ja=c[_+808>>2]|0;kb=(((Aa|0)>(ja|0)?ja:Aa)|0)>1;Aa=o+5432|0;c[Aa>>2]=kb&1;ja=za&65535;if(!kb){Kb=Aa;Lb=ja;O=132;break}c[ua>>2]=cEb(ba((W&65535)+2|0,(ja*96|0)+192|0)|0)|0;Mb=Aa}else{Aa=o+5432|0;c[Aa>>2]=0;Kb=Aa;Lb=za&65535;O=132}}while(0);if((O|0)==132){c[ua>>2]=cEb(((Lb+(W<<1&131070)|0)*96|0)+96|0)|0;c[o+108>>2]=cEb(e[Jb>>1]<<2)|0;Mb=Kb}za=o+184|0;c[za>>2]=cEb((e[Jb>>1]|0)*9|0)|0;_=o+180|0;c[_>>2]=cEb((e[Jb>>1]<<5)+32|0)|0;Aa=o;c[Aa>>2]=cEb(12288)|0;ja=cEb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+1520>>2]=ja;ja=cEb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+3056>>2]=ja;ja=cEb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+4592>>2]=ja;ja=cEb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+6128>>2]=ja;ja=cEb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+7664>>2]=ja;ja=cEb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+9200>>2]=ja;ja=cEb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+10736>>2]=ja;ja=cEb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+12272>>2]=ja;ja=c[ua>>2]|0;if((ja|0)==0){I=-12;break a}if((c[za>>2]|0)==0){I=-12;break a}if((c[_>>2]|0)==0){I=-12;break a}if((c[o+108>>2]|0)==0){if((c[Mb>>2]|0)==0){I=-12;break a}}c[o+104>>2]=ja+96}ja=7;_=0;za=c[Q>>2]|0;Aa=c[Z>>2]|0;kb=c[N>>2]|0;while(1){Ca=ja-1|0;va=_<<1;Fa=d[1086680+za|0]|0;ob=za<<Fa;c[Q>>2]=ob;Ea=kb<<Fa;xb=Fa+Aa|0;do{if((xb|0)>-1){Fa=c[H>>2]|0;if(!(Fa>>>0<(c[Na>>2]|0)>>>0)){Nb=Ea;Ob=xb;break}c[H>>2]=Fa+2;lb=Fa;Nb=((de((d[lb]|d[lb+1|0]<<8)<<16>>16|0)|0)&65535)<<xb|Ea;Ob=xb-16|0}else{Nb=Ea;Ob=xb}}while(0);c[Z>>2]=Ob;xb=((ob<<7)-128>>8)+1|0;Ea=xb<<16;lb=Nb>>>0>=Ea>>>0;Fa=lb?ob-xb|0:xb;c[Q>>2]=Fa;xb=Nb-(lb?Ea:0)|0;c[N>>2]=xb;Pb=lb&1|va;if((Ca|0)==0){break}else{ja=Ca;_=Pb;za=Fa;Aa=Ob;kb=xb}}kb=D5a(t,4)|0;Aa=D5a(t,4)|0;za=D5a(t,4)|0;_=D5a(t,4)|0;ja=D5a(t,4)|0;ua=o+89|0;W=0;do{do{if((a[B]|0)==0){Qb=Pb}else{xb=a[p+91+W|0]|0;if((a[ua]|0)!=0){Qb=xb;break}Qb=xb+Pb|0}}while(0);Ca=Qb+kb|0;if(Ca>>>0<128>>>0){Rb=Ca}else{Rb=-Ca>>31&127}b[p+116+(W*12|0)>>1]=d[126456+Rb|0]|0;if(Qb>>>0<128>>>0){Sb=Qb}else{Sb=-Qb>>31&127}b[p+116+(W*12|0)+2>>1]=b[126664+(Sb<<1)>>1]|0;Ca=Qb+Aa|0;if(Ca>>>0<128>>>0){Tb=Ca}else{Tb=-Ca>>31&127}b[p+116+(W*12|0)+4>>1]=d[126456+Tb|0]<<1;Ca=Qb+za|0;if(Ca>>>0<128>>>0){Ub=Ca}else{Ub=-Ca>>31&127}Ca=((e[126664+(Ub<<1)>>1]|0)*101581|0)>>>16&65535;va=p+116+(W*12|0)+6|0;b[va>>1]=Ca;ob=Qb+_|0;if(ob>>>0<128>>>0){Vb=ob}else{Vb=-ob>>31&127}ob=d[126456+Vb|0]|0;xb=p+116+(W*12|0)+8|0;b[xb>>1]=ob;Fa=Qb+ja|0;if(Fa>>>0<128>>>0){Wb=Fa}else{Wb=-Fa>>31&127}b[p+116+(W*12|0)+10>>1]=b[126664+(Wb<<1)>>1]|0;b[va>>1]=(Ca&65535)>>>0>8>>>0?Ca:8;b[xb>>1]=(ob&65535)>>>0>132>>>0?132:ob;W=W+1|0;}while((W|0)<4);W=c[Q>>2]|0;if((a[z]|0)==0){ja=d[1086680+W|0]|0;_=c[Z>>2]|0;za=c[N>>2]|0;Aa=W<<ja;c[Q>>2]=Aa;kb=za<<ja;za=_+ja|0;do{if((za|0)>-1){ja=c[H>>2]|0;if(!(ja>>>0<(c[Na>>2]|0)>>>0)){Xb=kb;Yb=za;break}c[H>>2]=ja+2;_=ja;Xb=((de((d[_]|d[_+1|0]<<8)<<16>>16|0)|0)&65535)<<za|kb;Yb=za-16|0}else{Xb=kb;Yb=za}}while(0);c[Z>>2]=Yb;za=((Aa<<7)-128>>8)+1|0;kb=za<<16;_=Xb>>>0>=kb>>>0;ja=_&1;ua=_?Aa-za|0:za;za=Xb-(_?kb:0)|0;c[N>>2]=za;kb=d[1086680+ua|0]|0;_=ua<<kb;c[Q>>2]=_;ua=za<<kb;za=kb+Yb|0;do{if((za|0)>-1){kb=c[H>>2]|0;if(!(kb>>>0<(c[Na>>2]|0)>>>0)){Zb=ua;_b=za;break}c[H>>2]=kb+2;ob=kb;Zb=((de((d[ob]|d[ob+1|0]<<8)<<16>>16|0)|0)&65535)<<za|ua;_b=za-16|0}else{Zb=ua;_b=za}}while(0);c[Z>>2]=_b;za=((_<<7)-128>>8)+1|0;ua=za<<16;Aa=Zb>>>0>=ua>>>0;c[Q>>2]=Aa?_-za|0:za;c[N>>2]=Zb-(Aa?ua:0);c[o+4548>>2]=C5a(p,ja,2)|0;c[o+4552>>2]=C5a(p,Aa&1,3)|0;Aa=c[Q>>2]|0;ua=d[1086680+Aa|0]|0;za=c[Z>>2]|0;ob=c[N>>2]|0;kb=Aa<<ua;c[Q>>2]=kb;Aa=ob<<ua;ob=za+ua|0;do{if((ob|0)>-1){ua=c[H>>2]|0;if(!(ua>>>0<(c[Na>>2]|0)>>>0)){$b=Aa;ac=ob;break}c[H>>2]=ua+2;za=ua;$b=((de((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<ob|Aa;ac=ob-16|0}else{$b=Aa;ac=ob}}while(0);c[Z>>2]=ac;ob=((kb<<7)-128>>8)+1|0;Aa=ob<<16;ja=$b>>>0>=Aa>>>0;_=ja?kb-ob|0:ob;ob=$b-(ja?Aa:0)|0;c[N>>2]=ob;a[o+74|0]=ja&1;ja=d[1086680+_|0]|0;Aa=_<<ja;c[Q>>2]=Aa;_=ob<<ja;ob=ja+ac|0;do{if((ob|0)>-1){ja=c[H>>2]|0;if(!(ja>>>0<(c[Na>>2]|0)>>>0)){bc=_;cc=ob;break}c[H>>2]=ja+2;za=ja;bc=((de((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<ob|_;cc=ob-16|0}else{bc=_;cc=ob}}while(0);c[Z>>2]=cc;ob=((Aa<<7)-128>>8)+1|0;_=ob<<16;kb=bc>>>0>=_>>>0;za=kb?Aa-ob|0:ob;c[Q>>2]=za;ob=bc-(kb?_:0)|0;c[N>>2]=ob;a[o+75|0]=kb&1;dc=za;ec=cc;fc=ob}else{dc=W;ec=c[Z>>2]|0;fc=c[N>>2]|0}ob=d[1086680+dc|0]|0;za=dc<<ob;c[Q>>2]=za;kb=fc<<ob;_=ob+ec|0;do{if((_|0)>-1){ob=c[H>>2]|0;if(!(ob>>>0<(c[Na>>2]|0)>>>0)){gc=kb;hc=_;break}c[H>>2]=ob+2;ja=ob;gc=((de((d[ja]|d[ja+1|0]<<8)<<16>>16|0)|0)&65535)<<_|kb;hc=_-16|0}else{gc=kb;hc=_}}while(0);c[Z>>2]=hc;_=((za<<7)-128>>8)+1|0;kb=_<<16;W=gc>>>0>=kb>>>0;Aa=W?za-_|0:_;c[Q>>2]=Aa;_=gc-(W?kb:0)|0;c[N>>2]=_;kb=o+4556|0;c[kb>>2]=W&1;if(!W){UGb(o+2372|0,o+208|0,2164)|0}if((a[z]|0)==0){W=d[1086680+Aa|0]|0;ja=Aa<<W;c[Q>>2]=ja;Aa=_<<W;_=W+hc|0;do{if((_|0)>-1){W=c[H>>2]|0;if(!(W>>>0<(c[Na>>2]|0)>>>0)){ic=Aa;jc=_;break}c[H>>2]=W+2;ob=W;ic=((de((d[ob]|d[ob+1|0]<<8)<<16>>16|0)|0)&65535)<<_|Aa;jc=_-16|0}else{ic=Aa;jc=_}}while(0);c[Z>>2]=jc;_=((ja<<7)-128>>8)+1|0;Aa=_<<16;za=ic>>>0>=Aa>>>0;c[Q>>2]=za?ja-_|0:_;c[N>>2]=ic-(za?Aa:0);kc=za&1}else{kc=1}za=o+4544|0;c[za>>2]=kc;Aa=0;do{_=0;do{ob=126584+(_*10|0)|0;W=0;do{ua=0;do{xb=d[122960+(Aa*264|0)+(_*33|0)+(W*11|0)+ua|0]|0;Ca=c[Q>>2]|0;va=d[1086680+Ca|0]|0;Fa=c[Z>>2]|0;lb=c[N>>2]|0;Ea=Ca<<va;c[Q>>2]=Ea;Ca=lb<<va;lb=Fa+va|0;do{if((lb|0)>-1){va=c[H>>2]|0;if(!(va>>>0<(c[Na>>2]|0)>>>0)){lc=Ca;mc=lb;break}c[H>>2]=va+2;Fa=va;lc=((de((d[Fa]|d[Fa+1|0]<<8)<<16>>16|0)|0)&65535)<<lb|Ca;mc=lb-16|0}else{lc=Ca;mc=lb}}while(0);c[Z>>2]=mc;lb=((ba(Ea-1|0,xb)|0)>>8)+1|0;Ca=lb<<16;if(lc>>>0<Ca>>>0){c[Q>>2]=lb;c[N>>2]=lc}else{Fa=Ea-lb|0;c[Q>>2]=Fa;lb=lc-Ca|0;c[N>>2]=lb;Ca=8;va=0;nc=Fa;Fa=mc;oc=lb;while(1){lb=Ca-1|0;pc=va<<1;qc=d[1086680+nc|0]|0;rc=nc<<qc;c[Q>>2]=rc;sc=oc<<qc;tc=qc+Fa|0;do{if((tc|0)>-1){qc=c[H>>2]|0;if(!(qc>>>0<(c[Na>>2]|0)>>>0)){uc=sc;vc=tc;break}c[H>>2]=qc+2;wc=qc;uc=((de((d[wc]|d[wc+1|0]<<8)<<16>>16|0)|0)&65535)<<tc|sc;vc=tc-16|0}else{uc=sc;vc=tc}}while(0);c[Z>>2]=vc;tc=((rc<<7)-128>>8)+1|0;sc=tc<<16;wc=uc>>>0>=sc>>>0;qc=wc?rc-tc|0:tc;c[Q>>2]=qc;tc=uc-(wc?sc:0)|0;c[N>>2]=tc;xc=wc&1|pc;if((lb|0)==0){break}else{Ca=lb;va=xc;nc=qc;Fa=vc;oc=tc}}oc=xc&255;Fa=0;nc=a[ob]|0;do{a[p+222+(Aa*528|0)+((nc<<24>>24)*33|0)+(W*11|0)+ua|0]=oc;Fa=Fa+1|0;nc=a[126584+(_*10|0)+Fa|0]|0;}while(nc<<24>>24>-1)}ua=ua+1|0;}while((ua|0)<11);W=W+1|0;}while((W|0)<3);_=_+1|0;}while((_|0)<8);Aa=Aa+1|0;}while((Aa|0)<4);Aa=c[Q>>2]|0;ja=d[1086680+Aa|0]|0;_=c[Z>>2]|0;W=c[N>>2]|0;ob=Aa<<ja;c[Q>>2]=ob;Aa=W<<ja;W=_+ja|0;do{if((W|0)>-1){ja=c[H>>2]|0;if(!(ja>>>0<(c[Na>>2]|0)>>>0)){yc=Aa;zc=W;break}c[H>>2]=ja+2;_=ja;yc=((de((d[_]|d[_+1|0]<<8)<<16>>16|0)|0)&65535)<<W|Aa;zc=W-16|0}else{yc=Aa;zc=W}}while(0);c[Z>>2]=zc;W=((ob<<7)-128>>8)+1|0;Aa=W<<16;_=yc>>>0>=Aa>>>0;ja=_?ob-W|0:W;c[Q>>2]=ja;W=yc-(_?Aa:0)|0;c[N>>2]=W;a[o+62|0]=_&1;if(_){_=8;Aa=0;R=ja;wa=zc;ua=W;while(1){Ba=_-1|0;Da=Aa<<1;Ia=d[1086680+R|0]|0;nc=R<<Ia;c[Q>>2]=nc;Fa=ua<<Ia;oc=Ia+wa|0;do{if((oc|0)>-1){Ia=c[H>>2]|0;if(!(Ia>>>0<(c[Na>>2]|0)>>>0)){Ac=Fa;Bc=oc;break}c[H>>2]=Ia+2;va=Ia;Ac=((de((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)&65535)<<oc|Fa;Bc=oc-16|0}else{Ac=Fa;Bc=oc}}while(0);c[Z>>2]=Bc;oc=((nc<<7)-128>>8)+1|0;Fa=oc<<16;va=Ac>>>0>=Fa>>>0;Cc=va?nc-oc|0:oc;c[Q>>2]=Cc;Dc=Ac-(va?Fa:0)|0;c[N>>2]=Dc;Ec=va&1|Da;if((Ba|0)==0){break}else{_=Ba;Aa=Ec;R=Cc;wa=Bc;ua=Dc}}a[o+211|0]=Ec;Fc=Cc;Gc=Bc;Hc=Dc}else{Fc=ja;Gc=zc;Hc=W}if((a[z]|0)==0){ua=8;wa=0;R=Fc;Aa=Gc;_=Hc;while(1){ob=ua-1|0;va=wa<<1;Fa=d[1086680+R|0]|0;oc=R<<Fa;c[Q>>2]=oc;Ia=_<<Fa;Ca=Fa+Aa|0;do{if((Ca|0)>-1){Fa=c[H>>2]|0;if(!(Fa>>>0<(c[Na>>2]|0)>>>0)){Ic=Ia;Jc=Ca;break}c[H>>2]=Fa+2;Ea=Fa;Ic=((de((d[Ea]|d[Ea+1|0]<<8)<<16>>16|0)|0)&65535)<<Ca|Ia;Jc=Ca-16|0}else{Ic=Ia;Jc=Ca}}while(0);c[Z>>2]=Jc;Ca=((oc<<7)-128>>8)+1|0;Ia=Ca<<16;Ba=Ic>>>0>=Ia>>>0;Kc=Ba?oc-Ca|0:Ca;c[Q>>2]=Kc;Lc=Ic-(Ba?Ia:0)|0;c[N>>2]=Lc;Mc=Ba&1|va;if((ob|0)==0){break}else{ua=ob;wa=Mc;R=Kc;Aa=Jc;_=Lc}}a[o+212|0]=Mc;_=8;Aa=0;R=Kc;wa=Jc;ua=Lc;while(1){W=_-1|0;ja=Aa<<1;Ba=d[1086680+R|0]|0;Ia=R<<Ba;c[Q>>2]=Ia;Ca=ua<<Ba;Da=Ba+wa|0;do{if((Da|0)>-1){Ba=c[H>>2]|0;if(!(Ba>>>0<(c[Na>>2]|0)>>>0)){Nc=Ca;Oc=Da;break}c[H>>2]=Ba+2;nc=Ba;Nc=((de((d[nc]|d[nc+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|Ca;Oc=Da-16|0}else{Nc=Ca;Oc=Da}}while(0);c[Z>>2]=Oc;Da=((Ia<<7)-128>>8)+1|0;Ca=Da<<16;ob=Nc>>>0>=Ca>>>0;Pc=ob?Ia-Da|0:Da;c[Q>>2]=Pc;Qc=Nc-(ob?Ca:0)|0;c[N>>2]=Qc;Rc=ob&1|ja;if((W|0)==0){break}else{_=W;Aa=Rc;R=Pc;wa=Oc;ua=Qc}}a[o+213|0]=Rc;ua=8;wa=0;R=Pc;Aa=Oc;_=Qc;while(1){ob=ua-1|0;Ca=wa<<1;Da=d[1086680+R|0]|0;va=R<<Da;c[Q>>2]=va;oc=_<<Da;nc=Da+Aa|0;do{if((nc|0)>-1){Da=c[H>>2]|0;if(!(Da>>>0<(c[Na>>2]|0)>>>0)){Sc=oc;Tc=nc;break}c[H>>2]=Da+2;Ba=Da;Sc=((de((d[Ba]|d[Ba+1|0]<<8)<<16>>16|0)|0)&65535)<<nc|oc;Tc=nc-16|0}else{Sc=oc;Tc=nc}}while(0);c[Z>>2]=Tc;nc=((va<<7)-128>>8)+1|0;oc=nc<<16;W=Sc>>>0>=oc>>>0;Uc=W?va-nc|0:nc;c[Q>>2]=Uc;Vc=Sc-(W?oc:0)|0;c[N>>2]=Vc;Wc=W&1|Ca;if((ob|0)==0){break}else{ua=ob;wa=Wc;R=Uc;Aa=Tc;_=Vc}}a[o+214|0]=Wc;_=d[1086680+Uc|0]|0;Aa=Uc<<_;c[Q>>2]=Aa;R=Vc<<_;wa=_+Tc|0;do{if((wa|0)>-1){_=c[H>>2]|0;if(!(_>>>0<(c[Na>>2]|0)>>>0)){Xc=R;Yc=wa;break}c[H>>2]=_+2;ua=_;Xc=((de((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535)<<wa|R;Yc=wa-16|0}else{Xc=R;Yc=wa}}while(0);c[Z>>2]=Yc;wa=((Aa<<7)-128>>8)+1|0;R=wa<<16;ua=Xc>>>0>=R>>>0;_=ua?Aa-wa|0:wa;c[Q>>2]=_;wa=Xc-(ua?R:0)|0;c[N>>2]=wa;if(ua){ua=0;R=_;W=Yc;oc=wa;while(1){nc=8;ja=0;Ia=R;Ba=W;Da=oc;while(1){Ea=nc-1|0;Fa=ja<<1;xb=d[1086680+Ia|0]|0;tc=Ia<<xb;c[Q>>2]=tc;qc=Da<<xb;wc=xb+Ba|0;do{if((wc|0)>-1){xb=c[H>>2]|0;if(!(xb>>>0<(c[Na>>2]|0)>>>0)){Zc=qc;_c=wc;break}c[H>>2]=xb+2;sc=xb;Zc=((de((d[sc]|d[sc+1|0]<<8)<<16>>16|0)|0)&65535)<<wc|qc;_c=wc-16|0}else{Zc=qc;_c=wc}}while(0);c[Z>>2]=_c;wc=((tc<<7)-128>>8)+1|0;qc=wc<<16;sc=Zc>>>0>=qc>>>0;xb=sc?tc-wc|0:wc;c[Q>>2]=xb;wc=Zc-(sc?qc:0)|0;c[N>>2]=wc;$c=sc&1|Fa;if((Ea|0)==0){break}else{nc=Ea;ja=$c;Ia=xb;Ba=_c;Da=wc}}a[p+215+ua|0]=$c;Da=ua+1|0;Ba=c[Q>>2]|0;Ia=c[Z>>2]|0;ja=c[N>>2]|0;if((Da|0)<4){ua=Da;R=Ba;W=Ia;oc=ja}else{ad=Ba;bd=Ia;cd=ja;break}}}else{ad=_;bd=Yc;cd=wa}oc=d[1086680+ad|0]|0;W=ad<<oc;c[Q>>2]=W;R=cd<<oc;ua=oc+bd|0;do{if((ua|0)>-1){oc=c[H>>2]|0;if(!(oc>>>0<(c[Na>>2]|0)>>>0)){dd=R;ed=ua;break}c[H>>2]=oc+2;Aa=oc;dd=((de((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<ua|R;ed=ua-16|0}else{dd=R;ed=ua}}while(0);c[Z>>2]=ed;ua=((W<<7)-128>>8)+1|0;R=ua<<16;wa=dd>>>0>=R>>>0;_=wa?W-ua|0:ua;c[Q>>2]=_;ua=dd-(wa?R:0)|0;c[N>>2]=ua;if(wa){wa=8;R=0;Aa=_;_=ed;oc=ua;while(1){ua=wa-1|0;ja=R<<1;Ia=d[1086680+Aa|0]|0;Ba=Aa<<Ia;c[Q>>2]=Ba;Da=oc<<Ia;nc=Ia+_|0;do{if((nc|0)>-1){Ia=c[H>>2]|0;if(!(Ia>>>0<(c[Na>>2]|0)>>>0)){fd=Da;gd=nc;break}c[H>>2]=Ia+2;ob=Ia;fd=((de((d[ob]|d[ob+1|0]<<8)<<16>>16|0)|0)&65535)<<nc|Da;gd=nc-16|0}else{fd=Da;gd=nc}}while(0);c[Z>>2]=gd;nc=((Ba<<7)-128>>8)+1|0;Da=nc<<16;ob=fd>>>0>=Da>>>0;hd=ob?Ba-nc|0:nc;c[Q>>2]=hd;id=fd-(ob?Da:0)|0;c[N>>2]=id;jd=ob&1|ja;if((ua|0)==0){break}else{wa=ua;R=jd;Aa=hd;_=gd;oc=id}}a[o+219|0]=jd;oc=8;_=0;Aa=hd;R=gd;wa=id;while(1){W=oc-1|0;ob=_<<1;Da=d[1086680+Aa|0]|0;nc=Aa<<Da;c[Q>>2]=nc;Ia=wa<<Da;Ca=Da+R|0;do{if((Ca|0)>-1){Da=c[H>>2]|0;if(!(Da>>>0<(c[Na>>2]|0)>>>0)){kd=Ia;ld=Ca;break}c[H>>2]=Da+2;va=Da;kd=((de((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)&65535)<<Ca|Ia;ld=Ca-16|0}else{kd=Ia;ld=Ca}}while(0);c[Z>>2]=ld;Ca=((nc<<7)-128>>8)+1|0;Ia=Ca<<16;ua=kd>>>0>=Ia>>>0;md=ua?nc-Ca|0:Ca;c[Q>>2]=md;nd=kd-(ua?Ia:0)|0;c[N>>2]=nd;od=ua&1|ob;if((W|0)==0){break}else{oc=W;_=od;Aa=md;R=ld;wa=nd}}a[o+220|0]=od;wa=8;R=0;Aa=md;_=ld;oc=nd;while(1){ua=wa-1|0;Ia=R<<1;Ca=d[1086680+Aa|0]|0;ja=Aa<<Ca;c[Q>>2]=ja;Ba=oc<<Ca;va=Ca+_|0;do{if((va|0)>-1){Ca=c[H>>2]|0;if(!(Ca>>>0<(c[Na>>2]|0)>>>0)){pd=Ba;qd=va;break}c[H>>2]=Ca+2;Da=Ca;pd=((de((d[Da]|d[Da+1|0]<<8)<<16>>16|0)|0)&65535)<<va|Ba;qd=va-16|0}else{pd=Ba;qd=va}}while(0);c[Z>>2]=qd;va=((ja<<7)-128>>8)+1|0;Ba=va<<16;W=pd>>>0>=Ba>>>0;ob=W?ja-va|0:va;c[Q>>2]=ob;va=pd-(W?Ba:0)|0;c[N>>2]=va;rd=W&1|Ia;if((ua|0)==0){break}else{wa=ua;R=rd;Aa=ob;_=qd;oc=va}}a[o+221|0]=rd;sd=0}else{sd=0}do{oc=0;do{_=d[126088+(sd*19|0)+oc|0]|0;Aa=c[Q>>2]|0;R=d[1086680+Aa|0]|0;wa=c[Z>>2]|0;va=c[N>>2]|0;ob=Aa<<R;c[Q>>2]=ob;Aa=va<<R;va=wa+R|0;do{if((va|0)>-1){R=c[H>>2]|0;if(!(R>>>0<(c[Na>>2]|0)>>>0)){td=Aa;ud=va;break}c[H>>2]=R+2;wa=R;td=((de((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)<<va|Aa;ud=va-16|0}else{td=Aa;ud=va}}while(0);c[Z>>2]=ud;va=((ba(ob-1|0,_)|0)>>8)+1|0;Aa=va<<16;if(td>>>0<Aa>>>0){c[Q>>2]=va;c[N>>2]=td}else{Ea=ob-va|0;c[Q>>2]=Ea;va=td-Aa|0;c[N>>2]=va;Aa=7;Fa=0;tc=Ea;Ea=ud;wa=va;while(1){va=Aa-1|0;R=Fa<<1;W=d[1086680+tc|0]|0;Ba=tc<<W;c[Q>>2]=Ba;nc=wa<<W;Da=W+Ea|0;do{if((Da|0)>-1){W=c[H>>2]|0;if(!(W>>>0<(c[Na>>2]|0)>>>0)){vd=nc;wd=Da;break}c[H>>2]=W+2;Ca=W;vd=((de((d[Ca]|d[Ca+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|nc;wd=Da-16|0}else{vd=nc;wd=Da}}while(0);c[Z>>2]=wd;Da=((Ba<<7)-128>>8)+1|0;nc=Da<<16;Ca=vd>>>0>=nc>>>0;W=Ca?Ba-Da|0:Da;c[Q>>2]=W;Da=vd-(Ca?nc:0)|0;c[N>>2]=Da;xd=Ca&1|R;if((va|0)==0){break}else{Aa=va;Fa=xd;tc=W;Ea=wd;wa=Da}}wa=xd<<1;a[p+2334+(sd*19|0)+oc|0]=(wa|0)==0|wa}oc=oc+1|0;}while((oc|0)<19);sd=sd+1|0;}while((sd|0)<2)}oc=o+8|0;ua=oc;Ia=oc;ja=c[Ia>>2]|0;do{if((c[za>>2]|0)==0){if((c[o+4548>>2]|0)==0){O=283;break}if((c[o+4552>>2]|0)==0){O=283}else{yd=8;zd=0}}else{O=283}}while(0);if((O|0)==283){yd=(a[z]|0)==0?32:48;zd=1}if((c[f+856>>2]|0)<(yd|0)){if((a[V]|0)==0){Ad=0}else{Ad=(c[f+848>>2]|0)<(yd|0)|0}a[o+61|0]=Ad;wa=o+5348|0;Ea=o+12|0;tc=o+16|0;Fa=o+20|0;Aa=wa;ob=(Aa|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|ob)){if((Aa|0)==(c[Ea>>2]|0)){break}if((Aa|0)==(c[tc>>2]|0)){break}if((Aa|0)==(c[Fa>>2]|0)){break}XAb(o+5360|0);U0a(c[u>>2]|0,wa)}}while(0);wa=o+5364|0;_=wa;Da=(_|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|Da)){if((_|0)==(c[Ea>>2]|0)){break}if((_|0)==(c[tc>>2]|0)){break}if((_|0)==(c[Fa>>2]|0)){break}XAb(o+5376|0);U0a(c[u>>2]|0,wa)}}while(0);wa=o+5380|0;W=wa;Ca=(W|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|Ca)){if((W|0)==(c[Ea>>2]|0)){break}if((W|0)==(c[tc>>2]|0)){break}if((W|0)==(c[Fa>>2]|0)){break}XAb(o+5392|0);U0a(c[u>>2]|0,wa)}}while(0);wa=o+5396|0;nc=wa;wc=(nc|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|wc)){if((nc|0)==(c[Ea>>2]|0)){break}if((nc|0)==(c[tc>>2]|0)){break}if((nc|0)==(c[Fa>>2]|0)){break}XAb(o+5408|0);U0a(c[u>>2]|0,wa)}}while(0);wa=o+5412|0;xb=wa;sc=(xb|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|sc)){if((xb|0)==(c[Ea>>2]|0)){break}if((xb|0)==(c[tc>>2]|0)){break}if((xb|0)==(c[Fa>>2]|0)){break}XAb(o+5424|0);U0a(c[u>>2]|0,wa)}}while(0);do{if(ob){O=297}else{if((Aa|0)==(c[Ea>>2]|0)){O=297;break}if((Aa|0)==(c[tc>>2]|0)){O=297;break}if((Aa|0)==(c[Fa>>2]|0)){O=297}else{Bd=Aa}}}while(0);c:do{if((O|0)==297){do{if(!Da){if((_|0)==(c[Ea>>2]|0)){break}if((_|0)==(c[tc>>2]|0)){break}if((_|0)!=(c[Fa>>2]|0)){Bd=_;break c}}}while(0);do{if(!Ca){if((W|0)==(c[Ea>>2]|0)){break}if((W|0)==(c[tc>>2]|0)){break}if((W|0)!=(c[Fa>>2]|0)){Bd=W;break c}}}while(0);do{if(!wc){if((nc|0)==(c[Ea>>2]|0)){break}if((nc|0)==(c[tc>>2]|0)){break}if((nc|0)!=(c[Fa>>2]|0)){Bd=nc;break c}}}while(0);if(sc){Dd=f;yDb(Dd,8,2198e3,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Cd();return 0}if((xb|0)==(c[Ea>>2]|0)){Dd=f;yDb(Dd,8,2198e3,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Cd();return 0}if((xb|0)==(c[tc>>2]|0)){Dd=f;yDb(Dd,8,2198e3,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Cd();return 0}if((xb|0)!=(c[Fa>>2]|0)){Bd=xb;break}Dd=f;yDb(Dd,8,2198e3,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Cd();return 0}}while(0);c[Ia>>2]=Bd;xb=Bd|0;sc=Bd|0;if((c[c[sc>>2]>>2]|0)!=0){XAb(Bd+12|0);U0a(c[u>>2]|0,xb)}nc=a[z]|0;d:do{if(nc<<24>>24==0){do{if((c[Ea>>2]|0)!=0){if((c[tc>>2]|0)==0){break}if((c[Fa>>2]|0)!=0){break d}}}while(0);yDb(f,24,2311536,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;I=-1094995529;break a}}while(0);Ia=c[sc>>2]|0;c[Ia+84>>2]=nc&255;c[Ia+88>>2]=(a[z]|0)!=0?1:2;Ia=W0a(c[u>>2]|0,xb,zd)|0;if((Ia|0)<0){I=Ia;break a}Ia=o+48|0;wc=o+50|0;W=VAb(ba(e[wc>>1]|0,e[Ia>>1]|0)|0)|0;Ca=Bd+12|0;c[Ca>>2]=W;if((W|0)==0){U0a(c[u>>2]|0,xb);I=-12;break a}W=c[o+4552>>2]|0;if((W|0)==-1){c[o+36>>2]=c[Fa>>2]}else{c[o+36>>2]=c[ua+(W<<2)>>2]}W=c[o+4548>>2]|0;if((W|0)==-1){c[o+32>>2]=c[tc>>2]}else{c[o+32>>2]=c[ua+(W<<2)>>2]}if((c[za>>2]|0)==0){c[o+28>>2]=c[Ea>>2]}else{c[o+28>>2]=Bd}W=o+24|0;c[W>>2]=Bd;X0a(f);_=c[sc>>2]|0;c[o+52>>2]=c[_+32>>2];c[o+56>>2]=c[_+36>>2];TGb(c[o+184>>2]|0,0,(e[Ia>>1]|0)*9|0|0)|0;_=o+5432|0;Da=c[_>>2]|0;do{if((Da|0)==0){TGb((c[o+104>>2]|0)+(((e[wc>>1]<<1)-1|0)*96|0)|0,0,((e[Ia>>1]|0)*96|0)+96|0)|0;Aa=c[_>>2]|0;if((Aa|0)!=0){Ed=Aa;O=323;break}if((a[z]|0)==0){TGb(o+76|0,0,12)|0;break}else{TGb(c[o+108>>2]|0,2,e[Ia>>1]<<2|0)|0;Ed=c[_>>2]|0;O=323;break}}else{Ed=Da;O=323}}while(0);do{if((O|0)==323){TGb(o+76|0,0,12)|0;if((Ed|0)!=1){break}Da=(ja|0)==0;do{if(!Da){if((a[B]|0)==0){break}if((a[o+90|0]|0)!=0){break}Z0a(ja|0,1,0)}}while(0);_=c[n>>2]|0;Ia=_;sc=_+66|0;b[sc>>1]=-64;Ea=_+50|0;za=b[Ea>>1]|0;ua=za<<6;tc=_+70|0;b[tc>>1]=ua;if(za<<16>>16==0){break}Fa=_+4536|0;nc=_+48|0;Aa=_+112|0;ob=_+64|0;wa=_+68|0;qc=_+188|0;Fd=qc;Gd=_+90|0;Hd=_+88|0;Id=_+62|0;Jd=_+60|0;Kd=_+212|0;Ld=qc;qc=_+192|0;Md=_+204|0;Nd=_+196|0;Od=_+200|0;Pd=_+213|0;Qd=m;Rd=l;Sd=m;Td=l|0;Ud=l+4|0;Vd=Ud|0;Wd=l+8|0;Xd=Wd|0;Yd=Sd+3|0;Zd=Sd+2|0;_d=Sd+1|0;$d=Ud;ae=Ud+2|0;Ud=Wd;be=Wd+2|0;Wd=_+2334|0;ce=_+2353|0;ee=l+12|0;fe=_+214|0;ge=_+5432|0;he=_+108|0;ie=_+211|0;je=_+208|0;_=ja+12|0;ke=0;le=b[nc>>1]|0;me=-64;ne=ua;ua=za;while(1){za=c[Fa>>2]|0;oe=le&65535;pe=ke+1|0;c[Aa>>2]=33686018;b[ob>>1]=-64;b[wa>>1]=le<<6;if(le<<16>>16==0){qe=0;re=me;se=ne;te=ua}else{ue=(ke|0)==0;ve=0;we=za+(((ba(oe+1|0,pe)|0)+1|0)*96|0)|0;za=ba(oe,ke)|0;xe=oe;while(1){if(ue){c[we+(~xe*96|0)+22>>2]=33686018}oe=(c[(c[Ca>>2]|0)+4>>2]|0)+za|0;do{if(Da){ye=0}else{ze=c[_>>2]|0;if((ze|0)==0){ye=0;break}ye=(c[ze+4>>2]|0)+za|0}}while(0);do{if((a[Gd]|0)==0){if((a[Hd]|0)==0){Ae=a[oe]|0;break}else{va=a[(ye|0)==0?oe:ye]|0;a[oe]=va;Ae=va;break}}else{va=a[je]|0;R=c[Ld>>2]|0;Ba=d[1086680+R|0]|0;ze=c[qc>>2]|0;Be=c[Md>>2]|0;Ce=R<<Ba;c[Ld>>2]=Ce;R=Be<<Ba;Be=ze+Ba|0;do{if((Be|0)>-1){Ba=c[Nd>>2]|0;if(!(Ba>>>0<(c[Od>>2]|0)>>>0)){De=R;Ee=Be;break}c[Nd>>2]=Ba+2;ze=Ba;De=((de((d[ze]|d[ze+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|R;Ee=Be-16|0}else{De=R;Ee=Be}}while(0);c[qc>>2]=Ee;Be=((ba(Ce-1|0,va&255)|0)>>8)+1|0;R=Be<<16;ze=De>>>0>=R>>>0;Ba=ze&1;Fe=ze?Ce-Be|0:Be;c[Ld>>2]=Fe;Be=De-(ze?R:0)|0;c[Md>>2]=Be;R=a[(ze?2:1)+(Ia+208)|0]|0;ze=d[1086680+Fe|0]|0;Ge=Fe<<ze;c[Ld>>2]=Ge;Fe=Be<<ze;Be=ze+Ee|0;do{if((Be|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){He=Fe;Ie=Be;break}c[Nd>>2]=ze+2;Je=ze;He=((de((d[Je]|d[Je+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|Fe;Ie=Be-16|0}else{He=Fe;Ie=Be}}while(0);c[qc>>2]=Ie;Be=((ba(Ge-1|0,R&255)|0)>>8)+1|0;Fe=Be<<16;Ce=He>>>0>=Fe>>>0;c[Ld>>2]=Ce?Ge-Be|0:Be;c[Md>>2]=He-(Ce?Fe:0);Fe=Ce&1|Ba<<1;a[oe]=Fe;Ae=Fe}}while(0);a[we+5|0]=Ae;if((a[Id]|0)==0){Ke=0}else{oe=a[ie]|0;Fe=c[Ld>>2]|0;Ce=d[1086680+Fe|0]|0;Be=c[qc>>2]|0;va=c[Md>>2]|0;Je=Fe<<Ce;c[Ld>>2]=Je;Fe=va<<Ce;va=Be+Ce|0;do{if((va|0)>-1){Ce=c[Nd>>2]|0;if(!(Ce>>>0<(c[Od>>2]|0)>>>0)){Le=Fe;Me=va;break}c[Nd>>2]=Ce+2;Be=Ce;Le=((de((d[Be]|d[Be+1|0]<<8)<<16>>16|0)|0)&65535)<<va|Fe;Me=va-16|0}else{Le=Fe;Me=va}}while(0);c[qc>>2]=Me;va=((ba(Je-1|0,oe&255)|0)>>8)+1|0;Fe=va<<16;Be=Le>>>0>=Fe>>>0;c[Ld>>2]=Be?Je-va|0:va;c[Md>>2]=Le-(Be?Fe:0);Ke=Be&1}a[we|0]=Ke;do{if((a[Jd]|0)==0){Be=d[Kd]|0;Fe=c[Ld>>2]|0;va=d[1086680+Fe|0]|0;Ce=c[qc>>2]|0;ze=c[Md>>2]|0;Ne=Fe<<va;c[Ld>>2]=Ne;Fe=ze<<va;ze=Ce+va|0;do{if((ze|0)>-1){va=c[Nd>>2]|0;if(!(va>>>0<(c[Od>>2]|0)>>>0)){Oe=Fe;Qe=ze;break}c[Nd>>2]=va+2;Ce=va;Oe=((de((d[Ce]|d[Ce+1|0]<<8)<<16>>16|0)|0)&65535)<<ze|Fe;Qe=ze-16|0}else{Oe=Fe;Qe=ze}}while(0);c[qc>>2]=Qe;ze=((ba(Ne-1|0,Be)|0)>>8)+1|0;Fe=ze<<16;if(Oe>>>0<Fe>>>0){c[Ld>>2]=ze;c[Md>>2]=Oe;Ba=0;Ge=ze;R=Qe;Ce=Oe;while(1){va=a[Ia+215+Ba|0]|0;Re=d[1086680+Ge|0]|0;Se=Ge<<Re;c[Ld>>2]=Se;Te=Ce<<Re;Ue=Re+R|0;do{if((Ue|0)>-1){Re=c[Nd>>2]|0;if(!(Re>>>0<(c[Od>>2]|0)>>>0)){Ve=Te;We=Ue;break}c[Nd>>2]=Re+2;Xe=Re;Ve=((de((d[Xe]|d[Xe+1|0]<<8)<<16>>16|0)|0)&65535)<<Ue|Te;We=Ue-16|0}else{Ve=Te;We=Ue}}while(0);c[qc>>2]=We;Ue=((ba(Se-1|0,va&255)|0)>>8)+1|0;Te=Ue<<16;lb=Ve>>>0>=Te>>>0;pc=lb?Se-Ue|0:Ue;c[Ld>>2]=pc;Ue=Ve-(lb?Te:0)|0;c[Md>>2]=Ue;Te=a[(lb&1)+(126072+(Ba<<1))|0]|0;Ye=Te<<24>>24;if(Te<<24>>24>0){Ba=Ye;Ge=pc;R=We;Ce=Ue}else{break}}Ce=-Ye|0;a[we+1|0]=Ce;if((Ce&255|0)==4){Ce=we+(~e[nc>>1]*96|0)+22|0;R=we+22|0;x=d[Ce]|d[Ce+1|0]<<8|d[Ce+2|0]<<16|d[Ce+3|0]<<24|0;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;R=0;do{Ce=0;Ge=c[Ld>>2]|0;Ba=c[qc>>2]|0;Be=c[Md>>2]|0;while(1){Ue=a[126040+Ce|0]|0;pc=d[1086680+Ge|0]|0;Te=Ge<<pc;c[Ld>>2]=Te;lb=Be<<pc;rc=pc+Ba|0;do{if((rc|0)>-1){pc=c[Nd>>2]|0;if(!(pc>>>0<(c[Od>>2]|0)>>>0)){Ze=lb;_e=rc;break}c[Nd>>2]=pc+2;Xe=pc;Ze=((de((d[Xe]|d[Xe+1|0]<<8)<<16>>16|0)|0)&65535)<<rc|lb;_e=rc-16|0}else{Ze=lb;_e=rc}}while(0);c[qc>>2]=_e;rc=((ba(Te-1|0,Ue&255)|0)>>8)+1|0;lb=rc<<16;Xe=Ze>>>0>=lb>>>0;pc=Xe?Te-rc|0:rc;c[Ld>>2]=pc;rc=Ze-(Xe?lb:0)|0;c[Md>>2]=rc;$e=a[(Xe&1)+(125112+(Ce<<1))|0]|0;if($e<<24>>24>0){Ce=$e<<24>>24;Ge=pc;Ba=_e;Be=rc}else{break}}a[we+6+R|0]=-$e;R=R+1|0;}while((R|0)<16)}R=0;Be=c[Ld>>2]|0;Ba=c[qc>>2]|0;Ge=c[Md>>2]|0;while(1){Ce=a[Ia+219+R|0]|0;Se=d[1086680+Be|0]|0;va=Be<<Se;c[Ld>>2]=va;rc=Ge<<Se;pc=Se+Ba|0;do{if((pc|0)>-1){Se=c[Nd>>2]|0;if(!(Se>>>0<(c[Od>>2]|0)>>>0)){af=rc;bf=pc;break}c[Nd>>2]=Se+2;Xe=Se;af=((de((d[Xe]|d[Xe+1|0]<<8)<<16>>16|0)|0)&65535)<<pc|rc;bf=pc-16|0}else{af=rc;bf=pc}}while(0);c[qc>>2]=bf;pc=((ba(va-1|0,Ce&255)|0)>>8)+1|0;rc=pc<<16;Xe=af>>>0>=rc>>>0;Se=Xe?va-pc|0:pc;c[Ld>>2]=Se;pc=af-(Xe?rc:0)|0;c[Md>>2]=pc;cf=a[(Xe&1)+(125088+(R<<1))|0]|0;if(cf<<24>>24>0){R=cf<<24>>24;Be=Se;Ba=bf;Ge=pc}else{break}}a[we+4|0]=-cf;a[we+2|0]=0;a[we+3|0]=4;c[we+32>>2]=0;break}Ge=Ne-ze|0;Ba=Oe-Fe|0;c[Md>>2]=Ba;Be=d[Pd]|0;R=d[1086680+Ge|0]|0;pc=Ge<<R;c[Ld>>2]=pc;Ge=Ba<<R;Ba=R+Qe|0;do{if((Ba|0)>-1){R=c[Nd>>2]|0;if(!(R>>>0<(c[Od>>2]|0)>>>0)){df=Ge;ef=Ba;break}c[Nd>>2]=R+2;Se=R;df=((de((d[Se]|d[Se+1|0]<<8)<<16>>16|0)|0)&65535)<<Ba|Ge;ef=Ba-16|0}else{df=Ge;ef=Ba}}while(0);c[qc>>2]=ef;Ba=((ba(pc-1|0,Be)|0)>>8)+1|0;Ge=Ba<<16;if(df>>>0<Ge>>>0){c[Ld>>2]=Ba;c[Md>>2]=df;a[we+2|0]=1;ff=0}else{Fe=pc-Ba|0;Ba=df-Ge|0;c[Md>>2]=Ba;Ge=a[fe]|0;ze=d[1086680+Fe|0]|0;Ne=Fe<<ze;c[Ld>>2]=Ne;Fe=Ba<<ze;Ba=ze+ef|0;do{if((Ba|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){gf=Fe;hf=Ba;break}c[Nd>>2]=ze+2;Se=ze;gf=((de((d[Se]|d[Se+1|0]<<8)<<16>>16|0)|0)&65535)<<Ba|Fe;hf=Ba-16|0}else{gf=Fe;hf=Ba}}while(0);c[qc>>2]=hf;Ba=((ba(Ne-1|0,Ge&255)|0)>>8)+1|0;Fe=Ba<<16;pc=gf>>>0>=Fe>>>0;c[Ld>>2]=pc?Ne-Ba|0:Ba;c[Md>>2]=gf-(pc?Fe:0);Fe=pc?3:2;a[we+2|0]=Fe;ff=(Fe&255)-1|0}Fe=Ia+76+(ff<<2)|0;c[Fe>>2]=(c[Fe>>2]|0)+1;Fe=a[(d[we+2|0]|0)+(Ia+72)|0]|0;c[m>>2]=0;pc=e[nc>>1]|0;Ba=~pc;Be=-2-pc|0;c[Td>>2]=0;c[Vd>>2]=0;c[Xd>>2]=0;pc=a[we+(Ba*96|0)+2|0]|0;Se=pc&255;do{if(pc<<24>>24==0){jf=0;kf=2}else{ze=c[we+(Ba*96|0)+28>>2]|0;if((ze|0)==0){a[Qd]=2;jf=0;kf=4;break}if(Fe<<24>>24==(a[Ia+72+Se|0]|0)){lf=ze}else{R=~ze;lf=(R&2147450879)+65537^R&-2147450880}c[Vd>>2]=lf;a[_d]=2;jf=1;kf=2}}while(0);Se=a[we-96+2|0]|0;pc=Se&255;do{if(Se<<24>>24==0){mf=jf}else{Ne=c[we-96+28>>2]|0;if((Ne|0)==0){a[Qd]=kf;mf=jf;break}if(Fe<<24>>24==(a[Ia+72+pc|0]|0)){nf=Ne}else{Ge=~Ne;nf=(Ge&2147450879)+65537^Ge&-2147450880}if((nf|0)==(c[Rd+(jf<<2)>>2]|0)){of=jf}else{Ge=jf+1|0;c[Rd+(Ge<<2)>>2]=nf;of=Ge}Ge=Sd+of|0;a[Ge]=(a[Ge]|0)+2;mf=of}}while(0);pc=a[we+(Be*96|0)+2|0]|0;Se=pc&255;do{if(!(pc<<24>>24==0)){Ge=c[we+(Be*96|0)+28>>2]|0;if((Ge|0)==0){a[Qd]=(a[Qd]|0)+1;break}if(Fe<<24>>24==(a[Ia+72+Se|0]|0)){pf=Ge}else{Ne=~Ge;pf=(Ne&2147450879)+65537^Ne&-2147450880}if((pf|0)==(c[Rd+(mf<<2)>>2]|0)){qf=mf}else{Ne=mf+1|0;c[Rd+(Ne<<2)>>2]=pf;qf=Ne}Ne=Sd+qf|0;a[Ne]=(a[Ne]|0)+1}}while(0);Se=we+3|0;a[Se]=4;Fe=a[Qd]|0;pc=c[126168+((Fe&255)<<4)>>2]|0;Ne=c[Ld>>2]|0;Ge=d[1086680+Ne|0]|0;R=c[qc>>2]|0;ze=c[Md>>2]|0;Xe=Ne<<Ge;c[Ld>>2]=Xe;Ne=ze<<Ge;ze=R+Ge|0;do{if((ze|0)>-1){Ge=c[Nd>>2]|0;if(!(Ge>>>0<(c[Od>>2]|0)>>>0)){rf=Ne;sf=ze;break}c[Nd>>2]=Ge+2;R=Ge;rf=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<ze|Ne;sf=ze-16|0}else{rf=Ne;sf=ze}}while(0);c[qc>>2]=sf;ze=((ba(Xe-1|0,pc)|0)>>8)+1|0;Ne=ze<<16;if(rf>>>0<Ne>>>0){c[Ld>>2]=ze;c[Md>>2]=rf;a[we+1|0]=5;c[we+28>>2]=0;c[we+32>>2]=0;break}c[Ld>>2]=Xe-ze;c[Md>>2]=rf-Ne;Ne=we+1|0;a[Ne]=6;do{if((a[Yd]|0)!=0){if((c[Vd>>2]|0)!=(c[ee>>2]|0)){break}a[_d]=(a[_d]|0)+1}}while(0);Xe=a[Zd]|0;pc=a[_d]|0;if((Xe&255)>>>0>(pc&255)>>>0){a[Zd]=pc;a[_d]=Xe;ze=c[Xd>>2]|0;c[Xd>>2]=c[Vd>>2];c[Vd>>2]=ze;tf=Xe;uf=pc}else{tf=pc;uf=Xe}Xe=c[126172+((tf&255)<<4)>>2]|0;pc=c[Ld>>2]|0;ze=d[1086680+pc|0]|0;R=c[qc>>2]|0;Ge=c[Md>>2]|0;rc=pc<<ze;c[Ld>>2]=rc;pc=Ge<<ze;Ge=R+ze|0;do{if((Ge|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){vf=pc;wf=Ge;break}c[Nd>>2]=ze+2;R=ze;vf=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|pc;wf=Ge-16|0}else{vf=pc;wf=Ge}}while(0);c[qc>>2]=wf;Ge=((ba(rc-1|0,Xe)|0)>>8)+1|0;pc=Ge<<16;if(vf>>>0<pc>>>0){c[Ld>>2]=Ge;c[Md>>2]=vf;R=we+28|0;ze=b[$d>>1]|0;lb=b[ob>>1]|0;Re=b[wa>>1]|0;if(ze<<16>>16<lb<<16>>16){xf=lb}else{xf=ze<<16>>16>Re<<16>>16?Re:ze}b[R>>1]=xf;ze=b[ae>>1]|0;Re=b[sc>>1]|0;lb=b[tc>>1]|0;if(ze<<16>>16<Re<<16>>16){yf=Re}else{yf=ze<<16>>16>lb<<16>>16?lb:ze}b[we+30>>1]=yf;c[we+32>>2]=c[R>>2];break}R=rc-Ge|0;Ge=vf-pc|0;c[Md>>2]=Ge;pc=c[126176+((uf&255)<<4)>>2]|0;ze=d[1086680+R|0]|0;lb=R<<ze;c[Ld>>2]=lb;R=Ge<<ze;Ge=ze+wf|0;do{if((Ge|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){zf=R;Af=Ge;break}c[Nd>>2]=ze+2;Re=ze;zf=((de((d[Re]|d[Re+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|R;Af=Ge-16|0}else{zf=R;Af=Ge}}while(0);c[qc>>2]=Af;Ge=((ba(lb-1|0,pc)|0)>>8)+1|0;R=Ge<<16;if(zf>>>0<R>>>0){c[Ld>>2]=Ge;c[Md>>2]=zf;rc=we+28|0;Xe=b[Ud>>1]|0;Re=b[ob>>1]|0;ze=b[wa>>1]|0;if(Xe<<16>>16<Re<<16>>16){Bf=Re}else{Bf=Xe<<16>>16>ze<<16>>16?ze:Xe}b[rc>>1]=Bf;Xe=b[be>>1]|0;ze=b[sc>>1]|0;Re=b[tc>>1]|0;if(Xe<<16>>16<ze<<16>>16){Cf=ze}else{Cf=Xe<<16>>16>Re<<16>>16?Re:Xe}b[we+30>>1]=Cf;c[we+32>>2]=c[rc>>2];break}rc=lb-Ge|0;c[Ld>>2]=rc;Ge=zf-R|0;c[Md>>2]=Ge;R=we+28|0;Xe=(tf&255)>>>0>=(Fe&255)>>>0|0;Re=b[Rd+(Xe<<2)>>1]|0;ze=b[ob>>1]|0;Df=b[wa>>1]|0;if(Re<<16>>16<ze<<16>>16){Ef=ze}else{Ef=Re<<16>>16>Df<<16>>16?Df:Re}Re=R|0;b[Re>>1]=Ef;Df=b[Rd+(Xe<<2)+2>>1]|0;Xe=b[sc>>1]|0;ze=b[tc>>1]|0;if(Df<<16>>16<Xe<<16>>16){Ff=Xe}else{Ff=Df<<16>>16>ze<<16>>16?ze:Df}Df=we+30|0;b[Df>>1]=Ff;ze=(((a[we+(Ba*96|0)+1|0]|0)==7)+((a[we-96+1|0]|0)==7)&255)<<1|(a[we+(Be*96|0)+1|0]|0)==7;a[Yd]=ze;Xe=c[126180+((ze&255)<<4)>>2]|0;ze=d[1086680+rc|0]|0;Gf=rc<<ze;c[Ld>>2]=Gf;rc=Ge<<ze;Ge=ze+Af|0;do{if((Ge|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){Hf=rc;If=Ge;break}c[Nd>>2]=ze+2;Jf=ze;Hf=((de((d[Jf]|d[Jf+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|rc;If=Ge-16|0}else{Hf=rc;If=Ge}}while(0);c[qc>>2]=If;Ge=((ba(Gf-1|0,Xe)|0)>>8)+1|0;rc=Ge<<16;if(Hf>>>0<rc>>>0){c[Ld>>2]=Ge;c[Md>>2]=Hf;Be=B5a(Fd,Wd)|0;b[Df>>1]=(e[Df>>1]|0)+Be;Be=B5a(Fd,ce)|0;b[Re>>1]=(e[Re>>1]|0)+Be;c[we+32>>2]=c[R>>2];break}c[Ld>>2]=Gf-Ge;c[Md>>2]=Hf-rc;a[Ne]=7;rc=d[we-96+3|0]|0;Ge=~e[nc>>1];Be=d[we+(Ge*96|0)+3|0]|0;Ba=c[Ld>>2]|0;Fe=d[1086680+Ba|0]|0;lb=c[qc>>2]|0;pc=c[Md>>2]|0;Jf=Ba<<Fe;c[Ld>>2]=Jf;Ba=pc<<Fe;pc=lb+Fe|0;do{if((pc|0)>-1){Fe=c[Nd>>2]|0;if(!(Fe>>>0<(c[Od>>2]|0)>>>0)){Kf=Ba;Lf=pc;break}c[Nd>>2]=Fe+2;lb=Fe;Kf=((de((d[lb]|d[lb+1|0]<<8)<<16>>16|0)|0)&65535)<<pc|Ba;Lf=pc-16|0}else{Kf=Ba;Lf=pc}}while(0);c[qc>>2]=Lf;pc=((Jf*110|0)-110>>8)+1|0;Ba=pc<<16;do{if(Kf>>>0<Ba>>>0){c[Ld>>2]=pc;c[Md>>2]=Kf;Mf=3}else{Ne=Jf-pc|0;Gf=Kf-Ba|0;c[Md>>2]=Gf;Re=d[1086680+Ne|0]|0;Xe=Ne<<Re;c[Ld>>2]=Xe;Ne=Gf<<Re;Gf=Re+Lf|0;do{if((Gf|0)>-1){Re=c[Nd>>2]|0;if(!(Re>>>0<(c[Od>>2]|0)>>>0)){Nf=Ne;Of=Gf;break}c[Nd>>2]=Re+2;lb=Re;Nf=((de((d[lb]|d[lb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gf|Ne;Of=Gf-16|0}else{Nf=Ne;Of=Gf}}while(0);c[qc>>2]=Of;Gf=((Xe*111|0)-111>>8)+1|0;Ne=Gf<<16;if(Nf>>>0<Ne>>>0){c[Ld>>2]=Gf;c[Md>>2]=Nf;Mf=2;break}va=Xe-Gf|0;Gf=Nf-Ne|0;c[Md>>2]=Gf;Ne=d[1086680+va|0]|0;Ce=va<<Ne;c[Ld>>2]=Ce;va=Gf<<Ne;Gf=Ne+Of|0;do{if((Gf|0)>-1){Ne=c[Nd>>2]|0;if(!(Ne>>>0<(c[Od>>2]|0)>>>0)){Pf=va;Qf=Gf;break}c[Nd>>2]=Ne+2;lb=Ne;Pf=((de((d[lb]|d[lb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gf|va;Qf=Gf-16|0}else{Pf=va;Qf=Gf}}while(0);c[qc>>2]=Qf;Gf=((Ce*150|0)-150>>8)+1|0;va=Gf<<16;Xe=Pf>>>0>=va>>>0;c[Ld>>2]=Xe?Ce-Gf|0:Gf;c[Md>>2]=Pf-(Xe?va:0);Mf=Xe&1}}while(0);Ba=d[126344+Mf|0]|0;a[Se]=Mf;pc=we+28|0;Jf=0;do{Xe=a[126352+(Mf<<4)+Jf|0]|0;va=Xe&255;if((va&3|0)==0){Rf=we-96+32+(d[va+3+(126264+(rc<<4))|0]<<2)|0}else{Rf=we+32+(d[va-1+(126264+(Mf<<4))|0]<<2)|0}Gf=c[Rf>>2]|0;if((Xe&255)>>>0<4>>>0){Sf=we+(Ge*96|0)+32+(d[va+12+(126264+(Be<<4))|0]<<2)|0}else{Sf=we+32+(d[va-4+(126264+(Mf<<4))|0]<<2)|0}va=c[Sf>>2]|0;do{if((Gf|0)==(va|0)){Tf=125072+((4-((Gf|0)!=0)|0)*3|0)|0}else{if((va|0)==0){Tf=125078;break}Tf=125072+(((Gf|0)==0|0)*3|0)|0}}while(0);Ce=d[Tf]|0;Xe=c[Ld>>2]|0;lb=d[1086680+Xe|0]|0;Ne=c[qc>>2]|0;Re=c[Md>>2]|0;Fe=Xe<<lb;c[Ld>>2]=Fe;Xe=Re<<lb;Re=Ne+lb|0;do{if((Re|0)>-1){lb=c[Nd>>2]|0;if(!(lb>>>0<(c[Od>>2]|0)>>>0)){Uf=Xe;Vf=Re;break}c[Nd>>2]=lb+2;Ne=lb;Uf=((de((d[Ne]|d[Ne+1|0]<<8)<<16>>16|0)|0)&65535)<<Re|Xe;Vf=Re-16|0}else{Uf=Xe;Vf=Re}}while(0);c[qc>>2]=Vf;Re=((ba(Fe-1|0,Ce)|0)>>8)+1|0;Xe=Re<<16;do{if(Uf>>>0<Xe>>>0){c[Ld>>2]=Re;c[Md>>2]=Uf;c[we+32+(Jf<<2)>>2]=Gf}else{Ne=Fe-Re|0;c[Ld>>2]=Ne;lb=Uf-Xe|0;c[Md>>2]=lb;ze=d[Tf+1|0]|0;Wf=d[1086680+Ne|0]|0;Xf=Ne<<Wf;c[Ld>>2]=Xf;Ne=lb<<Wf;lb=Wf+Vf|0;do{if((lb|0)>-1){Wf=c[Nd>>2]|0;if(!(Wf>>>0<(c[Od>>2]|0)>>>0)){Yf=Ne;Zf=lb;break}c[Nd>>2]=Wf+2;_f=Wf;Yf=((de((d[_f]|d[_f+1|0]<<8)<<16>>16|0)|0)&65535)<<lb|Ne;Zf=lb-16|0}else{Yf=Ne;Zf=lb}}while(0);c[qc>>2]=Zf;lb=((ba(Xf-1|0,ze)|0)>>8)+1|0;Ne=lb<<16;if(Yf>>>0<Ne>>>0){c[Ld>>2]=lb;c[Md>>2]=Yf;c[we+32+(Jf<<2)>>2]=va;break}Te=Xf-lb|0;c[Ld>>2]=Te;lb=Yf-Ne|0;c[Md>>2]=lb;Ne=d[Tf+2|0]|0;Ue=d[1086680+Te|0]|0;_f=Te<<Ue;c[Ld>>2]=_f;Te=lb<<Ue;lb=Ue+Zf|0;do{if((lb|0)>-1){Ue=c[Nd>>2]|0;if(!(Ue>>>0<(c[Od>>2]|0)>>>0)){$f=Te;ag=lb;break}c[Nd>>2]=Ue+2;Wf=Ue;$f=((de((d[Wf]|d[Wf+1|0]<<8)<<16>>16|0)|0)&65535)<<lb|Te;ag=lb-16|0}else{$f=Te;ag=lb}}while(0);c[qc>>2]=ag;lb=((ba(_f-1|0,Ne)|0)>>8)+1|0;Te=lb<<16;if($f>>>0<Te>>>0){c[Ld>>2]=lb;c[Md>>2]=$f;c[we+32+(Jf<<2)>>2]=0;break}else{c[Ld>>2]=_f-lb;c[Md>>2]=$f-Te;Te=e[Df>>1]|0;b[we+32+(Jf<<2)+2>>1]=Te+(B5a(Fd,Wd)|0);Te=e[pc>>1]|0;b[we+32+(Jf<<2)>>1]=Te+(B5a(Fd,ce)|0);break}}}while(0);Jf=Jf+1|0;}while((Jf|0)<(Ba|0));c[R>>2]=c[we+32+(Ba-1<<2)>>2]}else{Jf=0;pc=c[Ld>>2]|0;Df=c[qc>>2]|0;Be=c[Md>>2]|0;while(1){Ge=a[126080+Jf|0]|0;rc=d[1086680+pc|0]|0;Se=pc<<rc;c[Ld>>2]=Se;va=Be<<rc;Xe=rc+Df|0;do{if((Xe|0)>-1){rc=c[Nd>>2]|0;if(!(rc>>>0<(c[Od>>2]|0)>>>0)){bg=va;cg=Xe;break}c[Nd>>2]=rc+2;Re=rc;bg=((de((d[Re]|d[Re+1|0]<<8)<<16>>16|0)|0)&65535)<<Xe|va;cg=Xe-16|0}else{bg=va;cg=Xe}}while(0);c[qc>>2]=cg;Xe=((ba(Se-1|0,Ge&255)|0)>>8)+1|0;va=Xe<<16;Re=bg>>>0>=va>>>0;rc=Re?Se-Xe|0:Xe;c[Ld>>2]=rc;Xe=bg-(Re?va:0)|0;c[Md>>2]=Xe;va=a[(Re&1)+(126064+(Jf<<1))|0]|0;dg=va<<24>>24;if(va<<24>>24>0){Jf=dg;pc=rc;Df=cg;Be=Xe}else{break}}Be=-dg|0;a[we+1|0]=Be;Df=Be&255;if((Df|0)==4){Be=we+(~e[nc>>1]*96|0)+22|0;pc=we+22|0;x=d[Be]|d[Be+1|0]<<8|d[Be+2|0]<<16|d[Be+3|0]<<24|0;a[pc]=x;x=x>>8;a[pc+1|0]=x;x=x>>8;a[pc+2|0]=x;x=x>>8;a[pc+3|0]=x;pc=0;Be=we+6|0;while(1){Jf=Ia+112+pc|0;Ba=0;R=Be;Xe=a[Jf]|0;while(1){rc=Xe&255;va=we+22+Ba|0;Re=d[va]|0;Fe=0;Gf=c[Ld>>2]|0;Ce=c[qc>>2]|0;Te=c[Md>>2]|0;while(1){lb=a[125136+(Re*90|0)+(rc*9|0)+Fe|0]|0;Xf=d[1086680+Gf|0]|0;ze=Gf<<Xf;c[Ld>>2]=ze;Wf=Te<<Xf;Ue=Xf+Ce|0;do{if((Ue|0)>-1){Xf=c[Nd>>2]|0;if(!(Xf>>>0<(c[Od>>2]|0)>>>0)){eg=Wf;fg=Ue;break}c[Nd>>2]=Xf+2;gg=Xf;eg=((de((d[gg]|d[gg+1|0]<<8)<<16>>16|0)|0)&65535)<<Ue|Wf;fg=Ue-16|0}else{eg=Wf;fg=Ue}}while(0);c[qc>>2]=fg;Ue=((ba(ze-1|0,lb&255)|0)>>8)+1|0;Wf=Ue<<16;gg=eg>>>0>=Wf>>>0;Xf=gg?ze-Ue|0:Ue;c[Ld>>2]=Xf;Ue=eg-(gg?Wf:0)|0;c[Md>>2]=Ue;hg=a[(gg&1)+(125112+(Fe<<1))|0]|0;if(hg<<24>>24>0){Fe=hg<<24>>24;Gf=Xf;Ce=fg;Te=Ue}else{break}}Te=-hg&255;a[R]=Te;a[va]=Te;a[Jf]=Te;Ce=Ba+1|0;if((Ce|0)>=4){break}Ba=Ce;R=R+1|0;Xe=Te}Xe=pc+1|0;if((Xe|0)<4){pc=Xe;Be=Be+4|0}else{break}}}else{Be=ba(d[126056+Df|0]|0,16843009)|0;if((c[ge>>2]|0)==0){c[(c[he>>2]|0)+(ve<<2)>>2]=Be}else{c[we+22>>2]=Be}c[Aa>>2]=Be}Be=0;pc=c[Ld>>2]|0;Xe=c[qc>>2]|0;R=c[Md>>2]|0;while(1){Ba=a[125096+Be|0]|0;Jf=d[1086680+pc|0]|0;Se=pc<<Jf;c[Ld>>2]=Se;Ge=R<<Jf;Te=Jf+Xe|0;do{if((Te|0)>-1){Jf=c[Nd>>2]|0;if(!(Jf>>>0<(c[Od>>2]|0)>>>0)){ig=Ge;jg=Te;break}c[Nd>>2]=Jf+2;Ce=Jf;ig=((de((d[Ce]|d[Ce+1|0]<<8)<<16>>16|0)|0)&65535)<<Te|Ge;jg=Te-16|0}else{ig=Ge;jg=Te}}while(0);c[qc>>2]=jg;Te=((ba(Se-1|0,Ba&255)|0)>>8)+1|0;Ge=Te<<16;Ce=ig>>>0>=Ge>>>0;Jf=Ce?Se-Te|0:Te;c[Ld>>2]=Jf;Te=ig-(Ce?Ge:0)|0;c[Md>>2]=Te;kg=a[(Ce&1)+(125088+(Be<<1))|0]|0;if(kg<<24>>24>0){Be=kg<<24>>24;pc=Jf;Xe=jg;R=Te}else{break}}a[we+4|0]=-kg;a[we+2|0]=0}}while(0);b[ob>>1]=(b[ob>>1]|0)-64;b[wa>>1]=(b[wa>>1]|0)-64;Je=ve+1|0;lg=b[nc>>1]|0;oe=lg&65535;if((Je|0)<(oe|0)){ve=Je;we=we+96|0;za=za+1|0;xe=oe}else{break}}qe=lg;re=b[sc>>1]|0;se=b[tc>>1]|0;te=b[Ea>>1]|0}xe=re-64&65535;b[sc>>1]=xe;za=se-64&65535;b[tc>>1]=za;if((pe|0)<(te&65535|0)){ke=pe;le=qe;me=xe;ne=za;ua=te}else{break}}}}while(0);if((c[f+816>>2]|0)==1){mg=1}else{Ca=c[oa>>2]|0;ua=c[f+808>>2]|0;mg=(Ca|0)>(ua|0)?ua:Ca}c[o+5428>>2]=mg;c[o+40>>2]=Bd;c[o+44>>2]=ja;b[o+66>>1]=-64;b[o+70>>1]=b[wc>>1]<<6;Ca=c[o>>2]|0;c[Ca+840>>2]=0;c[Ca+844>>2]=2147483647;c[Ca+2376>>2]=0;c[Ca+2380>>2]=2147483647;c[Ca+3912>>2]=0;c[Ca+3916>>2]=2147483647;c[Ca+5448>>2]=0;c[Ca+5452>>2]=2147483647;c[Ca+6984>>2]=0;c[Ca+6988>>2]=2147483647;c[Ca+8520>>2]=0;c[Ca+8524>>2]=2147483647;c[Ca+10056>>2]=0;c[Ca+10060>>2]=2147483647;c[Ca+11592>>2]=0;c[Ca+11596>>2]=2147483647;Pe[c[f+828>>2]&255](f,30,Ca,0,mg)|0;Y0a(xb,2147483647,0);c[oc>>2]=c[W>>2];c[oc+4>>2]=c[W+4>>2];c[oc+8>>2]=c[W+8>>2];c[oc+12>>2]=c[W+12>>2];ng=Bd}else{c[C>>2]=1;Ca=o+24|0;c[Ca>>2]=c[oc>>2];c[Ca+4>>2]=c[oc+4>>2];c[Ca+8>>2]=c[oc+8>>2];c[Ca+12>>2]=c[oc+12>>2];ng=0}if((c[kb>>2]|0)==0){UGb(o+208|0,o+2372|0,2164)|0}do{if((c[C>>2]|0)==0){Ca=MCb(g,c[ng>>2]|0)|0;if((Ca|0)<0){og=Ca;i=k;return og|0}else{c[h>>2]=1;break}}}while(0);og=c[r>>2]|0;i=k;return og|0}}while(0);yDb(c[u>>2]|0,16,1891656,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;I=-1094995529}}while(0);G=o+24|0;u=o+8|0;c[G>>2]=c[u>>2];c[G+4>>2]=c[u+4>>2];c[G+8>>2]=c[u+8>>2];c[G+12>>2]=c[u+12>>2];og=I;i=k;return og|0}function v5a(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;g=f+60|0;j=c[g>>2]|0;k=c[j>>2]|0;l=c[j+40>>2]|0;m=c[j+5428>>2]|0;c[k+(h*1536|0)+836>>2]=i;n=j+50|0;if((e[n>>1]|0)<=(h|0)){return 0}o=k+(h*1536|0)+840|0;k=j+61|0;p=j+66|0;q=j+70|0;r=f+816|0;f=l|0;l=h;s=j;while(1){c[o>>2]=l<<16;A5a(s,h,i);a:do{if((a[k]|0)!=0){j=c[g>>2]|0;t=c[j>>2]|0;u=c[t+(i*1536|0)+840>>2]>>16;v=c[c[j+40>>2]>>2]|0;w=j+52|0;x=j+56|0;y=ba(c[x>>2]|0,u<<3)|0;z=j+48|0;if((b[z>>1]|0)==0){break}A=ba(u<<4,c[w>>2]|0)|0;B=t+(i*1536|0)+1520|0;t=(c[j+5428>>2]|0)==1;C=j+99|0;D=j+180|0;E=j+60|0;F=j+4776|0;G=j+4784|0;H=(u|0)==0;u=j+4772|0;I=j+4780|0;J=j+4756|0;K=j+4764|0;L=j+4760|0;M=j+4768|0;N=j+4792|0;O=j+4788|0;j=(c[v+8>>2]|0)+y|0;P=(c[v+4>>2]|0)+y|0;y=(c[v>>2]|0)+A|0;A=0;while(1){v=c[B>>2]|0;do{if(t){Q=A+1|0;R=c[D>>2]|0;S=R+(Q<<5)|0;T=c[w>>2]|0;if((a[C]|0)==0){U=c[x>>2]|0;V=T*15|0;W=y+V|0;X=c[W+4>>2]|0;Y=S;c[Y>>2]=c[W>>2];c[Y+4>>2]=X;X=y+(V+8)|0;V=c[X+4>>2]|0;Y=R+(Q<<5)+8|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=V;V=U*7|0;U=P+V|0;Y=c[U+4>>2]|0;X=R+(Q<<5)+16|0;c[X>>2]=c[U>>2];c[X+4>>2]=Y;Y=j+V|0;V=c[Y+4>>2]|0;X=R+(Q<<5)+24|0;c[X>>2]=c[Y>>2];c[X+4>>2]=V;break}else{V=T*15|0;T=y+V|0;X=c[T+4>>2]|0;Y=S;c[Y>>2]=c[T>>2];c[Y+4>>2]=X;X=y+(V+8)|0;V=c[X+4>>2]|0;Y=R+(Q<<5)+8|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=V;break}}}while(0);V=a[v+(A*3|0)|0]|0;do{if((a[C]|0)==0){Y=a[v+(A*3|0)+2|0]|0;X=V&255;Q=d[v+(A*3|0)+1|0]|0;R=c[w>>2]|0;T=c[x>>2]|0;if(V<<24>>24==0){break}S=Q+(X<<1)|0;U=S+4|0;W=d[1060096+(d[E]<<6)+X|0]|0;if((A|0)!=0){le[c[L>>2]&1023](y,R,U,Q,W);Se[c[M>>2]&511](P,j,T,U,Q,W)}X=Y<<24>>24!=0;if(X){le[c[F>>2]&1023](y+4|0,R,S,Q,W);le[c[F>>2]&1023](y+8|0,R,S,Q,W);le[c[F>>2]&1023](y+12|0,R,S,Q,W);Se[c[G>>2]&511](P+4|0,j+4|0,T,S,Q,W)}if(!H){le[c[J>>2]&1023](y,R,U,Q,W);Se[c[K>>2]&511](P,j,T,U,Q,W)}if(!X){break}le[c[u>>2]&1023](y+(R<<2)|0,R,S,Q,W);le[c[u>>2]&1023](y+(R<<3)|0,R,S,Q,W);le[c[u>>2]&1023](y+(R*12|0)|0,R,S,Q,W);R=T<<2;Se[c[I>>2]&511](P+R|0,j+R|0,T,S,Q,W)}else{W=a[v+(A*3|0)+2|0]|0;Q=c[w>>2]|0;if(V<<24>>24==0){break}S=(d[v+(A*3|0)+1|0]|0)+((V&255)<<1)|0;T=S+4|0;if((A|0)!=0){Xe[c[N>>2]&4095](y,Q,T)}R=W<<24>>24!=0;if(R){Xe[c[N>>2]&4095](y+4|0,Q,S);Xe[c[N>>2]&4095](y+8|0,Q,S);Xe[c[N>>2]&4095](y+12|0,Q,S)}if(!H){Xe[c[O>>2]&4095](y,Q,T)}if(!R){break}Xe[c[O>>2]&4095](y+(Q<<2)|0,Q,S);Xe[c[O>>2]&4095](y+(Q<<3)|0,Q,S);Xe[c[O>>2]&4095](y+(Q*12|0)|0,Q,S)}}while(0);V=A+1|0;if((V|0)>=(e[z>>1]|0)){break a}j=j+8|0;P=P+8|0;y=y+16|0;A=V}}}while(0);b[p>>1]=(b[p>>1]|0)-64;b[q>>1]=(b[q>>1]|0)-64;if((c[r>>2]|0)==1){Y0a(f,l,0)}A=l+m|0;if((A|0)>=(e[n>>1]|0)){break}l=A;s=c[g>>2]|0}return 0}function w5a(a){a=a|0;var b=0;b=c[a+60>>2]|0;x5a(b,1);JCb(b+5348|0);JCb(b+5364|0);JCb(b+5380|0);JCb(b+5396|0);JCb(b+5412|0);return 0}function x5a(a,b){a=a|0;b=b|0;var d=0;d=a+4|0;XAb(a+5360|0);U0a(c[d>>2]|0,a+5348|0);XAb(a+5376|0);U0a(c[d>>2]|0,a+5364|0);XAb(a+5392|0);U0a(c[d>>2]|0,a+5380|0);XAb(a+5408|0);U0a(c[d>>2]|0,a+5396|0);XAb(a+5424|0);U0a(c[d>>2]|0,a+5412|0);TGb(a+8|0,0,16)|0;if((b|0)==0){return}b=a;d=c[b>>2]|0;if((d|0)!=0){$Db(d+1520|0);$Db((c[b>>2]|0)+3056|0);$Db((c[b>>2]|0)+4592|0);$Db((c[b>>2]|0)+6128|0);$Db((c[b>>2]|0)+7664|0);$Db((c[b>>2]|0)+9200|0);$Db((c[b>>2]|0)+10736|0);$Db((c[b>>2]|0)+12272|0)}$Db(a);$Db(a+4536|0);$Db(a+108|0);$Db(a+184|0);$Db(a+180|0);c[a+104>>2]=0;return}function y5a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+60|0;d=c[b>>2]|0;e=d;c[d+4>>2]=a;c[a+140>>2]=0;c[(c[a+64>>2]|0)+4>>2]=1;T3a(d+4724|0,8);cia(d+5012|0,141,8,1);E5a(d+4732|0,0);d=0;while(1){if(!(d>>>0<5>>>0)){f=0;g=5;break}a=ICb()|0;c[e+5348+(d<<4)>>2]=a;if((a|0)==0){break}else{d=d+1|0}}if((g|0)==5){return f|0}g=c[b>>2]|0;x5a(g,1);JCb(g+5348|0);JCb(g+5364|0);JCb(g+5380|0);JCb(g+5396|0);JCb(g+5412|0);f=-12;return f|0}function z5a(a){a=a|0;var b=0;b=c[a+60>>2]|0;a=b+4|0;XAb(b+5360|0);U0a(c[a>>2]|0,b+5348|0);XAb(b+5376|0);U0a(c[a>>2]|0,b+5364|0);XAb(b+5392|0);U0a(c[a>>2]|0,b+5380|0);XAb(b+5408|0);U0a(c[a>>2]|0,b+5396|0);XAb(b+5424|0);U0a(c[a>>2]|0,b+5412|0);TGb(b+8|0,0,16)|0;return}



function QKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,j=0,k=0.0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0.0,y=0,z=0,A=0.0,B=0;d=i;i=i+176|0;e=d|0;f=d+88|0;j=c<<1;h[e>>3]=1.0;k=+h[a>>3]*-2.0;l=e+8|0;h[l>>3]=k;m=(c|0)<2;a:do{if(!m){n=2;o=k;p=1.0;while(1){q=+h[a+((n<<1)-2<<3)>>3]*-2.0;r=n-1|0;s=e+(r<<3)|0;t=e+(n<<3)|0;h[t>>3]=p*2.0+o*q;do{if((r|0)>1){u=n-2|0;v=+h[e+(n-3<<3)>>3];h[s>>3]=o+(q*p+v);if((u|0)>1){w=u;x=v}else{break}while(1){u=e+(w<<3)|0;y=w-1|0;v=+h[e+(w-2<<3)>>3];h[u>>3]=+h[u>>3]+(q*x+v);if((y|0)>1){w=y;x=v}else{break}}}}while(0);h[l>>3]=q+ +h[l>>3];r=n+1|0;if((r|0)>(c|0)){break a}n=r;o=+h[t>>3];p=+h[s>>3]}}}while(0);h[f>>3]=1.0;x=+h[a+8>>3]*-2.0;l=f+8|0;h[l>>3]=x;b:do{if(!m){w=2;k=x;p=1.0;while(1){o=+h[a+((w<<1)-1<<3)>>3]*-2.0;n=w-1|0;r=f+(n<<3)|0;y=f+(w<<3)|0;h[y>>3]=p*2.0+k*o;do{if((n|0)>1){u=w-2|0;v=+h[f+(w-3<<3)>>3];h[r>>3]=k+(o*p+v);if((u|0)>1){z=u;A=v}else{break}while(1){u=f+(z<<3)|0;B=z-1|0;v=+h[f+(z-2<<3)>>3];h[u>>3]=+h[u>>3]+(o*A+v);if((B|0)>1){z=B;A=v}else{break}}}}while(0);h[l>>3]=o+ +h[l>>3];n=w+1|0;if((n|0)>(c|0)){break b}w=n;k=+h[y>>3];p=+h[r>>3]}}}while(0);if((c|0)==0){i=d;return}l=c;A=+h[e+(c<<3)>>3];x=+h[f+(c<<3)>>3];while(1){c=l-1|0;p=+h[e+(c<<3)>>3];k=A+p;q=+h[f+(c<<3)>>3];v=x-q;g[b+(c<<2)>>2]=(k+v)*.5;g[b+(j-l<<2)>>2]=(k-v)*.5;if((c|0)==0){break}else{l=c;A=p;x=q}}i=d;return}function RKa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0.0,h=0,i=0.0;c=b-1|0;if((c|0)>0){d=0}else{return}do{b=d;while(1){e=a+(b<<2)|0;f=+g[e>>2];h=a+(b+1<<2)|0;i=+g[h>>2];if(!(f>i)){break}g[h>>2]=f;g[e>>2]=i;if((b|0)>0){b=b-1|0}else{break}}d=d+1|0;}while((d|0)<(c|0));return}function SKa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b;if((c[b+20>>2]|0)!=0){e=c[d>>2]|0;c[d>>2]=e+((c[b+4>>2]|0)-e);return}e=b+16456|0;f=c[e>>2]|0;if((f|0)<=0){return}g=c[b+4>>2]|0;b=f;f=c[d>>2]|0;while(1){if((g|0)==(f|0)){h=9;break}i=g;j=i-f|0;k=j>>>0>b>>>0?b:j;j=f+k|0;c[d>>2]=j;if((i-j|0)<1){h=6;break}i=f+(k+1)|0;c[d>>2]=i;k=a[j]|0;j=k&255;c[e>>2]=j;if(k<<24>>24==0){h=9;break}else{b=j;f=i}}if((h|0)==6){c[e>>2]=0;return}else if((h|0)==9){return}}function TKa(a){a=a|0;c[a>>2]=cEb(16460)|0;return}function UKa(a){a=a|0;$Db(a);return}function VKa(a,b,d,f,g){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;if((b-1|0)>>>0>10>>>0){j=-1;i=h;return j|0}if(!((f|0)>-1)){yDb(0,0,2264536,(k=i,i=i+24|0,c[k>>2]=2321928,c[k+8>>2]=2186016,c[k+16>>2]=135,k)|0);i=k;Cd();return 0}c[a>>2]=d;c[a+8>>2]=d;c[a+4>>2]=d+f;c[a+16>>2]=0;c[a+12>>2]=0;c[a+16456>>2]=0;c[a+32>>2]=b;f=b+1|0;c[a+24>>2]=f;c[a+28>>2]=e[684760+(f<<1)>>1]|0;c[a+48>>2]=1<<f;f=1<<b;c[a+36>>2]=f;c[a+40>>2]=f+1;b=f+2|0;c[a+44>>2]=b;c[a+56>>2]=b;c[a+60>>2]=-1;c[a+64>>2]=-1;c[a+68>>2]=a+72;c[a+20>>2]=g;c[a+52>>2]=(g|0)==1;j=0;i=h;return j|0}function WKa(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;i=f+40|0;if((c[i>>2]|0)<0){j=0;return j|0}k=f+68|0;l=f+64|0;m=f+60|0;n=f+72|0;o=f+20|0;p=f+12|0;q=f+24|0;r=f+16456|0;s=f+4|0;t=f;u=f+16|0;v=f+28|0;w=f+36|0;x=f+32|0;y=f+44|0;z=f+56|0;A=f+48|0;B=f+8264|0;C=f+52|0;D=c[k>>2]|0;E=c[m>>2]|0;F=c[l>>2]|0;G=g;g=h;a:while(1){if(D>>>0>n>>>0){H=F;I=E;J=D}else{K=F;L=E;M=D;while(1){N=c[o>>2]|0;O=K;P=L;Q=c[p>>2]|0;R=c[q>>2]|0;while(1){S=(Q|0)<(R|0);if((N|0)==0){if(S){T=c[s>>2]|0;U=c[r>>2]|0;V=Q;W=c[t>>2]|0;while(1){X=T;if((U|0)==0){if((X-W|0)<1){Y=0;Z=W}else{_=W+1|0;c[t>>2]=_;Y=d[W]|0;Z=_}c[r>>2]=Y;$=Y;aa=Z}else{$=U;aa=W}if((X-aa|0)<1){ba=0;ca=aa}else{X=aa+1|0;c[t>>2]=X;ba=d[aa]|0;ca=X}X=c[u>>2]|ba<<V;c[u>>2]=X;_=V+8|0;c[p>>2]=_;da=$-1|0;c[r>>2]=da;if((_|0)<(R|0)){U=da;V=_;W=ca}else{ea=_;fa=X;break}}}else{ea=Q;fa=c[u>>2]|0}c[u>>2]=fa>>>(R>>>0);ga=fa;ha=ea}else{W=c[u>>2]|0;if(S){V=c[s>>2]|0;U=W;T=c[t>>2]|0;X=Q;while(1){if((V-T|0)<1){ia=0;ja=T}else{_=T+1|0;c[t>>2]=_;ia=d[T]|0;ja=_}_=ia|U<<8;c[u>>2]=_;da=X+8|0;c[p>>2]=da;if((da|0)<(R|0)){U=_;T=ja;X=da}else{ka=_;la=da;break}}}else{ka=W;la=Q}ga=ka>>>((la-R|0)>>>0);ha=la}X=ha-R|0;c[p>>2]=X;ma=c[v>>2]&ga;if((ma|0)==(c[i>>2]|0)){na=38;break a}if((ma|0)!=(c[w>>2]|0)){break}T=(c[x>>2]|0)+1|0;c[q>>2]=T;c[v>>2]=e[684760+(T<<1)>>1]|0;c[z>>2]=c[y>>2];c[A>>2]=1<<T;O=-1;P=-1;Q=X;R=T}R=c[z>>2]|0;if((ma|0)==(R|0)&(P|0)>-1){a[M]=P;oa=M+1|0;pa=O}else{if((ma|0)<(R|0)){oa=M;pa=ma}else{na=38;break a}}if((pa|0)<(c[y>>2]|0)){qa=pa;ra=oa}else{R=pa;Q=oa;while(1){N=Q+1|0;a[Q]=a[f+(R+4168)|0]|0;T=e[B+(R<<1)>>1]|0;if((T|0)<(c[y>>2]|0)){qa=T;ra=N;break}else{R=T;Q=N}}}Q=qa&255;R=ra+1|0;a[ra]=Q;N=c[z>>2]|0;T=c[A>>2]|0;if((N|0)<(T|0)&(O|0)>-1){a[f+(N+4168)|0]=Q;Q=c[z>>2]|0;c[z>>2]=Q+1;b[B+(Q<<1)>>1]=O;sa=c[z>>2]|0;ta=c[A>>2]|0}else{sa=N;ta=T}do{if((sa|0)>=(ta-(c[C>>2]|0)|0)){T=c[q>>2]|0;if((T|0)>=12){break}c[A>>2]=ta<<1;N=T+1|0;c[q>>2]=N;c[v>>2]=e[684760+(N<<1)>>1]|0}}while(0);if(R>>>0>n>>>0){H=ma;I=qa;J=R;break}else{K=ma;L=qa;M=R}}}L=J-1|0;a[G]=a[L]|0;K=g-1|0;if((K|0)==0){ua=L;va=0;wa=H;xa=I;break}else{D=L;E=I;F=H;G=G+1|0;g=K}}if((na|0)==38){c[i>>2]=-1;ua=M;va=g;wa=O;xa=P}c[k>>2]=ua;c[l>>2]=wa;c[m>>2]=xa;j=h-va|0;return j|0}function XKa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;c[a>>2]=256;c[a+4>>2]=257;c[a+196976>>2]=e;h=(d|0)<0;j=h?0:b;b=h?0:d;c[a+196972>>2]=b<<3;c[a+196960>>2]=j;c[a+196968>>2]=j+b;c[a+196964>>2]=j;c[a+196956>>2]=32;c[a+196952>>2]=0;c[a+196948>>2]=d;if((e-9|0)>>>0<4>>>0){c[a+196980>>2]=1<<e;c[a+196984>>2]=0;c[a+196988>>2]=-1;c[a+196944>>2]=9;c[a+196992>>2]=f;c[a+196996>>2]=g;i=i;return}else{yDb(0,0,2264360,(g=i,i=i+24|0,c[g>>2]=2321824,c[g+8>>2]=2185992,c[g+16>>2]=210,g)|0);i=g;Cd()}}function YKa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=b+196984|0;if((e*3|0|0)>((c[b+196948>>2]|0)-(c[f>>2]|0)<<1|0)){g=-1;return g|0}h=b+196988|0;if((c[h>>2]|0)==-1){i=b+196944|0;Xe[c[b+196996>>2]&4095](b+196952|0,c[i>>2]|0,c[b>>2]|0);c[i>>2]=9;i=0;while(1){c[b+8+(i*12|0)>>2]=-2;j=i+1|0;if((j|0)<16411){i=j}else{k=0;break}}do{i=k<<6;c[b+8+(i*12|0)+4>>2]=k;a[b+8+(i*12|0)+8|0]=k;c[b+8+(i*12|0)>>2]=-1;k=k+1|0;}while((k|0)<256);c[b+196940>>2]=258}a:do{if((e|0)>0){k=b+196996|0;i=b+196952|0;j=b+196944|0;l=b+196940|0;m=b+196992|0;n=b+196980|0;o=b|0;p=d;q=1;while(1){r=p+1|0;s=a[p]|0;t=c[h>>2]|0;u=(s&255)<<6;v=((t|0)>0?t:0)^u;w=(v|0)>16410?v-16411|0:v;v=(w|0)==0?1:16411-w|0;x=c[b+8+(w*12|0)>>2]|0;b:do{if((x|0)==-2){y=w;z=14}else{A=w;B=x;while(1){if((a[b+8+(A*12|0)+8|0]|0)==s<<24>>24&(B|0)==(t|0)){break}C=A-v|0;D=(C|0)<0?C+16411|0:C;C=c[b+8+(D*12|0)>>2]|0;if((C|0)==-2){y=D;z=14;break b}else{A=D;B=C}}if((t|0)==-2){y=A;z=14;break}E=A;F=c[l>>2]|0}}while(0);do{if((z|0)==14){z=0;Xe[c[k>>2]&4095](i,c[j>>2]|0,t);v=c[h>>2]|0;c[b+8+(y*12|0)+4>>2]=c[l>>2];a[b+8+(y*12|0)+8|0]=s;c[b+8+(y*12|0)>>2]=v;v=(c[l>>2]|0)+1|0;c[l>>2]=v;x=c[j>>2]|0;if((v|0)<(((c[m>>2]|0)==0)+(1<<x)|0)){E=u;F=v;break}c[j>>2]=x+1;E=u;F=v}}while(0);c[h>>2]=c[b+8+(E*12|0)+4>>2];if((F|0)>=((c[n>>2]|0)-1|0)){Xe[c[k>>2]&4095](i,c[j>>2]|0,c[o>>2]|0);c[j>>2]=9;u=0;while(1){c[b+8+(u*12|0)>>2]=-2;s=u+1|0;if((s|0)<16411){u=s}else{G=0;break}}do{u=G<<6;c[b+8+(u*12|0)+4>>2]=G;a[b+8+(u*12|0)+8|0]=G;c[b+8+(u*12|0)>>2]=-1;G=G+1|0;}while((G|0)<256);c[l>>2]=258}if((q|0)>=(e|0)){break a}p=r;q=q+1|0}}}while(0);e=32-(c[b+196956>>2]|0)+((c[b+196964>>2]|0)-(c[b+196960>>2]|0)<<3)>>3;b=e-(c[f>>2]|0)|0;c[f>>2]=e;g=b;return g|0}function ZKa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a+196988|0;e=c[d>>2]|0;f=a+196996|0;if((e|0)==-1){g=a+196952|0;h=a+196944|0}else{i=a+196952|0;j=a+196944|0;Xe[c[f>>2]&4095](i,c[j>>2]|0,e);g=i;h=j}Xe[c[f>>2]&4095](g,c[h>>2]|0,c[a+4>>2]|0);if((c[a+196992>>2]|0)==0){Xe[c[f>>2]&4095](g,1,0)}me[b&511](g);c[d>>2]=-1;d=32-(c[a+196956>>2]|0)+((c[a+196964>>2]|0)-(c[a+196960>>2]|0)<<3)>>3;g=a+196984|0;a=d-(c[g>>2]|0)|0;c[g>>2]=d;return a|0}function _Ka(a){a=a|0;var b=0;if(((c[a+416>>2]|0)-1|0)>>>0>1>>>0){b=-22;return b|0}c[a+420>>2]=6;b=0;return b|0}function $Ka(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;k=i;i=i+8|0;l=k|0;m=g;n=c[j+24>>2]|0;o=c[j+28>>2]|0;j=c[f+60>>2]|0;p=(c[f+48>>2]|0)==86025;q=p&1;r=f+416|0;s=c[r>>2]|0;do{if(((o|0)%(s<<q|0)|0|0)==0){t=o;u=s}else{yDb(f,16,2005552,(v=i,i=i+8|0,c[v>>2]=o,v)|0);i=v;v=c[r>>2]|0;w=(o|0)%(v<<q|0)|0;if((o|0)==(w|0)){x=-1094995529}else{t=o-w|0;u=v;break}i=k;return x|0}}while(0);o=q^1;c[g+76>>2]=((t<<o)*3|0|0)/(u|0)|0;u=_$a(f,m,0)|0;if((u|0)<0){x=u;i=k;return x|0}u=c[g+64>>2]|0;g=c[r>>2]|0;if((g|0)>0){m=1<<q;f=(m|0)>0;s=l|0;v=l+1|0;w=l+2|0;y=l+3|0;z=l+4|0;A=l+5|0;B=j;j=1<<o;C=3<<o;o=0;D=g;while(1){if(((t|0)/(D<<q|0)|0|0)>0){g=o<<q;E=B+(o*10|0)|0;F=B+(o*10|0)+8|0;G=B+(o*10|0)+6|0;H=B+(o*10|0)+2|0;I=B+(o*10|0)+4|0;J=0;K=c[u+(o<<2)>>2]|0;L=D;while(1){if(f){M=0;N=K;O=L;while(1){P=a[n+(M+g+((ba(O,J)|0)<<q))|0]|0;Q=(P&255)>>>5;a[s]=Q;R=(P&255)>>>3&3;a[v]=R;S=P&7;a[w]=S;a[y]=S;a[z]=R;a[A]=Q;if(p){Q=0;R=N;while(1){S=d[l+3+Q|0]|0;P=c[194184+(Q*12|0)>>2]|0;T=b[E>>1]|0;U=ba((T&65535)>>>4&127,P)|0;if((S|0)<(P|0)){V=b[(c[194180+(Q*12|0)>>2]|0)+(U+S<<1)>>1]|0}else{V=~b[(c[194180+(Q*12|0)>>2]|0)+((P<<1)+~S+U<<1)>>1]}U=T<<16>>16;T=U-(U>>>5)+(e[(c[194176+(Q*12|0)>>2]|0)+(S<<1)>>1]|0)&65535;b[E>>1]=T<<16>>16<0?0:T;T=(b[F>>1]|0)+(V<<16>>16)|0;if((T|0)>32767){W=32767}else{W=(T|0)<-32768?-32767:T<<16>>16}b[F>>1]=W-(W>>>3);b[R>>1]=W>>>8&255|W&65280;T=Q+1|0;if((T|0)<3){Q=T;R=R+(j<<1)|0}else{break}}}else{R=0;Q=N;while(1){T=d[l+R|0]|0;S=c[194184+(R*12|0)>>2]|0;U=b[E>>1]|0;P=ba((U&65535)>>>4&127,S)|0;if((T|0)<(S|0)){X=b[(c[194180+(R*12|0)>>2]|0)+(P+T<<1)>>1]|0}else{X=~b[(c[194180+(R*12|0)>>2]|0)+((S<<1)+~T+P<<1)>>1]}P=U<<16>>16;U=P-(P>>>5)+(e[(c[194176+(R*12|0)>>2]|0)+(T<<1)>>1]|0)&65535;b[E>>1]=U<<16>>16<0?0:U;U=b[G>>1]|0;T=X<<16>>16;P=b[H>>1]|0;do{if((U^X)<<16>>16>-1){S=P+506|0;Y=(S|0)>32767?32767:S&65535;b[H>>1]=Y;Z=Y}else{Y=P-314|0;if((Y|0)<-32768){b[H>>1]=-32767;Z=-32767;break}else{S=Y&65535;b[H>>1]=S;Z=S;break}}}while(0);P=(b[F>>1]|0)+T|0;if((P|0)>32767){_=32767}else{_=(P|0)<-32768?-32767:P<<16>>16}b[F>>1]=(ba(_,Z<<16>>16)|0)>>>15;P=_>>>1&65535;S=b[I>>1]|0;Y=P<<16>>16;$=S+(U<<16>>16)-(S-Y>>2)|0;b[Q>>1]=$>>>8&255|$&65280;$=(b[G>>1]|0)+Y+((b[I>>1]|0)-Y>>2)|0;b[Q+2>>1]=$>>>8&255|$&65280;b[I>>1]=b[G>>1]|0;b[G>>1]=P;P=R+1|0;if((P|0)<3){R=P;Q=Q+(j<<1)|0}else{break}}}Q=N+(C<<1)|0;R=M+1|0;P=c[r>>2]|0;if((R|0)<(m|0)){M=R;N=Q;O=P}else{aa=Q;ca=P;break}}}else{aa=K;ca=L}O=J+1|0;if((O|0)<((t|0)/(ca<<q|0)|0|0)){J=O;K=aa;L=ca}else{da=ca;break}}}else{da=D}L=o+1|0;if((L|0)<(da|0)){o=L;D=da}else{break}}}c[h>>2]=1;x=t;i=k;return x|0}function aLa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=+e;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0.0,v=0.0;TGb(a|0,0,60)|0;f=1<<b;c[a+20>>2]=b;c[a+16>>2]=f;h=f>>2;i=a+60|0;c[i>>2]=0;do{if(($8(a,b-2|0,d)|0)<0){j=a+24|0}else{k=WDb(((f|0)/2|0)<<2)|0;l=k;m=a+24|0;c[m>>2]=l;if((k|0)==0){j=m;break}n=c[i>>2]|0;if((n|0)==0){o=l+(h<<2)|0;c[a+28>>2]=o;p=1;q=o}else if((n|0)==1){n=k+4|0;c[a+28>>2]=n;p=2;q=n}else{j=m;break}r=(e<0.0?+(h|0):0.0)+.125;s=+R(+Q(+e));if((h|0)<=0){t=0;return t|0}u=+(f|0);m=0;while(1){v=(r+ +(m|0))*6.283185307179586/u;n=ba(m,p)|0;g[l+(n<<2)>>2]=s*(-0.0- +T(v));g[q+(n<<2)>>2]=s*(-0.0- +U(v));n=m+1|0;if((n|0)<(h|0)){m=n}else{t=0;break}}return t|0}}while(0);$Db(j);d9(a);t=-1;return t|0}function bLa(a){a=a|0;$Db(a+24|0);d9(a);return}function cLa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0;f=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=b;b=1<<c[a+20>>2];k=b>>2;l=b>>3;if((k|0)>0){m=d+((b>>1)-1<<2)|0;b=d;d=0;while(1){n=e[f+(d<<1)>>1]|0;o=h+(d<<2)|0;p=i+(d<<2)|0;g[j+(n<<3)>>2]=+g[m>>2]*+g[o>>2]- +g[b>>2]*+g[p>>2];g[j+(n<<3)+4>>2]=+g[m>>2]*+g[p>>2]+ +g[b>>2]*+g[o>>2];o=d+1|0;if((o|0)<(k|0)){m=m-8|0;b=b+8|0;d=o}else{break}}}ne[c[a+36>>2]&1023](a,j);if((l|0)>0){q=0}else{return}do{a=l-q-1|0;d=j+(a<<3)+4|0;r=+g[d>>2];s=+g[i+(a<<2)>>2];b=j+(a<<3)|0;t=+g[b>>2];u=+g[h+(a<<2)>>2];a=q+l|0;m=j+(a<<3)+4|0;v=+g[m>>2];w=+g[i+(a<<2)>>2];k=j+(a<<3)|0;x=+g[k>>2];y=+g[h+(a<<2)>>2];g[b>>2]=r*s-t*u;g[d>>2]=w*x+v*y;g[k>>2]=v*w-x*y;g[m>>2]=s*t+r*u;q=q+1|0;}while((q|0)<(l|0));return}function dLa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0,k=0;e=1<<c[a+20>>2];f=e>>1;h=e>>2;cLa(a,b+(h<<2)|0,d);if((h|0)<=0){return}d=f-1|0;a=e-1|0;e=0;i=0;while(1){g[b+(e<<2)>>2]=-0.0- +g[b+(d+i<<2)>>2];g[b+(a+i<<2)>>2]=+g[b+(e+f<<2)>>2];j=e+1|0;k=~e;if((j|0)<(h|0)){e=j;i=k}else{break}}return}function eLa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0;f=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=b;b=1<<c[a+20>>2];k=b>>1;l=b>>2;m=b>>3;n=l*3|0;o=(m|0)>0;if(!o){ne[c[a+36>>2]&1023](a,j);return}p=n-1|0;q=l-1|0;r=k-1|0;s=b-1|0;b=0;do{t=b<<1;u=-0.0- +g[d+(t+n<<2)>>2]- +g[d+(p-t<<2)>>2];v=+g[d+(q-t<<2)>>2]- +g[d+(t+l<<2)>>2];w=e[f+(b<<1)>>1]|0;x=h+(b<<2)|0;y=i+(b<<2)|0;g[j+(w<<3)>>2]=u*(-0.0- +g[x>>2])-v*+g[y>>2];g[j+(w<<3)+4>>2]=u*+g[y>>2]+v*(-0.0- +g[x>>2]);v=+g[d+(t<<2)>>2]- +g[d+(r-t<<2)>>2];u=-0.0- +g[d+(t+k<<2)>>2]- +g[d+(s-t<<2)>>2];t=b+m|0;x=e[f+(t<<1)>>1]|0;y=h+(t<<2)|0;w=i+(t<<2)|0;g[j+(x<<3)>>2]=v*(-0.0- +g[y>>2])-u*+g[w>>2];g[j+(x<<3)+4>>2]=v*+g[w>>2]+u*(-0.0- +g[y>>2]);b=b+1|0;}while((b|0)<(m|0));ne[c[a+36>>2]&1023](a,j);if(o){z=0}else{return}do{o=m-z-1|0;a=j+(o<<3)|0;u=+g[a>>2];v=-0.0- +g[i+(o<<2)>>2];b=j+(o<<3)+4|0;A=+g[b>>2];B=-0.0- +g[h+(o<<2)>>2];o=z+m|0;f=j+(o<<3)|0;C=+g[f>>2];D=-0.0- +g[i+(o<<2)>>2];s=j+(o<<3)+4|0;E=+g[s>>2];F=-0.0- +g[h+(o<<2)>>2];g[a>>2]=A*v+u*B;g[b>>2]=C*D-E*F;g[f>>2]=E*D+C*F;g[s>>2]=u*v-A*B;z=z+1|0;}while((z|0)<(m|0));return}function fLa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b+1432>>2]=((c[a+128>>2]|0)+15|0)/16|0;c[b+1436>>2]=((c[a+132>>2]|0)+15|0)/16|0;c[b>>2]=a;Z3(b+4|0,a);xMa();x2(b+1132|0,b+1280|0,1075976);b=a+788|0;if((c[b>>2]|0)!=0){d=a+140|0;c[d>>2]=12;return 0}c[b>>2]=2;d=a+140|0;c[d>>2]=12;return 0}function gLa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;k=i;i=i+16|0;l=k|0;m=c[f+60>>2]|0;n=m;o=c[j+24>>2]|0;p=c[j+28>>2]|0;j=l|0;c[j>>2]=g;c[l+4>>2]=0;c[l+8>>2]=0;g=W0a(f,l,0)|0;if((g|0)<0){q=g;i=k;return q|0}g=c[j>>2]|0;c[g+88>>2]=1;c[g+84>>2]=1;g=m+2224|0;l=g;O$a(g,m+2228|0,p);g=c[l>>2]|0;if((g|0)==0){q=-12;i=k;return q|0}Xe[c[m+1104>>2]&4095](g,o,(p+1|0)/2|0);o=c[l>>2]|0;l=p>>>0>268435455>>>0?-8:p<<3;p=l>>>0>2147483639>>>0|(o|0)==0;g=p?0:o;o=p?0:l;l=m+1260|0;c[l>>2]=g;f=m+1272|0;c[f>>2]=o;r=o+8|0;s=m+1276|0;c[s>>2]=r;c[m+1264>>2]=g+(o>>3);o=m+1268|0;c[o>>2]=0;if(p){q=p?-1094995529:0;i=k;return q|0}p=r>>>0>32>>>0?32:r;c[o>>2]=p;t=g+(p>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)>>>16;t=p+16|0;p=r>>>0>t>>>0?t:r;c[o>>2]=p;t=m+1416|0;c[t>>2]=u;u=g+(p>>>3)|0;g=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(p&7)>>>16;u=p+16|0;c[o>>2]=r>>>0>u>>>0?u:r;r=m+1412|0;c[r>>2]=g;c[m+1428>>2]=128;c[m+1424>>2]=128;c[m+1420>>2]=128;g=m+1440|0;c[g>>2]=0;u=m+1432|0;p=c[u>>2]|0;a:do{if((p|0)>0){v=m+1444|0;w=m+1436|0;x=m+1456|0;y=x;z=m+44|0;A=x;x=m+1124|0;B=m+1584|0;C=m+1712|0;D=m+1840|0;E=m;F=m+1968|0;G=m+2096|0;H=c[w>>2]|0;I=0;J=p;b:while(1){c[v>>2]=0;if((H|0)>0){do{me[c[z>>2]&511](A);K=0;while(1){if((K|0)>=6){break}L=c[1403248+(K<<2)>>2]|0;M=y+(L<<7)|0;N=c[t>>2]|0;if((c[r>>2]|0)==2){O=c[o>>2]|0;P=c[s>>2]|0;Q=c[l>>2]|0;R=Q+(O>>>3)|0;S=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>22;R=O+10|0;O=P>>>0>R>>>0?R:P;c[o>>2]=O;T=(S<<1)+1024&65535;U=O;V=P;W=Q}else{Q=K>>>0>1>>>0?0:L-3|0;if((Q|0)==0){P=c[1889813]|0;O=c[o>>2]|0;S=c[s>>2]|0;R=c[l>>2]|0;X=R+(O>>>3)|0;Y=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(O&7)>>>23;X=b[P+(Y<<2)>>1]|0;Z=b[P+(Y<<2)+2>>1]|0;Y=Z<<16>>16;if(Z<<16>>16<0){Z=O+9|0;_=S>>>0>Z>>>0?Z:S;Z=R+(_>>>3)|0;$=((fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(_&7)>>>((Y+32|0)>>>0))+X|0;aa=b[P+($<<2)+2>>1]|0;ca=b[P+($<<2)>>1]|0;da=_}else{aa=Y;ca=X;da=O}O=aa+da|0;ea=ca;fa=S;ga=R;ha=S>>>0>O>>>0?O:S}else{S=c[1889819]|0;O=c[o>>2]|0;R=c[s>>2]|0;X=c[l>>2]|0;Y=X+(O>>>3)|0;_=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(O&7)>>>23;Y=b[S+(_<<2)>>1]|0;$=b[S+(_<<2)+2>>1]|0;_=$<<16>>16;if($<<16>>16<0){$=O+9|0;P=R>>>0>$>>>0?$:R;$=X+(P>>>3)|0;Z=((fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(P&7)>>>((_+32|0)>>>0))+Y|0;ia=b[S+(Z<<2)+2>>1]|0;ja=b[S+(Z<<2)>>1]|0;ka=P}else{ia=_;ja=Y;ka=O}O=ia+ka|0;ea=ja;fa=R;ga=X;ha=R>>>0>O>>>0?O:R}c[o>>2]=ha;if((ea|0)<0){la=19;break b}if((ea|0)==0){ma=0}else{R=ga+(ha>>>3)|0;O=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(ha&7);R=(O^-2147483648)>>31;X=ea+ha|0;c[o>>2]=fa>>>0>X>>>0?X:fa;X=((R^O)>>>((32-ea|0)>>>0)^R)-R|0;if((X|0)>65534){q=-1094995529;la=41;break b}else{ma=X}}X=n+1420+(Q<<2)|0;Q=(c[X>>2]|0)+ma|0;c[X>>2]=Q;T=Q<<3&65535;U=c[o>>2]|0;V=c[s>>2]|0;W=c[l>>2]|0}b[M>>1]=T;M=-N|0;Q=c[287062]|0;X=U;R=0;c:while(1){O=W+(X>>>3)|0;Y=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(X&7);O=Y>>>23;_=b[Q+(O<<2)>>1]|0;P=a[Q+(O<<2)+2|0]|0;Z=P<<24>>24;if(P<<24>>24<0){P=Y<<9;S=X+9|0;$=(P>>>((Z+32|0)>>>0))+_|0;na=$;oa=a[Q+($<<2)+2|0]|0;pa=b[Q+($<<2)>>1]|0;qa=P;ra=V>>>0>S>>>0?S:V}else{na=O;oa=Z;pa=_;qa=Y;ra=X}Y=qa<<oa;_=oa+ra|0;sa=V>>>0>_>>>0?_:V;do{if((pa|0)==127){break c}else if((pa|0)==0){_=sa+6|0;Z=V>>>0>_>>>0?_:V;_=W+(Z>>>3)|0;O=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Z&7)>>22;_=Z+10|0;Z=V>>>0>_>>>0?_:V;_=R+1+(Y>>>26)|0;S=d[n+1284+_|0]|0;if((O|0)<0){ta=-(((ba(ba(O,M)|0,e[1179176+(S<<1)>>1]|0)|0)>>>3)+65535|1)&65535;ua=Z;va=_;wa=S;break}else{P=ba(O,N)|0;ta=(((ba(P,e[1179176+(S<<1)>>1]|0)|0)>>>3)+65535|1)&65535;ua=Z;va=_;wa=S;break}}else{S=(d[Q+(na<<2)+3|0]|0)+R|0;_=d[n+1284+S|0]|0;Z=ba(pa,N)|0;P=Y>>31;O=((ba(Z,e[1179176+(_<<1)>>1]|0)|0)>>>3^P)-P|0;P=sa+1|0;ta=O&65535;ua=V>>>0>P>>>0?P:V;va=S;wa=_}}while(0);if((va|0)>63){la=32;break b}b[y+(L<<7)+(wa<<1)>>1]=ta;X=ua;R=va}c[o>>2]=sa;c[n+2232+(L<<2)>>2]=R;if(((c[f>>2]|0)-(c[o>>2]|0)|0)<0){q=-1094995529;la=41;break b}else{K=K+1|0}}K=c[j>>2]|0;X=c[g>>2]|0;N=c[v>>2]|0;Q=c[K+32>>2]|0;M=c[K>>2]|0;Y=(ba(N<<4,Q)|0)+(X<<4)|0;_=c[K+4>>2]|0;S=N<<3;N=K+36|0;P=c[N>>2]|0;O=X<<3;X=c[K+8>>2]|0;Z=K+40|0;K=c[Z>>2]|0;Xe[c[x>>2]&4095](M+Y|0,Q,A);Xe[c[x>>2]&4095](M+(Y|8)|0,Q,B);$=Y+(Q<<3)|0;Xe[c[x>>2]&4095](M+$|0,Q,C);Xe[c[x>>2]&4095](M+($+8)|0,Q,D);if((c[(c[E>>2]|0)+88>>2]&8192|0)==0){Q=X+((ba(K,S)|0)+O)|0;K=_+((ba(P,S)|0)+O)|0;Xe[c[x>>2]&4095](K,c[N>>2]|0,F);Xe[c[x>>2]&4095](Q,c[Z>>2]|0,G)}Z=(c[v>>2]|0)+1|0;c[v>>2]=Z;xa=c[w>>2]|0;}while((Z|0)<(xa|0));ya=xa;za=c[g>>2]|0;Aa=c[u>>2]|0}else{ya=H;za=I;Aa=J}Z=za+1|0;c[g>>2]=Z;if((Z|0)<(Aa|0)){H=ya;I=Z;J=Aa}else{break a}}if((la|0)==19){yDb(0,16,2108808,(Ba=i,i=i+1|0,i=i+7&-8,c[Ba>>2]=0,Ba)|0);i=Ba;q=-1094995529;i=k;return q|0}else if((la|0)==32){J=c[v>>2]|0;yDb(c[E>>2]|0,16,2185944,(Ba=i,i=i+16|0,c[Ba>>2]=c[g>>2],c[Ba+8>>2]=J,Ba)|0);i=Ba;q=-1094995529;i=k;return q|0}else if((la|0)==41){i=k;return q|0}}}while(0);c[h>>2]=1;q=(((c[o>>2]|0)+31|0)/32|0)<<2;i=k;return q|0}function hLa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+2224|0);c[b+2228>>2]=0;return 0}function iLa(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;f=c[a+60>>2]|0;g=c[a+96>>2]|0;do{if((g|0)!=0){if((c[a+100>>2]|0)<16){break}h=g+12|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=1462504;while(1){k=c[h>>2]|0;if((k|0)==0){l=6;break}if((k|0)==(j|0)){break}else{h=h+16|0}}if((l|0)==6){yDb(a,16,2108776,(m=i,i=i+8|0,c[m>>2]=j,m)|0);i=m;n=-1094995529;i=b;return n|0}k=c[h+12>>2]|0;c[a+412>>2]=k;o=c[h+8>>2]|0;c[a+416>>2]=o;p=(c[h+4>>2]|0)*1e3|0;c[a+72>>2]=p;q=(k|0)/1e3|0;if((o-1|0)>>>0>1>>>0){yDb(a,16,2051e3,(m=i,i=i+8|0,c[m>>2]=o,m)|0);i=m;n=-1094995529;i=b;return n|0}r=(o|0)==1;s=a+448|0;c[s>>2]=r?4:3;c[s+4>>2]=r?0:0;r=(p|0)/(o*1e3|0|0)|0;s=(o<<16)+(q<<8)+r|0;if((s|0)==76848){c[f+232>>2]=1188880;t=1188880}else if((s|0)==142368){c[f+232>>2]=1189240;t=1189240}else if((s|0)==69648){c[f+232>>2]=1189840;t=1189840}else if((s|0)==67592){c[f+232>>2]=1190320;t=1190320}else if((s|0)==76840){c[f+232>>2]=1189120;t=1189120}else if((s|0)==76832){c[f+232>>2]=1189360;t=1189360}else if((s|0)==142384){c[f+232>>2]=1188760;t=1188760}else if((s|0)==133128){c[f+232>>2]=1190200;t=1190200}else if((s|0)==135184){c[f+232>>2]=1189720;t=1189720}else if((s|0)==133126){c[f+232>>2]=1190440;t=1190440}else if((s|0)==133898){c[f+232>>2]=1189960;t=1189960}else if((s|0)==142376){c[f+232>>2]=1189e3;t=1189e3}else if((s|0)==136728){c[f+232>>2]=1189480;t=1189480}else if((s|0)==68362){c[f+232>>2]=1190080;t=1190080}else if((s|0)==71192){c[f+232>>2]=1189600;t=1189600}else if((s|0)==67590){c[f+232>>2]=1190560;t=1190560}else{yDb(a,16,2005488,(m=i,i=i+16|0,c[m>>2]=q,c[m+8>>2]=r,m)|0);i=m;n=-38;i=b;return n|0}c[f+36872>>2]=1;c[f+36876>>2]=274;c[f+36880>>2]=4;c[f+36884>>2]=160;c[f+34228>>2]=(ba(e[t+96>>1]|0,p)|0)/(k|0)|0;c[f+236>>2]=(r|0)==6;n=C$a(a)|0;i=b;return n|0}}while(0);yDb(a,16,2185904,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=b;return n|0}function jLa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;h=i;j=c[e+232>>2]|0;k=c[(c[e>>2]|0)+416>>2]|0;l=g<<3;g=l>>>0>2147483639>>>0|(f|0)==0;m=g?0:f;f=g?8:l+8|0;l=e+34236|0;c[l>>2]=0;g=e+34232|0;a:do{if((c[g>>2]|0)>0){n=(k|0)>0;o=e+34184|0;p=e+34168|0;q=j+112|0;r=j+115|0;s=j+104|0;t=j+105|0;u=j+107|0;v=j+106|0;w=e+236|0;x=0;y=0;while(1){z=m+(x>>>3)|0;A=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((x&7)>>>0)&15;z=x+4|0;B=f>>>0>z>>>0?z:f;c[e+34240+(y*1316|0)>>2]=A;if(A>>>0>8>>>0){break}A=c[1109088+(c[e+34240+((c[l>>2]|0)*1316|0)>>2]<<2)>>2]|0;z=e+34240+(y*1316|0)+4|0;c[z>>2]=A;C=a[j+(A<<5)|0]|0;D=C&255;do{if((A|0)==0){E=B}else{if((c[w>>2]|0)!=0){E=B;break}F=B+2|0;E=f>>>0>F>>>0?F:f}}while(0);B=e+34172+(A<<2)|0;if((c[B>>2]|0)>0){F=e+34156+(A<<2)|0;G=0;H=e+34240+(y*1316|0)+8|0;I=E;while(1){J=(G|0)>=(c[F>>2]|0)|0;K=d[e+34140+(A<<1)+J|0]|0;L=m+(I>>>3)|0;M=32-K|0;N=K+I|0;K=f>>>0>N>>>0?N:f;a[H]=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((I&7)>>>0)<<M>>>(M>>>0);M=d[e+34148+(A<<1)+J|0]|0;J=m+(K>>>3)|0;L=32-M|0;N=K+M|0;M=f>>>0>N>>>0?N:f;a[H+1|0]=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((K&7)>>>0)<<L>>>(L>>>0);L=G+1|0;if((L|0)<(c[B>>2]|0)){G=L;H=H+2|0;I=M}else{O=M;break}}}else{O=E}do{if(C<<24>>24==0|n^1){P=O}else{I=O;H=0;while(1){G=I;B=0;A=c[z>>2]|0;while(1){if((a[j+(A<<5)+16|0]|0)==0){Q=G;R=A}else{F=G;M=0;L=A;while(1){K=d[j+(L<<5)+17|0]|0;J=m+(F>>>3)|0;N=32-K|0;S=K+F|0;K=f>>>0>S>>>0?S:f;a[e+34240+(y*1316|0)+1126+(H<<6)+(B<<2)+M|0]=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((F&7)>>>0)<<N>>>(N>>>0);N=M+1|0;J=c[z>>2]|0;if((N|0)<(d[j+(J<<5)+16|0]|0)){F=K;M=N;L=J}else{Q=K;R=J;break}}}L=B+1|0;if((L|0)<(D|0)){G=Q;B=L;A=R}else{break}}A=H+1|0;if((A|0)<(k|0)){I=Q;H=A}else{break}}if(C<<24>>24==0|n^1){P=Q;break}else{T=Q;U=0}while(1){H=T;I=0;while(1){V=((H|0)<(f|0))+H|0;a[e+34240+(y*1316|0)+1254+(U<<4)+I|0]=(d[m+(H>>>3)|0]|0)>>>((H&7)>>>0)&1;A=I+1|0;if((A|0)<(D|0)){H=V;I=A}else{break}}I=U+1|0;if((I|0)<(k|0)){T=V;U=I}else{P=V;break}}}}while(0);b:do{if((c[z>>2]|0)==2){if(n){W=P;X=0}else{Y=P;break}while(1){I=m+(W>>>3)|0;H=W+8|0;A=f>>>0>H>>>0?H:f;a[e+34240+(y*1316|0)+1092+X|0]=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((W&7)>>>0);I=X+1|0;if((I|0)<(k|0)){W=A;X=I}else{Z=A;_=30;break}}}else{if(!n){Y=P;break}if(C<<24>>24==0){A=P;I=0;while(1){H=m+(A>>>3)|0;B=A+8|0;G=f>>>0>B>>>0?B:f;a[e+34240+(y*1316|0)+1092+I|0]=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((A&7)>>>0);H=I+1|0;if((H|0)<(k|0)){A=G;I=H}else{Z=G;_=30;break b}}}else{$=P;aa=0}while(1){I=m+($>>>3)|0;A=$+8|0;a[e+34240+(y*1316|0)+1092+aa|0]=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>(($&7)>>>0);I=ba(aa,D)|0;G=f>>>0>A>>>0?A:f;A=0;while(1){H=m+(G>>>3)|0;B=G+5|0;ca=f>>>0>B>>>0?B:f;a[A+I+(e+34240+(y*1316|0)+1094)|0]=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((G&7)>>>0)&31;H=A+1|0;if((H|0)<(D|0)){G=ca;A=H}else{break}}A=aa+1|0;if((A|0)<(k|0)){$=ca;aa=A}else{Z=ca;_=30;break}}}}while(0);do{if((_|0)==30){_=0;if(n){da=Z;ea=0}else{Y=Z;break}while(1){D=d[s]|0;C=m+(da>>>3)|0;A=32-D|0;G=D+da|0;D=f>>>0>G>>>0?G:f;a[e+34240+(y*1316|0)+1296+ea|0]=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((da&7)>>>0)<<A>>>(A>>>0);A=d[t]|0;C=m+(D>>>3)|0;G=32-A|0;I=D+A|0;A=f>>>0>I>>>0?I:f;a[e+34240+(y*1316|0)+1286+ea|0]=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((D&7)>>>0)<<G>>>(G>>>0);if((a[u]|0)==0){fa=A}else{G=A;A=0;while(1){D=d[v]|0;C=m+(G>>>3)|0;I=32-D|0;H=D+G|0;D=f>>>0>H>>>0?H:f;a[e+34240+(y*1316|0)+1288+(ea<<2)+A|0]=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((G&7)>>>0)<<I>>>(I>>>0);I=A+1|0;if((I|0)<(d[u]|0)){G=D;A=I}else{fa=D;break}}}A=ea+1|0;if((A|0)<(k|0)){da=fa;ea=A}else{Y=fa;break}}}}while(0);do{if((c[z>>2]|0)==2){if((c[o>>2]|0)>0){A=0;G=e+34240+(y*1316|0)+1032|0;D=Y;while(1){I=(A|0)>=(c[p>>2]|0)|0;C=d[e+34146+I|0]|0;H=m+(D>>>3)|0;B=32-C|0;L=C+D|0;C=f>>>0>L>>>0?L:f;a[G]=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((D&7)>>>0)<<B>>>(B>>>0);B=d[e+34154+I|0]|0;I=m+(C>>>3)|0;H=32-B|0;L=C+B|0;B=f>>>0>L>>>0?L:f;a[G+1|0]=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((C&7)>>>0)<<H>>>(H>>>0);H=A+1|0;if((H|0)<(c[o>>2]|0)){A=H;G=G+2|0;D=B}else{ga=B;break}}}else{ga=Y}if(n){ha=ga;ia=0}else{ja=ga;break}while(1){D=d[q]|0;G=m+(ha>>>3)|0;A=32-D|0;B=D+ha|0;D=f>>>0>B>>>0?B:f;c[e+34240+(y*1316|0)+1300+(ia<<2)>>2]=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((ha&7)>>>0)<<A>>>(A>>>0);A=d[r]|0;G=m+(D>>>3)|0;B=32-A|0;H=D+A|0;A=f>>>0>H>>>0?H:f;c[e+34240+(y*1316|0)+1308+(ia<<2)>>2]=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((D&7)>>>0)<<B>>>(B>>>0);B=ia+1|0;if((B|0)<(k|0)){ha=A;ia=B}else{ja=A;break}}}else{ja=Y}}while(0);z=ja&3;if((z|0)==0){ka=ja}else{A=4-z+ja|0;ka=f>>>0>A>>>0?A:f}A=(c[l>>2]|0)+1|0;c[l>>2]=A;if((A|0)<(c[g>>2]|0)){x=ka;y=A}else{la=ka;break a}}yDb(b,16,1967888,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;ma=-1094995529;i=h;return ma|0}else{la=0}}while(0);ma=(la+7|0)/8|0;i=h;return ma|0}function kLa(e,f,h,j,k,l,m){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=+l;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0,L=0,M=0,N=0,O=0;n=i;i=i+16|0;o=n|0;p=c[e+232>>2]|0;g[o>>2]=.4000000059604645;g[o+4>>2]=.3499999940395355;g[o+8>>2]=.2800000011920929;q=a[p+(m<<5)+16|0]|0;r=q&255;s=(d[p+(m<<5)+8|0]|0)/(q&255)|0;t=s&255;u=e|0;v=(c[(c[u>>2]|0)+416>>2]|0)==1?.5:+g[o+(m<<2)>>2];if(s<<24>>24==0){i=n;return}s=q<<24>>24==0;q=p+(m<<5)+12|0;o=(h|0)!=0;h=p+(m<<5)+4|0;w=1.0-v;p=r>>>0>1>>>0?r:1;x=0;y=0;z=k;while(1){if(s){A=y;B=z}else{k=c[q>>2]|0;C=0;D=y;E=z;while(1){F=+(b[k+((ba(d[f+C|0]|0,t)|0)+x<<1)>>1]|0)*.00048828125;do{if((c[(c[u>>2]|0)+416>>2]|0)==1){if(o){G=F+v*+g[e+400+(m*320|0)+(j*160|0)+(D<<2)>>2]}else{G=F}H=G}else{I=F;if(!o){H=I;break}H=w*I+v*+g[e+400+(m*320|0)+(j*160|0)+(D<<2)>>2]}}while(0);I=H+1.0;g[e+400+(m*320|0)+(j*160|0)+(D<<2)>>2]=F;J=(I<.1?.10000000149011612:I)*l;K=b[(c[h>>2]|0)+(D<<1)>>1]|0;L=K&65535;if(!(K<<16>>16==0)){K=E;M=L;while(1){N=M-1|0;g[K>>2]=J;if((N|0)==0){break}else{K=K+4|0;M=N}}}O=E+(L<<2)|0;M=C+1|0;if((M|0)>=(r|0)){break}C=M;D=D+1|0;E=O}A=p+y|0;B=O}E=x+1|0;if((E|0)<(t|0)){x=E;y=A;z=B}else{break}}i=n;return}function lLa(e,f,h,i,j){e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;k=c[e+232>>2]|0;l=c[e>>2]|0;e=c[l+412>>2]|0;m=(e|0)/1e3|0;n=c[l+416>>2]|0;o=(c[l+72>>2]|0)/(n*1e3|0|0)|0;l=b[k+96>>1]|0;p=(n|0)==1;q=+((l&65535)>>>0)/+(m|0)*.2;if(p){r=+gc(+q);s=r;t=+gc(+6.0)+r}else{r=q*400.0;s=+(~~(r+.5)|0)/400.0;t=+(~~(r*6.0+.5)|0)/400.0}r=s+ +(f|0)*(t-s)/+((1<<(d[k+112|0]|0))-1|0);if(p){u=+Wc(+r)}else{u=+(~~(r*400.0+.5)|0)/400.0}switch(m|0){case 8:{v=2.0;break};case 44:{v=8.0;break};case 11:{v=3.0;break};case 22:{v=(o|0)==32?2.0:4.0;break};case 16:{v=3.0;break};default:{v=4.0}}m=a[k+114|0]|0;p=m&255;f=~~(v/(+(l&65535|0)/u)*+(p|0));if((e-22e3|0)>>>0<1e3>>>0&(o|0)==32){w=~~(+(f|0)*(2.0/u+1.0)+.5)}else{w=f}v=(n|0)==2?25.0e3:2.0e4;r=v/+((1<<(d[k+115|0]|0))-1|0);s=(+(h|0)*r+r*.5)/v;if(s<-1.0){x=-1.0}else{x=s>1.0?1.0:s}s=(+_(+Q(+x)*5.303304908059076)+-1.0)*v*(x>0.0?1.0:-1.0)/200.0*.0001220703125;h=i+(p<<2)|0;k=(w|0)/2|0;if((w|0)>1){n=(k|0)>1;f=0;o=i;while(1){e=j+(f<<2)|0;g[e>>2]=+g[e>>2]+s*+g[o>>2];e=f+1|0;if((e|0)<(k|0)){f=e;o=o+4|0}else{break}}y=i+((n?k:1)<<2)|0}else{y=i}i=w>>1;k=((m<<24>>24!=0?i:-i|0)+p|0)/(w|0)|0;p=~~(u+.5);i=(w|0)/-2|0;m=(w+1|0)/2|0;if((k|0)>1){w=(i|0)<(m|0);n=m-i|0;o=1;f=y;e=p;while(1){if(w){l=i;z=f;while(1){A=j+(l+e<<2)|0;g[A>>2]=+g[A>>2]+s*+g[z>>2];A=l+1|0;if((A|0)<(m|0)){l=A;z=z+4|0}else{break}}B=f+(n<<2)|0}else{B=f}z=o+1|0;l=~~(u*+(z|0)+.5);if((z|0)<(k|0)){o=z;f=B;e=l}else{C=B;D=l;break}}}else{C=y;D=p}if((i|0)<(m|0)&C>>>0<h>>>0){E=i;F=C}else{return}while(1){C=F+4|0;i=j+(E+D<<2)|0;g[i>>2]=+g[i>>2]+s*+g[F>>2];i=E+1|0;if((i|0)<(m|0)&C>>>0<h>>>0){E=i;F=C}else{break}}return}function mLa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+1216|0;e=d|0;f=d+1024|0;TGb(f|0,0,192)|0;IAb(e,0,1);KAb(e,2218640,(g=i,i=i+8|0,c[g>>2]=2209256,g)|0);i=g;h=c[b+96>>2]|0;if((h|0)==0){j=2;k=0;l=0;m=0;n=16777215;o=16;p=e|0;q=c[p>>2]|0;r=phb(b,q,o,n,0,m,l,k,j)|0;i=d;return r|0}oLa(f|0,h)|0;h=0;s=16;t=16777215;u=0;v=0;w=0;x=2;while(1){y=a[f+(h*24|0)|0]|0;switch(((y-65|0)>>>0<26>>>0?y^32:y)|0){case 112:{z=8;A=w;B=v;C=u;D=t;E=s;break};case 121:{y=c[f+(h*24|0)+8>>2]|0;z=x;A=(y&4|0)==0?w:1;B=(y&1|0)==0?v:1;C=(y&2|0)==0?u:1;D=t;E=s;break};case 102:{PAb(e);y=c[f+(h*24|0)+16>>2]|0;KAb(e,2200680,(g=i,i=i+16|0,c[g>>2]=c[f+(h*24|0)+20>>2],c[g+8>>2]=y,g)|0);i=g;z=x;A=w;B=v;C=u;D=t;E=s;break};case 99:{z=x;A=w;B=v;C=u;D=c[f+(h*24|0)+8>>2]|0;E=s;break};case 115:{z=x;A=w;B=v;C=u;D=t;E=c[f+(h*24|0)+8>>2]|0;break};default:{z=x;A=w;B=v;C=u;D=t;E=s}}y=h+1|0;if(y>>>0<8>>>0){h=y;s=E;t=D;u=C;v=B;w=A;x=z}else{j=z;k=A;l=B;m=C;n=D;o=E;break}}p=e|0;q=c[p>>2]|0;r=phb(b,q,o,n,0,m,l,k,j)|0;i=d;return r|0}function nLa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+1248|0;h=g|0;j=g+1032|0;k=g+1040|0;l=g+1232|0;m=g+1240|0;n=d;o=c[f+24>>2]|0;p=f+28|0;q=c[p>>2]|0;r=o+q|0;TGb(k|0,0,192)|0;if((q|0)<1){s=q;i=g;return s|0}t=xd(o|0,2185824,(u=i,i=i+8|0,c[u>>2]=g+1024,u)|0)|0;i=u;do{if((t|0)==1){if((a[o+((c[p>>2]|0)-1)|0]|0)!=10){IAb(h,0,2048);if((q|0)>0){v=7;break}else{break}}yDb(b,16,2108616,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;s=-1094995529;i=g;return s|0}else{IAb(h,0,2048);v=7}}while(0);a:do{if((v|0)==7){q=k|0;t=o;while(1){if((a[t]|0)==0){break a}w=oLa(q,t)|0;x=0;do{y=k+(x*24|0)+4|0;z=c[y>>2]|0;do{if((z|0)!=2){b:do{switch(a[k+(x*24|0)|0]|0){case 111:{A=c[k+(x*24|0)+12>>2]|0;KAb(h,2243160,(u=i,i=i+16|0,c[u>>2]=c[k+(x*24|0)+8>>2],c[u+8>>2]=A,u)|0);i=u;break};case 102:{A=c[k+(x*24|0)+16>>2]|0;KAb(h,2289088,(u=i,i=i+16|0,c[u>>2]=c[k+(x*24|0)+20>>2],c[u+8>>2]=A,u)|0);i=u;break};case 99:{KAb(h,2307416,(u=i,i=i+8|0,c[u>>2]=c[k+(x*24|0)+8>>2],u)|0);i=u;break};case 89:case 121:{A=c[k+(x*24|0)+8>>2]|0;if((A&1|0)!=0){KAb(h,2331776,(u=i,i=i+8|0,c[u>>2]=105,u)|0);i=u}if((A&2|0)!=0){KAb(h,2331776,(u=i,i=i+8|0,c[u>>2]=98,u)|0);i=u}if((A&4|0)!=0){KAb(h,2331776,(u=i,i=i+8|0,c[u>>2]=117,u)|0);i=u}if((A&8|0)==0){break b}KAb(h,2331776,(u=i,i=i+8|0,c[u>>2]=115,u)|0);i=u;break};case 112:{if((c[k+(x*24|0)+8>>2]|0)!=0){break b}KAb(h,2257432,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break};case 115:{KAb(h,2272912,(u=i,i=i+8|0,c[u>>2]=c[k+(x*24|0)+8>>2],u)|0);i=u;break};default:{}}}while(0);if((z|0)!=1){break}c[y>>2]=2}}while(0);x=x+1|0;}while(x>>>0<8>>>0);c:do{if(w>>>0<r>>>0){x=w;while(1){y=a[x]|0;if((y<<24>>24|0)==0){B=x;break c}else if((y<<24>>24|0)==124){C=7;break}MAb(h,y,1);y=x+1|0;if(y>>>0<r>>>0){x=y}else{B=y;break c}}while(1){if((c[k+(C*24|0)+4>>2]|0)==0){y=k+(C*24|0)|0;z=a[y]|0;do{if((z|0)==121){A=c[k+(C*24|0)+8>>2]|0;if((A&8|0)!=0){KAb(h,1967864,(u=i,i=i+8|0,c[u>>2]=115,u)|0);i=u}if((A&4|0)!=0){KAb(h,1967864,(u=i,i=i+8|0,c[u>>2]=117,u)|0);i=u}if((A&2|0)!=0){KAb(h,1967864,(u=i,i=i+8|0,c[u>>2]=98,u)|0);i=u}if((A&1|0)==0){break}KAb(h,1967864,(u=i,i=i+8|0,c[u>>2]=105,u)|0);i=u}else if((z|0)==115){KAb(h,2351792,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u}else if((z|0)==99){KAb(h,1915296,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u}else if((z|0)==102){KAb(h,1894728,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u}}while(0);a[y]=0}if((C|0)>0){C=C-1|0}else{break}}KAb(h,2050968,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;B=x+1|0}else{B=w}}while(0);if(B>>>0<r>>>0){t=B}else{break}}}}while(0);if((c[h+4>>2]|0)!=0){KAb(h,2005440,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;QAb(h,j)|0;h=c[j>>2]|0;if((a[h]|0)==0){D=h}else{h=f+8|0;u=c[h>>2]|0;B=c[h+4>>2]|0;h=c[f+48>>2]|0;f=b+104|0;c[l>>2]=1;c[l+4>>2]=100;b=KDb(u,B,f,l)|0;if((h|0)==-1){E=-1}else{c[m>>2]=1;c[m+4>>2]=100;l=KDb(h,(h|0)<0|0?-1:0,f,m)|0;E=l}shb(n,c[j>>2]|0,b,E,0)|0;D=c[j>>2]|0}ZDb(D)}c[e>>2]=(c[d+12>>2]|0)!=0;s=c[p>>2]|0;i=g;return s|0}function oLa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=i;i=i+24|0;f=e+8|0;c[f>>2]=d;if((a[d]|0)!=123){g=d;i=e;return g|0}h=e+16|0;j=e|0;k=d;a:while(1){d=a[k+1|0]|0;TGb(h|0,0,3)|0;if(d<<24>>24==0){g=k;l=33;break}if((a[k+2|0]|0)!=58){g=k;l=33;break}m=k+3|0;c[f>>2]=m;switch(d<<24>>24|0){case 111:{n=kb(m|0,f|0,10)|0;o=c[f>>2]|0;if((a[o]|0)!=44){g=k;l=33;break a}p=o+1|0;c[f>>2]=p;o=kb(p|0,f|0,10)|0;p=c[f>>2]|0;if((a[p]|0)==125){q=0;r=0;s=o;t=n;u=1;v=111;w=p}else{g=k;l=33;break a}break};case 121:{x=0;l=7;break};case 67:{y=1;l=14;break};case 80:{p=k+4|0;c[f>>2]=p;if((a[p]|0)==125){q=0;r=0;s=0;t=(a[m]|0)==49|0;u=1;v=112;w=p}else{g=k;l=33;break a}break};case 83:{z=1;l=22;break};case 99:{y=0;l=14;break};case 115:{z=0;l=22;break};case 89:{x=1;l=7;break};case 72:{p=Vb(m|0,125)|0;if((p|0)==0){g=k;l=33;break a}n=p-m|0;if((n|0)<0){g=k;l=33;break a}p=k+(n+3)|0;c[f>>2]=p;q=n;r=m;s=0;t=0;u=0;v=104;w=p;break};case 70:{A=1;l=18;break};case 102:{A=0;l=18;break};default:{g=k;l=33;break a}}b:do{if((l|0)==7){l=0;p=0;n=m;while(1){o=a[n]|0;if((o<<24>>24|0)==0){g=k;l=33;break a}else if((o<<24>>24|0)==125){q=0;r=0;s=0;t=p;u=x;v=d;w=n;break b}B=Ib(1939520,o<<24>>24|0,5)|0;do{if((B|0)==0){C=p}else{o=B-1939520|0;if(!((o|0)>-1)){C=p;break}C=1<<o|p}}while(0);B=n+1|0;c[f>>2]=B;p=C;n=B}}else if((l|0)==14){l=0;if((a[m]|0)==36){n=k+4|0;c[f>>2]=n;D=n}else{D=m}n=(kb(D|0,f|0,16)|0)&16777215;p=c[f>>2]|0;if((a[p]|0)==125){q=0;r=0;s=0;t=n;u=y;v=99;w=p}else{g=k;l=33;break a}}else if((l|0)==18){l=0;p=Vb(m|0,125)|0;if((p|0)==0){g=k;l=33;break a}n=p-m|0;if((n|0)<0){g=k;l=33;break a}p=k+(n+3)|0;c[f>>2]=p;q=n;r=m;s=0;t=0;u=A;v=102;w=p}else if((l|0)==22){l=0;p=kb(m|0,f|0,10)|0;n=c[f>>2]|0;if((a[n]|0)==125){q=0;r=0;s=0;t=p;u=z;v=115;w=n}else{g=k;l=33;break a}}}while(0);a[j]=a[h]|0;a[j+1|0]=a[h+1|0]|0;a[j+2|0]=a[h+2|0]|0;m=Ib(2230696,v<<24>>24|0,9)|0;do{if((m|0)!=0){d=m-2230696|0;if((d|0)<0){break}n=b+(d*24|0)|0;a[n]=v;d=n+1|0;a[d]=a[j]|0;a[d+1|0]=a[j+1|0]|0;a[d+2|0]=a[j+2|0]|0;c[n+4>>2]=u;c[n+8>>2]=t;c[n+12>>2]=s;c[n+16>>2]=r;c[n+20>>2]=q}}while(0);m=w+1|0;c[f>>2]=m;if((a[m]|0)==123){k=m}else{g=m;l=33;break}}if((l|0)==33){i=e;return g|0}return 0}function pLa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+60|0;e=c[d>>2]|0;f=a+64|0;c[(c[f>>2]|0)+4>>2]=1;c[e+40>>2]=0;c[e+36>>2]=15;g=N_(e+2996|0,11,127,919776,1,1,918944,4,4,0,0,0,0)|0;if((g|0)<0){yDb(a,16,2331744,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=g;i=b;return j|0}Z3(e+1544|0,a);BFa(e+2788|0,c[a+88>>2]|0);x2(e+2672|0,e+1412|0,1426280);g=e+44|0;e=0;while(1){if(!(e>>>0<16>>>0)){j=0;k=12;break}h=ICb()|0;c[g+(e*12|0)>>2]=h;if((h|0)==0){break}else{e=e+1|0}}if((k|0)==12){i=b;return j|0}k=c[d>>2]|0;$Db(k+28|0);c[k+32>>2]=0;d=k+44|0;e=0;do{g=d+(e*12|0)|0;h=g|0;if((c[h>>2]|0)!=0){U0a(a,g)}JCb(h);e=e+1|0;}while(e>>>0<16>>>0);if((c[c[f>>2]>>2]|0)!=0){j=-12;i=b;return j|0}Q_(k+2996|0);j=-12;i=b;return j|0}function qLa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=l-20|0;m=c[e+60>>2]|0;n=m;if((l|0)<21){yDb(e,16,2185800,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}q=k+20|0;r=k+2|0;s=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=k+4|0;t=(d[r]|d[r+1|0]<<8)<<16>>16;r=t&65535;u=k+6|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;u=v&65535;w=k+12|0;x=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=a[k+16|0]|0;k=w&255;y=m;z=c[y>>2]|0;do{if((z|0)==0){do{if(!(t<<16>>16==160&v<<16>>16==120)){if(t<<16>>16==320&v<<16>>16==240){break}yDb(e,16,2108592,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}}while(0);c[y>>2]=e;c[e+120>>2]=r;c[e+124>>2]=u;c[e+140>>2]=0;A=-u|0;c[m+4>>2]=-(A>>3);c[m+16>>2]=r>>>3;B=-(A>>4)|0;c[m+8>>2]=B;A=r>>>4;c[m+20>>2]=A;c[m+12>>2]=B;c[m+24>>2]=A}else{if((r|0)==(c[z+120>>2]|0)){if((u|0)==(c[z+124>>2]|0)){break}}DDb(e,2050944,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=j;return p|0}}while(0);z=(x|0)!=0;do{if(z){x=m+44|0;if((c[c[x+((c[m+40>>2]|0)*12|0)>>2]>>2]|0)!=0){C=x;break}yDb(e,16,2005400,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}else{C=m+44|0}}while(0);x=m+36|0;U0a(e,C+((c[x>>2]|0)*12|0)|0);u=c[x>>2]|0;c[(c[C+(u*12|0)>>2]|0)+88>>2]=z?2:1;r=W0a(e,C+(u*12|0)|0,1)|0;if((r|0)<0){p=r;i=j;return p|0}r=c[x>>2]|0;u=m+3020|0;c[u>>2]=r;v=m+3016|0;c[v>>2]=r+15&15;t=m+236|0;A=c[C+(r*12|0)>>2]|0;B=c[(c[y>>2]|0)+124>>2]|0;D=c[A+32>>2]|0;c[t+(r<<6)>>2]=(c[A>>2]|0)+(ba(B-1|0,D)|0);E=(B>>1)-1|0;B=A+40|0;c[t+(r<<6)+4>>2]=(c[A+8>>2]|0)+(ba(E,c[B>>2]|0)|0);F=A+36|0;c[t+(r<<6)+8>>2]=(c[A+4>>2]|0)+(ba(E,c[F>>2]|0)|0);c[t+(r<<6)+32>>2]=-D;c[t+(r<<6)+36>>2]=-(c[F>>2]|0);c[t+(r<<6)+40>>2]=-(c[B>>2]|0);X0a(e);B=m+28|0;r=B;O$a(B,m+32|0,h);B=c[r>>2]|0;if((B|0)==0){p=-12;i=j;return p|0}Xe[c[m+2640>>2]&4095](B,q,h>>2);q=c[r>>2]|0;r=h<<3;h=r>>>0>2147483639>>>0|(q|0)==0;B=h?0:q;q=h?0:r;r=m+1392|0;c[r>>2]=B;c[m+1404>>2]=q;h=m+1408|0;c[h>>2]=q+8;c[m+1396>>2]=B+(q>>3);q=m+1400|0;c[q>>2]=0;B=z&1^1;t=1e4-s|0;s=m+40|0;F=m+2804|0;D=m+1264|0;E=m+1580|0;A=(w&255)>>>0>1>>>0;w=m+3e3|0;G=m+2996|0;H=m+2664|0;m=(t|0)>1e4?1e4:t;I=0;J=0;a:while(1){K=(J|0)!=0;L=K?1e3:2e3;M=((t|0)<(L|0)?L:m)<<2;L=c[x>>2]|0;N=c[n+236+(L<<6)+32+(J<<2)>>2]|0;O=n+4+(J<<2)|0;if((c[O>>2]|0)>0){P=n+16+(J<<2)|0;Q=(J|B|0)==0;R=I;S=c[n+236+(c[s>>2]<<6)+(J<<2)>>2]|0;T=c[n+236+(L<<6)+(J<<2)>>2]|0;L=0;while(1){U=c[P>>2]|0;if((U|0)>0){V=0;W=S;X=T;while(1){do{if(z){Y=c[q>>2]|0;Z=c[r>>2]|0;_=d[Z+(Y>>>3)|0]|0;$=c[h>>2]|0;aa=((Y|0)<($|0))+Y|0;c[q>>2]=aa;if(K^(_&128>>>((Y&7)>>>0)|0)!=0){Z0a(n+44+((c[s>>2]|0)*12|0)|0,R,0);cf[c[F>>2]&1023](X,W,N,8);break}if(!Q){ca=25;break}Y=d[Z+(aa>>>3)|0]|0;_=((aa|0)<($|0))+aa|0;c[q>>2]=_;if((Y&128>>>((aa&7)>>>0)|0)==0){ca=25;break}aa=Z+(_>>>3)|0;Z=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(_&7)>>>28;aa=_+4|0;c[q>>2]=$>>>0>aa>>>0?aa:$;$=c[x>>2]|0;aa=Z+$&15;Z=c[n+236+(aa<<6)>>2]|0;if((aa|0)==($|0)|(Z|0)==0){yDb(c[y>>2]|0,16,1939480,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else{Z0a(n+44+(aa*12|0)|0,R,0);cf[c[F>>2]&1023](X,Z+(W-(c[n+236+(c[s>>2]<<6)+(J<<2)>>2]|0))|0,N,8);break}}else{ca=25}}while(0);if((ca|0)==25){ca=0;me[c[E>>2]&511](D);Z=c[q>>2]|0;aa=c[h>>2]|0;$=c[r>>2]|0;_=$+(Z>>>3)|0;Y=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Z&7)>>>24;_=Z+8|0;Z=aa>>>0>_>>>0?_:aa;c[q>>2]=Z;b[D>>1]=Y<<3;b:do{if(A){Y=1;_=Z;da=aa;ea=$;while(1){fa=c[w>>2]|0;ga=c[G>>2]|0;ha=ea+(_>>>3)|0;ia=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(_&7)>>>((32-ga|0)>>>0);ha=b[fa+(ia<<2)>>1]|0;ja=b[fa+(ia<<2)+2>>1]|0;ia=ja<<16>>16;do{if(ja<<16>>16<0){ka=ga+_|0;la=da>>>0>ka>>>0?ka:da;ka=ea+(la>>>3)|0;ma=((fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(la&7)>>>((ia+32|0)>>>0))+ha|0;ka=b[fa+(ma<<2)>>1]|0;na=b[fa+(ma<<2)+2>>1]|0;ma=na<<16>>16;if(!(na<<16>>16<0)){oa=ma;pa=ka;qa=la;break}na=la-ia|0;la=da>>>0>na>>>0?na:da;na=ea+(la>>>3)|0;ra=((fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(la&7)>>>((ma+32|0)>>>0))+ka|0;oa=b[fa+(ra<<2)+2>>1]|0;pa=b[fa+(ra<<2)>>1]|0;qa=la}else{oa=ia;pa=ha;qa=_}}while(0);ha=oa+qa|0;ia=da>>>0>ha>>>0?ha:da;c[q>>2]=ia;if((pa|0)==(-1|0)){ca=36;break a}else if((pa|0)==0){break b}ha=(pa&15)+Y|0;fa=pa>>>4;if(ha>>>0>63>>>0){ca=36;break a}ga=ea+(ia>>>3)|0;ja=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ia&7)>>>((32-fa|0)>>>0);ga=ia+fa|0;c[q>>2]=da>>>0>ga>>>0?ga:da;ga=a[133160+(fa<<6)+ja|0]|0;if(ha>>>0<3>>>0){sa=ga<<4&65535}else{sa=((ba(M,ga)|0)/1001|0)&65535}b[n+1264+(d[n+1416+ha|0]<<1)>>1]=sa;ga=ha+1|0;if(!(ga>>>0<k>>>0)){break b}Y=ga;_=c[q>>2]|0;da=c[h>>2]|0;ea=c[r>>2]|0}}}while(0);Xe[c[H>>2]&4095](X,N,D)}$=W+8|0;aa=X+8|0;Z=V+1|0;ea=c[P>>2]|0;if((Z|0)<(ea|0)){V=Z;W=$;X=aa}else{ta=$;ua=aa;va=ea;break}}}else{ta=S;ua=T;va=U}X=N-va<<3;W=R+1|0;Y0a(n+44+((c[x>>2]|0)*12|0)|0,R,0);V=L+1|0;if((V|0)<(c[O>>2]|0)){R=W;S=ta+X|0;T=ua+X|0;L=V}else{wa=W;break}}}else{wa=I}L=J+1|0;if((L|0)<3){I=wa;J=L}else{xa=0;break}}if((ca|0)==36){yDb(c[y>>2]|0,16,1967744,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;xa=-1094995529}Y0a(C+((c[x>>2]|0)*12|0)|0,2147483647,0);do{if((xa|0)<0){if((c[e+816>>2]&1|0)!=0){break}U0a(e,C+((c[x>>2]|0)*12|0)|0);p=xa;i=j;return p|0}}while(0);xa=MCb(f,c[C+((c[x>>2]|0)*12|0)>>2]|0)|0;if((xa|0)<0){p=xa;i=j;return p|0}c[g>>2]=1;c[s>>2]=c[u>>2];u=c[v>>2]|0;c[x>>2]=u;U0a(e,C+(u*12|0)|0);p=l;i=j;return p|0}function rLa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+60>>2]|0;$Db(b+28|0);c[b+32>>2]=0;d=b+44|0;e=0;do{f=d+(e*12|0)|0;g=f|0;if((c[g>>2]|0)!=0){U0a(a,f)}JCb(g);e=e+1|0;}while(e>>>0<16>>>0);if((c[c[a+64>>2]>>2]|0)!=0){return 0}Q_(b+2996|0);return 0}function sLa(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=0;i=0;j=1;while(1){k=a[f+j|0]|0;l=k&255;if(k<<24>>24==0){m=h;n=i}else{k=j&255;o=l>>>0>1>>>0?l:1;p=i+o|0;q=h;r=0;s=i;while(1){t=d[g+q|0]|0;a[c+t|0]=k;b[e+(t<<1)>>1]=s;t=r+1|0;if((t|0)<(l|0)){q=q+1|0;r=t;s=s+1|0}else{break}}m=h+o|0;n=p}s=j+1|0;if((s|0)<17){h=m;i=n<<1;j=s}else{break}}return}function tLa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;f=c[a+60>>2]|0;k=f;l=f+1144|0;c[l>>2]=0;m=f+2944|0;c[m>>2]=0;n=f+2948|0;c[n>>2]=0;o=f+2964|0;c[o>>2]=0;p=h+j|0;if((j|0)>268435455){q=-1094995529;i=g;return q|0}r=a;s=f+8|0;t=f+20|0;u=f+24|0;v=f+12|0;w=f+16|0;x=f+28|0;y=a+696|0;z=f+816|0;A=f+820|0;B=f+2960|0;C=h;D=j;a:while(1){E=D<<3;F=E>>>0>2147483639>>>0|(C|0)==0;G=F?0:C;H=F?8:E+8|0;E=H>>>0>32>>>0?32:H;F=G+(E>>>3)|0;I=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)&-65536;F=E+16|0;E=H>>>0>F>>>0?F:H;F=G+(E>>>3)|0;J=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>16;F=E+16|0;E=H>>>0>F>>>0?F:H;if((J|I|0)!=1835692135){K=4;break}I=G+(E>>>3)|0;J=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(E&7)&-65536;I=E+16|0;E=H>>>0>I>>>0?I:H;I=G+(E>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(E&7)>>>16;I=E+16|0;E=F|J;yDb(r,48,2108568,(L=i,i=i+8|0,c[L>>2]=E,L)|0);i=L;J=(H>>>0>I>>>0?I:H)+32|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;F=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)&-65536;J=I+16|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;M=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)>>>16;J=I+16|0;I=H>>>0>J>>>0?J:H;J=M|F;if(J>>>0<D>>>0){N=J}else{yDb(r,24,2050904,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;N=0}yDb(r,48,2005368,(L=i,i=i+8|0,c[L>>2]=N,L)|0);i=L;J=G+(I>>>3)|0;F=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)&-65536;J=I+16|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;M=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)>>>16;J=I+16|0;I=H>>>0>J>>>0?J:H;J=M|F;do{if(J>>>0<D>>>0){yDb(r,48,1939464,(L=i,i=i+8|0,c[L>>2]=J,L)|0);i=L;if((J|0)==0){break}F=C+J|0;M=p-F<<3;O=M>>>0>2147483639>>>0|(F|0)==0;P=O?0:F;F=O?0:M;c[s>>2]=P;c[t>>2]=F;c[u>>2]=F+8;c[v>>2]=P+(F>>3);c[w>>2]=0;c[x>>2]=219;if((wLa(k)|0)>=0){break}if((c[y>>2]&8|0)!=0){q=-1094995529;K=36;break a}}else{yDb(r,24,1967712,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;yDb(r,48,1939464,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L}}while(0);J=G+(I>>>3)|0;F=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)&-65536;J=I+16|0;P=H>>>0>J>>>0?J:H;J=G+(P>>>3)|0;M=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(P&7)>>>16;J=P+16|0;P=H>>>0>J>>>0?J:H;J=M|F;do{if(J>>>0<D>>>0){yDb(r,48,1894696,(L=i,i=i+8|0,c[L>>2]=J,L)|0);i=L;if((J|0)==0){break}F=C+J|0;M=p-F<<3;O=M>>>0>2147483639>>>0|(F|0)==0;Q=O?0:F;F=O?0:M;c[s>>2]=Q;c[t>>2]=F;c[u>>2]=F+8;c[v>>2]=Q+(F>>3);c[w>>2]=0;c[x>>2]=196;vLa(k)|0}else{yDb(r,24,1915264,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;yDb(r,48,1894696,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L}}while(0);J=G+(P>>>3)|0;I=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(P&7)&-65536;J=P+16|0;F=H>>>0>J>>>0?J:H;J=G+(F>>>3)|0;Q=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(F&7)>>>16;J=F+16|0;F=H>>>0>J>>>0?J:H;J=Q|I;do{if(J>>>0<D>>>0){yDb(r,48,2331728,(L=i,i=i+8|0,c[L>>2]=J,L)|0);i=L;if((J|0)==0){break}I=C+J|0;Q=p-I<<3;M=Q>>>0>2147483639>>>0|(I|0)==0;O=M?0:I;I=M?0:Q;c[s>>2]=O;c[t>>2]=I;c[u>>2]=I+8;c[v>>2]=O+(I>>3);c[w>>2]=0;c[x>>2]=192;if((yLa(k)|0)<0){q=-1;K=36;break a}}else{yDb(r,24,2351728,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;yDb(r,48,2331728,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L}}while(0);J=G+(F>>>3)|0;P=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(F&7)&-65536;J=F+16|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;O=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)>>>16;J=I+16|0;I=H>>>0>J>>>0?J:H;J=O|P;if(J>>>0<D>>>0){R=J}else{yDb(r,24,2307384,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;R=0}yDb(r,48,2289072,(L=i,i=i+8|0,c[L>>2]=R,L)|0);i=L;J=G+(I>>>3)|0;P=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)&-65536;J=I+16|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;O=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)>>>16|P;if(O>>>0<D>>>0){S=O}else{yDb(r,24,2351728,(L=i,i=i+16|0,c[L>>2]=O,c[L+8>>2]=D,L)|0);i=L;S=0}yDb(r,48,2272896,(L=i,i=i+8|0,c[L>>2]=S,L)|0);i=L;do{if((R|0)!=0){O=C+R|0;P=D-R|0;I=(E>>>0>P>>>0?P:E)<<3;P=I>>>0>2147483639>>>0|(O|0)==0;J=P?0:O;O=P?0:I;c[s>>2]=J;c[t>>2]=O;c[u>>2]=O+8;c[v>>2]=J+(O>>3);c[w>>2]=0;O=J;c[o>>2]=S-R-((fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)>>>16);c[x>>2]=218;if((zLa(k,0,0,0)|0)>=0){break}if((c[y>>2]&8|0)!=0){q=-1094995529;K=36;break a}}}while(0);if((c[z>>2]|0)==0){K=30;break}E=c[A>>2]^1;c[A>>2]=E;if((E|0)==(c[B>>2]|0)|(N|0)==0){K=30;break}c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;E=j-N|0;if((E|0)>268435455){q=-1094995529;K=36;break}else{C=h+N|0;D=E}}if((K|0)==4){yDb(r,24,2185752,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-1094995529;i=g;return q|0}else if((K|0)==30){if((c[l>>2]|0)==0){yDb(r,24,2257416,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=j;i=g;return q|0}l=MCb(b,c[f+1140>>2]|0)|0;if((l|0)<0){q=l;i=g;return q|0}c[e>>2]=1;if((c[f+824>>2]|0)!=0){q=j;i=g;return q|0}if((c[a+688>>2]&16|0)==0){q=j;i=g;return q|0}a=c[f+792>>2]|0;e=c[f+796>>2]|0;l=(a|0)>(e|0)?a:e;e=c[f+800>>2]|0;yDb(r,48,2243152,(L=i,i=i+8|0,c[L>>2]=(l|0)>(e|0)?l:e,L)|0);i=L;q=j;i=g;return q|0}else if((K|0)==36){i=g;return q|0}return 0}function uLa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;f=i;i=i+15360|0;g=f|0;h=f+256|0;j=f+768|0;k=f+1280|0;l=f+1536|0;m=f+2048|0;n=f+2560|0;o=f+2816|0;p=f+3328|0;q=f+3840|0;r=f+4096|0;s=f+4608|0;t=f+5120|0;u=f+5376|0;v=f+5888|0;w=f+6400|0;x=f+6656|0;y=f+7168|0;z=f+7680|0;A=f+7936|0;B=f+8448|0;C=f+8960|0;D=f+9216|0;E=f+9728|0;F=f+10240|0;G=f+10496|0;H=f+11008|0;I=f+11520|0;J=f+11776|0;K=f+12288|0;L=f+12800|0;M=f+13056|0;N=f+13568|0;O=f+14080|0;P=f+14336|0;Q=f+14848|0;R=c[e+60>>2]|0;S=R;T=R+1140|0;do{if((c[T>>2]|0)==0){U=ICb()|0;c[R+1136>>2]=U;if((U|0)==0){V=-12;i=f;return V|0}else{c[T>>2]=U;break}}}while(0);T=R+4|0;c[T>>2]=e;BFa(R+2736|0,c[e+88>>2]|0);Z3(R+1492|0,e);x2(R+2620|0,R+1360|0,1075976);c[R+32>>2]=0;c[R+36>>2]=0;c[R+28>>2]=-1;c[R+812>>2]=1;c[R+1144>>2]=0;c[R+808>>2]=c[e+132>>2];c[e+400>>2]=2;U=R+552|0;W=I|0;I=J;X=K;TGb(W|0,0,256)|0;sLa(W,J|0,1744176,1743824);J=0;do{b[K+(J<<1)>>1]=J;J=J+1|0;}while((J|0)<256);J=U;N_(J,9,12,W,1,1,I,2,2,X,2,2,0)|0;X=R+572|0;I=F|0;F=G;W=H;TGb(I|0,0,256)|0;sLa(I,G|0,1744200,1743824);G=0;do{b[H+(G<<1)>>1]=G;G=G+1|0;}while((G|0)<256);G=X;N_(G,9,12,I,1,1,F,2,2,W,2,2,0)|0;W=R+632|0;F=C|0;C=D;I=E;TGb(F|0,0,256)|0;sLa(F,D|0,1744224,1743840);D=0;do{b[E+(D<<1)>>1]=D+16;D=D+1|0;}while((D|0)<256);D=W;b[E>>1]=4096;N_(D,9,251,F,1,1,C,2,2,I,2,2,0)|0;I=R+652|0;C=z|0;z=A;F=B;TGb(C|0,0,256)|0;sLa(C,A|0,1744248,1744008);A=0;do{b[B+(A<<1)>>1]=A+16;A=A+1|0;}while((A|0)<256);A=I;b[B>>1]=4096;N_(A,9,251,C,1,1,z,2,2,F,2,2,0)|0;F=R+712|0;z=w|0;w=x;C=y;TGb(z|0,0,256)|0;sLa(z,x|0,1744224,1743840);x=0;do{b[y+(x<<1)>>1]=x;x=x+1|0;}while((x|0)<256);x=F;N_(x,9,251,z,1,1,w,2,2,C,2,2,0)|0;C=R+732|0;w=O|0;O=P;z=Q;TGb(w|0,0,256)|0;sLa(w,P|0,1744248,1744008);P=0;do{b[Q+(P<<1)>>1]=P;P=P+1|0;}while((P|0)<256);P=C;N_(P,9,251,w,1,1,O,2,2,z,2,2,0)|0;do{if((c[R+2984>>2]|0)!=0){z=e;yDb(z,32,2262384,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;O=c[e+96>>2]|0;w=c[e+100>>2]<<3;C=w>>>0>2147483639>>>0|(O|0)==0;Q=C?0:O;O=C?0:w;c[R+8>>2]=Q;c[R+20>>2]=O;c[R+24>>2]=O+8;c[R+12>>2]=Q+(O>>3);c[R+16>>2]=0;if((vLa(S)|0)==0){break}yDb(z,16,2321456,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;z=t|0;O=u;Q=v;TGb(z|0,0,256)|0;sLa(z,u|0,1744176,1743824);w=0;do{b[v+(w<<1)>>1]=w;w=w+1|0;}while((w|0)<256);N_(J,9,12,z,1,1,O,2,2,Q,2,2,0)|0;w=q|0;C=r;F=s;TGb(w|0,0,256)|0;sLa(w,r|0,1744200,1743824);y=0;do{b[s+(y<<1)>>1]=y;y=y+1|0;}while((y|0)<256);N_(G,9,12,w,1,1,C,2,2,F,2,2,0)|0;y=n|0;Q=o;O=p;TGb(y|0,0,256)|0;sLa(y,o|0,1744224,1743840);z=0;do{b[p+(z<<1)>>1]=z+16;z=z+1|0;}while((z|0)<256);b[p>>1]=4096;N_(D,9,251,y,1,1,Q,2,2,O,2,2,0)|0;z=k|0;F=l;C=m;TGb(z|0,0,256)|0;sLa(z,l|0,1744248,1744008);w=0;do{b[m+(w<<1)>>1]=w+16;w=w+1|0;}while((w|0)<256);b[m>>1]=4096;N_(A,9,251,z,1,1,F,2,2,C,2,2,0)|0;w=g|0;O=h;Q=j;TGb(w|0,0,256)|0;sLa(w,h|0,1744224,1743840);y=0;do{b[j+(y<<1)>>1]=y;y=y+1|0;}while((y|0)<256);N_(x,9,251,w,1,1,O,2,2,Q,2,2,0)|0;y=L|0;C=M;F=N;TGb(y|0,0,256)|0;sLa(y,M|0,1744248,1744008);z=0;do{b[N+(z<<1)>>1]=z;z=z+1|0;}while((z|0)<256);N_(P,9,251,y,1,1,C,2,2,F,2,2,0)|0}}while(0);P=c[e+408>>2]|0;do{if((P|0)==0){if((c[e+52>>2]|0)!=1196444237){break}c[R+2960>>2]=1}else if((P|0)==3){c[R+2960>>2]=1;yDb(e,48,2185728,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y}}while(0);P=c[e+100>>2]|0;do{if((P|0)>8){N=c[e+96>>2]|0;M=N;if((d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)!=44){break}M=N+4|0;if((d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)!=24){break}c[R+2952>>2]=1;M=(P|0)>14;do{if(M){L=N+12|0;x=a[L]|0;if(x<<24>>24==1){c[R+2960>>2]=1;Z=a[L]|0}else{Z=x}if(!(Z<<24>>24==2)){break}c[R+2960>>2]=0}}while(0);F=c[T>>2]|0;if((c[F+688>>2]&1|0)==0){break}if(M){_=d[N+12|0]|0}else{_=-1}yDb(F,32,2338232,(Y=i,i=i+16|0,c[Y>>2]=P,c[Y+8>>2]=_,Y)|0);i=Y}}while(0);if((c[(c[e+12>>2]|0)+12>>2]|0)!=108){V=0;i=f;return V|0}c[R+2972>>2]=1;V=0;i=f;return V|0}function vLa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+280|0;f=e|0;g=e+24|0;h=b+16|0;j=c[h>>2]|0;k=b+24|0;l=c[k>>2]|0;m=b+8|0;n=(c[m>>2]|0)+(j>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(j&7)>>>16;n=j+16|0;c[h>>2]=l>>>0>n>>>0?n:l;l=o-2|0;if((l|0)<=0){p=0;i=e;return p|0}o=b+4|0;n=f|0;j=g|0;q=l;while(1){if((q|0)<17){p=-1094995529;r=15;break}l=c[h>>2]|0;s=c[k>>2]|0;t=c[m>>2]|0;u=t+(l>>>3)|0;v=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(l&7);u=v>>>28;w=l+4|0;l=s>>>0>w>>>0?w:s;c[h>>2]=l;if(v>>>0>536870911>>>0){p=-1094995529;r=15;break}v=t+(l>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(l&7);v=w>>>28;x=l+4|0;l=s>>>0>x>>>0?x:s;c[h>>2]=l;if(w>>>0>1073741823>>>0){p=-1094995529;r=15;break}else{y=1;z=0;A=l}do{l=t+(A>>>3)|0;w=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(A&7)>>>24;l=A+8|0;A=s>>>0>l>>>0?l:s;c[h>>2]=A;a[f+y|0]=w;z=w+z|0;y=y+1|0;}while((y|0)<17);w=q-17|0;if((w|0)<(z|0)|(z|0)>256){p=-1094995529;r=15;break}if((z|0)>0){l=0;x=0;B=A;do{C=t+(B>>>3)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7)>>>24;C=B+8|0;B=s>>>0>C>>>0?C:s;c[h>>2]=B;x=(D|0)>(x|0)?D:x;a[g+l|0]=D;l=l+1|0;}while((l|0)<(z|0));E=x+1|0}else{E=1}l=w-z|0;B=b+552+(u*80|0)+(v*20|0)|0;Q_(B);yDb(c[o>>2]|0,48,1939432,(s=i,i=i+24|0,c[s>>2]=u,c[s+8>>2]=v,c[s+16>>2]=E,s)|0);i=s;s=(u|0)!=0;t=xLa(B,n,j,E,s&1)|0;if((t|0)<0){p=t;r=15;break}if(s){s=b+712+(v*20|0)|0;Q_(s);t=xLa(s,n,j,E,0)|0;if((t|0)<0){p=t;r=15;break}}if((l|0)>0){q=l}else{p=0;r=15;break}}if((r|0)==15){i=e;return p|0}return 0}function wLa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;f=a+16|0;g=c[f>>2]|0;h=a+24|0;j=c[h>>2]|0;k=a+8|0;l=c[k>>2]|0;m=l+(g>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(g&7)>>>16;m=g+16|0;g=j>>>0>m>>>0?m:j;c[f>>2]=g;m=n-2|0;if((m|0)<=64){o=0;i=e;return o|0}n=a+4|0;p=a+1365|0;q=a+1372|0;r=m;m=g;g=j;j=l;while(1){l=j+(m>>>3)|0;s=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7);l=m+4|0;t=g>>>0>l>>>0?l:g;c[f>>2]=t;if(s>>>0>536870911>>>0){u=4;break}l=j+(t>>>3)|0;v=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(t&7);l=v>>>28;w=t+4|0;c[f>>2]=g>>>0>w>>>0?w:g;if(v>>>0>1073741823>>>0){o=-1;u=10;break}yDb(c[n>>2]|0,48,2005352,(x=i,i=i+8|0,c[x>>2]=l,x)|0);i=x;v=s>>>0>268435455>>>0?16:8;s=32-v|0;w=0;do{t=d[a+1364+w|0]|0;y=c[f>>2]|0;z=c[h>>2]|0;A=(c[k>>2]|0)+(y>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7)>>>(s>>>0);A=y+v|0;c[f>>2]=z>>>0>A>>>0?A:z;b[a+40+(l<<7)+(t<<1)>>1]=B;w=w+1|0;}while((w|0)<64);w=b[a+40+(l<<7)+((d[p]|0)<<1)>>1]|0;v=b[a+40+(l<<7)+((d[q]|0)<<1)>>1]|0;s=(w<<16>>16>v<<16>>16?w:v)<<16>>16>>1;c[a+792+(l<<2)>>2]=s;yDb(c[n>>2]|0,48,1967696,(x=i,i=i+16|0,c[x>>2]=l,c[x+8>>2]=s,x)|0);i=x;s=r-65|0;if((s|0)<=64){o=0;u=10;break}r=s;m=c[f>>2]|0;g=c[h>>2]|0;j=c[k>>2]|0}if((u|0)==4){yDb(c[n>>2]|0,16,2050880,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;o=-1094995529;i=e;return o|0}else if((u|0)==10){i=e;return o|0}return 0}function xLa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+1280|0;j=h+256|0;k=h+768|0;l=h|0;TGb(l|0,0,256)|0;if((f|0)>=257){yDb(0,0,2218608,(m=i,i=i+24|0,c[m>>2]=2339544,c[m+8>>2]=2200656,c[m+16>>2]=56,m)|0);i=m;Cd();return 0}sLa(l,j|0,d,e);e=g<<4;d=0;do{b[k+(d<<1)>>1]=d+e;d=d+1|0;}while((d|0)<256);if((g|0)==0){n=j;o=k;p=N_(a,9,f,l,1,1,n,2,2,o,2,2,0)|0;i=h;return p|0}b[k>>1]=4096;n=j;o=k;p=N_(a,9,f,l,1,1,n,2,2,o,2,2,0)|0;i=h;return p|0}function yLa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;b=i;i=i+32|0;e=b|0;f=b+16|0;c[a+2968>>2]=0;g=a+848|0;c[g>>2]=0;h=a+840|0;c[h>>2]=0;j=a+16|0;k=c[j>>2]|0;l=a+24|0;m=c[l>>2]|0;n=a+8|0;o=c[n>>2]|0;p=o+(k>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(k&7)>>>16;p=k+16|0;k=m>>>0>p>>>0?p:m;c[j>>2]=k;p=o+(k>>>3)|0;r=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(k&7)>>>24;p=k+8|0;c[j>>2]=m>>>0>p>>>0?p:m;m=a+860|0;c[m>>2]=r;p=a+4|0;k=c[p>>2]|0;c[k+796>>2]=r;do{if((c[a+856>>2]|0)==0){if((c[m>>2]|0)!=9){break}c[a+852>>2]=1}else{c[m>>2]=9}}while(0);r=a+824|0;do{if((c[r>>2]|0)!=0){if((c[k+800>>2]|0)==0){break}yDb(k,16,1915216,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1;i=b;return t|0}}while(0);u=c[j>>2]|0;v=c[l>>2]|0;w=o+(u>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>16;w=u+16|0;u=v>>>0>w>>>0?w:v;c[j>>2]=u;w=o+(u>>>3)|0;o=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>16;w=u+16|0;c[j>>2]=v>>>0>w>>>0?w:v;v=a+816|0;do{if((c[v>>2]|0)==0){y=x}else{if((c[a+900>>2]|0)!=(o|0)){y=x;break}w=c[a+904>>2]|0;y=(w|0)==(x+1|0)?w:x}}while(0);yDb(k,48,1894672,(s=i,i=i+16|0,c[s>>2]=o,c[s+8>>2]=y,s)|0);i=s;if((hDb(o,y,0,c[p>>2]|0)|0)!=0){t=-1094995529;i=b;return t|0}k=c[j>>2]|0;x=c[l>>2]|0;w=c[n>>2]|0;u=w+(k>>>3)|0;z=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(k&7)>>>24;u=k+8|0;k=x>>>0>u>>>0?u:x;c[j>>2]=k;if((z-1|0)>>>0>3>>>0){t=-1;i=b;return t|0}do{if((c[v>>2]|0)!=0){if((c[a+820>>2]|0)!=((c[a+2960>>2]|0)==0|0)){break}if((z|0)==(c[a+916>>2]|0)){break}yDb(c[p>>2]|0,16,2351680,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=b;return t|0}}while(0);u=a+828|0;A=c[u>>2]|0;do{if((A|0)!=0){if((c[m>>2]|0)<9|(z|0)==1){break}EDb(c[p>>2]|0,2331672,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1163346256;i=b;return t|0}}while(0);B=a+916|0;c[B>>2]=z;C=a+1096|0;c[C>>2]=1;D=a+1100|0;c[D>>2]=1;E=e;TGb(E|0,0,16)|0;F=f;TGb(F|0,0,16)|0;do{if((z|0)==0){G=A}else{H=0;I=k;J=x;K=w;while(1){L=K+(I>>>3)|0;M=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(I&7)>>>24;L=I+8|0;c[j>>2]=J>>>0>L>>>0?L:J;L=a+936+(H<<2)|0;c[L>>2]=M-1;M=c[j>>2]|0;N=c[l>>2]|0;O=c[n>>2]|0;P=O+(M>>>3)|0;Q=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7)>>>28;P=M+4|0;M=N>>>0>P>>>0?P:N;c[j>>2]=M;c[e+(H<<2)>>2]=Q;P=O+(M>>>3)|0;R=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7)>>>28;P=M+4|0;M=N>>>0>P>>>0?P:N;c[j>>2]=M;c[f+(H<<2)>>2]=R;if((Q|0)>(c[C>>2]|0)){c[C>>2]=Q}if((R|0)>(c[D>>2]|0)){c[D>>2]=R}P=O+(M>>>3)|0;O=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7);P=O>>>24;S=M+8|0;c[j>>2]=N>>>0>S>>>0?S:N;c[a+1104+(H<<2)>>2]=P;if(O>>>0>67108863>>>0){T=26;break}if((Q|0)==0){U=R;T=29;break}if((R|0)==0){U=0;T=29;break}O=c[L>>2]|0;yDb(c[p>>2]|0,48,2272856,(s=i,i=i+40|0,c[s>>2]=H,c[s+8>>2]=Q,c[s+16>>2]=R,c[s+24>>2]=O,c[s+32>>2]=P,s)|0);i=s;P=H+1|0;if((P|0)>=(z|0)){T=32;break}H=P;I=c[j>>2]|0;J=c[l>>2]|0;K=c[n>>2]|0}if((T|0)==26){yDb(c[p>>2]|0,16,2307360,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=b;return t|0}else if((T|0)==29){yDb(c[p>>2]|0,16,2289024,(s=i,i=i+24|0,c[s>>2]=H,c[s+8>>2]=Q,c[s+16>>2]=U,s)|0);i=s;t=-1094995529;i=b;return t|0}else if((T|0)==32){G=c[u>>2]|0;break}}}while(0);do{if((G|0)!=0){if((c[C>>2]|0)<=1){if((c[D>>2]|0)<=1){break}}EDb(c[p>>2]|0,2257392,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1163346256;i=b;return t|0}}while(0);G=a+900|0;U=a+904|0;do{if((o|0)==(c[G>>2]|0)){if((y|0)!=(c[U>>2]|0)){T=42;break}if((PGb(a+952|0,E,16)|0)!=0){T=42;break}if((PGb(a+968|0,F,16)|0)!=0){T=42;break}V=y;W=a+1144|0}else{T=42}}while(0);do{if((T|0)==42){c[G>>2]=o;c[U>>2]=y;Q=a+952|0;c[Q>>2]=c[E>>2];c[Q+4>>2]=c[E+4>>2];c[Q+8>>2]=c[E+8>>2];c[Q+12>>2]=c[E+12>>2];Q=a+968|0;c[Q>>2]=c[F>>2];c[Q+4>>2]=c[F+4>>2];c[Q+8>>2]=c[F+8>>2];c[Q+12>>2]=c[F+12>>2];c[v>>2]=0;Q=a+1144|0;c[Q>>2]=0;n=a+812|0;do{if((c[n>>2]|0)==0){X=y}else{l=c[a+808>>2]|0;if((l|0)==0){X=y;break}if((y|0)>=((l*3|0|0)/4|0|0)){X=y;break}c[v>>2]=1;l=a+2960|0;c[a+820>>2]=c[l>>2];j=c[a+1140>>2]|0;c[j+296>>2]=1;c[j+300>>2]=(c[l>>2]|0)==0;X=y<<1}}while(0);H=V$a(c[p>>2]|0,o,X)|0;if((H|0)<0){t=H;i=b;return t|0}else{c[n>>2]=0;V=X;W=Q;break}}}while(0);do{if((c[W>>2]|0)==0){T=53}else{if((c[v>>2]|0)==0){T=53;break}if((c[a+820>>2]|0)!=((c[a+2960>>2]|0)==0|0)){T=53;break}if((c[a+832>>2]|0)==0){break}DDb(c[p>>2]|0,2243112,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=b;return t|0}}while(0);do{if((T|0)==53){do{if((c[D>>2]|0)==1){if((c[C>>2]|0)!=1){T=58;break}X=c[r>>2]|0;if((X|0)!=1){Y=X;T=59;break}if(!((z-3|0)>>>0<2>>>0)){T=58;break}c[a+836>>2]=1}else{T=58}}while(0);if((T|0)==58){Y=c[r>>2]|0;T=59}do{if((T|0)==59){if((Y|0)!=0){break}c[a+836>>2]=0}}while(0);Q=c[a+968>>2]<<24|c[a+952>>2]<<28|c[a+956>>2]<<20|c[a+972>>2]<<16|c[a+960>>2]<<12|c[a+976>>2]<<8|c[a+964>>2]<<4|c[a+980>>2];yDb(c[p>>2]|0,48,2230680,(s=i,i=i+8|0,c[s>>2]=Q,s)|0);i=s;if((Q&-791621424|0)==0){Z=Q-(Q>>>1&2021161080)|0}else{Z=Q}if((Z&218959117|0)==0){_=Z-(Z>>>1&126322567)|0}else{_=Z}do{if((_|0)==554766592){Q=c[m>>2]|0;if((Q|0)<9){n=c[a+2956>>2]|0;X=c[p>>2]|0;c[X+140>>2]=(n|0)!=0?4:13;$=n;aa=X}else{X=c[p>>2]|0;c[X+140>>2]=56;$=c[a+2956>>2]|0;aa=X}c[aa+396>>2]=($|0)!=0?1:2;ca=aa;da=Q}else if((_|0)==285212672|(_|0)==318767104|(_|0)==335544320|(_|0)==822083584|(_|0)==855638016|(_|0)==872415232|(_|0)==1090519040|(_|0)==1124073472|(_|0)==1140850688){Q=c[m>>2]|0;X=c[p>>2]|0;n=X+140|0;if((Q|0)<9){c[n>>2]=8;ca=X;da=Q;break}else{c[n>>2]=32;ca=X;da=Q;break}}else if((_|0)==286331153){do{if((c[a+836>>2]|0)==0){Q=c[m>>2]|0;if((c[a+872>>2]|0)==0&(Q|0)<9){X=c[p>>2]|0;c[X+140>>2]=317;ea=X;fa=Q;break}else{X=c[p>>2]|0;c[X+140>>2]=(Q|0)<9?299:108;c[X+396>>2]=(c[a+2956>>2]|0)!=0?1:2;ea=X;fa=Q;break}}else{Q=c[m>>2]|0;X=c[p>>2]|0;c[X+140>>2]=(Q|0)<10?29:292;ea=X;fa=Q}}while(0);if((c[B>>2]|0)==4){ca=ea;da=fa;break}yDb(0,0,2218608,(s=i,i=i+24|0,c[s>>2]=2192136,c[s+8>>2]=2200656,c[s+16>>2]=409,s)|0);i=s;Cd();return 0}else if((_|0)==303173888|(_|0)==571613440){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}X=(c[a+2956>>2]|0)!=0;n=c[p>>2]|0;c[n+140>>2]=X?5:14;c[n+396>>2]=X?1:2;c[g>>2]=2;c[h>>2]=(_|0)==571613440;c[a+844>>2]=c[a+904>>2];ca=n;da=Q}else if((_|0)==555815168|(_|0)==572592640){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}n=(c[a+2956>>2]|0)!=0;X=c[p>>2]|0;c[X+140>>2]=n?5:14;c[X+396>>2]=n?1:2;c[g>>2]=(_|0)==572592640;c[h>>2]=2;c[a+844>>2]=c[a+904>>2];ca=X;da=Q}else if((_|0)==286331136){a:do{if((c[a+836>>2]|0)==0){do{if((c[a+936>>2]|0)==81){if((c[a+940>>2]|0)!=70){break}if((c[a+944>>2]|0)!=65){break}Q=c[m>>2]|0;X=c[p>>2]|0;c[X+140>>2]=(Q|0)<9?82:88;ga=X;ha=Q;break a}}while(0);Q=c[m>>2]|0;if((Q|0)<9){X=c[a+2956>>2]|0;n=c[p>>2]|0;c[n+140>>2]=(X|0)!=0?5:14;ia=X;ja=n}else{n=c[p>>2]|0;c[n+140>>2]=58;ia=c[a+2956>>2]|0;ja=n}c[ja+396>>2]=(ia|0)!=0?1:2;ga=ja;ha=Q}else{Q=c[m>>2]|0;n=c[p>>2]|0;c[n+140>>2]=(Q|0)<10?3:68;ga=n;ha=Q}}while(0);if((c[B>>2]|0)==3){ca=ga;da=ha;break}yDb(0,0,2218608,(s=i,i=i+24|0,c[s>>2]=2209232,c[s+8>>2]=2200656,c[s+16>>2]=396,s)|0);i=s;Cd();return 0}else if((_|0)==303108352|(_|0)==572592384|(_|0)==571547904){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}n=(c[a+2956>>2]|0)!=0;X=c[p>>2]|0;c[X+140>>2]=n?33:34;c[X+396>>2]=n?1:2;c[h>>2]=((_|0)==572592384)<<1|(_|0)==571547904;c[a+844>>2]=(c[a+904>>2]|0)/2|0;ca=X;da=Q}else if((_|0)==571543808){Q=c[m>>2]|0;if((Q|0)<9){X=c[a+2956>>2]|0;n=c[p>>2]|0;c[n+140>>2]=(X|0)!=0?0:12;ka=X;la=n}else{n=c[p>>2]|0;c[n+140>>2]=54;ka=c[a+2956>>2]|0;la=n}c[la+396>>2]=(ka|0)!=0?1:2;ca=la;da=Q}else if((_|0)==1091637504){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}n=(c[a+2956>>2]|0)!=0;X=c[p>>2]|0;c[X+140>>2]=n?7:320;c[X+396>>2]=n?1:2;ca=X;da=Q}else if((_|0)==571609344|(_|0)==571544064){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}X=(c[a+2956>>2]|0)!=0;n=c[p>>2]|0;c[n+140>>2]=X?4:13;c[n+396>>2]=X?1:2;c[g>>2]=(_|0)==571609344?2:1;ca=n;da=Q}else if((_|0)==572657920){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}n=(c[a+2956>>2]|0)!=0;X=c[p>>2]|0;c[X+140>>2]=n?5:14;c[X+396>>2]=n?1:2;c[g>>2]=2;c[h>>2]=2;c[a+844>>2]=(c[a+904>>2]|0)/2|0;ca=X;da=Q}else{T=108}}while(0);if((T|0)==108){yDb(c[p>>2]|0,16,2175800,(s=i,i=i+8|0,c[s>>2]=_,s)|0);i=s;t=-1163346256;i=b;return t|0}if((c[h>>2]|0)==0){if((c[g>>2]|0)!=0){T=111}}else{T=111}do{if((T|0)==111){if((c[ca+800>>2]|0)==0){break}yDb(ca,16,2165360,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1163346256;i=b;return t|0}}while(0);do{if((c[u>>2]|0)==0){ma=c[ca+140>>2]|0}else{c[g>>2]=0;c[h>>2]=0;if((c[B>>2]|0)>1){c[ca+140>>2]=2;ma=2;break}Q=ca+140|0;if((da|0)<9){c[Q>>2]=8;ma=8;break}else{c[Q>>2]=32;ma=32;break}}}while(0);Q=bFb(ma)|0;c[a+2996>>2]=Q;if((Q|0)==0){yDb(c[p>>2]|0,16,2158704,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-558323010;i=b;return t|0}Q=a+1140|0;KCb(c[Q>>2]|0);if((_$a(c[p>>2]|0,c[Q>>2]|0,1)|0)<0){t=-1;i=b;return t|0}X=c[Q>>2]|0;c[X+88>>2]=1;c[X+84>>2]=1;c[W>>2]=1;Q=c[v>>2]|0;c[a+1148>>2]=c[X+32>>2]<<Q;c[a+1152>>2]=c[X+36>>2]<<Q;c[a+1156>>2]=c[X+40>>2]<<Q;c[a+1160>>2]=c[X+44>>2]<<Q;if((q|0)==((z*3|0)+8|0)){break}yDb(c[p>>2]|0,48,2151608,(s=i,i=i+8|0,c[s>>2]=q,s)|0);i=s}}while(0);do{if((c[a+836>>2]|0)!=0){if((c[r>>2]|0)!=0){break}if((c[u>>2]|0)!=0){break}yDb(c[p>>2]|0,16,2144568,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1163346256;i=b;return t|0}}while(0);if((c[a+832>>2]|0)==0){t=0;i=b;return t|0}s=c[C>>2]<<3;C=(o-1+s|0)/(s|0)|0;s=c[D>>2]<<3;b:do{if((c[B>>2]|0)>0){D=ba((V-1+s|0)/(s|0)|0,C)|0;o=0;while(1){p=a+952+(o<<2)|0;u=ba(D,c[p>>2]|0)|0;r=ba(u,c[a+968+(o<<2)>>2]|0)|0;u=a+1296+(o<<2)|0;$Db(u);q=a+1312+(o<<2)|0;$Db(q);c[u>>2]=cEb(r<<7)|0;z=cEb(r)|0;c[q>>2]=z;if((c[u>>2]|0)==0|(z|0)==0){t=-12;break}c[a+920+(o<<2)>>2]=ba(c[p>>2]|0,C)|0;o=o+1|0;if((o|0)>=(c[B>>2]|0)){break b}}i=b;return t|0}}while(0);TGb(a+1328|0,0,32)|0;t=0;i=b;return t|0}function zLa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0;k=i;i=i+64|0;l=k|0;m=k+16|0;n=k+32|0;o=k+48|0;p=f+824|0;q=(c[p>>2]|0)!=0?1:8;if((c[f+1144>>2]|0)==0){yDb(c[f+4>>2]|0,24,2138944,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1;i=k;return s|0}t=f+1140|0;if((c[c[t>>2]>>2]|0)==0){yDb(0,0,2218608,(r=i,i=i+24|0,c[r>>2]=2132712,c[r+8>>2]=2200656,c[r+16>>2]=1312,r)|0);i=r;Cd();return 0}u=f+16|0;v=c[u>>2]|0;w=f+24|0;y=c[w>>2]|0;z=f+8|0;A=c[z>>2]|0;B=A+(v>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7)>>>16;B=v+16|0;v=y>>>0>B>>>0?B:y;c[u>>2]=v;B=A+(v>>>3)|0;D=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7);B=D>>>24;E=v+8|0;v=y>>>0>E>>>0?E:y;c[u>>2]=v;if((B|0)==0|D>>>0>83886079>>>0){yDb(c[f+4>>2]|0,16,2126304,(r=i,i=i+8|0,c[r>>2]=B,r)|0);i=r;s=-1163346256;i=k;return s|0}if((C|0)!=((B<<1)+6|0)){yDb(c[f+4>>2]|0,16,2120504,(r=i,i=i+8|0,c[r>>2]=C,r)|0);i=r;s=-1094995529;i=k;return s|0}C=A+(v>>>3)|0;A=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(v&7)>>>24;C=v+8|0;c[u>>2]=y>>>0>C>>>0?C:y;y=f+4|0;C=f+916|0;v=(B|0)==3;E=f+832|0;G=f+1016|0;H=(B|0)==1;I=0;J=A;while(1){A=J-1|0;yDb(c[y>>2]|0,48,2114344,(r=i,i=i+8|0,c[r>>2]=A,r)|0);i=r;K=c[C>>2]|0;L=0;while(1){if((L|0)>=(K|0)){break}if((A|0)==(c[f+936+(L<<2)>>2]|0)){break}else{L=L+1|0}}M=c[y>>2]|0;if((L|0)==(K|0)){N=14;break}A=(I|0)==0|(c[M+52>>2]|0)==1246975053&v&(K|0)==3^1?L:3-I|0;c[f+1080+(I<<2)>>2]=c[f+1104+(A<<2)>>2];O=f+952+(A<<2)|0;P=f+968+(A<<2)|0;c[f+1032+(I<<2)>>2]=ba(c[P>>2]|0,c[O>>2]|0)|0;c[f+1048+(I<<2)>>2]=c[O>>2];c[f+1064+(I<<2)>>2]=c[P>>2];do{if(v){if((c[C>>2]|0)!=3){Q=A;break}if((c[(c[y>>2]|0)+140>>2]|0)!=82){Q=A;break}Q=(I+2|0)%3|0}else{if(!H){Q=A;break}if((c[C>>2]|0)!=3){Q=A;break}if((c[(c[y>>2]|0)+140>>2]|0)!=82){Q=A;break}Q=(A+2|0)%3|0}}while(0);c[f+984+(I<<2)>>2]=Q;A=c[u>>2]|0;L=c[w>>2]|0;P=(c[z>>2]|0)+(A>>>3)|0;O=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(A&7)>>>28;P=A+4|0;c[u>>2]=L>>>0>P>>>0?P:L;L=f+1e3+(I<<2)|0;c[L>>2]=O;O=c[u>>2]|0;P=c[w>>2]|0;A=(c[z>>2]|0)+(O>>>3)|0;R=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(O&7);A=R>>>28;S=O+4|0;c[u>>2]=P>>>0>S>>>0?S:P;c[f+1016+(I<<2)>>2]=A;P=c[L>>2]|0;if(P>>>0>3>>>0|R>>>0>1073741823>>>0){N=374;break}if((c[f+552+(P*20|0)+4>>2]|0)==0){N=374;break}if((c[E>>2]|0)==0){if((c[f+632+(A*20|0)+4>>2]|0)==0){N=374;break}}else{if((c[f+712+((c[G>>2]|0)*20|0)+4>>2]|0)==0){N=374;break}}A=I+1|0;P=c[u>>2]|0;T=c[w>>2]|0;U=c[z>>2]|0;R=U+(P>>>3)|0;V=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(P&7)>>>24;R=P+8|0;W=T>>>0>R>>>0?R:T;c[u>>2]=W;if((A|0)<(B|0)){I=A;J=V}else{N=29;break}}if((N|0)==14){yDb(M,16,2100168,(r=i,i=i+8|0,c[r>>2]=K,r)|0);i=r;s=-1094995529;i=k;return s|0}else if((N|0)==29){K=U+(W>>>3)|0;M=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(W&7);K=M>>>24;J=W+8|0;W=T>>>0>J>>>0?J:T;c[u>>2]=W;J=c[y>>2]|0;if((c[J+52>>2]|0)==1196444227){X=0;Y=0}else{I=U+(W>>>3)|0;G=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(W&7)>>>28;I=W+4|0;W=T>>>0>I>>>0?I:T;c[u>>2]=W;I=U+(W>>>3)|0;U=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(W&7)>>>28;I=W+4|0;c[u>>2]=T>>>0>I>>>0?I:T;X=G;Y=U}do{if(D>>>0>33554431>>>0){U=ba(c[f+1096>>2]|0,q)|0;c[f+908>>2]=((c[f+900>>2]|0)-1+U|0)/(U|0)|0;U=ba(c[f+1100>>2]|0,q)|0;c[f+912>>2]=((c[f+904>>2]|0)-1+U|0)/(U|0)|0}else{if((c[f+828>>2]|0)!=0){break}U=f+1048|0;G=f+1064|0;T=(c[f+1100>>2]|0)/(c[G>>2]|0)|0;I=ba((c[f+1096>>2]|0)/(c[U>>2]|0)|0,q)|0;c[f+908>>2]=(I-1+(c[f+900>>2]|0)|0)/(I|0)|0;I=ba(T,q)|0;c[f+912>>2]=(I-1+(c[f+904>>2]|0)|0)/(I|0)|0;c[f+1032>>2]=1;c[U>>2]=1;c[G>>2]=1}}while(0);if((c[J+688>>2]&1|0)==0){Z=f+2964|0}else{q=(c[f+836>>2]|0)!=0?2073184:9203288;D=c[f+860>>2]|0;G=f+2964|0;U=c[G>>2]|0;if((c[f+856>>2]|0)==0){_=(c[f+852>>2]|0)!=0?2060280:9203288}else{_=2064216}yDb(J,48,2088232,(r=i,i=i+72|0,c[r>>2]=(c[p>>2]|0)!=0?2083608:2077968,c[r+8>>2]=q,c[r+16>>2]=V,c[r+24>>2]=Y,c[r+32>>2]=K,c[r+40>>2]=D,c[r+48>>2]=U,c[r+56>>2]=_,c[r+64>>2]=B,r)|0);i=r;Z=G}G=c[Z>>2]|0;if((G|0)>0){Z=c[w>>2]|0;_=G;G=c[u>>2]|0;do{U=G+8|0;G=Z>>>0>U>>>0?U:Z;_=_-1|0;}while((_|0)>0);c[u>>2]=G}G=f+860|0;_=f+832|0;Z=(V|0)==0;U=(g|0)!=0;D=f+908|0;q=f+912|0;J=f+2948|0;I=(j|0)==0;T=f+2944|0;W=f+20|0;E=f+816|0;Q=f+2752|0;C=f+1528|0;H=f+1168|0;v=f+8|0;A=f+2612|0;R=(X|0)==0;X=f+820|0;P=f+1136|0;L=f+984|0;S=f+1080|0;O=K>>>0<V>>>0|M>>>0>1073741823>>>0;M=(Y|0)==0;$=_Gb(1,0,K+1|0)|0;aa=F;ca=_Gb(1,0,V|0)|0;da=ZGb($,aa,ca,F)|0;ca=F;aa=f+1016|0;$=f+1364+K|0;ea=K&255;fa=f+12|0;ga=f+828|0;ha=f+836|0;ia=(B-1|0)>>>0<4>>>0;ja=f+1148|0;ka=f+916|0;la=f+1100|0;ma=f+1096|0;na=f+2976|0;oa=na;pa=f+2980|0;qa=f+852|0;ra=f+856|0;sa=o|0;ta=l|0;ua=o+4|0;va=l+4|0;wa=o+8|0;xa=l+8|0;ya=o+12|0;za=l+12|0;Aa=0;a:while(1){if((Aa|0)<(B|0)){c[f+1120+(Aa<<2)>>2]=4<<c[G>>2];Aa=Aa+1|0;continue}b:do{if((c[p>>2]|0)==0){if((c[_>>2]|0)==0|Z){Ba=(c[G>>2]|0)>8?2:1;do{if(U){Ca=ba(c[q>>2]|0,c[D>>2]|0)|0;if((Ca+7>>3|0)==(h|0)){Da=Ca>>>0>2147483639>>>0;Ea=Da?0:g;Fa=Da?8:Ca+8|0;N=306;break}else{yDb(c[y>>2]|0,16,1881552,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;Ga=-1094995529;break}}else{Ea=0;Fa=0;N=306}}while(0);c:do{if((N|0)==306){N=0;c[J>>2]=0;Ca=0;do{Da=c[f+984+(Ca<<2)>>2]|0;c[m+(Da<<2)>>2]=c[(c[t>>2]|0)+(Da<<2)>>2];if(I){Ha=0}else{Ha=c[j+(Da<<2)>>2]|0}c[n+(Da<<2)>>2]=Ha;c[o+(Da<<2)>>2]=c[f+1148+(Da<<2)>>2];Ia=f+1328+(Da<<3)|0;Da=c[Ia+4>>2]|0;c[Ia>>2]=c[Ia>>2]|1;c[Ia+4>>2]=Da;Ca=Ca+1|0;}while((Ca|0)<(B|0));Ca=c[q>>2]|0;if((Ca|0)<=0){Ga=0;break}Da=0;Ia=0;Ja=c[D>>2]|0;Ka=Ca;d:while(1){if((Ja|0)>0){Ca=Da;La=0;while(1){if(U){Ma=(d[Ea+(Ca>>>3)|0]&128>>>((Ca&7)>>>0)|0)==0;Na=((Ca|0)<(Fa|0))+Ca|0}else{Ma=0;Na=Ca}Oa=c[T>>2]|0;do{if((Oa|0)!=0){if((c[J>>2]|0)!=0){break}c[J>>2]=Oa}}while(0);Pa=(c[W>>2]|0)-(c[u>>2]|0)|0;if((Pa|0)<0){N=319;break d}else{Qa=0}do{Oa=c[f+1032+(Qa<<2)>>2]|0;Ra=c[f+984+(Qa<<2)>>2]|0;Sa=c[f+1048+(Qa<<2)>>2]|0;e:do{if((Oa|0)>0){Ta=c[o+(Ra<<2)>>2]|0;Ua=ba(c[f+1064+(Qa<<2)>>2]|0,Ia)|0;Va=ba(Sa,La)|0;Wa=c[m+(Ra<<2)>>2]|0;Xa=n+(Ra<<2)|0;Ya=f+1e3+(Qa<<2)|0;Za=f+1016+(Qa<<2)|0;_a=f+1080+(Qa<<2)|0;$a=f+1120+(Qa<<2)|0;ab=f+920+(Ra<<2)|0;bb=f+1296+(Ra<<2)|0;cb=Ta>>1;db=Ta<<1;eb=db+Ta|0;fb=0;gb=0;hb=1;while(1){ib=gb+Ua|0;jb=fb+Va|0;kb=(ba(jb,Ba)|0)+(ba(ib,Ta)|0)<<3;lb=c[(c[y>>2]|0)+800>>2]|0;mb=kb>>lb;if((c[E>>2]|0)==0){nb=mb}else{nb=((c[X>>2]|0)==0?0:cb)+mb|0}mb=Wa+nb|0;f:do{if((c[_>>2]|0)==0){if(Ma){kb=c[Xa>>2]|0;ob=kb+nb|0;if((lb|0)==0){cf[c[Q>>2]&1023](mb,ob,Ta,8);break}else if((lb|0)==1){pb=ob;qb=mb;x=d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0;a[qb]=x;x=x>>8;a[qb+1|0]=x;x=x>>8;a[qb+2|0]=x;x=x>>8;a[qb+3|0]=x;qb=nb+Ta|0;pb=kb+qb|0;rb=Wa+qb|0;x=d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0;a[rb]=x;x=x>>8;a[rb+1|0]=x;x=x>>8;a[rb+2|0]=x;x=x>>8;a[rb+3|0]=x;rb=nb+db|0;pb=kb+rb|0;qb=Wa+rb|0;x=d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0;a[qb]=x;x=x>>8;a[qb+1|0]=x;x=x>>8;a[qb+2|0]=x;x=x>>8;a[qb+3|0]=x;qb=eb+nb|0;pb=kb+qb|0;rb=Wa+qb|0;x=d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0;a[rb]=x;x=x>>8;a[rb+1|0]=x;x=x>>8;a[rb+2|0]=x;x=x>>8;a[rb+3|0]=x;break}else if((lb|0)==2){rb=ob;pb=mb;x=(d[rb]|d[rb+1|0]<<8)<<16>>16;a[pb]=x;x=x>>8;a[pb+1|0]=x;pb=nb+Ta|0;rb=kb+pb|0;kb=Wa+pb|0;x=(d[rb]|d[rb+1|0]<<8)<<16>>16;a[kb]=x;x=x>>8;a[kb+1|0]=x;break}else if((lb|0)==3){a[mb]=a[ob]|0;break}else{break}}me[c[C>>2]&511](H);ob=c[Za>>2]|0;kb=c[_a>>2]|0;rb=FLa(f,c[Ya>>2]|0)|0;if((rb|0)==1048575){N=332;break d}pb=ba(b[f+40+(kb<<7)>>1]|0,rb)|0;rb=pb+(c[$a>>2]|0)|0;c[$a>>2]=rb;b[H>>1]=rb;rb=c[w>>2]|0;pb=c[v>>2]|0;qb=c[f+632+(ob*20|0)+4>>2]|0;ob=0;sb=c[u>>2]|0;while(1){tb=pb+(sb>>>3)|0;ub=(fe(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(sb&7);tb=ub>>>23;vb=b[qb+(tb<<2)>>1]|0;wb=b[qb+(tb<<2)+2>>1]|0;tb=wb<<16>>16;if(wb<<16>>16<0){wb=sb+9|0;xb=rb>>>0>wb>>>0?wb:rb;wb=pb+(xb>>>3)|0;yb=(fe(d[wb]|d[wb+1|0]<<8|d[wb+2|0]<<16|d[wb+3|0]<<24|0)|0)<<(xb&7);wb=(yb>>>((tb+32|0)>>>0))+vb|0;zb=b[qb+(wb<<2)>>1]|0;Ab=b[qb+(wb<<2)+2>>1]|0;Bb=yb;Cb=xb}else{zb=vb;Ab=tb;Bb=ub;Cb=sb}ub=Ab+Cb|0;tb=rb>>>0>ub>>>0?ub:rb;Db=(zb>>>4)+ob|0;ub=zb&15;if((ub|0)==0){Eb=tb}else{if(ub>>>0>9>>>0){vb=pb+(tb>>>3)|0;Fb=(fe(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(tb&7)}else{Fb=Bb<<Ab}vb=(Fb^-2147483648)>>31;xb=tb+ub|0;if((Db|0)>63){N=340;break d}tb=d[f+1364+Db|0]|0;b[f+1168+(tb<<1)>>1]=ba(b[f+40+(kb<<7)+(tb<<1)>>1]|0,((vb^Fb)>>>((32-ub|0)>>>0)^vb)-vb|0)|0;Eb=rb>>>0>xb>>>0?xb:rb}if((Db|0)<63){ob=Db;sb=Eb}else{break}}c[u>>2]=Eb;Xe[c[A>>2]&4095](mb,Ta,H);sb=c[G>>2]|0;if((sb&7|0)==0){break}ob=8>>>((c[(c[y>>2]|0)+800>>2]|0)>>>0);rb=(ob|0)>0;if((sb|0)<=8){if(rb){Gb=0}else{break}while(1){kb=(ba(Gb,Ta)|0)+nb|0;pb=0;do{qb=Wa+(kb+pb)|0;a[qb]=d[qb]<<8-(c[G>>2]|0);pb=pb+1|0;}while((pb|0)<(ob|0));Gb=Gb+1|0;if((Gb|0)>=(ob|0)){break f}}}if(!rb){break}pb=16-sb|0;kb=0;do{qb=(ba(kb,Ta)|0)+nb|0;xb=0;do{vb=Wa+(qb+(xb<<1))|0;b[vb>>1]=e[vb>>1]<<pb;xb=xb+1|0;}while((xb|0)<(ob|0));kb=kb+1|0;}while((kb|0)<(ob|0))}else{ob=(ba(c[ab>>2]|0,ib)|0)+jb|0;kb=(c[bb>>2]|0)+(ob<<7)|0;if(!R){ob=c[u>>2]|0;pb=d[(c[v>>2]|0)+(ob>>>3)|0]<<(ob&7)>>>7;c[u>>2]=((ob|0)<(c[w>>2]|0))+ob;b[kb>>1]=((b[f+40+(c[_a>>2]<<7)>>1]&-(pb&1))<<Y)+(e[kb>>1]|0);break}pb=c[Ya>>2]|0;ob=c[_a>>2]|0;me[c[C>>2]&511](kb);sb=FLa(f,pb)|0;if((sb|0)==1048575){N=359;break d}pb=(ba(b[f+40+(ob<<7)>>1]|0,sb)|0)<<Y;sb=pb+(c[$a>>2]|0)|0;c[$a>>2]=sb;b[kb>>1]=sb}}while(0);jb=fb+1|0;ib=(jb|0)==(Sa|0);if((hb|0)>=(Oa|0)){break e}fb=ib?0:jb;gb=(ib&1)+gb|0;hb=hb+1|0}}}while(0);Qa=Qa+1|0;}while((Qa|0)<(B|0));ELa(f,B)|0;Oa=La+1|0;Hb=c[D>>2]|0;if((Oa|0)<(Hb|0)){Ca=Na;La=Oa}else{break}}Ib=Na;Jb=Hb;Kb=c[q>>2]|0}else{Ib=Da;Jb=Ja;Kb=Ka}Ca=Ia+1|0;if((Ca|0)<(Kb|0)){Da=Ib;Ia=Ca;Ja=Jb;Ka=Kb}else{Ga=0;break c}}if((N|0)==319){N=0;yDb(c[y>>2]|0,16,1880280,(r=i,i=i+8|0,c[r>>2]=-Pa,r)|0);i=r;Ga=-1094995529;break}else if((N|0)==332){N=0;yDb(c[y>>2]|0,16,2354616,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}else if((N|0)==340){N=0;yDb(c[y>>2]|0,16,2346272,(r=i,i=i+8|0,c[r>>2]=Db,r)|0);i=r}else if((N|0)==359){N=0;yDb(c[y>>2]|0,16,2354616,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;yDb(c[y>>2]|0,16,2355864,(r=i,i=i+16|0,c[r>>2]=Ia,c[r+8>>2]=La,r)|0);i=r;Ga=-1094995529;break}yDb(c[y>>2]|0,16,2355864,(r=i,i=i+16|0,c[r>>2]=Ia,c[r+8>>2]=La,r)|0);i=r;Ga=-1094995529}}while(0);if((Ga|0)<0){s=Ga;N=375;break a}else{break}}Ba=c[t>>2]|0;if((Ba|0)!=(c[P>>2]|0)){N=211;break a}Ka=c[L>>2]|0;Ja=c[Ba+(Ka<<2)>>2]|0;Ba=c[f+1148+(Ka<<2)>>2]|0;Da=c[S>>2]|0;Ca=(c[G>>2]|0)>8?16:8;if(O){N=213;break a}if(M){Oa=f+1328+(Ka<<3)|0;Sa=c[Oa>>2]|da;Ra=c[Oa+4>>2]|ca;c[Oa>>2]=Sa;c[Oa+4>>2]=Ra;Lb=(Sa|0)==(-1|0)&(Ra|0)==(-1|0)&1}else{Lb=0}do{if((c[E>>2]|0)==0){Mb=Ja}else{if((c[X>>2]|0)==0){Mb=Ja;break}Mb=Ja+(Ba>>1)|0}}while(0);c[J>>2]=0;Ja=c[q>>2]|0;if((Ja|0)<=0){break}Ra=Ba<<3;Sa=f+920+(Ka<<2)|0;Oa=f+1296+(Ka<<2)|0;hb=f+1312+(Ka<<2)|0;gb=(Lb|0)==0;fb=0;Nb=0;$a=c[D>>2]|0;_a=Ja;while(1){Ja=ba(c[Sa>>2]|0,Nb)|0;if(($a|0)>0){Ya=ba(Ra,Nb)|0;bb=fb;Ob=0;ab=Mb+(Ya>>c[(c[y>>2]|0)+800>>2])|0;Ya=(c[Oa>>2]|0)+(Ja<<7)|0;Wa=(c[hb>>2]|0)+Ja|0;while(1){Ja=c[T>>2]|0;do{if((Ja|0)!=0){if((c[J>>2]|0)!=0){break}c[J>>2]=Ja}}while(0);Ja=Ya|0;Ta=c[aa>>2]|0;g:do{if(R){if((bb|0)!=0){Pb=bb-1|0;break}Za=c[w>>2]|0;eb=c[v>>2]|0;db=c[f+712+(Ta*20|0)+4>>2]|0;Xa=V;cb=c[u>>2]|0;while(1){Va=eb+(cb>>>3)|0;Ua=(fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(cb&7);Va=Ua>>>23;ib=b[db+(Va<<2)>>1]|0;jb=b[db+(Va<<2)+2>>1]|0;Va=jb<<16>>16;if(jb<<16>>16<0){jb=cb+9|0;mb=Za>>>0>jb>>>0?jb:Za;jb=eb+(mb>>>3)|0;lb=(fe(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(mb&7);jb=(lb>>>((Va+32|0)>>>0))+ib|0;Qb=b[db+(jb<<2)>>1]|0;Rb=b[db+(jb<<2)+2>>1]|0;Sb=lb;Tb=mb}else{Qb=ib;Rb=Va;Sb=Ua;Tb=cb}Ua=Rb+Tb|0;Ub=Za>>>0>Ua>>>0?Ua:Za;Vb=Qb>>>4;Ua=Qb&15;if((Ua|0)==0){if((Vb|0)!=15){N=279;break}Wb=Xa+15|0;if((Wb|0)<(K|0)){Xb=Wb;Yb=Ub}else{N=278;break a}}else{Zb=Vb+Xa|0;if(Ua>>>0>9>>>0){Va=eb+(Ub>>>3)|0;_b=(fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ub&7)}else{_b=Sb<<Rb}Va=(_b^-2147483648)>>31;$b=((Va^_b)>>>((32-Ua|0)>>>0)^Va)-Va|0;Va=Ub+Ua|0;ac=Za>>>0>Va>>>0?Va:Za;if((Zb|0)>=(K|0)){N=272;break}Va=d[f+1364+Zb|0]|0;b[Ya+(Va<<1)>>1]=(ba(b[f+40+(Da<<7)+(Va<<1)>>1]|0,$b)|0)<<Y;Xb=Zb;Yb=ac}Xa=Xb+1|0;cb=Yb}if((N|0)==272){N=0;if((Zb|0)!=(K|0)){N=274;break a}cb=d[$]|0;b[Ya+(cb<<1)>>1]=(ba(b[f+40+(Da<<7)+(cb<<1)>>1]|0,$b)|0)<<Y;bc=K;cc=ac;dc=0}else if((N|0)==279){N=0;cb=1<<Vb;if((Vb|0)==0){ec=Ub;fc=cb}else{db=eb+(Ub>>>3)|0;Va=((fe(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(Ub&7)>>>((32-Vb|0)>>>0))+cb|0;cb=Ub+Vb|0;ec=Za>>>0>cb>>>0?cb:Za;fc=Va}bc=Xa;cc=ec;dc=fc-1|0}c[u>>2]=cc;if((bc|0)<=(d[Wa]|0)){Pb=dc;break}a[Wa]=bc;Pb=dc}else{Va=d[Wa]|0;cb=Va>>>0<K>>>0?Va:K;Va=c[u>>2]|0;db=c[w>>2]|0;do{if((bb|0)==0){Ua=c[v>>2]|0;ib=c[f+712+(Ta*20|0)+4>>2]|0;mb=Va;lb=V;h:while(1){jb=Ua+(mb>>>3)|0;sb=(fe(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(mb&7)>>>23;jb=b[ib+(sb<<2)>>1]|0;kb=b[ib+(sb<<2)+2>>1]|0;sb=kb<<16>>16;if(kb<<16>>16<0){kb=mb+9|0;pb=db>>>0>kb>>>0?kb:db;kb=Ua+(pb>>>3)|0;ob=((fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(pb&7)>>>((sb+32|0)>>>0))+jb|0;gc=b[ib+(ob<<2)+2>>1]|0;hc=b[ib+(ob<<2)>>1]|0;ic=pb}else{gc=sb;hc=jb;ic=mb}jb=gc+ic|0;jc=db>>>0>jb>>>0?jb:db;kc=hc>>>4;i:do{if((hc&15|0)==0){if((kc|0)!=15){break h}if((lb|0)>(cb|0)){lc=15;mc=lb;nc=jc}else{jb=15;sb=lb;pb=jc;while(1){ob=d[f+1364+sb|0]|0;kb=Ya+(ob<<1)|0;rb=b[kb>>1]|0;if(rb<<16>>16==0){if((jb|0)==0){oc=pb;pc=sb;break i}else{qc=pb;rc=jb-1|0}}else{xb=Ua+(pb>>>3)|0;qb=(fe(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0)<<(pb&7);xb=rb<<16>>16;rb=xb>>15;b[kb>>1]=(((b[f+40+(Da<<7)+(ob<<1)>>1]^rb)-rb&qb>>31)<<Y)+xb;xb=pb+1|0;qc=db>>>0>xb>>>0?xb:db;rc=jb}xb=sb+1|0;if((xb|0)>(cb|0)){lc=rc;mc=xb;nc=qc;break}else{jb=rc;sb=xb;pb=qc}}}sc=lc+mc|0;if((sc|0)>(K|0)){N=248;break a}else{oc=nc;pc=sc}}else{pb=Ua+(jc>>>3)|0;sb=(fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(jc&7)>>>31;pb=jc+1|0;jb=db>>>0>pb>>>0?pb:db;j:do{if((lb|0)>(cb|0)){tc=kc;uc=lb;vc=jb;N=234}else{pb=kc;xb=lb;qb=jb;while(1){rb=a[f+1364+xb|0]|0;ob=rb&255;kb=Ya+(ob<<1)|0;vb=b[kb>>1]|0;if(vb<<16>>16==0){if((pb|0)==0){wc=xb;xc=qb;yc=rb;break j}else{zc=qb;Ac=pb-1|0}}else{rb=Ua+(qb>>>3)|0;ub=(fe(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(qb&7);rb=vb<<16>>16;vb=rb>>15;b[kb>>1]=(((b[f+40+(Da<<7)+(ob<<1)>>1]^vb)-vb&ub>>31)<<Y)+rb;rb=qb+1|0;zc=db>>>0>rb>>>0?rb:db;Ac=pb}rb=xb+1|0;if((rb|0)>(cb|0)){tc=Ac;uc=rb;vc=zc;N=234;break}else{pb=Ac;xb=rb;qb=zc}}}}while(0);if((N|0)==234){N=0;Bc=tc+uc|0;if((Bc|0)>(K|0)){N=236;break a}wc=Bc;xc=vc;yc=a[f+1364+Bc|0]|0}jb=yc&255;qb=sb-1|0;b[Ya+(jb<<1)>>1]=(b[f+40+(Da<<7)+(jb<<1)>>1]^qb)-qb<<Y;if((wc|0)==(K|0)){N=242;break h}else{oc=xc;pc=wc}}}while(0);mb=oc;lb=pc+1|0}if((N|0)==242){N=0;if((d[Wa]|0)>>>0<K>>>0){a[Wa]=ea}c[u>>2]=xc;Pb=0;break g}mb=1<<kc;if((kc|0)==0){Cc=jc;Dc=mb}else{ib=Ua+(jc>>>3)|0;qb=((fe(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)|0)<<(jc&7)>>>((32-kc|0)>>>0))+mb|0;mb=jc+kc|0;Cc=db>>>0>mb>>>0?mb:db;Dc=qb}qb=Dc-1|0;if((lb|0)<=(d[Wa]|0)){Ec=Cc;Fc=lb;Gc=qb;break}a[Wa]=lb;Ec=Cc;Fc=lb;Gc=qb}else{Ec=Va;Fc=V;Gc=bb-1|0}}while(0);if((Fc|0)>(cb|0)){Hc=Ec}else{Va=Fc;Xa=Ec;while(1){Za=d[f+1364+Va|0]|0;eb=Ya+(Za<<1)|0;qb=b[eb>>1]|0;if(qb<<16>>16==0){Ic=Xa}else{mb=(c[v>>2]|0)+(Xa>>>3)|0;ib=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(Xa&7);mb=qb<<16>>16;qb=mb>>15;b[eb>>1]=(((b[f+40+(Da<<7)+(Za<<1)>>1]^qb)-qb&ib>>31)<<Y)+mb;mb=Xa+1|0;Ic=db>>>0>mb>>>0?mb:db}mb=Va+1|0;if((mb|0)>(cb|0)){Hc=Ic;break}else{Va=mb;Xa=Ic}}}c[u>>2]=Hc;Pb=Gc}}while(0);if(gb){Jc=ab}else{Xe[c[A>>2]&4095](ab,Ba,Ja);Ta=c[G>>2]|0;k:do{if((Ta&7|0)!=0){Xa=8>>>((c[(c[y>>2]|0)+800>>2]|0)>>>0);Va=(Xa|0)>0;if((Ta|0)<=8){if(Va){Kc=0}else{break}while(1){cb=ba(Kc,Ba)|0;db=0;do{mb=ab+(db+cb)|0;a[mb]=d[mb]<<8-(c[G>>2]|0);db=db+1|0;}while((db|0)<(Xa|0));Kc=Kc+1|0;if((Kc|0)>=(Xa|0)){break k}}}if(!Va){break}db=16-Ta|0;cb=0;do{lb=ba(cb,Ba)|0;Ua=0;do{mb=ab+((Ua<<1)+lb)|0;b[mb>>1]=e[mb>>1]<<db;Ua=Ua+1|0;}while((Ua|0)<(Xa|0));cb=cb+1|0;}while((cb|0)<(Xa|0))}}while(0);Jc=ab+(Ca>>>((c[(c[y>>2]|0)+800>>2]|0)>>>0))|0}Ta=(ELa(f,0)|0)==0;Lc=Ta?Pb:0;Ta=Ob+1|0;Mc=c[D>>2]|0;if((Ta|0)<(Mc|0)){bb=Lc;Ob=Ta;ab=Jc;Ya=Ya+128|0;Wa=Wa+1|0}else{break}}Nc=Lc;Oc=Mc;Pc=c[q>>2]|0}else{Nc=fb;Oc=$a;Pc=_a}Wa=Nb+1|0;if((Wa|0)<(Pc|0)){fb=Nc;Nb=Wa;$a=Oc;_a=Pc}else{break}}}else{if((c[t>>2]|0)!=(c[P>>2]|0)){N=49;break a}if((c[ga>>2]|0)!=0){_a=KJa(f,V,Y,K)|0;if((_a|0)<0){s=_a;N=375;break a}else{break}}if((c[ha>>2]|0)!=0){_a=c[ja>>2]|0;$a=(1<<c[G>>2])-1|0;fb=$a<<Y;if(!(((c[ka>>2]|0)-3|0)>>>0<2>>>0)){s=-1094995529;N=375;break a}if((c[la>>2]|0)!=1){s=-1094995529;N=375;break a}if((c[ma>>2]|0)!=1){s=-1094995529;N=375;break a}c[J>>2]=c[T>>2];kEb(oa,pa,c[D>>2]<<3);Ca=c[na>>2]|0;Ba=1<<(c[G>>2]|0)-1&65535;gb=Ca|0;b[gb>>1]=Ba;Da=Ca+2|0;b[Da>>1]=Ba;hb=Ca+4|0;b[hb>>1]=Ba;Oa=Ca+6|0;b[Oa>>1]=Ba;if((c[q>>2]|0)<=0){break}Ba=_a>>1;Ra=0;Sa=0;Ka=0;while(1){Wa=c[c[t>>2]>>2]|0;Ya=ba(Ra,_a)|0;ab=Wa+Ya|0;do{if((c[E>>2]|0)==0){Qc=ab}else{if((c[X>>2]|0)==0){Qc=ab;break}Qc=Wa+(Ya+Ba)|0}}while(0);Ya=e[gb>>1]|0;c[sa>>2]=Ya;c[ta>>2]=Ya;Ya=e[Da>>1]|0;c[ua>>2]=Ya;c[va>>2]=Ya;Ya=e[hb>>1]|0;c[wa>>2]=Ya;c[xa>>2]=Ya;Ya=e[Oa>>1]|0;c[ya>>2]=Ya;c[za>>2]=Ya;Ya=c[D>>2]|0;if((Ya|0)>0){Wa=Sa;ab=Ka;bb=0;Ia=c[T>>2]|0;while(1){do{if((Ia|0)==0){Rc=ab;Sc=Wa}else{if((c[J>>2]|0)!=0){Rc=ab;Sc=Wa;break}c[J>>2]=Ia;Ta=1<<(c[G>>2]|0)-1;c[sa>>2]=Ta;c[ta>>2]=Ta;c[ua>>2]=Ta;c[va>>2]=Ta;c[wa>>2]=Ta;c[xa>>2]=Ta;c[ya>>2]=Ta;c[za>>2]=Ta;Rc=bb;Sc=Ra}}while(0);l:do{if((Ra|0)==(Sc|0)){Tc=0;N=73}else{if((Ra|0)==(Sc+1|0)){if(!((bb|0)>=(Rc|0)&(bb|0)!=0)){Tc=0;N=73;break}}else{if((bb|0)==0){Tc=0;N=73;break}}if((V|0)==0){Ta=0;while(1){Ja=Ca+(bb<<3)+(Ta<<1)|0;c[l+(Ta<<2)>>2]=e[Ja>>1]|0;Xa=FLa(f,c[f+1e3+(Ta<<2)>>2]|0)|0;if((Xa|0)==1048575){s=-1;N=375;break a}cb=(Xa&$a)<<Y;b[Ja>>1]=cb;c[o+(Ta<<2)>>2]=cb&65535;Ta=Ta+1|0;if((Ta|0)>=(B|0)){break l}}}else if((V|0)==1){Tc=0;N=73;break}else{Uc=0}while(1){Ta=l+(Uc<<2)|0;cb=c[Ta>>2]|0;Ja=Ca+(bb<<3)+(Uc<<1)|0;Xa=e[Ja>>1]|0;c[Ta>>2]=Xa;switch(V|0){case 2:{Vc=Xa;break};case 3:{Vc=cb;break};case 4:{Vc=Xa-cb+(c[o+(Uc<<2)>>2]|0)|0;break};case 5:{Vc=(c[o+(Uc<<2)>>2]|0)+(Xa-cb>>1)|0;break};case 6:{Vc=((c[o+(Uc<<2)>>2]|0)-cb>>1)+Xa|0;break};case 0:{Vc=0;break};default:{Vc=(c[o+(Uc<<2)>>2]|0)+Xa>>1}}Xa=FLa(f,c[f+1e3+(Uc<<2)>>2]|0)|0;if((Xa|0)==1048575){s=-1;N=375;break a}cb=(Xa<<Y)+Vc&fb;b[Ja>>1]=cb;c[o+(Uc<<2)>>2]=cb&65535;Uc=Uc+1|0;if((Uc|0)>=(B|0)){break l}}}}while(0);if((N|0)==73){while(1){N=0;cb=Ca+(bb<<3)+(Tc<<1)|0;c[l+(Tc<<2)>>2]=e[cb>>1]|0;Ja=o+(Tc<<2)|0;Xa=c[Ja>>2]|0;Ta=FLa(f,c[f+1e3+(Tc<<2)>>2]|0)|0;if((Ta|0)==1048575){s=-1;N=375;break a}db=(Ta<<Y)+Xa&fb;b[cb>>1]=db;c[Ja>>2]=db&65535;db=Tc+1|0;if((db|0)<(B|0)){Tc=db;N=73}else{break}}}db=c[T>>2]|0;do{if((db|0)!=0){Ja=(c[J>>2]|0)-1|0;c[J>>2]=Ja;if((Ja|0)!=0){break}Ja=c[u>>2]|0;cb=-Ja&7;Xa=c[w>>2]|0;if((cb|0)==0){Wc=Ja}else{Ta=cb+Ja|0;Ja=Xa>>>0>Ta>>>0?Ta:Xa;c[u>>2]=Ja;Wc=Ja}Ja=Wc+16|0;c[u>>2]=Xa>>>0>Ja>>>0?Ja:Xa}}while(0);Xa=bb+1|0;Ja=c[D>>2]|0;if((Xa|0)<(Ja|0)){Wa=Sc;ab=Rc;bb=Xa;Ia=db}else{Xc=Sc;Yc=Rc;Zc=Ja;break}}}else{Xc=Sa;Yc=Ka;Zc=Ya}m:do{if((c[ka>>2]|0)==4){Ia=Qc;bb=0;ab=Zc;while(1){Wa=c[f+984+(bb<<2)>>2]|0;Ja=c[G>>2]|0;do{if((Ja|0)<9){if((ab|0)>0){_c=0}else{$c=ab;break}while(1){a[Qc+((_c<<2|3)-Wa)|0]=b[Ca+(_c<<3)+(bb<<1)>>1];Xa=_c+1|0;Ta=c[D>>2]|0;if((Xa|0)<(Ta|0)){_c=Xa}else{$c=Ta;break}}}else{if((Ja|0)==9){s=-1163346256;N=375;break a}if((ab|0)>0){ad=0}else{$c=ab;break}while(1){b[Ia+((ad<<2)+Wa<<1)>>1]=b[Ca+(ad<<3)+(bb<<1)>>1]|0;Ta=ad+1|0;if((Ta|0)<(ab|0)){ad=Ta}else{$c=ab;break}}}}while(0);Wa=bb+1|0;if((Wa|0)<(B|0)){bb=Wa;ab=$c}else{break}}}else{if((c[qa>>2]|0)!=0){if((Zc|0)>0){bd=0}else{break}while(1){ab=Ca+(bd<<3)+2|0;bb=Ca+(bd<<3)+4|0;Ia=(e[Ca+(bd<<3)>>1]|0)-(((e[ab>>1]|0)+512+(e[bb>>1]|0)|0)>>>2)|0;db=Ia&255;Wa=bd*3|0;a[Qc+(Wa+1)|0]=db;a[Qc+Wa|0]=Ia+(e[ab>>1]|0);a[Qc+(Wa+2)|0]=db+(b[bb>>1]&255);bd=bd+1|0;if((bd|0)>=(c[D>>2]|0)){break m}}}if((c[ra>>2]|0)!=0){if((Zc|0)>0){cd=0}else{break}while(1){bb=Ca+(cd<<3)+2|0;db=Ca+(cd<<3)+4|0;Wa=(e[Ca+(cd<<3)>>1]|0)-(((e[db>>1]|0)+(e[bb>>1]|0)|0)>>>2)|0;ab=Wa&255;Ia=cd*3|0;a[Qc+(Ia+1)|0]=ab;a[Qc+Ia|0]=Wa+(e[bb>>1]|0);a[Qc+(Ia+2)|0]=ab+(b[db>>1]&255);cd=cd+1|0;if((cd|0)>=(c[D>>2]|0)){break m}}}db=Qc;ab=0;Ia=Zc;while(1){bb=c[f+984+(ab<<2)>>2]|0;Wa=c[G>>2]|0;do{if((Wa|0)<9){if((Ia|0)<=0){dd=Ia;break}Ja=2-bb|0;Ta=0;while(1){a[Qc+(Ja+(Ta*3|0))|0]=b[Ca+(Ta<<3)+(ab<<1)>>1];Xa=Ta+1|0;cb=c[D>>2]|0;if((Xa|0)<(cb|0)){Ta=Xa}else{dd=cb;break}}}else{if((Wa|0)==9){s=-1163346256;N=375;break a}if((Ia|0)<=0){dd=Ia;break}Ta=2-bb|0;Ja=0;while(1){b[db+(Ta+(Ja*3|0)<<1)>>1]=b[Ca+(Ja<<3)+(ab<<1)>>1]|0;cb=Ja+1|0;if((cb|0)<(Ia|0)){Ja=cb}else{dd=Ia;break}}}}while(0);bb=ab+1|0;if((bb|0)<(B|0)){ab=bb;Ia=dd}else{break}}}}while(0);Ya=Ra+1|0;if((Ya|0)<(c[q>>2]|0)){Ra=Ya;Sa=Xc;Ka=Yc}else{break b}}}Ka=c[G>>2]|0;Sa=Ka+7&-8;Ra=Sa-Ka+Y|0;Ca=(1<<Ka)-1<<Ra;if(!ia){N=119;break a}Ka=c[q>>2]|0;if((Ka|0)<=0){break}fb=(Sa|0)>8;$a=(Sa|0)<9;Oa=1<<Sa-1;Sa=0;hb=0;Da=0;gb=c[D>>2]|0;Ba=Ka;while(1){if((gb|0)>0){Ka=Sa;_a=hb;Ya=0;Ia=c[T>>2]|0;while(1){do{if((Ia|0)==0){ed=_a;fd=Ka}else{if((c[J>>2]|0)!=0){ed=_a;fd=Ka;break}c[J>>2]=Ia;ed=Da;fd=Ya}}while(0);ab=(Ya|0)!=0;db=(Da|0)==(ed|0);do{if(db|ab^1){N=128}else{if((Da|0)==(ed+1|0)&(Ya|0)<(fd|0)){N=128;break}if((c[E>>2]|0)==0){gd=0}else{N=128;break}do{bb=c[f+1032+(gd<<2)>>2]|0;Wa=c[f+984+(gd<<2)>>2]|0;Ja=c[f+1048+(gd<<2)>>2]|0;Ta=c[f+1148+(Wa<<2)>>2]|0;if(fb){hd=(Ta|0)/2|0}else{hd=Ta}if((bb|0)>0){Ta=f+1e3+(gd<<2)|0;cb=ba(c[f+1064+(gd<<2)>>2]|0,Da)|0;Xa=ba(Ja,Ya)|0;Va=~hd;Ua=-hd|0;lb=0;mb=0;ib=0;while(1){qb=FLa(f,c[Ta>>2]|0)|0;if((qb|0)==1048575){s=-1;N=375;break a}Za=c[(c[t>>2]|0)+(Wa<<2)>>2]|0;eb=ba(mb+cb|0,hd)|0;if($a){jb=lb+Xa+eb|0;switch(V|0){case 4:{id=(d[Za+(jb-hd)|0]|0)+(d[Za+(jb-1)|0]|0)-(d[Za+(jb+Va)|0]|0)|0;break};case 6:{id=((d[Za+(jb-1)|0]|0)-(d[Za+(jb+Va)|0]|0)>>1)+(d[Za+(jb-hd)|0]|0)|0;break};case 0:{id=0;break};case 3:{id=d[Za+(jb+Va)|0]|0;break};case 5:{id=((d[Za+(jb-hd)|0]|0)-(d[Za+(jb+Va)|0]|0)>>1)+(d[Za+(jb-1)|0]|0)|0;break};case 1:{id=d[Za+(jb-1)|0]|0;break};case 2:{id=d[Za+(jb-hd)|0]|0;break};default:{id=((d[Za+(jb-hd)|0]|0)+(d[Za+(jb-1)|0]|0)|0)>>>1}}a[Za+jb|0]=(id&Ca)+(qb<<Ra)}else{jb=(eb<<1)+(lb+Xa<<1)|0;eb=Za+jb|0;switch(V|0){case 0:{jd=0;break};case 2:{jd=e[eb+(Ua<<1)>>1]|0;break};case 3:{jd=e[eb+(Va<<1)>>1]|0;break};case 4:{jd=(e[eb+(Ua<<1)>>1]|0)+(e[Za+(jb-2)>>1]|0)-(e[eb+(Va<<1)>>1]|0)|0;break};case 5:{jd=((e[eb+(Ua<<1)>>1]|0)-(e[eb+(Va<<1)>>1]|0)>>1)+(e[Za+(jb-2)>>1]|0)|0;break};case 6:{jd=((e[Za+(jb-2)>>1]|0)-(e[eb+(Va<<1)>>1]|0)>>1)+(e[eb+(Ua<<1)>>1]|0)|0;break};case 1:{jd=e[Za+(jb-2)>>1]|0;break};default:{jd=((e[eb+(Ua<<1)>>1]|0)+(e[Za+(jb-2)>>1]|0)|0)>>>1}}b[eb>>1]=(jd&Ca)+(qb<<Ra)}qb=lb+1|0;eb=(qb|0)==(Ja|0);jb=ib+1|0;if((jb|0)<(bb|0)){lb=eb?0:qb;mb=(eb&1)+mb|0;ib=jb}else{break}}}gd=gd+1|0;}while((gd|0)<(B|0))}}while(0);if((N|0)==128){N=0;if(db){kd=0}else{kd=(Ya|0)>=(fd|0)|(Da|0)!=(ed+1|0)}if(ab){ld=db&(Ya|0)==(fd|0)^1}else{ld=0}ib=0;do{mb=c[f+1032+(ib<<2)>>2]|0;lb=c[f+984+(ib<<2)>>2]|0;bb=c[f+1048+(ib<<2)>>2]|0;Ja=c[f+1148+(lb<<2)>>2]|0;if(fb){md=(Ja|0)/2|0}else{md=Ja}if((mb|0)>0){Ja=f+1e3+(ib<<2)|0;Ua=ba(c[f+1064+(ib<<2)>>2]|0,Da)|0;Va=ba(bb,Ya)|0;Xa=~md;cb=md>>1;Wa=-md|0;Ta=0;jb=0;eb=0;while(1){qb=FLa(f,c[Ja>>2]|0)|0;if((qb|0)==1048575){s=-1;N=375;break a}Za=c[(c[t>>2]|0)+(lb<<2)>>2]|0;xb=ba(jb+Ua|0,md)|0;if($a){pb=Ta+Va+xb|0;rb=Za+pb|0;ub=(Ta|0)!=0|ld;n:do{if((jb|0)!=0|kd){if(!ub){nd=d[Za+(pb-md)|0]|0;break}switch(V|0){case 4:{nd=(d[Za+(pb-md)|0]|0)+(d[Za+(pb-1)|0]|0)-(d[Za+(pb+Xa)|0]|0)|0;break n;break};case 5:{nd=((d[Za+(pb-md)|0]|0)-(d[Za+(pb+Xa)|0]|0)>>1)+(d[Za+(pb-1)|0]|0)|0;break n;break};case 6:{nd=((d[Za+(pb-1)|0]|0)-(d[Za+(pb+Xa)|0]|0)>>1)+(d[Za+(pb-md)|0]|0)|0;break n;break};case 3:{nd=d[Za+(pb+Xa)|0]|0;break n;break};case 0:{nd=0;break n;break};case 1:{nd=d[Za+(pb-1)|0]|0;break n;break};case 2:{nd=d[Za+(pb-md)|0]|0;break n;break};default:{nd=((d[Za+(pb-md)|0]|0)+(d[Za+(pb-1)|0]|0)|0)>>>1;break n}}}else{if(!ub){nd=Oa;break}nd=d[Za+(pb-1)|0]|0}}while(0);do{if((c[E>>2]|0)==0){od=rb}else{if((c[X>>2]|0)==0){od=rb;break}od=Za+(pb+cb)|0}}while(0);a[od]=(nd&Ca)+(qb<<Ra)}else{pb=(xb<<1)+(Ta+Va<<1)|0;rb=Za+pb|0;ub=(Ta|0)!=0|ld;o:do{if((jb|0)!=0|kd){if(!ub){pd=e[rb+(Wa<<1)>>1]|0;break}switch(V|0){case 5:{pd=((e[rb+(Wa<<1)>>1]|0)-(e[rb+(Xa<<1)>>1]|0)>>1)+(e[Za+(pb-2)>>1]|0)|0;break o;break};case 1:{pd=e[Za+(pb-2)>>1]|0;break o;break};case 0:{pd=0;break o;break};case 6:{pd=((e[Za+(pb-2)>>1]|0)-(e[rb+(Xa<<1)>>1]|0)>>1)+(e[rb+(Wa<<1)>>1]|0)|0;break o;break};case 2:{pd=e[rb+(Wa<<1)>>1]|0;break o;break};case 3:{pd=e[rb+(Xa<<1)>>1]|0;break o;break};case 4:{pd=(e[rb+(Wa<<1)>>1]|0)+(e[Za+(pb-2)>>1]|0)-(e[rb+(Xa<<1)>>1]|0)|0;break o;break};default:{pd=((e[rb+(Wa<<1)>>1]|0)+(e[Za+(pb-2)>>1]|0)|0)>>>1;break o}}}else{if(!ub){pd=Oa;break}pd=e[Za+(pb-2)>>1]|0}}while(0);do{if((c[E>>2]|0)==0){qd=rb}else{if((c[X>>2]|0)==0){qd=rb;break}qd=rb+(cb<<1)|0}}while(0);b[qd>>1]=(pd&Ca)+(qb<<Ra)}rb=Ta+1|0;pb=(rb|0)==(bb|0);Za=eb+1|0;if((Za|0)<(mb|0)){Ta=pb?0:rb;jb=(pb&1)+jb|0;eb=Za}else{break}}}ib=ib+1|0;}while((ib|0)<(B|0))}ib=c[T>>2]|0;do{if((ib|0)!=0){db=(c[J>>2]|0)-1|0;c[J>>2]=db;if((db|0)!=0){break}db=c[u>>2]|0;ab=-db&7;eb=c[w>>2]|0;if((ab|0)==0){rd=db}else{jb=ab+db|0;db=eb>>>0>jb>>>0?jb:eb;c[u>>2]=db;rd=db}db=rd+16|0;c[u>>2]=eb>>>0>db>>>0?db:eb}}while(0);eb=Ya+1|0;sd=c[D>>2]|0;if((eb|0)<(sd|0)){Ka=fd;_a=ed;Ya=eb;Ia=ib}else{break}}td=fd;ud=ed;vd=sd;wd=c[q>>2]|0}else{td=Sa;ud=hb;vd=gb;wd=Ba}Ia=Da+1|0;if((Ia|0)<(wd|0)){Sa=td;hb=ud;Da=Ia;gb=vd;Ba=wd}else{break}}}}while(0);if((c[E>>2]|0)==0){s=0;N=375;break}Ba=c[u>>2]|0;gb=c[W>>2]|0;if((gb-Ba|0)<=32){s=0;N=375;break}Da=c[z>>2]|0;hb=Da+(Ba>>>3)|0;if(!(((fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(Ba&7)&-16777216|0)==-16777216)){s=0;N=375;break}hb=c[fa>>2]|0;Sa=c[w>>2]|0;Ra=-Ba&7;if((Ra|0)==0){xd=Ba}else{Ca=Ra+Ba|0;xd=Sa>>>0>Ca>>>0?Ca:Sa}Ca=Da+(xd>>>3)|0;if(!(((fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(xd&7)&-65536|0)==-3080192)){s=0;N=375;break}yDb(c[y>>2]|0,48,2044760,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;c[v>>2]=Da;c[fa>>2]=hb;c[W>>2]=gb;c[w>>2]=Sa;gb=xd+16|0;c[u>>2]=Sa>>>0>gb>>>0?gb:Sa;c[X>>2]=c[X>>2]^1;Aa=0}if((N|0)==49){yDb(0,0,2218608,(r=i,i=i+24|0,c[r>>2]=2055536,c[r+8>>2]=2200656,c[r+16>>2]=1402,r)|0);i=r;Cd();return 0}else if((N|0)==119){yDb(0,0,2218608,(r=i,i=i+24|0,c[r>>2]=2340888,c[r+8>>2]=2200656,c[r+16>>2]=962,r)|0);i=r;Cd();return 0}else if((N|0)==211){yDb(0,0,2218608,(r=i,i=i+24|0,c[r>>2]=2055536,c[r+8>>2]=2200656,c[r+16>>2]=1423,r)|0);i=r;Cd();return 0}else if((N|0)==213){yDb(c[y>>2]|0,16,2343376,(r=i,i=i+16|0,c[r>>2]=V,c[r+8>>2]=K,r)|0);i=r;s=-1094995529;i=k;return s|0}else if((N|0)==236){yDb(c[y>>2]|0,16,2346272,(r=i,i=i+8|0,c[r>>2]=Bc,r)|0);i=r}else if((N|0)==248){yDb(c[y>>2]|0,16,2346272,(r=i,i=i+8|0,c[r>>2]=sc,r)|0);i=r}else if((N|0)==274){yDb(c[y>>2]|0,16,2346272,(r=i,i=i+8|0,c[r>>2]=Zb,r)|0);i=r}else if((N|0)==278){yDb(c[y>>2]|0,16,2341944,(r=i,i=i+8|0,c[r>>2]=Wb,r)|0);i=r}else if((N|0)==375){i=k;return s|0}yDb(c[y>>2]|0,16,2355864,(r=i,i=i+16|0,c[r>>2]=Nb,c[r+8>>2]=Ob,r)|0);i=r;s=-1094995529;i=k;return s|0}else if((N|0)==374){yDb(c[y>>2]|0,16,2039768,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=k;return s|0}return 0}function ALa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;k=c[e>>2]|0;l=f;a:do{if((l-k|0)>1){m=k;n=a[k]|0;while(1){o=m+1|0;p=a[o]|0;if(n<<24>>24==-1){if((p&255)>>>0>191>>>0&p<<24>>24!=-1&o>>>0<f>>>0){break}}if((l-o|0)>1){m=o;n=p}else{q=-1;r=f;break a}}q=p&255;r=m+2|0}else{q=-1;r=f}}while(0);c[e>>2]=r;p=b+36|0;O$a(p,b+32|0,l-r|0);r=c[p>>2]|0;if((r|0)==0){s=-12;i=j;return s|0}if((q|0)!=218){c[g>>2]=c[e>>2];c[h>>2]=l-(c[e>>2]|0);s=q;i=j;return s|0}q=c[e>>2]|0;k=q>>>0<f>>>0;if((c[b+828>>2]|0)==0){n=b+4|0;b:do{if(k){b=r;o=q;while(1){t=o+1|0;u=a[o]|0;v=b+1|0;a[b]=u;do{if((c[(c[n>>2]|0)+48>>2]|0)!=101&u<<24>>24==-1){if(t>>>0<f>>>0){w=t}else{y=v;break b}while(1){z=w+1|0;A=a[w]|0;if(z>>>0<f>>>0&A<<24>>24==-1){w=z}else{break}}if((A+48&255)>>>0<8>>>0){a[v]=A;B=z;C=b+2|0;break}else{if(A<<24>>24==0){B=z;C=v;break}else{y=v;break b}}}else{B=t;C=v}}while(0);if(B>>>0<f>>>0){b=C;o=B}else{y=C;break}}}else{y=r}}while(0);c[g>>2]=c[p>>2];C=c[p>>2]|0;B=y;y=B-C|0;c[h>>2]=y;TGb(C+y|0,0,16)|0;yDb(c[n>>2]|0,48,2036408,(n=i,i=i+8|0,c[n>>2]=l-B-(c[e>>2]|0)+(c[p>>2]|0),n)|0);i=n;s=218;i=j;return s|0}c:do{if(k){n=0;e=q;while(1){B=n+1|0;if((a[e]|0)==-1){l=q+B|0;if(l>>>0<f>>>0){D=B;E=l}else{F=B;break}do{D=D+1|0;G=a[E]|0;E=q+D|0;}while(E>>>0<f>>>0&G<<24>>24==-1);if(G<<24>>24<0){F=D;break}else{H=D}}else{H=B}l=q+H|0;if(l>>>0<f>>>0){n=H;e=l}else{I=H;break c}}I=F-((F|0)<2?F:2)|0}else{I=0}}while(0);F=0;H=0;f=I<<3;D=32;G=(I|0)<0?0:r;E=0;d:while(1){k=H;J=D;K=G;L=E;while(1){if((k|0)>=(I|0)){break d}M=k+1|0;e=a[q+k|0]|0;n=e&255;if((J|0)>8){N=J-8|0;O=L<<8|n;P=K}else{l=K;x=fe(n>>>((8-J|0)>>>0)|L<<J|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;N=J+24|0;O=n;P=K+4|0}F=O;if(e<<24>>24==-1){break}else{k=M;J=N;K=P;L=O}}e=d[q+M|0]|0;if((N|0)>7){Q=N-7|0;R=e|O<<7;S=P}else{n=P;x=fe(e>>>((7-N|0)>>>0)|O<<N|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;Q=N+25|0;R=e;S=P+4|0}F=R;H=k+2|0;f=f-1|0;D=Q;G=S;E=R}if((J|0)<32){R=L<<J;F=R;L=R>>>24&255;R=J;J=K;while(1){a[J]=L;K=F;F=K<<8;E=R+8|0;if((E|0)<32){L=K>>>16&255;R=E;J=J+1|0}else{break}}}F=0;c[g>>2]=r;r=f+7>>3;c[h>>2]=r;TGb((c[p>>2]|0)+r|0,0,16)|0;s=218;i=j;return s|0}function BLa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0;h=i;i=i+104|0;j=h+32|0;k=h+48|0;l=h+56|0;m=h+64|0;n=h+72|0;o=h+80|0;p=h+88|0;q=h+96|0;r=e;e=c[g+24>>2]|0;s=c[g+28>>2]|0;g=c[b+60>>2]|0;t=g;u=g+2988|0;DBb(u);v=g+2992|0;w=v;$Db(v);x=g+872|0;c[x>>2]=-1;c[m>>2]=e;y=e+s|0;z=b;A=y;B=g+8|0;C=g+20|0;D=g+24|0;E=g+12|0;F=g+16|0;G=g+28|0;H=g+4|0;I=g+2944|0;J=g+2948|0;K=g+824|0;L=g+828|0;M=g+832|0;N=g+2968|0;O=b+696|0;P=h|0;Q=g+864|0;R=g+868|0;S=j|0;T=j+8|0;U=j+4|0;V=g+2952|0;W=g+836|0;X=g+856|0;Y=g+2960|0;Z=g+2956|0;_=g+2972|0;$=g+1144|0;aa=g+816|0;ca=g+820|0;da=e;a:while(1){b:do{if(da>>>0<y>>>0){ea=ALa(t,m,y,n,q)|0;if((ea|0)<0){fa=131;break}ga=c[q>>2]|0;if((ga|0)>268435455){fa=5;break a}ha=A-(c[m>>2]|0)|0;yDb(z,48,2028552,(ia=i,i=i+16|0,c[ia>>2]=ea,c[ia+8>>2]=ha,ia)|0);i=ia;ha=c[n>>2]|0;ja=ga>>>0>268435455>>>0?-8:ga<<3;ka=ja>>>0>2147483639>>>0|(ha|0)==0;la=ka?0:ha;ha=ka?0:ja;c[B>>2]=la;c[C>>2]=ha;c[D>>2]=ha+8;c[E>>2]=la+(ha>>3);c[F>>2]=0;if(ka){fa=7;break a}c[G>>2]=ea;if((c[(c[H>>2]|0)+688>>2]&256|0)!=0){yDb(z,48,2021592,(ia=i,i=i+8|0,c[ia>>2]=ea,ia)|0);i=ia}c:do{if((ea-208|0)>>>0<8>>>0){yDb(z,48,2017824,(ia=i,i=i+8|0,c[ia>>2]=ea&15,ia)|0);i=ia;fa=105}else{if(!((ea-224|0)>>>0<16>>>0)){switch(ea|0){case 219:{fa=107;break c;break};case 196:{fa=108;break c;break};case 194:{fa=111;break c;break};case 195:{fa=112;break c;break};case 221:{fa=127;break c;break};case 197:case 198:case 199:case 201:case 202:case 203:case 205:case 206:case 207:case 200:{fa=129;break c;break};case 218:{fa=125;break c;break};case 247:{fa=113;break c;break};case 248:{fa=114;break c;break};case 217:{fa=115;break b;break};case 254:{break};case 216:{fa=106;break c;break};case 192:case 193:{fa=110;break c;break};default:{break b}}ka=c[F>>2]|0;ha=c[D>>2]|0;la=(c[B>>2]|0)+(ka>>>3)|0;ja=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ka&7);la=ja>>>16;ma=ka+16|0;ka=ha>>>0>ma>>>0?ma:ha;c[F>>2]=ka;if(!(ja>>>0>131071>>>0)){break b}if(((la<<3)-16|0)>((c[C>>2]|0)-ka|0)){fa=105;break}ka=WDb(la-1|0)|0;if((ka|0)==0){fa=105;break}ha=la-2|0;do{if((ha|0)>0){ma=c[D>>2]|0;na=c[B>>2]|0;oa=0;pa=c[F>>2]|0;do{qa=na+(pa>>>3)|0;ra=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(pa&7)>>>24;qa=pa+8|0;pa=ma>>>0>qa>>>0?qa:ma;c[F>>2]=pa;a[ka+oa|0]=ra;oa=oa+1|0;}while((oa|0)<(ha|0));oa=ka+(la-3)|0;if((a[oa]|0)!=10){sa=ha;fa=87;break}a[oa]=0}else{sa=0;fa=87}}while(0);if((fa|0)==87){fa=0;a[ka+sa|0]=0}ha=c[H>>2]|0;if((c[ha+688>>2]&1|0)!=0){yDb(ha,32,1946776,(ia=i,i=i+8|0,c[ia>>2]=ka,ia)|0);i=ia}do{if((RGb(ka,1944704,4)|0)==0){c[V>>2]=1;ha=ja>>>0>983039>>>0;do{if(ha){oa=a[ka+12|0]|0;if((oa<<24>>24|0)==1){c[Y>>2]=1;break}else if((oa<<24>>24|0)==2){c[Y>>2]=0;break}else{break}}}while(0);oa=c[H>>2]|0;if((c[oa+688>>2]&1|0)==0){break}if(ha){ta=d[ka+12|0]|0}else{ta=-1}yDb(oa,32,2338232,(ia=i,i=i+16|0,c[ia>>2]=la,c[ia+8>>2]=ta,ia)|0);i=ia}else{if((QGb(ka,1942320)|0)==0){c[Z>>2]=1;break}if((RGb(ka,1934184,32)|0)!=0){if((RGb(ka,1931696,20)|0)!=0){break}}c[_>>2]=1}}while(0);ZDb(ka);fa=105;break}la=c[F>>2]|0;ja=c[D>>2]|0;oa=c[B>>2]|0;pa=oa+(la>>>3)|0;ma=(fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(la&7);pa=ma>>>16;na=la+16|0;la=ja>>>0>na>>>0?na:ja;c[F>>2]=la;if(ma>>>0<393216>>>0){fa=105;break}if((pa<<3|0)>((c[C>>2]|0)-la|0)){fa=105;break}ma=oa+(la>>>3)|0;na=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7)&-65536;ma=la+16|0;la=ja>>>0>ma>>>0?ma:ja;c[F>>2]=la;ma=oa+(la>>>3)|0;oa=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7)>>>16;ma=la+16|0;c[F>>2]=ja>>>0>ma>>>0?ma:ja;ja=oa|na;na=pa-6|0;if((c[(c[H>>2]|0)+688>>2]&256|0)!=0){I0a(P,32,fe(ja|0)|0)|0;yDb(c[H>>2]|0,48,1929872,(ia=i,i=i+24|0,c[ia>>2]=P,c[ia+8>>2]=ja,c[ia+16>>2]=na,ia)|0);i=ia}do{if((ja|0)==1279936838){oa=c[H>>2]|0;if((c[oa+688>>2]&1|0)!=0){yDb(oa,32,1911160,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia}oa=c[D>>2]|0;ma=(c[F>>2]|0)+16|0;la=(oa>>>0>ma>>>0?ma:oa)+16|0;ma=(oa>>>0>la>>>0?la:oa)+16|0;la=(oa>>>0>ma>>>0?ma:oa)+16|0;ma=oa>>>0>la>>>0?la:oa;c[F>>2]=ma;la=(c[B>>2]|0)+(ma>>>3)|0;ra=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>24;la=ma+8|0;c[F>>2]=oa>>>0>la>>>0?la:oa;if((ra|0)==1){c[W>>2]=1;c[X>>2]=0}else if((ra|0)==2){c[W>>2]=1;c[X>>2]=1}else{yDb(c[H>>2]|0,16,1909112,(ia=i,i=i+8|0,c[ia>>2]=ra,ia)|0);i=ia}ua=pa-15|0}else if((ja|0)==1096173873){c[V>>2]=1;ra=c[F>>2]|0;oa=c[D>>2]|0;la=(c[B>>2]|0)+(ra>>>3)|0;ma=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ra&7)>>>24;la=ra+8|0;c[F>>2]=oa>>>0>la>>>0?la:oa;yDb(c[H>>2]|0,48,1926448,(ia=i,i=i+8|0,c[ia>>2]=ma,ia)|0);i=ia;ua=pa-7|0}else if((ja|0)==1246120262){ma=c[D>>2]|0;oa=(c[F>>2]|0)+8|0;la=ma>>>0>oa>>>0?oa:ma;c[F>>2]=la;oa=c[B>>2]|0;ra=oa+(la>>>3)|0;qa=d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0;ra=la+8|0;va=ma>>>0>ra>>>0?ra:ma;c[F>>2]=va;ra=oa+(va>>>3)|0;wa=d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0;ra=va+8|0;xa=(ma>>>0>ra>>>0?ra:ma)+8|0;ra=ma>>>0>xa>>>0?xa:ma;c[F>>2]=ra;xa=oa+(ra>>>3)|0;ya=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(ra&7)>>>16;xa=ra+16|0;c[F>>2]=ma>>>0>xa>>>0?xa:ma;ma=c[H>>2]|0;xa=ma+224|0;c[xa>>2]=ya;ya=c[F>>2]|0;ra=c[D>>2]|0;za=oa+(ya>>>3)|0;Aa=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(ya&7)>>>16;za=ya+16|0;c[F>>2]=ra>>>0>za>>>0?za:ra;c[ma+228>>2]=Aa;if((c[ma+688>>2]&1|0)==0){Ba=oa}else{oa=fe(wa|0)|0;wa=(fe(qa|0)|0)<<(la&7)>>>24;la=c[xa>>2]|0;yDb(ma,32,1923280,(ia=i,i=i+32|0,c[ia>>2]=wa,c[ia+8>>2]=oa<<(va&7)>>>24,c[ia+16>>2]=la,c[ia+24>>2]=Aa,ia)|0);i=ia;Ba=c[B>>2]|0}Aa=c[F>>2]|0;la=c[D>>2]|0;va=Ba+(Aa>>>3)|0;oa=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(Aa&7)>>>24;va=Aa+8|0;Aa=la>>>0>va>>>0?va:la;c[F>>2]=Aa;va=Ba+(Aa>>>3)|0;wa=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(Aa&7)>>>24;va=Aa+8|0;c[F>>2]=la>>>0>va>>>0?va:la;if((oa|0)==0|(wa|0)==0){Ca=na}else{la=ba(oa*3|0,wa)|0;Ca=na-((pa-16-la|0)>0?la:0)|0}ua=Ca-10|0}else if((ja|0)==1097101154){la=c[F>>2]|0;wa=c[D>>2]|0;oa=c[B>>2]|0;va=oa+(la>>>3)|0;Aa=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(la&7);va=la+8|0;la=wa>>>0>va>>>0?va:wa;c[F>>2]=la;if((Aa&-16777216|0)!=1694498816){fa=43;break}Aa=la+16|0;la=(wa>>>0>Aa>>>0?Aa:wa)+16|0;Aa=(wa>>>0>la>>>0?la:wa)+16|0;la=wa>>>0>Aa>>>0?Aa:wa;c[F>>2]=la;Aa=oa+(la>>>3)|0;oa=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(la&7)>>>24;Aa=la+8|0;c[F>>2]=wa>>>0>Aa>>>0?Aa:wa;c[x>>2]=oa;wa=c[H>>2]|0;if((c[wa+688>>2]&1|0)!=0){yDb(wa,32,1919640,(ia=i,i=i+8|0,c[ia>>2]=oa,ia)|0);i=ia}ua=pa-13|0}else{oa=(na|0)>0;if((ja|0)==1919709027&oa){wa=c[F>>2]|0;Aa=c[D>>2]|0;la=(c[B>>2]|0)+(wa>>>3)|0;va=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(wa&7)>>>24;la=wa+8|0;c[F>>2]=Aa>>>0>la>>>0?la:Aa;c[Q>>2]=va;Aa=c[H>>2]|0;if((c[Aa+688>>2]&1|0)!=0){yDb(Aa,32,1906032,(ia=i,i=i+8|0,c[ia>>2]=va,ia)|0);i=ia}ua=pa-7|0;break}if(!((ja|0)==1836213880&oa)){fa=43;break}oa=c[F>>2]|0;va=c[D>>2]|0;Aa=(c[B>>2]|0)+(oa>>>3)|0;la=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(oa&7)>>>24;Aa=oa+8|0;c[F>>2]=va>>>0>Aa>>>0?Aa:va;c[R>>2]=la;va=c[H>>2]|0;if((c[va+688>>2]&1|0)!=0){yDb(va,32,1902784,(ia=i,i=i+8|0,c[ia>>2]=la,ia)|0);i=ia}ua=pa-7|0}}while(0);do{if((fa|0)==43){fa=0;ka=c[G>>2]|0;if((ka|0)==227){if(!((ja|0)==1598705747&(na|0)>9)){ua=na;break}la=c[H>>2]|0;if((c[la+688>>2]&1|0)!=0){yDb(la,32,1900256,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia}la=c[D>>2]|0;va=(c[F>>2]|0)+32|0;Aa=(la>>>0>va>>>0?va:la)+16|0;va=(la>>>0>Aa>>>0?Aa:la)+8|0;Aa=la>>>0>va>>>0?va:la;c[F>>2]=Aa;va=c[B>>2]|0;oa=va+(Aa>>>3)|0;wa=fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0;oa=Aa&7;ma=Aa+8|0;Aa=la>>>0>ma>>>0?ma:la;c[F>>2]=Aa;ma=va+(Aa>>>3)|0;xa=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(Aa&7)>>>24;ma=Aa+8|0;Aa=la>>>0>ma>>>0?ma:la;c[F>>2]=Aa;ma=va+(Aa>>>3)|0;va=d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0;ma=Aa+8|0;c[F>>2]=la>>>0>ma>>>0?ma:la;la=pa-16|0;ma=UFb()|0;c[w>>2]=ma;if((ma|0)==0){ua=la;break}qa=(fe(va|0)|0)<<(Aa&7)>>>24;if((qa|0)==0){c[ma>>2]=0;ua=la;break}else if((qa|0)!=1){ua=la;break}if((xa|0)==3){c[ma>>2]=2}else if((xa|0)==1){c[ma>>2]=6}else if((xa|0)==2){c[ma>>2]=1}if((67108864>>>(oa>>>0)&wa|0)!=0){ua=la;break}c[ma+4>>2]=1;ua=la;break}else if((ka|0)!=225){ua=na;break}if(!((ja|0)==1165519206&(na|0)>1)){if((na|0)<=32){ua=na;break}ka=c[F>>2]|0;la=c[D>>2]|0;ma=c[B>>2]|0;wa=ma+(ka>>>3)|0;oa=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ka&7)&-65536;wa=ka+16|0;ka=la>>>0>wa>>>0?wa:la;c[F>>2]=ka;wa=ma+(ka>>>3)|0;ma=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ka&7)>>>16;wa=ka+16|0;c[F>>2]=la>>>0>wa>>>0?wa:la;la=pa-10|0;if((ma|oa|0)!=1835692135){ua=la;break}oa=c[H>>2]|0;if((c[oa+688>>2]&1|0)==0){ua=la;break}yDb(oa,32,1886968,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;ua=la;break}la=c[D>>2]|0;oa=(c[F>>2]|0)+16|0;ma=la>>>0>oa>>>0?oa:la;oa=pa-8|0;wa=-ma&7;if((wa|0)==0){Da=ma}else{ka=wa+ma|0;Da=la>>>0>ka>>>0?ka:la}c[F>>2]=Da;la=c[B>>2]|0;ka=Da>>3;ma=la+ka|0;if(!((oa|0)>-1)){fa=60;break a}c[S>>2]=ma;c[T>>2]=ma;c[U>>2]=la+(ka+oa);if((P_a(j,k,l)|0)!=0){yDb(c[H>>2]|0,16,1897136,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;fa=105;break c}ka=c[l>>2]|0;la=c[T>>2]|0;ma=(c[U>>2]|0)-la|0;if((ka|0)<0){Ea=0}else{Ea=(ma|0)<(ka|0)?ma:ka}c[S>>2]=la+Ea;if((Qkb(c[H>>2]|0,j,c[k>>2]|0,0,u)|0)<0){yDb(c[H>>2]|0,16,1890688,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;fa=105;break c}else{la=(c[S>>2]|0)-(c[T>>2]|0)|0;ka=c[D>>2]|0;ma=(la<<3)+(c[F>>2]|0)|0;c[F>>2]=ka>>>0>ma>>>0?ma:ka;ua=oa-la|0;break}}}while(0);if((ua|0)<0){yDb(c[H>>2]|0,16,1885304,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia}pa=ua-1|0;if((pa|0)<=0){fa=105;break}na=c[D>>2]|0;ja=pa;pa=c[F>>2]|0;do{la=pa+8|0;pa=na>>>0>la>>>0?la:na;ja=ja-1|0;}while((ja|0)>0);c[F>>2]=pa;fa=105}}while(0);if((fa|0)==105){fa=0;switch(ea|0){case 219:{fa=107;break};case 196:{fa=108;break};case 194:{fa=111;break};case 195:{fa=112;break};case 221:{fa=127;break};case 197:case 198:case 199:case 201:case 202:case 203:case 205:case 206:case 207:case 200:{fa=129;break};case 218:{fa=125;break};case 247:{fa=113;break};case 248:{fa=114;break};case 217:{fa=115;break b;break};case 216:{fa=106;break};case 192:case 193:{fa=110;break};default:{break b}}}if((fa|0)==106){fa=0;c[I>>2]=0;c[J>>2]=0;break}else if((fa|0)==107){fa=0;wLa(t)|0;break}else if((fa|0)==108){fa=0;Fa=vLa(t)|0;if((Fa|0)<0){fa=109;break a}else{break}}else if((fa|0)==110){fa=0;c[K>>2]=0;c[L>>2]=0;c[M>>2]=0;ja=yLa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==111){fa=0;c[K>>2]=0;c[L>>2]=0;c[M>>2]=1;ja=yLa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==112){fa=0;c[K>>2]=1;c[L>>2]=0;c[M>>2]=0;ja=yLa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==113){fa=0;c[K>>2]=1;c[L>>2]=1;c[M>>2]=0;ja=yLa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==114){fa=0;ja=JJa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==125){fa=0;c[N>>2]=(c[N>>2]|0)+1;ja=zLa(t,0,0,0)|0;if((ja|0)>=0){break}if((c[O>>2]&8|0)==0){break}else{Ga=ja;break a}}else if((fa|0)==127){fa=0;ja=c[F>>2]|0;na=c[D>>2]|0;la=c[B>>2]|0;oa=la+(ja>>>3)|0;ka=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ja&7);oa=ja+16|0;ja=na>>>0>oa>>>0?oa:na;c[F>>2]=ja;if((ka&-65536|0)!=262144){break}ka=la+(ja>>>3)|0;la=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ja&7)>>>16;ka=ja+16|0;c[F>>2]=na>>>0>ka>>>0?ka:na;c[I>>2]=la;c[J>>2]=0;yDb(c[H>>2]|0,48,1948832,(ia=i,i=i+8|0,c[ia>>2]=la,ia)|0);i=ia;break}else if((fa|0)==129){fa=0;yDb(z,16,1995008,(ia=i,i=i+8|0,c[ia>>2]=ea,ia)|0);i=ia;break}}else{fa=131}}while(0);if((fa|0)==131){fa=0;if((c[$>>2]|0)==0){fa=134;break}if((c[N>>2]|0)==0){fa=134;break}yDb(z,24,1988264,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;fa=115}do{if((fa|0)==115){fa=0;c[N>>2]=0;if((c[$>>2]|0)==0){yDb(z,24,2009544,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;break}if((c[aa>>2]|0)==0){fa=119;break a}la=c[ca>>2]^1;c[ca>>2]=la;if((la|0)!=((c[Y>>2]|0)==0|0)){fa=119;break a}}}while(0);la=c[F>>2]|0;na=(la+7|0)/8|0;ka=(c[m>>2]|0)+na|0;c[m>>2]=ka;yDb(z,48,1991728,(ia=i,i=i+16|0,c[ia>>2]=na,c[ia+8>>2]=la,ia)|0);i=ia;da=ka}if((fa|0)==5){yDb(z,16,2032784,(ia=i,i=i+24|0,c[ia>>2]=ea,c[ia+8>>2]=ga,c[ia+16>>2]=s,ia)|0);i=ia;Ha=-1094995529;i=h;return Ha|0}else if((fa|0)==7){yDb(z,16,2024968,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Ga=-1094995529}else if((fa|0)==60){yDb(0,0,2218608,(ia=i,i=i+24|0,c[ia>>2]=1883952,c[ia+8>>2]=1882848,c[ia+16>>2]=135,ia)|0);i=ia;Cd();return 0}else if((fa|0)==109){yDb(z,16,2013688,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Ga=Fa}else if((fa|0)==119){Fa=g+1140|0;s=MCb(r,c[Fa>>2]|0)|0;if((s|0)<0){Ha=s;i=h;return Ha|0}c[f>>2]=1;c[$>>2]=0;do{if((c[K>>2]|0)==0){f=c[g+792>>2]|0;s=c[g+796>>2]|0;ga=(f|0)>(s|0)?f:s;s=c[g+800>>2]|0;f=(ga|0)>(s|0)?ga:s;s=((c[g+900>>2]|0)+15|0)/16|0;ga=UAb(s)|0;if((ga|0)!=0){TGb(c[ga+4>>2]|0,f&255|0,s|0)|0;GCb(r,ga,0,0)|0}if((c[b+688>>2]&16|0)==0){break}yDb(z,48,1999184,(ia=i,i=i+8|0,c[ia>>2]=f,ia)|0);i=ia}}while(0);K=g+840|0;f=c[K>>2]|0;d:do{if((f|0)!=0){ga=c[(c[Fa>>2]|0)+(f<<2)>>2]|0;s=c[b+140>>2]|0;if(!((s|0)==14|(s|0)==5|(s|0)==34|(s|0)==33)){yDb(0,0,2218608,(ia=i,i=i+24|0,c[ia>>2]=1981032,c[ia+8>>2]=2200656,c[ia+16>>2]=2042,ia)|0);i=ia;Cd();return 0}s=g+844|0;ea=c[s>>2]|0;if((ea|0)<=0){break}da=g+900|0;F=g+1148|0;Y=ga;ga=1;ca=f;aa=ea;while(1){ea=c[da>>2]|0;N=ea-1|0;if((N|0)==0){Ia=ca;Ja=aa}else{J=ea;ea=N;while(1){a[Y+ea|0]=((d[Y+((J|0)/2|0)|0]|0)+(d[Y+((ea|0)/2|0)|0]|0)|0)>>>1;N=ea-1|0;if((N|0)==0){break}else{J=ea;ea=N}}Ia=c[K>>2]|0;Ja=c[s>>2]|0}if((ga|0)>=(Ja|0)){break d}Y=Y+(c[F+(Ia<<2)>>2]|0)|0;ga=ga+1|0;ca=Ia;aa=Ja}}}while(0);Ja=g+848|0;Ia=c[Ja>>2]|0;e:do{if((Ia|0)!=0){K=g+904|0;f=g+1148|0;aa=ba((c[K>>2]|0)-1|0,c[f+(Ia<<2)>>2]|0)|0;ca=(c[(c[Fa>>2]|0)+(Ia<<2)>>2]|0)+aa|0;_Ga(c[(c[H>>2]|0)+140>>2]|0,o,p);aa=c[g+900>>2]>>c[o>>2];ga=c[b+140>>2]|0;if(!((ga|0)==14|(ga|0)==5|(ga|0)==13|(ga|0)==4)){yDb(0,0,2218608,(ia=i,i=i+24|0,c[ia>>2]=1978304,c[ia+8>>2]=2200656,c[ia+16>>2]=2057,ia)|0);i=ia;Cd();return 0}ga=c[K>>2]|0;K=ga-1|0;if((K|0)==0){break}F=(aa|0)>0;Y=c[Ja>>2]|0;s=ca;ca=ga;ga=K;K=Y;da=c[f+(Y<<2)>>2]|0;while(1){Y=ba(da,(ga|0)/2|0)|0;ea=c[(c[Fa>>2]|0)+(K<<2)>>2]|0;J=ba((ca|0)/2|0,da)|0;do{if((Y|0)==(J|0)){UGb(s|0,ea+Y|0,aa)|0}else{if(F){Ka=0}else{break}do{a[s+Ka|0]=((d[ea+(Ka+J)|0]|0)+(d[ea+(Ka+Y)|0]|0)|0)>>>1;Ka=Ka+1|0;}while((Ka|0)<(aa|0))}}while(0);Y=c[Ja>>2]|0;ea=c[f+(Y<<2)>>2]|0;J=ga-1|0;if((J|0)==0){break e}s=s+(-ea|0)|0;ca=ga;ga=J;K=Y;da=ea}}}while(0);if((c[_>>2]|0)!=0){_Ga(c[(c[H>>2]|0)+140>>2]|0,o,p);_=0;Ja=c[Fa>>2]|0;while(1){Ka=c[Ja+(_<<2)>>2]|0;b=c[Ja+68>>2]|0;g=c[Ja+72>>2]|0;if((_|0)!=0&(_|0)<3){La=-(-g>>c[p>>2])|0;Ma=-(-b>>c[o>>2])|0}else{La=g;Ma=b}do{if((Ka|0)==0){Na=Ja}else{b=(La|0)/2|0;if((La|0)<=1){Na=Ja;break}g=(Ma|0)>0;Ia=Ka+(ba(c[Ja+32+(_<<2)>>2]|0,La-1|0)|0)|0;da=Ka;K=0;ga=Ja;while(1){if(g){ca=0;do{s=Ia+ca|0;f=a[s]|0;aa=da+ca|0;a[s]=a[aa]|0;a[aa]=f;ca=ca+1|0;}while((ca|0)<(Ma|0));Oa=c[Fa>>2]|0}else{Oa=ga}ca=c[Oa+32+(_<<2)>>2]|0;f=K+1|0;if((f|0)<(b|0)){Ia=Ia+(-ca|0)|0;da=da+ca|0;K=f;ga=Oa}else{Na=Oa;break}}}}while(0);Ka=_+1|0;if((Ka|0)<4){_=Ka;Ja=Na}else{break}}}f:do{if((c[x>>2]|0)==0){if((c[(c[H>>2]|0)+140>>2]|0)!=317){break}Na=c[Fa>>2]|0;Ja=c[Na+68>>2]|0;_=c[Na+72>>2]|0;if((_|0)<=0){break}Oa=(Ja|0)>0;Ma=0;La=Na;while(1){Na=c[La>>2]|0;o=ba(c[La+32>>2]|0,Ma)|0;p=c[La+4>>2]|0;Ka=ba(c[La+36>>2]|0,Ma)|0;ga=c[La+8>>2]|0;K=ba(c[La+40>>2]|0,Ma)|0;da=c[La+12>>2]|0;Ia=ba(c[La+44>>2]|0,Ma)|0;if(Oa){b=0;do{g=da+(Ia+b)|0;f=Na+(o+b)|0;ca=d[f]|0;aa=p+(Ka+b)|0;s=ga+(K+b)|0;F=d[s]|0;ea=(d[g]|0)*257|0;a[f]=(ba(ea,d[aa]|0)|0)>>>16;a[aa]=(ba(ea,F)|0)>>>16;a[s]=(ba(ea,ca)|0)>>>16;a[g]=-1;b=b+1|0;}while((b|0)<(Ja|0))}b=Ma+1|0;if((b|0)>=(_|0)){break f}Ma=b;La=c[Fa>>2]|0}}}while(0);if((c[w>>2]|0)!=0){Fa=VFb(r)|0;if((Fa|0)!=0){H=c[w>>2]|0;c[Fa>>2]=c[H>>2];c[Fa+4>>2]=c[H+4>>2]}$Db(v)}v=FCb(r)|0;EBb(v,c[u>>2]|0,0);DBb(u);u=c[m>>2]|0;yDb(z,48,1975776,(ia=i,i=i+8|0,c[ia>>2]=A-u,ia)|0);i=ia;Ha=u-e|0;i=h;return Ha|0}else if((fa|0)==134){yDb(z,8,1983792,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Ha=-1094995529;i=h;return Ha|0}c[$>>2]=0;Ha=Ga;i=h;return Ha|0}function CLa(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[a+60>>2]|0;do{if((c[d+816>>2]|0)!=0){if((c[d+820>>2]|0)!=((c[d+2960>>2]|0)==0|0)){break}if((c[d+1144>>2]|0)==0){break}if((c[a+428>>2]|0)!=0){break}yDb(a,32,1973664,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}}while(0);a=d+1136|0;do{if((c[a>>2]|0)==0){e=c[d+1140>>2]|0;if((e|0)==0){break}KCb(e)}else{JCb(a);c[d+1140>>2]=0}}while(0);$Db(d+36|0);$Db(d+2992|0);$Db(d+2976|0);c[d+2980>>2]=0;Q_(d+552|0);Q_(d+572|0);Q_(d+592|0);Q_(d+612|0);Q_(d+632|0);Q_(d+652|0);Q_(d+672|0);Q_(d+692|0);Q_(d+712|0);Q_(d+732|0);Q_(d+752|0);Q_(d+772|0);$Db(d+1296|0);$Db(d+1312|0);$Db(d+1300|0);$Db(d+1316|0);$Db(d+1304|0);$Db(d+1320|0);$Db(d+1308|0);$Db(d+1324|0);DBb(d+2988|0);i=b;return 0}function DLa(a){a=a|0;c[(c[a+60>>2]|0)+1144>>2]=0;return}function ELa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[a+2944>>2]|0)==0){e=0;return e|0}f=a+2948|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;if((g|0)!=0){e=0;return e|0}do{if((c[(c[a+4>>2]|0)+48>>2]|0)==101){g=a+16|0;h=c[g>>2]|0;i=-h&7;if((i|0)!=0){j=c[a+24>>2]|0;k=i+h|0;c[g>>2]=j>>>0>k>>>0?k:j}if((b|0)<=0){l=9;break}j=a+860|0;k=0;do{c[a+1120+(k<<2)>>2]=4<<c[j>>2];k=k+1|0;}while((k|0)<(b|0));k=a+16|0;j=c[k>>2]|0;g=-j&7;if((c[f>>2]|0)==0){m=k;n=j;o=g;p=g;break}else{e=0}return e|0}else{l=9}}while(0);if((l|0)==9){l=a+16|0;f=c[l>>2]|0;g=-f&7;m=l;n=f;o=g;p=g}g=p|8;p=c[a+8>>2]|0;f=p+(n>>>3)|0;l=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(n&7)>>>((32-g|0)>>>0);if(!((l|0)==((1<<g)-1|0)|(l|0)==255)){e=0;return e|0}if((o|0)==0){q=n}else{l=c[a+24>>2]|0;g=o+n|0;o=l>>>0>g>>>0?g:l;c[m>>2]=o;q=o}o=c[a+20>>2]|0;a:do{if((o-q|0)>7){l=a+24|0;g=q;while(1){f=p+(g>>>3)|0;if(!(((fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(g&7)&-16777216|0)==-16777216)){r=g;break a}f=c[l>>2]|0;j=g+8|0;k=f>>>0>j>>>0?j:f;c[m>>2]=k;if((o-k|0)>7){g=k}else{r=k;break}}}else{r=q}}while(0);q=c[a+24>>2]|0;do{if((o-r|0)>7){g=p+(r>>>3)|0;l=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(r&7);g=r+8|0;k=q>>>0>g>>>0?g:q;c[m>>2]=k;if(!((l&-134217728|0)==-805306368)){s=k;break}if((b|0)<=0){e=1;return e|0}k=a+860|0;l=0;while(1){c[a+1120+(l<<2)>>2]=4<<c[k>>2];g=l+1|0;if((g|0)<(b|0)){l=g}else{e=1;break}}return e|0}else{s=r}}while(0);r=n-s|0;n=-s|0;b=q-s|0;if((r|0)<(n|0)){t=n}else{t=(b|0)<(r|0)?b:r}c[m>>2]=t+s;e=0;return e|0}function FLa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=c[a+552+(e*20|0)+4>>2]|0;h=a+16|0;j=c[h>>2]|0;k=c[a+24>>2]|0;l=c[a+8>>2]|0;m=l+(j>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>23;m=b[g+(n<<2)>>1]|0;o=b[g+(n<<2)+2>>1]|0;n=o<<16>>16;if(o<<16>>16<0){o=j+9|0;p=k>>>0>o>>>0?o:k;o=l+(p>>>3)|0;q=((fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(p&7)>>>((n+32|0)>>>0))+m|0;r=b[g+(q<<2)+2>>1]|0;s=b[g+(q<<2)>>1]|0;t=p}else{r=n;s=m;t=j}j=r+t|0;t=k>>>0>j>>>0?j:k;c[h>>2]=t;if(s>>>0>16>>>0){yDb(c[a+4>>2]|0,24,2348184,(j=i,i=i+24|0,c[j>>2]=0,c[j+8>>2]=e,c[j+16>>2]=a+552+(e*20|0),j)|0);i=j;u=1048575;i=f;return u|0}if((s|0)==0){u=0;i=f;return u|0}j=l+(t>>>3)|0;l=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(t&7);j=(l^-2147483648)>>31;e=t+s|0;c[h>>2]=k>>>0>e>>>0?e:k;u=((j^l)>>>((32-s|0)>>>0)^j)-j|0;i=f;return u|0}function GLa(a){a=a|0;var b=0,d=0,e=0;b=i;do{if((c[a+8>>2]|0)<=65500){if((c[a+12>>2]|0)>65500){break}d=WDb(1608)|0;if((d|0)==0){e=-12;i=b;return e|0}c[a+13080>>2]=-1023;c[a+13084>>2]=1023;sLa(d,d+12|0,1744176,1743824);sLa(d+36|0,d+48|0,1744200,1743824);sLa(d+72|0,d+328|0,1744224,1743840);sLa(d+840|0,d+1096|0,1744248,1744008);c[a+14052>>2]=d;e=0;i=b;return e|0}}while(0);yDb(a,16,2260960,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-22;i=b;return e|0}function HLa(a){a=a|0;ZDb(c[a+14052>>2]|0);return}function ILa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a+140|0;eFb(c[h>>2]|0,f,g)|0;j=c[h>>2]|0;a:do{if((c[(c[a+12>>2]|0)+12>>2]|0)==10){switch(j|0){case 298:case 30:case 3:{break};case 5:case 14:{k=5;break a;break};default:{k=6;break a}}c[b+8>>2]=1;c[d+8>>2]=1;c[b+4>>2]=1;c[d+4>>2]=1;c[b>>2]=1;c[d>>2]=1;i=e;return}else{if((j|0)==5|(j|0)==14){k=5}else{k=6}}}while(0);if((k|0)==5){c[d+8>>2]=2;c[d+4>>2]=2;c[d>>2]=2;c[b+8>>2]=1;c[b+4>>2]=1;c[b>>2]=1;i=e;return}else if((k|0)==6){c[d>>2]=2;k=2>>>((c[g>>2]|0)>>>0);c[d+4>>2]=k;c[d+8>>2]=k;c[b>>2]=2;k=2>>>((c[f>>2]|0)>>>0);c[b+4>>2]=k;c[b+8>>2]=k;i=e;return}}function JLa(b,f,g,h,j){b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=b+48|0;o=c[n>>2]|0;p=(o|0)!=108&(o|0)!=8;q=h;r=j;s=(PGb(q,r,128)|0)!=0|0;t=b+140|0;eFb(c[t>>2]|0,l,m)|0;u=b+12|0;v=c[t>>2]|0;if((c[(c[u>>2]|0)+12>>2]|0)==10){switch(v|0){case 298:case 30:case 3:{w=1;y=1;z=1;A=1;break};case 5:case 14:{B=4;break};default:{B=5}}}else{if((v|0)==5|(v|0)==14){B=4}else{B=5}}if((B|0)==4){w=2;y=2;z=1;A=1}else if((B|0)==5){w=2;y=2>>>((c[m>>2]|0)>>>0);z=2;A=2>>>((c[l>>2]|0)>>>0)}l=f|0;m=c[l>>2]|0;v=f+4|0;C=c[v>>2]|0;if((C|0)>8){D=C-8|0;E=m<<8|255}else{F=fe(255>>>((8-C|0)>>>0)|m<<C|0)|0;m=f+12|0;G=c[m>>2]|0;x=F;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;D=C+24|0;E=255}c[l>>2]=E;c[v>>2]=D;if((D|0)>8){H=D-8|0;I=E<<8|216}else{C=fe(216>>>((8-D|0)>>>0)|E<<D|0)|0;E=f+12|0;m=c[E>>2]|0;x=C;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;H=D+24|0;I=216}c[l>>2]=I;c[v>>2]=H;if((c[n>>2]|0)==108){J=H}else{D=b+224|0;do{if((c[D>>2]|0)>0){E=b+228|0;if((c[E>>2]|0)<=0){K=I;L=H;break}if((H|0)>8){M=H-8|0;N=I<<8|255}else{m=fe(I<<H|255>>>((8-H|0)>>>0)|0)|0;C=f+12|0;G=c[C>>2]|0;x=m;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;M=H+24|0;N=255}c[l>>2]=N;c[v>>2]=M;if((M|0)>8){O=M-8|0;P=N<<8|224}else{C=fe(224>>>((8-M|0)>>>0)|N<<M|0)|0;G=f+12|0;m=c[G>>2]|0;x=C;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;O=M+24|0;P=224}c[l>>2]=P;c[v>>2]=O;if((O|0)>16){Q=O-16|0;R=P<<16|16}else{G=fe(16>>>((16-O|0)>>>0)|P<<O|0)|0;m=f+12|0;C=c[m>>2]|0;x=G;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;Q=O+16|0;R=16}c[l>>2]=R;c[v>>2]=Q;L_(f,2351672,1);m=c[l>>2]|0;C=c[v>>2]|0;if((C|0)>16){S=C-16|0;T=m<<16|258}else{G=fe(258>>>((16-C|0)>>>0)|m<<C|0)|0;m=f+12|0;F=c[m>>2]|0;x=G;a[F]=x;x=x>>8;a[F+1|0]=x;x=x>>8;a[F+2|0]=x;x=x>>8;a[F+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;S=C+16|0;T=258}c[l>>2]=T;c[v>>2]=S;if((S|0)>8){U=S-8|0;V=T<<8}else{C=fe(T<<S|0)|0;m=f+12|0;F=c[m>>2]|0;x=C;a[F]=x;x=x>>8;a[F+1|0]=x;x=x>>8;a[F+2|0]=x;x=x>>8;a[F+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;U=S+24|0;V=0}c[l>>2]=V;c[v>>2]=U;m=c[D>>2]|0;if((U|0)>16){W=U-16|0;X=m|V<<16}else{F=fe(m>>>((16-U|0)>>>0)|V<<U|0)|0;C=f+12|0;G=c[C>>2]|0;x=F;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;W=U+16|0;X=m}c[l>>2]=X;c[v>>2]=W;m=c[E>>2]|0;if((W|0)>16){Y=W-16|0;Z=m|X<<16}else{E=fe(m>>>((16-W|0)>>>0)|X<<W|0)|0;C=f+12|0;G=c[C>>2]|0;x=E;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;Y=W+16|0;Z=m}c[l>>2]=Z;c[v>>2]=Y;if((Y|0)>8){_=Y-8|0;$=Z<<8}else{m=fe(Z<<Y|0)|0;C=f+12|0;G=c[C>>2]|0;x=m;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;_=Y+24|0;$=0}c[l>>2]=$;c[v>>2]=_;if((_|0)>8){aa=_-8|0;ba=$<<8}else{C=fe($<<_|0)|0;G=f+12|0;m=c[G>>2]|0;x=C;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;aa=_+24|0;ba=0}c[l>>2]=ba;c[v>>2]=aa;K=ba;L=aa}else{K=I;L=H}}while(0);if((c[b+88>>2]&8388608|0)==0){if((L|0)>8){ca=L-8|0;da=K<<8|255}else{H=fe(255>>>((8-L|0)>>>0)|K<<L|0)|0;K=f+12|0;I=c[K>>2]|0;x=H;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[K>>2]=(c[K>>2]|0)+4;ca=L+24|0;da=255}c[l>>2]=da;c[v>>2]=ca;if((ca|0)>8){ea=ca-8|0;fa=da<<8|254}else{L=fe(254>>>((8-ca|0)>>>0)|da<<ca|0)|0;da=f+12|0;K=c[da>>2]|0;x=L;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[da>>2]=(c[da>>2]|0)+4;ea=ca+24|0;fa=254}c[l>>2]=fa;c[v>>2]=ea;a:do{if((ea|0)<32){ca=fa<<ea;c[l>>2]=ca;da=f+12|0;K=ca>>>24&255;while(1){ca=c[da>>2]|0;c[da>>2]=ca+1;a[ca]=K;ca=c[l>>2]|0;c[l>>2]=ca<<8;L=(c[v>>2]|0)+8|0;c[v>>2]=L;if((L|0)>=32){ga=da;break a}K=ca>>>16&255}}else{ga=f+12|0}}while(0);c[v>>2]=32;ea=c[ga>>2]|0;c[l>>2]=0;c[v>>2]=16;L_(f,2331656,1);ga=ea;x=4096;a[ga]=x;x=x>>8;a[ga+1|0]=x}ga=c[t>>2]|0;if((ga|0)==0|(ga|0)==4|(ga|0)==5){ga=c[l>>2]|0;ea=c[v>>2]|0;if((ea|0)>8){ha=ea-8|0;ia=ga<<8|255}else{fa=fe(255>>>((8-ea|0)>>>0)|ga<<ea|0)|0;ga=f+12|0;K=c[ga>>2]|0;x=fa;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[ga>>2]=(c[ga>>2]|0)+4;ha=ea+24|0;ia=255}c[l>>2]=ia;c[v>>2]=ha;if((ha|0)>8){ja=ha-8|0;ka=ia<<8|254}else{ea=fe(254>>>((8-ha|0)>>>0)|ia<<ha|0)|0;ia=f+12|0;ga=c[ia>>2]|0;x=ea;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[ia>>2]=(c[ia>>2]|0)+4;ja=ha+24|0;ka=254}c[l>>2]=ka;c[v>>2]=ja;b:do{if((ja|0)<32){ha=ka<<ja;c[l>>2]=ha;ia=f+12|0;ga=ha>>>24&255;while(1){ha=c[ia>>2]|0;c[ia>>2]=ha+1;a[ha]=ga;ha=c[l>>2]|0;c[l>>2]=ha<<8;ea=(c[v>>2]|0)+8|0;c[v>>2]=ea;if((ea|0)>=32){la=ia;break b}ga=ha>>>16&255}}else{la=f+12|0}}while(0);c[v>>2]=32;ja=c[la>>2]|0;c[l>>2]=0;c[v>>2]=16;L_(f,2307304,1);la=ja;x=3072;a[la]=x;x=x>>8;a[la+1|0]=x}do{if((c[n>>2]|0)==10){ma=c[v>>2]|0;na=c[l>>2]|0}else{la=(PGb(q,r,128)|0)!=0;ja=c[l>>2]|0;ka=c[v>>2]|0;if((ka|0)>8){oa=ka-8|0;pa=ja<<8|255}else{ga=fe(255>>>((8-ka|0)>>>0)|ja<<ka|0)|0;ja=f+12|0;ia=c[ja>>2]|0;x=ga;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;oa=ka+24|0;pa=255}c[l>>2]=pa;c[v>>2]=oa;if((oa|0)>8){qa=oa-8|0;ra=pa<<8|219}else{ka=fe(219>>>((8-oa|0)>>>0)|pa<<oa|0)|0;ja=f+12|0;ia=c[ja>>2]|0;x=ka;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;qa=oa+24|0;ra=219}c[l>>2]=ra;c[v>>2]=qa;ja=la?132:67;if((qa|0)>16){sa=qa-16|0;ta=ra<<16|ja}else{ia=fe(ja>>>((16-qa|0)>>>0)|ra<<qa|0)|0;ka=f+12|0;ga=c[ka>>2]|0;x=ia;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[ka>>2]=(c[ka>>2]|0)+4;sa=qa+16|0;ta=ja}c[l>>2]=ta;c[v>>2]=sa;if((sa|0)>4){ua=sa-4|0;va=ta<<4}else{ja=fe(ta<<sa|0)|0;ka=f+12|0;ga=c[ka>>2]|0;x=ja;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[ka>>2]=(c[ka>>2]|0)+4;ua=sa+28|0;va=0}c[l>>2]=va;c[v>>2]=ua;if((ua|0)>4){wa=ua-4|0;xa=va<<4;ya=f+12|0}else{ka=fe(va<<ua|0)|0;ga=f+12|0;ja=c[ga>>2]|0;x=ka;a[ja]=x;x=x>>8;a[ja+1|0]=x;x=x>>8;a[ja+2|0]=x;x=x>>8;a[ja+3|0]=x;c[ga>>2]=(c[ga>>2]|0)+4;wa=ua+28|0;xa=0;ya=ga}c[l>>2]=xa;c[v>>2]=wa;ga=0;ja=xa;ka=wa;while(1){ia=e[h+((d[g+4+ga|0]|0)<<1)>>1]|0;if((ka|0)>8){za=ka-8|0;Aa=ia|ja<<8}else{ha=fe(ia>>>((8-ka|0)>>>0)|ja<<ka|0)|0;ea=c[ya>>2]|0;x=ha;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;c[ya>>2]=(c[ya>>2]|0)+4;za=ka+24|0;Aa=ia}c[l>>2]=Aa;c[v>>2]=za;ia=ga+1|0;if((ia|0)<64){ga=ia;ja=Aa;ka=za}else{break}}if(!la){ma=za;na=Aa;break}if((za|0)>4){Ba=za-4|0;Ca=Aa<<4}else{ka=fe(Aa<<za|0)|0;ja=c[ya>>2]|0;x=ka;a[ja]=x;x=x>>8;a[ja+1|0]=x;x=x>>8;a[ja+2|0]=x;x=x>>8;a[ja+3|0]=x;c[ya>>2]=(c[ya>>2]|0)+4;Ba=za+28|0;Ca=0}c[l>>2]=Ca;c[v>>2]=Ba;if((Ba|0)>4){Da=Ba-4|0;Ea=Ca<<4|1}else{ja=fe(1>>>((4-Ba|0)>>>0)|Ca<<Ba|0)|0;ka=c[ya>>2]|0;x=ja;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;c[ya>>2]=(c[ya>>2]|0)+4;Da=Ba+28|0;Ea=1}c[l>>2]=Ea;c[v>>2]=Da;ka=0;ja=Ea;ga=Da;while(1){ia=e[j+((d[g+4+ka|0]|0)<<1)>>1]|0;if((ga|0)>8){Fa=ga-8|0;Ga=ia|ja<<8}else{ea=fe(ia>>>((8-ga|0)>>>0)|ja<<ga|0)|0;ha=c[ya>>2]|0;x=ea;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;c[ya>>2]=(c[ya>>2]|0)+4;Fa=ga+24|0;Ga=ia}c[l>>2]=Ga;c[v>>2]=Fa;ia=ka+1|0;if((ia|0)<64){ka=ia;ja=Ga;ga=Fa}else{ma=Fa;na=Ga;break}}}}while(0);if((c[b+816>>2]&2|0)==0){Ha=na;Ia=ma}else{if((ma|0)>8){Ja=ma-8|0;Ka=na<<8|255}else{Ga=fe(na<<ma|255>>>((8-ma|0)>>>0)|0)|0;na=f+12|0;Fa=c[na>>2]|0;x=Ga;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;c[na>>2]=(c[na>>2]|0)+4;Ja=ma+24|0;Ka=255}c[l>>2]=Ka;c[v>>2]=Ja;if((Ja|0)>8){La=Ja-8|0;Ma=Ka<<8|221}else{ma=fe(221>>>((8-Ja|0)>>>0)|Ka<<Ja|0)|0;Ka=f+12|0;na=c[Ka>>2]|0;x=ma;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[Ka>>2]=(c[Ka>>2]|0)+4;La=Ja+24|0;Ma=221}c[l>>2]=Ma;c[v>>2]=La;if((La|0)>16){Na=La-16|0;Oa=Ma<<16|4}else{Ja=fe(4>>>((16-La|0)>>>0)|Ma<<La|0)|0;Ma=f+12|0;Ka=c[Ma>>2]|0;x=Ja;a[Ka]=x;x=x>>8;a[Ka+1|0]=x;x=x>>8;a[Ka+2|0]=x;x=x>>8;a[Ka+3|0]=x;c[Ma>>2]=(c[Ma>>2]|0)+4;Na=La+16|0;Oa=4}c[l>>2]=Oa;c[v>>2]=Na;La=(((c[b+120>>2]|0)-1|0)/(z<<3|0)|0)+1|0;if((Na|0)>16){Pa=Na-16|0;Qa=La|Oa<<16}else{Ma=fe(La>>>((16-Na|0)>>>0)|Oa<<Na|0)|0;Oa=f+12|0;Ka=c[Oa>>2]|0;x=Ma;a[Ka]=x;x=x>>8;a[Ka+1|0]=x;x=x>>8;a[Ka+2|0]=x;x=x>>8;a[Ka+3|0]=x;c[Oa>>2]=(c[Oa>>2]|0)+4;Pa=Na+16|0;Qa=La}c[l>>2]=Qa;c[v>>2]=Pa;Ha=Qa;Ia=Pa}if((Ia|0)>8){Ra=Ia-8|0;Sa=Ha<<8|255}else{Pa=fe(255>>>((8-Ia|0)>>>0)|Ha<<Ia|0)|0;Ha=f+12|0;Qa=c[Ha>>2]|0;x=Pa;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;c[Ha>>2]=(c[Ha>>2]|0)+4;Ra=Ia+24|0;Sa=255}c[l>>2]=Sa;c[v>>2]=Ra;if((Ra|0)>8){Ta=Ra-8|0;Ua=Sa<<8|196}else{Ia=fe(196>>>((8-Ra|0)>>>0)|Sa<<Ra|0)|0;Sa=f+12|0;Ha=c[Sa>>2]|0;x=Ia;a[Ha]=x;x=x>>8;a[Ha+1|0]=x;x=x>>8;a[Ha+2|0]=x;x=x>>8;a[Ha+3|0]=x;c[Sa>>2]=(c[Sa>>2]|0)+4;Ta=Ra+24|0;Ua=196}c[l>>2]=Ua;c[v>>2]=Ta;c:do{if((Ta|0)<32){Ra=Ua<<Ta;c[l>>2]=Ra;Sa=f+12|0;Ha=Ra>>>24&255;while(1){Ra=c[Sa>>2]|0;c[Sa>>2]=Ra+1;a[Ra]=Ha;Ra=c[l>>2]|0;c[l>>2]=Ra<<8;Ia=(c[v>>2]|0)+8|0;c[v>>2]=Ia;if((Ia|0)>=32){Va=Sa;break c}Ha=Ra>>>16&255}}else{Va=f+12|0}}while(0);c[v>>2]=32;Ta=c[Va>>2]|0;c[l>>2]=0;c[v>>2]=8;Ua=0;Ha=1;Sa=0;Ra=8;Ia=Ta;while(1){Qa=d[1744176+Ha|0]|0;Wa=Qa+Ua|0;if((Ra|0)>8){Xa=Ra-8|0;Ya=Qa|Sa<<8;Za=Ia}else{Pa=Ia;x=fe(Qa>>>((8-Ra|0)>>>0)|Sa<<Ra|0)|0;a[Pa]=x;x=x>>8;a[Pa+1|0]=x;x=x>>8;a[Pa+2|0]=x;x=x>>8;a[Pa+3|0]=x;Pa=(c[Va>>2]|0)+4|0;c[Va>>2]=Pa;Xa=Ra+24|0;Ya=Qa;Za=Pa}c[l>>2]=Ya;c[v>>2]=Xa;Pa=Ha+1|0;if((Pa|0)<17){Ua=Wa;Ha=Pa;Sa=Ya;Ra=Xa;Ia=Za}else{break}}if((Wa|0)>0){Ia=0;Ra=Xa;Sa=Za;Ha=Ya;while(1){Ua=d[1743824+Ia|0]|0;if((Ra|0)>8){_a=Ra-8|0;$a=Ua|Ha<<8;ab=Sa}else{Pa=Sa;x=fe(Ua>>>((8-Ra|0)>>>0)|Ha<<Ra|0)|0;a[Pa]=x;x=x>>8;a[Pa+1|0]=x;x=x>>8;a[Pa+2|0]=x;x=x>>8;a[Pa+3|0]=x;Pa=(c[Va>>2]|0)+4|0;c[Va>>2]=Pa;_a=Ra+24|0;$a=Ua;ab=Pa}c[l>>2]=$a;c[v>>2]=_a;Pa=Ia+1|0;if((Pa|0)<(Wa|0)){Ia=Pa;Ra=_a;Sa=ab;Ha=$a}else{bb=_a;cb=$a;db=ab;break}}}else{bb=Xa;cb=Ya;db=Za}if((bb|0)>4){eb=bb-4|0;fb=cb<<4;gb=db}else{Za=db;x=fe(cb<<bb|0)|0;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;Za=(c[Va>>2]|0)+4|0;c[Va>>2]=Za;eb=bb+28|0;fb=0;gb=Za}c[l>>2]=fb;c[v>>2]=eb;if((eb|0)>4){hb=eb-4|0;ib=fb<<4|1;jb=gb}else{Za=gb;x=fe(1>>>((4-eb|0)>>>0)|fb<<eb|0)|0;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;Za=(c[Va>>2]|0)+4|0;c[Va>>2]=Za;hb=eb+28|0;ib=1;jb=Za}c[l>>2]=ib;c[v>>2]=hb;Za=0;eb=1;fb=ib;ib=hb;hb=jb;while(1){jb=d[1744200+eb|0]|0;kb=jb+Za|0;if((ib|0)>8){lb=ib-8|0;mb=jb|fb<<8;nb=hb}else{gb=hb;x=fe(jb>>>((8-ib|0)>>>0)|fb<<ib|0)|0;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;gb=(c[Va>>2]|0)+4|0;c[Va>>2]=gb;lb=ib+24|0;mb=jb;nb=gb}c[l>>2]=mb;c[v>>2]=lb;gb=eb+1|0;if((gb|0)<17){Za=kb;eb=gb;fb=mb;ib=lb;hb=nb}else{break}}if((kb|0)>0){hb=0;ib=lb;fb=nb;eb=mb;while(1){Za=d[1743824+hb|0]|0;if((ib|0)>8){ob=ib-8|0;pb=Za|eb<<8;qb=fb}else{gb=fb;x=fe(Za>>>((8-ib|0)>>>0)|eb<<ib|0)|0;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;gb=(c[Va>>2]|0)+4|0;c[Va>>2]=gb;ob=ib+24|0;pb=Za;qb=gb}c[l>>2]=pb;c[v>>2]=ob;gb=hb+1|0;if((gb|0)<(kb|0)){hb=gb;ib=ob;fb=qb;eb=pb}else{rb=ob;sb=pb;tb=qb;break}}}else{rb=lb;sb=mb;tb=nb}if((rb|0)>4){ub=rb-4|0;vb=sb<<4|1;wb=tb}else{nb=tb;x=fe(1>>>((4-rb|0)>>>0)|sb<<rb|0)|0;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=(c[Va>>2]|0)+4|0;c[Va>>2]=nb;ub=rb+28|0;vb=1;wb=nb}c[l>>2]=vb;c[v>>2]=ub;if((ub|0)>4){xb=ub-4|0;yb=vb<<4;zb=wb}else{nb=wb;x=fe(vb<<ub|0)|0;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=(c[Va>>2]|0)+4|0;c[Va>>2]=nb;xb=ub+28|0;yb=0;zb=nb}c[l>>2]=yb;c[v>>2]=xb;nb=0;ub=1;vb=yb;yb=xb;xb=zb;while(1){zb=d[1744224+ub|0]|0;Ab=zb+nb|0;if((yb|0)>8){Bb=yb-8|0;Cb=zb|vb<<8;Db=xb}else{wb=xb;x=fe(zb>>>((8-yb|0)>>>0)|vb<<yb|0)|0;a[wb]=x;x=x>>8;a[wb+1|0]=x;x=x>>8;a[wb+2|0]=x;x=x>>8;a[wb+3|0]=x;wb=(c[Va>>2]|0)+4|0;c[Va>>2]=wb;Bb=yb+24|0;Cb=zb;Db=wb}c[l>>2]=Cb;c[v>>2]=Bb;wb=ub+1|0;if((wb|0)<17){nb=Ab;ub=wb;vb=Cb;yb=Bb;xb=Db}else{break}}if((Ab|0)>0){xb=0;yb=Bb;vb=Db;ub=Cb;while(1){nb=d[1743840+xb|0]|0;if((yb|0)>8){Eb=yb-8|0;Fb=nb|ub<<8;Gb=vb}else{wb=vb;x=fe(nb>>>((8-yb|0)>>>0)|ub<<yb|0)|0;a[wb]=x;x=x>>8;a[wb+1|0]=x;x=x>>8;a[wb+2|0]=x;x=x>>8;a[wb+3|0]=x;wb=(c[Va>>2]|0)+4|0;c[Va>>2]=wb;Eb=yb+24|0;Fb=nb;Gb=wb}c[l>>2]=Fb;c[v>>2]=Eb;wb=xb+1|0;if((wb|0)<(Ab|0)){xb=wb;yb=Eb;vb=Gb;ub=Fb}else{Hb=Eb;Ib=Fb;Jb=Gb;break}}}else{Hb=Bb;Ib=Cb;Jb=Db}if((Hb|0)>4){Kb=Hb-4|0;Lb=Ib<<4|1;Mb=Jb}else{Db=Jb;x=fe(1>>>((4-Hb|0)>>>0)|Ib<<Hb|0)|0;a[Db]=x;x=x>>8;a[Db+1|0]=x;x=x>>8;a[Db+2|0]=x;x=x>>8;a[Db+3|0]=x;Db=(c[Va>>2]|0)+4|0;c[Va>>2]=Db;Kb=Hb+28|0;Lb=1;Mb=Db}c[l>>2]=Lb;c[v>>2]=Kb;if((Kb|0)>4){Nb=Kb-4|0;Ob=Lb<<4|1;Pb=Mb}else{Db=Mb;x=fe(1>>>((4-Kb|0)>>>0)|Lb<<Kb|0)|0;a[Db]=x;x=x>>8;a[Db+1|0]=x;x=x>>8;a[Db+2|0]=x;x=x>>8;a[Db+3|0]=x;Db=(c[Va>>2]|0)+4|0;c[Va>>2]=Db;Nb=Kb+28|0;Ob=1;Pb=Db}c[l>>2]=Ob;c[v>>2]=Nb;Db=0;Kb=1;Lb=Ob;Ob=Nb;Nb=Pb;while(1){Pb=d[1744248+Kb|0]|0;Qb=Pb+Db|0;if((Ob|0)>8){Rb=Ob-8|0;Sb=Pb|Lb<<8;Tb=Nb}else{Mb=Nb;x=fe(Pb>>>((8-Ob|0)>>>0)|Lb<<Ob|0)|0;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;Mb=(c[Va>>2]|0)+4|0;c[Va>>2]=Mb;Rb=Ob+24|0;Sb=Pb;Tb=Mb}c[l>>2]=Sb;c[v>>2]=Rb;Mb=Kb+1|0;if((Mb|0)<17){Db=Qb;Kb=Mb;Lb=Sb;Ob=Rb;Nb=Tb}else{break}}if((Qb|0)>0){Nb=0;Ob=Rb;Rb=Sb;Sb=Tb;while(1){Tb=d[1744008+Nb|0]|0;if((Ob|0)>8){Ub=Ob-8|0;Vb=Tb|Rb<<8;Wb=Sb}else{Lb=Sb;x=fe(Tb>>>((8-Ob|0)>>>0)|Rb<<Ob|0)|0;a[Lb]=x;x=x>>8;a[Lb+1|0]=x;x=x>>8;a[Lb+2|0]=x;x=x>>8;a[Lb+3|0]=x;Lb=(c[Va>>2]|0)+4|0;c[Va>>2]=Lb;Ub=Ob+24|0;Vb=Tb;Wb=Lb}c[l>>2]=Vb;c[v>>2]=Ub;Lb=Nb+1|0;if((Lb|0)<(Qb|0)){Nb=Lb;Ob=Ub;Rb=Vb;Sb=Wb}else{break}}}Wb=Ta;x=de(Wa+70+kb+Ab+Qb&65535|0)|0;a[Wb]=x;x=x>>8;a[Wb+1|0]=x;Wb=c[n>>2]|0;do{if((Wb|0)==8){Qb=c[l>>2]|0;Ab=c[v>>2]|0;if((Ab|0)>8){Xb=Ab-8|0;Yb=Qb<<8|255}else{kb=fe(255>>>((8-Ab|0)>>>0)|Qb<<Ab|0)|0;Qb=f+12|0;Wa=c[Qb>>2]|0;x=kb;a[Wa]=x;x=x>>8;a[Wa+1|0]=x;x=x>>8;a[Wa+2|0]=x;x=x>>8;a[Wa+3|0]=x;c[Qb>>2]=(c[Qb>>2]|0)+4;Xb=Ab+24|0;Yb=255}c[l>>2]=Yb;c[v>>2]=Xb;if((Xb|0)>8){Zb=Xb-8|0;_b=Yb<<8|192;break}else{Ab=fe(192>>>((8-Xb|0)>>>0)|Yb<<Xb|0)|0;Qb=f+12|0;Wa=c[Qb>>2]|0;x=Ab;a[Wa]=x;x=x>>8;a[Wa+1|0]=x;x=x>>8;a[Wa+2|0]=x;x=x>>8;a[Wa+3|0]=x;c[Qb>>2]=(c[Qb>>2]|0)+4;Zb=Xb+24|0;_b=192;break}}else if((Wb|0)==10){Qb=c[l>>2]|0;Wa=c[v>>2]|0;if((Wa|0)>8){$b=Wa-8|0;ac=Qb<<8|255}else{Ab=fe(255>>>((8-Wa|0)>>>0)|Qb<<Wa|0)|0;Qb=f+12|0;kb=c[Qb>>2]|0;x=Ab;a[kb]=x;x=x>>8;a[kb+1|0]=x;x=x>>8;a[kb+2|0]=x;x=x>>8;a[kb+3|0]=x;c[Qb>>2]=(c[Qb>>2]|0)+4;$b=Wa+24|0;ac=255}c[l>>2]=ac;c[v>>2]=$b;if(($b|0)>8){Zb=$b-8|0;_b=ac<<8|195;break}else{Wa=fe(195>>>((8-$b|0)>>>0)|ac<<$b|0)|0;Qb=f+12|0;kb=c[Qb>>2]|0;x=Wa;a[kb]=x;x=x>>8;a[kb+1|0]=x;x=x>>8;a[kb+2|0]=x;x=x>>8;a[kb+3|0]=x;c[Qb>>2]=(c[Qb>>2]|0)+4;Zb=$b+24|0;_b=195;break}}else{yDb(0,0,2321264,(bc=i,i=i+24|0,c[bc>>2]=2185656,c[bc+8>>2]=2108464,c[bc+16>>2]=255,bc)|0);i=bc;Cd()}}while(0);c[l>>2]=_b;c[v>>2]=Zb;if((Zb|0)>16){cc=Zb-16|0;dc=_b<<16|17}else{$b=fe(17>>>((16-Zb|0)>>>0)|_b<<Zb|0)|0;_b=f+12|0;ac=c[_b>>2]|0;x=$b;a[ac]=x;x=x>>8;a[ac+1|0]=x;x=x>>8;a[ac+2|0]=x;x=x>>8;a[ac+3|0]=x;c[_b>>2]=(c[_b>>2]|0)+4;cc=Zb+16|0;dc=17}c[l>>2]=dc;c[v>>2]=cc;do{if((o|0)==108|(o|0)==8){B=208}else{Zb=c[t>>2]|0;if(!((Zb|0)==298|(Zb|0)==30|(Zb|0)==3)){B=208;break}if((cc|0)>8){ec=cc-8|0;fc=dc<<8|9;break}else{Zb=fe(9>>>((8-cc|0)>>>0)|dc<<cc|0)|0;_b=f+12|0;ac=c[_b>>2]|0;x=Zb;a[ac]=x;x=x>>8;a[ac+1|0]=x;x=x>>8;a[ac+2|0]=x;x=x>>8;a[ac+3|0]=x;c[_b>>2]=(c[_b>>2]|0)+4;ec=cc+24|0;fc=9;break}}}while(0);do{if((B|0)==208){if((cc|0)>8){ec=cc-8|0;fc=dc<<8|8;break}else{t=fe(8>>>((8-cc|0)>>>0)|dc<<cc|0)|0;_b=f+12|0;ac=c[_b>>2]|0;x=t;a[ac]=x;x=x>>8;a[ac+1|0]=x;x=x>>8;a[ac+2|0]=x;x=x>>8;a[ac+3|0]=x;c[_b>>2]=(c[_b>>2]|0)+4;ec=cc+24|0;fc=8;break}}}while(0);c[l>>2]=fc;c[v>>2]=ec;cc=c[b+124>>2]|0;if((ec|0)>16){gc=ec-16|0;hc=fc<<16|cc}else{dc=fe(fc<<ec|cc>>>((16-ec|0)>>>0)|0)|0;fc=f+12|0;B=c[fc>>2]|0;x=dc;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[fc>>2]=(c[fc>>2]|0)+4;gc=ec+16|0;hc=cc}c[l>>2]=hc;c[v>>2]=gc;cc=c[b+120>>2]|0;if((gc|0)>16){ic=gc-16|0;jc=hc<<16|cc}else{ec=fe(hc<<gc|cc>>>((16-gc|0)>>>0)|0)|0;hc=f+12|0;fc=c[hc>>2]|0;x=ec;a[fc]=x;x=x>>8;a[fc+1|0]=x;x=x>>8;a[fc+2|0]=x;x=x>>8;a[fc+3|0]=x;c[hc>>2]=(c[hc>>2]|0)+4;ic=gc+16|0;jc=cc}c[l>>2]=jc;c[v>>2]=ic;if((ic|0)>8){kc=ic-8|0;lc=jc<<8|3}else{cc=fe(3>>>((8-ic|0)>>>0)|jc<<ic|0)|0;jc=f+12|0;gc=c[jc>>2]|0;x=cc;a[gc]=x;x=x>>8;a[gc+1|0]=x;x=x>>8;a[gc+2|0]=x;x=x>>8;a[gc+3|0]=x;c[jc>>2]=(c[jc>>2]|0)+4;kc=ic+24|0;lc=3}c[l>>2]=lc;c[v>>2]=kc;if((kc|0)>8){mc=kc-8|0;nc=lc<<8|1}else{ic=fe(1>>>((8-kc|0)>>>0)|lc<<kc|0)|0;lc=f+12|0;jc=c[lc>>2]|0;x=ic;a[jc]=x;x=x>>8;a[jc+1|0]=x;x=x>>8;a[jc+2|0]=x;x=x>>8;a[jc+3|0]=x;c[lc>>2]=(c[lc>>2]|0)+4;mc=kc+24|0;nc=1}c[l>>2]=nc;c[v>>2]=mc;if((mc|0)>4){oc=mc-4|0;pc=nc<<4|z}else{kc=fe(z>>>((4-mc|0)>>>0)|nc<<mc|0)|0;nc=f+12|0;lc=c[nc>>2]|0;x=kc;a[lc]=x;x=x>>8;a[lc+1|0]=x;x=x>>8;a[lc+2|0]=x;x=x>>8;a[lc+3|0]=x;c[nc>>2]=(c[nc>>2]|0)+4;oc=mc+28|0;pc=z}c[l>>2]=pc;c[v>>2]=oc;if((oc|0)>4){qc=oc-4|0;rc=pc<<4|w}else{z=fe(w>>>((4-oc|0)>>>0)|pc<<oc|0)|0;pc=f+12|0;mc=c[pc>>2]|0;x=z;a[mc]=x;x=x>>8;a[mc+1|0]=x;x=x>>8;a[mc+2|0]=x;x=x>>8;a[mc+3|0]=x;c[pc>>2]=(c[pc>>2]|0)+4;qc=oc+28|0;rc=w}c[l>>2]=rc;c[v>>2]=qc;if((qc|0)>8){sc=qc-8|0;tc=rc<<8}else{w=fe(rc<<qc|0)|0;rc=f+12|0;oc=c[rc>>2]|0;x=w;a[oc]=x;x=x>>8;a[oc+1|0]=x;x=x>>8;a[oc+2|0]=x;x=x>>8;a[oc+3|0]=x;c[rc>>2]=(c[rc>>2]|0)+4;sc=qc+24|0;tc=0}c[l>>2]=tc;c[v>>2]=sc;if((sc|0)>8){uc=sc-8|0;vc=tc<<8|2}else{qc=fe(2>>>((8-sc|0)>>>0)|tc<<sc|0)|0;tc=f+12|0;rc=c[tc>>2]|0;x=qc;a[rc]=x;x=x>>8;a[rc+1|0]=x;x=x>>8;a[rc+2|0]=x;x=x>>8;a[rc+3|0]=x;c[tc>>2]=(c[tc>>2]|0)+4;uc=sc+24|0;vc=2}c[l>>2]=vc;c[v>>2]=uc;if((uc|0)>4){wc=uc-4|0;xc=vc<<4|A}else{sc=fe(A>>>((4-uc|0)>>>0)|vc<<uc|0)|0;vc=f+12|0;tc=c[vc>>2]|0;x=sc;a[tc]=x;x=x>>8;a[tc+1|0]=x;x=x>>8;a[tc+2|0]=x;x=x>>8;a[tc+3|0]=x;c[vc>>2]=(c[vc>>2]|0)+4;wc=uc+28|0;xc=A}c[l>>2]=xc;c[v>>2]=wc;if((wc|0)>4){yc=wc-4|0;zc=xc<<4|y}else{uc=fe(y>>>((4-wc|0)>>>0)|xc<<wc|0)|0;xc=f+12|0;vc=c[xc>>2]|0;x=uc;a[vc]=x;x=x>>8;a[vc+1|0]=x;x=x>>8;a[vc+2|0]=x;x=x>>8;a[vc+3|0]=x;c[xc>>2]=(c[xc>>2]|0)+4;yc=wc+28|0;zc=y}c[l>>2]=zc;c[v>>2]=yc;wc=p?0:s;if((yc|0)>8){Ac=yc-8|0;Bc=zc<<8|wc}else{s=fe(wc>>>((8-yc|0)>>>0)|zc<<yc|0)|0;zc=f+12|0;xc=c[zc>>2]|0;x=s;a[xc]=x;x=x>>8;a[xc+1|0]=x;x=x>>8;a[xc+2|0]=x;x=x>>8;a[xc+3|0]=x;c[zc>>2]=(c[zc>>2]|0)+4;Ac=yc+24|0;Bc=wc}c[l>>2]=Bc;c[v>>2]=Ac;if((Ac|0)>8){Cc=Ac-8|0;Dc=Bc<<8|3}else{yc=fe(3>>>((8-Ac|0)>>>0)|Bc<<Ac|0)|0;Bc=f+12|0;zc=c[Bc>>2]|0;x=yc;a[zc]=x;x=x>>8;a[zc+1|0]=x;x=x>>8;a[zc+2|0]=x;x=x>>8;a[zc+3|0]=x;c[Bc>>2]=(c[Bc>>2]|0)+4;Cc=Ac+24|0;Dc=3}c[l>>2]=Dc;c[v>>2]=Cc;if((Cc|0)>4){Ec=Cc-4|0;Fc=Dc<<4|A}else{Ac=fe(A>>>((4-Cc|0)>>>0)|Dc<<Cc|0)|0;Dc=f+12|0;Bc=c[Dc>>2]|0;x=Ac;a[Bc]=x;x=x>>8;a[Bc+1|0]=x;x=x>>8;a[Bc+2|0]=x;x=x>>8;a[Bc+3|0]=x;c[Dc>>2]=(c[Dc>>2]|0)+4;Ec=Cc+28|0;Fc=A}c[l>>2]=Fc;c[v>>2]=Ec;if((Ec|0)>4){Gc=Ec-4|0;Hc=Fc<<4|y}else{A=fe(y>>>((4-Ec|0)>>>0)|Fc<<Ec|0)|0;Fc=f+12|0;Cc=c[Fc>>2]|0;x=A;a[Cc]=x;x=x>>8;a[Cc+1|0]=x;x=x>>8;a[Cc+2|0]=x;x=x>>8;a[Cc+3|0]=x;c[Fc>>2]=(c[Fc>>2]|0)+4;Gc=Ec+28|0;Hc=y}c[l>>2]=Hc;c[v>>2]=Gc;if((Gc|0)>8){Ic=Gc-8|0;Jc=Hc<<8|wc}else{y=fe(wc>>>((8-Gc|0)>>>0)|Hc<<Gc|0)|0;Hc=f+12|0;Ec=c[Hc>>2]|0;x=y;a[Ec]=x;x=x>>8;a[Ec+1|0]=x;x=x>>8;a[Ec+2|0]=x;x=x>>8;a[Ec+3|0]=x;c[Hc>>2]=(c[Hc>>2]|0)+4;Ic=Gc+24|0;Jc=wc}c[l>>2]=Jc;c[v>>2]=Ic;if((Ic|0)>8){Kc=Ic-8|0;Lc=Jc<<8|255}else{wc=fe(255>>>((8-Ic|0)>>>0)|Jc<<Ic|0)|0;Jc=f+12|0;Gc=c[Jc>>2]|0;x=wc;a[Gc]=x;x=x>>8;a[Gc+1|0]=x;x=x>>8;a[Gc+2|0]=x;x=x>>8;a[Gc+3|0]=x;c[Jc>>2]=(c[Jc>>2]|0)+4;Kc=Ic+24|0;Lc=255}c[l>>2]=Lc;c[v>>2]=Kc;if((Kc|0)>8){Mc=Kc-8|0;Nc=Lc<<8|218}else{Ic=fe(218>>>((8-Kc|0)>>>0)|Lc<<Kc|0)|0;Lc=f+12|0;Jc=c[Lc>>2]|0;x=Ic;a[Jc]=x;x=x>>8;a[Jc+1|0]=x;x=x>>8;a[Jc+2|0]=x;x=x>>8;a[Jc+3|0]=x;c[Lc>>2]=(c[Lc>>2]|0)+4;Mc=Kc+24|0;Nc=218}c[l>>2]=Nc;c[v>>2]=Mc;if((Mc|0)>16){Oc=Mc-16|0;Pc=Nc<<16|12}else{Kc=fe(12>>>((16-Mc|0)>>>0)|Nc<<Mc|0)|0;Nc=f+12|0;Lc=c[Nc>>2]|0;x=Kc;a[Lc]=x;x=x>>8;a[Lc+1|0]=x;x=x>>8;a[Lc+2|0]=x;x=x>>8;a[Lc+3|0]=x;c[Nc>>2]=(c[Nc>>2]|0)+4;Oc=Mc+16|0;Pc=12}c[l>>2]=Pc;c[v>>2]=Oc;if((Oc|0)>8){Qc=Oc-8|0;Rc=Pc<<8|3}else{Mc=fe(3>>>((8-Oc|0)>>>0)|Pc<<Oc|0)|0;Pc=f+12|0;Nc=c[Pc>>2]|0;x=Mc;a[Nc]=x;x=x>>8;a[Nc+1|0]=x;x=x>>8;a[Nc+2|0]=x;x=x>>8;a[Nc+3|0]=x;c[Pc>>2]=(c[Pc>>2]|0)+4;Qc=Oc+24|0;Rc=3}c[l>>2]=Rc;c[v>>2]=Qc;if((Qc|0)>8){Sc=Qc-8|0;Tc=Rc<<8|1}else{Oc=fe(1>>>((8-Qc|0)>>>0)|Rc<<Qc|0)|0;Rc=f+12|0;Pc=c[Rc>>2]|0;x=Oc;a[Pc]=x;x=x>>8;a[Pc+1|0]=x;x=x>>8;a[Pc+2|0]=x;x=x>>8;a[Pc+3|0]=x;c[Rc>>2]=(c[Rc>>2]|0)+4;Sc=Qc+24|0;Tc=1}c[l>>2]=Tc;c[v>>2]=Sc;if((Sc|0)>4){Uc=Sc-4|0;Vc=Tc<<4}else{Qc=fe(Tc<<Sc|0)|0;Tc=f+12|0;Rc=c[Tc>>2]|0;x=Qc;a[Rc]=x;x=x>>8;a[Rc+1|0]=x;x=x>>8;a[Rc+2|0]=x;x=x>>8;a[Rc+3|0]=x;c[Tc>>2]=(c[Tc>>2]|0)+4;Uc=Sc+28|0;Vc=0}c[l>>2]=Vc;c[v>>2]=Uc;if((Uc|0)>4){Wc=Uc-4|0;Xc=Vc<<4}else{Sc=fe(Vc<<Uc|0)|0;Vc=f+12|0;Tc=c[Vc>>2]|0;x=Sc;a[Tc]=x;x=x>>8;a[Tc+1|0]=x;x=x>>8;a[Tc+2|0]=x;x=x>>8;a[Tc+3|0]=x;c[Vc>>2]=(c[Vc>>2]|0)+4;Wc=Uc+28|0;Xc=0}c[l>>2]=Xc;c[v>>2]=Wc;if((Wc|0)>8){Yc=Wc-8|0;Zc=Xc<<8|2}else{Uc=fe(2>>>((8-Wc|0)>>>0)|Xc<<Wc|0)|0;Xc=f+12|0;Vc=c[Xc>>2]|0;x=Uc;a[Vc]=x;x=x>>8;a[Vc+1|0]=x;x=x>>8;a[Vc+2|0]=x;x=x>>8;a[Vc+3|0]=x;c[Xc>>2]=(c[Xc>>2]|0)+4;Yc=Wc+24|0;Zc=2}c[l>>2]=Zc;c[v>>2]=Yc;if((Yc|0)>4){_c=Yc-4|0;$c=Zc<<4|1}else{Wc=fe(1>>>((4-Yc|0)>>>0)|Zc<<Yc|0)|0;Zc=f+12|0;Xc=c[Zc>>2]|0;x=Wc;a[Xc]=x;x=x>>8;a[Xc+1|0]=x;x=x>>8;a[Xc+2|0]=x;x=x>>8;a[Xc+3|0]=x;c[Zc>>2]=(c[Zc>>2]|0)+4;_c=Yc+28|0;$c=1}c[l>>2]=$c;c[v>>2]=_c;Yc=p&1^1;if((_c|0)>4){ad=_c-4|0;bd=$c<<4|Yc}else{p=fe(Yc>>>((4-_c|0)>>>0)|$c<<_c|0)|0;$c=f+12|0;Zc=c[$c>>2]|0;x=p;a[Zc]=x;x=x>>8;a[Zc+1|0]=x;x=x>>8;a[Zc+2|0]=x;x=x>>8;a[Zc+3|0]=x;c[$c>>2]=(c[$c>>2]|0)+4;ad=_c+28|0;bd=Yc}c[l>>2]=bd;c[v>>2]=ad;if((ad|0)>8){cd=ad-8|0;dd=bd<<8|3}else{_c=fe(3>>>((8-ad|0)>>>0)|bd<<ad|0)|0;bd=f+12|0;$c=c[bd>>2]|0;x=_c;a[$c]=x;x=x>>8;a[$c+1|0]=x;x=x>>8;a[$c+2|0]=x;x=x>>8;a[$c+3|0]=x;c[bd>>2]=(c[bd>>2]|0)+4;cd=ad+24|0;dd=3}c[l>>2]=dd;c[v>>2]=cd;if((cd|0)>4){ed=cd-4|0;fd=dd<<4|1}else{ad=fe(1>>>((4-cd|0)>>>0)|dd<<cd|0)|0;dd=f+12|0;bd=c[dd>>2]|0;x=ad;a[bd]=x;x=x>>8;a[bd+1|0]=x;x=x>>8;a[bd+2|0]=x;x=x>>8;a[bd+3|0]=x;c[dd>>2]=(c[dd>>2]|0)+4;ed=cd+28|0;fd=1}c[l>>2]=fd;c[v>>2]=ed;if((ed|0)>4){gd=ed-4|0;hd=fd<<4|Yc}else{cd=fe(Yc>>>((4-ed|0)>>>0)|fd<<ed|0)|0;fd=f+12|0;dd=c[fd>>2]|0;x=cd;a[dd]=x;x=x>>8;a[dd+1|0]=x;x=x>>8;a[dd+2|0]=x;x=x>>8;a[dd+3|0]=x;c[fd>>2]=(c[fd>>2]|0)+4;gd=ed+28|0;hd=Yc}c[l>>2]=hd;c[v>>2]=gd;if((o|0)==108|(o|0)==8){id=0}else{id=(c[b+216>>2]|0)+1|0}if((gd|0)>8){jd=gd-8|0;kd=hd<<8|id}else{Yc=fe(hd<<gd|id>>>((8-gd|0)>>>0)|0)|0;hd=f+12|0;ed=c[hd>>2]|0;x=Yc;a[ed]=x;x=x>>8;a[ed+1|0]=x;x=x>>8;a[ed+2|0]=x;x=x>>8;a[ed+3|0]=x;c[hd>>2]=(c[hd>>2]|0)+4;jd=gd+24|0;kd=id}c[l>>2]=kd;c[v>>2]=jd;id=c[n>>2]|0;do{if((id|0)==8){if((jd|0)>8){ld=jd-8|0;md=kd<<8|63;break}else{n=fe(kd<<jd|63>>>((8-jd|0)>>>0)|0)|0;gd=f+12|0;hd=c[gd>>2]|0;x=n;a[hd]=x;x=x>>8;a[hd+1|0]=x;x=x>>8;a[hd+2|0]=x;x=x>>8;a[hd+3|0]=x;c[gd>>2]=(c[gd>>2]|0)+4;ld=jd+24|0;md=63;break}}else if((id|0)==10){if((jd|0)>8){ld=jd-8|0;md=kd<<8;break}else{gd=fe(kd<<jd|0)|0;hd=f+12|0;n=c[hd>>2]|0;x=gd;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[hd>>2]=(c[hd>>2]|0)+4;ld=jd+24|0;md=0;break}}else{yDb(0,0,2321264,(bc=i,i=i+24|0,c[bc>>2]=2185656,c[bc+8>>2]=2108464,c[bc+16>>2]=312,bc)|0);i=bc;Cd()}}while(0);c[l>>2]=md;c[v>>2]=ld;if((ld|0)>8){nd=ld-8|0;od=md<<8}else{jd=fe(md<<ld|0)|0;md=f+12|0;kd=c[md>>2]|0;x=jd;a[kd]=x;x=x>>8;a[kd+1|0]=x;x=x>>8;a[kd+2|0]=x;x=x>>8;a[kd+3|0]=x;c[md>>2]=(c[md>>2]|0)+4;nd=ld+24|0;od=0}c[l>>2]=od;c[v>>2]=nd;J=nd}if(!((o|0)==108|(o|0)==8)){i=k;return}o=c[b+60>>2]|0;if((c[(c[u>>2]|0)+52>>2]|0)!=14672){yDb(0,0,2321264,(bc=i,i=i+24|0,c[bc>>2]=2050784,c[bc+8>>2]=2108464,c[bc+16>>2]=320,bc)|0);i=bc;Cd()}c[o+14056>>2]=32-J+((c[f+12>>2]|0)-(c[f+8>>2]|0)<<3)>>3;f=o+944|0;if((c[f>>2]|0)<=1){i=k;return}J=o+816|0;o=1;do{c[(c[J+(o<<2)>>2]|0)+14056>>2]=0;o=o+1|0;}while((o|0)<(c[f>>2]|0));i=k;return}function KLa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;e=b+8|0;f=c[e>>2]|0;g=-(f+d|0)|0;h=g&3;i=b+4|0;j=c[i>>2]|0;k=b+12|0;l=j&7;if((l|0)==0){m=j;n=b|0}else{o=(1<<l)-1|0;p=b|0;b=c[p>>2]|0;if((j|0)>(l|0)){q=j-l|0;r=b<<l|o}else{s=fe(o>>>((l-j|0)>>>0)|b<<j|0)|0;b=c[k>>2]|0;x=s;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;q=32-l+j|0;r=o}c[p>>2]=r;c[i>>2]=q;m=q;n=p}a:do{if((m|0)<32){p=c[n>>2]<<m;c[n>>2]=p;q=p>>>24&255;while(1){p=c[k>>2]|0;c[k>>2]=p+1;a[p]=q;p=c[n>>2]|0;c[n>>2]=p<<8;r=(c[i>>2]|0)+8|0;c[i>>2]=r;if((r|0)>=32){break a}q=p>>>16&255}}}while(0);c[i>>2]=32;c[n>>2]=0;m=c[k>>2]|0;q=32-(d<<3)-32+(m-(c[e>>2]|0)<<3)|0;e=q>>3;if((q|0)>0&(h|0)!=0){q=-e|0;p=g&3;g=p>>>0>1>>>0?-p|0:-1;p=g>>>0<q>>>0?q:g;g=0;q=0;do{g=((a[f+(q+d)|0]|0)==-1)+g|0;q=q+1|0;}while((q|0)<(e|0)&(q|0)<(h|0));t=g;u=-p|0}else{t=0;u=0}p=e-15|0;if((u|0)<(p|0)){g=d+4|0;h=d+8|0;q=d+12|0;r=u+(e-16-u&-16)|0;o=t;j=u;do{l=c[f+(j+d)>>2]|0;b=c[f+(g+j)>>2]|0;s=c[f+(h+j)>>2]|0;v=c[f+(q+j)>>2]|0;w=((b&252645135&b>>>4)+16843009&269488144)+((l&252645135&l>>>4)+16843009&269488144)+((s&252645135&s>>>4)+16843009&269488144)+((v&252645135&v>>>4)+16843009&269488144)|0;v=(w>>>4)+(w>>>20)|0;o=((v>>>8)+v&255)+o|0;j=j+16|0;}while((j|0)<(p|0));y=o;z=r+16|0}else{y=t;z=u}if((z|0)<(e|0)){u=y;t=z;while(1){z=((a[f+(t+d)|0]|0)==-1)+u|0;r=t+1|0;if((r|0)<(e|0)){u=z;t=r}else{A=z;break}}}else{A=y}if((A|0)==0){return}c[i>>2]=32;c[n>>2]=0;c[k>>2]=m+A;m=A;A=e;while(1){e=A-1|0;k=e+d|0;n=a[f+k|0]|0;if(n<<24>>24==-1){a[f+(m+d+e)|0]=0;B=m-1|0}else{B=m}a[f+(k+B)|0]=n;if((B|0)==0){break}else{m=B;A=e}}return}function LLa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b+784|0;e=(c[b+12480>>2]|0)-((c[b+12476>>2]|0)==0)|0;f=b+14056|0;KLa(d,c[f>>2]|0);do{if((c[(c[b+4>>2]|0)+816>>2]&2|0)!=0){if((e|0)>=(c[b+120>>2]|0)){break}g=e&7|208;h=d|0;i=c[h>>2]|0;j=b+788|0;k=c[j>>2]|0;if((k|0)>8){l=k-8|0;m=i<<8|255}else{n=fe(255>>>((8-k|0)>>>0)|i<<k|0)|0;i=b+796|0;o=c[i>>2]|0;x=n;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;l=k+24|0;m=255}c[h>>2]=m;c[j>>2]=l;if((l|0)>8){p=l-8|0;q=m<<8|g}else{k=fe(g>>>((8-l|0)>>>0)|m<<l|0)|0;i=b+796|0;o=c[i>>2]|0;x=k;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;p=l+24|0;q=g}c[h>>2]=q;c[j>>2]=p}}while(0);c[f>>2]=32-(c[b+788>>2]|0)+((c[b+796>>2]|0)-(c[b+792>>2]|0)<<3)>>3;f=128<<c[b+14176>>2];c[b+9860>>2]=f;c[b+9864>>2]=f;c[b+9868>>2]=f;return}function MLa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b|0;e=c[d>>2]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)>8){h=g-8|0;i=e<<8|255}else{j=fe(255>>>((8-g|0)>>>0)|e<<g|0)|0;e=b+12|0;k=c[e>>2]|0;x=j;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[e>>2]=(c[e>>2]|0)+4;h=g+24|0;i=255}c[d>>2]=i;c[f>>2]=h;if((h|0)>8){l=h-8|0;m=i<<8|217;c[d>>2]=m;c[f>>2]=l;return}else{g=fe(217>>>((8-h|0)>>>0)|i<<h|0)|0;i=b+12|0;b=c[i>>2]|0;x=g;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;l=h+24|0;m=217;c[d>>2]=m;c[f>>2]=l;return}}function NLa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;if((f|0)==0){i=d[g]|0;j=e[h>>1]|0;k=b|0;l=c[k>>2]|0;m=b+4|0;n=c[m>>2]|0;if((n|0)>(i|0)){o=n-i|0;p=l<<i|j}else{q=fe(j>>>((i-n|0)>>>0)|l<<n|0)|0;l=b+12|0;r=c[l>>2]|0;x=q;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;o=32-i+n|0;p=j}c[k>>2]=p;c[m>>2]=o;return}if((f|0)<0){s=-f|0;t=f-1|0}else{s=f;t=f}f=(s&65280|0)==0;o=(f?0:8)+(d[1191992+(f?s:s>>>8)|0]|0)|0;s=o+1|0;f=d[g+s|0]|0;g=e[h+(s<<1)>>1]|0;h=b|0;m=c[h>>2]|0;p=b+4|0;k=c[p>>2]|0;if((k|0)>(f|0)){u=k-f|0;v=m<<f|g}else{j=fe(g>>>((f-k|0)>>>0)|m<<k|0)|0;m=b+12|0;n=c[m>>2]|0;x=j;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;u=32-f+k|0;v=g}c[h>>2]=v;c[p>>2]=u;g=(1<<s)-1&t;if((u|0)>(s|0)){w=u-s|0;y=v<<s|g}else{t=fe(g>>>((s-u|0)>>>0)|v<<u|0)|0;v=b+12|0;b=c[v>>2]|0;x=t;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;w=31-o+u|0;y=g}c[h>>2]=y;c[p>>2]=w;return}function OLa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+14212|0;e=(c[d>>2]|0)==3;PLa(a,b|0,0);do{if(e){PLa(a,b+256|0,2);PLa(a,b+512|0,4);PLa(a,b+1024|0,8);PLa(a,b+640|0,5);PLa(a,b+1152|0,9);if((c[a+12476>>2]<<4|8|0)>=(c[a+8>>2]|0)){break}PLa(a,b+128|0,1);PLa(a,b+384|0,3);PLa(a,b+768|0,6);PLa(a,b+1280|0,10);PLa(a,b+896|0,7);PLa(a,b+1408|0,11)}else{PLa(a,b+128|0,1);PLa(a,b+256|0,2);PLa(a,b+384|0,3);PLa(a,b+512|0,4);if((c[d>>2]|0)==1){PLa(a,b+640|0,5);break}else{PLa(a,b+768|0,6);PLa(a,b+640|0,5);PLa(a,b+896|0,7);break}}}while(0);b=((c[a+796>>2]|0)-(c[a+792>>2]|0)<<3)+(32-(c[a+788>>2]|0))|0;d=a+13700|0;e=c[d>>2]|0;c[d>>2]=b;d=a+13672|0;c[d>>2]=(c[d>>2]|0)-e+b;return}function PLa(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=c[f+14052>>2]|0;if((h|0)<4){j=b[g>>1]|0;k=f+9860|0;l=f+784|0;NLa(l,j-(c[k>>2]|0)|0,i|0,i+12|0);m=i+328|0;n=i+72|0;o=j;p=k;q=l}else{l=b[g>>1]|0;k=f+9860+((h&1)+1<<2)|0;j=f+784|0;NLa(j,l-(c[k>>2]|0)|0,i+36|0,i+48|0);m=i+1096|0;n=i+840|0;o=l;p=k;q=j}c[p>>2]=o;o=c[f+180+(h<<2)>>2]|0;do{if((o|0)>=1){h=q|0;p=q+4|0;j=q+12|0;k=n+240|0;l=m+480|0;i=0;r=1;while(1){s=b[g+(d[f+368+r|0]<<1)>>1]|0;t=s<<16>>16;if(s<<16>>16==0){u=i+1|0}else{if((i|0)>15){v=i;w=c[h>>2]|0;y=c[p>>2]|0;while(1){z=d[k]|0;A=e[l>>1]|0;if((y|0)>(z|0)){B=y-z|0;C=w<<z|A}else{D=fe(A>>>((z-y|0)>>>0)|w<<y|0)|0;E=c[j>>2]|0;x=D;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;B=32-z+y|0;C=A}c[h>>2]=C;c[p>>2]=B;A=v-16|0;if((A|0)>15){v=A;w=C;y=B}else{break}}F=i&15}else{F=i}if(s<<16>>16<0){G=t-1|0;H=-t|0}else{G=t;H=t}y=(H&65280|0)==0;w=(d[1191992+(y?H:H>>>8)|0]|0)+(y?0:8)|0;y=w+1|0;v=y|F<<4;A=d[n+v|0]|0;z=e[m+(v<<1)>>1]|0;v=c[h>>2]|0;E=c[p>>2]|0;if((E|0)>(A|0)){I=E-A|0;J=v<<A|z}else{D=fe(z>>>((A-E|0)>>>0)|v<<E|0)|0;v=c[j>>2]|0;x=D;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;I=32-A+E|0;J=z}c[h>>2]=J;c[p>>2]=I;z=(1<<y)-1&G;if((I|0)>(y|0)){K=I-y|0;L=J<<y|z}else{E=fe(z>>>((y-I|0)>>>0)|J<<I|0)|0;y=c[j>>2]|0;x=E;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;K=31-w+I|0;L=z}c[h>>2]=L;c[p>>2]=K;u=0}z=r+1|0;if((z|0)>(o|0)){break}else{i=u;r=z}}if(!((o|0)>62&(u|0)==0)){break}return}}while(0);u=d[n]|0;n=e[m>>1]|0;m=q|0;o=c[m>>2]|0;K=q+4|0;L=c[K>>2]|0;if((L|0)>(u|0)){M=L-u|0;N=o<<u|n}else{I=fe(n>>>((u-L|0)>>>0)|o<<L|0)|0;o=q+12|0;q=c[o>>2]|0;x=I;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;M=32-u+L|0;N=n}c[m>>2]=N;c[K>>2]=M;return}function QLa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+24|0;g=f|0;h=f+16|0;j=c[a+60>>2]|0;eFb(c[a+140>>2]|0,f+8|0,h)|0;if((c[(c[j+4>>2]|0)+88>>2]&16384|0)!=0){k=-22;i=f;return k|0}l=PCb(d)|0;c[g>>2]=l;if((l|0)==0){k=-12;i=f;return k|0}d=j+120|0;m=j+12|0;j=ba(((c[d>>2]<<3)-(((c[m>>2]|0)/2|0)&7)<<1)-1|0,c[l+32>>2]|0)|0;n=l|0;c[n>>2]=(c[n>>2]|0)+j;j=c[g>>2]|0;n=j+32|0;c[n>>2]=-(c[n>>2]|0);n=ba((ba((c[d>>2]<<3)-(((c[m>>2]|0)/2|0)&7)|0,2>>>((c[h>>2]|0)>>>0))|0)-1|0,c[j+36>>2]|0)|0;l=j+4|0;c[l>>2]=(c[l>>2]|0)+n;n=c[g>>2]|0;l=n+36|0;c[l>>2]=-(c[l>>2]|0);l=ba((ba((c[d>>2]<<3)-(((c[m>>2]|0)/2|0)&7)|0,2>>>((c[h>>2]|0)>>>0))|0)-1|0,c[n+40>>2]|0)|0;h=n+8|0;c[h>>2]=(c[h>>2]|0)+l;l=c[g>>2]|0;h=l+40|0;c[h>>2]=-(c[h>>2]|0);h=rPa(a,b,l,e)|0;JCb(g);k=h;i=f;return k|0}function RLa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;f=i;if((c[e+12>>2]|0)<224){yDb(a,16,2260736,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1;i=f;return h|0}j=e|0;k=emb(c[j>>2]|0,26)|0;l=c[j>>2]|0;j=l+26|0;if(!(k<<16>>16==(d[j]|d[j+1|0]<<8)<<16>>16<<16>>16)){yDb(a,16,2321216,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=f;return h|0}g=e+8|0;a=c[g>>2]|0;j=e+16|0;e=c[j>>2]|0;k=l+(a>>>3)|0;m=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(a&7);k=a+24|0;a=e>>>0>k>>>0?k:e;c[g>>2]=a;if(!((m&-256|0)==-126718208)){h=-1094995529;i=f;return h|0}m=l+(a>>>3)|0;k=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(a&7)>>>24;m=a+8|0;c[g>>2]=e>>>0>m>>>0?m:e;c[b>>2]=k;if((k|0)==186){c[b+4>>2]=24;c[b+8>>2]=0;e=c[g>>2]|0;m=c[j>>2]|0;a=l+(e>>>3)|0;n=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(e&7)>>>28;a=e+4|0;c[g>>2]=m>>>0>a>>>0?a:m;if((n|0)==15){o=0}else{o=((n&8|0)!=0?44100:48e3)<<(n&7)}c[b+12>>2]=o;c[b+16>>2]=0;o=c[j>>2]|0;m=(c[g>>2]|0)+4|0;a=o>>>0>m>>>0?m:o;c[g>>2]=a;m=l+(a>>>3)|0;e=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(a&7)>>>30;m=a+2|0;c[g>>2]=o>>>0>m>>>0?m:o;c[b+24>>2]=e;e=c[g>>2]|0;o=c[j>>2]|0;m=l+(e>>>3)|0;a=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(e&7)>>>30;m=e+2|0;c[g>>2]=o>>>0>m>>>0?m:o;c[b+28>>2]=a;a=c[g>>2]|0;o=c[j>>2]|0;m=l+(a>>>3)|0;e=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(a&7);m=e>>>27;p=a+5|0;c[g>>2]=o>>>0>p>>>0?p:o;c[b+20>>2]=m;o=m&1;m=e>>>28;p=e>>>29;a=e>>>30&1;c[b+40>>2]=(e>>31&2|-p&1)+(-a&2)+(-o&2|-m&1);q=ZGb(0,0,o,0)|0;o=F&0;r=ZGb(0,0,m&1,0)|0;m=F&0;s=ZGb(0,0,p&1,0)|0;p=F&0;t=ZGb(0,0,a,0)|0;a=F&0;u=ZGb(0,0,e>>>31,0)|0;e=b+56|0;c[e>>2]=q&3|u&20480|r&4|s&8|t&1536;c[e+4>>2]=o|F&0|m|p|a;a=c[g>>2]|0;p=c[j>>2]|0;m=l+(a>>>3)|0;o=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(a&7)>>>30;m=a+2|0;c[g>>2]=p>>>0>m>>>0?m:p;c[b+32>>2]=o;o=c[g>>2]|0;p=c[j>>2]|0;m=l+(o>>>3)|0;a=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(o&7);m=o+13|0;c[g>>2]=p>>>0>m>>>0?m:p;p=a>>>19&1;m=a>>>20;o=a>>>21;e=a>>>22&1;t=a>>>23&1;s=a>>>24&1;r=a>>>25&1;u=a>>>26;q=a>>>27;v=a>>>28&1;w=a>>>29&1;x=a>>>30;y=a>>>31;c[b+44>>2]=(-o&1)+y+(-u&1)+(-q&1)+(-x&1)+(-e&2)+(-t&2)+(-s&2)+(-r&2)+(-v&2)+(-w&2)+(-p&2|-m&1);a=ZGb(0,0,p,0)|0;p=F&0;z=ZGb(0,0,m&1,0)|0;m=F&0;A=ZGb(0,0,o&1,0)|0;o=F&0;B=ZGb(0,0,e,0)|0;e=F&0;C=ZGb(0,0,t,0)|0;t=F&0;D=ZGb(0,0,s,0)|0;s=F&0;E=ZGb(0,0,r,0)|0;r=F&0;G=ZGb(0,0,u&1,0)|0;u=F&0;H=ZGb(0,0,q&1,0)|0;q=F&0;I=ZGb(0,0,v,0)|0;v=F&6;J=ZGb(0,0,w,0)|0;w=F&1;K=ZGb(0,0,x&1,0)|0;x=F&0;L=ZGb(0,0,y,0)|0;y=b+64|0;c[y>>2]=a&3|L&0|z&4|A&8|B&1536|C&20480|D&192|E&48|G&256|H&2048|I&0|J&-2147483648|K&8192;c[y+4>>2]=p|F&8|m|o|e|t|s|r|u|q|v|w|x;M=n}else if((k|0)==187){k=c[g>>2]|0;n=c[j>>2]|0;x=l+(k>>>3)|0;w=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(k&7)>>>28;x=k+4|0;c[g>>2]=n>>>0>x>>>0?x:n;c[b+4>>2]=d[678256+w|0]|0;w=c[g>>2]|0;n=c[j>>2]|0;x=l+(w>>>3)|0;k=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(w&7)>>>28;x=w+4|0;c[g>>2]=n>>>0>x>>>0?x:n;c[b+8>>2]=d[678256+k|0]|0;k=c[g>>2]|0;n=c[j>>2]|0;x=l+(k>>>3)|0;w=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(k&7)>>>28;x=k+4|0;c[g>>2]=n>>>0>x>>>0?x:n;if((w|0)==15){N=0}else{N=((w&8|0)!=0?44100:48e3)<<(w&7)}c[b+12>>2]=N;N=c[g>>2]|0;n=c[j>>2]|0;x=l+(N>>>3)|0;k=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(N&7)>>>28;x=N+4|0;c[g>>2]=n>>>0>x>>>0?x:n;if((k|0)==15){O=0}else{O=((k&8|0)!=0?44100:48e3)<<(k&7)}c[b+16>>2]=O;O=c[j>>2]|0;k=(c[g>>2]|0)+11|0;n=O>>>0>k>>>0?k:O;c[g>>2]=n;k=l+(n>>>3)|0;x=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(n&7)>>>27;k=n+5|0;c[g>>2]=O>>>0>k>>>0?k:O;c[b+20>>2]=x;c[b+36>>2]=d[678272+x|0]|0;O=1184840+(x<<3)|0;x=c[O+4>>2]|0;k=b+48|0;c[k>>2]=c[O>>2];c[k+4>>2]=x;M=w}else{h=-1094995529;i=f;return h|0}w=M&7;c[b+72>>2]=40<<w;c[b+76>>2]=64<<w;w=c[g>>2]|0;M=-w|0;x=c[j>>2]|0;k=x-w|0;if((M|0)>48){P=M}else{P=(k|0)<48?k:48}k=P+w|0;c[g>>2]=k;w=(d[l+(k>>>3)|0]|0)<<(k&7)>>>7;c[g>>2]=((k|0)<(x|0))+k;c[b+80>>2]=w&1;w=c[g>>2]|0;k=c[j>>2]|0;x=l+(w>>>3)|0;P=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(w&7)>>>17;x=w+15|0;c[g>>2]=k>>>0>x>>>0?x:k;c[b+84>>2]=((ba(P,c[b+12>>2]|0)|0)+8|0)>>>4;P=c[g>>2]|0;k=c[j>>2]|0;x=l+(P>>>3)|0;l=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(P&7)>>>28;x=P+4|0;c[g>>2]=k>>>0>x>>>0?x:k;c[b+88>>2]=l;l=c[g>>2]|0;b=-l|0;k=(c[j>>2]|0)-l|0;if((b|0)>92){Q=b}else{Q=(k|0)<92?k:92}c[g>>2]=Q+l;h=0;i=f;return h|0}function SLa(a){a=a|0;dmb();return 0}function TLa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=i;i=i+136|0;l=k|0;m=k+8|0;n=k+16|0;o=k+40|0;c[l>>2]=h;c[m>>2]=j;p=c[b>>2]|0;c[g>>2]=0;if((j|0)==0){q=0;i=k;return q|0}r=p+44|0;if((c[r>>2]|0)==0){a:do{if((j|0)>0){s=p+16|0;t=p+4|0;u=0;v=c[s>>2]|0;while(1){w=d[h+u|0]|0|v<<8;c[s>>2]=w;if((w&-2|0)==-126718022){if(((c[t>>2]|0)+u|0)>6){break}}x=u+1|0;if((x|0)<(c[m>>2]|0)){u=x;v=w}else{break a}}c[r>>2]=1;c[p+40>>2]=0;v=u-7|0;WRa(p,v,l,m)|0;q=v;i=k;return q|0}}while(0);if(!((WRa(p,-100,l,m)|0)==-1)){yDb(e,24,2185624,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}q=c[m>>2]|0;i=k;return q|0}h=p+40|0;v=c[h>>2]|0;t=p;do{if((v|0)==0){s=p+24|0;if((c[s>>2]|0)>0){w=p+28|0;x=p;z=p+4|0;do{A=c[w>>2]|0;c[w>>2]=A+1;B=c[x>>2]|0;C=a[B+A|0]|0;A=c[z>>2]|0;c[z>>2]=A+1;a[B+A|0]=C;C=(c[s>>2]|0)-1|0;c[s>>2]=C;}while((C|0)>0);D=c[m>>2]|0;E=z}else{D=j;E=p+4|0}s=c[E>>2]|0;if((D+s|0)<2){if(!((WRa(t,-100,l,m)|0)==-1)){yDb(e,24,2185624,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}q=c[m>>2]|0;i=k;return q|0}do{if((s|0)>0){x=(d[c[p>>2]|0]|0)<<8;if((s|0)<=1){F=x;G=26;break}H=(c[p>>2]|0)+1|0;I=x}else{F=(d[c[l>>2]|0]|0)<<8;G=26}}while(0);if((G|0)==26){H=(c[l>>2]|0)+(1-s)|0;I=F}z=d[H]|0|I&3840;x=z<<1;c[h>>2]=x;if((z|0)==0){break}z=x-s|0;c[h>>2]=z;J=z;K=c[m>>2]|0;G=29}else{J=v;K=j;G=29}}while(0);b:do{if((G|0)==29){j=(J|0)>(K|0)?-100:J;if((WRa(t,j,l,m)|0)<0){c[h>>2]=(c[h>>2]|0)-(c[m>>2]|0);q=c[m>>2]|0;i=k;return q|0}c[h>>2]=0;v=c[l>>2]|0;I=v+4|0;H=I;do{if(((fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)&-2|0)==-126718022){F=(c[m>>2]<<3)-32|0;D=F>>>0>2147483639>>>0|(I|0)==0;E=D?0:I;z=D?0:F;c[n>>2]=E;c[n+12>>2]=z;c[n+16>>2]=z+8;c[n+4>>2]=E+(z>>3);c[n+8>>2]=0;if((RLa(e,o,n)|0)<0){break b}z=c[o+4>>2]|0;c[e+796>>2]=z;c[e+420>>2]=(z|0)>16?2:1;c[e+412>>2]=c[o+12>>2];c[b+304>>2]=c[o+72>>2];z=e+416|0;if((c[z>>2]|0)==0){G=41}else{E=e+448|0;if((c[E>>2]|0)==0&(c[E+4>>2]|0)==0){G=41}}c:do{if((G|0)==41){E=c[e+440>>2]|0;F=(E-1|0)>>>0<2>>>0;if((c[o>>2]|0)==187){do{if(F){if((c[o+88>>2]|0)<=1){break}c[z>>2]=2;D=e+448|0;c[D>>2]=3;c[D+4>>2]=0;break c}}while(0);D=e+456|0;x=c[D>>2]|0;w=c[D+4>>2]|0;do{if(((x|0)!=0|(w|0)!=0)&((x&3|0)==(x|0)&(w&0|0)==(w|0))){if((c[o+88>>2]|0)<=1){break}c[z>>2]=2;D=e+448|0;c[D>>2]=3;c[D+4>>2]=0;break c}}while(0);c[z>>2]=c[o+36>>2];w=o+48|0;x=c[w+4>>2]|0;D=e+448|0;c[D>>2]=c[w>>2];c[D+4>>2]=x;break}do{if(F){if((c[o+88>>2]|0)<=1){break}c[z>>2]=2;x=e+448|0;c[x>>2]=3;c[x+4>>2]=0;break c}}while(0);do{if((E|0)>0){F=c[o+40>>2]|0;if((E|0)>(F|0)){break}c[z>>2]=F;F=o+56|0;x=c[F+4>>2]|0;D=e+448|0;c[D>>2]=c[F>>2];c[D+4>>2]=x;break c}}while(0);E=e+456|0;x=c[E>>2]|0;D=c[E+4>>2]|0;do{if(((x|0)!=0|(D|0)!=0)&((x&3|0)==(x|0)&(D&0|0)==(D|0))){if((c[o+88>>2]|0)<=1){break}c[z>>2]=2;E=e+448|0;c[E>>2]=3;c[E+4>>2]=0;break c}}while(0);E=c[o+44>>2]|0;do{if((E|0)==0){F=o+56|0;L=c[F+4>>2]|0;M=c[F>>2]|0}else{if(!((x|0)==0&(D|0)==0)){F=o+56|0;w=c[F>>2]|0;u=c[F+4>>2]|0;if((w&x|0)==(x|0)&(u&D|0)==(D|0)){L=u;M=w;break}}c[z>>2]=E;w=o+64|0;u=c[w+4>>2]|0;F=e+448|0;c[F>>2]=c[w>>2];c[F+4>>2]=u;break c}}while(0);c[z>>2]=c[o+40>>2];E=e+448|0;c[E>>2]=M;c[E+4>>2]=L}}while(0);if((c[o+80>>2]|0)==0){c[e+72>>2]=c[o+84>>2]}c[p+48>>2]=c[o+88>>2];N=c[l>>2]|0}else{z=c[p+48>>2]|0;if((z|0)>-1){E=0;D=-1;x=0;while(1){u=a[v+x|0]|0;F=x+2|0;w=u^E^a[v+(x+1)|0];if((D|0)<0|u<<24>>24<0){O=x+4|0;P=a[v+F|0]^w^a[v+(x+3)|0]}else{O=F;P=w}w=D+1|0;if((w|0)<(z|0)){E=P;D=w;x=O}else{Q=P;break}}}else{Q=0}x=Q&255;if((x>>>4^x&15|0)==15){N=v;break}yDb(e,32,2108432,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;break b}}while(0);c[f>>2]=N;c[g>>2]=c[m>>2];q=j;i=k;return q|0}}while(0);c[r>>2]=0;q=1;i=k;return q|0}function ULa(a){a=a|0;var b=0;b=c[a+60>>2]|0;if((c[1282500]|0)==0){c[1282501]=5097008;c[1282503]=512;N_(513e4,9,18,1185097,2,1,1185096,2,1,0,0,0,4)|0;c[1282506]=5094960;c[1282508]=512;N_(5130020,9,16,1185133,2,1,1185132,2,1,0,0,0,4)|0;c[1282511]=5092912;c[1282513]=512;N_(5130040,9,15,1185169,2,1,1185168,2,1,0,0,0,4)|0}dmb();c[b>>2]=a;c[b+1548>>2]=-1;c[b+3076>>2]=-1;c[b+4604>>2]=-1;XLa(b+11332|0);return 0}function VLa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0;k=i;i=i+1480|0;l=k|0;m=k+1344|0;n=k+1440|0;o=k+1464|0;p=k+1472|0;q=c[j+24>>2]|0;r=c[j+28>>2]|0;j=c[f+60>>2]|0;s=j;if((r|0)<4){t=-1094995529;i=k;return t|0}u=q;v=((de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)<<1&8190;if(v>>>0<4>>>0|v>>>0>r>>>0){t=-1094995529;i=k;return t|0}r=q+4|0;u=(v<<3)-32|0;w=u>>>0>2147483639>>>0|(r|0)==0;y=w?0:r;r=w?0:u;u=n|0;c[u>>2]=y;w=n+12|0;c[w>>2]=r;z=n+16|0;c[z>>2]=r|8;A=n+4|0;c[A>>2]=y+(r>>3);r=n+8|0;c[r>>2]=0;y=j+4|0;c[y>>2]=0;B=c[u>>2]|0;C=c[r>>2]|0;D=c[z>>2]|0;E=B+(C>>>3)|0;G=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(C&7)>>>16;E=C+16|0;C=D>>>0>E>>>0?E:D;D=B+(C>>>3)|0;a:do{if(((fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>>17|G<<15|0)==2084124637){B=j;E=RLa(c[B>>2]|0,m,n)|0;do{if((E|0)==0){H=m+4|0;I=c[H>>2]|0;if((I|0)==0){yDb(c[B>>2]|0,16,2024928,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}if((c[m+8>>2]|0)>(I|0)){yDb(c[B>>2]|0,16,2021528,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}I=c[m+16>>2]|0;K=c[m+12>>2]|0;do{if((I|0)==0){if((K|0)!=0){L=K;break}yDb(c[B>>2]|0,16,2013656,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}else{if((I|0)==(K|0)){L=I;break}yDb(c[B>>2]|0,16,2017744,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}}while(0);if((L|0)>192e3){yDb(c[B>>2]|0,16,2009480,(J=i,i=i+16|0,c[J>>2]=L,c[J+8>>2]=192e3,J)|0);i=J;break a}I=m+72|0;K=c[I>>2]|0;if((K|0)>160){yDb(c[B>>2]|0,16,1999120,(J=i,i=i+16|0,c[J>>2]=K,c[J+8>>2]=160,J)|0);i=J;break a}M=c[m+76>>2]|0;if((M|0)>256){yDb(c[B>>2]|0,16,1994944,(J=i,i=i+16|0,c[J>>2]=M,c[J+8>>2]=256,J)|0);i=J;break a}N=m+88|0;O=c[N>>2]|0;if((O|0)==0){break a}P=c[B>>2]|0;if((c[P+48>>2]|0)==86045&(O|0)>2){yDb(P,16,1991680,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}if((O|0)>3){DDb(P,1988200,(J=i,i=i+8|0,c[J>>2]=O,J)|0);i=J;break a}c[j+12>>2]=K;c[j+16>>2]=M;a[j+9|0]=O;M=j+10|0;a[M]=O+255;c[P+412>>2]=L;c[P+424>>2]=c[I>>2];c[P+796>>2]=c[H>>2];c[P+420>>2]=(c[H>>2]|0)>16?2:1;a[j+8|0]=1;a[j+24|0]=0;a[j+1552|0]=0;a[j+3080|0]=0;P=c[B>>2]|0;I=c[m>>2]|0;do{if((c[P+48>>2]|0)==86045){if((I|0)!=187){DDb(P,1983752,(J=i,i=i+8|0,c[J>>2]=I,J)|0);i=J;break a}O=(c[N>>2]|0)>1;if(O){K=j+40|0;c[K>>2]=3;c[K+4>>2]=0}K=m+48|0;Q=c[K+4>>2]|0;R=s+24+((O&1)*1528|0)+16|0;c[R>>2]=c[K>>2];c[R+4>>2]=Q}else{if((I|0)!=186){DDb(P,1980992,(J=i,i=i+8|0,c[J>>2]=I,J)|0);i=J;break a}Q=c[N>>2]|0;R=(Q|0)>1;K=R&1;do{if(R){O=j+40|0;c[O>>2]=3;c[O+4>>2]=0;if((Q|0)<=2){break}O=m+64|0;S=c[O>>2]|0;T=c[O+4>>2]|0;if((S|0)==0&(T|0)==0){O=m+56|0;U=c[O+4>>2]|0;V=j+3096|0;c[V>>2]=c[O>>2];c[V+4>>2]=U;break}else{U=j+3096|0;c[U>>2]=S;c[U+4>>2]=T;break}}}while(0);Q=m+56|0;R=c[Q>>2]|0;T=c[Q+4>>2]|0;Q=s+24+(K*1528|0)+16|0;c[Q>>2]=R;c[Q+4>>2]=T;Q=c[B>>2]|0;if(!((c[Q+416>>2]|0)<3&((R|0)==4&(T|0)==0))){break}if((a[M]|0)!=1){break}yDb(Q,48,1978256,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;a[M]=0;Q=c[B>>2]|0;if((c[Q+416>>2]|0)!=2){break}T=Q+448|0;c[T>>2]=3;c[T+4>>2]=0}}while(0);M=c[m+20>>2]|0;if((M|0)>17){W=(M|0)<21|0}else{W=0}a[j+11|0]=W;M=j+48|0;c[M>>2]=0;I=j+1576|0;c[I>>2]=0;P=j+3104|0;c[P>>2]=0;if((c[(c[B>>2]|0)+48>>2]|0)!=86061){break}H=c[N>>2]|0;do{if((H|0)>2){T=m+64|0;if(!((c[T>>2]&1536|0)==1536&(c[T+4>>2]&0|0)==0)){X=50;break}if((c[m+32>>2]|0)!=2){X=49;break}c[P>>2]=5;X=49}else{X=49}}while(0);if((X|0)==49){if((H|0)>1){X=50}}do{if((X|0)==50){P=m+56|0;if(!((c[P>>2]&1536|0)==1536&(c[P+4>>2]&0|0)==0)){break}if((c[m+28>>2]|0)!=2){break}c[I>>2]=5}}while(0);if((H|0)<=0){break}I=c[m+24>>2]|0;if((I|0)==2){c[M>>2]=6;break}else if((I|0)==1){c[M>>2]=1;break}else{break}}else{if((E|0)<0){break a}}}while(0);c[y>>2]=1;Y=32;X=59}else{Y=4;X=59}}while(0);b:do{if((X|0)==59){if((a[j+8|0]|0)==0){yDb(c[j>>2]|0,24,2050736,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;c[h>>2]=0;t=v;i=k;return t|0}m=j+9|0;c:do{if((a[m]|0)==0){Z=0}else{W=j;L=v-Y|0;G=j+10|0;C=0;D=0;E=0;while(1){B=c[r>>2]|0;I=c[u>>2]|0;P=d[I+(B>>>3)|0]|0;N=c[z>>2]|0;T=((B|0)<(N|0))+B|0;c[r>>2]=T;Q=d[I+(T>>>3)|0]<<(T&7)>>>7;R=((T|0)<(N|0))+T|0;c[r>>2]=R;T=Q&1;Q=d[I+(R>>>3)|0]<<(R&7)>>>7;U=((R|0)<(N|0))+R+1|0;R=N>>>0>U>>>0?U:N;c[r>>2]=R;U=I+(R>>>3)|0;I=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(R&7)>>>20;U=R+12|0;R=N>>>0>U>>>0?U:N;c[r>>2]=R;U=I<<1;if((P&128>>>((B&7)>>>0)|0)==0){_=C+2|0}else{$=c[W>>2]|0;if((c[$+48>>2]|0)==86045){X=65;break}B=R+16|0;c[r>>2]=N>>>0>B>>>0?B:N;_=C+4|0}if((T|0)==(c[y>>2]|0)){X=68;break}if((U+Y+_|0)>>>0>v>>>0){yDb(c[W>>2]|0,16,1939328,(J=i,i=i+8|0,c[J>>2]=E,J)|0);i=J;aa=L-_|0}else{aa=U}if(aa>>>0<D>>>0){X=72;break}if(E>>>0>(d[G]|0)>>>0){ba=D}else{a[o+E|0]=Q&1;b[p+(E<<1)>>1]=aa-D;ba=aa}Q=E+1|0;if(Q>>>0<(d[m]|0)>>>0){C=_;D=ba;E=Q}else{Z=_;break c}}if((X|0)==65){yDb($,16,2005272,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break b}else if((X|0)==68){yDb(c[W>>2]|0,16,1967640,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break b}else if((X|0)==72){yDb(f,16,1915112,(J=i,i=i+8|0,c[J>>2]=E,J)|0);i=J;break b}}}while(0);m=hmb(q,4)|0;D=((hmb(q+Y|0,Z)|0)^m)&255;if((D>>>4^D&15|0)!=15){yDb(f,16,1894648,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break}D=j+10|0;m=j+24|0;C=j+4608|0;G=C;L=j+12|0;M=j;H=l+640|0;Q=H;U=l+1312|0;T=j+11332|0;N=j+11|0;B=0;R=q+(Z+Y)|0;d:while(1){P=e[p+(B<<1)>>1]|0;I=P<<3;S=(R|0)==0?0:I;c[u>>2]=R;c[w>>2]=S;c[z>>2]=S+8;c[A>>2]=R+(S>>>3);c[r>>2]=0;S=m+(B*1528|0)+1514|0;TGb(C|0,0,68)|0;b[S>>1]=0;V=m+(B*1528|0)|0;O=s+24+(B*1528|0)+1220|0;ca=s+24+(B*1528|0)+1514|0;da=s+24+(B*1528|0)+1512|0;ea=s+24+(B*1528|0)+5|0;fa=s+24+(B*1528|0)+4|0;ga=s+24+(B*1528|0)+1222|0;ha=s+24+(B*1528|0)+1221|0;ia=s+24+(B*1528|0)+6|0;ja=s+24+(B*1528|0)+2|0;ka=B&255;la=s+24+(B*1528|0)+16|0;ma=s+24+(B*1528|0)+1212|0;na=s+24+(B*1528|0)+1216|0;oa=s+24+(B*1528|0)+1524|0;pa=s+24+(B*1528|0)+7|0;qa=s+24+(B*1528|0)+1516|0;ra=s+24+(B*1528|0)+1504|0;sa=s+24+(B*1528|0)+11|0;ta=s+24+(B*1528|0)+10|0;ua=s+24+(B*1528|0)+9|0;va=s+24+(B*1528|0)+12|0;wa=c[r>>2]|0;xa=R;ya=c[z>>2]|0;e:while(1){za=d[xa+(wa>>>3)|0]|0;Aa=((wa|0)<(ya|0))+wa|0;c[r>>2]=Aa;do{if((za&128>>>((wa&7)>>>0)|0)!=0){Ba=d[xa+(Aa>>>3)|0]|0;Ca=((Aa|0)<(ya|0))+Aa|0;c[r>>2]=Ca;if((Ba&128>>>((Aa&7)>>>0)|0)==0){if((a[V]|0)==0){X=243;break e}}else{Da=c[M>>2]|0;Ea=(c[Da+48>>2]|0)==86045?5:7;Ba=xa+(Ca>>>3)|0;Fa=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ca&7)>>>19;Ba=Ca+13|0;Ga=ya>>>0>Ba>>>0?Ba:ya;c[r>>2]=Ga;if((Fa|0)!=6389){X=83;break e}Ba=d[xa+(Ga>>>3)|0]<<(Ga&7)>>>7;Ha=((Ga|0)<(ya|0))+Ga|0;c[r>>2]=Ha;Ga=Ba&1;Ba=Ga&65535;b[ja>>1]=Ba;Ia=c[M>>2]|0;if(!((c[Ia+48>>2]|0)!=86045|(Ga|0)==0)){X=85;break e}Ga=Ha+16|0;Ha=ya>>>0>Ga>>>0?Ga:ya;c[r>>2]=Ha;Ga=xa+(Ha>>>3)|0;Ja=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ha&7)>>>28;Ga=Ha+4|0;Ha=ya>>>0>Ga>>>0?Ga:ya;c[r>>2]=Ha;Ga=xa+(Ha>>>3)|0;Ka=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ha&7);La=Ka>>>28;Ga=Ha+4|0;Ha=ya>>>0>Ga>>>0?Ga:ya;c[r>>2]=Ha;Ga=xa+(Ha>>>3)|0;Ma=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ha&7)>>>28;Ga=Ha+4|0;c[r>>2]=ya>>>0>Ga>>>0?Ga:ya;if(Ma>>>0>Ea>>>0){X=87;break e}if((La|0)!=(Ma|0)){X=89;break e}if(Ka>>>0>1610612735>>>0&Ba<<16>>16==0){X=91;break e}if(Ja>>>0>La>>>0){X=93;break e}a[fa]=Ja;Ja=La&255;a[ea]=Ja;a[ia]=Ja;Ja=c[Ia+440>>2]|0;do{if((Ja|0)>0){Ba=La+1|0;if((Ja|0)>(Ba|0)){X=98;break}if(!((d[D]|0)>>>0>B>>>0)){X=98;break}yDb(Ia,48,2044672,(J=i,i=i+16|0,c[J>>2]=Ba,c[J+8>>2]=B,J)|0);i=J;a[D]=ka}else{X=98}}while(0);do{if((X|0)==98){X=0;Ja=Ia+456|0;Ba=c[Ja>>2]|0;Ka=c[Ja+4>>2]|0;if((Ba|0)==0&(Ka|0)==0){break}Ja=c[la>>2]|0;Ma=c[la+4>>2]|0;if(!((Ja&Ba|0)==(Ba|0)&(Ma&Ka|0)==(Ka|0))){break}if(!((d[D]|0)>>>0>B>>>0)){break}yDb(Ia,48,2039672,(J=i,i=i+32|0,c[J>>2]=La+1,c[J+8>>2]=Ja,c[J+16>>2]=Ma,c[J+24>>2]=B,J)|0);i=J;a[D]=ka}}while(0);Ma=c[r>>2]|0;Ja=c[z>>2]|0;Ka=(c[u>>2]|0)+(Ma>>>3)|0;Ba=(fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ma&7)>>>28;Ka=Ma+4|0;c[r>>2]=Ja>>>0>Ka>>>0?Ka:Ja;a[ma]=Ba;Ba=c[r>>2]|0;Ja=c[z>>2]|0;Ka=c[u>>2]|0;Ma=Ka+(Ba>>>3)|0;Ga=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ba&7)>>>9;Ma=Ba+23|0;c[r>>2]=Ja>>>0>Ma>>>0?Ma:Ja;c[na>>2]=Ga;Ga=c[z>>2]|0;Ja=(c[r>>2]|0)+19|0;Ma=Ga>>>0>Ja>>>0?Ja:Ga;c[r>>2]=Ma;Ja=d[Ka+(Ma>>>3)|0]<<(Ma&7)>>>7;c[r>>2]=((Ma|0)<(Ga|0))+Ma;a[O]=Ja&1;Ja=c[r>>2]|0;Ma=c[z>>2]|0;Ga=(c[u>>2]|0)+(Ja>>>3)|0;Ka=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ja&7)>>>24;Ga=Ja+8|0;Ja=Ma>>>0>Ga>>>0?Ga:Ma;c[r>>2]=Ja;do{if((d[D]|0)==(B|0)){Ga=c[oa>>2]|0;if((Ga|0)==-1){Na=Ja;Oa=Ma;break}Ba=Ga>>>16^Ga;Ga=(Ba>>>8^Ba)&255;if((Ga|0)==(Ka|0)){Na=Ja;Oa=Ma;break}yDb(c[M>>2]|0,24,2036320,(J=i,i=i+16|0,c[J>>2]=Ka,c[J+8>>2]=Ga,J)|0);i=J;Na=c[r>>2]|0;Oa=c[z>>2]|0}else{Na=Ja;Oa=Ma}}while(0);Ma=Na+16|0;c[r>>2]=Oa>>>0>Ma>>>0?Ma:Oa;Ma=pa|0;x=0;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;Ma=pa+4|0;x=0;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;Pa=0;while(1){Ma=c[r>>2]|0;Ja=c[z>>2]|0;Ka=(c[u>>2]|0)+(Ma>>>3)|0;Ga=(fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ma&7)>>>26;Ka=Ma+6|0;c[r>>2]=Ja>>>0>Ka>>>0?Ka:Ja;if((c[(c[M>>2]|0)+48>>2]|0)==86061){Ja=c[la>>2]|0;Ka=c[la+4>>2]|0;f:do{if((hBb(Ja,Ka)|0)>(Ga|0)){Ma=Ga;Ba=0;while(1){Ha=187392+(Ba<<3)|0;Qa=c[Ha>>2]|0;Ra=c[Ha+4>>2]|0;if((Qa&Ja|0)==0&(Ra&Ka|0)==0){Sa=Ma}else{if((Ma|0)==0){Ta=Ra;Ua=Qa;break f}else{Sa=Ma-1|0}}Qa=Ba+1|0;if(Qa>>>0<20>>>0){Ma=Sa;Ba=Qa}else{Ta=0;Ua=0;break}}}else{Ta=0;Ua=0}}while(0);Va=kBb(c[la>>2]|0,c[la+4>>2]|0,Ua,Ta)|0}else{Va=Ga}if(Va>>>0>(d[ia]|0)>>>0){X=114;break e}a[s+24+(B*1528|0)+7+Va|0]=Pa;Ka=Pa+1|0;if(Ka>>>0>(d[ia]|0)>>>0){break}else{Pa=Ka}}Ka=(gmb(R,(c[r>>2]|0)-Ca|0)|0)&255;Ja=c[r>>2]|0;Ba=c[z>>2]|0;Ma=(c[u>>2]|0)+(Ja>>>3)|0;Qa=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ja&7)>>>24;Ma=Ja+8|0;c[r>>2]=Ba>>>0>Ma>>>0?Ma:Ba;if((Ka|0)!=(Qa|0)){yDb(c[M>>2]|0,16,2028520,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J}a[ha]=-1;a[ga]=0;b[da>>1]=8;c[oa>>2]=0;Qa=qa|0;x=0;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;Qa=qa+4|0;x=0;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;Qa=ra|0;x=0;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;Qa=ra+4|0;x=0;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;Qa=a[fa]|0;if(!((Qa&255)>>>0>(d[ea]|0)>>>0)){Ka=Qa&255;do{a[s+24+(B*1528|0)+28+(Ka*148|0)|0]=0;a[s+24+(B*1528|0)+28+(Ka*148|0)+36|0]=0;a[s+24+(B*1528|0)+28+(Ka*148|0)+1|0]=0;a[s+24+(B*1528|0)+28+(Ka*148|0)+37|0]=0;b[s+24+(B*1528|0)+28+(Ka*148|0)+136>>1]=0;c[s+24+(B*1528|0)+28+(Ka*148|0)+140>>2]=-8388608;a[s+24+(B*1528|0)+28+(Ka*148|0)+144|0]=0;a[s+24+(B*1528|0)+28+(Ka*148|0)+145|0]=24;Ka=Ka+1|0;}while(!(Ka>>>0>(d[ea]|0)>>>0))}do{if((d[D]|0)==(B|0)){Ka=c[M>>2]|0;c[Ka+416>>2]=(d[ia]|0)+1;Ca=c[la>>2]|0;Qa=c[la+4>>2]|0;Ba=Ka+448|0;c[Ba>>2]=Ca;c[Ba+4>>2]=Qa;if((c[Ka+48>>2]|0)!=86045){break}if((a[N]|0)==0){break}Ka=63;Ba=0;if((Ca|0)==59&(Qa|0)==0|(Ca|0)==55&(Qa|0)==0){Ma=a[sa]|0;a[sa]=a[ta]|0;a[ta]=a[ua]|0;a[ua]=Ma;break}else if((Ca|0)==(Ka|0)&(Qa|0)==(Ba|0)){Ba=a[sa]|0;a[sa]=a[ua]|0;a[ua]=Ba;Ba=a[va]|0;a[va]=a[ta]|0;a[ta]=Ba;break}else{break}}}while(0);a[V]=1}Ba=a[ha]|0;do{if((Ba&1)==0){Wa=Ba}else{Qa=c[r>>2]|0;Ka=c[u>>2]|0;Ca=d[Ka+(Qa>>>3)|0]|0;Ma=c[z>>2]|0;Ja=((Qa|0)<(Ma|0))+Qa|0;c[r>>2]=Ja;if((Ca&128>>>((Qa&7)>>>0)|0)==0){Wa=a[ha]|0;break}else{Qa=Ka+(Ja>>>3)|0;Ka=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Ja&7)>>>24;Qa=Ja+8|0;c[r>>2]=Ma>>>0>Qa>>>0?Qa:Ma;Ma=Ka&255;a[ha]=Ma;Wa=Ma;break}}}while(0);do{if(Wa<<24>>24<0){Ba=c[r>>2]|0;Ma=c[u>>2]|0;Ka=d[Ma+(Ba>>>3)|0]|0;Qa=c[z>>2]|0;Ja=((Ba|0)<(Qa|0))+Ba|0;c[r>>2]=Ja;if((Ka&128>>>((Ba&7)>>>0)|0)==0){break}Ba=Ma+(Ja>>>3)|0;Ma=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ja&7);Ba=Ma>>>23;Ka=Ja+9|0;c[r>>2]=Qa>>>0>Ka>>>0?Ka:Qa;b[da>>1]=Ba;if(Ma>>>0<67108864>>>0){X=137;break e}if((Ba|0)>(c[L>>2]|0)){X=137;break e}}}while(0);do{if(!((a[ha]&64)==0)){Ba=c[r>>2]|0;Ma=c[u>>2]|0;Qa=d[Ma+(Ba>>>3)|0]|0;c[r>>2]=((Ba|0)<(c[z>>2]|0))+Ba;if((Qa&128>>>((Ba&7)>>>0)|0)==0){break}Xa=c[M>>2]|0;Ya=(c[Xa+48>>2]|0)==86045?6:8;Ba=c[G>>2]|0;c[G>>2]=Ba+1;if((Ba|0)>1){X=141;break e}Ba=c[r>>2]|0;Qa=c[z>>2]|0;Ka=Ma+(Ba>>>3)|0;Ma=(fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ba&7)>>>28;Ka=Ba+4|0;c[r>>2]=Qa>>>0>Ka>>>0?Ka:Qa;Qa=Ma&255;a[ga]=Qa;if(Ma>>>0>Ya>>>0){X=144;break e}if(Qa<<24>>24==0){break}else{Za=0}do{Qa=c[r>>2]|0;Ma=c[z>>2]|0;Ka=(c[u>>2]|0)+(Qa>>>3)|0;Ba=(fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Qa&7)>>>28;Ka=Qa+4|0;c[r>>2]=Ma>>>0>Ka>>>0?Ka:Ma;Ma=s+24+(B*1528|0)+1223+Za|0;a[Ma]=Ba;Ba=c[r>>2]|0;Ka=c[z>>2]|0;Qa=c[u>>2]|0;Ja=Qa+(Ba>>>3)|0;Ca=(fe(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Ba&7)>>>28;Ja=Ba+4|0;Ba=Ka>>>0>Ja>>>0?Ja:Ka;c[r>>2]=Ba;Ja=d[Qa+(Ba>>>3)|0]<<(Ba&7)>>>7;c[r>>2]=((Ba|0)<(Ka|0))+Ba;a[s+24+(B*1528|0)+1231+Za|0]=Ja&1;_a=a[Ma]|0;Ma=a[ia]|0;Ja=Ma&255;if((_a&255)>>>0>(Ma&255)>>>0){X=146;break e}if((Ca|0)==15){X=148;break e}Ma=(b[ja>>1]|0)==0?Ja+2|0:Ja;Ja=14-Ca|0;Ba=Ca+2|0;Ka=30-Ca|0;Ca=c[u>>2]|0;Qa=0;do{Ra=c[r>>2]|0;Ha=d[Ca+(Ra>>>3)|0]|0;$a=c[z>>2]|0;ab=((Ra|0)<($a|0))+Ra|0;c[r>>2]=ab;if((Ha&128>>>((Ra&7)>>>0)|0)==0){bb=0}else{Ra=Ca+(ab>>>3)|0;Ha=(fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(ab&7)>>Ka;Ra=Ba+ab|0;c[r>>2]=$a>>>0>Ra>>>0?Ra:$a;bb=Ha}c[s+24+(B*1528|0)+1240+(Za<<5)+(Qa<<2)>>2]=bb<<Ja;Qa=Qa+1|0;}while(!(Qa>>>0>Ma>>>0));if((b[ja>>1]|0)==0){a[s+24+(B*1528|0)+1496+Za|0]=0}else{Ma=c[r>>2]|0;Qa=c[z>>2]|0;Ja=Ca+(Ma>>>3)|0;Ba=(fe(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Ma&7)>>>28;Ja=Ma+4|0;c[r>>2]=Qa>>>0>Ja>>>0?Ja:Qa;a[s+24+(B*1528|0)+1496+Za|0]=Ba}Za=Za+1|0;}while(Za>>>0<(d[ga]|0)>>>0)}}while(0);g:do{if(!((a[ha]&32)==0)){Ga=c[r>>2]|0;Ba=c[u>>2]|0;Qa=d[Ba+(Ga>>>3)|0]|0;Ja=c[z>>2]|0;Ma=((Ga|0)<(Ja|0))+Ga|0;c[r>>2]=Ma;if((Qa&128>>>((Ga&7)>>>0)|0)==0){break}else{cb=0;db=Ma;eb=Ja;fb=Ba}while(1){Ba=fb+(db>>>3)|0;Ja=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(db&7)>>28;Ba=db+4|0;c[r>>2]=eb>>>0>Ba>>>0?Ba:eb;a[s+24+(B*1528|0)+1516+cb|0]=Ja;Ja=cb+1|0;if(Ja>>>0>(d[ia]|0)>>>0){break g}cb=Ja;db=c[r>>2]|0;eb=c[z>>2]|0;fb=c[u>>2]|0}}}while(0);h:do{if(!((a[ha]&16)==0)){Ja=c[r>>2]|0;Ba=c[u>>2]|0;Ma=d[Ba+(Ja>>>3)|0]|0;Ga=c[z>>2]|0;Qa=((Ja|0)<(Ga|0))+Ja|0;c[r>>2]=Qa;if((Ma&128>>>((Ja&7)>>>0)|0)==0){break}else{gb=0;hb=Qa;ib=Ga;jb=Ba}while(1){Ba=jb+(hb>>>3)|0;Ga=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(hb&7)>>>28;Ba=hb+4|0;c[r>>2]=ib>>>0>Ba>>>0?Ba:ib;a[s+24+(B*1528|0)+1504+gb|0]=Ga;Ba=(d[s+24+(B*1528|0)+28+(gb*148|0)+145|0]|0)-Ga|0;Ga=a[s+24+(B*1528|0)+28+(gb*148|0)+144|0]|0;if(Ga<<24>>24==0){kb=b[s+24+(B*1528|0)+28+(gb*148|0)+136>>1]|0;lb=Ba-1|0}else{kb=(b[s+24+(B*1528|0)+28+(gb*148|0)+136>>1]|0)-(7<<Ba)|0;lb=2-(Ga&255)+Ba|0}if((lb|0)>-1){mb=kb-(1<<lb)|0}else{mb=kb}c[s+24+(B*1528|0)+28+(gb*148|0)+140>>2]=mb;Ba=gb+1|0;if(Ba>>>0>(d[ea]|0)>>>0){break h}gb=Ba;hb=c[r>>2]|0;ib=c[z>>2]|0;jb=c[u>>2]|0}}}while(0);Ba=a[fa]|0;if((Ba&255)>>>0>(d[ea]|0)>>>0){break}Ga=Ba&255;do{Ba=c[r>>2]|0;Qa=c[u>>2]|0;Ja=d[Qa+(Ba>>>3)|0]|0;Ma=c[z>>2]|0;Ka=((Ba|0)<(Ma|0))+Ba|0;c[r>>2]=Ka;if((Ja&128>>>((Ba&7)>>>0)|0)!=0){do{if(!((a[ha]&8)==0)){Ba=d[Qa+(Ka>>>3)|0]|0;c[r>>2]=((Ka|0)<(Ma|0))+Ka;if((Ba&128>>>((Ka&7)>>>0)|0)==0){break}if((WLa(s,n,B,Ga,0)|0)<0){X=242;break e}}}while(0);do{if(!((a[ha]&4)==0)){Ka=c[r>>2]|0;Ma=d[(c[u>>2]|0)+(Ka>>>3)|0]|0;c[r>>2]=((Ka|0)<(c[z>>2]|0))+Ka;if((Ma&128>>>((Ka&7)>>>0)|0)==0){break}if((WLa(s,n,B,Ga,1)|0)<0){X=242;break e}}}while(0);Ka=a[s+24+(B*1528|0)+28+(Ga*148|0)|0]|0;Ma=a[s+24+(B*1528|0)+28+(Ga*148|0)+36|0]|0;if(((Ma&255)+(Ka&255)|0)>8){X=180;break e}Qa=Ka<<24>>24==0;Ka=Ma<<24>>24==0;if(!(Qa|Ka)){if((a[s+24+(B*1528|0)+28+(Ga*148|0)+1|0]|0)!=(a[s+24+(B*1528|0)+28+(Ga*148|0)+37|0]|0)){X=183;break e}}if(!(Ka|Qa^1)){a[s+24+(B*1528|0)+28+(Ga*148|0)+1|0]=a[s+24+(B*1528|0)+28+(Ga*148|0)+37|0]|0}Qa=c[r>>2]|0;do{if((a[ha]&2)==0){nb=Qa;ob=c[z>>2]|0;pb=c[u>>2]|0}else{Ka=c[u>>2]|0;Ma=d[Ka+(Qa>>>3)|0]|0;Ba=c[z>>2]|0;Ja=((Qa|0)<(Ba|0))+Qa|0;c[r>>2]=Ja;if((Ma&128>>>((Qa&7)>>>0)|0)==0){nb=Ja;ob=Ba;pb=Ka;break}Ma=Ka+(Ja>>>3)|0;Ha=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ja&7)>>17;Ma=Ja+15|0;Ja=Ba>>>0>Ma>>>0?Ma:Ba;c[r>>2]=Ja;b[s+24+(B*1528|0)+28+(Ga*148|0)+136>>1]=Ha;nb=Ja;ob=Ba;pb=Ka}}while(0);Qa=pb+(nb>>>3)|0;Ka=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(nb&7)>>>30;Qa=nb+2|0;c[r>>2]=ob>>>0>Qa>>>0?Qa:ob;Qa=s+24+(B*1528|0)+28+(Ga*148|0)+144|0;a[Qa]=Ka;Ka=c[r>>2]|0;Ba=c[z>>2]|0;Ja=(c[u>>2]|0)+(Ka>>>3)|0;Ha=(fe(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Ka&7);Ja=Ha>>>27;Ma=Ka+5|0;c[r>>2]=Ba>>>0>Ma>>>0?Ma:Ba;qb=s+24+(B*1528|0)+28+(Ga*148|0)+145|0;a[qb]=Ja;if(Ha>>>0>3355443199>>>0){X=191;break e}Ha=Ja-(d[s+24+(B*1528|0)+1504+Ga|0]|0)|0;Ja=a[Qa]|0;if(Ja<<24>>24==0){rb=b[s+24+(B*1528|0)+28+(Ga*148|0)+136>>1]|0;sb=Ha-1|0}else{rb=(b[s+24+(B*1528|0)+28+(Ga*148|0)+136>>1]|0)-(7<<Ha)|0;sb=2-(Ja&255)+Ha|0}if((sb|0)>-1){tb=rb-(1<<sb)|0}else{tb=rb}c[s+24+(B*1528|0)+28+(Ga*148|0)+140>>2]=tb}Ga=Ga+1|0;}while(!(Ga>>>0>(d[ea]|0)>>>0))}}while(0);if((a[V]|0)==0){X=243;break}if((a[O]|0)==0){ub=0}else{Aa=c[r>>2]|0;za=c[z>>2]|0;K=(c[u>>2]|0)+(Aa>>>3)|0;Ga=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(Aa&7)>>>16;K=Aa+16|0;c[r>>2]=za>>>0>K>>>0?K:za;DDb(c[M>>2]|0,2230632,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;ub=Ga+Aa|0}Aa=e[ca>>1]|0;Ga=e[da>>1]|0;if((Ga+Aa|0)>(c[L>>2]|0)){X=203;break d}TGb(s+4932+(Aa<<3)|0,0,Ga<<3|0)|0;if((b[da>>1]|0)==0){vb=a[ea]|0;wb=0}else{Ga=0;while(1){Aa=a[ga]|0;if(!(Aa<<24>>24==0)){za=0;K=Aa;while(1){if((a[s+24+(B*1528|0)+1231+za|0]|0)==0){xb=K}else{Aa=c[r>>2]|0;Ha=d[(c[u>>2]|0)+(Aa>>>3)|0]<<(Aa&7)>>>7;c[r>>2]=((Aa|0)<(c[z>>2]|0))+Aa;a[s+4932+((e[ca>>1]|0)+Ga<<3)+za|0]=Ha&1;xb=a[ga]|0}Ha=za+1|0;if(Ha>>>0<(xb&255)>>>0){za=Ha;K=xb}else{break}}}K=a[fa]|0;za=a[ea]|0;if((K&255)>>>0>(za&255)>>>0){yb=za}else{za=K&255;while(1){K=a[s+24+(B*1528|0)+28+(za*148|0)+144|0]|0;Ha=d[s+24+(B*1528|0)+1504+za|0]|0;Aa=(d[s+24+(B*1528|0)+28+(za*148|0)+145|0]|0)-Ha|0;if(K<<24>>24==0){zb=0}else{Ja=c[5130004+(((K&255)-1|0)*20|0)>>2]|0;K=c[r>>2]|0;Qa=c[z>>2]|0;Ba=(c[u>>2]|0)+(K>>>3)|0;Ma=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(K&7)>>>23;Ba=b[Ja+(Ma<<2)>>1]|0;Ka=(b[Ja+(Ma<<2)+2>>1]|0)+K|0;c[r>>2]=Qa>>>0>Ka>>>0?Ka:Qa;if(Ba<<16>>16<0){t=-1094995529;X=284;break d}else{zb=Ba<<16>>16}}if((Aa|0)>0){Ba=c[r>>2]|0;Qa=c[z>>2]|0;Ka=(c[u>>2]|0)+(Ba>>>3)|0;K=(fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ba&7)>>>((32-Aa|0)>>>0);Ka=Ba+Aa|0;c[r>>2]=Qa>>>0>Ka>>>0?Ka:Qa;Ab=K+(zb<<Aa)|0}else{Ab=zb}c[s+6212+((e[ca>>1]|0)+Ga<<5)+(za<<2)>>2]=(c[s+24+(B*1528|0)+28+(za*148|0)+140>>2]|0)+Ab<<Ha;Ha=za+1|0;Aa=a[ea]|0;if(Ha>>>0>(Aa&255)>>>0){yb=Aa;break}else{za=Ha}}}za=Ga+1|0;Ha=b[da>>1]|0;if(za>>>0<(Ha&65535)>>>0){Ga=za}else{vb=yb;wb=Ha;break}}}Ga=a[fa]|0;if((Ga&255)>>>0>(vb&255)>>>0){Bb=wb}else{Ha=Ga&255;Ga=wb;while(1){za=d[s+24+(B*1528|0)+28+(Ha*148|0)+1|0]|0;Aa=-1<<d[s+24+(B*1528|0)+1504+Ha|0];K=s+24+(B*1528|0)+28+(Ha*148|0)+4|0;UGb(Q|0,K|0,32)|0;Qa=s+24+(B*1528|0)+28+(Ha*148|0)+40|0;c[U>>2]=c[Qa>>2];c[U+4>>2]=c[Qa+4>>2];c[U+8>>2]=c[Qa+8>>2];c[U+12>>2]=c[Qa+12>>2];Be[c[T>>2]&127](H,s+24+(B*1528|0)+28+(Ha*148|0)+72|0,d[s+24+(B*1528|0)+28+(Ha*148|0)|0]|0,d[s+24+(B*1528|0)+28+(Ha*148|0)+36|0]|0,za,Aa,Ga&65535,s+6212+(e[ca>>1]<<5)+(Ha<<2)|0);UGb(K|0,l+(160-(e[da>>1]|0)<<2)|0,32)|0;K=l+672+(160-(e[da>>1]|0)<<2)|0;c[Qa>>2]=c[K>>2];c[Qa+4>>2]=c[K+4>>2];c[Qa+8>>2]=c[K+8>>2];c[Qa+12>>2]=c[K+12>>2];K=Ha+1|0;Qa=b[da>>1]|0;if(K>>>0>(d[ea]|0)>>>0){Bb=Qa;break}else{Ha=K;Ga=Qa}}}b[ca>>1]=(b[ca>>1]|0)+Bb;Ga=c[r>>2]|0;if((a[O]|0)==0){Cb=Ga}else{if((Ga|0)==(ub|0)){Db=ub}else{yDb(c[M>>2]|0,16,2209200,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Db=c[r>>2]|0}Ga=c[z>>2]|0;Ha=Db+8|0;Qa=Ga>>>0>Ha>>>0?Ha:Ga;c[r>>2]=Qa;Cb=Qa}if((Cb|0)>=(I|0)){X=282;break d}Eb=c[u>>2]|0;Qa=d[Eb+(Cb>>>3)|0]|0;Fb=c[z>>2]|0;Gb=((Cb|0)<(Fb|0))+Cb|0;c[r>>2]=Gb;if((Qa&128>>>((Cb&7)>>>0)|0)==0){wa=Gb;xa=Eb;ya=Fb}else{X=227;break}}if((X|0)==83){X=0;yDb(Da,16,2077920,(J=i,i=i+8|0,c[J>>2]=Fa,J)|0);i=J;X=242}else if((X|0)==85){X=0;yDb(Ia,16,2073144,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==87){X=0;yDb(Ia,16,2068648,(J=i,i=i+8|0,c[J>>2]=Ea,J)|0);i=J;X=242}else if((X|0)==89){X=0;yDb(Ia,16,2064168,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==91){X=0;DDb(Ia,2060216,(J=i,i=i+8|0,c[J>>2]=La+2,J)|0);i=J;X=242}else if((X|0)==93){X=0;yDb(Ia,16,2055472,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==114){X=0;DDb(c[M>>2]|0,2032720,(J=i,i=i+16|0,c[J>>2]=Pa,c[J+8>>2]=Va,J)|0);i=J;X=242}else if((X|0)==137){X=0;yDb(c[M>>2]|0,16,2200632,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;b[da>>1]=0;X=242}else if((X|0)==141){X=0;yDb(Xa,16,2100120,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==144){X=0;yDb(Xa,16,2093512,(J=i,i=i+8|0,c[J>>2]=Ya,J)|0);i=J;X=242}else if((X|0)==146){X=0;yDb(c[M>>2]|0,16,2088176,(J=i,i=i+8|0,c[J>>2]=_a&255,J)|0);i=J;X=242}else if((X|0)==148){X=0;yDb(c[M>>2]|0,16,2083536,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==180){X=0;yDb(c[M>>2]|0,16,2192104,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==183){X=0;yDb(c[M>>2]|0,16,2175744,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==191){X=0;yDb(c[M>>2]|0,16,2165336,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;a[qb]=0;X=242}else if((X|0)==227){X=0;ya=(-Gb&15)+Gb|0;xa=Fb>>>0>ya>>>0?ya:Fb;c[r>>2]=xa;do{if((I-xa|0)>31){ya=Eb+(xa>>>3)|0;wa=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(xa&7);ya=xa+16|0;O=Fb>>>0>ya>>>0?ya:Fb;c[r>>2]=O;if(!((wa&-65536|0)==-768344064)){t=-1094995529;X=284;break d}wa=Eb+(O>>>3)|0;ya=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(O&7)>>>16;wa=O+16|0;c[r>>2]=Fb>>>0>wa>>>0?wa:Fb;wa=c[(c[M>>2]|0)+48>>2]|0;do{if((wa|0)==86061){if((ya&8192|0)==0){break}O=ya&8191;ca=e[S>>1]|0;b[S>>1]=ca-(O>>>0>ca>>>0?ca:O)}else{if(!((wa|0)!=86045|(ya|0)==53812)){t=-1094995529;X=284;break d}}}while(0);if((B|0)!=(d[D]|0)){break}yDb(c[M>>2]|0,32,2351640,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J}}while(0);do{if((a[o+B|0]|0)!=0){if((I-(c[r>>2]|0)|0)!=16){X=282;break d}S=P-2|0;xa=hmb(R,S)|0;da=fmb(R,S)|0;S=c[r>>2]|0;ya=c[z>>2]|0;wa=c[u>>2]|0;O=wa+(S>>>3)|0;ca=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(S&7)>>>24;O=S+8|0;S=ya>>>0>O>>>0?O:ya;c[r>>2]=S;if((ca^xa&255|0)==169){Hb=S;Ib=ya;Jb=wa}else{yDb(c[M>>2]|0,16,2331616,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J;Hb=c[r>>2]|0;Ib=c[z>>2]|0;Jb=c[u>>2]|0}wa=Jb+(Hb>>>3)|0;ya=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Hb&7)>>>24;wa=Hb+8|0;c[r>>2]=Ib>>>0>wa>>>0?wa:Ib;if((ya|0)==(da&255|0)){break}yDb(c[M>>2]|0,16,2307272,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J}}while(0);if((I|0)==(c[r>>2]|0)){X=242}else{X=282;break}}if((X|0)==242){X=0;if((a[V]|0)==0){X=243}}if((X|0)==243){X=0;yDb(c[M>>2]|0,16,2288976,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J}da=B+1|0;Kb=d[D]|0;if(da>>>0>Kb>>>0){X=245;break}else{B=da;R=R+P|0}}if((X|0)==203){yDb(c[M>>2]|0,16,2218560,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;t=-1094995529;i=k;return t|0}else if((X|0)==245){R=d[s+24+(Kb*1528|0)+6|0]|0;H=s+24+(Kb*1528|0)+1216|0;T=c[H>>2]|0;do{if((b[s+24+(Kb*1528|0)+2>>1]|0)==0){U=s+24+(Kb*1528|0)+1514|0;if((b[U>>1]|0)==0){Lb=R+2|0;Mb=T;break}Q=s+24+(Kb*1528|0)+1212|0;L=R+1|0;G=R+2|0;N=T;m=0;while(1){C=N>>>7;c[s+6212+(m<<5)+(L<<2)>>2]=N>>>15<<24>>24<<d[Q];c[s+6212+(m<<5)+(G<<2)>>2]=C<<24>>24<<d[Q];da=C&65535;C=(da|N<<16)^da<<5;da=m+1|0;if(da>>>0<(e[U>>1]|0)>>>0){N=C;m=da}else{Lb=G;Mb=C;break}}}else{G=j+16|0;if((c[G>>2]|0)==0){Lb=R;Mb=T;break}else{Nb=T;Ob=0}while(1){m=Nb>>>15&255;a[s+4676+Ob|0]=a[630496+m|0]|0;N=(m|Nb<<8)^m<<5;m=Ob+1|0;if(m>>>0<(c[G>>2]|0)>>>0){Nb=N;Ob=m}else{Lb=R;Mb=N;break}}}}while(0);c[H>>2]=Mb;R=s+24+(Kb*1528|0)+1222|0;T=a[R]|0;if(!(T<<24>>24==0)){G=s+24+(Kb*1528|0)+1514|0;N=j+16|0;m=0;U=T&255;Q=b[G>>1]|0;L=T;while(1){T=a[s+24+(Kb*1528|0)+1496+m|0]|0;P=d[s+24+(Kb*1528|0)+1223+m|0]|0;V=U-m|0;I=V<<1|1;if(Q<<16>>16==0){Pb=0;Qb=L}else{C=-1<<d[s+24+(Kb*1528|0)+1504+P|0];da=0;ya=(T&255)+7|0;if(T<<24>>24==0){T=0;while(1){wa=a[s+4932+(T<<3)+m|0]|0;S=0;xa=0;ca=0;do{O=c[s+6212+(T<<5)+(S<<2)>>2]|0;ea=c[s+24+(Kb*1528|0)+1240+(m<<5)+(S<<2)>>2]|0;fa=gHb(ea,(ea|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;ca=YGb(fa,F,ca,xa)|0;xa=F;S=S+1|0;}while(!(S>>>0>Lb>>>0));S=YGb((ca>>>14|xa<<18)&C,(xa>>>14|0<<18)&da,wa<<24>>24,wa<<24>>24<0|0?-1:0)|0;c[s+6212+(T<<5)+(P<<2)>>2]=S;S=T+1|0;fa=b[G>>1]|0;if(S>>>0<(fa&65535)>>>0){T=S}else{Rb=fa;break}}}else{T=V;fa=0;while(1){S=a[s+4932+(fa<<3)+m|0]|0;O=0;ea=0;ga=0;do{ha=c[s+6212+(fa<<5)+(O<<2)>>2]|0;ia=c[s+24+(Kb*1528|0)+1240+(m<<5)+(O<<2)>>2]|0;ja=gHb(ia,(ia|0)<0|0?-1:0,ha,(ha|0)<0|0?-1:0)|0;ga=YGb(ja,F,ga,ea)|0;ea=F;O=O+1|0;}while(!(O>>>0>Lb>>>0));O=(c[N>>2]|0)-1&T;wa=a[s+4676+O|0]<<ya;xa=YGb(wa,(wa|0)<0|0?-1:0,ga,ea)|0;wa=F;ca=YGb((xa>>>14|wa<<18)&C,(wa>>>14|0<<18)&da,S<<24>>24,S<<24>>24<0|0?-1:0)|0;c[s+6212+(fa<<5)+(P<<2)>>2]=ca;ca=fa+1|0;wa=b[G>>1]|0;if(ca>>>0<(wa&65535)>>>0){T=O+I|0;fa=ca}else{Rb=wa;break}}}Pb=Rb;Qb=a[R]|0}fa=m+1|0;I=Qb&255;if(fa>>>0<I>>>0){m=fa;U=I;Q=Pb;L=Qb}else{break}}}L=d[D]|0;Q=g;U=c[M>>2]|0;m=(c[U+420>>2]|0)==2;R=s+24+(L*1528|0)+6|0;do{if((c[U+416>>2]|0)==((d[R]|0)+1|0)){G=s+24+(L*1528|0)+1514|0;N=b[G>>1]|0;if(N<<16>>16==0){yDb(U,16,2243088,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Sb=-1094995529;break}c[g+76>>2]=N&65535;N=_$a(U,Q,0)|0;if((N|0)<0){Sb=N;break}N=c[g>>2]|0;H=b[G>>1]|0;if(!(H<<16>>16==0)){I=s+24+(L*1528|0)+1524|0;if(m){fa=N;T=0;while(1){P=fa;da=0;while(1){C=d[s+24+(L*1528|0)+7+da|0]|0;ya=c[s+6212+(T<<5)+(C<<2)>>2]<<a[s+24+(L*1528|0)+1516+C|0];c[I>>2]=(ya&16777215)<<C^c[I>>2];Tb=P+4|0;c[P>>2]=ya<<8;ya=da+1|0;if(ya>>>0>(d[R]|0)>>>0){break}else{P=Tb;da=ya}}da=T+1|0;if(da>>>0<(H&65535)>>>0){fa=Tb;T=da}else{break}}}else{T=N;fa=0;while(1){H=T;da=0;P=c[I>>2]|0;while(1){S=d[s+24+(L*1528|0)+7+da|0]|0;ea=c[s+6212+(fa<<5)+(S<<2)>>2]<<a[s+24+(L*1528|0)+1516+S|0];ga=(ea&16777215)<<S^P;c[I>>2]=ga;Ub=H+2|0;b[H>>1]=ea>>>8;ea=da+1|0;if(ea>>>0>(d[R]|0)>>>0){break}else{H=Ub;da=ea;P=ga}}P=fa+1|0;if(P>>>0<(e[G>>1]|0)>>>0){T=Ub;fa=P}else{break}}}}fa=W$a(Q,c[s+24+(L*1528|0)+24>>2]|0)|0;if((fa|0)<0){Sb=fa;break}c[h>>2]=1;Sb=0}else{yDb(U,16,2257368,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Sb=-1094995529}}while(0);t=(Sb|0)<0?Sb:v;i=k;return t|0}else if((X|0)==282){yDb(c[M>>2]|0,16,2272824,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J;t=-1094995529;i=k;return t|0}else if((X|0)==284){i=k;return t|0}}}while(0);a[j+8|0]=0;t=-1094995529;i=k;return t|0}function WLa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;k=b;l=(h|0)!=0;m=l?4:8;n=l?73:70;if(!(h>>>0<2>>>0)){yDb(0,0,2158672,(o=i,i=i+24|0,c[o>>2]=2151560,c[o+8>>2]=2144544,c[o+16>>2]=640,o)|0);i=o;Cd();return 0}l=b+4612+(g<<3)+(h<<2)|0;p=c[l>>2]|0;c[l>>2]=p+1;if((p|0)>1){yDb(c[b>>2]|0,16,2138896,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;q=-1094995529;i=j;return q|0}p=e+8|0;l=c[p>>2]|0;r=e+16|0;s=c[r>>2]|0;t=e|0;e=(c[t>>2]|0)+(l>>>3)|0;u=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(l&7);e=u>>>28;v=l+4|0;c[p>>2]=s>>>0>v>>>0?v:s;if(e>>>0>m>>>0){yDb(c[b>>2]|0,16,2132656,(o=i,i=i+24|0,c[o>>2]=n&255,c[o+8>>2]=e,c[o+16>>2]=m,o)|0);i=o;q=-1094995529;i=j;return q|0}a[b+24+(f*1528|0)+28+(g*148|0)+(h*36|0)|0]=e;if((e|0)==0){q=0;i=j;return q|0}m=c[p>>2]|0;s=c[r>>2]|0;v=(c[t>>2]|0)+(m>>>3)|0;l=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(m&7)>>>28;v=m+4|0;c[p>>2]=s>>>0>v>>>0?v:s;a[b+24+(f*1528|0)+28+(g*148|0)+(h*36|0)+1|0]=l;l=c[p>>2]|0;s=c[r>>2]|0;v=c[t>>2]|0;t=v+(l>>>3)|0;m=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(l&7)>>>27;t=l+5|0;l=s>>>0>t>>>0?t:s;c[p>>2]=l;t=v+(l>>>3)|0;w=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(l&7)>>>29;t=l+3|0;l=s>>>0>t>>>0?t:s;c[p>>2]=l;if((m-1|0)>>>0>15>>>0){yDb(c[b>>2]|0,16,2126224,(o=i,i=i+8|0,c[o>>2]=n&255,o)|0);i=o;q=-1094995529;i=j;return q|0}if((w+m|0)>16){yDb(c[b>>2]|0,16,2120432,(o=i,i=i+8|0,c[o>>2]=n&255,o)|0);i=o;q=-1094995529;i=j;return q|0}n=32-m|0;t=0;x=l;l=s;do{s=v+(x>>>3)|0;y=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(x&7)>>n;s=x+m|0;c[p>>2]=l>>>0>s>>>0?s:l;c[b+24+(f*1528|0)+28+(g*148|0)+72+(h<<5)+(t<<2)>>2]=y<<w;t=t+1|0;x=c[p>>2]|0;l=c[r>>2]|0}while((t|0)<(e|0));t=d[v+(x>>>3)|0]|0;w=((x|0)<(l|0))+x|0;c[p>>2]=w;if((t&128>>>((x&7)>>>0)|0)==0){q=0;i=j;return q|0}if((h|0)==0){yDb(c[b>>2]|0,16,2114304,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;q=-1094995529;i=j;return q|0}o=v+(w>>>3)|0;x=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(w&7)>>>28;o=w+4|0;w=l>>>0>o>>>0?o:l;c[p>>2]=w;o=v+(w>>>3)|0;t=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(w&7)>>>28;o=w+4|0;c[p>>2]=l>>>0>o>>>0?o:l;l=32-x|0;if((x|0)==0){TGb(k+((f*1528|0)+(g*148|0)+(h*36|0)+56)|0,0,(u>>>0>536870911>>>0?e<<2:4)|0)|0;q=0;i=j;return q|0}else{u=0;while(1){k=c[p>>2]|0;o=c[r>>2]|0;w=v+(k>>>3)|0;m=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(k&7)>>l;w=k+x|0;c[p>>2]=o>>>0>w>>>0?w:o;c[b+24+(f*1528|0)+28+(g*148|0)+(h*36|0)+4+(u<<2)>>2]=m<<t;m=u+1|0;if((m|0)<(e|0)){u=m}else{q=0;break}}i=j;return q|0}return 0}function XLa(a){a=a|0;c[a>>2]=6;return}function YLa(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0;j=a+672|0;if((h|0)<=0){return}k=(e|0)!=0;l=f;f=g;m=0;if((d|0)!=0){n=j;o=0;p=a;q=i;while(1){r=c[q>>2]|0;s=0;t=0;u=0;do{v=c[p+(s<<2)>>2]|0;w=c[b+(s<<2)>>2]|0;x=gHb(w,(w|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;u=YGb(x,F,u,t)|0;t=F;s=s+1|0;}while(s>>>0<d>>>0);if(k){s=0;x=t;v=u;while(1){w=c[n+(s<<2)>>2]|0;y=c[b+(s+8<<2)>>2]|0;z=gHb(y,(y|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=YGb(z,F,v,x)|0;z=F;y=s+1|0;if(y>>>0<e>>>0){s=y;x=z;v=w}else{A=z;B=w;break}}}else{A=t;B=u}v=aHb(B|0,A|0,l|0)|0;x=F;s=YGb(v,x,r,0)|0;w=s&f;s=w;z=p-4|0;c[z>>2]=s;y=ZGb(w,F&m,v,x)|0;x=n-4|0;c[x>>2]=y;c[q>>2]=s;s=o+1|0;if((s|0)<(h|0)){n=x;o=s;p=z;q=q+32|0}else{break}}return}if(k){C=j;D=0;E=a;G=i}else{k=j;j=0;q=a;a=i;while(1){i=c[a>>2]&g;p=q-4|0;c[p>>2]=i;o=k-4|0;c[o>>2]=i;c[a>>2]=i;i=j+1|0;if((i|0)<(h|0)){k=o;j=i;q=p;a=a+32|0}else{break}}return}while(1){a=c[G>>2]|0;q=0;j=0;k=0;do{g=c[C+(q<<2)>>2]|0;p=c[b+(q+8<<2)>>2]|0;i=gHb(p,(p|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;k=YGb(i,F,k,j)|0;j=F;q=q+1|0;}while(q>>>0<e>>>0);q=aHb(k|0,j|0,l|0)|0;r=F;u=YGb(q,r,a,0)|0;t=u&f;u=t;i=E-4|0;c[i>>2]=u;g=ZGb(t,F&m,q,r)|0;r=C-4|0;c[r>>2]=g;c[G>>2]=u;u=D+1|0;if((u|0)<(h|0)){C=r;D=u;E=i;G=G+32|0}else{break}}return}function ZLa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;a=ICb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function _La(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=c[j>>2]|0;k=c[a+60>>2]|0;l=k;if((f|0)<6){m=-1094995529;i=g;return m|0}n=h;o=(d[n]|d[n+1|0]<<8)<<16>>16;n=h+6|0;if(!((f-6|0)>-1)){yDb(0,0,2185576,(p=i,i=i+24|0,c[p>>2]=2108384,c[p+8>>2]=2050696,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}p=k+1032|0;c[p>>2]=n;c[k+1040>>2]=n;n=k+1036|0;c[n>>2]=h+f;f=k+4|0;h=$$a(a,c[f>>2]|0)|0;if((h|0)<0){m=h;i=g;return m|0}a:do{switch(o&65535|0){case 12:{h=k;a=0;b:while(1){q=0;do{r=c[p>>2]|0;s=c[n>>2]|0;if((s|0)==(r|0)){break a}t=c[h>>2]|0;if((a|0)>=(c[t+124>>2]|0)){break a}u=s;if((u-r|0)<1){v=0;w=r;x=31}else{s=r+1|0;c[p>>2]=s;y=d[r]|0;if((y&128|0)==0){v=y;w=s;x=31}else{z=y;A=1}}do{if((x|0)==31){x=0;y=(v&127)+2|0;if((u-w|0)<1){z=0;A=y;break}c[p>>2]=w+1;z=d[w]|0;A=y}}while(0);u=A<<1;y=c[t+120>>2]|0;if((u|0)>(y-q|0)){m=-1094995529;break b}if((z|0)==0){B=y}else{y=c[f>>2]|0;TGb((c[y>>2]|0)+((ba(c[y+32>>2]|0,a)|0)+q)|0,z&255|0,u|0)|0;B=c[(c[h>>2]|0)+120>>2]|0}q=u+q|0;}while((q|0)<(B|0));a=a+1|0}i=g;return m|0};case 8:{a=k;h=0;c:while(1){q=0;do{u=c[p>>2]|0;y=c[n>>2]|0;if((y|0)==(u|0)){break a}s=c[a>>2]|0;if((h|0)>=(c[s+124>>2]|0)){break a}r=y;if((r-u|0)<1){C=0;D=u;x=18}else{y=u+1|0;c[p>>2]=y;E=d[u]|0;if((E&128|0)==0){C=E;D=y;x=18}else{F=E;G=1}}do{if((x|0)==18){x=0;E=(C&127)+2|0;if((r-D|0)<1){F=0;G=E;break}c[p>>2]=D+1;F=d[D]|0;G=E}}while(0);r=c[s+120>>2]|0;if((G|0)>(r-q|0)){m=-1094995529;break c}if((F|0)==0){H=r}else{r=c[f>>2]|0;TGb((c[r>>2]|0)+((ba(c[r+32>>2]|0,h)|0)+q)|0,F&255|0,G|0)|0;H=c[(c[a>>2]|0)+120>>2]|0}q=G+q|0;}while((q|0)<(H|0));h=h+1|0}i=g;return m|0};case 14:{h=k;a=0;d:while(1){q=a|1;r=0;do{t=c[p>>2]|0;E=c[n>>2]|0;if((E|0)==(t|0)){break a}y=c[h>>2]|0;if((a|0)>=(c[y+124>>2]|0)){break a}u=E;if((u-t|0)<1){I=0;J=t;x=44}else{E=t+1|0;c[p>>2]=E;K=d[t]|0;if((K&128|0)==0){I=K;J=E;x=44}else{L=K;M=1}}do{if((x|0)==44){x=0;K=(I&127)+2|0;if((u-J|0)<1){L=0;M=K;break}c[p>>2]=J+1;L=d[J]|0;M=K}}while(0);u=M<<1;s=c[y+120>>2]|0;if((u|0)>(s-r|0)){m=-1094995529;break d}if((L|0)==0){N=s}else{s=c[f>>2]|0;K=L&255;TGb((c[s>>2]|0)+((ba(c[s+32>>2]|0,a)|0)+r)|0,K|0,u|0)|0;s=c[f>>2]|0;TGb((c[s>>2]|0)+((ba(c[s+32>>2]|0,q)|0)+r)|0,K|0,u|0)|0;N=c[(c[h>>2]|0)+120>>2]|0}r=u+r|0;}while((r|0)<(N|0));a=a+2|0}i=g;return m|0};case 49:{a=c[n>>2]|0;h=c[p>>2]|0;r=a-h|0;q=h+(r>>>0>4>>>0?4:r)|0;c[p>>2]=q;r=0;h=a;a=q;while(1){if((h-a|0)<3){O=-16777216}else{c[p>>2]=a+3;O=(d[a]|0)<<16|(d[a+1|0]|0)<<8|(d[a+2|0]|0)|-16777216}c[l+8+(r<<2)>>2]=O;c[l+8+(r+128<<2)>>2]=O<<2;q=r+1|0;if((q|0)>=128){break}r=q;h=c[n>>2]|0;a=c[p>>2]|0}m=c[j>>2]|0;i=g;return m|0};case 5:{P=aMa(l,0,0)|0;x=54;break};case 13:{P=aMa(l,1,0)|0;x=54;break};case 15:{P=aMa(l,1,1)|0;x=54;break};default:{m=-1094995529;i=g;return m|0}}}while(0);do{if((x|0)==54){if((P|0)<0){m=P}else{break}i=g;return m|0}}while(0);UGb(c[(c[f>>2]|0)+4>>2]|0,k+8|0,1024)|0;k=MCb(b,c[f>>2]|0)|0;if((k|0)<0){m=k;i=g;return m|0}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function $La(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function aMa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;h=b+1036|0;j=b+1032|0;k=c[j>>2]|0;l=c[h>>2]|0;if((l-k|0)<2){m=0;n=k}else{o=k+2|0;c[j>>2]=o;p=k;m=(d[p]|d[p+1|0]<<8)<<16>>16&65535;n=o}o=l-n|0;if(o>>>0<m>>>0){q=-1094995529;i=g;return q|0}l=n+m|0;if(!((o-m|0)>-1)){yDb(0,0,2185576,(m=i,i=i+24|0,c[m>>2]=2108384,c[m+8>>2]=2050696,c[m+16>>2]=135,m)|0);i=m;Cd();return 0}m=b|0;p=f+1|0;k=e+1|0;r=n+o|0;o=b+4|0;b=(e|0)!=0;s=(f|0)==0;t=0;u=l;v=n;a:while(1){n=t;w=v;while(1){if(!(w>>>0<l>>>0)){q=0;x=32;break a}y=c[h>>2]|0;z=y;if((z-w|0)<1){A=0;B=w}else{C=w+1|0;c[j>>2]=C;A=d[w]|0;B=C}if((z-B|0)<1){D=0;E=B}else{z=B+1|0;c[j>>2]=z;D=d[B]|0;E=z}F=D|A<<1&256;G=A&127;if((G|0)==0){n=F+n|0;w=E}else{break}}if((n+f|0)>=(c[(c[m>>2]|0)+124>>2]|0)){q=0;x=32;break}w=n+1|0;z=u;C=F;H=1;I=y;J=E;while(1){if((I-J|0)<1){K=0}else{c[j>>2]=J+1;K=d[J]|0}L=z;M=0;N=C;while(1){if((N+e|0)>=(c[(c[m>>2]|0)+120>>2]|0)){q=-1094995529;x=32;break a}do{if((1<<7-M&K|0)==0){O=L}else{if((r-L|0)<1){P=0;Q=L}else{P=a[L]|0;Q=L+1|0}R=c[o>>2]|0;S=(ba(c[R+32>>2]|0,n)|0)+N|0;a[(c[R>>2]|0)+S|0]=P;if(b){S=c[o>>2]|0;R=N+1+(ba(c[S+32>>2]|0,n)|0)|0;a[(c[S>>2]|0)+R|0]=P}if(s){O=Q;break}R=c[o>>2]|0;S=(ba(c[R+32>>2]|0,w)|0)+N|0;a[(c[R>>2]|0)+S|0]=P;if(!b){O=Q;break}S=c[o>>2]|0;R=N+1+(ba(c[S+32>>2]|0,w)|0)|0;a[(c[S>>2]|0)+R|0]=P;O=Q}}while(0);T=k+N|0;R=M+1|0;if((R|0)<8){L=O;M=R;N=T}else{break}}if((H|0)>=(G|0)){break}z=O;C=T;H=H+1|0;I=c[h>>2]|0;J=c[j>>2]|0}t=p+n|0;u=O;v=c[j>>2]|0}if((x|0)==32){i=g;return q|0}return 0}function bMa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;f=b+60|0;g=c[f>>2]|0;h=b+120|0;j=b+124|0;k=(c[j>>2]|0)+3&-4;if((c[b+100>>2]|0)<2){yDb(b,16,2005184,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=e;return m|0}l=(c[h>>2]|0)+3&-4;if((a[4876858]|0)==0){n=0;while(1){o=n*1e3|0;p=n&255;q=-31;do{r=((q*701|0)+o|0)/1e3|0;s=(q*-357|0)+o|0;t=r<<10;u=q&255;v=-31;do{w=(s+(v*-172|0)|0)/1e3|0;x=((v*886|0)+o|0)/1e3|0;do{if((w|r|x)>>>0<32>>>0){y=w<<5|t|x;if((y|0)>=32768){break}z=4876858+(y*3|0)|0;A=4876857+(y*3|0)|0;B=4876856+(y*3|0)|0;if(!((a[A]|a[z]|a[B])<<24>>24==0)){break}a[B]=p;a[A]=u;a[z]=v}}while(0);v=v+1|0;}while((v|0)<32);q=q+1|0;}while((q|0)<32);q=n+1|0;if((q|0)<32){n=q}else{C=0;break}}do{n=C<<5;q=0;do{p=31;do{o=p+n|0;v=4876856+(o*3|0)|0;p=p-1|0;if((a[4876857+(o*3|0)|0]|a[4876858+(o*3|0)|0]|a[v])<<24>>24==0){o=4876856+((p+n|0)*3|0)|0;a[v]=a[o]|0;a[v+1|0]=a[o+1|0]|0;a[v+2|0]=a[o+2|0]|0}}while((p|0)>(q|0));p=31-q|0;o=0;do{v=o+n|0;u=4876856+(v*3|0)|0;o=o+1|0;if((a[4876857+(v*3|0)|0]|a[4876858+(v*3|0)|0]|a[u])<<24>>24==0){v=4876856+((o+n|0)*3|0)|0;a[u]=a[v]|0;a[u+1|0]=a[v+1|0]|0;a[u+2|0]=a[v+2|0]|0}}while((o|0)<(p|0));q=q+1|0;}while((q|0)<31);C=C+1|0;}while((C|0)<1024)}c[g>>2]=b;Z3(g+8|0,b);C=g+1252|0;q=C;c[q>>2]=cEb(ba(c[h>>2]|0,k)|0)|0;n=ba(c[j>>2]|0,c[h>>2]|0)|0;h=n>>>0>65535>>>0;p=h?n>>>16:n;n=h?16:0;if((p&65280|0)==0){D=n;E=p}else{D=n|8;E=p>>>8}c[g+1256>>2]=D+1+(d[1191992+E|0]|0);E=g+1420|0;D=E;c[D>>2]=cEb((c[j>>2]|0)*3|0)|0;j=cEb(((ba(l,k)|0)/16|0)*3|0)|0;k=g+1424|0;c[k>>2]=j;do{if((c[q>>2]|0)!=0){if((c[D>>2]|0)==0|(j|0)==0){break}c[b+140>>2]=46;l=ICb()|0;c[g+4>>2]=l;if((l|0)!=0){m=0;i=e;return m|0}l=c[f>>2]|0;$Db(l+1252|0);$Db(l+1420|0);$Db(l+1424|0);$Db(l+1432|0);JCb(l+4|0);m=-12;i=e;return m|0}}while(0);$Db(C);$Db(E);$Db(k);m=-12;i=e;return m|0}function cMa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0;k=i;i=i+24|0;l=k|0;m=c[j+24>>2]|0;n=c[j+28>>2]|0;j=c[f+60>>2]|0;o=j;p=j+4|0;q=$$a(f,c[p>>2]|0)|0;if((q|0)<0){r=q;i=k;return r|0}q=j+1432|0;s=q;O$a(q,j+1436|0,n);q=c[s>>2]|0;if((q|0)==0){r=-12;i=k;return r|0}Xe[c[j+1104>>2]&4095](q,m,(n|0)/4|0);q=n&3;if((q|0)!=0){t=n&-4;UGb((c[s>>2]|0)+t|0,m+t|0,q)|0}q=c[s>>2]|0;s=n<<3;t=s>>>0>2147483639>>>0|(q|0)==0;m=t?0:q;q=t?0:s;s=l|0;c[s>>2]=m;c[l+12>>2]=q;t=q+8|0;u=l+16|0;c[u>>2]=t;c[l+4>>2]=m+(q>>3);q=l+8|0;c[q>>2]=0;v=j+1252|0;TGb(c[v>>2]|0,0,ba(c[f+124>>2]|0,c[f+120>>2]|0)|0)|0;w=f+96|0;f=m;x=fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;f=((d[(c[w>>2]|0)+1|0]|0)>>>1&1^1)&255;y=0;z=t;t=x;x=m;do{m=y+12|0;A=z>>>0>m>>>0?m:z;m=x+(A>>>3)|0;B=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(A&7)>>>20;m=A+12|0;c[q>>2]=z>>>0>m>>>0?m:z;eMa(o,l,t>>>20,8,f);eMa(o,l,B,4,f);f=f+1|0;y=c[q>>2]|0;z=c[u>>2]|0;x=c[s>>2]|0;B=x+(y>>>3)|0;t=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)}while((f|0)<2);f=y+4|0;y=t>>>28;t=z>>>0>f>>>0?f:z;c[q>>2]=t;f=j+1260|0;c[f>>2]=y;a:do{if((y|0)!=0){B=c[v>>2]|0;if((a[B]|0)==0){m=x+(t>>>3)|0;A=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(t&7)>>>17;m=t+15|0;C=z>>>0>m>>>0?m:z;c[q>>2]=C;b[c[c[p>>2]>>2]>>1]=A;a[B]=1;D=c[f>>2]|0;E=C}else{D=y;E=t}C=x+(E>>>3)|0;B=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>28;C=E+4|0;A=z>>>0>C>>>0?C:z;c[q>>2]=A;do{if((D|0)==1){a[j+1277|0]=B;F=1;G=A;H=z;I=x}else{c[j+1268>>2]=B;if((D|0)>0){C=0;m=A;do{J=x+(m>>>3)|0;K=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(m&7)>>>28;J=m+4|0;m=z>>>0>J>>>0?J:z;a[o+1272+(C<<3)+5|0]=K;C=C+1|0;}while((C|0)<(c[f>>2]|0));c[q>>2]=m}C=j+1264|0;c[C>>2]=0;if((fMa(o,l,0,0)|0)<0){break a}K=c[f>>2]|0;if((c[C>>2]|0)<(K|0)){yDb(c[j>>2]|0,16,2185560,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;break a}else{F=K;G=c[q>>2]|0;H=c[u>>2]|0;I=c[s>>2]|0;break}}}while(0);A=I+(G>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(G&7)>>>14;A=G+18|0;K=H>>>0>A>>>0?A:H;c[q>>2]=K;if((a[c[w>>2]|0]|0)==5){L=B;M=K}else{A=I+(K>>>3)|0;C=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(K&7)>>>14;A=K+18|0;K=H>>>0>A>>>0?A:H;c[q>>2]=K;L=C+B|0;M=K}if((L|0)==0){break}K=j+1268|0;B=c[K>>2]|0;if((B|0)<1){break}C=j+1400|0;if((N_(C,B,F,j+1276|0,8,1,j+1272|0,8,4,0,0,0,0)|0)!=0){break}B=j;A=c[B>>2]|0;if((c[A+124>>2]|0)>0){J=j+1428|0;N=j+1429|0;O=j+1430|0;P=j+1404|0;Q=j+1420|0;R=0;S=0;T=0;U=0;V=A;W=M;X=H;Y=H;while(1){Z=ba(c[V+120>>2]|0,U)|0;if((a[(c[v>>2]|0)+Z|0]|0)==0){Z=(c[f>>2]|0)==1;if(Z){_=0;$=W;aa=X;ca=Y}else{da=c[P>>2]|0;ea=c[K>>2]|0;fa=I+(W>>>3)|0;ga=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(W&7)>>>((32-ea|0)>>>0);ea=b[da+(ga<<2)>>1]|0;fa=(b[da+(ga<<2)+2>>1]|0)+W|0;ga=H>>>0>fa>>>0?fa:H;c[q>>2]=ga;_=ea;$=ga;aa=H;ca=H}ga=a[o+1272+(_<<3)+5|0]|0;ea=ba(d[J]|0,(ga&255)-7|0)|0;if(ga<<24>>24==0){ha=2}else{ha=ga<<24>>24==14?2:1}a[J]=ha;ga=ea+(T&255)|0;ea=ga<<24;if((ea|0)<0){ia=0}else{ia=(ea|0)>520093696?31:ga&255}do{if((U&3|0)==0){if(Z){ja=0;ka=$;la=aa}else{ga=c[P>>2]|0;ea=c[K>>2]|0;fa=I+($>>>3)|0;da=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<($&7)>>>((32-ea|0)>>>0);ea=b[ga+(da<<2)>>1]|0;fa=(b[ga+(da<<2)+2>>1]|0)+$|0;da=ca>>>0>fa>>>0?fa:ca;c[q>>2]=da;ja=ea;ka=da;la=ca}da=a[o+1272+(ja<<3)+5|0]|0;ea=ba(d[N]|0,(da&255)-7|0)|0;if(da<<24>>24==0){ma=2}else{ma=da<<24>>24==14?2:1}a[N]=ma;da=ea+(S&255)|0;ea=da<<24;if((ea|0)<-536870912){na=-32}else{na=(ea|0)>520093696?31:da&255}if(Z){oa=0;pa=ka}else{da=c[P>>2]|0;ea=c[K>>2]|0;fa=I+(ka>>>3)|0;ga=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ka&7)>>>((32-ea|0)>>>0);ea=b[da+(ga<<2)>>1]|0;fa=(b[da+(ga<<2)+2>>1]|0)+ka|0;ga=la>>>0>fa>>>0?fa:la;c[q>>2]=ga;oa=ea;pa=ga}ga=a[o+1272+(oa<<3)+5|0]|0;ea=ba(d[O]|0,(ga&255)-7|0)|0;if(ga<<24>>24==0){qa=2}else{qa=ga<<24>>24==14?2:1}a[O]=qa;ga=ea+(R&255)|0;ea=ga<<24;if((ea|0)<-536870912){ra=na;sa=-32;ta=pa;ua=la;break}ra=na;sa=(ea|0)>520093696?31:ga&255;ta=pa;ua=la}else{ra=S;sa=R;ta=$;ua=aa}}while(0);Z=(c[Q>>2]|0)+(U*3|0)|0;a[Z]=ia;a[Z+1|0]=ra;a[Z+2|0]=sa;Z=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;m=ra<<24>>24;ga=sa<<24>>24;ea=(ia<<24>>24)*1e3|0;b[(c[Z>>2]|0)+(ba(c[Z+32>>2]|0,U)|0)>>1]=d[((((ga*-172|0)+ea+(m*-357|0)|0)/1e3|0)<<3)+1236056|0]<<2&992|d[((((m*701|0)+ea|0)/1e3|0)<<3)+1236056|0]<<7&31744|(a[((((ga*886|0)+ea|0)/1e3|0)<<3)+1236056|0]&255)>>>3;va=ia;wa=ra;xa=sa;ya=c[B>>2]|0;za=ta;Aa=ua;Ba=ca}else{TGb(J|0,1,3)|0;ea=c[p>>2]|0;ga=4876856+((e[(c[ea>>2]|0)+(ba(c[ea+32>>2]|0,U)|0)>>1]|0)*3|0)|0;va=a[ga]|0;wa=a[ga+1|0]|0;xa=a[ga+2|0]|0;ya=V;za=W;Aa=X;Ba=Y}ga=U+1|0;if((ga|0)<(c[ya+124>>2]|0)){R=xa;S=wa;T=va;U=ga;V=ya;W=za;X=Aa;Y=Ba}else{Ca=ya;Da=Q;Ea=J;Fa=N;Ga=O;Ha=P;Ia=za;break}}}else{Ca=A;Da=j+1420|0;Ea=j+1428|0;Fa=j+1429|0;Ga=j+1430|0;Ha=j+1404|0;Ia=M}P=j+1424|0;O=0;N=Ca;J=Ia;Q=H;Y=H;while(1){if((O|0)<(c[N+124>>2]|0)){X=O;W=N;V=J;U=Q;T=Y;while(1){S=W+120|0;R=c[S>>2]|0;ga=ba(R,X)|0;ea=(c[Da>>2]|0)+(X*3|0)|0;m=a[ea]|0;Z=a[ea+1|0]|0;fa=a[ea+2|0]|0;ea=c[v>>2]|0;if((a[ea+ga|0]|0)==0){TGb(Ea|0,1,3)|0;Ja=1;Ka=c[S>>2]|0}else{Ja=0;Ka=R}b:do{if((Ja|0)<(Ka|0)){R=(X&3|0)==0;S=(X|0)/4|0;da=fa;La=Z;Ma=m;Na=Ja;Oa=Ka;Pa=W;Qa=ea;Ra=V;Sa=U;Ta=T;while(1){Ua=Na+ga|0;Va=a[Qa+Ua|0]|0;Wa=Va&255;if(Va<<24>>24==0){if((c[f>>2]|0)==1){Xa=0;Ya=Ra;Za=Sa;_a=Ta}else{$a=c[Ha>>2]|0;ab=c[K>>2]|0;bb=I+(Ra>>>3)|0;cb=(fe(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(Ra&7)>>>((32-ab|0)>>>0);ab=b[$a+(cb<<2)>>1]|0;bb=(b[$a+(cb<<2)+2>>1]|0)+Ra|0;cb=H>>>0>bb>>>0?bb:H;c[q>>2]=cb;Xa=ab;Ya=cb;Za=H;_a=H}cb=a[o+1272+(Xa<<3)+5|0]|0;ab=ba(d[Ea]|0,(cb&255)-7|0)|0;if(cb<<24>>24==0){db=2}else{db=cb<<24>>24==14?2:1}a[Ea]=db;cb=ab+(Ma&255)|0;ab=cb<<24;if((ab|0)<0){eb=0}else{eb=(ab|0)>520093696?31:cb&255}do{if((Na&3|0)==0){if(!R){cb=((ba(c[Pa+120>>2]|0,S)|0)+Na|0)/4|0;ab=c[P>>2]|0;fb=a[ab+(cb*3|0)+1|0]|0;gb=a[ab+(cb*3|0)+2|0]|0;hb=Ya;ib=Za;break}if((c[f>>2]|0)==1){jb=0;kb=Ya;lb=Za}else{cb=c[Ha>>2]|0;ab=c[K>>2]|0;bb=I+(Ya>>>3)|0;$a=(fe(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(Ya&7)>>>((32-ab|0)>>>0);ab=b[cb+($a<<2)>>1]|0;bb=(b[cb+($a<<2)+2>>1]|0)+Ya|0;$a=_a>>>0>bb>>>0?bb:_a;c[q>>2]=$a;jb=ab;kb=$a;lb=_a}$a=a[o+1272+(jb<<3)+5|0]|0;ab=ba(d[Fa]|0,($a&255)-7|0)|0;if($a<<24>>24==0){mb=2}else{mb=$a<<24>>24==14?2:1}a[Fa]=mb;$a=ab+(La&255)|0;ab=$a<<24;if((ab|0)<-536870912){nb=-32}else{nb=(ab|0)>520093696?31:$a&255}if((c[f>>2]|0)==1){ob=0;pb=kb}else{$a=c[Ha>>2]|0;ab=c[K>>2]|0;bb=I+(kb>>>3)|0;cb=(fe(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(kb&7)>>>((32-ab|0)>>>0);ab=b[$a+(cb<<2)>>1]|0;bb=(b[$a+(cb<<2)+2>>1]|0)+kb|0;cb=lb>>>0>bb>>>0?bb:lb;c[q>>2]=cb;ob=ab;pb=cb}cb=a[o+1272+(ob<<3)+5|0]|0;ab=ba(d[Ga]|0,(cb&255)-7|0)|0;if(cb<<24>>24==0){qb=2}else{qb=cb<<24>>24==14?2:1}a[Ga]=qb;cb=ab+(da&255)|0;ab=cb<<24;if((ab|0)<-536870912){rb=-32}else{rb=(ab|0)>520093696?31:cb&255}cb=((ba(c[Pa+120>>2]|0,S)|0)+Na|0)/4|0;ab=(c[P>>2]|0)+(cb*3|0)|0;a[ab]=eb;a[ab+1|0]=nb;a[ab+2|0]=rb;fb=nb;gb=rb;hb=pb;ib=lb}else{fb=La;gb=da;hb=Ya;ib=Za}}while(0);ab=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;cb=fb<<24>>24;bb=gb<<24>>24;$a=(eb<<24>>24)*1e3|0;b[(c[ab>>2]|0)+((ba(c[ab+32>>2]|0,X)|0)+(Na<<1))>>1]=d[((((bb*-172|0)+$a+(cb*-357|0)|0)/1e3|0)<<3)+1236056|0]<<2&992|d[((((cb*701|0)+$a|0)/1e3|0)<<3)+1236056|0]<<7&31744|(a[((((bb*886|0)+$a|0)/1e3|0)<<3)+1236056|0]&255)>>>3;sb=Na+1|0;tb=eb;ub=fb;vb=gb;wb=hb;xb=ib;yb=_a}else{c:do{if(R){do{if(!((d[Qa+(Ua+Oa)|0]|0)>>>0<(Va&255)>>>0)){if((d[Qa+(Ua+(Oa<<1))|0]|0)>>>0<(Va&255)>>>0){break}if(!((d[Qa+(Ua+(Oa*3|0))|0]|0)>>>0<(Va&255)>>>0)){break c}}}while(0);$a=Na+3&-4;bb=Wa+Na|0;if(($a|0)<(bb|0)){zb=$a;Ab=Oa}else{break}while(1){$a=((ba(Ab,S)|0)+zb|0)/4|0;cb=c[p>>2]|0;VGb((c[P>>2]|0)+($a*3|0)|0,4876856+((e[(c[cb>>2]|0)+((ba(c[cb+32>>2]|0,X)|0)+(zb<<1))>>1]|0)*3|0)|0,3)|0;cb=zb+4|0;if((cb|0)>=(bb|0)){break c}zb=cb;Ab=c[(c[B>>2]|0)+120>>2]|0}}}while(0);Va=Wa+Na|0;TGb(Ea|0,1,3)|0;Ua=c[p>>2]|0;bb=4876856+((e[(c[Ua>>2]|0)+((Va<<1)-2+(ba(c[Ua+32>>2]|0,X)|0))>>1]|0)*3|0)|0;sb=Va;tb=a[bb]|0;ub=a[bb+1|0]|0;vb=a[bb+2|0]|0;wb=Ra;xb=Sa;yb=Ta}bb=c[B>>2]|0;Va=c[bb+120>>2]|0;if((sb|0)>=(Va|0)){Bb=bb;Cb=wb;Db=xb;Eb=yb;break b}da=vb;La=ub;Ma=tb;Na=sb;Oa=Va;Pa=bb;Qa=c[v>>2]|0;Ra=wb;Sa=xb;Ta=yb}}else{Bb=W;Cb=V;Db=U;Eb=T}}while(0);ga=X+2|0;if((ga|0)<(c[Bb+124>>2]|0)){X=ga;W=Bb;V=Cb;U=Db;T=Eb}else{Fb=Bb;Gb=Cb;Hb=Db;Ib=Eb;break}}}else{Fb=N;Gb=J;Hb=Q;Ib=Y}T=O+1|0;if((T|0)<2){O=T;N=Fb;J=Gb;Q=Hb;Y=Ib}else{break}}Q_(C)}}while(0);Ib=MCb(g,c[p>>2]|0)|0;if((Ib|0)<0){r=Ib;i=k;return r|0}c[h>>2]=1;r=n;i=k;return r|0}function dMa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+1252|0);$Db(b+1420|0);$Db(b+1424|0);$Db(b+1432|0);JCb(b+4|0);return 0}function eMa(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((g|0)==0){return}j=e+1256|0;k=f+8|0;l=f+16|0;m=f|0;f=32-h|0;n=(i|0)!=0;i=e|0;o=e+4|0;p=e+1252|0;e=0;q=g;while(1){g=q-1|0;r=c[j>>2]|0;do{if((r|0)==0){s=0;t=c[k>>2]|0;u=c[l>>2]|0;v=c[m>>2]|0}else{w=c[k>>2]|0;x=c[l>>2]|0;y=c[m>>2]|0;z=y+(w>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7);if((r|0)<26){z=w+r|0;B=x>>>0>z>>>0?z:x;c[k>>2]=B;s=A>>>((32-r|0)>>>0);t=B;u=x;v=y;break}else{B=w+16|0;w=x>>>0>B>>>0?B:x;c[k>>2]=w;B=r-16|0;z=y+(w>>>3)|0;C=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7)>>>((48-r|0)>>>0);z=w+B|0;w=x>>>0>z>>>0?z:x;c[k>>2]=w;s=C|A>>>16<<B;t=w;u=x;v=y;break}}}while(0);r=v+(t>>>3)|0;y=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7)>>>(f>>>0);r=t+h|0;x=u>>>0>r>>>0?r:u;c[k>>2]=x;r=y+1|0;y=v+(x>>>3)|0;w=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(x&7)>>>(f>>>0);y=x+h|0;x=u>>>0>y>>>0?y:u;c[k>>2]=x;y=w+1|0;if(n){w=v+(x>>>3)|0;B=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(x&7)>>>17;w=x+15|0;c[k>>2]=u>>>0>w>>>0?w:u;D=B&65535}else{D=e}B=c[i>>2]|0;w=c[B+120>>2]|0;x=(s|0)%(w|0)|0;A=(s|0)/(w|0)|0;C=c[B+124>>2]|0;a:do{if((A|0)<(C|0)){B=w-x|0;z=(r|0)>(B|0)?B:r;B=C-A|0;E=(y|0)>(B|0)?B:y;B=c[o>>2]|0;F=(ba(c[B+32>>2]|0,A)|0)+(x<<1)|0;G=(c[B>>2]|0)+F|0;F=E-1|0;if((E|0)==0){break}E=z&255;B=(z|0)>0;if(!n){if(B){H=s;I=F;while(1){a[(c[p>>2]|0)+H|0]=E;if((I|0)==0){break a}else{H=(c[(c[i>>2]|0)+120>>2]|0)+H|0;I=I-1|0}}}else{I=s;H=F;while(1){a[(c[p>>2]|0)+I|0]=E;if((H|0)==0){break a}else{I=(c[(c[i>>2]|0)+120>>2]|0)+I|0;H=H-1|0}}}}if(B){J=s;K=G;L=F}else{H=s;I=F;while(1){a[(c[p>>2]|0)+H|0]=E;if((I|0)==0){break a}else{H=(c[(c[i>>2]|0)+120>>2]|0)+H|0;I=I-1|0}}}while(1){a[(c[p>>2]|0)+J|0]=E;I=0;do{b[K+(I<<1)>>1]=D;I=I+1|0;}while((I|0)<(z|0));if((L|0)==0){break}else{J=(c[(c[i>>2]|0)+120>>2]|0)+J|0;K=K+(((c[(c[o>>2]|0)+32>>2]|0)/2|0)<<1)|0;L=L-1|0}}}}while(0);if((g|0)==0){break}else{e=D;q=g}}return}function fMa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;j=e+8|0;k=e|0;l=e+16|0;m=b+1268|0;n=g;g=f;while(1){f=c[j>>2]|0;o=d[(c[k>>2]|0)+(f>>>3)|0]|0;c[j>>2]=((f|0)<(c[l>>2]|0))+f;if((o&128>>>((f&7)>>>0)|0)==0){p=6;break}q=g+1|0;r=c[m>>2]|0;if((q|0)>(r|0)){p=4;break}f=n<<1;if((fMa(b,e,q,f|1)|0)<0){s=-1094995529;p=9;break}else{n=f;g=q}}if((p|0)==4){yDb(c[b>>2]|0,16,2108352,(t=i,i=i+16|0,c[t>>2]=q,c[t+8>>2]=r,t)|0);i=t;s=-1094995529;i=h;return s|0}else if((p|0)==6){r=b+1264|0;q=c[r>>2]|0;if((q|0)>15){yDb(c[b>>2]|0,16,2050680,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}else{c[b+1272+(q<<3)>>2]=n;n=c[r>>2]|0;c[r>>2]=n+1;a[b+1272+(n<<3)+4|0]=g;s=0;i=h;return s|0}}else if((p|0)==9){i=h;return s|0}return 0}function gMa(a){a=a|0;return qhb(a)|0}function hMa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;i=i+1040|0;j=h|0;k=h+1024|0;l=h+1032|0;m=e;n=c[g+24>>2]|0;if((n|0)==0){o=-1094995529;i=h;return o|0}p=g+28|0;q=c[p>>2]|0;if((q|0)<2){o=-1094995529;i=h;return o|0}r=n;s=(d[r]|d[r+1|0]<<8)<<16>>16;if((q|0)==2){o=s<<16>>16==0?0:-1094995529;i=h;return o|0}r=((de(s|0)|0)&65535)+2|0;s=(r|0)>(q|0)?q:r;r=n+s|0;q=g+8|0;t=c[q>>2]|0;u=c[q+4>>2]|0;v=b+104|0;c[k>>2]=1;c[k+4>>2]=100;b=KDb(t,u,v,k)|0;k=b;b=c[g+48>>2]|0;g=YGb(b,(b|0)<0|0?-1:0,c[q>>2]|0,c[q+4>>2]|0)|0;c[l>>2]=1;c[l+4>>2]=100;q=KDb(g,F,v,l)|0;IAb(j,0,-1);if((s|0)>2){s=n+2|0;do{n=a[s]|0;l=n<<24>>24;if((l|0)==10){KAb(j,2185552,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}else if((l|0)!=13){MAb(j,n,1)}s=s+1|0;}while(s>>>0<r>>>0)}KAb(j,2108344,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if(!((c[j+4>>2]|0)>>>0<(c[j+8>>2]|0)>>>0)){o=-12;i=h;return o|0}shb(m,c[j>>2]|0,k,q-k|0,0)|0;c[f>>2]=(c[e+12>>2]|0)!=0;QAb(j,0)|0;o=c[p>>2]|0;i=h;return o|0}function iMa(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;d=a+100|0;c[d>>2]=48;e=cEb(48)|0;c[a+96>>2]=e;if((e|0)==0){f=-12;return f|0}UGb(e|0,671784,c[d>>2]|0)|0;d=uhb(c[a+860>>2]|0)|0;c[b>>2]=d;f=(d|0)!=0?0:-1094995529;return f|0}function jMa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+8|0;h=g|0;j=c[b+60>>2]|0;k=j+4|0;l=j+2052|0;m=l;c[m>>2]=k;c[j+2056>>2]=l;l=f+12|0;if((c[l>>2]|0)==0){n=0;i=g;return n|0}o=f+16|0;f=j;p=0;do{q=c[(c[o>>2]|0)+(p<<2)>>2]|0;if((c[q+84>>2]|0)!=3){r=4;break}s=xhb(c[f>>2]|0,c[q+92>>2]|0,0,h)|0;a:do{if((s|0)!=0){q=s;do{t=c[h>>2]|0;c[h>>2]=t-1;if((t|0)==0){break a}zhb(671832,j,c[q+16>>2]|0)|0;q=q+20|0;}while((q|0)!=0)}}while(0);p=p+1|0;}while(p>>>0<(c[l>>2]|0)>>>0);if((r|0)==4){yDb(b,16,2185512,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;n=-38;i=g;return n|0}if((c[m>>2]|0)==(k|0)){n=0;i=g;return n|0}m=d;x=de((SGb(k|0)|0)&65535|0)|0;a[m]=x;x=x>>8;a[m+1|0]=x;m=sAb(d+2|0,k,e-2|0)|0;if((m|0)>(e-3|0)){yDb(b,16,2108304,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;n=-22;i=g;return n|0}else{n=m+2|0;i=g;return n|0}return 0}function kMa(a){a=a|0;whb(c[c[a+60>>2]>>2]|0);return 0}function lMa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a+2056|0;g=c[f>>2]|0;h=a+2052|0;a=c[h>>2]|0;if(g>>>0<a>>>0){yDb(0,0,2050648,(j=i,i=i+24|0,c[j>>2]=2005160,c[j+8>>2]=1967608,c[j+16>>2]=91,j)|0);i=j;Cd()}else{j=g-a|0;g=d+1|0;sAb(a,b,(j|0)>(g|0)?g:j)|0;j=c[h>>2]|0;g=(c[f>>2]|0)-j|0;c[h>>2]=j+((g|0)>(d|0)?d:g);i=e;return}}function mMa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;b=i;d=a+2056|0;e=c[d>>2]|0;f=a+2052|0;a=c[f>>2]|0;if(e>>>0<a>>>0){yDb(0,0,2050648,(g=i,i=i+24|0,c[g>>2]=2005160,c[g+8>>2]=1967608,c[g+16>>2]=99,g)|0);i=g;Cd()}g=e-a|0;sAb(a,1939304,(g|0)>2?2:g)|0;g=c[f>>2]|0;if(!((c[d>>2]|0)>>>0>g>>>0)){i=b;return}c[f>>2]=g+1;i=b;return}function nMa(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;h=g|0;j=c[b+60>>2]|0;k=g;l=c[b+416>>2]|0;if((l|0)!=2){DDb(b,1967592,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1163346256;i=f;return n|0}l=c[b+100>>2]|0;if((l|0)<16){yDb(b,16,1939272,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1;i=f;return n|0}TGb(j+1316|0,0,256)|0;oDb(j+12468|0,-559038737);Z3(j,b);bOa(j+1244|0);Xe[c[j+1096>>2]&4095](h,c[b+96>>2]|0,4);Lmb();l=(d[k]|0)>>>7;c[j+1288>>2]=l;o=(d[k]|0)>>>6&1;c[j+1292>>2]=o;k=c[h>>2]&63;c[j+1304>>2]=k;if(k>>>0>31>>>0){yDb(b,16,1915064,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;n=-1;i=f;return n|0}h=g+12|0;g=(d[h]|0)>>>7;c[j+1296>>2]=g;p=(fe(c[h>>2]|0)|0)>>>20&2047;c[j+1300>>2]=p;h=b;yDb(h,48,1894576,(m=i,i=i+40|0,c[m>>2]=l,c[m+8>>2]=o,c[m+16>>2]=g,c[m+24>>2]=p,c[m+32>>2]=k,m)|0);i=m;c[j+12728>>2]=0;c[b+420>>2]=6;j=b+448|0;c[j>>2]=3;c[j+4>>2]=0;if(a[661824]|0){n=0;i=f;return n|0}yDb(h,48,2351592,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;c[1078145]=4845600;c[1078147]=8;if((N_(4312576,3,4,657993,2,1,657992,2,1,0,0,0,4)|0)!=0){yDb(h,16,2331568,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=f;return n|0}c[2128637]=4876576;c[2128639]=64;if((N_(8514544,6,16,661793,2,1,661792,2,1,0,0,0,4)|0)!=0){yDb(h,16,2307176,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=f;return n|0}c[1282827]=4874528;c[1282829]=512;if((N_(5131304,9,10,661769,2,1,661768,2,1,0,0,0,4)|0)==0){q=0}else{yDb(h,16,2288928,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=f;return n|0}a:while(1){j=q<<1;b=658e3+q|0;r=0;while(1){if((r|0)>=2){break}k=r+j|0;p=e[552528+(k<<1)>>1]|0;c[4601144+(q*40|0)+(r*20|0)+4>>2]=4845632+(p<<2);c[4601144+(q*40|0)+(r*20|0)+12>>2]=(e[552528+(k+1<<1)>>1]|0)-p;if((N_(4601144+(q*40|0)+(r*20|0)|0,9,d[b]|0,658024+(q<<9)+(r<<8)+2|0,4,2,658024+(q<<9)+(r<<8)|0,4,2,0,0,0,4)|0)==0){r=r+1|0}else{s=17;break a}}b=q+1|0;if((b|0)<7){q=b}else{s=19;break}}if((s|0)==17){yDb(h,16,2272712,(m=i,i=i+16|0,c[m>>2]=q,c[m+8>>2]=r,m)|0);i=m;n=-1;i=f;return n|0}else if((s|0)==19){a[661824]=1;n=0;i=f;return n|0}return 0}function oMa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;j=i;k=c[h+24>>2]|0;l=c[e+60>>2]|0;m=l;n=l+1572|0;o=n;p=l+1304|0;TGb(n|0,0,((c[p>>2]|0)*52|0)+52|0)|0;n=h+28|0;h=c[n>>2]|0;q=h&-4;if((q|0)<1){yDb(e,16,2185472,(r=i,i=i+8|0,c[r>>2]=h,r)|0);i=r;s=-1094995529;i=j;return s|0}if((q|0)!=(h|0)){yDb(e,24,2108224,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}h=d[k]|0;t=a[k+1|0]|0;u=q-4|0;q=f+76|0;c[q>>2]=1152;v=_$a(e,f,0)|0;if((v|0)<0){s=v;i=j;return s|0}v=l+12460|0;w=v;O$a(v,l+12464|0,u);v=c[w>>2]|0;if((v|0)==0){s=-12;i=j;return s|0}Xe[c[l+1096>>2]&4095](v,k+4|0,u>>2);k=c[w>>2]|0;w=u<<3;u=w>>>0>2147483639>>>0|(k|0)==0;v=u?0:k;k=u?8:w|8;u=(k|0)<(h|0)?k:h;do{if((c[p>>2]|0)<0){x=u;y=-1}else{h=l+1292|0;z=u;A=-1;B=0;a:while(1){C=B-1|0;b:do{if((B|0)==0){D=0;E=z;while(1){if((D|0)>=2){F=E;break b}G=v+(E>>>3)|0;H=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7)>>>28;G=E+4|0;c[o+4+(D<<2)>>2]=H;if((H+1|0)>>>0>18>>>0){I=18;break a}else{D=D+1|0;E=k>>>0>G>>>0?G:k}}}else{E=0;D=z;while(1){if((E|0)>=2){F=D;break b}G=c[1282827]|0;H=v+(D>>>3)|0;J=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(D&7)>>>23;H=(b[G+(J<<2)+2>>1]|0)+D|0;K=k>>>0>H>>>0?H:k;H=(b[G+(J<<2)>>1]|0)-5|0;if((H|0)==4){J=v+(K>>>3)|0;G=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(K&7)>>>28;J=K+4|0;c[o+(B*52|0)+4+(E<<2)>>2]=G;L=k>>>0>J>>>0?J:k;M=G}else{G=(c[o+(C*52|0)+4+(E<<2)>>2]|0)+H|0;c[o+(B*52|0)+4+(E<<2)>>2]=G;L=K;M=G}if((M+1|0)>>>0>18>>>0){I=18;break a}else{E=E+1|0;D=L}}}}while(0);if((c[o+(B*52|0)+4>>2]|0)==0){if((c[o+(B*52|0)+8>>2]|0)==0){N=A;O=F}else{I=21}}else{I=21}do{if((I|0)==21){I=0;if((c[h>>2]|0)==0){N=B;O=F;break}c[o+(B*52|0)>>2]=d[v+(F>>>3)|0]<<(F&7)>>>7&1;N=B;O=((F|0)<(k|0))+F|0}}while(0);C=B+1|0;if((C|0)>(c[p>>2]|0)){break}else{z=O;A=N;B=C}}if((I|0)==18){yDb(e,16,2050624,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}B=(N|0)<0;if(B){x=O;y=N;break}else{P=O;Q=0}while(1){if((c[o+(Q*52|0)+4>>2]|0)==0){R=P}else{A=c[1078145]|0;z=v+(P>>>3)|0;h=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(P&7)>>>29;z=(b[A+(h<<2)+2>>1]|0)+P|0;c[o+(Q*52|0)+12>>2]=b[A+(h<<2)>>1]|0;R=k>>>0>z>>>0?z:k}if((c[o+(Q*52|0)+8>>2]|0)==0){S=R}else{z=c[1078145]|0;h=v+(R>>>3)|0;A=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(R&7)>>>29;h=(b[z+(A<<2)+2>>1]|0)+R|0;c[o+(Q*52|0)+16>>2]=b[z+(A<<2)>>1]|0;S=k>>>0>h>>>0?h:k}h=Q+1|0;if((h|0)>(N|0)){break}else{P=S;Q=h}}if(B){x=S;y=N;break}h=l+1316|0;A=S;z=0;while(1){C=A;D=0;while(1){if((c[o+(z*52|0)+4+(D<<2)>>2]|0)==0){T=C}else{E=h+(D<<7)+(z<<2)|0;G=c[E>>2]|0;K=o+(z*52|0)+20+(D*12|0)+8|0;c[K>>2]=G;H=c[2128637]|0;J=v+(C>>>3)|0;U=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(C&7)>>>26;J=(b[H+(U<<2)+2>>1]|0)+C|0;V=k>>>0>J>>>0?J:k;J=(b[H+(U<<2)>>1]|0)-7|0;if((J|0)==8){U=v+(V>>>3)|0;W=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(V&7)>>>26;U=V+6|0;X=W;Y=k>>>0>U>>>0?U:k}else{X=J+G|0;Y=V}c[o+(z*52|0)+20+(D*12|0)>>2]=X;V=c[o+(z*52|0)+12+(D<<2)>>2]|0;if((V|0)==2){c[o+(z*52|0)+20+(D*12|0)+4>>2]=X;J=v+(Y>>>3)|0;U=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(Y&7)>>>26;J=(b[H+(U<<2)+2>>1]|0)+Y|0;W=k>>>0>J>>>0?J:k;J=(b[H+(U<<2)>>1]|0)-7|0;if((J|0)==8){U=v+(W>>>3)|0;Z=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(W&7)>>>26;U=W+6|0;_=Z;$=k>>>0>U>>>0?U:k}else{_=J+X|0;$=W}c[K>>2]=_;aa=$;ba=_}else if((V|0)==3){c[o+(z*52|0)+20+(D*12|0)+4>>2]=X;c[K>>2]=X;aa=Y;ba=X}else if((V|0)==0){W=v+(Y>>>3)|0;J=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Y&7)>>>26;W=(b[H+(J<<2)+2>>1]|0)+Y|0;U=k>>>0>W>>>0?W:k;W=(b[H+(J<<2)>>1]|0)-7|0;if((W|0)==8){J=v+(U>>>3)|0;Z=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(U&7)>>>26;J=U+6|0;ca=Z;da=k>>>0>J>>>0?J:k}else{ca=W+X|0;da=U}c[o+(z*52|0)+20+(D*12|0)+4>>2]=ca;U=v+(da>>>3)|0;W=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(da&7)>>>26;U=(b[H+(W<<2)+2>>1]|0)+da|0;J=k>>>0>U>>>0?U:k;U=(b[H+(W<<2)>>1]|0)-7|0;if((U|0)==8){W=v+(J>>>3)|0;Z=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(J&7)>>>26;W=J+6|0;ea=Z;fa=k>>>0>W>>>0?W:k}else{ea=U+ca|0;fa=J}c[K>>2]=ea;aa=fa;ba=ea}else if((V|0)==1){V=v+(Y>>>3)|0;J=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Y&7)>>>26;V=(b[H+(J<<2)+2>>1]|0)+Y|0;U=k>>>0>V>>>0?V:k;V=(b[H+(J<<2)>>1]|0)-7|0;if((V|0)==8){J=v+(U>>>3)|0;H=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(U&7)>>>26;J=U+6|0;ga=H;ha=k>>>0>J>>>0?J:k}else{ga=V+X|0;ha=U}c[o+(z*52|0)+20+(D*12|0)+4>>2]=ga;c[K>>2]=ga;aa=ha;ba=ga}else{aa=Y;ba=G}c[E>>2]=ba;T=aa}E=D+1|0;if((E|0)<2){C=T;D=E}else{break}}D=z+1|0;if((D|0)>(N|0)){x=T;y=N;break}else{A=T;z=D}}}}while(0);T=l+3236|0;N=T;TGb(T|0,0,9216)|0;T=l+12724|0;aa=x;x=0;ba=0;while(1){Y=aa;ga=0;while(1){ha=c[o+(ba*52|0)+4+(ga<<2)>>2]|0;X=N+(ga*4608|0)+(x<<2)|0;c:do{switch(ha|0){case 8:case 9:case 10:case 11:case 12:case 13:case 14:case 15:case 16:case 17:{ea=ha-1|0;fa=33-ha|0;ca=(-1<<ha-2)+1|0;da=X;_=0;$=Y;while(1){S=v+($>>>3)|0;Q=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<($&7)>>>(fa>>>0);S=ea+$|0;P=k>>>0>S>>>0?S:k;c[da>>2]=ca+Q;Q=_+1|0;if((Q|0)<36){da=da+4|0;_=Q;$=P}else{ia=P;break}}break};case 2:{$=c[4601188+((d[v+(Y>>>3)|0]<<(Y&7)>>>7&1)*20|0)>>2]|0;_=X;da=1;ca=((Y|0)<(k|0))+Y|0;while(1){ea=v+(ca>>>3)|0;fa=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ca&7)>>>23;ea=b[$+(fa<<2)>>1]|0;P=b[$+(fa<<2)+2>>1]|0;fa=P<<16>>16;if(P<<16>>16<0){P=ca+9|0;Q=k>>>0>P>>>0?P:k;P=v+(Q>>>3)|0;S=((fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Q&7)>>>((fa+32|0)>>>0))+ea|0;ja=b[$+(S<<2)+2>>1]|0;ka=b[$+(S<<2)>>1]|0;la=Q}else{ja=fa;ka=ea;la=ca}ea=ja+la|0;fa=k>>>0>ea>>>0?ea:k;c[_>>2]=a[661640+ka|0]|0;c[_+4>>2]=a[661608+ka|0]|0;if((da|0)>=18){ia=fa;break c}_=_+8|0;da=da+1|0;ca=fa}break};case 1:{ca=c[4601148+((d[v+(Y>>>3)|0]<<(Y&7)>>>7&1)*20|0)>>2]|0;da=X;_=1;$=((Y|0)<(k|0))+Y|0;while(1){fa=v+($>>>3)|0;ea=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<($&7)>>>23;fa=b[ca+(ea<<2)>>1]|0;Q=b[ca+(ea<<2)+2>>1]|0;ea=Q<<16>>16;if(Q<<16>>16<0){Q=$+9|0;S=k>>>0>Q>>>0?Q:k;Q=v+(S>>>3)|0;P=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(S&7)>>>((ea+32|0)>>>0))+fa|0;ma=b[ca+(P<<2)+2>>1]|0;na=b[ca+(P<<2)>>1]|0;oa=S}else{ma=ea;na=fa;oa=$}fa=ma+oa|0;ea=k>>>0>fa>>>0?fa:k;c[da>>2]=a[661736+na|0]|0;c[da+4>>2]=a[661704+na|0]|0;c[da+8>>2]=a[661672+na|0]|0;if((_|0)>=12){ia=ea;break c}da=da+12|0;_=_+1|0;$=ea}break};case-1:{$=X;_=0;while(1){da=c[T>>2]|0;c[m+12468+((da&63)<<2)>>2]=(c[m+12468+((da+9&63)<<2)>>2]|0)+(c[m+12468+((da+40&63)<<2)>>2]|0);da=c[T>>2]|0;c[T>>2]=da+1;c[$>>2]=(c[m+12468+((da&63)<<2)>>2]&1020)-510;da=_+1|0;if((da|0)<36){$=$+4|0;_=da}else{ia=Y;break}}break};case 3:case 4:case 5:case 6:case 7:{_=ha-1|0;$=d[658016+_|0]|0;da=c[4601144+(_*40|0)+((d[v+(Y>>>3)|0]<<(Y&7)>>>7&1)*20|0)+4>>2]|0;_=X;ca=1;ea=((Y|0)<(k|0))+Y|0;while(1){fa=v+(ea>>>3)|0;S=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ea&7)>>>23;fa=b[da+(S<<2)>>1]|0;P=b[da+(S<<2)+2>>1]|0;S=P<<16>>16;if(P<<16>>16<0){P=ea+9|0;Q=k>>>0>P>>>0?P:k;P=v+(Q>>>3)|0;R=((fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Q&7)>>>((S+32|0)>>>0))+fa|0;pa=b[da+(R<<2)+2>>1]|0;qa=b[da+(R<<2)>>1]|0;ra=Q}else{pa=S;qa=fa;ra=ea}fa=pa+ra|0;S=k>>>0>fa>>>0?fa:k;c[_>>2]=qa-$;if((ca|0)>=36){ia=S;break c}_=_+4|0;ca=ca+1|0;ea=S}break};default:{ia=Y}}}while(0);X=ga+1|0;if((X|0)<2){Y=ia;ga=X}else{break}}ga=ba+1|0;if((ga|0)<32){aa=ia;x=x+36|0;ba=ga}else{break}}Mmb(m,y,c[f+64>>2]|0,2);do{if(t<<24>>24==0){if((w|0)>=(ia|0)&(ia+32|0)>(w|0)){break}yDb(e,16,2005112,(r=i,i=i+16|0,c[r>>2]=ia,c[r+8>>2]=w,r)|0);i=r;s=-1;i=j;return s|0}else{c[q>>2]=c[l+1300>>2]}}while(0);q=l+12728|0;l=c[q>>2]|0;if((l|0)==0){c[g>>2]=1;s=c[n>>2]|0;i=j;return s|0}else{c[q>>2]=l-1;c[g>>2]=0;s=c[n>>2]|0;i=j;return s|0}return 0}function pMa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+12460|0);c[b+12464>>2]=0;return 0}function qMa(a){a=a|0;var b=0;b=c[a+60>>2]|0;TGb(b+1316|0,0,256)|0;c[b+12728>>2]=32;return}function rMa(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[f+60>>2]|0;j=c[f+100>>2]|0;if((j|0)<2){yDb(f,16,2108192,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;l=-1;i=g;return l|0}TGb(h+1316|0,0,256)|0;oDb(h+12468|0,-559038737);Z3(h,f);bOa(h+1244|0);Lmb();j=c[f+96>>2]|0;m=(j|0)==0;n=j;o=((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24)&31)+1|0;c[h+1304>>2]=o;if(o>>>0>31>>>0){yDb(f,16,2050600,(k=i,i=i+8|0,c[k>>2]=o,k)|0);i=k;l=-1094995529;i=g;return l|0}o=j+1|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=(j>>>4&15)+1|0;if(n>>>0>2>>>0){DDb(f,2005088,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=g;return l|0}p=m?0:4;c[h+1292>>2]=(j&255)<<p>>>7&1;c[h+12456>>2]=1<<((fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<((p|m&1)^1)>>>29<<1);c[f+420>>2]=6;m=(n|0)==2;p=f+448|0;c[p>>2]=m?3:4;c[p+4>>2]=m?0:0;c[f+416>>2]=n;if(a[653216]|0){l=0;i=g;return l|0}yDb(f,48,1967576,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;c[2218511]=4843432;c[2218513]=542;N_(8874040,9,33,657952,1,1,657912,1,1,0,0,0,4)|0;c[1154367]=4813888;c[1154369]=520;N_(4617464,9,19,652408,1,1,652384,1,1,0,0,0,4)|0;c[1154341]=4807680;c[1154343]=524;N_(4617360,9,256,650224,1,1,649968,1,1,0,0,0,4)|0;c[1078135]=4807648;c[1078137]=8;N_(4312536,3,4,649848,1,1,649840,1,1,0,0,0,4)|0;c[1078140]=4807136;c[1078142]=128;N_(4312556,7,16,649824,1,1,649808,1,1,0,0,0,4)|0;c[2128627]=4818360;c[2128629]=560;N_(8514504,9,64,653152,1,1,653088,1,1,0,0,0,4)|0;c[2128632]=4815968;c[2128634]=598;N_(8514524,9,65,653016,1,1,652944,1,1,0,0,0,4)|0;c[1154347]=4811840;c[1154349]=512;N_(4617384,9,49,651816,1,1,651760,1,1,651704,1,1,4)|0;c[1154352]=4809776;c[1154354]=516;N_(4617404,9,81,651616,1,1,651528,1,1,651440,1,1,4)|0;k=0;f=0;n=640;m=1184;p=1748;o=2298;h=2426;j=2554;q=3066;r=3578;s=4106;t=4618;while(1){c[4597468+(k*20|0)>>2]=4820600+((f&65535)<<2);u=k+1|0;c[4597476+(k*20|0)>>2]=(n&65535)-(e[134944+(k<<1)>>1]|0);N_(4597464+(k*20|0)|0,9,17,649896+(k*17|0)|0,1,1,649856+(k*17|0)|0,1,1,0,0,0,4)|0;c[4617428+(k*20|0)>>2]=4820600+((m&65535)<<2);v=b[134944+(k+2<<1)>>1]|0;c[4617436+(k*20|0)>>2]=(p&65535)-(v&65535);N_(4617424+(k*20|0)|0,9,125,652128+(k*125|0)|0,1,1,651872+(k*125|0)|0,1,1,0,0,0,4)|0;c[4600988+(k*20|0)>>2]=4820600+((o&65535)<<2);w=b[134944+(k+4<<1)>>1]|0;c[4600996+(k*20|0)>>2]=(h&65535)-(w&65535);N_(4600984+(k*20|0)|0,7,15,651408+(k*15|0)|0,1,1,651376+(k*15|0)|0,1,1,0,0,0,4)|0;c[4601028+(k*20|0)>>2]=4820600+((j&65535)<<2);x=b[134944+(k+6<<1)>>1]|0;c[4601036+(k*20|0)>>2]=(q&65535)-(x&65535);N_(4601024+(k*20|0)|0,9,31,651312+(k*31|0)|0,1,1,651248+(k*31|0)|0,1,1,0,0,0,4)|0;c[4601068+(k*20|0)>>2]=4820600+((r&65535)<<2);y=b[134944+(k+8<<1)>>1]|0;c[4601076+(k*20|0)>>2]=(s&65535)-(y&65535);N_(4601064+(k*20|0)|0,9,63,651120+(k*63|0)|0,1,1,650992+(k*63|0)|0,1,1,0,0,0,4)|0;z=t&65535;c[4601108+(k*20|0)>>2]=4820600+(z<<2);A=b[134944+(k+11<<1)>>1]|0;c[4601116+(k*20|0)>>2]=(A&65535)-z;N_(4601104+(k*20|0)|0,9,127,650736+(k*127|0)|0,1,1,650480+(k*127|0)|0,1,1,0,0,0,4)|0;if((u|0)<2){k=u;f=n;n=v;m=p;p=w;o=h;h=x;j=q;q=y;r=s;s=t;t=A}else{break}}a[653216]=1;l=0;i=g;return l|0}function sMa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0;j=i;i=i+24|0;k=j|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;h=c[e+60>>2]|0;n=h;o=h+1572|0;c[f+76>>2]=1152;p=_$a(e,f,0)|0;if((p|0)<0){q=p;i=j;return q|0}p=h+12452|0;r=(c[p>>2]|0)==0;if(r){TGb(h+3236|0,0,9216)|0;c[h+1312>>2]=0;s=0}else{s=c[h+1312>>2]&7}t=m<<3;u=t>>>0>2147483639>>>0|(l|0)==0;v=u?0:l;l=u?0:t;u=k|0;c[u>>2]=v;w=k+12|0;c[w>>2]=l;x=l+8|0;y=k+16|0;c[y>>2]=x;c[k+4>>2]=v+(l>>3);l=k+8|0;z=h+1312|0;A=x>>>0>s>>>0?s:x;c[l>>2]=A;do{if(r){s=(c[h+1304>>2]|0)+1|0;B=a[655336+s|0]|0;if(B<<24>>24==0){C=0;D=A;break}E=B&255;B=E-1|0;do{if((B|0)==0){F=0;G=A}else{H=v+(A>>>3)|0;I=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(A&7);if((B|0)<26){H=B+A|0;J=x>>>0>H>>>0?H:x;c[l>>2]=J;F=I>>>((33-E|0)>>>0);G=J;break}else{J=A+16|0;H=x>>>0>J>>>0?J:x;J=E-17|0;K=v+(H>>>3)|0;L=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(H&7)>>>((49-E|0)>>>0);K=H+J|0;H=x>>>0>K>>>0?K:x;c[l>>2]=H;F=L|I>>>16<<J;G=H;break}}}while(0);E=c[653224+(s<<2)>>2]|0;if(F>>>0<E>>>0){C=F;D=G;break}B=d[v+(G>>>3)|0]<<(G&7)>>>7;H=((G|0)<(x|0))+G|0;c[l>>2]=H;C=(B&1|F<<1)-E|0;D=H}else{H=c[h+1308>>2]|0;E=c[2218511]|0;B=v+(A>>>3)|0;J=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>23;B=b[E+(J<<2)>>1]|0;I=b[E+(J<<2)+2>>1]|0;J=I<<16>>16;if(I<<16>>16<0){I=A+9|0;L=x>>>0>I>>>0?I:x;I=v+(L>>>3)|0;K=((fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>((J+32|0)>>>0))+B|0;M=b[E+(K<<2)+2>>1]|0;N=b[E+(K<<2)>>1]|0;O=L}else{M=J;N=B;O=A}B=M+O|0;J=x>>>0>B>>>0?B:x;c[l>>2]=J;B=N+H|0;if((B|0)<=32){C=B;D=J;break}C=B-33|0;D=J}}while(0);N=h+1304|0;if((C|0)>((c[N>>2]|0)+1|0)){yDb(e,16,2185448,(O=i,i=i+8|0,c[O>>2]=C,O)|0);i=O;q=-1094995529;i=j;return q|0}c[h+1308>>2]=C;do{if((C|0)==0){P=0}else{O=C-1|0;M=(C|0)>0;if(M){A=O;F=D;G=0;J=0;while(1){B=c[4597468+(((G|0)>2|0)*20|0)>>2]|0;H=v+(F>>>3)|0;L=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>23;H=b[B+(L<<2)>>1]|0;K=b[B+(L<<2)+2>>1]|0;L=K<<16>>16;if(K<<16>>16<0){K=F+9|0;E=x>>>0>K>>>0?K:x;K=v+(E>>>3)|0;I=((fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(E&7)>>>((L+32|0)>>>0))+H|0;Q=b[B+(I<<2)+2>>1]|0;R=b[B+(I<<2)>>1]|0;S=E}else{Q=L;R=H;S=F}H=Q+S|0;L=x>>>0>H>>>0?H:x;H=G+R|0;E=(H|0)>15?H-17|0:H;c[o+(A*52|0)+4>>2]=E;H=c[4597468+(((J|0)>2|0)*20|0)>>2]|0;I=v+(L>>>3)|0;B=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>23;I=b[H+(B<<2)>>1]|0;K=b[H+(B<<2)+2>>1]|0;B=K<<16>>16;if(K<<16>>16<0){K=L+9|0;T=x>>>0>K>>>0?K:x;K=v+(T>>>3)|0;U=((fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(T&7)>>>((B+32|0)>>>0))+I|0;V=b[H+(U<<2)+2>>1]|0;W=b[H+(U<<2)>>1]|0;X=T}else{V=B;W=I;X=L}L=V+X|0;Y=x>>>0>L>>>0?L:x;L=J+W|0;I=(L|0)>15?L-17|0:L;c[o+(A*52|0)+8>>2]=I;if((A|0)>0){A=A-1|0;F=Y;G=E;J=I}else{break}}c[l>>2]=Y;Z=Y}else{Z=D}if((c[h+1292>>2]|0)==0){P=C;break}if(M){J=0;G=0;while(1){if((c[o+(G*52|0)+4>>2]|0)==0){if((c[o+(G*52|0)+8>>2]|0)==0){_=J}else{$=29}}else{$=29}if(($|0)==29){$=0;_=J+1|0}F=G+1|0;if((F|0)<(C|0)){J=_;G=F}else{aa=_;break}}}else{aa=0}G=a[655336+aa|0]|0;do{if(G<<24>>24==0){ba=0}else{J=G&255;F=J-1|0;do{if((F|0)==0){ca=0;da=Z}else{A=v+(Z>>>3)|0;s=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(Z&7);if((F|0)<26){A=Z+F|0;I=x>>>0>A>>>0?A:x;c[l>>2]=I;ca=s>>>((33-J|0)>>>0);da=I;break}else{I=Z+16|0;A=x>>>0>I>>>0?I:x;I=J-17|0;E=v+(A>>>3)|0;L=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(A&7)>>>((49-J|0)>>>0);E=A+I|0;A=x>>>0>E>>>0?E:x;c[l>>2]=A;ca=L|s>>>16<<I;da=A;break}}}while(0);J=c[653224+(aa<<2)>>2]|0;if(ca>>>0<J>>>0){ba=ca;break}F=d[v+(da>>>3)|0]<<(da&7)>>>7;c[l>>2]=((da|0)<(x|0))+da;ba=(F&1|ca<<1)-J|0}}while(0);G=uMa(k,aa,ba)|0;if(M){ea=O;fa=G}else{P=C;break}while(1){if((c[o+(ea*52|0)+4>>2]|0)==0){if((c[o+(ea*52|0)+8>>2]|0)==0){ga=fa}else{$=42}}else{$=42}if(($|0)==42){$=0;c[o+(ea*52|0)>>2]=fa&1;ga=fa>>1}if((ea|0)>0){ea=ea-1|0;fa=ga}else{P=C;break}}}}while(0);if((P|0)<(c[N>>2]|0)){ga=P;do{c[o+(ga*52|0)+8>>2]=0;c[o+(ga*52|0)+4>>2]=0;ga=ga+1|0;}while((ga|0)<(c[N>>2]|0))}if(r){r=h+1444|0;N=h+1316|0;ga=0;do{c[r+(ga<<2)>>2]=1;c[N+(ga<<2)>>2]=1;ga=ga+1|0;}while((ga|0)<32)}ga=(C|0)>0;do{if(ga){N=c[y>>2]|0;r=c[u>>2]|0;P=0;do{fa=c[o+(P*52|0)+4>>2]|0;ea=(fa|0)==0;$=c[o+(P*52|0)+8>>2]|0;do{if((fa|$|0)!=0){ba=(($|0)!=0)+((fa|0)!=0)|0;aa=ba-1|0;if((ba|0)<=0){break}ba=c[4312540+(aa*20|0)>>2]|0;ca=c[4312536+(aa*20|0)>>2]|0;da=c[l>>2]|0;x=r+(da>>>3)|0;v=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(da&7)>>>((32-ca|0)>>>0);ca=b[ba+(v<<2)>>1]|0;x=(b[ba+(v<<2)+2>>1]|0)+da|0;c[l>>2]=N>>>0>x>>>0?x:N;if(!ea){c[o+(P*52|0)+12>>2]=ca>>(aa<<1)}if(($|0)==0){break}c[o+(P*52|0)+16>>2]=ca&3}}while(0);P=P+1|0;}while((P|0)<(C|0));if(!ga){break}P=h+1316|0;N=c[y>>2]|0;r=c[u>>2]|0;$=0;do{ea=0;do{if((c[o+($*52|0)+4+(ea<<2)>>2]|0)!=0){fa=P+(ea<<7)+($<<2)|0;if((c[fa>>2]|0)==0){ca=c[2128632]|0;aa=c[l>>2]|0;x=r+(aa>>>3)|0;da=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(aa&7)>>>23;x=b[ca+(da<<2)>>1]|0;v=b[ca+(da<<2)+2>>1]|0;da=v<<16>>16;if(v<<16>>16<0){v=aa+9|0;ba=N>>>0>v>>>0?v:N;v=r+(ba>>>3)|0;Z=((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(ba&7)>>>((da+32|0)>>>0))+x|0;ha=b[ca+(Z<<2)+2>>1]|0;ia=b[ca+(Z<<2)>>1]|0;ja=ba}else{ha=da;ia=x;ja=aa}aa=ha+ja|0;x=N>>>0>aa>>>0?aa:N;c[l>>2]=x;if((ia|0)==64){aa=r+(x>>>3)|0;da=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(x&7)>>>26;aa=x+6|0;ba=N>>>0>aa>>>0?aa:N;c[l>>2]=ba;ka=da|64;la=ba}else{ka=ia;la=x}c[o+($*52|0)+20+(ea*12|0)>>2]=(ka+103+(c[o+($*52|0)+20+(ea*12|0)+8>>2]|0)&127)-6;ma=la}else{x=c[l>>2]|0;ba=r+(x>>>3)|0;da=(fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(x&7)>>>25;ba=x+7|0;x=N>>>0>ba>>>0?ba:N;c[l>>2]=x;c[o+($*52|0)+20+(ea*12|0)>>2]=da-6;c[fa>>2]=0;ma=x}x=o+($*52|0)+12+(ea<<2)|0;fa=0;da=ma;while(1){if((c[x>>2]&2>>>(fa>>>0)|0)==0){ba=c[2128627]|0;aa=r+(da>>>3)|0;Z=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(da&7)>>>23;aa=b[ba+(Z<<2)>>1]|0;ca=b[ba+(Z<<2)+2>>1]|0;Z=ca<<16>>16;if(ca<<16>>16<0){ca=da+9|0;v=N>>>0>ca>>>0?ca:N;ca=r+(v>>>3)|0;_=((fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(v&7)>>>((Z+32|0)>>>0))+aa|0;na=b[ba+(_<<2)+2>>1]|0;oa=b[ba+(_<<2)>>1]|0;pa=v}else{na=Z;oa=aa;pa=da}aa=na+pa|0;Z=N>>>0>aa>>>0?aa:N;c[l>>2]=Z;if((oa|0)==31){aa=r+(Z>>>3)|0;v=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(Z&7)>>>26;aa=Z+6|0;_=N>>>0>aa>>>0?aa:N;c[l>>2]=_;qa=v|64;ra=_}else{qa=oa;ra=Z}c[o+($*52|0)+20+(ea*12|0)+(fa+1<<2)>>2]=(qa+103+(c[o+($*52|0)+20+(ea*12|0)+(fa<<2)>>2]|0)&127)-6;sa=ra}else{c[o+($*52|0)+20+(ea*12|0)+(fa+1<<2)>>2]=c[o+($*52|0)+20+(ea*12|0)+(fa<<2)>>2];sa=da}Z=fa+1|0;if((Z|0)<2){fa=Z;da=sa}else{break}}}ea=ea+1|0;}while((ea|0)<2);$=$+1|0;}while(($|0)<(C|0));if(!ga){break}$=h+3236|0;N=h+12468|0;r=h+12724|0;P=0;ea=0;while(1){da=0;do{fa=c[o+(P*52|0)+4+(da<<2)>>2]|0;switch(fa|0){case-1:{x=0;do{Z=c[r>>2]|0;c[N+((Z&63)<<2)>>2]=(c[N+((Z+9&63)<<2)>>2]|0)+(c[N+((Z+40&63)<<2)>>2]|0);Z=c[r>>2]|0;c[r>>2]=Z+1;c[$+(da*4608|0)+(x+ea<<2)>>2]=(c[N+((Z&63)<<2)>>2]&1020)-510;x=x+1|0;}while((x|0)<36);break};case 5:case 6:case 7:case 8:{x=c[649768+(fa<<2)>>2]|0;Z=fa-5|0;_=c[y>>2]|0;v=c[u>>2]|0;aa=c[552504+(Z<<2)>>2]|0;ba=0;ca=x<<1;D=c[l>>2]|0;while(1){Y=ca>>>0>x>>>0|0;W=c[4600984+(Z*40|0)+(Y*20|0)+4>>2]|0;X=c[4600984+(Z*40|0)+(Y*20|0)>>2]|0;Y=v+(D>>>3)|0;V=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(D&7)>>>((32-X|0)>>>0);Y=b[W+(V<<2)>>1]|0;R=b[W+(V<<2)+2>>1]|0;V=R<<16>>16;if(R<<16>>16<0){R=D+X|0;X=_>>>0>R>>>0?R:_;R=v+(X>>>3)|0;S=((fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(X&7)>>>((V+32|0)>>>0))+Y|0;ta=b[W+(S<<2)+2>>1]|0;ua=b[W+(S<<2)>>1]|0;va=X}else{ta=V;ua=Y;va=D}Y=ta+va|0;wa=_>>>0>Y>>>0?Y:_;Y=aa+ua|0;c[$+(da*4608|0)+(ba+ea<<2)>>2]=Y;V=ba+1|0;if((V|0)<36){ba=V;ca=((Y|0)>-1?Y:-Y|0)+(ca>>1)|0;D=wa}else{break}}c[l>>2]=wa;break};case 3:case 4:{D=fa-3|0;ca=c[y>>2]|0;ba=c[u>>2]|0;aa=c[559496+(D<<2)>>2]|0;_=c[4617388+(D*20|0)>>2]|0;D=0;v=c[l>>2]|0;do{Z=ba+(v>>>3)|0;x=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(v&7)>>>23;Z=b[_+(x<<2)>>1]|0;Y=b[_+(x<<2)+2>>1]|0;x=Y<<16>>16;if(Y<<16>>16<0){Y=v+9|0;V=ca>>>0>Y>>>0?Y:ca;Y=ba+(V>>>3)|0;X=((fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(V&7)>>>((x+32|0)>>>0))+Z|0;xa=b[_+(X<<2)+2>>1]|0;ya=b[_+(X<<2)>>1]|0;za=V}else{xa=x;ya=Z;za=v}Z=xa+za|0;v=ca>>>0>Z>>>0?Z:ca;Z=aa+ya|0;x=D+ea|0;c[$+(da*4608|0)+((x|1)<<2)>>2]=Z>>4;c[$+(da*4608|0)+(x<<2)>>2]=(Z&8|0)!=0?Z|-16:Z&15;D=D+2|0;}while((D|0)<36);c[l>>2]=v;break};case 0:{break};case 1:{D=0;aa=c[y>>2]|0;ca=c[u>>2]|0;do{_=c[1154367]|0;ba=c[l>>2]|0;Z=ca+(ba>>>3)|0;x=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(ba&7)>>>23;Z=b[_+(x<<2)>>1]|0;V=b[_+(x<<2)+2>>1]|0;x=V<<16>>16;if(V<<16>>16<0){V=ba+9|0;X=aa>>>0>V>>>0?V:aa;V=ca+(X>>>3)|0;Y=((fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(X&7)>>>((x+32|0)>>>0))+Z|0;Aa=b[_+(Y<<2)+2>>1]|0;Ba=b[_+(Y<<2)>>1]|0;Ca=X}else{Aa=x;Ba=Z;Ca=ba}ba=Aa+Ca|0;c[l>>2]=aa>>>0>ba>>>0?ba:aa;ba=uMa(k,18,Ba)|0;Z=D+ea|0;ca=c[u>>2]|0;aa=c[y>>2]|0;x=0;X=ba;while(1){if((X&131072|0)==0){Da=0}else{ba=c[l>>2]|0;Y=d[ca+(ba>>>3)|0]<<(ba&7)>>>7;c[l>>2]=((ba|0)<(aa|0))+ba;Da=(Y<<1&2)-1|0}c[$+(da*4608|0)+(Z+x<<2)>>2]=Da;Y=x+1|0;if((Y|0)<18){x=Y;X=X<<1}else{break}}D=D+18|0;}while((D|0)<36);break};case 2:{D=c[y>>2]|0;aa=c[u>>2]|0;ca=0;v=6;X=c[l>>2]|0;while(1){x=c[4617428+(((v|0)>3|0)*20|0)>>2]|0;Z=aa+(X>>>3)|0;Y=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(X&7)>>>23;Z=b[x+(Y<<2)>>1]|0;ba=b[x+(Y<<2)+2>>1]|0;Y=ba<<16>>16;if(ba<<16>>16<0){ba=X+9|0;_=D>>>0>ba>>>0?ba:D;ba=aa+(_>>>3)|0;V=((fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(_&7)>>>((Y+32|0)>>>0))+Z|0;Ea=b[x+(V<<2)+2>>1]|0;Fa=b[x+(V<<2)>>1]|0;Ga=_}else{Ea=Y;Fa=Z;Ga=X}Z=Ea+Ga|0;Ha=D>>>0>Z>>>0?Z:D;Z=ca+ea|0;c[$+(da*4608|0)+(Z<<2)>>2]=a[652688+Fa|0]|0;c[$+(da*4608|0)+(Z+1<<2)>>2]=a[652560+Fa|0]|0;c[$+(da*4608|0)+(Z+2<<2)>>2]=a[652432+Fa|0]|0;Z=ca+3|0;if((Z|0)<36){ca=Z;v=(a[652816+Fa|0]|0)+(v>>1)|0;X=Ha}else{break}}c[l>>2]=Ha;break};default:{X=c[y>>2]|0;v=c[u>>2]|0;ca=(-1<<fa-2)+1|0;D=fa-9|0;aa=41-fa|0;Z=c[l>>2]|0;Y=c[1154341]|0;if((fa|0)==9){_=0;V=Z;while(1){x=v+(V>>>3)|0;ba=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(V&7)>>>23;x=b[Y+(ba<<2)>>1]|0;S=b[Y+(ba<<2)+2>>1]|0;ba=S<<16>>16;if(S<<16>>16<0){S=V+9|0;W=X>>>0>S>>>0?S:X;S=v+(W>>>3)|0;R=((fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(W&7)>>>((ba+32|0)>>>0))+x|0;Ia=b[Y+(R<<2)+2>>1]|0;Ja=b[Y+(R<<2)>>1]|0;Ka=W}else{Ia=ba;Ja=x;Ka=V}x=Ia+Ka|0;ba=X>>>0>x>>>0?x:X;c[$+(da*4608|0)+(_+ea<<2)>>2]=ca+Ja;x=_+1|0;if((x|0)<36){_=x;V=ba}else{La=ba;break}}}else{V=0;_=Z;while(1){fa=v+(_>>>3)|0;ba=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(_&7)>>>23;fa=b[Y+(ba<<2)>>1]|0;x=b[Y+(ba<<2)+2>>1]|0;ba=x<<16>>16;if(x<<16>>16<0){x=_+9|0;W=X>>>0>x>>>0?x:X;x=v+(W>>>3)|0;R=((fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(W&7)>>>((ba+32|0)>>>0))+fa|0;Ma=b[Y+(R<<2)+2>>1]|0;Na=b[Y+(R<<2)>>1]|0;Oa=W}else{Ma=ba;Na=fa;Oa=_}fa=Ma+Oa|0;ba=X>>>0>fa>>>0?fa:X;fa=$+(da*4608|0)+(V+ea<<2)|0;W=Na<<D;c[fa>>2]=W;R=v+(ba>>>3)|0;x=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(ba&7)>>>(aa>>>0);R=ba+D|0;ba=X>>>0>R>>>0?R:X;c[fa>>2]=ca+(x|W);W=V+1|0;if((W|0)<36){V=W;_=ba}else{La=ba;break}}}c[l>>2]=La}}da=da+1|0;}while((da|0)<2);da=P+1|0;if((da|0)<(C|0)){P=da;ea=ea+36|0}else{break}}}}while(0);Mmb(n,C-1|0,c[f+64>>2]|0,c[e+416>>2]|0);e=(c[p>>2]|0)+1|0;c[p>>2]=e;f=c[l>>2]|0;c[z>>2]=f;if(((c[w>>2]|0)-f|0)<8){c[z>>2]=t}if((e|0)>=(c[h+12456>>2]|0)){c[p>>2]=0}c[g>>2]=1;if((c[p>>2]|0)==0){q=m;i=j;return q|0}q=c[z>>2]>>3;i=j;return q|0}function tMa(a){a=a|0;c[(c[a+60>>2]|0)+12452>>2]=0;return}function uMa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((e|0)==0|(e|0)==(b|0)){f=0;g=e<<1;h=(g|0)>(b|0);i=h<<31>>31;j=f^i;return j|0}k=b-e|0;l=(k|0)<(e|0)?k:e;k=l-1|0;m=655864+(k<<7)|0;n=b-1|0;o=d[655336+(k*33|0)+n|0]|0;p=o-1|0;do{if((p|0)==0){q=0}else{r=a+8|0;s=c[r>>2]|0;t=c[a+16>>2]|0;u=c[a>>2]|0;v=u+(s>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(s&7);if((p|0)<26){v=s+p|0;c[r>>2]=t>>>0>v>>>0?v:t;q=w>>>((33-o|0)>>>0);break}else{v=s+16|0;s=t>>>0>v>>>0?v:t;c[r>>2]=s;v=o-17|0;x=u+(s>>>3)|0;u=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(s&7)>>>((49-o|0)>>>0);x=s+v|0;c[r>>2]=t>>>0>x>>>0?x:t;q=u|w>>>16<<v;break}}}while(0);o=c[653224+(k*132|0)+(n<<2)>>2]|0;if(q>>>0<o>>>0){y=q;z=m;A=0;B=b;C=l}else{n=a+8|0;k=c[n>>2]|0;p=(d[(c[a>>2]|0)+(k>>>3)|0]|0)<<(k&7)>>>7;c[n>>2]=((k|0)<(c[a+16>>2]|0))+k;y=(p&1|q<<1)-o|0;z=m;A=0;B=b;C=l}while(1){l=B-1|0;m=c[z+(l<<2)>>2]|0;if(y>>>0<m>>>0){D=y;E=z;F=A;G=C}else{D=y-m|0;E=z-128|0;F=1<<l|A;G=C-1|0}if((G|0)>0){y=D;z=E;A=F;B=l;C=G}else{f=F;break}}g=e<<1;h=(g|0)>(b|0);i=h<<31>>31;j=f^i;return j|0}function vMa(a){a=a|0;var b=0;b=c[1178424+(c[a+14176>>2]<<2)>>2]|0;c[a+9892>>2]=b;c[a+9888>>2]=b;return}function wMa(a){a=a|0;var b=0;b=1<<(c[a+14176>>2]|0)+7;c[a+9860>>2]=b;c[a+9864>>2]=b;c[a+9868>>2]=b;TGb(a+11824|0,0,32)|0;return}function xMa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(a[1180200]|0){return}a[1180200]=1;c[1889813]=6859944;c[1889815]=512;N_(7559248,9,12,1179904,1,1,1179880,2,2,0,0,0,4)|0;c[1889819]=6857888;c[1889821]=514;N_(7559272,9,12,1179944,1,1,1179920,2,2,0,0,0,4)|0;c[1439777]=6855816;c[1439779]=518;N_(5759104,9,17,1180089,2,1,1180088,2,1,0,0,0,4)|0;c[1719029]=6853664;c[1719031]=538;N_(6876112,9,36,1180129,2,1,1180128,2,1,0,0,0,4)|0;c[1719041]=6851616;c[1719043]=512;N_(6876160,9,64,1179961,2,1,1179960,2,1,0,0,0,4)|0;c[1719035]=6851360;c[1719037]=64;N_(6876136,6,7,194953,2,1,194952,2,1,0,0,0,4)|0;c[1719067]=6851104;c[1719069]=64;N_(6876264,6,11,198041,2,1,198040,2,1,0,0,0,4)|0;OOa(1148184,6844904);OOa(1147992,6845294);c[287058]=6848384;c[287060]=680;d=c[287048]|0;N_(1148228,9,(c[287046]|0)+2|0,d+2|0,4,2,d,4,2,0,0,0,4)|0;c[287062]=6864688;if((c[287059]|0)>0){d=0;do{e=c[287058]|0;f=b[e+(d<<2)>>1]|0;g=f<<16>>16;h=b[e+(d<<2)+2>>1]|0;do{if(h<<16>>16==0){i=65;j=64}else{if(h<<16>>16<0){i=0;j=f;break}e=c[287046]|0;if((g|0)==(e|0)){i=65;j=0;break}if((g|0)==(e+1|0)){i=0;j=127;break}i=(a[(c[287049]|0)+g|0]|0)+1&255;j=a[(c[287050]|0)+g|0]|0}}while(0);a[(c[287062]|0)+(d<<2)+2|0]=h;g=c[287062]|0;b[g+(d<<2)>>1]=j;a[g+(d<<2)+3|0]=i;d=d+1|0;}while((d|0)<(c[287059]|0))}c[287010]=6845688;c[287012]=674;d=c[287e3]|0;N_(1148036,9,(c[286998]|0)+2|0,d+2|0,4,2,d,4,2,0,0,0,4)|0;c[287014]=6861992;if((c[287011]|0)>0){k=0}else{return}do{d=c[287010]|0;i=b[d+(k<<2)>>1]|0;j=i<<16>>16;g=b[d+(k<<2)+2>>1]|0;do{if(g<<16>>16==0){l=65;m=64}else{if(g<<16>>16<0){l=0;m=i;break}d=c[286998]|0;if((j|0)==(d|0)){l=65;m=0;break}if((j|0)==(d+1|0)){l=0;m=127;break}l=(a[(c[287001]|0)+j|0]|0)+1&255;m=a[(c[287002]|0)+j|0]|0}}while(0);a[(c[287014]|0)+(k<<2)+2|0]=g;j=c[287014]|0;b[j+(k<<2)>>1]=m;a[j+(k<<2)+3|0]=l;k=k+1|0;}while((k|0)<(c[287011]|0));return}function yMa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;i=i+8|0;h=g|0;j=b+16|0;k=c[j>>2]|0;c[h>>2]=k;if((e|0)==0){l=0;i=g;return l|0}a:do{if((e|0)>0){m=b+20|0;n=d+e|0;o=d;b:do{if((f|0)==0){p=0;q=c[m>>2]|0;r=k;while(1){do{if((q&1|0)==0){s=(f1a(d+p|0,n,h)|0)-o|0;t=s-1|0;u=c[m>>2]|0;v=c[h>>2]|0;do{if((u|0)==0){if(!((v-257|0)>>>0<175>>>0)){w=0;x=16;break}c[m>>2]=4;y=s;z=v}else{w=u;x=16}}while(0);if((x|0)==16){x=0;if((v|0)==439){A=t;x=37;break b}if((w|0)==2&(v|0)==435){c[m>>2]=0;B=0;x=20}else{if((w|0)<4){B=w;x=20}else{C=w;D=v}}do{if((x|0)==20){x=0;if((v|0)!=437){C=B;D=v;break}u=B+1|0;c[m>>2]=u;C=u;D=437}}while(0);if((C|0)==4){y=t;z=D}else{E=t;F=C;G=D;break}}if((z&-256|0)==256&(z-257|0)>>>0>174>>>0){H=y;x=45;break b}else{E=y;F=4;G=z}}else{do{if((r|0)==437){if((a[d+p|0]&-16)<<24>>24==-128){I=q;break}v=q-1|0;c[m>>2]=v;I=v}else if((r|0)==439){if((a[d+p|0]&3)==3){c[m>>2]=0;I=0;break}else{v=q+1&3;c[m>>2]=v;I=v;break}}else{I=q}}while(0);t=r+1|0;c[h>>2]=t;E=p;F=I;G=t}}while(0);t=E+1|0;if((t|0)<(e|0)){p=t;q=F;r=G}else{J=G;break a}}}else{r=0;do{q=c[m>>2]|0;c:do{if((q&1|0)==0){p=(f1a(d+r|0,n,h)|0)-o|0;t=p-1|0;v=c[m>>2]|0;u=c[h>>2]|0;do{if((v|0)==0){if(!((u-257|0)>>>0<175>>>0)){K=0;x=36;break}c[m>>2]=4;L=p;M=u}else{K=v;x=36}}while(0);do{if((x|0)==36){x=0;if((u|0)==439){A=t;x=37;break b}if((K|0)==2&(u|0)==435){c[m>>2]=0;N=0;x=41}else{if((K|0)<4){N=K;x=41}else{O=K;P=u}}do{if((x|0)==41){x=0;if((u|0)!=437){O=N;P=u;break}v=N+1|0;c[m>>2]=v;O=v;P=437}}while(0);if((O|0)==4){L=t;M=P;break}else if((O|0)!=0){Q=t;break c}if((P|0)!=256){Q=t;break c}SRa(f,p-4|0,1);Q=t;break c}}while(0);if((M&-256|0)==256&(M-257|0)>>>0>174>>>0){H=L;x=45;break b}else{Q=L}}else{t=c[h>>2]|0;do{if((t|0)==437){if((a[d+r|0]&-16)<<24>>24==-128){break}c[m>>2]=q-1}else if((t|0)==439){if((a[d+r|0]&3)==3){c[m>>2]=0;break}else{c[m>>2]=q+1&3;break}}}while(0);c[h>>2]=t+1;Q=r}}while(0);r=Q+1|0;}while((r|0)<(e|0));J=c[h>>2]|0;break a}}while(0);if((x|0)==37){c[m>>2]=0;c[j>>2]=-1;l=A+1|0;i=g;return l|0}else if((x|0)==45){c[m>>2]=0;c[j>>2]=-1;l=H-3|0;i=g;return l|0}}else{J=k}}while(0);c[j>>2]=J;l=-100;i=g;return l|0}function zMa(a,b,c){a=a|0;b=b|0;c=c|0;return AMa(a,b,c)|0}function AMa(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;k=c[f+9960>>2]|0;l=(h|0)<4?0:h-3|0;m=f+14120|0;n=HMa(m,l)|0;if((n|0)>65534){o=-1;i=j;return o|0}p=f+9860+(l<<2)|0;l=(c[p>>2]|0)+n|0;c[p>>2]=l;b[g>>1]=ba(e[f+12560>>1]|0,l)|0;l=f+14128|0;p=c[l>>2]|0;n=c[m>>2]|0;m=n+(p>>>3)|0;q=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7);a:do{if((q|0)<-1073741824){r=p;s=0}else{m=-k|0;t=c[287062]|0;u=q;v=p;w=0;b:while(1){x=u>>>23;y=b[t+(x<<2)>>1]|0;z=a[t+(x<<2)+2|0]|0;A=z<<24>>24;if(z<<24>>24<0){z=u<<9;B=(z>>>((A+32|0)>>>0))+y|0;C=B;D=a[t+(B<<2)+2|0]|0;E=z;F=v+9|0;G=b[t+(B<<2)>>1]|0}else{C=x;D=A;E=u;F=v;G=y}y=E<<D;A=D+F|0;do{if((G|0)==0){x=y>>>26;B=A+6|0;z=n+(B>>>3)|0;H=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7);B=H>>24;do{if((B|0)==-128){I=H<<16;J=A+22|0;K=H>>>16|-256}else{if((B|0)!=0){I=H<<8;J=A+14|0;K=B;break}I=H<<16;J=A+22|0;K=H>>>16&255}}while(0);H=w+1+x|0;if((H|0)>63){L=15;break b}B=d[f+368+H|0]|0;if((K|0)<0){M=I;N=J;O=-(((ba(ba(K,m)|0,e[f+12560+(B<<1)>>1]|0)|0)>>>4)+65535|1)&65535;P=H;Q=B;break}else{z=ba(K,k)|0;M=I;N=J;O=(((ba(z,e[f+12560+(B<<1)>>1]|0)|0)>>>4)+65535|1)&65535;P=H;Q=B;break}}else{B=(d[t+(C<<2)+3|0]|0)+w|0;if((B|0)>63){L=8;break b}H=d[f+368+B|0]|0;z=ba(G,k)|0;R=y>>31;M=y<<1;N=A+1|0;O=((((ba(z,e[f+12560+(H<<1)>>1]|0)|0)>>>4)+65535|1)^R)-R&65535;P=B;Q=H}}while(0);b[g+(Q<<1)>>1]=O;if((M|0)<-1073741824){r=N;s=P;break a}A=n+(N>>>3)|0;u=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(N&7);v=N;w=P}if((L|0)==8){w=c[f+12480>>2]|0;yDb(c[f+4>>2]|0,16,1962304,(S=i,i=i+16|0,c[S>>2]=c[f+12476>>2],c[S+8>>2]=w,S)|0);i=S;o=-1094995529;i=j;return o|0}else if((L|0)==15){w=c[f+12480>>2]|0;yDb(c[f+4>>2]|0,16,1962304,(S=i,i=i+16|0,c[S>>2]=c[f+12476>>2],c[S+8>>2]=w,S)|0);i=S;o=-1094995529;i=j;return o|0}}}while(0);c[l>>2]=r+2;c[f+180+(h<<2)>>2]=s;o=0;i=j;return o|0}function BMa(b){b=b|0;var d=0,e=0;d=c[b+60>>2]|0;e=0;do{a[d+(e+11184)|0]=e;e=e+1|0;}while((e|0)<64);e=d;IOa(e);c[d+4>>2]=b;c[d+60>>2]=c[b+88>>2];c[d+64>>2]=c[b+92>>2];vMa(e);xMa();c[d+14672>>2]=0;c[d+108>>2]=0;c[d+14676>>2]=0;e=(c[b+12>>2]|0)+12|0;c[d+48>>2]=c[e>>2];c[b+396>>2]=1;c[b+400>>2]=(c[e>>2]|0)==1?2:1;return 0}function CMa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[g+24>>2]|0;c[j>>2]=l;m=c[g+28>>2]|0;c[k>>2]=m;g=a+60|0;n=c[g>>2]|0;o=e;if((m|0)==0){p=3}else if((m|0)==4){e=l;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==-1224671232){p=3}}if((p|0)==3){if((c[n+13944>>2]|0)!=0){q=m;i=h;return q|0}e=n+9852|0;r=c[e>>2]|0;if((r|0)==0){q=m;i=h;return q|0}s=MCb(o,r|0)|0;if((s|0)<0){q=s;i=h;return q|0}c[e>>2]=0;c[f>>2]=1;q=c[k>>2]|0;i=h;return q|0}do{if((c[n+60>>2]&65536|0)!=0){e=n+13744|0;if((WRa(e,yMa(e,l,m,0)|0,j,k)|0)>=0){break}q=c[k>>2]|0;i=h;return q|0}}while(0);m=S0a(c[a+52>>2]|0)|0;c[n+88>>2]=m;do{if((c[n+14672>>2]|0)==0){if(!((m|0)==844251990|(m|0)==808539970)){break}l=c[g>>2]|0;e=l;c[l+28>>2]=0;s=l+14672|0;if((c[s>>2]|0)==0){t=l}else{LOa(e);c[s>>2]=0;t=c[g>>2]|0}r=l+8|0;c[r>>2]=c[a+128>>2];u=l+12|0;c[u>>2]=c[a+132>>2];c[a+176>>2]=0;c[l+13944>>2]=1;v=c[t+14212>>2]|0;if((v|0)<2){w=V0a(a,(c[a+48>>2]|0)==1?648592:646800)|0}else{w=(v|0)==2?4:5}v=a+140|0;c[v>>2]=w;x=R0a(a)|0;c[a+712>>2]=x;y=(x|0)==0;if(y){if(((c[v>>2]|0)-37|0)>>>0<2>>>0){p=19}}else{p=19}do{if((p|0)==19){x=a+788|0;if((c[x>>2]|0)==0){c[x>>2]=2}if(y){break}if((c[v>>2]|0)!=16){break}c[(c[g>>2]|0)+14288>>2]=1;c[a+292>>2]=2}}while(0);if((FOa(e)|0)<0){break}c[s>>2]=1;v=l+12560|0;y=l+12688|0;x=l+12816|0;z=l+12944|0;A=0;do{B=d[l+(A+11184)|0]|0;C=b[1179176+(A<<1)>>1]|0;b[v+(B<<1)>>1]=C;b[y+(B<<1)>>1]=C;C=b[1179048+(A<<1)>>1]|0;b[x+(B<<1)>>1]=C;b[z+(B<<1)>>1]=C;A=A+1|0;}while((A|0)<64);c[l+14152>>2]=1;c[l+14224>>2]=1;c[l+14172>>2]=3;c[l+14240>>2]=0;c[l+14180>>2]=1;c[l+14212>>2]=1;if((c[l+88>>2]|0)==808539970){c[(c[l+4>>2]|0)+48>>2]=1;c[l+48>>2]=1}else{c[l+14284>>2]=1;c[(c[l+4>>2]|0)+48>>2]=2;c[l+48>>2]=2}c[l+14732>>2]=c[r>>2];c[l+14736>>2]=c[u>>2];c[l+14740>>2]=1}}while(0);c[n+14724>>2]=0;g=c[a+96>>2]|0;do{if((g|0)!=0){p=n+14764|0;if((c[p>>2]|0)!=0){break}w=FMa(a,o,f,g,c[a+100>>2]|0)|0;if((c[f>>2]|0)!=0){yDb(a,16,2272688,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;c[f>>2]=0}c[p>>2]=1;if((w|0)>=0){break}if((c[a+696>>2]&8|0)==0){break}c[n+9856>>2]=0;q=w;i=h;return q|0}}while(0);g=FMa(a,o,f,c[j>>2]|0,c[k>>2]|0)|0;do{if((g|0)>=0){if((c[f>>2]|0)==0){q=g}else{break}i=h;return q|0}}while(0);c[n+9856>>2]=0;q=g;i=h;return q|0}function DMa(a){a=a|0;var b=0;b=c[a+60>>2]|0;if((c[b+14672>>2]|0)!=0){LOa(b)}$Db(b+14716|0);return 0}function EMa(a){a=a|0;c[(c[a+60>>2]|0)+14752>>2]=0;bPa(a);return}function FMa(f,h,j,k,l){f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,ne=0,oe=0,pe=0,qe=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0;m=i;i=i+336|0;n=m|0;o=m+24|0;p=m+152|0;q=m+256|0;r=m+264|0;s=m+272|0;t=m+280|0;u=m+288|0;v=m+296|0;w=m+304|0;x=m+312|0;y=m+320|0;z=m+328|0;A=f+60|0;B=c[A>>2]|0;C=B;D=B;E=k+l|0;c[z>>2]=-1;G=f1a(k,E,z)|0;H=c[z>>2]|0;do{if(H>>>0>511>>>0){I=G;J=4}else{K=E;L=f+688|0;M=B+14152|0;N=B+14172|0;O=B+4|0;P=B+14240|0;Q=B+120|0;R=B+140|0;S=B+9928|0;T=B+124|0;U=B+14180|0;V=B+14224|0;W=B+48|0;X=B+9848|0;Y=B+9992|0;Z=B+9988|0;_=B+14752|0;$=B+9852|0;aa=f+856|0;ca=B+14672|0;da=f+328|0;ea=f+332|0;fa=f;ga=f+696|0;ha=B+14760|0;ia=B+9856|0;ja=f+140|0;ka=B+14724|0;la=B+13708|0;ma=B+13704|0;na=B+14120|0;oa=na;pa=na;na=B+14132|0;qa=B+14136|0;ra=B+14124|0;sa=B+14128|0;ta=B+14236|0;ua=B+14192|0;va=B+9960|0;wa=B+14424|0;xa=B+12476|0;ya=B+12480|0;za=B+88|0;Aa=B+116|0;Ba=B+12484|0;Ca=B+14156|0;Da=B+14160|0;Ea=B+14164|0;Fa=B+14168|0;Ga=B+14200|0;Ha=B+14184|0;Ia=B+14176|0;Ja=B+14188|0;Ka=B+14196|0;La=B+14204|0;Ma=B+14208|0;Na=B+14340|0;Oa=B+14212|0;Pa=B+10096|0;Qa=B+14220|0;Ra=B+11824|0;Sa=B+12488|0;Ta=B+64|0;Ua=B+12560|0;Va=B+12688|0;Wa=Ra;Xa=B+11832|0;Ya=B+11744|0;Za=B+11828|0;_a=B+11836|0;$a=B+11748|0;ab=B+9160|0;bb=B+11736|0;cb=B+11740|0;db=B+11840|0;eb=B+11848|0;fb=B+11776|0;gb=B+11844|0;hb=B+11852|0;ib=B+11780|0;jb=B+14232|0;kb=B+14228|0;lb=B+11816|0;mb=B+11808|0;nb=B+180|0;ob=B+12816|0;pb=B+12944|0;qb=B+9148|0;rb=B+12544|0;sb=B+14216|0;tb=B+12548|0;ub=B+12552|0;vb=B+56|0;wb=B+128|0;xb=B+9924|0;yb=B+9180|0;zb=B+9152|0;Ab=B+9184|0;Bb=B+7624|0;Cb=B+7628|0;Db=B+7632|0;Eb=B+7636|0;Fb=B+14680|0;Gb=B+14716|0;Hb=Gb;Ib=B+14712|0;Jb=B+14704|0;Kb=B+14720|0;Lb=f+96|0;Mb=B+8|0;Nb=B+12|0;Ob=B+14756|0;Pb=p|0;Qb=m+216|0;Rb=q;Sb=w;Tb=y;Ub=f+48|0;Vb=f+176|0;Wb=f+108|0;Xb=f+104|0;Yb=f+224|0;Zb=f+112|0;_b=f+712|0;$b=f+788|0;ac=f+292|0;bc=o;cc=t|0;dc=t+4|0;ec=u|0;fc=u+4|0;gc=v|0;hc=v+4|0;ic=r|0;jc=r+4|0;kc=x|0;lc=x+4|0;mc=f+540|0;nc=f+72|0;oc=f+128|0;pc=f+132|0;qc=B+24|0;rc=B+13944|0;sc=B+60|0;tc=B+14744|0;uc=B+14748|0;vc=B+14684|0;wc=B+14688|0;xc=B+14692|0;yc=B+14694|0;zc=B+14696|0;Ac=B+14698|0;Bc=B+14700|0;Cc=B+14702|0;Dc=B+7712|0;Ec=B+7708|0;Fc=B+11184|0;Gc=B+232|0;Hc=B+364|0;Ic=f+272|0;Jc=m+8|0;Kc=f+616|0;Lc=k;Mc=0;Nc=0;Oc=0;Pc=G;Qc=H;a:while(1){Rc=Pc;Sc=K-Rc|0;if((c[L>>2]&256|0)==0){Tc=Qc}else{yDb(fa,48,2257312,(Uc=i,i=i+24|0,c[Uc>>2]=Qc,c[Uc+8>>2]=Rc-Lc,c[Uc+16>>2]=Sc,Uc)|0);i=Uc;Tc=c[z>>2]|0}b:do{switch(Tc|0){case 434:{Rc=Pc+Sc|0;if((Sc|0)>29){Vc=(c[A>>2]|0)+14756|0;Wc=0;do{if((PGb(Pc+Wc|0,1950600,9)|0)==0){c[Vc>>2]=1}Wc=Wc+1|0;}while((Wc|0)<20)}Wc=Rc;if((Sc|0)<=4){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Vc=a[Pc]|0;do{if(Vc<<24>>24==68){if((a[Pc+1|0]|0)!=84){break}if((a[Pc+2|0]|0)!=71){break}if((a[Pc+3|0]|0)!=49){break}$c=d[Pc+4|0]|0;ad=($c&128|0)==0?Pc+5|0:Pc+7|0;if(($c&64|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((Wc-ad|0)<1){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}c[Ic>>2]=a[ad]&15;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}while(0);if((Sc|0)<=5){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}do{if(Vc<<24>>24==74){if((a[Pc+1|0]|0)!=80){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+2|0]|0)!=51){break}if((a[Pc+3|0]|0)!=68){break}if((a[Pc+4|0]|0)!=3){break}Wc=a[Pc+5|0]&127;Rc=Wc&255;if(!((Wc<<24>>24|0)==3|(Wc<<24>>24|0)==4|(Wc<<24>>24|0)==8|(Wc<<24>>24|0)==35)){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Wc=c[A>>2]|0;c[Wc+14712>>2]=1;if((Rc|0)==8){c[Wc+14704>>2]=0;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else if((Rc|0)==35){c[Wc+14704>>2]=5;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else if((Rc|0)==3){c[Wc+14704>>2]=1;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else if((Rc|0)==4){c[Wc+14704>>2]=2;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}}while(0);Wc=c[A>>2]|0;do{if(Vc<<24>>24==71){if((a[Pc+1|0]|0)!=65){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+2|0]|0)!=57){break}if((a[Pc+3|0]|0)!=52){break}if((a[Pc+4|0]|0)!=3){break}Rc=d[Pc+5|0]|0;if((Rc&64|0)==0){break}ad=Rc&31;if((ad|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Rc=ad*3|0;if((Rc+7|0)>(Sc|0)){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}ad=Wc+14716|0;$Db(ad);$c=Wc+14720|0;c[$c>>2]=Rc;bd=WDb(Rc)|0;c[ad>>2]=bd;if((bd|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}UGb(bd|0,Pc+7|0,c[$c>>2]|0)|0;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}while(0);if(!((Sc|0)>10&Vc<<24>>24==67)){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+1|0]|0)!=67){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+2|0]|0)!=1){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+3|0]|0)==-8){cd=5;dd=0}else{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}while(1){$c=cd+6|0;if(($c|0)>(Sc|0)){break}if((a[Pc+cd|0]&-2)<<24>>24==-2){cd=$c;dd=dd+1|0}else{break}}if((dd|0)<=0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Vc=Wc+14716|0;$Db(Vc);$c=dd*6|0;c[Wc+14720>>2]=$c;bd=WDb($c)|0;c[Vc>>2]=bd;if((bd|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Vc=a[Pc+4|0]|0;$c=(Vc<<24>>24>>7)-3&255;ad=(Vc&255)>>>7|-4;Vc=Pc+5|0;Rc=0;ed=bd;while(1){a[ed]=(a[Vc]|0)==-1?$c:-3;a[ed+1|0]=a[Vc+1|0]|0;a[ed+2|0]=a[Vc+2|0]|0;a[ed+3|0]=(a[Vc+3|0]|0)==-1?ad:-3;a[ed+4|0]=a[Vc+4|0]|0;a[ed+5|0]=a[Vc+5|0]|0;bd=Rc+1|0;if((bd|0)<(dd|0)){Vc=Vc+6|0;Rc=bd;ed=ed+6|0}else{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break}}break};case 437:{ed=Sc<<3;Rc=ed>>>0>2147483639>>>0|(Pc|0)==0;Vc=Rc?0:Pc;ad=Rc?0:ed;c[pa>>2]=Vc;c[na>>2]=ad;c[qa>>2]=ad+8;c[ra>>2]=Vc+(ad>>3);c[sa>>2]=0;ad=Vc;ed=(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)>>>4&15;c[sa>>2]=4;switch(ed|0){case 8:{if((Mc|0)!=256){yDb(fa,16,2175712,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}c[jb>>2]=0;c[kb>>2]=0;ed=(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24)&15;c[sa>>2]=8;c[Ca>>2]=ed;Rc=Vc+1|0;$c=(d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24|0)>>>4&15;c[sa>>2]=12;c[Da>>2]=$c;Wc=(d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24)&15;c[sa>>2]=16;c[Ea>>2]=Wc;Rc=Vc+2|0;bd=(d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24|0)>>>4&15;c[sa>>2]=20;c[Fa>>2]=bd;do{if((c[Y>>2]|0)==0){if((c[ca>>2]|0)==0){gd=ed;hd=$c;id=Wc;jd=bd;kd=20;ld=Vc;break}yDb(c[O>>2]|0,16,1948776,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;Rc=c[Ea>>2]|0;md=c[Fa>>2]|0;c:do{if((Rc|0)==15&(md|0)==15){nd=c[Ca>>2]|0;do{if((nd|0)==15){if((c[Da>>2]|0)!=15){break}c[Y>>2]=1;od=1;pd=15;qd=15;break c}}while(0);c[Y>>2]=2;od=2;pd=nd;qd=15}else{c[Y>>2]=3;od=3;pd=c[Ca>>2]|0;qd=md}}while(0);c[Dc>>2]=od;c[Ec>>2]=(od|0)==1;gd=pd;hd=c[Da>>2]|0;id=Rc;jd=qd;kd=c[sa>>2]|0;ld=c[pa>>2]|0}else{gd=ed;hd=$c;id=Wc;jd=bd;kd=20;ld=Vc}}while(0);c[Ca>>2]=((gd|0)==0)+gd;c[Da>>2]=((hd|0)==0)+hd;c[Ea>>2]=((id|0)==0)+id;c[Fa>>2]=((jd|0)==0)+jd;bd=ld+(kd>>>3)|0;Wc=(fe(d[bd]|d[bd+1|0]<<8|d[bd+2|0]<<16|d[bd+3|0]<<24|0)|0)<<(kd&7)>>>30;bd=kd+2|0;c[sa>>2]=bd;c[Ia>>2]=Wc;Wc=ld+(bd>>>3)|0;$c=(fe(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)<<(bd&7)>>>30;bd=kd+4|0;c[sa>>2]=bd;c[N>>2]=$c;$c=d[ld+(bd>>>3)|0]<<(bd&7)>>>7;bd=kd+5|0;c[sa>>2]=bd;c[Ha>>2]=$c&1;$c=d[ld+(bd>>>3)|0]<<(bd&7)>>>7;bd=kd+6|0;c[sa>>2]=bd;c[U>>2]=$c&1;$c=d[ld+(bd>>>3)|0]<<(bd&7)>>>7;bd=kd+7|0;c[sa>>2]=bd;c[Ja>>2]=$c&1;$c=d[ld+(bd>>>3)|0]<<(bd&7)>>>7;bd=kd+8|0;c[sa>>2]=bd;c[ua>>2]=$c&1;$c=d[ld+(bd>>>3)|0]<<(bd&7)>>>7;bd=kd+9|0;c[sa>>2]=bd;c[Ka>>2]=$c&1;$c=d[ld+(bd>>>3)|0]<<(bd&7)>>>7;bd=kd+10|0;c[sa>>2]=bd;Wc=$c&1;c[Ga>>2]=Wc;$c=d[ld+(bd>>>3)|0]<<(bd&7)>>>7;bd=kd+11|0;c[sa>>2]=bd;c[La>>2]=$c&1;$c=d[ld+(bd>>>3)|0]<<(bd&7)>>>7;bd=kd+12|0;c[sa>>2]=bd;c[Ma>>2]=$c&1;$c=d[ld+(bd>>>3)|0]<<(bd&7)>>>7;c[sa>>2]=kd+13;c[V>>2]=$c&1;if((Wc|0)==0){x2(Fc,Gc,1075976);x2(Fc,Hc,1075976);Xc=Oc;Yc=Nc;Zc=256;_c=Pc;break b}else{x2(Fc,Gc,1264880);x2(Fc,Hc,1264880);Xc=Oc;Yc=Nc;Zc=256;_c=Pc;break b}break};case 3:{Wc=a[Vc]|0;c[sa>>2]=5;if((Wc&8)==0){rd=5;sd=Vc}else{IMa(D,Va,Ua,1);rd=c[sa>>2]|0;sd=c[pa>>2]|0}Wc=d[sd+(rd>>>3)|0]|0;$c=rd+1|0;c[sa>>2]=$c;if((Wc&128>>>((rd&7)>>>0)|0)==0){td=$c;ud=sd}else{IMa(D,pb,ob,0);td=c[sa>>2]|0;ud=c[pa>>2]|0}$c=d[ud+(td>>>3)|0]|0;Wc=td+1|0;c[sa>>2]=Wc;d:do{if(($c&128>>>((td&7)>>>0)|0)!=0){bd=0;ed=Wc;md=ud;while(1){vd=d[(d[1075976+bd|0]|0)+(D+11184)|0]|0;wd=md+(ed>>>3)|0;xd=(fe(d[wd]|d[wd+1|0]<<8|d[wd+2|0]<<16|d[wd+3|0]<<24|0)|0)<<(ed&7)>>>24;c[sa>>2]=ed+8;if((xd|0)==0){break}if((bd|0)!=0|(xd|0)==8){yd=xd&65535}else{yDb(c[O>>2]|0,48,1942256,(Uc=i,i=i+8|0,c[Uc>>2]=xd,Uc)|0);i=Uc;yd=8}b[D+12688+(vd<<1)>>1]=yd;vd=bd+1|0;if((vd|0)>=64){break d}bd=vd;ed=c[sa>>2]|0;md=c[pa>>2]|0}yDb(c[O>>2]|0,16,1944688,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc}}while(0);Wc=c[sa>>2]|0;$c=c[pa>>2]|0;md=d[$c+(Wc>>>3)|0]|0;ed=Wc+1|0;c[sa>>2]=ed;if((md&128>>>((Wc&7)>>>0)|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{zd=0;Ad=ed}while(1){ed=a[(d[1075976+zd|0]|0)+(D+11184)|0]|0;Wc=$c+(Ad>>>3)|0;md=(fe(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)<<(Ad&7)>>>24;Wc=Ad+8|0;c[sa>>2]=Wc;if((md|0)==0){break}b[D+12944+((ed&255)<<1)>>1]=md;md=zd+1|0;if((md|0)<64){zd=md;Ad=Wc}else{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}yDb(c[O>>2]|0,16,1944688,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b;break};case 7:{do{if((c[M>>2]|0)==0){if((c[N>>2]|0)!=3){Bd=1;break}Bd=(c[La>>2]|0)==0?2:3}else{if((c[La>>2]|0)==0){Bd=1;break}Bd=(c[Ha>>2]|0)==0?2:3}}while(0);$c=0;Wc=4;md=Vc;while(1){ed=md+(Wc>>>3)|0;bd=(fe(d[ed]|d[ed+1|0]<<8|d[ed+2|0]<<16|d[ed+3|0]<<24|0)|0)<<(Wc&7)>>>16;c[sa>>2]=Wc+16;b[C+14692+($c<<2)>>1]=bd;bd=c[sa>>2]|0;ed=bd+1|0;c[sa>>2]=ed;Rc=(c[pa>>2]|0)+(ed>>>3)|0;vd=(fe(d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24|0)|0)<<(ed&7)>>>16;c[sa>>2]=bd+17;b[C+14692+($c<<2)+2>>1]=vd;vd=(c[sa>>2]|0)+1|0;c[sa>>2]=vd;bd=$c+1|0;if((bd|0)>=(Bd|0)){break}$c=bd;Wc=vd;md=c[pa>>2]|0}md=c[O>>2]|0;if((c[md+688>>2]&1|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Wc=b[yc>>1]|0;$c=b[zc>>1]|0;vd=b[Ac>>1]|0;bd=b[Bc>>1]|0;ed=b[Cc>>1]|0;yDb(md,48,1946744,(Uc=i,i=i+48|0,c[Uc>>2]=b[xc>>1]|0,c[Uc+8>>2]=Wc,c[Uc+16>>2]=$c,c[Uc+24>>2]=vd,c[Uc+32>>2]=bd,c[Uc+40>>2]=ed,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b;break};case 1:{if((Mc|0)!=0){yDb(fa,16,2192072,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}c[sa>>2]=5;ed=(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24)&7;c[sa>>2]=8;bd=c[O>>2]|0;vd=bd+840|0;c[vd>>2]=ed;ed=c[sa>>2]|0;$c=Vc+(ed>>>3)|0;Wc=(fe(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(ed&7)>>>28;c[sa>>2]=ed+4;ed=bd+844|0;c[ed>>2]=Wc;Wc=c[sa>>2]|0;$c=d[Vc+(Wc>>>3)|0]<<(Wc&7)>>>7;md=Wc+1|0;c[sa>>2]=md;c[M>>2]=$c&1;$c=Vc+(md>>>3)|0;Rc=(fe(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(md&7)>>>30;md=Wc+3|0;c[sa>>2]=md;c[Oa>>2]=Rc;Rc=Vc+(md>>>3)|0;$c=(fe(d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24|0)|0)<<(md&7)>>>30;md=Wc+5|0;c[sa>>2]=md;Rc=Vc+(md>>>3)|0;xd=(fe(d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24|0)|0)<<(md&7)>>>30;md=Wc+7|0;c[sa>>2]=md;c[Mb>>2]=c[Mb>>2]|$c<<12;c[Nb>>2]=xd<<12|c[Nb>>2];xd=Vc+(md>>>3)|0;$c=ba((fe(d[xd]|d[xd+1|0]<<8|d[xd+2|0]<<16|d[xd+3|0]<<24|0)|0)<<(md&7)>>>20,104857600)|0;c[qc>>2]=$c+(c[qc>>2]|0);$c=Wc+20|0;c[sa>>2]=$c;md=Vc+($c>>>3)|0;xd=(fe(d[md]|d[md+1|0]<<8|d[md+2|0]<<16|d[md+3|0]<<24|0)|0)<<($c&7)&-16777216;c[sa>>2]=Wc+28;Wc=bd+524|0;c[Wc>>2]=xd+(c[Wc>>2]|0);xd=c[sa>>2]|0;$c=d[Vc+(xd>>>3)|0]<<(xd&7)>>>7;md=xd+1|0;c[sa>>2]=md;c[rc>>2]=$c&1;if((c[sc>>2]&524288|0)!=0){c[rc>>2]=1}$c=Vc+(md>>>3)|0;Rc=(fe(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(md&7)>>>30;md=xd+3|0;c[sa>>2]=md;c[tc>>2]=Rc+1;Rc=Vc+(md>>>3)|0;$c=(fe(d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24|0)|0)<<(md&7)>>>27;c[sa>>2]=xd+8;c[uc>>2]=$c+1;c[bd+48>>2]=2;c[W>>2]=2;if((c[bd+688>>2]&1|0)==0){Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break b}$c=c[ed>>2]|0;ed=c[M>>2]|0;xd=c[Oa>>2]|0;md=c[Wc>>2]|0;Wc=c[qc>>2]|0;yDb(bd,48,1931632,(Uc=i,i=i+48|0,c[Uc>>2]=c[vd>>2],c[Uc+8>>2]=$c,c[Uc+16>>2]=ed,c[Uc+24>>2]=xd,c[Uc+32>>2]=md,c[Uc+40>>2]=Wc,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break b;break};case 2:{c[sa>>2]=7;Wc=a[Vc]|0;c[sa>>2]=8;if((Wc&1)==0){Dd=8;Ed=c[O>>2]|0}else{Wc=Vc+1|0;md=(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24)&255;c[sa>>2]=16;Wc=c[O>>2]|0;c[Wc+384>>2]=md;md=Vc+2|0;xd=(d[md]|d[md+1|0]<<8|d[md+2|0]<<16|d[md+3|0]<<24)&255;c[sa>>2]=24;c[Wc+388>>2]=xd;xd=Vc+3|0;md=(d[xd]|d[xd+1|0]<<8|d[xd+2|0]<<16|d[xd+3|0]<<24)&255;c[sa>>2]=32;c[Wc+392>>2]=md;Dd=32;Ed=Wc}Wc=Vc+(Dd>>>3)|0;md=(fe(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)>>>18;Wc=Dd+15|0;c[sa>>2]=Wc;xd=Vc+(Wc>>>3)|0;Wc=(fe(d[xd]|d[xd+1|0]<<8|d[xd+2|0]<<16|d[xd+3|0]<<24|0)|0)>>>11&16383;c[sa>>2]=Dd+29;c[vc>>2]=md<<4;c[wc>>2]=Wc<<4;if((c[Ed+688>>2]&1|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}yDb(Ed,48,1934168,(Uc=i,i=i+16|0,c[Uc>>2]=md,c[Uc+8>>2]=Wc,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b;break};default:{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}break};case 435:{if((Mc|0)!=0){yDb(fa,16,2243008,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}Wc=c[A>>2]|0;md=Wc;xd=Sc<<3;ed=xd>>>0>2147483639>>>0|(Pc|0)==0;$c=ed?0:Pc;vd=ed?0:xd;xd=Wc+14120|0;c[xd>>2]=$c;c[Wc+14132>>2]=vd;c[Wc+14136>>2]=vd+8;c[Wc+14124>>2]=$c+(vd>>3);vd=Wc+14128|0;c[vd>>2]=0;ed=$c;bd=(fe(d[ed]|d[ed+1|0]<<8|d[ed+2|0]<<16|d[ed+3|0]<<24|0)|0)>>>20;c[vd>>2]=12;ed=$c+1|0;Rc=(fe(d[ed]|d[ed+1|0]<<8|d[ed+2|0]<<16|d[ed+3|0]<<24|0)|0)>>>16&4095;c[vd>>2]=24;do{if((bd|0)==0|(Rc|0)==0){yDb(fa,24,1928136,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;if((c[ga>>2]&131074|0)!=0){break}Fd=c[vd>>2]|0;Gd=c[xd>>2]|0;J=33}else{Fd=24;Gd=$c;J=33}}while(0);do{if((J|0)==33){J=0;$c=Gd+(Fd>>>3)|0;Vc=(fe(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(Fd&7)>>>28;$c=Fd+4|0;c[vd>>2]=$c;c[Wc+13928>>2]=Vc;if((Vc|0)==0){yDb(fa,16,1926408,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;if((c[ga>>2]&131074|0)!=0){break}Hd=c[vd>>2]|0;Id=c[xd>>2]|0}else{Hd=$c;Id=Gd}$c=Id+(Hd>>>3)|0;Vc=(fe(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(Hd&7);$c=Vc>>>28;ad=Hd+4|0;c[vd>>2]=ad;c[Wc+10012>>2]=$c;if(($c|0)==0|Vc>>>0>3758096383>>>0){break}Vc=Id+(ad>>>3)|0;$c=(fe(d[Vc]|d[Vc+1|0]<<8|d[Vc+2|0]<<16|d[Vc+3|0]<<24|0)|0)<<(ad&7)>>>14;ad=Hd+22|0;c[vd>>2]=ad;Vc=Wc+24|0;c[Vc>>2]=$c*400|0;$c=d[Id+(ad>>>3)|0]|0;ed=Hd+23|0;c[vd>>2]=ed;if(($c&128>>>((ad&7)>>>0)|0)==0){break}c[Wc+8>>2]=bd;c[Wc+12>>2]=Rc;ad=Id+(ed>>>3)|0;$c=(fe(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)<<(ed&7)>>>22;c[vd>>2]=Hd+33;ed=Wc+4|0;c[(c[ed>>2]|0)+524>>2]=$c<<14;$c=c[vd>>2]|0;ad=$c+1|0;c[vd>>2]=ad;wd=d[Id+(ad>>>3)|0]|0;c[vd>>2]=$c+2;if((128>>>((ad&7)>>>0)&wd|0)==0){wd=Wc+12560|0;ad=Wc+12688|0;$c=0;do{Jd=d[Wc+($c+11184)|0]|0;Kd=b[1179176+($c<<1)>>1]|0;b[wd+(Jd<<1)>>1]=Kd;b[ad+(Jd<<1)>>1]=Kd;$c=$c+1|0;}while(($c|0)<64)}else{IMa(md,Wc+12688|0,Wc+12560|0,1)}$c=c[vd>>2]|0;ad=d[(c[xd>>2]|0)+($c>>>3)|0]|0;c[vd>>2]=$c+1;if((ad&128>>>(($c&7)>>>0)|0)==0){$c=Wc+12816|0;ad=Wc+12944|0;wd=0;do{Kd=d[Wc+(wd+11184)|0]|0;Jd=b[1179048+(wd<<1)>>1]|0;b[$c+(Kd<<1)>>1]=Jd;b[ad+(Kd<<1)>>1]=Jd;wd=wd+1|0;}while((wd|0)<64)}else{IMa(md,Wc+12944|0,Wc+12816|0,0)}wd=c[vd>>2]|0;ad=(c[xd>>2]|0)+(wd>>>3)|0;if(((fe(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)&-512>>>((wd&7)>>>0)|0)!=0){yDb(c[ed>>2]|0,16,1924848,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;break}c[Wc+14152>>2]=1;c[Wc+14224>>2]=1;c[Wc+14172>>2]=3;c[Wc+14240>>2]=0;c[Wc+14180>>2]=1;c[Wc+14212>>2]=1;wd=c[ed>>2]|0;c[wd+48>>2]=1;c[Wc+48>>2]=1;c[Wc+28>>2]=0;c[Wc+14284>>2]=0;if((c[Wc+60>>2]&524288|0)!=0){c[Wc+13944>>2]=1}if((c[wd+688>>2]&1|0)==0){break}ad=c[Vc>>2]|0;yDb(wd,48,1923248,(Uc=i,i=i+16|0,c[Uc>>2]=c[wd+524>>2],c[Uc+8>>2]=ad,Uc)|0);i=Uc}}while(0);if((c[Lb>>2]|0)==(k|0)){Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break b}c[_>>2]=1;Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break};case 256:{do{if((Oc|0)!=0){if((c[N>>2]|0)!=3){break}yDb(fa,24,2230552,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}while(0);Ld=c[Mb>>2]|0;Md=c[Nb>>2]|0;if((Ld|0)<1|(Md|0)<1){J=59;break a}if((c[Ob>>2]|0)!=0){c[Ia>>2]=3;b[Ua>>1]=1}if(!((Mc|0)==257|(Mc|0)==0)){yDb(fa,16,2200600,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=1;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}Wc=c[A>>2]|0;xd=Wc;vd=Wc+14672|0;e:do{if((c[vd>>2]|0)==0){Nd=Wc+8|0;J=73}else{md=c[oc>>2]|0;Rc=Wc+8|0;do{if((md|0)==(c[Rc>>2]|0)){bd=c[pc>>2]|0;if((bd|0)!=(c[Wc+12>>2]|0)){break}if((c[Wc+14732>>2]|0)!=(md|0)){break}if((c[Wc+14736>>2]|0)!=(bd|0)){break}if((c[Wc+14728>>2]|0)!=(c[Wc+13928>>2]|0)){break}if((c[Wc+14740>>2]|0)==(c[Wc+14152>>2]|0)){Od=0;break e}if((bd&31|0)==0){Od=0;break e}}}while(0);md=Wc+13744|0;c[Qb>>2]=c[md>>2];c[Qb+4>>2]=c[md+4>>2];c[Qb+8>>2]=c[md+8>>2];c[Qb+12>>2]=c[md+12>>2];c[Qb+16>>2]=c[md+16>>2];c[Qb+20>>2]=c[md+20>>2];c[Qb+24>>2]=c[md+24>>2];c[Qb+28>>2]=c[md+28>>2];c[Qb+32>>2]=c[md+32>>2];c[Qb+36>>2]=c[md+36>>2];c[md>>2]=0;LOa(xd);c[md>>2]=c[Qb>>2];c[md+4>>2]=c[Qb+4>>2];c[md+8>>2]=c[Qb+8>>2];c[md+12>>2]=c[Qb+12>>2];c[md+16>>2]=c[Qb+16>>2];c[md+20>>2]=c[Qb+20>>2];c[md+24>>2]=c[Qb+24>>2];c[md+28>>2]=c[Qb+28>>2];c[md+32>>2]=c[Qb+32>>2];c[md+36>>2]=c[Qb+36>>2];c[vd>>2]=0;Nd=Rc;J=73}}while(0);do{if((J|0)==73){J=0;md=c[Nd>>2]|0;if((md|0)==0){Od=-2;break}Vc=Wc+12|0;ed=c[Vc>>2]|0;if((ed|0)==0){Od=-2;break}bd=V$a(f,md,ed)|0;if((bd|0)<0){Od=bd;break}bd=c[Ub>>2]|0;do{if((bd|0)==2){ed=c[Wc+24>>2]|0;if((ed|0)==0){break}c[mc>>2]=ed}else if((bd|0)==1){ed=c[Wc+24>>2]|0;if((ed|0)==104857200){if((c[Wc+9996>>2]|0)==65535){break}}else if((ed|0)==0){break}c[nc>>2]=ed}}while(0);Rc=Wc+13928|0;c[Wc+14728>>2]=c[Rc>>2];c[Wc+14732>>2]=c[Nd>>2];c[Wc+14736>>2]=c[Vc>>2];c[Wc+14740>>2]=c[Wc+14152>>2];c[Vb>>2]=(c[Wc+13944>>2]|0)==0;f:do{if((bd|0)==1){ed=Wc+10012|0;c[Wb>>2]=c[1180208+(c[ed>>2]<<3)>>2];c[Xb>>2]=c[1180212+(c[ed>>2]<<3)>>2];lFb(Rb,1.0/+g[1179816+(c[Rc>>2]<<2)>>2],255);ed=c[q+4>>2]|0;c[Yb>>2]=c[q>>2];c[Yb+4>>2]=ed;c[Zb>>2]=1}else{ed=Wc+4|0;md=c[ed>>2]|0;ad=c[Wc+10012>>2]|0;wd=ba(c[1180208+(ad<<3)>>2]<<1,c[Wc+14744>>2]|0)|0;$c=ba(c[Wc+14748>>2]|0,c[1180212+(ad<<3)>>2]|0)|0;iFb(md+108|0,md+104|0,wd,(wd|0)<0|0?-1:0,$c,($c|0)<0|0?-1:0,1073741824,0)|0;c[Zb>>2]=2;$c=c[Rc>>2]|0;if(($c|0)<=1){wd=1178440+($c<<3)|0;md=(c[ed>>2]|0)+224|0;ad=c[wd+4>>2]|0;c[md>>2]=c[wd>>2];c[md+4>>2]=ad;break}ad=Wc+14684|0;c[cc>>2]=c[ad>>2];md=Wc+14688|0;c[dc>>2]=c[md>>2];kFb(s,1178440+($c<<3)|0,t);c[ec>>2]=c[Nd>>2];c[fc>>2]=c[Vc>>2];jFb(r,s,u);$c=c[ad>>2]|0;do{if(($c|0)!=0){if((c[md>>2]|0)==0){break}ad=c[ic>>2]|0;wd=c[jc>>2]|0;Jd=ad;Kd=(ad|0)<0|0?-1:0;Pd=gHb(Jd,Kd,3,0)|0;Qd=wd;Rd=(wd|0)<0|0?-1:0;if((Pd|0)==(Qd<<2|0>>>30|0)&(F|0)==(Rd<<2|Qd>>>30|0)){if(!((wd|0)!=0|(ad|0)>0)){J=89}}else{J=89}if((J|0)==89){J=0;Pd=gHb(Jd,Kd,9,0)|0;if(!((Pd|0)==(Qd<<4|0>>>28|0)&(F|0)==(Rd<<4|Qd>>>28|0))){break}if(!((wd|0)!=0|(ad|0)>0)){break}}ad=(c[ed>>2]|0)+224|0;wd=1178440+(c[Rc>>2]<<3)|0;c[kc>>2]=$c;c[lc>>2]=c[md>>2];kFb(Tb,wd,x);wd=ad;ad=c[y+4>>2]|0;c[wd>>2]=c[y>>2];c[wd+4>>2]=ad;break f}}while(0);md=(c[ed>>2]|0)+224|0;$c=1178440+(c[Rc>>2]<<3)|0;c[gc>>2]=c[Nd>>2];c[hc>>2]=c[Vc>>2];kFb(Sb,$c,v);$c=md;md=c[w+4>>2]|0;c[$c>>2]=c[w>>2];c[$c+4>>2]=md}}while(0);Vc=c[(c[A>>2]|0)+14212>>2]|0;if((Vc|0)<2){Sd=V0a(f,(c[Ub>>2]|0)==1?648592:646800)|0}else{Sd=(Vc|0)==2?4:5}c[ja>>2]=Sd;Vc=R0a(f)|0;c[_b>>2]=Vc;Rc=(Vc|0)==0;if(Rc){if(((c[ja>>2]|0)-37|0)>>>0<2>>>0){J=99}}else{J=99}do{if((J|0)==99){J=0;if((c[$b>>2]|0)==0){c[$b>>2]=2}if(Rc){break}if((c[ja>>2]|0)!=16){break}c[(c[A>>2]|0)+14288>>2]=1;c[ac>>2]=2}}while(0);UGb(Pb|0,Wc+11184|0,64)|0;if((FOa(xd)|0)<0){Od=-2;break}Rc=Wc+12560|0;Vc=Rc;UGb(bc|0,Rc|0,128)|0;Rc=0;do{b[Vc+(d[Wc+(Rc+11184)|0]<<1)>>1]=b[o+(d[p+Rc|0]<<1)>>1]|0;Rc=Rc+1|0;}while((Rc|0)<64);Rc=Wc+12816|0;Vc=Rc;UGb(bc|0,Rc|0,128)|0;Rc=0;do{b[Vc+(d[Wc+(Rc+11184)|0]<<1)>>1]=b[o+(d[p+Rc|0]<<1)>>1]|0;Rc=Rc+1|0;}while((Rc|0)<64);Rc=Wc+12688|0;Vc=Rc;UGb(bc|0,Rc|0,128)|0;Rc=0;do{b[Vc+(d[Wc+(Rc+11184)|0]<<1)>>1]=b[o+(d[p+Rc|0]<<1)>>1]|0;Rc=Rc+1|0;}while((Rc|0)<64);Rc=Wc+12944|0;Vc=Rc;UGb(bc|0,Rc|0,128)|0;Rc=0;do{b[Vc+(d[Wc+(Rc+11184)|0]<<1)>>1]=b[o+(d[p+Rc|0]<<1)>>1]|0;Rc=Rc+1|0;}while((Rc|0)<64);c[vd>>2]=1;Od=0}}while(0);if((Od|0)<0){J=115;break a}vd=c[A>>2]|0;Wc=Sc<<3;xd=Wc>>>0>2147483639>>>0|(Pc|0)==0;Rc=xd?0:Pc;Vc=xd?0:Wc;c[vd+14120>>2]=Rc;c[vd+14132>>2]=Vc;c[vd+14136>>2]=Vc+8;c[vd+14124>>2]=Rc+(Vc>>3);Vc=vd+14128|0;c[Vc>>2]=0;Wc=Rc;xd=(fe(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)>>>22;c[Vc>>2]=10;Wc=Rc+1|0;bd=(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)>>>3&7;c[Vc>>2]=13;c[vd+9992>>2]=bd;g:do{if((bd|0)==0|bd>>>0>3>>>0){J=127}else{md=(fe(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)>>>11&65535;c[Vc>>2]=29;c[vd+9996>>2]=md;do{if((bd-2|0)>>>0<2>>>0){$c=Rc+3|0;nd=(d[$c]|0)>>>2;c[Vc>>2]=30;c[vd+14228>>2]=nd&1;nd=$c;$c=(fe(d[nd]|d[nd+1|0]<<8|d[nd+2|0]<<16|d[nd+3|0]<<24|0)|0)>>>23&7;c[Vc>>2]=33;nd=($c|0)==0;if(nd){if((c[ga>>2]&131074|0)!=0){J=127;break g}}ad=(nd&1)+$c|0;c[vd+14156>>2]=ad;c[vd+14160>>2]=ad;if((bd|0)!=3){break}ad=Rc+4|0;$c=(d[ad]|0)>>>6;c[Vc>>2]=34;c[vd+14232>>2]=$c&1;$c=ad;ad=(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)>>>3&7;c[Vc>>2]=37;$c=(ad|0)==0;if($c){if((c[ga>>2]&131074|0)!=0){J=127;break g}}nd=($c&1)+ad|0;c[vd+14164>>2]=nd;c[vd+14168>>2]=nd}}while(0);c[vd+7712>>2]=bd;c[vd+7708>>2]=(bd|0)==1;if((c[L>>2]&1|0)!=0){yDb(fa,48,1929832,(Uc=i,i=i+24|0,c[Uc>>2]=md,c[Uc+8>>2]=xd,c[Uc+16>>2]=bd,Uc)|0);i=Uc}c[vd+168>>2]=8;c[vd+172>>2]=8}}while(0);if((J|0)==127){J=0;c[Y>>2]=0}c[ha>>2]=1;Xc=1;Yc=Nc;Zc=256;_c=Pc;break};case 440:{if((Mc|0)!=0){yDb(fa,16,2165288,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}c[P>>2]=0;vd=c[A>>2]|0;bd=Sc<<3;xd=bd>>>0>2147483639>>>0|(Pc|0)==0;Vc=xd?0:Pc;Rc=xd?0:bd;c[vd+14120>>2]=Vc;c[vd+14132>>2]=Rc;c[vd+14136>>2]=Rc+8;c[vd+14124>>2]=Vc+(Rc>>3);Rc=vd+14128|0;c[Rc>>2]=0;bd=Vc;xd=(fe(d[bd]|d[bd+1|0]<<8|d[bd+2|0]<<16|d[bd+3|0]<<24|0)|0)>>>7;c[Rc>>2]=25;c[Kc>>2]=xd;c[Kc+4>>2]=0;bd=Vc+3|0;Vc=(d[bd]|0)>>>6;c[Rc>>2]=26;Wc=vd+9988|0;c[Wc>>2]=Vc&1;Vc=a[bd]|0;c[Rc>>2]=27;Rc=vd+4|0;if((c[(c[Rc>>2]|0)+688>>2]&1|0)!=0){aGb(Jc,xd)|0;xd=c[Wc>>2]|0;yDb(c[Rc>>2]|0,48,1952848,(Uc=i,i=i+24|0,c[Uc>>2]=Jc,c[Uc+8>>2]=xd,c[Uc+16>>2]=(Vc&255)>>>5&1,Uc)|0);i=Uc}c[_>>2]=1;Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break};default:{do{if((Tc-257|0)>>>0<175>>>0&(Mc|0)==256){do{if((c[M>>2]|0)!=0){if((c[V>>2]|0)!=0){break}c[V>>2]=1;yDb(c[O>>2]|0,16,2158616,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc}}while(0);md=c[N>>2]|0;if((md|0)==0){J=237}else{if((c[V>>2]|0)==0|(md|0)==3){Td=md}else{J=237}}if((J|0)==237){J=0;yDb(c[O>>2]|0,16,2151520,(Uc=i,i=i+8|0,c[Uc>>2]=md,Uc)|0);i=Uc;c[N>>2]=3;Td=3}do{if((c[M>>2]|0)==0){Ud=Td}else{if((c[U>>2]|0)!=0){Ud=Td;break}yDb(c[O>>2]|0,24,2144512,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;Ud=c[N>>2]|0}}while(0);if((Ud|0)==3){c[P>>2]=0;c[R>>2]=c[Q>>2]<<4;break}else{c[P>>2]=c[P>>2]^1;md=c[Q>>2]|0;c[R>>2]=md<<3;TGb(c[S>>2]|0,0,ba(md,c[T>>2]|0)|0)|0;break}}}while(0);md=(c[z>>2]|0)-257|0;if(md>>>0>174>>>0|(Mc|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Vc=c[N>>2]|0;xd=(Vc|0)!=3|0;Rc=c[W>>2]|0;do{if((Rc|0)==1){Vd=md}else{if((c[Q>>2]|0)<=175){Vd=md;break}Vd=(d[Pc]<<2&896)+md|0}}while(0);Wd=((Vc|0)==2)+(Vd<<xd)|0;if((Sc|0)<2){J=249;break a}Xd=c[Q>>2]|0;if((Wd|0)>=(Xd|0)){J=251;break a}md=c[Y>>2]|0;if((c[X>>2]|0)==0&(md|0)==3){if((c[Z>>2]|0)==0){Xc=Oc;Yc=1;Zc=257;_c=Pc;break b}else{Yd=3;J=255}}else{if((md|0)==1){Zd=1;_d=1;J=256}else{Yd=md;J=255}}if((J|0)==255){J=0;if((c[Ta>>2]&4194304|0)==0){$d=Yd;ae=0}else{Zd=Yd;_d=0;J=256}}if((J|0)==256){J=0;c[_>>2]=1;$d=Zd;ae=_d}if((c[$>>2]|0)==0&($d|0)==2){if((c[_>>2]|0)==0){Xc=Oc;Yc=1;Zc=257;_c=Pc;break b}}md=c[aa>>2]|0;do{if((md|0)>7){if(($d|0)==3){Xc=Oc;Yc=1;Zc=257;_c=Pc;break b}if((md|0)<=31){break}if((md|0)>47|ae^1){Xc=Oc;Yc=1;Zc=257;_c=Pc;break b}}}while(0);if((c[ca>>2]|0)==0){Xc=Oc;Yc=Nc;Zc=257;_c=Pc;break b}if((Rc|0)==2){if((Wd|0)<(c[da>>2]|0)){Xc=Oc;Yc=Nc;Zc=257;_c=Pc;break b}if((Wd|0)>=(Xd-(c[ea>>2]|0)|0)){Xc=Oc;Yc=Nc;Zc=257;_c=Pc;break b}}if(($d|0)==0){yDb(fa,16,2126192,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=257;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}do{if((c[ha>>2]|0)==0){be=Nc}else{c[ha>>2]=0;ce=c[O>>2]|0;do{if((c[P>>2]|0)!=0|(Vc|0)==3){if((ROa(D,ce)|0)<0){fd=-1;J=641;break a}ePa(D);md=c[ia>>2]|0;xd=md+292|0;c[xd>>2]=0;do{if((c[La>>2]|0)!=0){if((c[M>>2]|0)==0){if((c[V>>2]|0)==0){break}c[xd>>2]=1;break}if((c[Ha>>2]|0)==0){c[xd>>2]=2;break}else{c[xd>>2]=4;break}}}while(0);xd=TCb(md|0,0,24)|0;if((xd|0)==0){fd=-1;J=641;break a}UGb(c[xd+4>>2]|0,Fb|0,24)|0;if((c[Hb>>2]|0)!=0){xd=TCb(c[ia>>2]|0,1,c[Kb>>2]|0)|0;if((xd|0)!=0){UGb(c[xd+4>>2]|0,c[Hb>>2]|0,c[Kb>>2]|0)|0}$Db(Gb)}if((c[Ib>>2]|0)==0){break}xd=VFb(c[ia>>2]|0)|0;if((xd|0)==0){fd=-1;J=641;break a}ed=xd;xd=c[Jb+4>>2]|0;c[ed>>2]=c[Jb>>2];c[ed+4>>2]=xd;c[Ib>>2]=0}else{if((c[ia>>2]|0)==0){J=288;break a}xd=c[ce+712>>2]|0;do{if((xd|0)!=0){if((c[ce+288>>2]&2|0)==0){break}if((re[c[xd+32>>2]&4095](ce)|0)>=0){break}yDb(ce,16,1955056,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc}}while(0);xd=c[ia>>2]|0;md=c[xd>>2]|0;c[Bb>>2]=md;if((c[N>>2]|0)==2){c[Bb>>2]=md+(c[xd+32>>2]|0);c[Cb>>2]=(c[xd+4>>2]|0)+(c[xd+36>>2]|0);c[Db>>2]=(c[xd+8>>2]|0)+(c[xd+40>>2]|0);c[Eb>>2]=(c[xd+12>>2]|0)+(c[xd+44>>2]|0);break}else{c[Cb>>2]=c[xd+4>>2];c[Db>>2]=c[xd+8>>2];c[Eb>>2]=c[xd+12>>2];break}}}while(0);xd=c[ce+712>>2]|0;if((xd|0)==0){be=0;break}if((ze[c[xd+24>>2]&511](ce,k,l)|0)<0){fd=-1;J=641;break a}else{be=0}}}while(0);if((c[ia>>2]|0)==0){J=299;break a}if(((c[ja>>2]|0)-37|0)>>>0<2>>>0){c[ka>>2]=(c[ka>>2]|0)+1;Xc=Oc;Yc=be;Zc=257;_c=Pc;break b}Vc=c[O>>2]|0;Rc=c[Vc+800>>2]|0;xd=(c[N>>2]|0)!=3;md=xd&1;c[la>>2]=-1;c[ma>>2]=-1;ed=c[Q>>2]|0;if((ed|0)<=(Wd|0)){J=303;break a}Wc=Sc<<3;vd=Wc>>>0>2147483639>>>0|(Pc|0)==0;bd=vd?0:Pc;nd=vd?0:Wc;c[pa>>2]=bd;c[na>>2]=nd;c[qa>>2]=nd+8;c[ra>>2]=bd+(nd>>3);c[sa>>2]=0;if((c[W>>2]|0)!=1&(ed|0)>175){c[sa>>2]=3}wMa(D);c[ta>>2]=0;ed=c[sa>>2]|0;nd=c[pa>>2]|0;bd=nd+(ed>>>3)|0;Wc=(fe(d[bd]|d[bd+1|0]<<8|d[bd+2|0]<<16|d[bd+3|0]<<24|0)|0)<<(ed&7)>>>27;bd=ed+5|0;c[sa>>2]=bd;if((c[ua>>2]|0)==0){de=Wc<<1}else{de=d[630464+Wc|0]|0}c[va>>2]=de;h:do{if((de|0)==0){yDb(c[O>>2]|0,16,2088160,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1}else{Wc=c[na>>2]|0;if((Wc-bd|0)<1){ee=-1094995529;break}else{ge=bd}while(1){ed=d[nd+(ge>>>3)|0]|0;he=ge+1|0;c[sa>>2]=he;if((ed&128>>>((ge&7)>>>0)|0)==0){break}ed=ge+9|0;c[sa>>2]=ed;if((Wc-ed|0)<1){ee=-1094995529;break h}else{ge=ed}}c[xa>>2]=0;do{if((Wd|0)==0){if((c[za>>2]|0)!=1179208787){J=315;break}c[sa>>2]=ge+2;ie=0}else{J=315}}while(0);i:do{if((J|0)==315){J=0;if((Wc-he|0)<=0){ie=0;break}ed=c[1719029]|0;vd=0;ad=he;while(1){$c=nd+(ad>>>3)|0;wd=(fe(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(ad&7)>>>23;$c=b[ed+(wd<<2)>>1]|0;Qd=b[ed+(wd<<2)+2>>1]|0;wd=Qd<<16>>16;if(Qd<<16>>16<0){Qd=ad+9|0;Rd=nd+(Qd>>>3)|0;Pd=((fe(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(Qd&7)>>>((wd+32|0)>>>0))+$c|0;je=b[ed+(Pd<<2)+2>>1]|0;ke=Qd;le=b[ed+(Pd<<2)>>1]|0}else{je=wd;ke=ad;le=$c}$c=je+ke|0;c[sa>>2]=$c;if((le|0)<0){J=322;break}if((le|0)<=32){J=327;break}if((le|0)==33){wd=vd+33|0;c[xa>>2]=wd;ne=wd}else{ne=vd}if((Wc-$c|0)>0){vd=ne;ad=$c}else{ie=ne;break i}}if((J|0)==322){J=0;yDb(c[O>>2]|0,16,2077896,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==327){J=0;ad=le+vd|0;c[xa>>2]=ad;ie=ad;break}}}while(0);if(!(ie>>>0<(c[Aa>>2]|0)>>>0)){yDb(c[O>>2]|0,16,2073120,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break}Wc=Vc+712|0;ad=c[Wc>>2]|0;do{if((ad|0)==0){J=333}else{if((c[ad+28>>2]|0)==0){J=333;break}ed=Pc-4|0;c[n>>2]=-1;$c=Pc+Sc|0;wd=f1a(Pc-2|0,$c,n)|0;Pd=wd>>>0<$c>>>0?wd-4|0:wd;c[ya>>2]=Wd;if((ze[c[(c[Wc>>2]|0)+28>>2]&511](Vc,ed,Pd-ed|0)|0)<0){ee=-1;break h}else{oe=Pd}}}while(0);if((J|0)==333){J=0;c[ma>>2]=ie;c[ya>>2]=Wd;c[la>>2]=Wd;c[Ba>>2]=0;$Oa(D);do{if((c[ya>>2]|0)==0){if((c[xa>>2]|0)!=0){break}if((c[P>>2]|0)==0){if((c[N>>2]|0)!=3){break}}Wc=c[O>>2]|0;if((c[Wc+688>>2]&1|0)==0){break}ad=Wc;Wc=c[va>>2]|0;Pd=c[Ca>>2]|0;ed=c[Da>>2]|0;wd=c[Ea>>2]|0;$c=c[Fa>>2]|0;Qd=c[Y>>2]|0;do{if((Qd|0)==1){pe=2064120}else{if((Qd|0)==2){pe=2060208;break}pe=(Qd|0)==3?2055464:2044664}}while(0);Qd=(c[M>>2]|0)!=0?2039664:9203272;vd=(c[V>>2]|0)!=0?2032712:9203272;Rd=(c[Ga>>2]|0)!=0?2028512:9203272;Kd=(c[Ha>>2]|0)!=0?2024920:9203272;Jd=c[Ia>>2]|0;qe=c[N>>2]|0;se=c[U>>2]|0;te=c[Ja>>2]|0;ue=c[ua>>2]|0;ve=c[Ka>>2]|0;we=c[La>>2]|0;xe=(c[Ma>>2]|0)!=0?2021520:9203272;yDb(ad,48,2068544,(Uc=i,i=i+144|0,c[Uc>>2]=Wc,c[Uc+8>>2]=Pd,c[Uc+16>>2]=ed,c[Uc+24>>2]=wd,c[Uc+32>>2]=$c,c[Uc+40>>2]=pe,c[Uc+48>>2]=Qd,c[Uc+56>>2]=vd,c[Uc+64>>2]=Rd,c[Uc+72>>2]=Kd,c[Uc+80>>2]=Jd,c[Uc+88>>2]=qe,c[Uc+96>>2]=se,c[Uc+104>>2]=te,c[Uc+112>>2]=ue,c[Uc+120>>2]=ve,c[Uc+128>>2]=we,c[Uc+136>>2]=xe,Uc)|0);i=Uc}}while(0);xe=16>>>(Rc>>>0);we=1<<md;ve=c[Ba>>2]|0;j:while(1){ue=1<<c[Oa>>2];te=ue+4|0;c[Ba>>2]=ve-1;se=c[Y>>2]|0;do{if((ve|0)==0){do{if((se|0)==3){qe=c[1719067]|0;Jd=c[sa>>2]|0;Kd=c[pa>>2]|0;Rd=Kd+(Jd>>>3)|0;vd=(fe(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(Jd&7)>>>26;Rd=b[qe+(vd<<2)>>1]|0;Qd=(b[qe+(vd<<2)+2>>1]|0)+Jd|0;c[sa>>2]=Qd;if(Rd<<16>>16<0){J=361;break j}ye=1679920+(Rd<<16>>16<<2)|0;Ae=Qd;Be=Kd;J=363}else if((se|0)==2){Kd=c[1719035]|0;Qd=c[sa>>2]|0;Rd=c[pa>>2]|0;Jd=Rd+(Qd>>>3)|0;vd=(fe(d[Jd]|d[Jd+1|0]<<8|d[Jd+2|0]<<16|d[Jd+3|0]<<24|0)|0)<<(Qd&7)>>>26;Jd=b[Kd+(vd<<2)>>1]|0;qe=(b[Kd+(vd<<2)+2>>1]|0)+Qd|0;c[sa>>2]=qe;if(Jd<<16>>16<0){J=358;break j}ye=559856+(Jd<<16>>16<<2)|0;Ae=qe;Be=Rd;J=363}else{Rd=c[sa>>2]|0;qe=c[pa>>2]|0;Jd=d[qe+(Rd>>>3)|0]|0;Qd=Rd+1|0;c[sa>>2]=Qd;if((Jd&128>>>((Rd&7)>>>0)|0)!=0){Ce=1;J=364;break}Jd=d[qe+(Qd>>>3)|0]|0;c[sa>>2]=Rd+2;if((Jd&128>>>((Qd&7)>>>0)|0)==0){J=356;break j}else{Ce=65537;J=364}}}while(0);k:do{if((J|0)==363){J=0;Qd=c[ye>>2]|0;if((Qd&7|0)!=0){Ce=Qd;J=364;break}l:do{if((Qd&536870912|0)==0){Jd=(c[N>>2]|0)==3;if(Jd){if((c[U>>2]|0)==0){J=430}else{De=2;Ee=Ae}}else{J=430}do{if((J|0)==430){J=0;Rd=Be+(Ae>>>3)|0;qe=(fe(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(Ae&7)>>>30;Rd=Ae+2|0;c[sa>>2]=Rd;if(!Jd){De=qe;Ee=Rd;break}if((Qd&131072|0)==0){De=qe;Ee=Rd;break}vd=d[Be+(Rd>>>3)|0]<<(Rd&7)>>>7;Rd=Ae+3|0;c[sa>>2]=Rd;c[ta>>2]=vd&1;De=qe;Ee=Rd}}while(0);if((Qd&65536|0)==0){Fe=Ee}else{Rd=Be+(Ee>>>3)|0;qe=(fe(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(Ee&7)>>>27;Rd=Ee+5|0;c[sa>>2]=Rd;if((c[ua>>2]|0)==0){Ge=qe<<1}else{Ge=d[630464+qe|0]|0}c[va>>2]=Ge;Fe=Rd}c[bb>>2]=Qd>>>13&3;if((De|0)==3){if((c[M>>2]|0)!=0){J=459;break j}c[cb>>2]=4;Rd=Qd;qe=0;while(1){do{if((12288<<(qe<<1)&Rd|0)==0){He=Rd}else{vd=(c[N>>2]|0)==3|0;Kd=D+11824+(qe<<4)|0;Ie=GMa(D,c[D+14156+(qe<<3)>>2]|0,c[Kd>>2]|0)|0;c[Kd>>2]=Ie;c[D+11824+(qe<<4)+8>>2]=Ie;Kd=c[sa>>2]|0;Je=c[pa>>2]|0;Ke=d[Je+(Kd>>>3)|0]|0;Le=Kd+1|0;c[sa>>2]=Le;if((Ke&128>>>((Kd&7)>>>0)|0)==0){Me=0}else{Ke=d[Je+(Le>>>3)|0]<<(Le&7)>>>7;c[sa>>2]=Kd+2;Me=1-(Ke<<1&2)|0}Ke=D+11824+(qe<<4)+4|0;Kd=GMa(D,c[D+14156+(qe<<3)+4>>2]|0,c[Ke>>2]>>vd)|0;Le=c[sa>>2]|0;Je=c[pa>>2]|0;Ne=d[Je+(Le>>>3)|0]|0;Oe=Le+1|0;c[sa>>2]=Oe;if((Ne&128>>>((Le&7)>>>0)|0)==0){Pe=0}else{Ne=d[Je+(Oe>>>3)|0]<<(Oe&7)>>>7;c[sa>>2]=Le+2;Pe=1-(Ne<<1&2)|0}Ne=Kd<<vd;c[Ke>>2]=Ne;c[D+11824+(qe<<4)+12>>2]=Ne;c[D+11744+(qe<<5)>>2]=Ie;c[D+11744+(qe<<5)+4>>2]=Kd;c[D+11744+(qe<<5)+8>>2]=Ie;c[D+11744+(qe<<5)+12>>2]=Kd;Ne=c[N>>2]|0;if((Ne|0)==3){Ke=(c[Ha>>2]|0)!=0?1:3;vd=(Ie|0)>0|0;c[D+11744+(qe<<5)+16>>2]=((ba(Ke,Ie)|0)+vd>>1)+Me;Le=(Kd|0)>0|0;c[D+11744+(qe<<5)+20>>2]=Pe-1+((ba(Ke,Kd)|0)+Le>>1);Oe=4-Ke|0;c[D+11744+(qe<<5)+24>>2]=((ba(Oe,Ie)|0)+vd>>1)+Me;c[D+11744+(qe<<5)+28>>2]=Pe+1+((ba(Oe,Kd)|0)+Le>>1);He=Rd|136;break}Le=Rd|8;c[D+11744+(qe<<5)+16>>2]=Me+(((Ie|0)>0)+Ie>>1);Ie=Pe+(((Kd|0)>0)+Kd>>1)|0;Kd=D+11744+(qe<<5)+20|0;c[Kd>>2]=Ie;if((Ne|0)==1){c[Kd>>2]=Ie-1;He=Le;break}else{c[Kd>>2]=Ie+1;He=Le;break}}}while(0);Le=qe+1|0;if((Le|0)<2){Rd=He;qe=Le}else{Qe=He;break}}}else if((De|0)==2){if(!Jd){qe=Qd|144;c[cb>>2]=2;Rd=0;while(1){if((12288<<(Rd<<1)&qe|0)!=0){Le=D+14156+(Rd<<3)|0;Ie=c[sa>>2]|0;Kd=d[(c[pa>>2]|0)+(Ie>>>3)|0]<<(Ie&7)>>>7;c[sa>>2]=Ie+1;c[D+11808+(Rd<<3)>>2]=Kd&1;Kd=D+11824+(Rd<<4)|0;Ie=GMa(D,c[Le>>2]|0,c[Kd>>2]|0)|0;c[Kd>>2]=Ie;c[D+11744+(Rd<<5)>>2]=Ie;Ie=D+14156+(Rd<<3)+4|0;Kd=D+11824+(Rd<<4)+4|0;Ne=GMa(D,c[Ie>>2]|0,c[Kd>>2]|0)|0;c[Kd>>2]=Ne;c[D+11744+(Rd<<5)+4>>2]=Ne;Ne=c[sa>>2]|0;Kd=d[(c[pa>>2]|0)+(Ne>>>3)|0]<<(Ne&7)>>>7;c[sa>>2]=Ne+1;c[D+11808+(Rd<<3)+4>>2]=Kd&1;Kd=D+11824+(Rd<<4)+8|0;Ne=GMa(D,c[Le>>2]|0,c[Kd>>2]|0)|0;c[Kd>>2]=Ne;c[D+11744+(Rd<<5)+8>>2]=Ne;Ne=D+11824+(Rd<<4)+12|0;Kd=GMa(D,c[Ie>>2]|0,c[Ne>>2]|0)|0;c[Ne>>2]=Kd;c[D+11744+(Rd<<5)+12>>2]=Kd}Kd=Rd+1|0;if((Kd|0)<2){Rd=Kd}else{Qe=qe;break l}}}qe=Qd|8;c[cb>>2]=0;do{if((Qd&12288|0)!=0){Rd=GMa(D,c[Ca>>2]|0,c[Wa>>2]|0)|0;c[Xa>>2]=Rd;c[Wa>>2]=Rd;c[Ya>>2]=Rd;Rd=GMa(D,c[Da>>2]|0,c[Za>>2]|0)|0;c[_a>>2]=Rd;c[Za>>2]=Rd;c[$a>>2]=Rd;if((c[kb>>2]|0)==0){break}c[Ya>>2]=c[Ya>>2]<<1;c[$a>>2]=Rd<<1}}while(0);if((Qd&49152|0)==0){Qe=qe;break}Rd=GMa(D,c[Ea>>2]|0,c[db>>2]|0)|0;c[eb>>2]=Rd;c[db>>2]=Rd;c[fb>>2]=Rd;Rd=GMa(D,c[Fa>>2]|0,c[gb>>2]|0)|0;c[hb>>2]=Rd;c[gb>>2]=Rd;c[ib>>2]=Rd;if((c[jb>>2]|0)==0){Qe=qe;break}c[fb>>2]=c[fb>>2]<<1;c[ib>>2]=Rd<<1;Qe=qe;break}else if((De|0)==1){c[cb>>2]=3;if(Jd){Rd=Qd|144;Kd=0;while(1){if((12288<<(Kd<<1)&Rd|0)!=0){Ne=D+14156+(Kd<<3)|0;Ie=D+14156+(Kd<<3)+4|0;Le=c[sa>>2]|0;Oe=d[(c[pa>>2]|0)+(Le>>>3)|0]<<(Le&7)>>>7;c[sa>>2]=Le+1;c[D+11808+(Kd<<3)>>2]=Oe&1;Oe=D+11824+(Kd<<4)|0;Le=GMa(D,c[Ne>>2]|0,c[Oe>>2]|0)|0;c[Oe>>2]=Le;c[D+11744+(Kd<<5)>>2]=Le;Le=D+11824+(Kd<<4)+4|0;Oe=GMa(D,c[Ie>>2]|0,c[Le>>2]>>1)|0;c[Le>>2]=Oe<<1;c[D+11744+(Kd<<5)+4>>2]=Oe;Oe=c[sa>>2]|0;Le=d[(c[pa>>2]|0)+(Oe>>>3)|0]<<(Oe&7)>>>7;c[sa>>2]=Oe+1;c[D+11808+(Kd<<3)+4>>2]=Le&1;Le=D+11824+(Kd<<4)+8|0;Oe=GMa(D,c[Ne>>2]|0,c[Le>>2]|0)|0;c[Le>>2]=Oe;c[D+11744+(Kd<<5)+8>>2]=Oe;Oe=D+11824+(Kd<<4)+12|0;Le=GMa(D,c[Ie>>2]|0,c[Oe>>2]>>1)|0;c[Oe>>2]=Le<<1;c[D+11744+(Kd<<5)+12>>2]=Le}Le=Kd+1|0;if((Le|0)<2){Kd=Le}else{Qe=Rd;break l}}}if((c[M>>2]|0)!=0){J=454;break a}Rd=Qd|136;if((Qd&12288|0)!=0){Kd=d[Be+(Fe>>>3)|0]<<(Fe&7)>>>7;c[sa>>2]=Fe+1;c[mb>>2]=Kd&1;Kd=GMa(D,c[Ca>>2]|0,c[Wa>>2]|0)|0;c[Wa>>2]=Kd;c[Xa>>2]=Kd;c[Ya>>2]=Kd;Kd=GMa(D,c[Da>>2]|0,c[Za>>2]|0)|0;c[Za>>2]=Kd;c[_a>>2]=Kd;c[$a>>2]=Kd}if((Qd&49152|0)==0){Qe=Rd;break}Kd=c[sa>>2]|0;Jd=d[(c[pa>>2]|0)+(Kd>>>3)|0]<<(Kd&7)>>>7;c[sa>>2]=Kd+1;c[lb>>2]=Jd&1;Jd=GMa(D,c[Ea>>2]|0,c[db>>2]|0)|0;c[db>>2]=Jd;c[eb>>2]=Jd;c[fb>>2]=Jd;Jd=GMa(D,c[Fa>>2]|0,c[gb>>2]|0)|0;c[gb>>2]=Jd;c[hb>>2]=Jd;c[ib>>2]=Jd;Qe=Rd;break}else{J=472;break j}}else{c[bb>>2]=1;Rd=c[N>>2]|0;if((Rd|0)==3){if((c[U>>2]|0)==0){Jd=d[Be+(Ae>>>3)|0]<<(Ae&7)>>>7;Kd=Ae+1|0;c[sa>>2]=Kd;c[ta>>2]=Jd&1;Re=Kd}else{Re=Ae}c[cb>>2]=0;Se=Qd;Te=Re}else{c[cb>>2]=3;c[mb>>2]=Rd-1;Se=Qd|128;Te=Ae}if((Se&65536|0)!=0){Rd=Be+(Te>>>3)|0;Kd=(fe(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(Te&7)>>>27;c[sa>>2]=Te+5;if((c[ua>>2]|0)==0){Ue=Kd<<1}else{Ue=d[630464+Kd|0]|0}c[va>>2]=Ue}c[Ya>>2]=0;c[$a>>2]=0;TGb(Ra|0,0,16)|0;Qe=Se}}while(0);c[Sa>>2]=0;if((Qe&131072|0)==0){TGb(nb|0,-1|0,48)|0;Ve=Qe;break}me[c[Pa>>2]&511](c[Na>>2]|0);Qd=c[1719041]|0;Kd=c[sa>>2]|0;Rd=c[pa>>2]|0;Jd=Rd+(Kd>>>3)|0;qe=(fe(d[Jd]|d[Jd+1|0]<<8|d[Jd+2|0]<<16|d[Jd+3|0]<<24|0)|0)<<(Kd&7)>>>23;Jd=b[Qd+(qe<<2)>>1]|0;Le=(b[Qd+(qe<<2)+2>>1]|0)+Kd|0;c[sa>>2]=Le;if((te|0)>6){Kd=ue-2|0;qe=Rd+(Le>>>3)|0;Rd=(fe(d[qe]|d[qe+1|0]<<8|d[qe+2|0]<<16|d[qe+3|0]<<24|0)|0)<<(Le&7)>>>((34-ue|0)>>>0);c[sa>>2]=Le+Kd;me[c[Pa>>2]&511]((c[Na>>2]|0)+768|0);We=Rd|Jd<<Kd}else{We=Jd}if((We|0)<1){J=478;break j}Jd=(c[Ta>>2]&1|0)!=0;if((c[W>>2]|0)==2){if(Jd){Kd=We;Rd=0;while(1){if((Kd&32|0)==0){c[D+180+(Rd<<2)>>2]=-1}else{Le=c[D+14292+(Rd<<2)>>2]|0;qe=Le|0;Qd=c[va>>2]|0;Oe=c[sa>>2]|0;Ie=c[pa>>2]|0;Ne=Ie+(Oe>>>3)|0;vd=(fe(d[Ne]|d[Ne+1|0]<<8|d[Ne+2|0]<<16|d[Ne+3|0]<<24|0)|0)<<(Oe&7);if((vd|0)<0){Ne=(Qd*3|0)>>1;if((vd&1073741824|0)==0){Xe=Ne&65535}else{Xe=-Ne&65535}b[qe>>1]=Xe;qe=vd<<2;Ne=Oe+2|0;if((qe|0)<-1073741824){Ye=Ne;Ze=0}else{_e=qe;$e=Ne;af=0;J=486}}else{_e=vd;$e=Oe;af=-1;J=486}m:do{if((J|0)==486){J=0;Oe=c[287062]|0;vd=_e;Ne=$e;qe=af;while(1){Ke=vd>>>23;Je=b[Oe+(Ke<<2)>>1]|0;bf=a[Oe+(Ke<<2)+2|0]|0;cf=bf<<24>>24;if(bf<<24>>24<0){bf=vd<<9;df=(bf>>>((cf+32|0)>>>0))+Je|0;ef=df;ff=b[Oe+(df<<2)>>1]|0;gf=a[Oe+(df<<2)+2|0]|0;hf=bf;jf=Ne+9|0}else{ef=Ke;ff=Je;gf=cf;hf=vd;jf=Ne}cf=hf<<gf;Je=gf+jf|0;do{if((ff|0)==0){Ke=Je+6|0;bf=Ie+(Ke>>>3)|0;df=(fe(d[bf]|d[bf+1|0]<<8|d[bf+2|0]<<16|d[bf+3|0]<<24|0)|0)<<(Ke&7);Ke=df>>20;bf=df<<12;df=Je+18|0;kf=qe+1+(cf>>>26)|0;lf=d[D+368+kf|0]|0;if((Ke|0)<0){mf=-((ba(-Ke<<1|1,Qd)|0)>>>1)&65535;nf=bf;of=df;pf=kf;qf=lf;break}else{mf=(ba(Ke<<1|1,Qd)|0)>>>1&65535;nf=bf;of=df;pf=kf;qf=lf;break}}else{lf=(d[Oe+(ef<<2)+3|0]|0)+qe|0;kf=cf>>31;mf=((ba(ff<<1|1,Qd)|0)>>>1^kf)-kf&65535;nf=cf<<1;of=Je+1|0;pf=lf;qf=d[D+368+lf|0]|0}}while(0);b[Le+(qf<<1)>>1]=mf;if((nf|0)<-1073741824|(pf|0)>63){Ye=of;Ze=pf;break m}Je=Ie+(of>>>3)|0;vd=(fe(d[Je]|d[Je+1|0]<<8|d[Je+2|0]<<16|d[Je+3|0]<<24|0)|0)<<(of&7);Ne=of;qe=pf}}}while(0);c[sa>>2]=Ye+2;c[D+180+(Rd<<2)>>2]=Ze}Ie=Rd+1|0;if((Ie|0)<6){Kd=Kd<<1;Rd=Ie}else{Ve=Qe;break k}}}if((te|0)<=0){Ve=Qe;break}Rd=We<<8-ue;Kd=0;while(1){if((Rd&2048|0)==0){c[D+180+(Kd<<2)>>2]=-1}else{Ie=c[D+14292+(Kd<<2)>>2]|0;Le=c[va>>2]|0;Qd=c[sa>>2]|0;qe=(Kd|0)<4?ob:pb;Ne=c[pa>>2]|0;vd=Ne+(Qd>>>3)|0;Oe=(fe(d[vd]|d[vd+1|0]<<8|d[vd+2|0]<<16|d[vd+3|0]<<24|0)|0)<<(Qd&7);if((Oe|0)<0){vd=(ba(Le*3|0,e[qe>>1]|0)|0)>>5;Je=(Oe&1073741824|0)==0?vd:-vd|0;b[Ie>>1]=Je;vd=Je^1;Je=Oe<<2;cf=Qd+2|0;if((Je|0)<-1073741824){rf=cf;sf=vd;tf=0}else{uf=Je;vf=cf;wf=vd;xf=0;J=504}}else{uf=Oe;vf=Qd;wf=1;xf=-1;J=504}n:do{if((J|0)==504){J=0;Qd=c[287062]|0;Oe=uf;vd=vf;cf=wf;Je=xf;while(1){lf=Oe>>>23;kf=b[Qd+(lf<<2)>>1]|0;df=a[Qd+(lf<<2)+2|0]|0;bf=df<<24>>24;if(df<<24>>24<0){df=Oe<<9;Ke=(df>>>((bf+32|0)>>>0))+kf|0;yf=Ke;zf=a[Qd+(Ke<<2)+2|0]|0;Af=df;Bf=vd+9|0;Cf=b[Qd+(Ke<<2)>>1]|0}else{yf=lf;zf=bf;Af=Oe;Bf=vd;Cf=kf}kf=Af<<zf;bf=zf+Bf|0;do{if((Cf|0)==0){lf=bf+6|0;Ke=Ne+(lf>>>3)|0;df=(fe(d[Ke]|d[Ke+1|0]<<8|d[Ke+2|0]<<16|d[Ke+3|0]<<24|0)|0)<<(lf&7);lf=df>>20;Ke=df<<12;df=bf+18|0;Df=Je+1+(kf>>>26)|0;if((Df|0)>63){J=512;break j}Ef=d[D+368+Df|0]|0;if((lf|0)<0){Ff=ba(-lf<<1|1,Le)|0;Gf=Ke;Hf=df;If=-((ba(Ff,e[qe+(Ef<<1)>>1]|0)|0)>>5)|0;Jf=Df;Kf=Ef;break}else{Ff=ba(lf<<1|1,Le)|0;Gf=Ke;Hf=df;If=(ba(Ff,e[qe+(Ef<<1)>>1]|0)|0)>>5;Jf=Df;Kf=Ef;break}}else{Ef=(d[Qd+(yf<<2)+3|0]|0)+Je|0;if((Ef|0)>63){J=509;break j}Df=d[D+368+Ef|0]|0;Ff=ba(Cf<<1|1,Le)|0;df=kf>>31;Gf=kf<<1;Hf=bf+1|0;If=((ba(Ff,e[qe+(Df<<1)>>1]|0)|0)>>5^df)-df|0;Jf=Ef;Kf=Df}}while(0);bf=If^cf;b[Ie+(Kf<<1)>>1]=If;if((Gf|0)<-1073741824){rf=Hf;sf=bf;tf=Jf;break n}kf=Ne+(Hf>>>3)|0;Oe=(fe(d[kf]|d[kf+1|0]<<8|d[kf+2|0]<<16|d[kf+3|0]<<24|0)|0)<<(Hf&7);vd=Hf;cf=bf;Je=Jf}}}while(0);c[sa>>2]=rf+2;Ne=Ie+126|0;b[Ne>>1]=e[Ne>>1]^sf&1;c[D+180+(Kd<<2)>>2]=tf}Ne=Kd+1|0;if((Ne|0)<(te|0)){Rd=Rd<<1;Kd=Ne}else{Ve=Qe;break k}}}if(Jd){Lf=We;Mf=0}else{Kd=We;Rd=0;while(1){if((Kd&32|0)==0){c[D+180+(Rd<<2)>>2]=-1}else{Ne=c[D+14292+(Rd<<2)>>2]|0;qe=Ne|0;Le=c[va>>2]|0;Je=c[sa>>2]|0;cf=c[pa>>2]|0;vd=cf+(Je>>>3)|0;Oe=(fe(d[vd]|d[vd+1|0]<<8|d[vd+2|0]<<16|d[vd+3|0]<<24|0)|0)<<(Je&7);if((Oe|0)<0){vd=((ba(Le*3|0,e[ob>>1]|0)|0)>>5)-1|1;if((Oe&1073741824|0)==0){Nf=vd&65535}else{Nf=-vd&65535}b[qe>>1]=Nf;qe=Oe<<2;vd=Je+2|0;if((qe|0)<-1073741824){Of=vd;Pf=0}else{Qf=qe;Rf=vd;Sf=0;J=553}}else{Qf=Oe;Rf=Je;Sf=-1;J=553}o:do{if((J|0)==553){J=0;Je=c[287062]|0;Oe=Qf;vd=Rf;qe=Sf;while(1){Qd=Oe>>>23;bf=b[Je+(Qd<<2)>>1]|0;kf=a[Je+(Qd<<2)+2|0]|0;Df=kf<<24>>24;if(kf<<24>>24<0){kf=Oe<<9;Ef=(kf>>>((Df+32|0)>>>0))+bf|0;Tf=Ef;Uf=a[Je+(Ef<<2)+2|0]|0;Vf=kf;Wf=vd+9|0;Xf=b[Je+(Ef<<2)>>1]|0}else{Tf=Qd;Uf=Df;Vf=Oe;Wf=vd;Xf=bf}bf=Vf<<Uf;Df=Uf+Wf|0;do{if((Xf|0)==0){Qd=bf>>>26;Ef=Df+6|0;kf=cf+(Ef>>>3)|0;df=(fe(d[kf]|d[kf+1|0]<<8|d[kf+2|0]<<16|d[kf+3|0]<<24|0)|0)<<(Ef&7);Ef=df>>24;do{if((Ef|0)==-128){Yf=df<<16;Zf=Df+22|0;_f=df>>>16|-256}else{if((Ef|0)!=0){Yf=df<<8;Zf=Df+14|0;_f=Ef;break}Yf=df<<16;Zf=Df+22|0;_f=df>>>16&255}}while(0);df=qe+1+Qd|0;if((df|0)>63){J=565;break j}Ef=d[D+368+df|0]|0;if((_f|0)<0){kf=ba(-_f<<1|1,Le)|0;$f=Yf;ag=Zf;bg=-(((ba(kf,e[D+12816+(Ef<<1)>>1]|0)|0)>>>5)+65535|1)&65535;cg=df;dg=Ef;break}else{kf=ba(_f<<1|1,Le)|0;$f=Yf;ag=Zf;bg=(((ba(kf,e[D+12816+(Ef<<1)>>1]|0)|0)>>>5)+65535|1)&65535;cg=df;dg=Ef;break}}else{Ef=(d[Je+(Tf<<2)+3|0]|0)+qe|0;if((Ef|0)>63){J=558;break j}df=d[D+368+Ef|0]|0;kf=ba(Xf<<1|1,Le)|0;Ff=bf>>31;$f=bf<<1;ag=Df+1|0;bg=((((ba(kf,e[D+12816+(df<<1)>>1]|0)|0)>>>5)+65535|1)^Ff)-Ff&65535;cg=Ef;dg=df}}while(0);b[Ne+(dg<<1)>>1]=bg;if(($f|0)<-1073741824){Of=ag;Pf=cg;break o}Df=cf+(ag>>>3)|0;Oe=(fe(d[Df]|d[Df+1|0]<<8|d[Df+2|0]<<16|d[Df+3|0]<<24|0)|0)<<(ag&7);vd=ag;qe=cg}}}while(0);c[sa>>2]=Of+2;c[D+180+(Rd<<2)>>2]=Pf}cf=Rd+1|0;if((cf|0)<6){Kd=Kd<<1;Rd=cf}else{Ve=Qe;break k}}}while(1){p:do{if((Lf&32|0)==0){c[D+180+(Mf<<2)>>2]=-1}else{Rd=c[D+14292+(Mf<<2)>>2]|0;Kd=Rd|0;Jd=c[va>>2]|0;cf=c[sa>>2]|0;Ne=c[pa>>2]|0;Le=Ne+(cf>>>3)|0;Ie=(fe(d[Le]|d[Le+1|0]<<8|d[Le+2|0]<<16|d[Le+3|0]<<24|0)|0)<<(cf&7);if((Ie|0)<0){Le=((Jd*3|0)>>1)-1|1;if((Ie&1073741824|0)==0){eg=Le&65535}else{eg=-Le&65535}b[Kd>>1]=eg;Kd=Ie<<2;Le=cf+2|0;if((Kd|0)<-1073741824){fg=Le;gg=0}else{hg=Kd;ig=Le;jg=0;J=527}}else{hg=Ie;ig=cf;jg=-1;J=527}q:do{if((J|0)==527){J=0;cf=c[287062]|0;Ie=hg;Le=ig;Kd=jg;r:while(1){qe=Ie>>>23;vd=b[cf+(qe<<2)>>1]|0;Oe=a[cf+(qe<<2)+2|0]|0;Je=Oe<<24>>24;if(Oe<<24>>24<0){Oe=Ie<<9;Df=(Oe>>>((Je+32|0)>>>0))+vd|0;kg=Df;lg=a[cf+(Df<<2)+2|0]|0;mg=Oe;ng=Le+9|0;og=b[cf+(Df<<2)>>1]|0}else{kg=qe;lg=Je;mg=Ie;ng=Le;og=vd}vd=mg<<lg;Je=lg+ng|0;do{if((og|0)==0){qe=vd>>>26;Df=Je+6|0;Oe=Ne+(Df>>>3)|0;bf=(fe(d[Oe]|d[Oe+1|0]<<8|d[Oe+2|0]<<16|d[Oe+3|0]<<24|0)|0)<<(Df&7);Df=bf>>24;do{if((Df|0)==-128){pg=bf<<16;qg=Je+22|0;rg=bf>>>16|-256}else{if((Df|0)!=0){pg=bf<<8;qg=Je+14|0;rg=Df;break}pg=bf<<16;qg=Je+22|0;rg=bf>>>16&255}}while(0);bf=Kd+1+qe|0;if((bf|0)>63){J=539;break r}Df=d[D+368+bf|0]|0;if((rg|0)<0){sg=pg;tg=qg;ug=-(((ba(-rg<<1|1,Jd)|0)>>>1)+65535|1)&65535;vg=bf;wg=Df;break}else{sg=pg;tg=qg;ug=(((ba(rg<<1|1,Jd)|0)>>>1)+65535|1)&65535;vg=bf;wg=Df;break}}else{Df=(d[cf+(kg<<2)+3|0]|0)+Kd|0;if((Df|0)>63){J=532;break r}bf=vd>>31;sg=vd<<1;tg=Je+1|0;ug=((((ba(og<<1|1,Jd)|0)>>>1)+65535|1)^bf)-bf&65535;vg=Df;wg=d[D+368+Df|0]|0}}while(0);b[Rd+(wg<<1)>>1]=ug;if((sg|0)<-1073741824){fg=tg;gg=vg;break q}Je=Ne+(tg>>>3)|0;Ie=(fe(d[Je]|d[Je+1|0]<<8|d[Je+2|0]<<16|d[Je+3|0]<<24|0)|0)<<(tg&7);Le=tg;Kd=vg}if((J|0)==532){J=0;Kd=c[ya>>2]|0;yDb(c[O>>2]|0,16,1962304,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=Kd,Uc)|0);i=Uc;break p}else if((J|0)==539){J=0;Kd=c[ya>>2]|0;yDb(c[O>>2]|0,16,1962304,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=Kd,Uc)|0);i=Uc;break p}}}while(0);c[sa>>2]=fg+2;c[D+180+(Mf<<2)>>2]=gg}}while(0);Ne=Mf+1|0;if((Ne|0)<6){Lf=Lf<<1;Mf=Ne}else{Ve=Qe;break}}}}while(0);s:do{if((J|0)==364){J=0;me[c[Pa>>2]&511](c[Na>>2]|0);if((c[Qa>>2]|0)==0){me[c[Pa>>2]&511]((c[Na>>2]|0)+768|0)}Ne=(c[N>>2]|0)==3;do{if(Ne){if((c[U>>2]|0)!=0){break}Rd=c[sa>>2]|0;Jd=d[(c[pa>>2]|0)+(Rd>>>3)|0]<<(Rd&7)>>>7;c[sa>>2]=Rd+1;c[ta>>2]=Jd&1}}while(0);if((Ce&65536|0)!=0){Jd=c[sa>>2]|0;Rd=(c[pa>>2]|0)+(Jd>>>3)|0;Kd=(fe(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(Jd&7)>>>27;c[sa>>2]=Jd+5;if((c[ua>>2]|0)==0){xg=Kd<<1}else{xg=d[630464+Kd|0]|0}c[va>>2]=xg}if((c[Ja>>2]|0)==0){TGb(Ra|0,0,32)|0}else{if(!Ne){c[sa>>2]=(c[sa>>2]|0)+1}Kd=GMa(D,c[Ca>>2]|0,c[Wa>>2]|0)|0;c[Xa>>2]=Kd;c[Wa>>2]=Kd;c[Ya>>2]=Kd;Kd=GMa(D,c[Da>>2]|0,c[Za>>2]|0)|0;c[_a>>2]=Kd;c[Za>>2]=Kd;c[$a>>2]=Kd;c[sa>>2]=(c[sa>>2]|0)+1}c[Sa>>2]=1;if((c[W>>2]|0)!=2){Kd=0;while(1){if((Kd|0)>=6){Ve=Ce;break s}if((AMa(D,c[D+14292+(Kd<<2)>>2]|0,Kd)|0)<0){ee=-1;break h}else{Kd=Kd+1|0}}}if((c[Ta>>2]&1|0)!=0){Kd=0;while(1){Ne=c[D+14292+(Kd<<2)>>2]|0;Jd=c[va>>2]|0;if((Kd|0)<4){yg=Ua;zg=0}else{yg=Va;zg=(Kd&1)+1|0}Rd=HMa(oa,zg)|0;if((Rd|0)<=65534){Le=D+9860+(zg<<2)|0;Ie=(c[Le>>2]|0)+Rd|0;c[Le>>2]=Ie;b[Ne>>1]=Ie<<3-(c[Ia>>2]|0);Ie=-Jd|0;Le=c[pa>>2]|0;Rd=c[((c[Ka>>2]|0)==0?1148184:1147992)+64>>2]|0;cf=c[sa>>2]|0;Je=0;while(1){vd=Le+(cf>>>3)|0;Qd=(fe(d[vd]|d[vd+1|0]<<8|d[vd+2|0]<<16|d[vd+3|0]<<24|0)|0)<<(cf&7);vd=Qd>>>23;Df=b[Rd+(vd<<2)>>1]|0;bf=a[Rd+(vd<<2)+2|0]|0;Oe=bf<<24>>24;if(bf<<24>>24<0){bf=Qd<<9;df=(bf>>>((Oe+32|0)>>>0))+Df|0;Ag=df;Bg=a[Rd+(df<<2)+2|0]|0;Cg=bf;Dg=cf+9|0;Eg=b[Rd+(df<<2)>>1]|0}else{Ag=vd;Bg=Oe;Cg=Qd;Dg=cf;Eg=Df}Df=d[Rd+(Ag<<2)+3|0]|0;Qd=Cg<<Bg;Fg=Bg+Dg|0;if((Eg|0)>63|(Je|0)>63){break}do{if((Eg|0)==0){Oe=Fg+6|0;vd=Le+(Oe>>>3)|0;df=(fe(d[vd]|d[vd+1|0]<<8|d[vd+2|0]<<16|d[vd+3|0]<<24|0)|0)<<(Oe&7)>>20;Oe=Fg+18|0;vd=Je+1+(Qd>>>26)|0;bf=d[D+368+vd|0]|0;if((df|0)<0){Gg=Oe;Hg=-((ba(ba(df,Ie)|0,e[yg+(bf<<1)>>1]|0)|0)>>>4)&65535;Ig=vd;Jg=bf;break}else{Ef=ba(df,Jd)|0;Gg=Oe;Hg=(ba(Ef,e[yg+(bf<<1)>>1]|0)|0)>>>4&65535;Ig=vd;Jg=bf;break}}else{bf=Df+Je|0;vd=d[D+368+bf|0]|0;Ef=ba(Eg,Jd)|0;Oe=Qd>>31;Gg=Fg+1|0;Hg=((ba(Ef,e[yg+(vd<<1)>>1]|0)|0)>>>4^Oe)-Oe&65535;Ig=bf;Jg=vd}}while(0);b[Ne+(Jg<<1)>>1]=Hg;cf=Gg;Je=Ig}c[sa>>2]=Fg;c[D+180+(Kd<<2)>>2]=Je}cf=Kd+1|0;if((cf|0)<6){Kd=cf}else{Ve=Ce;break s}}}if((te|0)>0){Kg=0}else{Ve=Ce;break}while(1){Kd=c[D+14292+(Kg<<2)>>2]|0;cf=c[va>>2]|0;if((Kg|0)<4){Lg=Ua;Mg=0}else{Lg=Va;Mg=(Kg&1)+1|0}Ne=HMa(oa,Mg)|0;if((Ne|0)>65534){ee=-1;break h}Jd=D+9860+(Mg<<2)|0;Ie=(c[Jd>>2]|0)+Ne|0;c[Jd>>2]=Ie;Jd=Ie<<3-(c[Ia>>2]|0)&65535;b[Kd>>1]=Jd;Ie=-cf|0;Ne=c[pa>>2]|0;Le=c[((c[Ka>>2]|0)==0?1148184:1147992)+64>>2]|0;Rd=c[sa>>2]|0;Qd=Jd<<16>>16^1;Jd=0;t:while(1){Df=Ne+(Rd>>>3)|0;vd=(fe(d[Df]|d[Df+1|0]<<8|d[Df+2|0]<<16|d[Df+3|0]<<24|0)|0)<<(Rd&7);Df=vd>>>23;bf=b[Le+(Df<<2)>>1]|0;Oe=a[Le+(Df<<2)+2|0]|0;Ef=Oe<<24>>24;if(Oe<<24>>24<0){Oe=vd<<9;df=(Oe>>>((Ef+32|0)>>>0))+bf|0;Ng=df;Og=a[Le+(df<<2)+2|0]|0;Pg=Oe;Qg=Rd+9|0;Rg=b[Le+(df<<2)>>1]|0}else{Ng=Df;Og=Ef;Pg=vd;Qg=Rd;Rg=bf}bf=Pg<<Og;Sg=Og+Qg|0;do{if((Rg|0)==127){break t}else if((Rg|0)==0){vd=Sg+6|0;Ef=Ne+(vd>>>3)|0;Df=(fe(d[Ef]|d[Ef+1|0]<<8|d[Ef+2|0]<<16|d[Ef+3|0]<<24|0)|0)<<(vd&7)>>20;vd=Sg+18|0;Ef=Jd+1+(bf>>>26)|0;if((Ef|0)>63){J=408;break j}df=d[D+368+Ef|0]|0;if((Df|0)<0){Tg=vd;Ug=-((ba(ba(Df,Ie)|0,e[Lg+(df<<1)>>1]|0)|0)>>4)|0;Vg=Ef;Wg=df;break}else{Oe=ba(Df,cf)|0;Tg=vd;Ug=(ba(Oe,e[Lg+(df<<1)>>1]|0)|0)>>4;Vg=Ef;Wg=df;break}}else{df=(d[Le+(Ng<<2)+3|0]|0)+Jd|0;if((df|0)>63){J=405;break j}Ef=d[D+368+df|0]|0;Oe=ba(Rg,cf)|0;vd=bf>>31;Tg=Sg+1|0;Ug=((ba(Oe,e[Lg+(Ef<<1)>>1]|0)|0)>>4^vd)-vd|0;Vg=df;Wg=Ef}}while(0);b[Kd+(Wg<<1)>>1]=Ug;Rd=Tg;Qd=Ug^Qd;Jd=Vg}c[sa>>2]=Sg;Rd=Kd+126|0;b[Rd>>1]=e[Rd>>1]^Qd&1;c[D+180+(Kg<<2)>>2]=Jd;Rd=Kg+1|0;if((Rd|0)<(te|0)){Kg=Rd}else{Ve=Ce;break}}}}while(0);Rd=(ba(c[T>>2]|0,c[ya>>2]|0)|0)+(c[xa>>2]|0)|0;c[(c[ab>>2]|0)+(Rd<<2)>>2]=Ve}else{if((se|0)==2){c[xb>>2]=1;Rd=(ba(c[T>>2]|0,c[ya>>2]|0)|0)+(c[xa>>2]|0)|0;c[(c[ab>>2]|0)+(Rd<<2)>>2]=14344;break}Rd=c[xa>>2]|0;if((Rd|0)==0){cf=c[ya>>2]|0;Le=c[T>>2]|0;Ie=(c[Aa>>2]|0)-1+(ba(cf-1|0,Le)|0)|0;Ne=c[ab>>2]|0;Xg=Ne+(Ie<<2)|0;Yg=cf;Zg=Le;_g=Ne}else{Ne=c[ya>>2]|0;Le=c[T>>2]|0;cf=Rd-1+(ba(Le,Ne)|0)|0;Ie=c[ab>>2]|0;Xg=Ie+(cf<<2)|0;Yg=Ne;Zg=Le;_g=Ie}Ie=c[Xg>>2]|0;if((Ie&7|0)!=0){J=350;break j}c[_g+((ba(Yg,Zg)|0)+Rd<<2)>>2]=Ie|2048;if((c[$a>>2]|c[Ya>>2]|c[fb>>2]|c[ib>>2]|0)!=0){break}c[xb>>2]=1}}while(0);do{if((c[qb>>2]|0)!=0){if((c[vb>>2]|0)!=0){break}se=c[wb>>2]|0;te=c[xa>>2]|0;ue=c[ya>>2]|0;$c=(ba(ue,se)|0)+te<<1;wd=(ba(c[T>>2]|0,ue)|0)+te<<2;te=0;ue=$c;while(1){$c=ue+1|0;ed=wd|1;do{if((c[Sa>>2]|0)==0){Pd=c[cb>>2]|0;if((Pd|0)==3){if(xd){J=584}else{J=585}}else if((Pd|0)==0){J=584}else{J=585}if((J|0)==584){J=0;$g=c[$a>>2]&65535;ah=c[Ya>>2]&65535;break}else if((J|0)==585){J=0;$g=c[D+11744+(te<<3)+4>>2]&65535;ah=c[D+11744+(te<<3)>>2]&65535;break}}else{$g=0;ah=0}}while(0);Pd=c[qb>>2]|0;b[Pd+(ue<<2)>>1]=ah;b[Pd+(ue<<2)+2>>1]=$g;b[Pd+($c<<2)>>1]=ah;b[Pd+($c<<2)+2>>1]=$g;Pd=c[D+11808+(te<<2)>>2]&255;a[(c[yb>>2]|0)+ed|0]=Pd;a[(c[yb>>2]|0)+wd|0]=Pd;do{if((c[Sa>>2]|0)==0){if((c[Y>>2]|0)!=3){bh=0;ch=0;break}Pd=c[cb>>2]|0;if((Pd|0)==3){if(xd){J=632}else{J=633}}else if((Pd|0)==0){J=632}else{J=633}if((J|0)==632){J=0;bh=c[ib>>2]&65535;ch=c[fb>>2]&65535;break}else if((J|0)==633){J=0;bh=c[D+11776+(te<<3)+4>>2]&65535;ch=c[D+11776+(te<<3)>>2]&65535;break}}else{bh=0;ch=0}}while(0);Pd=c[zb>>2]|0;b[Pd+(ue<<2)>>1]=ch;b[Pd+(ue<<2)+2>>1]=bh;b[Pd+($c<<2)>>1]=ch;b[Pd+($c<<2)+2>>1]=bh;Pd=c[D+11816+(te<<2)>>2]&255;a[(c[Ab>>2]|0)+ed|0]=Pd;a[(c[Ab>>2]|0)+wd|0]=Pd;Pd=te+1|0;if((Pd|0)<2){wd=wd+2|0;te=Pd;ue=ue+se|0}else{break}}}}while(0);c[rb>>2]=(c[rb>>2]|0)+xe;se=xe>>c[sb>>2];c[tb>>2]=(c[tb>>2]|0)+se;c[ub>>2]=(c[ub>>2]|0)+se;YOa(D,c[Na>>2]|0);se=(c[xa>>2]|0)+1|0;c[xa>>2]=se;if((se|0)>=(c[Aa>>2]|0)){se=16>>>((c[(c[O>>2]|0)+800>>2]|0)>>>0);_Oa(D,ba(c[ya>>2]>>md,se)|0,se);dPa(D);c[xa>>2]=0;se=(c[ya>>2]|0)+we|0;c[ya>>2]=se;if((se|0)>=(c[Q>>2]|0)){J=589;break}$Oa(D)}se=c[Ba>>2]|0;if(!((se|0)==-1)){ve=se;continue}c[Ba>>2]=0;se=c[1719029]|0;dh=c[pa>>2]|0;ue=c[sa>>2]|0;eh=0;u:while(1){te=ue;while(1){wd=dh+(te>>>3)|0;Pd=(fe(d[wd]|d[wd+1|0]<<8|d[wd+2|0]<<16|d[wd+3|0]<<24|0)|0)<<(te&7)>>>23;wd=b[se+(Pd<<2)>>1]|0;Wc=b[se+(Pd<<2)+2>>1]|0;Pd=Wc<<16>>16;if(Wc<<16>>16<0){Wc=te+9|0;ad=dh+(Wc>>>3)|0;Ie=((fe(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)<<(Wc&7)>>>((Pd+32|0)>>>0))+wd|0;fh=b[se+(Ie<<2)+2>>1]|0;gh=Wc;hh=b[se+(Ie<<2)>>1]|0}else{fh=Pd;gh=te;hh=wd}ih=fh+gh|0;c[sa>>2]=ih;if((hh|0)<0){J=614;break j}if((hh|0)<=32){break u}if((hh|0)==33){break}else if((hh|0)==35){J=618;break j}else{te=ih}}te=eh+33|0;c[Ba>>2]=te;ue=ih;eh=te}ue=hh+eh|0;c[Ba>>2]=ue;if((ue|0)==0){ve=0;continue}se=c[Y>>2]|0;if((se|0)==1){J=623;break}c[Sa>>2]=0;TGb(nb|0,-1|0,48)|0;te=c[N>>2]|0;c[cb>>2]=(te|0)==3?0:3;if((se|0)==2){c[bb>>2]=1;c[$a>>2]=0;c[Ya>>2]=0;TGb(Ra|0,0,16)|0;c[mb>>2]=te&1^1;ve=ue;continue}else{c[Ya>>2]=c[Wa>>2];c[$a>>2]=c[Za>>2];c[fb>>2]=c[db>>2];c[ib>>2]=c[gb>>2];ve=ue;continue}}v:do{if((J|0)==350){J=0;yDb(c[O>>2]|0,16,1991656,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==356){J=0;ve=c[ya>>2]|0;yDb(c[O>>2]|0,16,1988160,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ve,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==358){J=0;ve=c[ya>>2]|0;yDb(c[O>>2]|0,16,1983712,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ve,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==361){J=0;ve=c[ya>>2]|0;yDb(c[O>>2]|0,16,1980952,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ve,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==405){J=0;ve=c[ya>>2]|0;yDb(c[O>>2]|0,16,1962304,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ve,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==408){J=0;ve=c[ya>>2]|0;yDb(c[O>>2]|0,16,1962304,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ve,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==459){J=0;yDb(c[O>>2]|0,16,1975744,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==472){J=0;ve=c[ya>>2]|0;yDb(c[O>>2]|0,16,1973632,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ve,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==478){J=0;ve=c[xa>>2]|0;we=c[ya>>2]|0;yDb(c[O>>2]|0,16,1970936,(Uc=i,i=i+24|0,c[Uc>>2]=We,c[Uc+8>>2]=ve,c[Uc+16>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==509){J=0;we=c[ya>>2]|0;yDb(c[O>>2]|0,16,1962304,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==512){J=0;we=c[ya>>2]|0;yDb(c[O>>2]|0,16,1962304,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==558){J=0;we=c[ya>>2]|0;yDb(c[O>>2]|0,16,1962304,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==565){J=0;we=c[ya>>2]|0;yDb(c[O>>2]|0,16,1962304,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==589){J=0;we=c[sa>>2]|0;ve=c[na>>2]|0;xe=ve-we|0;do{if((c[Oa>>2]|0)==2){if((c[Y>>2]|0)!=1){jh=0;break}if((c[Vc+840>>2]|0)!=0){jh=0;break}if((c[Vc+844>>2]|0)!=5){jh=0;break}if((c[Ia>>2]|0)!=2){jh=0;break}if((c[ua>>2]|0)!=1){jh=0;break}if((c[Ga>>2]|0)!=0){jh=0;break}jh=(c[V>>2]|0)==0}else{jh=0}}while(0);ue=jh&1;do{if((xe|0)<32|jh){kh=ue}else{te=(c[pa>>2]|0)+(((-we&7)+we|0)>>>3)|0;if(((fe(d[te]|d[te+1|0]<<8|d[te+2|0]<<16|d[te+3|0]<<24|0)|0)&-256|0)!=101591808){kh=ue;break}yDb(Vc,48,2017704,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;kh=1}}while(0);do{if((xe|0)<0){lh=c[pa>>2]|0;mh=c[sa>>2]|0;nh=32-xe|0}else{if((ve|0)==(we|0)){oh=c[sa>>2]|0;break v}ue=c[pa>>2]|0;te=c[sa>>2]|0;se=ue+(te>>>3)|0;wd=(fe(d[se]|d[se+1|0]<<8|d[se+2|0]<<16|d[se+3|0]<<24|0)|0)<<(te&7);se=32-xe|0;if((wd>>>(((xe|0)>23?9:se)>>>0)|0)!=0&(kh|0)==0){lh=ue;mh=te;nh=se;break}if((c[Vc+696>>2]&262146|0)!=0&(xe|0)>8){lh=ue;mh=te;nh=se}else{oh=te;break v}}}while(0);we=lh+(mh>>>3)|0;ve=(fe(d[we]|d[we+1|0]<<8|d[we+2|0]<<16|d[we+3|0]<<24|0)|0)<<(mh&7);yDb(Vc,16,2013624,(Uc=i,i=i+16|0,c[Uc>>2]=xe,c[Uc+8>>2]=ve>>>(((xe|0)>23?9:nh)>>>0),Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==614){J=0;yDb(c[O>>2]|0,16,2009456,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==618){J=0;if((eh|0)==0){ve=dh+(ih>>>3)|0;if(((fe(d[ve]|d[ve+1|0]<<8|d[ve+2|0]<<16|d[ve+3|0]<<24|0)|0)&-131072>>>((ih&7)>>>0)|0)==0){oh=ih;break}}yDb(c[O>>2]|0,16,1999104,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==623){J=0;ve=c[ya>>2]|0;yDb(c[O>>2]|0,16,1994912,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ve,Uc)|0);i=Uc;ee=-1;break h}}while(0);if(((c[na>>2]|0)-oh|0)<0){ee=-1094995529;break}oe=Pc+((oh-1|0)/8|0)|0}Lkb(wa,c[ma>>2]|0,c[la>>2]|0,(c[xa>>2]|0)-1|0,c[ya>>2]|0,112);Xc=Oc;Yc=be;Zc=257;_c=oe;break b}}while(0);if((c[ga>>2]&8|0)!=0){fd=ee;J=641;break a}Vc=c[ma>>2]|0;if(!((Vc|0)>-1)){Xc=Oc;Yc=be;Zc=257;_c=Pc;break b}md=c[la>>2]|0;if(!((md|0)>-1)){Xc=Oc;Yc=be;Zc=257;_c=Pc;break b}Lkb(wa,Vc,md,c[xa>>2]|0,c[ya>>2]|0,14);Xc=Oc;Yc=be;Zc=257;_c=Pc}}}while(0);c[z>>2]=-1;ph=f1a(_c,E,z)|0;Sc=c[z>>2]|0;if(Sc>>>0>511>>>0){J=3;break}else{Mc=Zc;Nc=Yc;Oc=Xc;Pc=ph;Qc=Sc}}if((J|0)==3){if((Yc|0)==0){I=ph;J=4;break}else{qh=ph;break}}else if((J|0)==59){yDb(fa,16,2218520,(Uc=i,i=i+16|0,c[Uc>>2]=Ld,c[Uc+8>>2]=Md,Uc)|0);i=Uc;fd=-1094995529;i=m;return fd|0}else if((J|0)==115){yDb(fa,16,2209168,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;fd=Od;i=m;return fd|0}else if((J|0)==249){yDb(c[O>>2]|0,16,2138872,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;fd=-1094995529;i=m;return fd|0}else if((J|0)==251){yDb(c[O>>2]|0,16,2132624,(Uc=i,i=i+16|0,c[Uc>>2]=Wd,c[Uc+8>>2]=Xd,Uc)|0);i=Uc;fd=-1;i=m;return fd|0}else if((J|0)==288){yDb(ce,16,1957448,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;fd=-1;i=m;return fd|0}else if((J|0)==299){yDb(fa,16,2120392,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;fd=-1094995529;i=m;return fd|0}else if((J|0)==303){yDb(0,0,2114272,(Uc=i,i=i+24|0,c[Uc>>2]=2100096,c[Uc+8>>2]=2093488,c[Uc+16>>2]=1708,Uc)|0);i=Uc;Cd();return 0}else if((J|0)==454){yDb(0,0,2114272,(Uc=i,i=i+24|0,c[Uc>>2]=1978224,c[Uc+8>>2]=2093488,c[Uc+16>>2]=960,Uc)|0);i=Uc;Cd();return 0}else if((J|0)==641){i=m;return fd|0}}}while(0);do{if((J|0)==4){ce=c[A>>2]|0;Xd=ce;if((c[ce+14672>>2]|0)==0){qh=I;break}Wd=ce+9856|0;if((c[Wd>>2]|0)==0){qh=I;break}Od=c[ce+4>>2]|0;Md=c[Od+712>>2]|0;do{if((Md|0)!=0){if((re[c[Md+32>>2]&4095](Od)|0)>=0){break}yDb(f,16,1921560,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc}}while(0);if((c[ce+14240>>2]|0)!=0){qh=I;break}if((c[ce+14760>>2]|0)!=0){qh=I;break}Mkb(ce+14424|0);SOa(Xd);do{if((c[ce+9992>>2]|0)==3){J=13}else{if((c[ce+13944>>2]|0)!=0){J=13;break}if((c[f+816>>2]&1|0)!=0){Od=ce+108|0;c[Od>>2]=(c[Od>>2]|0)+1}Od=ce+9848|0;Md=c[Od>>2]|0;if((Md|0)==0){break}fa=MCb(h,Md|0)|0;if((fa|0)<0){fd=fa;i=m;return fd|0}else{VOa(Xd,c[Od>>2]|0,h);WOa(Xd,h,c[Od>>2]|0,1)|0;break}}}while(0);do{if((J|0)==13){ce=MCb(h,c[Wd>>2]|0)|0;if((ce|0)<0){fd=ce;i=m;return fd|0}else{VOa(Xd,c[Wd>>2]|0,h);WOa(Xd,h,c[Wd>>2]|0,1)|0;break}}}while(0);if((c[B+9848>>2]|0)==0){if((c[B+13944>>2]|0)==0){qh=I;break}}c[j>>2]=1;qh=I}}while(0);c[B+9992>>2]=0;do{if((c[f+696>>2]&8|0)!=0){if((c[B+14456>>2]|0)==0){break}else{fd=-1094995529}i=m;return fd|0}}while(0);f=qh-k-(c[B+13752>>2]|0)|0;fd=(f|0)<0?0:f;i=m;return fd|0}function GMa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=c[1439777]|0;h=a+14128|0;i=c[h>>2]|0;j=c[a+14120>>2]|0;a=j+(i>>>3)|0;k=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>23;a=b[g+(k<<2)>>1]|0;l=b[g+(k<<2)+2>>1]|0;k=l<<16>>16;if(l<<16>>16<0){l=i+9|0;m=j+(l>>>3)|0;n=((fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(l&7)>>>((k+32|0)>>>0))+a|0;o=b[g+(n<<2)+2>>1]|0;p=l;q=b[g+(n<<2)>>1]|0}else{o=k;p=i;q=a}a=o+p|0;c[h>>2]=a;if((q|0)==0){r=f;return r|0}if((q|0)<0){r=65535;return r|0}p=d[j+(a>>>3)|0]|0;o=a+1|0;c[h>>2]=o;i=e-1|0;if((i|0)==0){s=q}else{k=j+(o>>>3)|0;j=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(o&7)>>>((33-e|0)>>>0);c[h>>2]=a+e;s=(j|q-1<<i)+1|0}i=28-e|0;r=((p&128>>>((a&7)>>>0)|0)==0?s:-s|0)+f<<i>>i;return r|0}function HMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;if((e|0)==0){e=c[1889813]|0;g=a+8|0;h=c[g>>2]|0;j=c[a>>2]|0;k=j+(h>>>3)|0;l=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(h&7)>>>23;k=b[e+(l<<2)>>1]|0;m=b[e+(l<<2)+2>>1]|0;l=m<<16>>16;if(m<<16>>16<0){m=h+9|0;n=j+(m>>>3)|0;o=((fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(m&7)>>>((l+32|0)>>>0))+k|0;p=b[e+(o<<2)+2>>1]|0;q=m;r=b[e+(o<<2)>>1]|0}else{p=l;q=h;r=k}k=p+q|0;c[g>>2]=k;s=r;t=k;u=j}else{j=c[1889819]|0;k=a+8|0;r=c[k>>2]|0;g=c[a>>2]|0;q=g+(r>>>3)|0;p=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>23;q=b[j+(p<<2)>>1]|0;h=b[j+(p<<2)+2>>1]|0;p=h<<16>>16;if(h<<16>>16<0){h=r+9|0;l=g+(h>>>3)|0;o=((fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>((p+32|0)>>>0))+q|0;v=b[j+(o<<2)+2>>1]|0;w=h;x=b[j+(o<<2)>>1]|0}else{v=p;w=r;x=q}q=v+w|0;c[k>>2]=q;s=x;t=q;u=g}if((s|0)<0){yDb(0,16,1959648,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;y=65535;i=f;return y|0}if((s|0)==0){y=0;i=f;return y|0}g=u+(t>>>3)|0;u=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(t&7);g=(u^-2147483648)>>31;c[a+8>>2]=t+s;y=((g^u)>>>((32-s|0)>>>0)^g)-g|0;i=f;return y|0}function IMa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;k=e+14128|0;l=e+14120|0;m=(g|0)==0;n=e+4|0;a:do{if((h|0)==0){o=c[k>>2]|0;p=c[l>>2]|0;if(m){q=0;r=o;do{s=a[(d[1075976+q|0]|0)+(e+11184)|0]|0;t=p+(r>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(r&7)>>>24;r=r+8|0;c[k>>2]=r;if((u|0)==0){break a}b[f+((s&255)<<1)>>1]=u;q=q+1|0;}while((q|0)<64);i=j;return}else{q=0;r=o;do{u=d[(d[1075976+q|0]|0)+(e+11184)|0]|0;s=p+(r>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>24;r=r+8|0;c[k>>2]=r;if((t|0)==0){break a}s=t&65535;b[f+(u<<1)>>1]=s;b[g+(u<<1)>>1]=s;q=q+1|0;}while((q|0)<64);i=j;return}}else{if(m){q=0;do{r=d[(d[1075976+q|0]|0)+(e+11184)|0]|0;p=c[k>>2]|0;o=(c[l>>2]|0)+(p>>>3)|0;s=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(p&7)>>>24;c[k>>2]=p+8;if((s|0)==0){break a}if((q|0)!=0|(s|0)==8){v=s&65535}else{yDb(c[n>>2]|0,48,1942256,(w=i,i=i+8|0,c[w>>2]=s,w)|0);i=w;v=8}b[f+(r<<1)>>1]=v;q=q+1|0;}while((q|0)<64);i=j;return}else{q=0;do{r=d[(d[1075976+q|0]|0)+(e+11184)|0]|0;s=c[k>>2]|0;p=(c[l>>2]|0)+(s>>>3)|0;o=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(s&7)>>>24;c[k>>2]=s+8;if((o|0)==0){break a}if((q|0)!=0|(o|0)==8){x=o&65535}else{yDb(c[n>>2]|0,48,1942256,(w=i,i=i+8|0,c[w>>2]=o,w)|0);i=w;x=8}b[f+(r<<1)>>1]=x;b[g+(r<<1)>>1]=x;q=q+1|0;}while((q|0)<64);i=j;return}}}while(0);yDb(c[n>>2]|0,16,1944688,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;i=j;return}function JMa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;do{if((c[b+48>>2]|0)==2){if((c[b+12>>2]|0)<=2800){e=13;break}f=b+12480|0;g=(c[f>>2]&127)+257|0;h=b+784|0;K_(h);i=g>>>16;j=h|0;h=c[j>>2]|0;k=b+788|0;l=c[k>>2]|0;if((l|0)>16){m=l-16|0;n=h<<16|i}else{o=fe(i>>>((16-l|0)>>>0)|h<<l|0)|0;h=b+796|0;p=c[h>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;m=l+16|0;n=i}c[j>>2]=n;c[k>>2]=m;i=g&65535;if((m|0)>16){q=m-16|0;r=n<<16|i}else{g=fe(i>>>((16-m|0)>>>0)|n<<m|0)|0;l=b+796|0;h=c[l>>2]|0;x=g;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;q=m+16|0;r=i}c[j>>2]=r;c[k>>2]=q;i=c[f>>2]>>7;if((q|0)>3){s=q-3|0;t=r<<3|i}else{f=fe(i>>>((3-q|0)>>>0)|r<<q|0)|0;l=b+796|0;h=c[l>>2]|0;x=f;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;s=q+29|0;t=i}c[j>>2]=t;c[k>>2]=s;u=t;v=s}else{e=13}}while(0);if((e|0)==13){e=(c[b+12480>>2]|0)+257|0;s=b+784|0;K_(s);t=e>>16;q=s|0;s=c[q>>2]|0;r=b+788|0;m=c[r>>2]|0;if((m|0)>16){w=m-16|0;y=s<<16|t}else{n=fe(t>>>((16-m|0)>>>0)|s<<m|0)|0;s=b+796|0;k=c[s>>2]|0;x=n;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;w=m+16|0;y=t}c[q>>2]=y;c[r>>2]=w;t=e&65535;if((w|0)>16){z=w-16|0;A=y<<16|t}else{e=fe(t>>>((16-w|0)>>>0)|y<<w|0)|0;y=b+796|0;m=c[y>>2]|0;x=e;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;z=w+16|0;A=t}c[q>>2]=A;c[r>>2]=z;u=A;v=z}z=b+784|0;A=c[b+9960>>2]|0;if((c[b+14192>>2]|0)==0){if((v|0)>5){B=v-5|0;C=u<<5|A}else{r=fe(A>>>((5-v|0)>>>0)|u<<v|0)|0;q=b+796|0;t=c[q>>2]|0;x=r;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;B=v+27|0;C=A}c[z>>2]=C;c[b+788>>2]=B;D=C;E=B}else{B=d[904944+A|0]|0;if((v|0)>5){F=v-5|0;G=u<<5|B}else{A=fe(B>>>((5-v|0)>>>0)|u<<v|0)|0;u=b+796|0;C=c[u>>2]|0;x=A;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;F=v+27|0;G=B}c[z>>2]=G;c[b+788>>2]=F;D=G;E=F}F=z|0;z=b+788|0;if((E|0)>1){H=E-1|0;I=D<<1;c[F>>2]=I;c[z>>2]=H;return}else{G=fe(D<<E|0)|0;D=b+796|0;b=c[D>>2]|0;x=G;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;H=E+31|0;I=0;c[F>>2]=I;c[z>>2]=H;return}}function KMa(b,e){b=b|0;e=e|0;var f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0;e=i;f=b+4|0;h=c[f>>2]|0;j=+(c[h+224>>2]|0)/+(c[h+228>>2]|0);h=j==0.0;if((c[b+7708>>2]|0)==0){k=b+784|0;l=k;m=k|0;n=b+788|0}else{k=b+10012|0;o=c[k>>2]|0;p=c[1180208+(o<<3)>>2]|0;q=c[1180212+(o<<3)>>2]|0;o=b+784|0;K_(o);r=o|0;s=c[r>>2]|0;t=b+788|0;u=c[t>>2]|0;if((u|0)>16){v=u-16|0;w=s<<16}else{y=fe(s<<u|0)|0;s=b+796|0;z=c[s>>2]|0;x=y;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;v=u+16|0;w=0}c[r>>2]=w;c[t>>2]=v;if((v|0)>16){A=v-16|0}else{u=fe(435>>>((16-v|0)>>>0)|w<<v|0)|0;w=b+796|0;s=c[w>>2]|0;x=u;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;A=v+16|0}c[r>>2]=435;c[t>>2]=A;v=b+8|0;w=c[v>>2]&4095;if((A|0)>12){B=A-12|0;C=w|1781760}else{s=fe(w>>>((12-A|0)>>>0)|435<<A|0)|0;u=b+796|0;z=c[u>>2]|0;x=s;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;B=A+20|0;C=w}c[r>>2]=C;c[t>>2]=B;w=b+12|0;A=c[w>>2]&4095;if((B|0)>12){D=B-12|0;E=A|C<<12}else{u=fe(A>>>((12-B|0)>>>0)|C<<B|0)|0;C=b+796|0;z=c[C>>2]|0;x=u;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;D=B+20|0;E=A}c[r>>2]=E;c[t>>2]=D;A=b+48|0;G=h?1.0:j;h=b+13928|0;if((c[A>>2]|0)==1){B=1;j=1.0e10;while(1){H=G-1.0/+g[1179816+(B<<2)>>2];if(H<0.0){I=-0.0-H}else{I=H}if(I<j){c[h>>2]=B;J=I}else{J=j}C=B+1|0;if((C|0)<15){B=C;j=J}else{break}}}else{B=1;J=1.0e10;while(1){if((B|0)<2){K=1.0/+g[1179816+(B<<2)>>2]}else{K=+(c[1178440+(B<<3)>>2]|0)/+(c[1178444+(B<<3)>>2]|0)*+(c[w>>2]|0)/+(c[v>>2]|0)}j=G-K;if(j<0.0){L=-0.0-j}else{L=j}if(L<J){c[h>>2]=B;M=L}else{M=J}C=B+1|0;if((C|0)<15){B=C;J=M}else{break}}}B=c[h>>2]|0;if((D|0)>4){N=D-4|0;O=B|E<<4}else{h=fe(B>>>((4-D|0)>>>0)|E<<D|0)|0;E=b+796|0;C=c[E>>2]|0;x=h;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;N=D+28|0;O=B}c[r>>2]=O;c[t>>2]=N;B=c[k>>2]|0;if((N|0)>4){P=N-4|0;Q=B|O<<4}else{k=fe(B>>>((4-N|0)>>>0)|O<<N|0)|0;O=b+796|0;D=c[O>>2]|0;x=k;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[O>>2]=(c[O>>2]|0)+4;P=N+28|0;Q=B}c[r>>2]=Q;c[t>>2]=P;B=c[f>>2]|0;N=c[B+540>>2]|0;do{if((N|0)==0){R=262143}else{O=(N+399|0)/400|0;if(!(O>>>0>262143>>>0)){R=O;break}R=(c[A>>2]|0)==1?262143:O}}while(0);N=c[B+524>>2]|0;if((N|0)==0){S=(((c[b+24>>2]|0)*20|0|0)/575964|0)<<13}else{S=N}N=S+16383|0;S=R&262143;if((P|0)>18){T=P-18|0;U=S|Q<<18}else{B=fe(S>>>((18-P|0)>>>0)|Q<<P|0)|0;Q=b+796|0;O=c[Q>>2]|0;x=B;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;T=P+14|0;U=S}c[r>>2]=U;c[t>>2]=T;if((T|0)>1){V=T-1|0;W=U<<1|1}else{S=fe(1>>>((1-T|0)>>>0)|U<<T|0)|0;U=b+796|0;P=c[U>>2]|0;x=S;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[U>>2]=(c[U>>2]|0)+4;V=T+31|0;W=1}c[r>>2]=W;c[t>>2]=V;T=N>>>14&1023;if((V|0)>10){X=V-10|0;Y=W<<10|T}else{U=fe(T>>>((10-V|0)>>>0)|W<<V|0)|0;W=b+796|0;P=c[W>>2]|0;x=U;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;X=V+22|0;Y=T}c[r>>2]=Y;c[t>>2]=X;do{if((c[v>>2]|0)<769){if((c[w>>2]|0)>=577){Z=0;break}T=ba(c[b+120>>2]|0,c[b+116>>2]|0)|0;if((T|0)>=397){Z=0;break}if((ba(T,p)|0)>(q*9900|0|0)|(p|0)>(q*30|0|0)){Z=0;break}T=c[(c[f>>2]|0)+276>>2]|0;if(!((T|0)!=0&(T|0)<128&N>>>0<344064>>>0&R>>>0<4641>>>0)){Z=0;break}Z=(c[A>>2]|0)==1|0}else{Z=0}}while(0);if((X|0)>1){_=X-1|0;$=Z|Y<<1}else{T=fe(Z>>>((1-X|0)>>>0)|Y<<X|0)|0;Y=b+796|0;V=c[Y>>2]|0;x=T;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[Y>>2]=(c[Y>>2]|0)+4;_=X+31|0;$=Z}c[r>>2]=$;c[t>>2]=_;jPa(o,c[(c[f>>2]|0)+300>>2]|0);jPa(o,c[(c[f>>2]|0)+304>>2]|0);if((c[A>>2]|0)==2){K_(o);A=c[r>>2]|0;_=c[t>>2]|0;if((_|0)>16){aa=_-16|0;ca=A<<16}else{$=fe(A<<_|0)|0;A=b+796|0;Z=c[A>>2]|0;x=$;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;aa=_+16|0;ca=0}c[r>>2]=ca;c[t>>2]=aa;if((aa|0)>16){da=aa-16|0}else{_=fe(437>>>((16-aa|0)>>>0)|ca<<aa|0)|0;ca=b+796|0;A=c[ca>>2]|0;x=_;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[ca>>2]=(c[ca>>2]|0)+4;da=aa+16|0}c[r>>2]=437;c[t>>2]=da;if((da|0)>4){ea=da-4|0;fa=6993}else{aa=fe(1>>>((4-da|0)>>>0)|437<<da|0)|0;ca=b+796|0;A=c[ca>>2]|0;x=aa;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[ca>>2]=(c[ca>>2]|0)+4;ea=da+28|0;fa=1}c[r>>2]=fa;c[t>>2]=ea;da=c[f>>2]|0;ca=(c[da+840>>2]|0)==0|0;if((ea|0)>1){ga=ea-1|0;ha=ca|fa<<1;ia=da}else{da=fe(ca>>>((1-ea|0)>>>0)|fa<<ea|0)|0;fa=b+796|0;A=c[fa>>2]|0;x=da;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[fa>>2]=(c[fa>>2]|0)+4;ga=ea+31|0;ha=ca;ia=c[f>>2]|0}c[r>>2]=ha;c[t>>2]=ga;ca=c[ia+840>>2]|0;if((ga|0)>3){ja=ga-3|0;ka=ca|ha<<3;la=ia}else{ia=fe(ca>>>((3-ga|0)>>>0)|ha<<ga|0)|0;ha=b+796|0;ea=c[ha>>2]|0;x=ia;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;c[ha>>2]=(c[ha>>2]|0)+4;ja=ga+29|0;ka=ca;la=c[f>>2]|0}c[r>>2]=ka;c[t>>2]=ja;ca=c[la+844>>2]|0;if((ja|0)>4){ma=ja-4|0;na=ca|ka<<4}else{la=fe(ca>>>((4-ja|0)>>>0)|ka<<ja|0)|0;ka=b+796|0;ga=c[ka>>2]|0;x=la;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[ka>>2]=(c[ka>>2]|0)+4;ma=ja+28|0;na=ca}c[r>>2]=na;c[t>>2]=ma;ca=c[b+14152>>2]|0;if((ma|0)>1){oa=ma-1|0;pa=ca|na<<1}else{ja=fe(ca>>>((1-ma|0)>>>0)|na<<ma|0)|0;na=b+796|0;ka=c[na>>2]|0;x=ja;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;c[na>>2]=(c[na>>2]|0)+4;oa=ma+31|0;pa=ca}c[r>>2]=pa;c[t>>2]=oa;ca=c[b+14212>>2]|0;if((oa|0)>2){qa=oa-2|0;ra=ca|pa<<2}else{ma=fe(ca>>>((2-oa|0)>>>0)|pa<<oa|0)|0;pa=b+796|0;na=c[pa>>2]|0;x=ma;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[pa>>2]=(c[pa>>2]|0)+4;qa=oa+30|0;ra=ca}c[r>>2]=ra;c[t>>2]=qa;ca=c[v>>2]>>12;if((qa|0)>2){sa=qa-2|0;ta=ca|ra<<2}else{v=fe(ca>>>((2-qa|0)>>>0)|ra<<qa|0)|0;ra=b+796|0;oa=c[ra>>2]|0;x=v;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;c[ra>>2]=(c[ra>>2]|0)+4;sa=qa+30|0;ta=ca}c[r>>2]=ta;c[t>>2]=sa;ca=c[w>>2]>>12;if((sa|0)>2){ua=sa-2|0;va=ca|ta<<2}else{w=fe(ca>>>((2-sa|0)>>>0)|ta<<sa|0)|0;ta=b+796|0;qa=c[ta>>2]|0;x=w;a[qa]=x;x=x>>8;a[qa+1|0]=x;x=x>>8;a[qa+2|0]=x;x=x>>8;a[qa+3|0]=x;c[ta>>2]=(c[ta>>2]|0)+4;ua=sa+30|0;va=ca}c[r>>2]=va;c[t>>2]=ua;ca=R>>>18;if((ua|0)>12){wa=ua-12|0;xa=va<<12|ca}else{R=fe(ca>>>((12-ua|0)>>>0)|va<<ua|0)|0;va=b+796|0;sa=c[va>>2]|0;x=R;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;c[va>>2]=(c[va>>2]|0)+4;wa=ua+20|0;xa=ca}c[r>>2]=xa;c[t>>2]=wa;if((wa|0)>1){ya=wa-1|0;za=xa<<1|1}else{ca=fe(1>>>((1-wa|0)>>>0)|xa<<wa|0)|0;xa=b+796|0;ua=c[xa>>2]|0;x=ca;a[ua]=x;x=x>>8;a[ua+1|0]=x;x=x>>8;a[ua+2|0]=x;x=x>>8;a[ua+3|0]=x;c[xa>>2]=(c[xa>>2]|0)+4;ya=wa+31|0;za=1}c[r>>2]=za;c[t>>2]=ya;wa=N>>>24;if((ya|0)>8){Aa=ya-8|0;Ba=za<<8|wa}else{N=fe(wa>>>((8-ya|0)>>>0)|za<<ya|0)|0;za=b+796|0;xa=c[za>>2]|0;x=N;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[za>>2]=(c[za>>2]|0)+4;Aa=ya+24|0;Ba=wa}c[r>>2]=Ba;c[t>>2]=Aa;wa=c[b+13944>>2]|0;if((Aa|0)>1){Ca=Aa-1|0;Da=wa|Ba<<1}else{ya=fe(wa>>>((1-Aa|0)>>>0)|Ba<<Aa|0)|0;Ba=b+796|0;za=c[Ba>>2]|0;x=ya;a[za]=x;x=x>>8;a[za+1|0]=x;x=x>>8;a[za+2|0]=x;x=x>>8;a[za+3|0]=x;c[Ba>>2]=(c[Ba>>2]|0)+4;Ca=Aa+31|0;Da=wa}c[r>>2]=Da;c[t>>2]=Ca;wa=(c[b+10016>>2]|0)-1|0;if((Ca|0)>2){Ea=Ca-2|0;Fa=wa|Da<<2}else{Aa=fe(wa>>>((2-Ca|0)>>>0)|Da<<Ca|0)|0;Da=b+796|0;Ba=c[Da>>2]|0;x=Aa;a[Ba]=x;x=x>>8;a[Ba+1|0]=x;x=x>>8;a[Ba+2|0]=x;x=x>>8;a[Ba+3|0]=x;c[Da>>2]=(c[Da>>2]|0)+4;Ea=Ca+30|0;Fa=wa}c[r>>2]=Fa;c[t>>2]=Ea;wa=(c[b+10020>>2]|0)-1|0;if((Ea|0)>5){Ga=Ea-5|0;Ha=wa|Fa<<5}else{Ca=fe(wa>>>((5-Ea|0)>>>0)|Fa<<Ea|0)|0;Fa=b+796|0;Da=c[Fa>>2]|0;x=Ca;a[Da]=x;x=x>>8;a[Da+1|0]=x;x=x>>8;a[Da+2|0]=x;x=x>>8;a[Da+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;Ga=Ea+27|0;Ha=wa}c[r>>2]=Ha;c[t>>2]=Ga}K_(o);Ga=c[r>>2]|0;Ha=c[t>>2]|0;if((Ha|0)>16){Ia=Ha-16|0;Ja=Ga<<16}else{wa=fe(Ga<<Ha|0)|0;Ga=b+796|0;Ea=c[Ga>>2]|0;x=wa;a[Ea]=x;x=x>>8;a[Ea+1|0]=x;x=x>>8;a[Ea+2|0]=x;x=x>>8;a[Ea+3|0]=x;c[Ga>>2]=(c[Ga>>2]|0)+4;Ia=Ha+16|0;Ja=0}c[r>>2]=Ja;c[t>>2]=Ia;if((Ia|0)>16){Ka=Ia-16|0}else{Ha=fe(440>>>((16-Ia|0)>>>0)|Ja<<Ia|0)|0;Ja=b+796|0;Ga=c[Ja>>2]|0;x=Ha;a[Ga]=x;x=x>>8;a[Ga+1|0]=x;x=x>>8;a[Ga+2|0]=x;x=x>>8;a[Ga+3|0]=x;c[Ja>>2]=(c[Ja>>2]|0)+4;Ka=Ia+16|0}c[r>>2]=440;c[t>>2]=Ka;Ia=b+14244|0;Ja=c[Ia>>2]|0;if((Ka|0)>1){La=Ka-1|0;Ma=Ja|880;Na=Ja}else{Ga=fe(Ja>>>((1-Ka|0)>>>0)|440<<Ka|0)|0;Ha=b+796|0;Ea=c[Ha>>2]|0;x=Ga;a[Ea]=x;x=x>>8;a[Ea+1|0]=x;x=x>>8;a[Ea+2|0]=x;x=x>>8;a[Ea+3|0]=x;c[Ha>>2]=(c[Ha>>2]|0)+4;La=Ka+31|0;Ma=Ja;Na=c[Ia>>2]|0}c[r>>2]=Ma;c[t>>2]=La;Ia=(((q|0)/2|0)+p|0)/(q|0)|0;q=c[(c[b+9856>>2]|0)+160>>2]|0;p=(c[f>>2]|0)+616|0;f=YGb(c[p>>2]|0,c[p+4>>2]|0,q,(q|0)<0|0?-1:0)|0;p=F;c[b+14140>>2]=q;if((Na|0)!=(c[b+14264>>2]&1|0)){yDb(0,0,2254616,(Oa=i,i=i+24|0,c[Oa>>2]=2024848,c[Oa+8>>2]=2185312,c[Oa+16>>2]=343,Oa)|0);i=Oa;Cd()}if((Na|0)==0){Pa=p;Qa=f;Ra=Ma;Sa=La}else{La=YFb(f,Ia)|0;Pa=(La|0)<0|0?-1:0;Qa=La;Ra=c[r>>2]|0;Sa=c[t>>2]|0}La=hHb(Qa,Pa,Ia*3600|0,0)|0;f=iHb(La,F,24,0)|0;La=f;if((Sa|0)>5){Ta=Sa-5|0;Ua=La|Ra<<5}else{f=fe(La>>>((5-Sa|0)>>>0)|Ra<<Sa|0)|0;Ra=b+796|0;Ma=c[Ra>>2]|0;x=f;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;c[Ra>>2]=(c[Ra>>2]|0)+4;Ta=Sa+27|0;Ua=La}c[r>>2]=Ua;c[t>>2]=Ta;La=hHb(Qa,Pa,Ia*60|0,0)|0;Sa=iHb(La,F,60,0)|0;La=Sa;if((Ta|0)>6){Va=Ta-6|0;Wa=La|Ua<<6}else{Sa=fe(La>>>((6-Ta|0)>>>0)|Ua<<Ta|0)|0;Ua=b+796|0;Ra=c[Ua>>2]|0;x=Sa;a[Ra]=x;x=x>>8;a[Ra+1|0]=x;x=x>>8;a[Ra+2|0]=x;x=x>>8;a[Ra+3|0]=x;c[Ua>>2]=(c[Ua>>2]|0)+4;Va=Ta+26|0;Wa=La}c[r>>2]=Wa;c[t>>2]=Va;if((Va|0)>1){Xa=Va-1|0;Ya=Wa<<1|1}else{La=fe(1>>>((1-Va|0)>>>0)|Wa<<Va|0)|0;Wa=b+796|0;Ta=c[Wa>>2]|0;x=La;a[Ta]=x;x=x>>8;a[Ta+1|0]=x;x=x>>8;a[Ta+2|0]=x;x=x>>8;a[Ta+3|0]=x;c[Wa>>2]=(c[Wa>>2]|0)+4;Xa=Va+31|0;Ya=1}c[r>>2]=Ya;c[t>>2]=Xa;Va=Ia;Ia=0;Wa=hHb(Qa,Pa,Va,Ia)|0;Ta=iHb(Wa,F,60,0)|0;Wa=Ta;if((Xa|0)>6){Za=Xa-6|0;_a=Wa|Ya<<6}else{Ta=fe(Wa>>>((6-Xa|0)>>>0)|Ya<<Xa|0)|0;Ya=b+796|0;La=c[Ya>>2]|0;x=Ta;a[La]=x;x=x>>8;a[La+1|0]=x;x=x>>8;a[La+2|0]=x;x=x>>8;a[La+3|0]=x;c[Ya>>2]=(c[Ya>>2]|0)+4;Za=Xa+26|0;_a=Wa}c[r>>2]=_a;c[t>>2]=Za;Wa=iHb(Qa,Pa,Va,Ia)|0;Ia=Wa;if((Za|0)>6){$a=Za-6|0;ab=Ia|_a<<6}else{Wa=fe(Ia>>>((6-Za|0)>>>0)|_a<<Za|0)|0;_a=b+796|0;Va=c[_a>>2]|0;x=Wa;a[Va]=x;x=x>>8;a[Va+1|0]=x;x=x>>8;a[Va+2|0]=x;x=x>>8;a[Va+3|0]=x;c[_a>>2]=(c[_a>>2]|0)+4;$a=Za+26|0;ab=Ia}c[r>>2]=ab;c[t>>2]=$a;Ia=(c[b+60>>2]|0)>>>31;if(($a|0)>1){bb=$a-1|0;cb=Ia|ab<<1}else{Za=fe(Ia>>>((1-$a|0)>>>0)|ab<<$a|0)|0;ab=b+796|0;_a=c[ab>>2]|0;x=Za;a[_a]=x;x=x>>8;a[_a+1|0]=x;x=x>>8;a[_a+2|0]=x;x=x>>8;a[_a+3|0]=x;c[ab>>2]=(c[ab>>2]|0)+4;bb=$a+31|0;cb=Ia}c[r>>2]=cb;c[t>>2]=bb;if((bb|0)>1){db=bb-1|0;eb=cb<<1}else{Ia=fe(cb<<bb|0)|0;cb=b+796|0;$a=c[cb>>2]|0;x=Ia;a[$a]=x;x=x>>8;a[$a+1|0]=x;x=x>>8;a[$a+2|0]=x;x=x>>8;a[$a+3|0]=x;c[cb>>2]=(c[cb>>2]|0)+4;db=bb+31|0;eb=0}c[r>>2]=eb;c[t>>2]=db;l=o;m=r;n=t}K_(l);t=c[m>>2]|0;r=c[n>>2]|0;if((r|0)>16){fb=r-16|0;gb=t<<16}else{o=fe(t<<r|0)|0;t=b+796|0;db=c[t>>2]|0;x=o;a[db]=x;x=x>>8;a[db+1|0]=x;x=x>>8;a[db+2|0]=x;x=x>>8;a[db+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;fb=r+16|0;gb=0}c[m>>2]=gb;c[n>>2]=fb;if((fb|0)>16){hb=fb-16|0}else{r=fe(256>>>((16-fb|0)>>>0)|gb<<fb|0)|0;gb=b+796|0;t=c[gb>>2]|0;x=r;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[gb>>2]=(c[gb>>2]|0)+4;hb=fb+16|0}c[m>>2]=256;c[n>>2]=hb;fb=(c[b+108>>2]|0)-(c[b+14140>>2]|0)&1023;if((hb|0)>10){ib=hb-10|0;jb=fb|262144}else{gb=fe(fb>>>((10-hb|0)>>>0)|256<<hb|0)|0;t=b+796|0;r=c[t>>2]|0;x=gb;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;ib=hb+22|0;jb=fb}c[m>>2]=jb;c[n>>2]=ib;fb=b+9992|0;hb=c[fb>>2]|0;if((ib|0)>3){kb=ib-3|0;lb=jb<<3|hb;mb=c[b+796>>2]|0}else{t=fe(jb<<ib|hb>>>((3-ib|0)>>>0)|0)|0;jb=b+796|0;r=c[jb>>2]|0;x=t;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[jb>>2]|0)+4|0;c[jb>>2]=r;kb=ib+29|0;lb=hb;mb=r}c[m>>2]=lb;c[n>>2]=kb;r=c[b+792>>2]|0;hb=b+796|0;c[b+14148>>2]=r+((32-kb+(mb-r<<3)|0)/8|0);if((kb|0)>16){nb=kb-16|0;ob=lb<<16|65535;pb=mb}else{r=mb;x=fe(65535>>>((16-kb|0)>>>0)|lb<<kb|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[hb>>2]|0)+4|0;c[hb>>2]=r;nb=kb+16|0;ob=65535;pb=r}c[m>>2]=ob;c[n>>2]=nb;do{if(((c[fb>>2]|0)-2|0)>>>0<2>>>0){if((nb|0)>1){qb=nb-1|0;rb=ob<<1;sb=pb}else{r=pb;x=fe(ob<<nb|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[hb>>2]|0)+4|0;c[hb>>2]=r;qb=nb+31|0;rb=0;sb=r}c[m>>2]=rb;c[n>>2]=qb;r=b+48|0;do{if((c[r>>2]|0)==1){kb=c[b+11556>>2]|0;if((qb|0)>3){tb=qb-3|0;ub=rb<<3|kb;vb=sb;break}else{lb=sb;x=fe(rb<<qb|kb>>>((3-qb|0)>>>0)|0)|0;a[lb]=x;x=x>>8;a[lb+1|0]=x;x=x>>8;a[lb+2|0]=x;x=x>>8;a[lb+3|0]=x;lb=(c[hb>>2]|0)+4|0;c[hb>>2]=lb;tb=qb+29|0;ub=kb;vb=lb;break}}else{if((qb|0)>3){tb=qb-3|0;ub=rb<<3|7;vb=sb;break}else{lb=sb;x=fe(rb<<qb|7>>>((3-qb|0)>>>0)|0)|0;a[lb]=x;x=x>>8;a[lb+1|0]=x;x=x>>8;a[lb+2|0]=x;x=x>>8;a[lb+3|0]=x;lb=(c[hb>>2]|0)+4|0;c[hb>>2]=lb;tb=qb+29|0;ub=7;vb=lb;break}}}while(0);c[m>>2]=ub;c[n>>2]=tb;if((c[fb>>2]|0)!=3){wb=tb;xb=ub;yb=vb;break}if((tb|0)>1){zb=tb-1|0;Ab=ub<<1;Bb=vb}else{lb=vb;x=fe(ub<<tb|0)|0;a[lb]=x;x=x>>8;a[lb+1|0]=x;x=x>>8;a[lb+2|0]=x;x=x>>8;a[lb+3|0]=x;lb=(c[hb>>2]|0)+4|0;c[hb>>2]=lb;zb=tb+31|0;Ab=0;Bb=lb}c[m>>2]=Ab;c[n>>2]=zb;if((c[r>>2]|0)==1){lb=c[b+11560>>2]|0;if((zb|0)>3){Cb=zb-3|0;Db=Ab<<3|lb;Eb=Bb}else{kb=Bb;x=fe(Ab<<zb|lb>>>((3-zb|0)>>>0)|0)|0;a[kb]=x;x=x>>8;a[kb+1|0]=x;x=x>>8;a[kb+2|0]=x;x=x>>8;a[kb+3|0]=x;kb=(c[hb>>2]|0)+4|0;c[hb>>2]=kb;Cb=zb+29|0;Db=lb;Eb=kb}c[m>>2]=Db;c[n>>2]=Cb;wb=Cb;xb=Db;yb=Eb;break}else{if((zb|0)>3){Fb=zb-3|0;Gb=Ab<<3|7;Hb=Bb}else{kb=Bb;x=fe(Ab<<zb|7>>>((3-zb|0)>>>0)|0)|0;a[kb]=x;x=x>>8;a[kb+1|0]=x;x=x>>8;a[kb+2|0]=x;x=x>>8;a[kb+3|0]=x;kb=(c[hb>>2]|0)+4|0;c[hb>>2]=kb;Fb=zb+29|0;Gb=7;Hb=kb}c[m>>2]=Gb;c[n>>2]=Fb;wb=Fb;xb=Gb;yb=Hb;break}}else{wb=nb;xb=ob;yb=pb}}while(0);if((wb|0)>1){Ib=wb-1|0;Jb=xb<<1}else{pb=yb;x=fe(xb<<wb|0)|0;a[pb]=x;x=x>>8;a[pb+1|0]=x;x=x>>8;a[pb+2|0]=x;x=x>>8;a[pb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Ib=wb+31|0;Jb=0}c[m>>2]=Jb;c[n>>2]=Ib;Ib=b+14180|0;c[Ib>>2]=1;if((c[b+48>>2]|0)==2){K_(l);Jb=c[m>>2]|0;wb=c[n>>2]|0;if((wb|0)>16){Kb=wb-16|0;Lb=Jb<<16}else{pb=fe(Jb<<wb|0)|0;Jb=c[hb>>2]|0;x=pb;a[Jb]=x;x=x>>8;a[Jb+1|0]=x;x=x>>8;a[Jb+2|0]=x;x=x>>8;a[Jb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Kb=wb+16|0;Lb=0}c[m>>2]=Lb;c[n>>2]=Kb;if((Kb|0)>16){Mb=Kb-16|0}else{wb=fe(437>>>((16-Kb|0)>>>0)|Lb<<Kb|0)|0;Lb=c[hb>>2]|0;x=wb;a[Lb]=x;x=x>>8;a[Lb+1|0]=x;x=x>>8;a[Lb+2|0]=x;x=x>>8;a[Lb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Mb=Kb+16|0}c[m>>2]=437;c[n>>2]=Mb;if((Mb|0)>4){Nb=Mb-4|0;Ob=7e3}else{Kb=fe(8>>>((4-Mb|0)>>>0)|437<<Mb|0)|0;Lb=c[hb>>2]|0;x=Kb;a[Lb]=x;x=x>>8;a[Lb+1|0]=x;x=x>>8;a[Lb+2|0]=x;x=x>>8;a[Lb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Nb=Mb+28|0;Ob=8}c[m>>2]=Ob;c[n>>2]=Nb;do{if(((c[fb>>2]|0)-2|0)>>>0<2>>>0){Mb=b+11556|0;Lb=c[Mb>>2]|0;if((Nb|0)>4){Pb=Nb-4|0;Qb=Ob<<4|Lb;Rb=Lb}else{Kb=fe(Ob<<Nb|Lb>>>((4-Nb|0)>>>0)|0)|0;wb=c[hb>>2]|0;x=Kb;a[wb]=x;x=x>>8;a[wb+1|0]=x;x=x>>8;a[wb+2|0]=x;x=x>>8;a[wb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Pb=Nb+28|0;Qb=Lb;Rb=c[Mb>>2]|0}c[m>>2]=Qb;c[n>>2]=Pb;if((Pb|0)>4){Sb=Pb-4|0;Tb=Qb<<4|Rb;break}else{Mb=fe(Qb<<Pb|Rb>>>((4-Pb|0)>>>0)|0)|0;Lb=c[hb>>2]|0;x=Mb;a[Lb]=x;x=x>>8;a[Lb+1|0]=x;x=x>>8;a[Lb+2|0]=x;x=x>>8;a[Lb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Sb=Pb+28|0;Tb=Rb;break}}else{if((Nb|0)>8){Sb=Nb-8|0;Tb=Ob<<8|255;break}else{Lb=fe(Ob<<Nb|255>>>((8-Nb|0)>>>0)|0)|0;Mb=c[hb>>2]|0;x=Lb;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Sb=Nb+24|0;Tb=255;break}}}while(0);c[m>>2]=Tb;c[n>>2]=Sb;do{if((c[fb>>2]|0)==3){Nb=b+11560|0;Ob=c[Nb>>2]|0;if((Sb|0)>4){Ub=Sb-4|0;Vb=Tb<<4|Ob;Wb=Ob}else{Rb=fe(Ob>>>((4-Sb|0)>>>0)|Tb<<Sb|0)|0;Pb=c[hb>>2]|0;x=Rb;a[Pb]=x;x=x>>8;a[Pb+1|0]=x;x=x>>8;a[Pb+2|0]=x;x=x>>8;a[Pb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Ub=Sb+28|0;Vb=Ob;Wb=c[Nb>>2]|0}c[m>>2]=Vb;c[n>>2]=Ub;if((Ub|0)>4){Xb=Ub-4|0;Yb=Vb<<4|Wb;break}else{Nb=fe(Vb<<Ub|Wb>>>((4-Ub|0)>>>0)|0)|0;Ob=c[hb>>2]|0;x=Nb;a[Ob]=x;x=x>>8;a[Ob+1|0]=x;x=x>>8;a[Ob+2|0]=x;x=x>>8;a[Ob+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Xb=Ub+28|0;Yb=Wb;break}}else{if((Sb|0)>8){Xb=Sb-8|0;Yb=Tb<<8|255;break}else{Ob=fe(255>>>((8-Sb|0)>>>0)|Tb<<Sb|0)|0;Nb=c[hb>>2]|0;x=Ob;a[Nb]=x;x=x>>8;a[Nb+1|0]=x;x=x>>8;a[Nb+2|0]=x;x=x>>8;a[Nb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Xb=Sb+24|0;Yb=255;break}}}while(0);c[m>>2]=Yb;c[n>>2]=Xb;Sb=c[b+14176>>2]|0;if((Xb|0)>2){Zb=Xb-2|0;_b=Yb<<2|Sb}else{Tb=fe(Yb<<Xb|Sb>>>((2-Xb|0)>>>0)|0)|0;Yb=c[hb>>2]|0;x=Tb;a[Yb]=x;x=x>>8;a[Yb+1|0]=x;x=x>>8;a[Yb+2|0]=x;x=x>>8;a[Yb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Zb=Xb+30|0;_b=Sb}c[m>>2]=_b;c[n>>2]=Zb;if((c[b+14172>>2]|0)!=3){yDb(0,0,2254616,(Oa=i,i=i+24|0,c[Oa>>2]=2320776,c[Oa+8>>2]=2185312,c[Oa+16>>2]=448,Oa)|0);i=Oa;Cd()}if((Zb|0)>2){$b=Zb-2|0;ac=_b<<2|3}else{Oa=fe(_b<<Zb|3>>>((2-Zb|0)>>>0)|0)|0;_b=c[hb>>2]|0;x=Oa;a[_b]=x;x=x>>8;a[_b+1|0]=x;x=x>>8;a[_b+2|0]=x;x=x>>8;a[_b+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;$b=Zb+30|0;ac=3}c[m>>2]=ac;c[n>>2]=$b;Zb=b+14152|0;do{if((c[Zb>>2]|0)==0){_b=c[(c[b+9856>>2]|0)+300>>2]|0;if(($b|0)>1){bc=$b-1|0;cc=ac<<1|_b;break}else{Oa=fe(ac<<$b|_b>>>((1-$b|0)>>>0)|0)|0;Sb=c[hb>>2]|0;x=Oa;a[Sb]=x;x=x>>8;a[Sb+1|0]=x;x=x>>8;a[Sb+2|0]=x;x=x>>8;a[Sb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;bc=$b+31|0;cc=_b;break}}else{if(($b|0)>1){bc=$b-1|0;cc=ac<<1;break}else{_b=fe(ac<<$b|0)|0;Sb=c[hb>>2]|0;x=_b;a[Sb]=x;x=x>>8;a[Sb+1|0]=x;x=x>>8;a[Sb+2|0]=x;x=x>>8;a[Sb+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;bc=$b+31|0;cc=0;break}}}while(0);c[m>>2]=cc;c[n>>2]=bc;$b=c[Zb>>2]|0;c[Ib>>2]=$b;if((bc|0)>1){dc=bc-1|0;ec=cc<<1|$b}else{Ib=fe($b>>>((1-bc|0)>>>0)|cc<<bc|0)|0;cc=c[hb>>2]|0;x=Ib;a[cc]=x;x=x>>8;a[cc+1|0]=x;x=x>>8;a[cc+2|0]=x;x=x>>8;a[cc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;dc=bc+31|0;ec=$b}c[m>>2]=ec;c[n>>2]=dc;$b=c[b+14188>>2]|0;if((dc|0)>1){fc=dc-1|0;gc=ec<<1|$b}else{bc=fe(ec<<dc|$b>>>((1-dc|0)>>>0)|0)|0;ec=c[hb>>2]|0;x=bc;a[ec]=x;x=x>>8;a[ec+1|0]=x;x=x>>8;a[ec+2|0]=x;x=x>>8;a[ec+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;fc=dc+31|0;gc=$b}c[m>>2]=gc;c[n>>2]=fc;$b=c[b+14192>>2]|0;if((fc|0)>1){hc=fc-1|0;ic=gc<<1|$b}else{dc=fe(gc<<fc|$b>>>((1-fc|0)>>>0)|0)|0;gc=c[hb>>2]|0;x=dc;a[gc]=x;x=x>>8;a[gc+1|0]=x;x=x>>8;a[gc+2|0]=x;x=x>>8;a[gc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;hc=fc+31|0;ic=$b}c[m>>2]=ic;c[n>>2]=hc;$b=c[b+14196>>2]|0;if((hc|0)>1){jc=hc-1|0;kc=ic<<1|$b}else{fc=fe(ic<<hc|$b>>>((1-hc|0)>>>0)|0)|0;ic=c[hb>>2]|0;x=fc;a[ic]=x;x=x>>8;a[ic+1|0]=x;x=x>>8;a[ic+2|0]=x;x=x>>8;a[ic+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;jc=hc+31|0;kc=$b}c[m>>2]=kc;c[n>>2]=jc;$b=c[b+14200>>2]|0;if((jc|0)>1){lc=jc-1|0;mc=kc<<1|$b}else{hc=fe(kc<<jc|$b>>>((1-jc|0)>>>0)|0)|0;kc=c[hb>>2]|0;x=hc;a[kc]=x;x=x>>8;a[kc+1|0]=x;x=x>>8;a[kc+2|0]=x;x=x>>8;a[kc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;lc=jc+31|0;mc=$b}c[m>>2]=mc;c[n>>2]=lc;$b=c[b+14204>>2]|0;if((lc|0)>1){nc=lc-1|0;oc=mc<<1|$b}else{jc=fe(mc<<lc|$b>>>((1-lc|0)>>>0)|0)|0;mc=c[hb>>2]|0;x=jc;a[mc]=x;x=x>>8;a[mc+1|0]=x;x=x>>8;a[mc+2|0]=x;x=x>>8;a[mc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;nc=lc+31|0;oc=$b}c[m>>2]=oc;c[n>>2]=nc;$b=c[Zb>>2]|0;Zb=b+14224|0;c[Zb>>2]=$b;lc=(c[b+14212>>2]|0)==1?$b:0;if((nc|0)>1){pc=nc-1|0;qc=oc<<1|lc;rc=$b}else{$b=fe(lc>>>((1-nc|0)>>>0)|oc<<nc|0)|0;oc=c[hb>>2]|0;x=$b;a[oc]=x;x=x>>8;a[oc+1|0]=x;x=x>>8;a[oc+2|0]=x;x=x>>8;a[oc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;pc=nc+31|0;qc=lc;rc=c[Zb>>2]|0}c[m>>2]=qc;c[n>>2]=pc;if((pc|0)>1){sc=pc-1|0;tc=qc<<1|rc}else{Zb=fe(qc<<pc|rc>>>((1-pc|0)>>>0)|0)|0;qc=c[hb>>2]|0;x=Zb;a[qc]=x;x=x>>8;a[qc+1|0]=x;x=x>>8;a[qc+2|0]=x;x=x>>8;a[qc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;sc=pc+31|0;tc=rc}c[m>>2]=tc;c[n>>2]=sc;if((sc|0)>1){uc=sc-1|0;vc=tc<<1}else{rc=fe(tc<<sc|0)|0;tc=c[hb>>2]|0;x=rc;a[tc]=x;x=x>>8;a[tc+1|0]=x;x=x>>8;a[tc+2|0]=x;x=x>>8;a[tc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;uc=sc+31|0;vc=0}c[m>>2]=vc;c[n>>2]=uc}if((c[b+14248>>2]|0)!=0){K_(l);uc=c[m>>2]|0;vc=c[n>>2]|0;if((vc|0)>16){wc=vc-16|0;xc=uc<<16}else{sc=fe(uc<<vc|0)|0;uc=c[hb>>2]|0;x=sc;a[uc]=x;x=x>>8;a[uc+1|0]=x;x=x>>8;a[uc+2|0]=x;x=x>>8;a[uc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;wc=vc+16|0;xc=0}c[m>>2]=xc;c[n>>2]=wc;if((wc|0)>16){yc=wc-16|0}else{vc=fe(434>>>((16-wc|0)>>>0)|xc<<wc|0)|0;xc=c[hb>>2]|0;x=vc;a[xc]=x;x=x>>8;a[xc+1|0]=x;x=x>>8;a[xc+2|0]=x;x=x>>8;a[xc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;yc=wc+16|0}c[m>>2]=434;c[n>>2]=yc;wc=0;xc=434;vc=yc;while(1){yc=d[429192+wc|0]|0;if((vc|0)>8){zc=vc-8|0;Ac=xc<<8|yc}else{uc=fe(yc>>>((8-vc|0)>>>0)|xc<<vc|0)|0;sc=c[hb>>2]|0;x=uc;a[sc]=x;x=x>>8;a[sc+1|0]=x;x=x>>8;a[sc+2|0]=x;x=x>>8;a[sc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;zc=vc+24|0;Ac=yc}c[m>>2]=Ac;c[n>>2]=zc;yc=wc+1|0;if(yc>>>0<14>>>0){wc=yc;xc=Ac;vc=zc}else{break}}}zc=VCb(c[b+9856>>2]|0,2)|0;if((zc|0)==0){Bc=b+12480|0;c[Bc>>2]=0;JMa(b);i=e;return}vc=c[c[zc+4>>2]>>2]|0;if((vc|0)==2){Cc=4}else if((vc|0)==0){Cc=8}else if((vc|0)==5){Cc=35}else if((vc|0)==1){Cc=3}else{Bc=b+12480|0;c[Bc>>2]=0;JMa(b);i=e;return}K_(l);l=c[m>>2]|0;vc=c[n>>2]|0;if((vc|0)>16){Dc=vc-16|0;Ec=l<<16}else{zc=fe(l<<vc|0)|0;l=c[hb>>2]|0;x=zc;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Dc=vc+16|0;Ec=0}c[m>>2]=Ec;c[n>>2]=Dc;if((Dc|0)>16){Fc=Dc-16|0}else{vc=fe(434>>>((16-Dc|0)>>>0)|Ec<<Dc|0)|0;Ec=c[hb>>2]|0;x=vc;a[Ec]=x;x=x>>8;a[Ec+1|0]=x;x=x>>8;a[Ec+2|0]=x;x=x>>8;a[Ec+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Fc=Dc+16|0}c[m>>2]=434;c[n>>2]=Fc;if((Fc|0)>8){Gc=Fc-8|0;Hc=111178}else{Dc=fe(74>>>((8-Fc|0)>>>0)|434<<Fc|0)|0;Ec=c[hb>>2]|0;x=Dc;a[Ec]=x;x=x>>8;a[Ec+1|0]=x;x=x>>8;a[Ec+2|0]=x;x=x>>8;a[Ec+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Gc=Fc+24|0;Hc=74}c[m>>2]=Hc;c[n>>2]=Gc;if((Gc|0)>8){Ic=Gc-8|0;Jc=Hc<<8|80}else{Fc=fe(80>>>((8-Gc|0)>>>0)|Hc<<Gc|0)|0;Hc=c[hb>>2]|0;x=Fc;a[Hc]=x;x=x>>8;a[Hc+1|0]=x;x=x>>8;a[Hc+2|0]=x;x=x>>8;a[Hc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Ic=Gc+24|0;Jc=80}c[m>>2]=Jc;c[n>>2]=Ic;if((Ic|0)>8){Kc=Ic-8|0;Lc=Jc<<8|51}else{Gc=fe(51>>>((8-Ic|0)>>>0)|Jc<<Ic|0)|0;Jc=c[hb>>2]|0;x=Gc;a[Jc]=x;x=x>>8;a[Jc+1|0]=x;x=x>>8;a[Jc+2|0]=x;x=x>>8;a[Jc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Kc=Ic+24|0;Lc=51}c[m>>2]=Lc;c[n>>2]=Kc;if((Kc|0)>8){Mc=Kc-8|0;Nc=Lc<<8|68}else{Ic=fe(68>>>((8-Kc|0)>>>0)|Lc<<Kc|0)|0;Lc=c[hb>>2]|0;x=Ic;a[Lc]=x;x=x>>8;a[Lc+1|0]=x;x=x>>8;a[Lc+2|0]=x;x=x>>8;a[Lc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Mc=Kc+24|0;Nc=68}c[m>>2]=Nc;c[n>>2]=Mc;if((Mc|0)>8){Oc=Mc-8|0;Pc=Nc<<8|3}else{Kc=fe(3>>>((8-Mc|0)>>>0)|Nc<<Mc|0)|0;Nc=c[hb>>2]|0;x=Kc;a[Nc]=x;x=x>>8;a[Nc+1|0]=x;x=x>>8;a[Nc+2|0]=x;x=x>>8;a[Nc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Oc=Mc+24|0;Pc=3}c[m>>2]=Pc;c[n>>2]=Oc;if((Oc|0)>1){Qc=Oc-1|0;Rc=Pc<<1|1}else{Mc=fe(1>>>((1-Oc|0)>>>0)|Pc<<Oc|0)|0;Pc=c[hb>>2]|0;x=Mc;a[Pc]=x;x=x>>8;a[Pc+1|0]=x;x=x>>8;a[Pc+2|0]=x;x=x>>8;a[Pc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Qc=Oc+31|0;Rc=1}c[m>>2]=Rc;c[n>>2]=Qc;if((Qc|0)>7){Sc=Qc-7|0;Tc=Rc<<7|Cc}else{Oc=fe(Cc>>>((7-Qc|0)>>>0)|Rc<<Qc|0)|0;Rc=c[hb>>2]|0;x=Oc;a[Rc]=x;x=x>>8;a[Rc+1|0]=x;x=x>>8;a[Rc+2|0]=x;x=x>>8;a[Rc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Sc=Qc+25|0;Tc=Cc}c[m>>2]=Tc;c[n>>2]=Sc;if((Sc|0)>8){Uc=Sc-8|0;Vc=Tc<<8|4}else{Cc=fe(4>>>((8-Sc|0)>>>0)|Tc<<Sc|0)|0;Tc=c[hb>>2]|0;x=Cc;a[Tc]=x;x=x>>8;a[Tc+1|0]=x;x=x>>8;a[Tc+2|0]=x;x=x>>8;a[Tc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Uc=Sc+24|0;Vc=4}c[m>>2]=Vc;c[n>>2]=Uc;if((Uc|0)>8){Wc=Uc-8|0;Xc=Vc<<8|255}else{Sc=fe(255>>>((8-Uc|0)>>>0)|Vc<<Uc|0)|0;Vc=c[hb>>2]|0;x=Sc;a[Vc]=x;x=x>>8;a[Vc+1|0]=x;x=x>>8;a[Vc+2|0]=x;x=x>>8;a[Vc+3|0]=x;c[hb>>2]=(c[hb>>2]|0)+4;Wc=Uc+24|0;Xc=255}c[m>>2]=Xc;c[n>>2]=Wc;Bc=b+12480|0;c[Bc>>2]=0;JMa(b);i=e;return}function LMa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0;k=i;l=c[f+12476>>2]|0;m=c[f+12480>>2]|0;n=(l|0)==(c[f+13704>>2]|0);if((c[f+14212>>2]|0)==1){if(n){o=(m|0)==(c[f+13708>>2]|0)}else{o=0}p=(c[f+180>>2]>>31)+32&-32;q=(c[f+184>>2]|0)>-1?p|16:p;p=(c[f+188>>2]|0)>-1?q|8:q;q=(c[f+192>>2]|0)>-1?p|4:p;p=(c[f+196>>2]|0)>-1?q|2:q;do{if((c[f+200>>2]|0)>-1){r=p|1;s=0}else{q=(p|0)==0;if(o|q^1){r=p;s=q;break}if((c[f+11740>>2]|0)!=0){r=p;s=q;break}if((l|0)==((c[f+116>>2]|0)-1|0)){if((m|0)==((c[f+812>>2]|0)-1|0)){r=p;s=q;break}if((c[f+48>>2]|0)!=1){r=p;s=q;break}}t=c[f+9992>>2]|0;u=(t|0)==2;if(u){if((j|h|0)!=0){r=p;s=q;break}}else{if((t|0)!=3){r=p;s=q;break}t=c[f+11736>>2]|0;if((t|0)!=(c[f+14144>>2]|0)){r=p;s=q;break}if((t&1|0)==0){v=0}else{v=(c[f+11748>>2]|0)-(c[f+11828>>2]|0)|(c[f+11744>>2]|0)-(c[f+11824>>2]|0)}if((t&2|0)==0){w=0}else{w=(c[f+11780>>2]|0)-(c[f+11844>>2]|0)|(c[f+11776>>2]|0)-(c[f+11840>>2]|0)}if((w|v|0)!=0){r=p;s=q;break}}q=f+12484|0;c[q>>2]=(c[q>>2]|0)+1;q=f+9960|0;c[q>>2]=(c[q>>2]|0)-(c[f+9984>>2]|0);q=f+13692|0;c[q>>2]=(c[q>>2]|0)+1;q=f+13696|0;c[q>>2]=(c[q>>2]|0)+1;q=f+13700|0;c[q>>2]=(c[q>>2]|0)+1;if(!u){i=k;return}TGb(f+11824|0,0,16)|0;i=k;return}}while(0);p=f+12484|0;v=c[p>>2]|0;if(o){if((v|0)!=0){yDb(0,0,2254616,(y=i,i=i+24|0,c[y>>2]=2028488,c[y+8>>2]=2185312,c[y+16>>2]=724,y)|0);i=y;Cd()}o=f+784|0;if((l|0)>32){w=f+788|0;u=f+796|0;q=l;t=c[o>>2]|0;z=c[w>>2]|0;while(1){if((z|0)>11){A=z-11|0;B=t<<11|8}else{C=fe(8>>>((11-z|0)>>>0)|t<<z|0)|0;D=c[u>>2]|0;x=C;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;A=z+21|0;B=8}c[o>>2]=B;c[w>>2]=A;D=q-33|0;if((D|0)>32){q=D;t=B;z=A}else{break}}E=((l-33|0)>>>0)%33|0;F=B;G=A}else{E=l;F=c[o>>2]|0;G=c[f+788>>2]|0}A=d[1180129+(E<<1)|0]|0;B=d[1180128+(E<<1)|0]|0;if((G|0)>(A|0)){H=G;I=F<<A|B}else{E=fe(B>>>((A-G|0)>>>0)|F<<G|0)|0;F=f+796|0;z=c[F>>2]|0;x=E;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[F>>2]=(c[F>>2]|0)+4;H=G+32|0;I=B}B=H-A|0;c[o>>2]=I;c[f+788>>2]=B;J=I;K=B}else{B=f+784|0;if((v|0)>32){I=f+788|0;o=f+796|0;A=v;H=c[B>>2]|0;G=c[I>>2]|0;while(1){if((G|0)>11){L=G-11|0;M=H<<11|8}else{F=fe(8>>>((11-G|0)>>>0)|H<<G|0)|0;z=c[o>>2]|0;x=F;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;L=G+21|0;M=8}c[B>>2]=M;c[I>>2]=L;z=A-33|0;if((z|0)>32){A=z;H=M;G=L}else{break}}N=((v-33|0)>>>0)%33|0;O=M;P=L}else{N=v;O=c[B>>2]|0;P=c[f+788>>2]|0}v=d[1180129+(N<<1)|0]|0;L=d[1180128+(N<<1)|0]|0;if((P|0)>(v|0)){Q=P;R=O<<v|L}else{N=fe(L>>>((v-P|0)>>>0)|O<<P|0)|0;O=f+796|0;M=c[O>>2]|0;x=N;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[O>>2]=(c[O>>2]|0)+4;Q=P+32|0;R=L}L=Q-v|0;c[B>>2]=R;c[f+788>>2]=L;J=R;K=L}L=c[f+9992>>2]|0;do{if((L|0)==1){R=f+9984|0;B=f+784|0;v=f+788|0;do{if((c[R>>2]|0)==0|s){if((K|0)>1){S=K-1|0;T=J<<1|1}else{Q=fe(1>>>((1-K|0)>>>0)|J<<K|0)|0;P=f+796|0;O=c[P>>2]|0;x=Q;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[P>>2]=(c[P>>2]|0)+4;S=K+31|0;T=1}c[B>>2]=T;c[v>>2]=S;if((c[f+14180>>2]|0)==0){P=c[f+14236>>2]|0;if((S|0)>1){U=S-1|0;V=P|T<<1}else{O=fe(P>>>((1-S|0)>>>0)|T<<S|0)|0;Q=f+796|0;M=c[Q>>2]|0;x=O;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;U=S+31|0;V=P}c[B>>2]=V;c[v>>2]=U;W=U}else{W=S}P=f+9960|0;c[P>>2]=(c[P>>2]|0)-(c[R>>2]|0);X=W}else{if((K|0)>2){Y=K-2|0;Z=J<<2|1}else{P=fe(1>>>((2-K|0)>>>0)|J<<K|0)|0;Q=f+796|0;M=c[Q>>2]|0;x=P;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;Y=K+30|0;Z=1}c[B>>2]=Z;c[v>>2]=Y;if((c[f+14180>>2]|0)==0){Q=c[f+14236>>2]|0;if((Y|0)>1){_=Y-1|0;$=Q|Z<<1}else{M=fe(Q>>>((1-Y|0)>>>0)|Z<<Y|0)|0;P=f+796|0;O=c[P>>2]|0;x=M;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[P>>2]=(c[P>>2]|0)+4;_=Y+31|0;$=Q}c[B>>2]=$;c[v>>2]=_;aa=$;ba=_}else{aa=Z;ba=Y}Q=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((ba|0)>5){ca=ba-5|0;da=Q|aa<<5}else{P=fe(Q>>>((5-ba|0)>>>0)|aa<<ba|0)|0;O=f+796|0;M=c[O>>2]|0;x=P;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[O>>2]=(c[O>>2]|0)+4;ca=ba+27|0;da=Q}c[B>>2]=da;c[v>>2]=ca;X=ca;break}else{O=d[904944+Q|0]|0;if((ba|0)>5){ea=ba-5|0;fa=O|aa<<5}else{Q=fe(O>>>((5-ba|0)>>>0)|aa<<ba|0)|0;M=f+796|0;P=c[M>>2]|0;x=Q;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[M>>2]=(c[M>>2]|0)+4;ea=ba+27|0;fa=O}c[B>>2]=fa;c[v>>2]=ea;X=ea;break}}}while(0);B=f+796|0;R=((c[B>>2]|0)-(c[f+792>>2]|0)<<3)+(32-X)|0;O=f+13700|0;M=c[O>>2]|0;c[O>>2]=R;O=f+13696|0;c[O>>2]=(c[O>>2]|0)-M+R;R=f+13680|0;c[R>>2]=(c[R>>2]|0)+1;ga=X;ha=f+12488|0;ia=v;ja=B;ka=r}else{B=f+12488|0;if((c[B>>2]|0)!=0){R=f+9984|0;M=f+784|0;O=f+788|0;do{if((c[R>>2]|0)==0|s){if((K|0)>5){la=K-5|0;ma=J<<5|3}else{P=fe(3>>>((5-K|0)>>>0)|J<<K|0)|0;Q=f+796|0;N=c[Q>>2]|0;x=P;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;la=K+27|0;ma=3}c[M>>2]=ma;c[O>>2]=la;if((c[f+14180>>2]|0)==0){Q=c[f+14236>>2]|0;if((la|0)>1){na=la-1|0;oa=Q|ma<<1}else{N=fe(Q>>>((1-la|0)>>>0)|ma<<la|0)|0;P=f+796|0;G=c[P>>2]|0;x=N;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[P>>2]=(c[P>>2]|0)+4;na=la+31|0;oa=Q}c[M>>2]=oa;c[O>>2]=na;pa=na}else{pa=la}Q=f+9960|0;c[Q>>2]=(c[Q>>2]|0)-(c[R>>2]|0);qa=pa}else{if((K|0)>6){ra=K-6|0;sa=J<<6|1}else{Q=fe(1>>>((6-K|0)>>>0)|J<<K|0)|0;P=f+796|0;G=c[P>>2]|0;x=Q;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[P>>2]=(c[P>>2]|0)+4;ra=K+26|0;sa=1}c[M>>2]=sa;c[O>>2]=ra;if((c[f+14180>>2]|0)==0){P=c[f+14236>>2]|0;if((ra|0)>1){ta=ra-1|0;ua=P|sa<<1}else{G=fe(P>>>((1-ra|0)>>>0)|sa<<ra|0)|0;Q=f+796|0;N=c[Q>>2]|0;x=G;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;ta=ra+31|0;ua=P}c[M>>2]=ua;c[O>>2]=ta;va=ua;wa=ta}else{va=sa;wa=ra}P=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((wa|0)>5){xa=wa-5|0;ya=P|va<<5}else{Q=fe(P>>>((5-wa|0)>>>0)|va<<wa|0)|0;N=f+796|0;G=c[N>>2]|0;x=Q;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;xa=wa+27|0;ya=P}c[M>>2]=ya;c[O>>2]=xa;qa=xa;break}else{N=d[904944+P|0]|0;if((wa|0)>5){za=wa-5|0;Aa=N|va<<5}else{P=fe(N>>>((5-wa|0)>>>0)|va<<wa|0)|0;G=f+796|0;Q=c[G>>2]|0;x=P;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;za=wa+27|0;Aa=N}c[M>>2]=Aa;c[O>>2]=za;qa=za;break}}}while(0);M=f+796|0;R=((c[M>>2]|0)-(c[f+792>>2]|0)<<3)+(32-qa)|0;v=f+13700|0;N=c[v>>2]|0;c[v>>2]=R;v=f+13696|0;c[v>>2]=(c[v>>2]|0)-N+R;R=f+13680|0;c[R>>2]=(c[R>>2]|0)+1;TGb(f+11824|0,0,32)|0;ga=qa;ha=B;ia=O;ja=M;ka=r;break}M=(c[f+11740>>2]|0)==0;R=(r|0)!=0;if((L|0)==2){if(M){do{if(R){N=(c[f+9984>>2]|0)!=0;v=f+784|0;G=f+788|0;if((j|h|0)==0){do{if(N){if((K|0)>5){Ba=K-5|0;Ca=J<<5|1}else{Q=fe(1>>>((5-K|0)>>>0)|J<<K|0)|0;P=f+796|0;H=c[P>>2]|0;x=Q;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[P>>2]=(c[P>>2]|0)+4;Ba=K+27|0;Ca=1}c[v>>2]=Ca;c[G>>2]=Ba;if((c[f+14180>>2]|0)==0){P=c[f+14236>>2]|0;if((Ba|0)>1){Da=Ba-1|0;Ea=P|Ca<<1}else{H=fe(P>>>((1-Ba|0)>>>0)|Ca<<Ba|0)|0;Q=f+796|0;A=c[Q>>2]|0;x=H;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;Da=Ba+31|0;Ea=P}c[v>>2]=Ea;c[G>>2]=Da;Fa=Ea;Ga=Da}else{Fa=Ca;Ga=Ba}P=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Ga|0)>5){Ha=Ga-5|0;Ia=P|Fa<<5}else{Q=fe(P>>>((5-Ga|0)>>>0)|Fa<<Ga|0)|0;A=f+796|0;H=c[A>>2]|0;x=Q;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Ha=Ga+27|0;Ia=P}c[v>>2]=Ia;c[G>>2]=Ha;Ja=Ha;break}else{A=d[904944+P|0]|0;if((Ga|0)>5){Ka=Ga-5|0;La=A|Fa<<5}else{P=fe(A>>>((5-Ga|0)>>>0)|Fa<<Ga|0)|0;H=f+796|0;Q=c[H>>2]|0;x=P;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;Ka=Ga+27|0;La=A}c[v>>2]=La;c[G>>2]=Ka;Ja=Ka;break}}else{if((K|0)>2){Ma=K-2|0;Na=J<<2|1}else{A=fe(1>>>((2-K|0)>>>0)|J<<K|0)|0;H=f+796|0;Q=c[H>>2]|0;x=A;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;Ma=K+30|0;Na=1}c[v>>2]=Na;c[G>>2]=Ma;if((c[f+14180>>2]|0)!=0){Ja=Ma;break}H=c[f+14236>>2]|0;if((Ma|0)>1){Oa=Ma-1|0;Pa=H|Na<<1}else{Q=fe(H>>>((1-Ma|0)>>>0)|Na<<Ma|0)|0;A=f+796|0;P=c[A>>2]|0;x=Q;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Oa=Ma+31|0;Pa=H}c[v>>2]=Pa;c[G>>2]=Oa;Ja=Oa}}while(0);H=c[f+796>>2]|0;A=(H-(c[f+792>>2]|0)<<3)+(32-Ja)|0;P=f+13700|0;Q=c[P>>2]|0;c[P>>2]=A;P=f+13696|0;c[P>>2]=(c[P>>2]|0)-Q+A;Qa=Ja;Ra=H;Sa=f+11824|0;Ta=f+11828|0;break}do{if(N){if((K|0)>5){Ua=K-5|0;Va=J<<5|2}else{H=fe(2>>>((5-K|0)>>>0)|J<<K|0)|0;A=f+796|0;Q=c[A>>2]|0;x=H;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Ua=K+27|0;Va=2}c[v>>2]=Va;c[G>>2]=Ua;if((c[f+14180>>2]|0)==0){if((Ua|0)>2){Wa=Ua-2|0;Xa=Va<<2|2}else{A=fe(2>>>((2-Ua|0)>>>0)|Va<<Ua|0)|0;Q=f+796|0;H=c[Q>>2]|0;x=A;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;Wa=Ua+30|0;Xa=2}c[v>>2]=Xa;c[G>>2]=Wa;Q=c[f+14236>>2]|0;if((Wa|0)>1){Ya=Wa-1|0;Za=Q|Xa<<1}else{H=fe(Q>>>((1-Wa|0)>>>0)|Xa<<Wa|0)|0;A=f+796|0;P=c[A>>2]|0;x=H;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Ya=Wa+31|0;Za=Q}c[v>>2]=Za;c[G>>2]=Ya;_a=Za;$a=Ya}else{_a=Va;$a=Ua}Q=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if(($a|0)>5){ab=$a-5|0;bb=Q|_a<<5}else{A=fe(Q>>>((5-$a|0)>>>0)|_a<<$a|0)|0;P=f+796|0;H=c[P>>2]|0;x=A;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[P>>2]=(c[P>>2]|0)+4;ab=$a+27|0;bb=Q}c[v>>2]=bb;c[G>>2]=ab;cb=ab;break}else{P=d[904944+Q|0]|0;if(($a|0)>5){db=$a-5|0;eb=P|_a<<5}else{Q=fe(P>>>((5-$a|0)>>>0)|_a<<$a|0)|0;H=f+796|0;A=c[H>>2]|0;x=Q;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;db=$a+27|0;eb=P}c[v>>2]=eb;c[G>>2]=db;cb=db;break}}else{if((K|0)>1){fb=K-1|0;gb=J<<1|1}else{P=fe(1>>>((1-K|0)>>>0)|J<<K|0)|0;H=f+796|0;A=c[H>>2]|0;x=P;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;fb=K+31|0;gb=1}c[v>>2]=gb;c[G>>2]=fb;if((c[f+14180>>2]|0)!=0){cb=fb;break}if((fb|0)>2){hb=fb-2|0;ib=gb<<2|2}else{H=fe(2>>>((2-fb|0)>>>0)|gb<<fb|0)|0;A=f+796|0;P=c[A>>2]|0;x=H;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;hb=fb+30|0;ib=2}c[v>>2]=ib;c[G>>2]=hb;A=c[f+14236>>2]|0;if((hb|0)>1){jb=hb-1|0;kb=A|ib<<1}else{P=fe(A>>>((1-hb|0)>>>0)|ib<<hb|0)|0;H=f+796|0;Q=c[H>>2]|0;x=P;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;jb=hb+31|0;kb=A}c[v>>2]=kb;c[G>>2]=jb;cb=jb}}while(0);v=f+792|0;N=f+796|0;A=((c[N>>2]|0)-(c[v>>2]|0)<<3)+(32-cb)|0;H=f+13700|0;Q=c[H>>2]|0;c[H>>2]=A;P=f+13696|0;c[P>>2]=(c[P>>2]|0)-Q+A;A=f+11824|0;Q=f+11556|0;PMa(f,h-(c[A>>2]|0)|0,c[Q>>2]|0);P=f+11828|0;PMa(f,j-(c[P>>2]|0)|0,c[Q>>2]|0);Q=c[G>>2]|0;I=c[N>>2]|0;N=(I-(c[v>>2]|0)<<3)+(32-Q)|0;v=c[H>>2]|0;c[H>>2]=N;H=f+13664|0;c[H>>2]=(c[H>>2]|0)-v+N;Qa=Q;Ra=I;Sa=A;Ta=P}else{P=f+784|0;A=f+788|0;if((K|0)>3){lb=K-3|0;mb=J<<3|1}else{I=fe(1>>>((3-K|0)>>>0)|J<<K|0)|0;Q=f+796|0;N=c[Q>>2]|0;x=I;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;lb=K+29|0;mb=1}c[P>>2]=mb;c[A>>2]=lb;if((c[f+14180>>2]|0)==0){if((lb|0)>2){nb=lb-2|0;ob=mb<<2|2}else{Q=fe(2>>>((2-lb|0)>>>0)|mb<<lb|0)|0;N=f+796|0;I=c[N>>2]|0;x=Q;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;nb=lb+30|0;ob=2}c[P>>2]=ob;c[A>>2]=nb;pb=nb}else{pb=lb}P=f+792|0;N=f+796|0;I=((c[N>>2]|0)-(c[P>>2]|0)<<3)+(32-pb)|0;Q=f+13700|0;v=c[Q>>2]|0;c[Q>>2]=I;H=f+13696|0;c[H>>2]=(c[H>>2]|0)-v+I;I=f+11824|0;v=f+11556|0;PMa(f,h-(c[I>>2]|0)|0,c[v>>2]|0);H=f+11828|0;PMa(f,j-(c[H>>2]|0)|0,c[v>>2]|0);v=f+9960|0;c[v>>2]=(c[v>>2]|0)-(c[f+9984>>2]|0);v=c[A>>2]|0;A=c[N>>2]|0;N=(A-(c[P>>2]|0)<<3)+(32-v)|0;P=c[Q>>2]|0;c[Q>>2]=N;Q=f+13664|0;c[Q>>2]=(c[Q>>2]|0)-P+N;Qa=v;Ra=A;Sa=I;Ta=H}}while(0);c[Sa>>2]=h;c[f+11832>>2]=h;c[Ta>>2]=j;c[f+11836>>2]=j;qb=Qa;rb=Ra}else{do{if(R){O=f+784|0;H=f+788|0;if((c[f+9984>>2]|0)==0){if((K|0)>1){sb=K-1|0;tb=J<<1|1}else{I=fe(1>>>((1-K|0)>>>0)|J<<K|0)|0;A=f+796|0;v=c[A>>2]|0;x=I;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;sb=K+31|0;tb=1}c[O>>2]=tb;c[H>>2]=sb;if((c[f+14180>>2]|0)!=0){ub=sb;vb=tb;break}if((sb|0)>2){wb=sb-2|0;xb=tb<<2|1}else{A=fe(1>>>((2-sb|0)>>>0)|tb<<sb|0)|0;v=f+796|0;I=c[v>>2]|0;x=A;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;wb=sb+30|0;xb=1}c[O>>2]=xb;c[H>>2]=wb;v=c[f+14236>>2]|0;if((wb|0)>1){yb=wb-1|0;zb=v|xb<<1}else{I=fe(v>>>((1-wb|0)>>>0)|xb<<wb|0)|0;A=f+796|0;N=c[A>>2]|0;x=I;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;yb=wb+31|0;zb=v}c[O>>2]=zb;c[H>>2]=yb;ub=yb;vb=zb;break}if((K|0)>5){Ab=K-5|0;Bb=J<<5|2}else{v=fe(2>>>((5-K|0)>>>0)|J<<K|0)|0;A=f+796|0;N=c[A>>2]|0;x=v;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Ab=K+27|0;Bb=2}c[O>>2]=Bb;c[H>>2]=Ab;if((c[f+14180>>2]|0)==0){if((Ab|0)>2){Cb=Ab-2|0;Db=Bb<<2|1}else{A=fe(1>>>((2-Ab|0)>>>0)|Bb<<Ab|0)|0;N=f+796|0;v=c[N>>2]|0;x=A;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;Cb=Ab+30|0;Db=1}c[O>>2]=Db;c[H>>2]=Cb;N=c[f+14236>>2]|0;if((Cb|0)>1){Eb=Cb-1|0;Fb=N|Db<<1}else{v=fe(N>>>((1-Cb|0)>>>0)|Db<<Cb|0)|0;A=f+796|0;I=c[A>>2]|0;x=v;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Eb=Cb+31|0;Fb=N}c[O>>2]=Fb;c[H>>2]=Eb;Gb=Fb;Hb=Eb}else{Gb=Bb;Hb=Ab}N=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Hb|0)>5){Ib=Hb-5|0;Jb=N|Gb<<5}else{A=fe(N>>>((5-Hb|0)>>>0)|Gb<<Hb|0)|0;I=f+796|0;v=c[I>>2]|0;x=A;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Ib=Hb+27|0;Jb=N}c[O>>2]=Jb;c[H>>2]=Ib;ub=Ib;vb=Jb;break}else{I=d[904944+N|0]|0;if((Hb|0)>5){Kb=Hb-5|0;Lb=I|Gb<<5}else{N=fe(I>>>((5-Hb|0)>>>0)|Gb<<Hb|0)|0;v=f+796|0;A=c[v>>2]|0;x=N;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;Kb=Hb+27|0;Lb=I}c[O>>2]=Lb;c[H>>2]=Kb;ub=Kb;vb=Lb;break}}else{H=f+784|0;O=f+788|0;if((K|0)>3){Mb=K-3|0;Nb=J<<3|1}else{I=fe(1>>>((3-K|0)>>>0)|J<<K|0)|0;v=f+796|0;A=c[v>>2]|0;x=I;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;Mb=K+29|0;Nb=1}c[H>>2]=Nb;c[O>>2]=Mb;if((Mb|0)>2){Ob=Mb-2|0;Pb=Nb<<2|1}else{v=fe(1>>>((2-Mb|0)>>>0)|Nb<<Mb|0)|0;A=f+796|0;I=c[A>>2]|0;x=v;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Ob=Mb+30|0;Pb=1}c[H>>2]=Pb;c[O>>2]=Ob;O=f+9960|0;c[O>>2]=(c[O>>2]|0)-(c[f+9984>>2]|0);ub=Ob;vb=Pb}}while(0);O=f+788|0;H=f+792|0;A=f+796|0;I=c[A>>2]|0;v=(I-(c[H>>2]|0)<<3)+(32-ub)|0;N=f+13700|0;P=c[N>>2]|0;c[N>>2]=v;Q=f+13696|0;c[Q>>2]=(c[Q>>2]|0)-P+v;v=f+784|0;P=f+11556|0;Q=c[f+11808>>2]|0;if((ub|0)>1){Qb=ub-1|0;Rb=Q|vb<<1}else{o=I;x=fe(Q>>>((1-ub|0)>>>0)|vb<<ub|0)|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Qb=ub+31|0;Rb=Q}c[v>>2]=Rb;c[O>>2]=Qb;Q=f+11744|0;o=f+11824|0;PMa(f,(c[Q>>2]|0)-(c[o>>2]|0)|0,c[P>>2]|0);I=f+11748|0;z=f+11828|0;PMa(f,(c[I>>2]|0)-(c[z>>2]>>1)|0,c[P>>2]|0);c[o>>2]=c[Q>>2];c[z>>2]=c[I>>2]<<1;I=c[f+11812>>2]|0;z=c[v>>2]|0;Q=c[O>>2]|0;if((Q|0)>1){Sb=Q-1|0;Tb=z<<1|I}else{o=fe(I>>>((1-Q|0)>>>0)|z<<Q|0)|0;z=c[A>>2]|0;x=o;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Sb=Q+31|0;Tb=I}c[v>>2]=Tb;c[O>>2]=Sb;v=f+11752|0;I=f+11832|0;PMa(f,(c[v>>2]|0)-(c[I>>2]|0)|0,c[P>>2]|0);Q=f+11756|0;z=f+11836|0;PMa(f,(c[Q>>2]|0)-(c[z>>2]>>1)|0,c[P>>2]|0);c[I>>2]=c[v>>2];c[z>>2]=c[Q>>2]<<1;Q=c[O>>2]|0;O=c[A>>2]|0;A=(O-(c[H>>2]|0)<<3)+(32-Q)|0;H=c[N>>2]|0;c[N>>2]=A;N=f+13664|0;c[N>>2]=(c[N>>2]|0)-H+A;qb=Q;rb=O}do{if(R){O=f+784|0;if((c[f+14220>>2]|0)!=0){Q=d[1179961+(r<<1)|0]|0;A=d[1179960+(r<<1)|0]|0;H=O|0;N=c[H>>2]|0;z=f+788|0;if((qb|0)>(Q|0)){Ub=qb;Vb=N<<Q|A}else{v=f+796|0;I=rb;x=fe(A>>>((Q-qb|0)>>>0)|N<<qb|0)|0;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;Ub=qb+32|0;Vb=A}A=Ub-Q|0;c[H>>2]=Vb;c[z>>2]=A;Wb=A;Xb=z;Yb=r;break}z=r>>2;A=d[1179961+(z<<1)|0]|0;H=d[1179960+(z<<1)|0]|0;z=O|0;O=c[z>>2]|0;Q=f+788|0;if((qb|0)>(A|0)){Zb=qb;_b=O<<A|H;$b=rb}else{v=f+796|0;I=rb;x=fe(H>>>((A-qb|0)>>>0)|O<<qb|0)|0;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;I=(c[v>>2]|0)+4|0;c[v>>2]=I;Zb=qb+32|0;_b=H;$b=I}I=Zb-A|0;c[z>>2]=_b;c[Q>>2]=I;A=r&3;if((I|0)>2){ac=I-2|0;bc=_b<<2|A}else{H=f+796|0;v=$b;x=fe(A>>>((2-I|0)>>>0)|_b<<I|0)|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;ac=I+30|0;bc=A}c[z>>2]=bc;c[Q>>2]=ac;Wb=ac;Xb=Q;Yb=r}else{Wb=qb;Xb=f+788|0;Yb=0}}while(0);Q=f+13684|0;c[Q>>2]=(c[Q>>2]|0)+1;ga=Wb;ha=B;ia=Xb;ja=f+796|0;ka=Yb;break}do{if(M){do{if(R){Q=c[f+11736>>2]|0;if((c[f+9984>>2]|0)==0){z=5-Q|0;A=f+784|0;I=f+788|0;if((K|0)>(z|0)){cc=K;dc=J<<z|3}else{H=fe(3>>>((z-K|0)>>>0)|J<<K|0)|0;v=f+796|0;O=c[v>>2]|0;x=H;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;cc=K+32|0;dc=3}v=cc-z|0;c[A>>2]=dc;c[I>>2]=v;if((c[f+14180>>2]|0)!=0){ec=v;break}if((v|0)>2){fc=v-2|0;gc=dc<<2|2}else{z=fe(2>>>((2-v|0)>>>0)|dc<<v|0)|0;O=f+796|0;H=c[O>>2]|0;x=z;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[O>>2]=(c[O>>2]|0)+4;fc=v+30|0;gc=2}c[A>>2]=gc;c[I>>2]=fc;v=c[f+14236>>2]|0;if((fc|0)>1){hc=fc-1|0;ic=v|gc<<1}else{O=fe(v>>>((1-fc|0)>>>0)|gc<<fc|0)|0;H=f+796|0;z=c[H>>2]|0;x=O;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;hc=fc+31|0;ic=v}c[A>>2]=ic;c[I>>2]=hc;ec=hc;break}do{if((Q|0)==1){I=f+784|0;A=f+788|0;if((K|0)>6){jc=K-6|0;kc=J<<6|3}else{v=fe(3>>>((6-K|0)>>>0)|J<<K|0)|0;H=f+796|0;z=c[H>>2]|0;x=v;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;jc=K+26|0;kc=3}c[I>>2]=kc;c[A>>2]=jc;if((c[f+14180>>2]|0)!=0){lc=kc;mc=jc;break}if((jc|0)>2){nc=jc-2|0;oc=kc<<2|2}else{H=fe(2>>>((2-jc|0)>>>0)|kc<<jc|0)|0;z=f+796|0;v=c[z>>2]|0;x=H;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;nc=jc+30|0;oc=2}c[I>>2]=oc;c[A>>2]=nc;z=c[f+14236>>2]|0;if((nc|0)>1){pc=nc-1|0;qc=z|oc<<1}else{v=fe(z>>>((1-nc|0)>>>0)|oc<<nc|0)|0;H=f+796|0;O=c[H>>2]|0;x=v;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;pc=nc+31|0;qc=z}c[I>>2]=qc;c[A>>2]=pc;lc=qc;mc=pc}else{A=8-Q|0;I=f+784|0;z=f+788|0;if((K|0)>(A|0)){rc=K;sc=J<<A|2}else{H=fe(2>>>((A-K|0)>>>0)|J<<K|0)|0;O=f+796|0;v=c[O>>2]|0;x=H;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[O>>2]=(c[O>>2]|0)+4;rc=K+32|0;sc=2}O=rc-A|0;c[I>>2]=sc;c[z>>2]=O;if((c[f+14180>>2]|0)!=0){lc=sc;mc=O;break}if((O|0)>2){tc=O-2|0;uc=sc<<2|2}else{A=fe(2>>>((2-O|0)>>>0)|sc<<O|0)|0;v=f+796|0;H=c[v>>2]|0;x=A;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;tc=O+30|0;uc=2}c[I>>2]=uc;c[z>>2]=tc;O=c[f+14236>>2]|0;if((tc|0)>1){vc=tc-1|0;wc=O|uc<<1}else{v=fe(O>>>((1-tc|0)>>>0)|uc<<tc|0)|0;H=f+796|0;A=c[H>>2]|0;x=v;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;vc=tc+31|0;wc=O}c[I>>2]=wc;c[z>>2]=vc;lc=wc;mc=vc}}while(0);Q=f+784|0;z=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((mc|0)>5){xc=mc-5|0;yc=z|lc<<5}else{I=fe(z>>>((5-mc|0)>>>0)|lc<<mc|0)|0;O=f+796|0;H=c[O>>2]|0;x=I;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[O>>2]=(c[O>>2]|0)+4;xc=mc+27|0;yc=z}c[Q>>2]=yc;c[f+788>>2]=xc;ec=xc;break}else{O=d[904944+z|0]|0;if((mc|0)>5){zc=mc-5|0;Ac=O|lc<<5}else{z=fe(O>>>((5-mc|0)>>>0)|lc<<mc|0)|0;H=f+796|0;I=c[H>>2]|0;x=z;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;zc=mc+27|0;Ac=O}c[Q>>2]=Ac;c[f+788>>2]=zc;ec=zc;break}}else{Q=5-(c[f+11736>>2]|0)|0;O=f+784|0;H=f+788|0;if((K|0)>(Q|0)){Bc=K;Cc=J<<Q|2}else{I=fe(2>>>((Q-K|0)>>>0)|J<<K|0)|0;z=f+796|0;A=c[z>>2]|0;x=I;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;Bc=K+32|0;Cc=2}z=Bc-Q|0;c[O>>2]=Cc;c[H>>2]=z;if((c[f+14180>>2]|0)==0){if((z|0)>2){Dc=z-2|0;Ec=Cc<<2|2}else{Q=fe(2>>>((2-z|0)>>>0)|Cc<<z|0)|0;A=f+796|0;I=c[A>>2]|0;x=Q;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Dc=z+30|0;Ec=2}c[O>>2]=Ec;c[H>>2]=Dc;Fc=Dc}else{Fc=z}z=f+9960|0;c[z>>2]=(c[z>>2]|0)-(c[f+9984>>2]|0);ec=Fc}}while(0);G=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-ec)|0;z=f+13700|0;H=c[z>>2]|0;c[z>>2]=G;z=f+13696|0;c[z>>2]=(c[z>>2]|0)-H+G;G=f+11736|0;H=c[G>>2]|0;if((H&1|0)==0){Gc=H}else{H=f+11744|0;z=f+11824|0;O=f+11556|0;PMa(f,(c[H>>2]|0)-(c[z>>2]|0)|0,c[O>>2]|0);A=f+11748|0;I=f+11828|0;PMa(f,(c[A>>2]|0)-(c[I>>2]|0)|0,c[O>>2]|0);O=c[H>>2]|0;c[f+11832>>2]=O;c[z>>2]=O;O=c[A>>2]|0;c[f+11836>>2]=O;c[I>>2]=O;O=f+13684|0;c[O>>2]=(c[O>>2]|0)+1;Gc=c[G>>2]|0}if((Gc&2|0)==0){break}G=f+11776|0;O=f+11840|0;I=f+11560|0;PMa(f,(c[G>>2]|0)-(c[O>>2]|0)|0,c[I>>2]|0);A=f+11780|0;z=f+11844|0;PMa(f,(c[A>>2]|0)-(c[z>>2]|0)|0,c[I>>2]|0);I=c[G>>2]|0;c[f+11848>>2]=I;c[O>>2]=I;I=c[A>>2]|0;c[f+11852>>2]=I;c[z>>2]=I;I=f+13688|0;c[I>>2]=(c[I>>2]|0)+1}else{do{if(R){I=c[f+11736>>2]|0;if((c[f+9984>>2]|0)==0){z=5-I|0;A=f+784|0;O=f+788|0;if((K|0)>(z|0)){Hc=K;Ic=J<<z|3}else{G=fe(3>>>((z-K|0)>>>0)|J<<K|0)|0;H=f+796|0;Q=c[H>>2]|0;x=G;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;Hc=K+32|0;Ic=3}H=Hc-z|0;c[A>>2]=Ic;c[O>>2]=H;if((c[f+14180>>2]|0)!=0){Jc=H;Kc=Ic;break}if((H|0)>2){Lc=H-2|0;Mc=Ic<<2|1}else{z=fe(1>>>((2-H|0)>>>0)|Ic<<H|0)|0;Q=f+796|0;G=c[Q>>2]|0;x=z;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;Lc=H+30|0;Mc=1}c[A>>2]=Mc;c[O>>2]=Lc;H=c[f+14236>>2]|0;if((Lc|0)>1){Nc=Lc-1|0;Oc=H|Mc<<1}else{Q=fe(H>>>((1-Lc|0)>>>0)|Mc<<Lc|0)|0;G=f+796|0;z=c[G>>2]|0;x=Q;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;Nc=Lc+31|0;Oc=H}c[A>>2]=Oc;c[O>>2]=Nc;Jc=Nc;Kc=Oc;break}do{if((I|0)==1){O=f+784|0;A=f+788|0;if((K|0)>6){Pc=K-6|0;Qc=J<<6|3}else{H=fe(3>>>((6-K|0)>>>0)|J<<K|0)|0;G=f+796|0;z=c[G>>2]|0;x=H;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;Pc=K+26|0;Qc=3}c[O>>2]=Qc;c[A>>2]=Pc;if((c[f+14180>>2]|0)!=0){Rc=Qc;Sc=Pc;break}if((Pc|0)>2){Tc=Pc-2|0;Uc=Qc<<2|1}else{G=fe(1>>>((2-Pc|0)>>>0)|Qc<<Pc|0)|0;z=f+796|0;H=c[z>>2]|0;x=G;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;Tc=Pc+30|0;Uc=1}c[O>>2]=Uc;c[A>>2]=Tc;z=c[f+14236>>2]|0;if((Tc|0)>1){Vc=Tc-1|0;Wc=z|Uc<<1}else{H=fe(z>>>((1-Tc|0)>>>0)|Uc<<Tc|0)|0;G=f+796|0;Q=c[G>>2]|0;x=H;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;Vc=Tc+31|0;Wc=z}c[O>>2]=Wc;c[A>>2]=Vc;Rc=Wc;Sc=Vc}else{A=8-I|0;O=f+784|0;z=f+788|0;if((K|0)>(A|0)){Xc=K;Yc=J<<A|2}else{G=fe(2>>>((A-K|0)>>>0)|J<<K|0)|0;Q=f+796|0;H=c[Q>>2]|0;x=G;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;Xc=K+32|0;Yc=2}Q=Xc-A|0;c[O>>2]=Yc;c[z>>2]=Q;if((c[f+14180>>2]|0)!=0){Rc=Yc;Sc=Q;break}if((Q|0)>2){Zc=Q-2|0;_c=Yc<<2|1}else{A=fe(1>>>((2-Q|0)>>>0)|Yc<<Q|0)|0;H=f+796|0;G=c[H>>2]|0;x=A;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;Zc=Q+30|0;_c=1}c[O>>2]=_c;c[z>>2]=Zc;Q=c[f+14236>>2]|0;if((Zc|0)>1){$c=Zc-1|0;ad=Q|_c<<1}else{H=fe(Q>>>((1-Zc|0)>>>0)|_c<<Zc|0)|0;G=f+796|0;A=c[G>>2]|0;x=H;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;$c=Zc+31|0;ad=Q}c[O>>2]=ad;c[z>>2]=$c;Rc=ad;Sc=$c}}while(0);I=f+784|0;z=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Sc|0)>5){bd=Sc-5|0;cd=z|Rc<<5}else{O=fe(z>>>((5-Sc|0)>>>0)|Rc<<Sc|0)|0;Q=f+796|0;G=c[Q>>2]|0;x=O;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;bd=Sc+27|0;cd=z}c[I>>2]=cd;c[f+788>>2]=bd;Jc=bd;Kc=cd;break}else{Q=d[904944+z|0]|0;if((Sc|0)>5){dd=Sc-5|0;ed=Q|Rc<<5}else{z=fe(Q>>>((5-Sc|0)>>>0)|Rc<<Sc|0)|0;G=f+796|0;O=c[G>>2]|0;x=z;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;dd=Sc+27|0;ed=Q}c[I>>2]=ed;c[f+788>>2]=dd;Jc=dd;Kc=ed;break}}else{I=5-(c[f+11736>>2]|0)|0;Q=f+784|0;G=f+788|0;if((K|0)>(I|0)){fd=K;gd=J<<I|2}else{O=fe(2>>>((I-K|0)>>>0)|J<<K|0)|0;z=f+796|0;A=c[z>>2]|0;x=O;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;fd=K+32|0;gd=2}z=fd-I|0;c[Q>>2]=gd;c[G>>2]=z;if((z|0)>2){hd=z-2|0;id=gd<<2|1}else{I=fe(1>>>((2-z|0)>>>0)|gd<<z|0)|0;A=f+796|0;O=c[A>>2]|0;x=I;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;hd=z+30|0;id=1}c[Q>>2]=id;c[G>>2]=hd;G=f+9960|0;c[G>>2]=(c[G>>2]|0)-(c[f+9984>>2]|0);Jc=hd;Kc=id}}while(0);G=f+788|0;Q=f+796|0;z=c[Q>>2]|0;A=(z-(c[f+792>>2]|0)<<3)+(32-Jc)|0;O=f+13700|0;I=c[O>>2]|0;c[O>>2]=A;O=f+13696|0;c[O>>2]=(c[O>>2]|0)-I+A;A=f+11736|0;I=c[A>>2]|0;if((I&1|0)==0){jd=I}else{I=f+784|0;O=f+11556|0;H=c[f+11808>>2]|0;if((Jc|0)>1){kd=Jc-1|0;ld=H|Kc<<1}else{v=z;x=fe(H>>>((1-Jc|0)>>>0)|Kc<<Jc|0)|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;kd=Jc+31|0;ld=H}c[I>>2]=ld;c[G>>2]=kd;H=f+11744|0;v=f+11824|0;PMa(f,(c[H>>2]|0)-(c[v>>2]|0)|0,c[O>>2]|0);z=f+11748|0;N=f+11828|0;PMa(f,(c[z>>2]|0)-(c[N>>2]>>1)|0,c[O>>2]|0);c[v>>2]=c[H>>2];c[N>>2]=c[z>>2]<<1;z=c[f+11812>>2]|0;N=c[I>>2]|0;H=c[G>>2]|0;if((H|0)>1){md=H-1|0;nd=N<<1|z}else{v=fe(z>>>((1-H|0)>>>0)|N<<H|0)|0;N=c[Q>>2]|0;x=v;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;md=H+31|0;nd=z}c[I>>2]=nd;c[G>>2]=md;I=f+11752|0;z=f+11832|0;PMa(f,(c[I>>2]|0)-(c[z>>2]|0)|0,c[O>>2]|0);H=f+11756|0;N=f+11836|0;PMa(f,(c[H>>2]|0)-(c[N>>2]>>1)|0,c[O>>2]|0);c[z>>2]=c[I>>2];c[N>>2]=c[H>>2]<<1;H=f+13684|0;c[H>>2]=(c[H>>2]|0)+1;jd=c[A>>2]|0}if((jd&2|0)==0){break}A=f+784|0;H=f+11560|0;N=c[f+11816>>2]|0;I=c[A>>2]|0;z=c[G>>2]|0;if((z|0)>1){od=z-1|0;pd=I<<1|N}else{O=fe(N>>>((1-z|0)>>>0)|I<<z|0)|0;I=c[Q>>2]|0;x=O;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;od=z+31|0;pd=N}c[A>>2]=pd;c[G>>2]=od;N=f+11776|0;z=f+11840|0;PMa(f,(c[N>>2]|0)-(c[z>>2]|0)|0,c[H>>2]|0);I=f+11780|0;O=f+11844|0;PMa(f,(c[I>>2]|0)-(c[O>>2]>>1)|0,c[H>>2]|0);c[z>>2]=c[N>>2];c[O>>2]=c[I>>2]<<1;I=c[f+11820>>2]|0;O=c[A>>2]|0;N=c[G>>2]|0;if((N|0)>1){qd=N-1|0;rd=O<<1|I}else{z=fe(I>>>((1-N|0)>>>0)|O<<N|0)|0;O=c[Q>>2]|0;x=z;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;qd=N+31|0;rd=I}c[A>>2]=rd;c[G>>2]=qd;G=f+11784|0;A=f+11848|0;PMa(f,(c[G>>2]|0)-(c[A>>2]|0)|0,c[H>>2]|0);I=f+11788|0;N=f+11852|0;PMa(f,(c[I>>2]|0)-(c[N>>2]>>1)|0,c[H>>2]|0);c[A>>2]=c[G>>2];c[N>>2]=c[I>>2]<<1;I=f+13688|0;c[I>>2]=(c[I>>2]|0)+1}}while(0);M=f+788|0;I=c[M>>2]|0;N=f+796|0;G=c[N>>2]|0;A=(G-(c[f+792>>2]|0)<<3)+(32-I)|0;H=f+13700|0;Q=c[H>>2]|0;c[H>>2]=A;H=f+13664|0;c[H>>2]=(c[H>>2]|0)-Q+A;if(!R){ga=I;ha=B;ia=M;ja=N;ka=0;break}A=f+784|0;if((c[f+14220>>2]|0)!=0){Q=d[1179961+(r<<1)|0]|0;H=d[1179960+(r<<1)|0]|0;O=A|0;z=c[O>>2]|0;if((I|0)>(Q|0)){sd=I;td=z<<Q|H}else{v=G;x=fe(H>>>((Q-I|0)>>>0)|z<<I|0)|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;sd=I+32|0;td=H}H=sd-Q|0;c[O>>2]=td;c[M>>2]=H;ga=H;ha=B;ia=M;ja=N;ka=r;break}H=r>>2;O=d[1179961+(H<<1)|0]|0;Q=d[1179960+(H<<1)|0]|0;H=A|0;A=c[H>>2]|0;if((I|0)>(O|0)){ud=I;vd=A<<O|Q;wd=G}else{v=G;x=fe(Q>>>((O-I|0)>>>0)|A<<I|0)|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;v=(c[N>>2]|0)+4|0;c[N>>2]=v;ud=I+32|0;vd=Q;wd=v}v=ud-O|0;c[H>>2]=vd;c[M>>2]=v;O=r&3;if((v|0)>2){xd=v-2|0;yd=vd<<2|O}else{Q=wd;x=fe(O>>>((2-v|0)>>>0)|vd<<v|0)|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;xd=v+30|0;yd=O}c[H>>2]=yd;c[M>>2]=xd;ga=xd;ha=B;ia=M;ja=N;ka=r}}while(0);r=f+784|0;xd=f+48|0;yd=f+14196|0;vd=0;wd=ga;while(1){if((1<<5-vd&ka|0)==0){zd=wd}else{ga=g+(vd<<7)|0;ud=c[287048]|0;td=c[f+180+(vd<<2)>>2]|0;do{if((c[ha>>2]|0)==0){sd=b[ga>>1]|0;qd=sd<<16>>16;if(((sd<<16>>16>-1?qd:-qd|0)|0)!=1){Ad=ud;Bd=qd;Dd=-1;Ed=0;break}sd=qd>>>31|2;qd=c[r>>2]|0;if((wd|0)>2){Fd=wd-2|0;Gd=qd<<2|sd}else{rd=fe(qd<<wd|sd>>>((2-wd|0)>>>0)|0)|0;qd=c[ja>>2]|0;x=rd;a[qd]=x;x=x>>8;a[qd+1|0]=x;x=x>>8;a[qd+2|0]=x;x=x>>8;a[qd+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;Fd=wd+30|0;Gd=sd}c[r>>2]=Gd;c[ia>>2]=Fd;Hd=ud;Id=0;Jd=1;Kd=405}else{if((vd|0)<4){Ld=0}else{Ld=(vd&1)+1|0}sd=b[ga>>1]|0;qd=f+9860+(Ld<<2)|0;rd=sd-(c[qd>>2]|0)|0;od=rd+255|0;do{if(od>>>0>510>>>0){if((rd|0)<0){pd=rd*-2|0;jd=(pd&65280|0)==0;Md=(d[1191992+(jd?pd:pd>>>8)|0]|0)+(jd?0:8)|0;Nd=rd-1|0}else{jd=rd<<1;pd=(jd&65280|0)==0;Md=(d[1191992+(pd?jd:rd>>>7&16777215)|0]|0)+(pd?0:8)|0;Nd=rd}if((Ld|0)==0){pd=(d[1179904+Md|0]|0)+Md|0;jd=(e[1179880+(Md<<1)>>1]<<Md)+((1<<Md)-1&Nd)|0;md=c[r>>2]|0;if((wd|0)>(pd|0)){Od=wd;Pd=jd|md<<pd}else{nd=fe(jd>>>((pd-wd|0)>>>0)|md<<wd|0)|0;md=c[ja>>2]|0;x=nd;a[md]=x;x=x>>8;a[md+1|0]=x;x=x>>8;a[md+2|0]=x;x=x>>8;a[md+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;Od=wd+32|0;Pd=jd}c[r>>2]=Pd;c[ia>>2]=Od-pd;break}else{pd=(d[1179944+Md|0]|0)+Md|0;jd=(e[1179920+(Md<<1)>>1]<<Md)+((1<<Md)-1&Nd)|0;md=c[r>>2]|0;if((wd|0)>(pd|0)){Qd=wd;Rd=jd|md<<pd}else{nd=fe(jd>>>((pd-wd|0)>>>0)|md<<wd|0)|0;md=c[ja>>2]|0;x=nd;a[md]=x;x=x>>8;a[md+1|0]=x;x=x>>8;a[md+2|0]=x;x=x>>8;a[md+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;Qd=wd+32|0;Rd=jd}c[r>>2]=Rd;c[ia>>2]=Qd-pd;break}}else{if((Ld|0)==0){pd=c[4802976+(od<<2)>>2]|0;jd=pd&255;md=pd>>>8;pd=c[r>>2]|0;if((wd|0)>(jd|0)){Sd=wd;Td=pd<<jd|md}else{nd=fe(md>>>((jd-wd|0)>>>0)|pd<<wd|0)|0;pd=c[ja>>2]|0;x=nd;a[pd]=x;x=x>>8;a[pd+1|0]=x;x=x>>8;a[pd+2|0]=x;x=x>>8;a[pd+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;Sd=wd+32|0;Td=md}c[r>>2]=Td;c[ia>>2]=Sd-jd;break}else{jd=c[4805088+(od<<2)>>2]|0;md=jd&255;pd=jd>>>8;jd=c[r>>2]|0;if((wd|0)>(md|0)){Ud=wd;Vd=jd<<md|pd}else{nd=fe(pd>>>((md-wd|0)>>>0)|jd<<wd|0)|0;jd=c[ja>>2]|0;x=nd;a[jd]=x;x=x>>8;a[jd+1|0]=x;x=x>>8;a[jd+2|0]=x;x=x>>8;a[jd+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;Ud=wd+32|0;Vd=pd}c[r>>2]=Vd;c[ia>>2]=Ud-md;break}}}while(0);c[qd>>2]=sd;Hd=(c[yd>>2]|0)==0?ud:c[287e3]|0;Id=0;Jd=1;Kd=405}}while(0);while(1){if((Kd|0)==405){Kd=0;if((Jd|0)>(td|0)){break}Ad=Hd;Bd=b[g+(vd<<7)+(d[f+368+Jd|0]<<1)>>1]|0;Dd=Id;Ed=Jd}do{if((Bd|0)==0){Wd=Dd}else{ud=Ed-Dd-1|0;ga=Bd>>31;B=(ga^Bd)-ga|0;if((B|0)<=(a[4802912+ud|0]|0)){R=B-1+(d[4805024+ud|0]|0)|0;od=e[Ad+(R<<2)+2>>1]|0;rd=od+1|0;md=e[Ad+(R<<2)>>1]<<1|ga&1;ga=c[r>>2]|0;R=c[ia>>2]|0;if((R|0)>(rd|0)){Xd=R-rd|0;Yd=md|ga<<rd}else{pd=fe(md>>>((rd-R|0)>>>0)|ga<<R|0)|0;ga=c[ja>>2]|0;x=pd;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;Xd=31-od+R|0;Yd=md}c[r>>2]=Yd;c[ia>>2]=Xd;Wd=Ed;break}md=e[Ad+446>>1]|0;R=e[Ad+444>>1]|0;od=c[r>>2]|0;ga=c[ia>>2]|0;if((ga|0)>(md|0)){Zd=ga-md|0;_d=od<<md|R}else{pd=fe(R>>>((md-ga|0)>>>0)|od<<ga|0)|0;od=c[ja>>2]|0;x=pd;a[od]=x;x=x>>8;a[od+1|0]=x;x=x>>8;a[od+2|0]=x;x=x>>8;a[od+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;Zd=32-md+ga|0;_d=R}c[r>>2]=_d;c[ia>>2]=Zd;if((Zd|0)>6){$d=Zd-6|0;ae=_d<<6|ud}else{R=fe(ud>>>((6-Zd|0)>>>0)|_d<<Zd|0)|0;ga=c[ja>>2]|0;x=R;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;$d=Zd+26|0;ae=ud}c[r>>2]=ae;c[ia>>2]=$d;if((c[xd>>2]|0)!=1){ud=Bd&4095;if(($d|0)>12){be=$d-12|0;ce=ae<<12|ud}else{ga=fe(ud>>>((12-$d|0)>>>0)|ae<<$d|0)|0;R=c[ja>>2]|0;x=ga;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;be=$d+20|0;ce=ud}c[r>>2]=ce;c[ia>>2]=be;Wd=Ed;break}if((B|0)<128){B=Bd&255;if(($d|0)>8){de=$d-8|0;ee=ae<<8|B}else{ud=fe(B>>>((8-$d|0)>>>0)|ae<<$d|0)|0;R=c[ja>>2]|0;x=ud;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;de=$d+24|0;ee=B}c[r>>2]=ee;c[ia>>2]=de;Wd=Ed;break}if((Bd|0)<0){B=Bd+33024|0;if(($d|0)>16){ge=$d-16|0;he=ae<<16|B}else{R=fe(B>>>((16-$d|0)>>>0)|ae<<$d|0)|0;ud=c[ja>>2]|0;x=R;a[ud]=x;x=x>>8;a[ud+1|0]=x;x=x>>8;a[ud+2|0]=x;x=x>>8;a[ud+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;ge=$d+16|0;he=B}c[r>>2]=he;c[ia>>2]=ge;Wd=Ed;break}else{B=Bd&65535;if(($d|0)>16){ie=$d-16|0;je=ae<<16|B}else{ud=fe(B>>>((16-$d|0)>>>0)|ae<<$d|0)|0;R=c[ja>>2]|0;x=ud;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;ie=$d+16|0;je=B}c[r>>2]=je;c[ia>>2]=ie;Wd=Ed;break}}}while(0);Hd=Ad;Id=Wd;Jd=Ed+1|0;Kd=405}td=e[Hd+450>>1]|0;sd=e[Hd+448>>1]|0;qd=c[r>>2]|0;B=c[ia>>2]|0;if((B|0)>(td|0)){ke=B-td|0;le=qd<<td|sd}else{R=fe(sd>>>((td-B|0)>>>0)|qd<<B|0)|0;qd=c[ja>>2]|0;x=R;a[qd]=x;x=x>>8;a[qd+1|0]=x;x=x>>8;a[qd+2|0]=x;x=x>>8;a[qd+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;ke=32-td+B|0;le=sd}c[r>>2]=le;c[ia>>2]=ke;zd=ke}sd=vd+1|0;if((sd|0)<6){vd=sd;wd=zd}else{break}}wd=c[ja>>2]|0;c[p>>2]=0;p=(c[ha>>2]|0)==0;ha=(wd-(c[f+792>>2]|0)<<3)+(32-zd)|0;zd=f+13700|0;wd=c[zd>>2]|0;c[zd>>2]=ha;zd=ha-wd|0;if(p){p=f+13676|0;c[p>>2]=(c[p>>2]|0)+zd;i=k;return}else{p=f+13672|0;c[p>>2]=(c[p>>2]|0)+zd;i=k;return}}else{if(n){me=(m|0)==(c[f+13708>>2]|0)}else{me=0}n=(c[f+180>>2]>>31)+128&-128;zd=(c[f+184>>2]|0)>-1?n|64:n;n=(c[f+188>>2]|0)>-1?zd|32:zd;zd=(c[f+192>>2]|0)>-1?n|16:n;n=(c[f+196>>2]|0)>-1?zd|8:zd;zd=(c[f+200>>2]|0)>-1?n|4:n;n=(c[f+204>>2]|0)>-1?zd|2:zd;do{if((c[f+208>>2]|0)>-1){ne=n|1;oe=0}else{zd=(n|0)==0;if(me|zd^1){ne=n;oe=zd;break}if((c[f+11740>>2]|0)!=0){ne=n;oe=zd;break}if((l|0)==((c[f+116>>2]|0)-1|0)){if((m|0)==((c[f+812>>2]|0)-1|0)){ne=n;oe=zd;break}if((c[f+48>>2]|0)!=1){ne=n;oe=zd;break}}p=c[f+9992>>2]|0;wd=(p|0)==2;if(wd){if((j|h|0)!=0){ne=n;oe=zd;break}}else{if((p|0)!=3){ne=n;oe=zd;break}p=c[f+11736>>2]|0;if((p|0)!=(c[f+14144>>2]|0)){ne=n;oe=zd;break}if((p&1|0)==0){pe=0}else{pe=(c[f+11748>>2]|0)-(c[f+11828>>2]|0)|(c[f+11744>>2]|0)-(c[f+11824>>2]|0)}if((p&2|0)==0){qe=0}else{qe=(c[f+11780>>2]|0)-(c[f+11844>>2]|0)|(c[f+11776>>2]|0)-(c[f+11840>>2]|0)}if((qe|pe|0)!=0){ne=n;oe=zd;break}}zd=f+12484|0;c[zd>>2]=(c[zd>>2]|0)+1;zd=f+9960|0;c[zd>>2]=(c[zd>>2]|0)-(c[f+9984>>2]|0);zd=f+13692|0;c[zd>>2]=(c[zd>>2]|0)+1;zd=f+13696|0;c[zd>>2]=(c[zd>>2]|0)+1;zd=f+13700|0;c[zd>>2]=(c[zd>>2]|0)+1;if(!wd){i=k;return}TGb(f+11824|0,0,16)|0;i=k;return}}while(0);n=f+12484|0;pe=c[n>>2]|0;if(me){if((pe|0)!=0){yDb(0,0,2254616,(y=i,i=i+24|0,c[y>>2]=2028488,c[y+8>>2]=2185312,c[y+16>>2]=724,y)|0);i=y;Cd()}y=f+784|0;if((l|0)>32){me=f+788|0;qe=f+796|0;m=l;wd=c[y>>2]|0;zd=c[me>>2]|0;while(1){if((zd|0)>11){re=zd-11|0;se=wd<<11|8}else{p=fe(8>>>((11-zd|0)>>>0)|wd<<zd|0)|0;ha=c[qe>>2]|0;x=p;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;c[qe>>2]=(c[qe>>2]|0)+4;re=zd+21|0;se=8}c[y>>2]=se;c[me>>2]=re;ha=m-33|0;if((ha|0)>32){m=ha;wd=se;zd=re}else{break}}te=((l-33|0)>>>0)%33|0;ue=se;ve=re}else{te=l;ue=c[y>>2]|0;ve=c[f+788>>2]|0}l=d[1180129+(te<<1)|0]|0;re=d[1180128+(te<<1)|0]|0;if((ve|0)>(l|0)){we=ve;xe=ue<<l|re}else{te=fe(re>>>((l-ve|0)>>>0)|ue<<ve|0)|0;ue=f+796|0;se=c[ue>>2]|0;x=te;a[se]=x;x=x>>8;a[se+1|0]=x;x=x>>8;a[se+2|0]=x;x=x>>8;a[se+3|0]=x;c[ue>>2]=(c[ue>>2]|0)+4;we=ve+32|0;xe=re}re=we-l|0;c[y>>2]=xe;c[f+788>>2]=re;ye=xe;ze=re}else{re=f+784|0;if((pe|0)>32){xe=f+788|0;y=f+796|0;l=pe;we=c[re>>2]|0;ve=c[xe>>2]|0;while(1){if((ve|0)>11){Ae=ve-11|0;Be=we<<11|8}else{ue=fe(8>>>((11-ve|0)>>>0)|we<<ve|0)|0;se=c[y>>2]|0;x=ue;a[se]=x;x=x>>8;a[se+1|0]=x;x=x>>8;a[se+2|0]=x;x=x>>8;a[se+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;Ae=ve+21|0;Be=8}c[re>>2]=Be;c[xe>>2]=Ae;se=l-33|0;if((se|0)>32){l=se;we=Be;ve=Ae}else{break}}Ce=((pe-33|0)>>>0)%33|0;De=Be;Ee=Ae}else{Ce=pe;De=c[re>>2]|0;Ee=c[f+788>>2]|0}pe=d[1180129+(Ce<<1)|0]|0;Ae=d[1180128+(Ce<<1)|0]|0;if((Ee|0)>(pe|0)){Fe=Ee;Ge=De<<pe|Ae}else{Ce=fe(Ae>>>((pe-Ee|0)>>>0)|De<<Ee|0)|0;De=f+796|0;Be=c[De>>2]|0;x=Ce;a[Be]=x;x=x>>8;a[Be+1|0]=x;x=x>>8;a[Be+2|0]=x;x=x>>8;a[Be+3|0]=x;c[De>>2]=(c[De>>2]|0)+4;Fe=Ee+32|0;Ge=Ae}Ae=Fe-pe|0;c[re>>2]=Ge;c[f+788>>2]=Ae;ye=Ge;ze=Ae}Ae=c[f+9992>>2]|0;do{if((Ae|0)==1){Ge=f+9984|0;re=f+784|0;pe=f+788|0;do{if((c[Ge>>2]|0)==0|oe){if((ze|0)>1){He=ze-1|0;Ie=ye<<1|1}else{Fe=fe(1>>>((1-ze|0)>>>0)|ye<<ze|0)|0;Ee=f+796|0;De=c[Ee>>2]|0;x=Fe;a[De]=x;x=x>>8;a[De+1|0]=x;x=x>>8;a[De+2|0]=x;x=x>>8;a[De+3|0]=x;c[Ee>>2]=(c[Ee>>2]|0)+4;He=ze+31|0;Ie=1}c[re>>2]=Ie;c[pe>>2]=He;if((c[f+14180>>2]|0)==0){Ee=c[f+14236>>2]|0;if((He|0)>1){Je=He-1|0;Ke=Ee|Ie<<1}else{De=fe(Ee>>>((1-He|0)>>>0)|Ie<<He|0)|0;Fe=f+796|0;Be=c[Fe>>2]|0;x=De;a[Be]=x;x=x>>8;a[Be+1|0]=x;x=x>>8;a[Be+2|0]=x;x=x>>8;a[Be+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;Je=He+31|0;Ke=Ee}c[re>>2]=Ke;c[pe>>2]=Je;Le=Je}else{Le=He}Ee=f+9960|0;c[Ee>>2]=(c[Ee>>2]|0)-(c[Ge>>2]|0);Me=Le}else{if((ze|0)>2){Ne=ze-2|0;Oe=ye<<2|1}else{Ee=fe(1>>>((2-ze|0)>>>0)|ye<<ze|0)|0;Fe=f+796|0;Be=c[Fe>>2]|0;x=Ee;a[Be]=x;x=x>>8;a[Be+1|0]=x;x=x>>8;a[Be+2|0]=x;x=x>>8;a[Be+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;Ne=ze+30|0;Oe=1}c[re>>2]=Oe;c[pe>>2]=Ne;if((c[f+14180>>2]|0)==0){Fe=c[f+14236>>2]|0;if((Ne|0)>1){Pe=Ne-1|0;Qe=Fe|Oe<<1}else{Be=fe(Fe>>>((1-Ne|0)>>>0)|Oe<<Ne|0)|0;Ee=f+796|0;De=c[Ee>>2]|0;x=Be;a[De]=x;x=x>>8;a[De+1|0]=x;x=x>>8;a[De+2|0]=x;x=x>>8;a[De+3|0]=x;c[Ee>>2]=(c[Ee>>2]|0)+4;Pe=Ne+31|0;Qe=Fe}c[re>>2]=Qe;c[pe>>2]=Pe;Re=Qe;Se=Pe}else{Re=Oe;Se=Ne}Fe=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Se|0)>5){Te=Se-5|0;Ue=Fe|Re<<5}else{Ee=fe(Fe>>>((5-Se|0)>>>0)|Re<<Se|0)|0;De=f+796|0;Be=c[De>>2]|0;x=Ee;a[Be]=x;x=x>>8;a[Be+1|0]=x;x=x>>8;a[Be+2|0]=x;x=x>>8;a[Be+3|0]=x;c[De>>2]=(c[De>>2]|0)+4;Te=Se+27|0;Ue=Fe}c[re>>2]=Ue;c[pe>>2]=Te;Me=Te;break}else{De=d[904944+Fe|0]|0;if((Se|0)>5){Ve=Se-5|0;We=De|Re<<5}else{Fe=fe(De>>>((5-Se|0)>>>0)|Re<<Se|0)|0;Be=f+796|0;Ee=c[Be>>2]|0;x=Fe;a[Ee]=x;x=x>>8;a[Ee+1|0]=x;x=x>>8;a[Ee+2|0]=x;x=x>>8;a[Ee+3|0]=x;c[Be>>2]=(c[Be>>2]|0)+4;Ve=Se+27|0;We=De}c[re>>2]=We;c[pe>>2]=Ve;Me=Ve;break}}}while(0);re=f+796|0;Ge=((c[re>>2]|0)-(c[f+792>>2]|0)<<3)+(32-Me)|0;De=f+13700|0;Be=c[De>>2]|0;c[De>>2]=Ge;De=f+13696|0;c[De>>2]=(c[De>>2]|0)-Be+Ge;Ge=f+13680|0;c[Ge>>2]=(c[Ge>>2]|0)+1;Xe=Me;Ye=f+12488|0;Ze=pe;_e=re;$e=ne}else{re=f+12488|0;if((c[re>>2]|0)!=0){Ge=f+9984|0;Be=f+784|0;De=f+788|0;do{if((c[Ge>>2]|0)==0|oe){if((ze|0)>5){af=ze-5|0;bf=ye<<5|3}else{Ee=fe(3>>>((5-ze|0)>>>0)|ye<<ze|0)|0;Fe=f+796|0;Ce=c[Fe>>2]|0;x=Ee;a[Ce]=x;x=x>>8;a[Ce+1|0]=x;x=x>>8;a[Ce+2|0]=x;x=x>>8;a[Ce+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;af=ze+27|0;bf=3}c[Be>>2]=bf;c[De>>2]=af;if((c[f+14180>>2]|0)==0){Fe=c[f+14236>>2]|0;if((af|0)>1){cf=af-1|0;df=Fe|bf<<1}else{Ce=fe(Fe>>>((1-af|0)>>>0)|bf<<af|0)|0;Ee=f+796|0;ve=c[Ee>>2]|0;x=Ce;a[ve]=x;x=x>>8;a[ve+1|0]=x;x=x>>8;a[ve+2|0]=x;x=x>>8;a[ve+3|0]=x;c[Ee>>2]=(c[Ee>>2]|0)+4;cf=af+31|0;df=Fe}c[Be>>2]=df;c[De>>2]=cf;ef=cf}else{ef=af}Fe=f+9960|0;c[Fe>>2]=(c[Fe>>2]|0)-(c[Ge>>2]|0);ff=ef}else{if((ze|0)>6){gf=ze-6|0;hf=ye<<6|1}else{Fe=fe(1>>>((6-ze|0)>>>0)|ye<<ze|0)|0;Ee=f+796|0;ve=c[Ee>>2]|0;x=Fe;a[ve]=x;x=x>>8;a[ve+1|0]=x;x=x>>8;a[ve+2|0]=x;x=x>>8;a[ve+3|0]=x;c[Ee>>2]=(c[Ee>>2]|0)+4;gf=ze+26|0;hf=1}c[Be>>2]=hf;c[De>>2]=gf;if((c[f+14180>>2]|0)==0){Ee=c[f+14236>>2]|0;if((gf|0)>1){jf=gf-1|0;kf=Ee|hf<<1}else{ve=fe(Ee>>>((1-gf|0)>>>0)|hf<<gf|0)|0;Fe=f+796|0;Ce=c[Fe>>2]|0;x=ve;a[Ce]=x;x=x>>8;a[Ce+1|0]=x;x=x>>8;a[Ce+2|0]=x;x=x>>8;a[Ce+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;jf=gf+31|0;kf=Ee}c[Be>>2]=kf;c[De>>2]=jf;lf=kf;mf=jf}else{lf=hf;mf=gf}Ee=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((mf|0)>5){nf=mf-5|0;of=Ee|lf<<5}else{Fe=fe(Ee>>>((5-mf|0)>>>0)|lf<<mf|0)|0;Ce=f+796|0;ve=c[Ce>>2]|0;x=Fe;a[ve]=x;x=x>>8;a[ve+1|0]=x;x=x>>8;a[ve+2|0]=x;x=x>>8;a[ve+3|0]=x;c[Ce>>2]=(c[Ce>>2]|0)+4;nf=mf+27|0;of=Ee}c[Be>>2]=of;c[De>>2]=nf;ff=nf;break}else{Ce=d[904944+Ee|0]|0;if((mf|0)>5){pf=mf-5|0;qf=Ce|lf<<5}else{Ee=fe(Ce>>>((5-mf|0)>>>0)|lf<<mf|0)|0;ve=f+796|0;Fe=c[ve>>2]|0;x=Ee;a[Fe]=x;x=x>>8;a[Fe+1|0]=x;x=x>>8;a[Fe+2|0]=x;x=x>>8;a[Fe+3|0]=x;c[ve>>2]=(c[ve>>2]|0)+4;pf=mf+27|0;qf=Ce}c[Be>>2]=qf;c[De>>2]=pf;ff=pf;break}}}while(0);Be=f+796|0;Ge=((c[Be>>2]|0)-(c[f+792>>2]|0)<<3)+(32-ff)|0;pe=f+13700|0;Ce=c[pe>>2]|0;c[pe>>2]=Ge;pe=f+13696|0;c[pe>>2]=(c[pe>>2]|0)-Ce+Ge;Ge=f+13680|0;c[Ge>>2]=(c[Ge>>2]|0)+1;TGb(f+11824|0,0,32)|0;Xe=ff;Ye=re;Ze=De;_e=Be;$e=ne;break}Be=(c[f+11740>>2]|0)==0;Ge=(ne|0)!=0;if((Ae|0)==2){if(Be){do{if(Ge){Ce=(c[f+9984>>2]|0)!=0;pe=f+784|0;ve=f+788|0;if((j|h|0)==0){do{if(Ce){if((ze|0)>5){rf=ze-5|0;sf=ye<<5|1}else{Fe=fe(1>>>((5-ze|0)>>>0)|ye<<ze|0)|0;Ee=f+796|0;we=c[Ee>>2]|0;x=Fe;a[we]=x;x=x>>8;a[we+1|0]=x;x=x>>8;a[we+2|0]=x;x=x>>8;a[we+3|0]=x;c[Ee>>2]=(c[Ee>>2]|0)+4;rf=ze+27|0;sf=1}c[pe>>2]=sf;c[ve>>2]=rf;if((c[f+14180>>2]|0)==0){Ee=c[f+14236>>2]|0;if((rf|0)>1){tf=rf-1|0;uf=Ee|sf<<1}else{we=fe(Ee>>>((1-rf|0)>>>0)|sf<<rf|0)|0;Fe=f+796|0;l=c[Fe>>2]|0;x=we;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;tf=rf+31|0;uf=Ee}c[pe>>2]=uf;c[ve>>2]=tf;vf=uf;wf=tf}else{vf=sf;wf=rf}Ee=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((wf|0)>5){xf=wf-5|0;yf=Ee|vf<<5}else{Fe=fe(Ee>>>((5-wf|0)>>>0)|vf<<wf|0)|0;l=f+796|0;we=c[l>>2]|0;x=Fe;a[we]=x;x=x>>8;a[we+1|0]=x;x=x>>8;a[we+2|0]=x;x=x>>8;a[we+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;xf=wf+27|0;yf=Ee}c[pe>>2]=yf;c[ve>>2]=xf;zf=xf;break}else{l=d[904944+Ee|0]|0;if((wf|0)>5){Af=wf-5|0;Bf=l|vf<<5}else{Ee=fe(l>>>((5-wf|0)>>>0)|vf<<wf|0)|0;we=f+796|0;Fe=c[we>>2]|0;x=Ee;a[Fe]=x;x=x>>8;a[Fe+1|0]=x;x=x>>8;a[Fe+2|0]=x;x=x>>8;a[Fe+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;Af=wf+27|0;Bf=l}c[pe>>2]=Bf;c[ve>>2]=Af;zf=Af;break}}else{if((ze|0)>2){Cf=ze-2|0;Df=ye<<2|1}else{l=fe(1>>>((2-ze|0)>>>0)|ye<<ze|0)|0;we=f+796|0;Fe=c[we>>2]|0;x=l;a[Fe]=x;x=x>>8;a[Fe+1|0]=x;x=x>>8;a[Fe+2|0]=x;x=x>>8;a[Fe+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;Cf=ze+30|0;Df=1}c[pe>>2]=Df;c[ve>>2]=Cf;if((c[f+14180>>2]|0)!=0){zf=Cf;break}we=c[f+14236>>2]|0;if((Cf|0)>1){Ef=Cf-1|0;Ff=we|Df<<1}else{Fe=fe(we>>>((1-Cf|0)>>>0)|Df<<Cf|0)|0;l=f+796|0;Ee=c[l>>2]|0;x=Fe;a[Ee]=x;x=x>>8;a[Ee+1|0]=x;x=x>>8;a[Ee+2|0]=x;x=x>>8;a[Ee+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;Ef=Cf+31|0;Ff=we}c[pe>>2]=Ff;c[ve>>2]=Ef;zf=Ef}}while(0);we=c[f+796>>2]|0;l=(we-(c[f+792>>2]|0)<<3)+(32-zf)|0;Ee=f+13700|0;Fe=c[Ee>>2]|0;c[Ee>>2]=l;Ee=f+13696|0;c[Ee>>2]=(c[Ee>>2]|0)-Fe+l;Gf=zf;Hf=we;If=f+11824|0;Jf=f+11828|0;break}do{if(Ce){if((ze|0)>5){Kf=ze-5|0;Lf=ye<<5|2}else{we=fe(2>>>((5-ze|0)>>>0)|ye<<ze|0)|0;l=f+796|0;Fe=c[l>>2]|0;x=we;a[Fe]=x;x=x>>8;a[Fe+1|0]=x;x=x>>8;a[Fe+2|0]=x;x=x>>8;a[Fe+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;Kf=ze+27|0;Lf=2}c[pe>>2]=Lf;c[ve>>2]=Kf;if((c[f+14180>>2]|0)==0){if((Kf|0)>2){Mf=Kf-2|0;Nf=Lf<<2|2}else{l=fe(2>>>((2-Kf|0)>>>0)|Lf<<Kf|0)|0;Fe=f+796|0;we=c[Fe>>2]|0;x=l;a[we]=x;x=x>>8;a[we+1|0]=x;x=x>>8;a[we+2|0]=x;x=x>>8;a[we+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;Mf=Kf+30|0;Nf=2}c[pe>>2]=Nf;c[ve>>2]=Mf;Fe=c[f+14236>>2]|0;if((Mf|0)>1){Of=Mf-1|0;Pf=Fe|Nf<<1}else{we=fe(Fe>>>((1-Mf|0)>>>0)|Nf<<Mf|0)|0;l=f+796|0;Ee=c[l>>2]|0;x=we;a[Ee]=x;x=x>>8;a[Ee+1|0]=x;x=x>>8;a[Ee+2|0]=x;x=x>>8;a[Ee+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;Of=Mf+31|0;Pf=Fe}c[pe>>2]=Pf;c[ve>>2]=Of;Qf=Pf;Rf=Of}else{Qf=Lf;Rf=Kf}Fe=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Rf|0)>5){Sf=Rf-5|0;Tf=Fe|Qf<<5}else{l=fe(Fe>>>((5-Rf|0)>>>0)|Qf<<Rf|0)|0;Ee=f+796|0;we=c[Ee>>2]|0;x=l;a[we]=x;x=x>>8;a[we+1|0]=x;x=x>>8;a[we+2|0]=x;x=x>>8;a[we+3|0]=x;c[Ee>>2]=(c[Ee>>2]|0)+4;Sf=Rf+27|0;Tf=Fe}c[pe>>2]=Tf;c[ve>>2]=Sf;Uf=Sf;break}else{Ee=d[904944+Fe|0]|0;if((Rf|0)>5){Vf=Rf-5|0;Wf=Ee|Qf<<5}else{Fe=fe(Ee>>>((5-Rf|0)>>>0)|Qf<<Rf|0)|0;we=f+796|0;l=c[we>>2]|0;x=Fe;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;Vf=Rf+27|0;Wf=Ee}c[pe>>2]=Wf;c[ve>>2]=Vf;Uf=Vf;break}}else{if((ze|0)>1){Xf=ze-1|0;Yf=ye<<1|1}else{Ee=fe(1>>>((1-ze|0)>>>0)|ye<<ze|0)|0;we=f+796|0;l=c[we>>2]|0;x=Ee;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;Xf=ze+31|0;Yf=1}c[pe>>2]=Yf;c[ve>>2]=Xf;if((c[f+14180>>2]|0)!=0){Uf=Xf;break}if((Xf|0)>2){Zf=Xf-2|0;_f=Yf<<2|2}else{we=fe(2>>>((2-Xf|0)>>>0)|Yf<<Xf|0)|0;l=f+796|0;Ee=c[l>>2]|0;x=we;a[Ee]=x;x=x>>8;a[Ee+1|0]=x;x=x>>8;a[Ee+2|0]=x;x=x>>8;a[Ee+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;Zf=Xf+30|0;_f=2}c[pe>>2]=_f;c[ve>>2]=Zf;l=c[f+14236>>2]|0;if((Zf|0)>1){$f=Zf-1|0;ag=l|_f<<1}else{Ee=fe(l>>>((1-Zf|0)>>>0)|_f<<Zf|0)|0;we=f+796|0;Fe=c[we>>2]|0;x=Ee;a[Fe]=x;x=x>>8;a[Fe+1|0]=x;x=x>>8;a[Fe+2|0]=x;x=x>>8;a[Fe+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;$f=Zf+31|0;ag=l}c[pe>>2]=ag;c[ve>>2]=$f;Uf=$f}}while(0);pe=f+792|0;Ce=f+796|0;l=((c[Ce>>2]|0)-(c[pe>>2]|0)<<3)+(32-Uf)|0;we=f+13700|0;Fe=c[we>>2]|0;c[we>>2]=l;Ee=f+13696|0;c[Ee>>2]=(c[Ee>>2]|0)-Fe+l;l=f+11824|0;Fe=f+11556|0;PMa(f,h-(c[l>>2]|0)|0,c[Fe>>2]|0);Ee=f+11828|0;PMa(f,j-(c[Ee>>2]|0)|0,c[Fe>>2]|0);Fe=c[ve>>2]|0;xe=c[Ce>>2]|0;Ce=(xe-(c[pe>>2]|0)<<3)+(32-Fe)|0;pe=c[we>>2]|0;c[we>>2]=Ce;we=f+13664|0;c[we>>2]=(c[we>>2]|0)-pe+Ce;Gf=Fe;Hf=xe;If=l;Jf=Ee}else{Ee=f+784|0;l=f+788|0;if((ze|0)>3){bg=ze-3|0;cg=ye<<3|1}else{xe=fe(1>>>((3-ze|0)>>>0)|ye<<ze|0)|0;Fe=f+796|0;Ce=c[Fe>>2]|0;x=xe;a[Ce]=x;x=x>>8;a[Ce+1|0]=x;x=x>>8;a[Ce+2|0]=x;x=x>>8;a[Ce+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;bg=ze+29|0;cg=1}c[Ee>>2]=cg;c[l>>2]=bg;if((c[f+14180>>2]|0)==0){if((bg|0)>2){dg=bg-2|0;eg=cg<<2|2}else{Fe=fe(2>>>((2-bg|0)>>>0)|cg<<bg|0)|0;Ce=f+796|0;xe=c[Ce>>2]|0;x=Fe;a[xe]=x;x=x>>8;a[xe+1|0]=x;x=x>>8;a[xe+2|0]=x;x=x>>8;a[xe+3|0]=x;c[Ce>>2]=(c[Ce>>2]|0)+4;dg=bg+30|0;eg=2}c[Ee>>2]=eg;c[l>>2]=dg;fg=dg}else{fg=bg}Ee=f+792|0;Ce=f+796|0;xe=((c[Ce>>2]|0)-(c[Ee>>2]|0)<<3)+(32-fg)|0;Fe=f+13700|0;pe=c[Fe>>2]|0;c[Fe>>2]=xe;we=f+13696|0;c[we>>2]=(c[we>>2]|0)-pe+xe;xe=f+11824|0;pe=f+11556|0;PMa(f,h-(c[xe>>2]|0)|0,c[pe>>2]|0);we=f+11828|0;PMa(f,j-(c[we>>2]|0)|0,c[pe>>2]|0);pe=f+9960|0;c[pe>>2]=(c[pe>>2]|0)-(c[f+9984>>2]|0);pe=c[l>>2]|0;l=c[Ce>>2]|0;Ce=(l-(c[Ee>>2]|0)<<3)+(32-pe)|0;Ee=c[Fe>>2]|0;c[Fe>>2]=Ce;Fe=f+13664|0;c[Fe>>2]=(c[Fe>>2]|0)-Ee+Ce;Gf=pe;Hf=l;If=xe;Jf=we}}while(0);c[If>>2]=h;c[f+11832>>2]=h;c[Jf>>2]=j;c[f+11836>>2]=j;gg=Gf;hg=Hf}else{do{if(Ge){De=f+784|0;we=f+788|0;if((c[f+9984>>2]|0)==0){if((ze|0)>1){ig=ze-1|0;jg=ye<<1|1}else{xe=fe(1>>>((1-ze|0)>>>0)|ye<<ze|0)|0;l=f+796|0;pe=c[l>>2]|0;x=xe;a[pe]=x;x=x>>8;a[pe+1|0]=x;x=x>>8;a[pe+2|0]=x;x=x>>8;a[pe+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;ig=ze+31|0;jg=1}c[De>>2]=jg;c[we>>2]=ig;if((c[f+14180>>2]|0)!=0){kg=ig;lg=jg;break}if((ig|0)>2){mg=ig-2|0;ng=jg<<2|1}else{l=fe(1>>>((2-ig|0)>>>0)|jg<<ig|0)|0;pe=f+796|0;xe=c[pe>>2]|0;x=l;a[xe]=x;x=x>>8;a[xe+1|0]=x;x=x>>8;a[xe+2|0]=x;x=x>>8;a[xe+3|0]=x;c[pe>>2]=(c[pe>>2]|0)+4;mg=ig+30|0;ng=1}c[De>>2]=ng;c[we>>2]=mg;pe=c[f+14236>>2]|0;if((mg|0)>1){og=mg-1|0;pg=pe|ng<<1}else{xe=fe(pe>>>((1-mg|0)>>>0)|ng<<mg|0)|0;l=f+796|0;Ce=c[l>>2]|0;x=xe;a[Ce]=x;x=x>>8;a[Ce+1|0]=x;x=x>>8;a[Ce+2|0]=x;x=x>>8;a[Ce+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;og=mg+31|0;pg=pe}c[De>>2]=pg;c[we>>2]=og;kg=og;lg=pg;break}if((ze|0)>5){qg=ze-5|0;rg=ye<<5|2}else{pe=fe(2>>>((5-ze|0)>>>0)|ye<<ze|0)|0;l=f+796|0;Ce=c[l>>2]|0;x=pe;a[Ce]=x;x=x>>8;a[Ce+1|0]=x;x=x>>8;a[Ce+2|0]=x;x=x>>8;a[Ce+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;qg=ze+27|0;rg=2}c[De>>2]=rg;c[we>>2]=qg;if((c[f+14180>>2]|0)==0){if((qg|0)>2){sg=qg-2|0;tg=rg<<2|1}else{l=fe(1>>>((2-qg|0)>>>0)|rg<<qg|0)|0;Ce=f+796|0;pe=c[Ce>>2]|0;x=l;a[pe]=x;x=x>>8;a[pe+1|0]=x;x=x>>8;a[pe+2|0]=x;x=x>>8;a[pe+3|0]=x;c[Ce>>2]=(c[Ce>>2]|0)+4;sg=qg+30|0;tg=1}c[De>>2]=tg;c[we>>2]=sg;Ce=c[f+14236>>2]|0;if((sg|0)>1){ug=sg-1|0;vg=Ce|tg<<1}else{pe=fe(Ce>>>((1-sg|0)>>>0)|tg<<sg|0)|0;l=f+796|0;xe=c[l>>2]|0;x=pe;a[xe]=x;x=x>>8;a[xe+1|0]=x;x=x>>8;a[xe+2|0]=x;x=x>>8;a[xe+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;ug=sg+31|0;vg=Ce}c[De>>2]=vg;c[we>>2]=ug;wg=vg;xg=ug}else{wg=rg;xg=qg}Ce=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((xg|0)>5){yg=xg-5|0;zg=Ce|wg<<5}else{l=fe(Ce>>>((5-xg|0)>>>0)|wg<<xg|0)|0;xe=f+796|0;pe=c[xe>>2]|0;x=l;a[pe]=x;x=x>>8;a[pe+1|0]=x;x=x>>8;a[pe+2|0]=x;x=x>>8;a[pe+3|0]=x;c[xe>>2]=(c[xe>>2]|0)+4;yg=xg+27|0;zg=Ce}c[De>>2]=zg;c[we>>2]=yg;kg=yg;lg=zg;break}else{xe=d[904944+Ce|0]|0;if((xg|0)>5){Ag=xg-5|0;Bg=xe|wg<<5}else{Ce=fe(xe>>>((5-xg|0)>>>0)|wg<<xg|0)|0;pe=f+796|0;l=c[pe>>2]|0;x=Ce;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[pe>>2]=(c[pe>>2]|0)+4;Ag=xg+27|0;Bg=xe}c[De>>2]=Bg;c[we>>2]=Ag;kg=Ag;lg=Bg;break}}else{we=f+784|0;De=f+788|0;if((ze|0)>3){Cg=ze-3|0;Dg=ye<<3|1}else{xe=fe(1>>>((3-ze|0)>>>0)|ye<<ze|0)|0;pe=f+796|0;l=c[pe>>2]|0;x=xe;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[pe>>2]=(c[pe>>2]|0)+4;Cg=ze+29|0;Dg=1}c[we>>2]=Dg;c[De>>2]=Cg;if((Cg|0)>2){Eg=Cg-2|0;Fg=Dg<<2|1}else{pe=fe(1>>>((2-Cg|0)>>>0)|Dg<<Cg|0)|0;l=f+796|0;xe=c[l>>2]|0;x=pe;a[xe]=x;x=x>>8;a[xe+1|0]=x;x=x>>8;a[xe+2|0]=x;x=x>>8;a[xe+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;Eg=Cg+30|0;Fg=1}c[we>>2]=Fg;c[De>>2]=Eg;De=f+9960|0;c[De>>2]=(c[De>>2]|0)-(c[f+9984>>2]|0);kg=Eg;lg=Fg}}while(0);De=f+788|0;we=f+792|0;l=f+796|0;xe=c[l>>2]|0;pe=(xe-(c[we>>2]|0)<<3)+(32-kg)|0;Ce=f+13700|0;Ee=c[Ce>>2]|0;c[Ce>>2]=pe;Fe=f+13696|0;c[Fe>>2]=(c[Fe>>2]|0)-Ee+pe;pe=f+784|0;Ee=f+11556|0;Fe=c[f+11808>>2]|0;if((kg|0)>1){Gg=kg-1|0;Hg=Fe|lg<<1}else{y=xe;x=fe(Fe>>>((1-kg|0)>>>0)|lg<<kg|0)|0;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;Gg=kg+31|0;Hg=Fe}c[pe>>2]=Hg;c[De>>2]=Gg;Fe=f+11744|0;y=f+11824|0;PMa(f,(c[Fe>>2]|0)-(c[y>>2]|0)|0,c[Ee>>2]|0);xe=f+11748|0;se=f+11828|0;PMa(f,(c[xe>>2]|0)-(c[se>>2]>>1)|0,c[Ee>>2]|0);c[y>>2]=c[Fe>>2];c[se>>2]=c[xe>>2]<<1;xe=c[f+11812>>2]|0;se=c[pe>>2]|0;Fe=c[De>>2]|0;if((Fe|0)>1){Ig=Fe-1|0;Jg=se<<1|xe}else{y=fe(xe>>>((1-Fe|0)>>>0)|se<<Fe|0)|0;se=c[l>>2]|0;x=y;a[se]=x;x=x>>8;a[se+1|0]=x;x=x>>8;a[se+2|0]=x;x=x>>8;a[se+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;Ig=Fe+31|0;Jg=xe}c[pe>>2]=Jg;c[De>>2]=Ig;pe=f+11752|0;xe=f+11832|0;PMa(f,(c[pe>>2]|0)-(c[xe>>2]|0)|0,c[Ee>>2]|0);Fe=f+11756|0;se=f+11836|0;PMa(f,(c[Fe>>2]|0)-(c[se>>2]>>1)|0,c[Ee>>2]|0);c[xe>>2]=c[pe>>2];c[se>>2]=c[Fe>>2]<<1;Fe=c[De>>2]|0;De=c[l>>2]|0;l=(De-(c[we>>2]|0)<<3)+(32-Fe)|0;we=c[Ce>>2]|0;c[Ce>>2]=l;Ce=f+13664|0;c[Ce>>2]=(c[Ce>>2]|0)-we+l;gg=Fe;hg=De}do{if(Ge){De=f+784|0;if((c[f+14220>>2]|0)!=0){Fe=d[1179961+(ne<<1)|0]|0;l=d[1179960+(ne<<1)|0]|0;we=De|0;Ce=c[we>>2]|0;se=f+788|0;if((gg|0)>(Fe|0)){Kg=gg;Lg=Ce<<Fe|l}else{pe=f+796|0;xe=hg;x=fe(l>>>((Fe-gg|0)>>>0)|Ce<<gg|0)|0;a[xe]=x;x=x>>8;a[xe+1|0]=x;x=x>>8;a[xe+2|0]=x;x=x>>8;a[xe+3|0]=x;c[pe>>2]=(c[pe>>2]|0)+4;Kg=gg+32|0;Lg=l}l=Kg-Fe|0;c[we>>2]=Lg;c[se>>2]=l;Mg=l;Ng=se;Og=ne;break}se=ne>>2;l=d[1179961+(se<<1)|0]|0;we=d[1179960+(se<<1)|0]|0;se=De|0;De=c[se>>2]|0;Fe=f+788|0;if((gg|0)>(l|0)){Pg=gg;Qg=De<<l|we;Rg=hg}else{pe=f+796|0;xe=hg;x=fe(we>>>((l-gg|0)>>>0)|De<<gg|0)|0;a[xe]=x;x=x>>8;a[xe+1|0]=x;x=x>>8;a[xe+2|0]=x;x=x>>8;a[xe+3|0]=x;xe=(c[pe>>2]|0)+4|0;c[pe>>2]=xe;Pg=gg+32|0;Qg=we;Rg=xe}xe=Pg-l|0;c[se>>2]=Qg;c[Fe>>2]=xe;l=ne&3;if((xe|0)>2){Sg=xe-2|0;Tg=Qg<<2|l}else{we=f+796|0;pe=Rg;x=fe(l>>>((2-xe|0)>>>0)|Qg<<xe|0)|0;a[pe]=x;x=x>>8;a[pe+1|0]=x;x=x>>8;a[pe+2|0]=x;x=x>>8;a[pe+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;Sg=xe+30|0;Tg=l}c[se>>2]=Tg;c[Fe>>2]=Sg;Mg=Sg;Ng=Fe;Og=ne}else{Mg=gg;Ng=f+788|0;Og=0}}while(0);Fe=f+13684|0;c[Fe>>2]=(c[Fe>>2]|0)+1;Xe=Mg;Ye=re;Ze=Ng;_e=f+796|0;$e=Og;break}do{if(Be){do{if(Ge){Fe=c[f+11736>>2]|0;if((c[f+9984>>2]|0)==0){se=5-Fe|0;l=f+784|0;xe=f+788|0;if((ze|0)>(se|0)){Ug=ze;Vg=ye<<se|3}else{we=fe(3>>>((se-ze|0)>>>0)|ye<<ze|0)|0;pe=f+796|0;De=c[pe>>2]|0;x=we;a[De]=x;x=x>>8;a[De+1|0]=x;x=x>>8;a[De+2|0]=x;x=x>>8;a[De+3|0]=x;c[pe>>2]=(c[pe>>2]|0)+4;Ug=ze+32|0;Vg=3}pe=Ug-se|0;c[l>>2]=Vg;c[xe>>2]=pe;if((c[f+14180>>2]|0)!=0){Wg=pe;break}if((pe|0)>2){Xg=pe-2|0;Yg=Vg<<2|2}else{se=fe(2>>>((2-pe|0)>>>0)|Vg<<pe|0)|0;De=f+796|0;we=c[De>>2]|0;x=se;a[we]=x;x=x>>8;a[we+1|0]=x;x=x>>8;a[we+2|0]=x;x=x>>8;a[we+3|0]=x;c[De>>2]=(c[De>>2]|0)+4;Xg=pe+30|0;Yg=2}c[l>>2]=Yg;c[xe>>2]=Xg;pe=c[f+14236>>2]|0;if((Xg|0)>1){Zg=Xg-1|0;_g=pe|Yg<<1}else{De=fe(pe>>>((1-Xg|0)>>>0)|Yg<<Xg|0)|0;we=f+796|0;se=c[we>>2]|0;x=De;a[se]=x;x=x>>8;a[se+1|0]=x;x=x>>8;a[se+2|0]=x;x=x>>8;a[se+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;Zg=Xg+31|0;_g=pe}c[l>>2]=_g;c[xe>>2]=Zg;Wg=Zg;break}do{if((Fe|0)==1){xe=f+784|0;l=f+788|0;if((ze|0)>6){$g=ze-6|0;ah=ye<<6|3}else{pe=fe(3>>>((6-ze|0)>>>0)|ye<<ze|0)|0;we=f+796|0;se=c[we>>2]|0;x=pe;a[se]=x;x=x>>8;a[se+1|0]=x;x=x>>8;a[se+2|0]=x;x=x>>8;a[se+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;$g=ze+26|0;ah=3}c[xe>>2]=ah;c[l>>2]=$g;if((c[f+14180>>2]|0)!=0){bh=ah;ch=$g;break}if(($g|0)>2){dh=$g-2|0;eh=ah<<2|2}else{we=fe(2>>>((2-$g|0)>>>0)|ah<<$g|0)|0;se=f+796|0;pe=c[se>>2]|0;x=we;a[pe]=x;x=x>>8;a[pe+1|0]=x;x=x>>8;a[pe+2|0]=x;x=x>>8;a[pe+3|0]=x;c[se>>2]=(c[se>>2]|0)+4;dh=$g+30|0;eh=2}c[xe>>2]=eh;c[l>>2]=dh;se=c[f+14236>>2]|0;if((dh|0)>1){fh=dh-1|0;gh=se|eh<<1}else{pe=fe(se>>>((1-dh|0)>>>0)|eh<<dh|0)|0;we=f+796|0;De=c[we>>2]|0;x=pe;a[De]=x;x=x>>8;a[De+1|0]=x;x=x>>8;a[De+2|0]=x;x=x>>8;a[De+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;fh=dh+31|0;gh=se}c[xe>>2]=gh;c[l>>2]=fh;bh=gh;ch=fh}else{l=8-Fe|0;xe=f+784|0;se=f+788|0;if((ze|0)>(l|0)){hh=ze;ih=ye<<l|2}else{we=fe(2>>>((l-ze|0)>>>0)|ye<<ze|0)|0;De=f+796|0;pe=c[De>>2]|0;x=we;a[pe]=x;x=x>>8;a[pe+1|0]=x;x=x>>8;a[pe+2|0]=x;x=x>>8;a[pe+3|0]=x;c[De>>2]=(c[De>>2]|0)+4;hh=ze+32|0;ih=2}De=hh-l|0;c[xe>>2]=ih;c[se>>2]=De;if((c[f+14180>>2]|0)!=0){bh=ih;ch=De;break}if((De|0)>2){jh=De-2|0;kh=ih<<2|2}else{l=fe(2>>>((2-De|0)>>>0)|ih<<De|0)|0;pe=f+796|0;we=c[pe>>2]|0;x=l;a[we]=x;x=x>>8;a[we+1|0]=x;x=x>>8;a[we+2|0]=x;x=x>>8;a[we+3|0]=x;c[pe>>2]=(c[pe>>2]|0)+4;jh=De+30|0;kh=2}c[xe>>2]=kh;c[se>>2]=jh;De=c[f+14236>>2]|0;if((jh|0)>1){lh=jh-1|0;mh=De|kh<<1}else{pe=fe(De>>>((1-jh|0)>>>0)|kh<<jh|0)|0;we=f+796|0;l=c[we>>2]|0;x=pe;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;lh=jh+31|0;mh=De}c[xe>>2]=mh;c[se>>2]=lh;bh=mh;ch=lh}}while(0);Fe=f+784|0;se=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((ch|0)>5){nh=ch-5|0;oh=se|bh<<5}else{xe=fe(se>>>((5-ch|0)>>>0)|bh<<ch|0)|0;De=f+796|0;we=c[De>>2]|0;x=xe;a[we]=x;x=x>>8;a[we+1|0]=x;x=x>>8;a[we+2|0]=x;x=x>>8;a[we+3|0]=x;c[De>>2]=(c[De>>2]|0)+4;nh=ch+27|0;oh=se}c[Fe>>2]=oh;c[f+788>>2]=nh;Wg=nh;break}else{De=d[904944+se|0]|0;if((ch|0)>5){ph=ch-5|0;qh=De|bh<<5}else{se=fe(De>>>((5-ch|0)>>>0)|bh<<ch|0)|0;we=f+796|0;xe=c[we>>2]|0;x=se;a[xe]=x;x=x>>8;a[xe+1|0]=x;x=x>>8;a[xe+2|0]=x;x=x>>8;a[xe+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;ph=ch+27|0;qh=De}c[Fe>>2]=qh;c[f+788>>2]=ph;Wg=ph;break}}else{Fe=5-(c[f+11736>>2]|0)|0;De=f+784|0;we=f+788|0;if((ze|0)>(Fe|0)){rh=ze;sh=ye<<Fe|2}else{xe=fe(2>>>((Fe-ze|0)>>>0)|ye<<ze|0)|0;se=f+796|0;l=c[se>>2]|0;x=xe;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[se>>2]=(c[se>>2]|0)+4;rh=ze+32|0;sh=2}se=rh-Fe|0;c[De>>2]=sh;c[we>>2]=se;if((c[f+14180>>2]|0)==0){if((se|0)>2){th=se-2|0;uh=sh<<2|2}else{Fe=fe(2>>>((2-se|0)>>>0)|sh<<se|0)|0;l=f+796|0;xe=c[l>>2]|0;x=Fe;a[xe]=x;x=x>>8;a[xe+1|0]=x;x=x>>8;a[xe+2|0]=x;x=x>>8;a[xe+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;th=se+30|0;uh=2}c[De>>2]=uh;c[we>>2]=th;vh=th}else{vh=se}se=f+9960|0;c[se>>2]=(c[se>>2]|0)-(c[f+9984>>2]|0);Wg=vh}}while(0);ve=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-Wg)|0;se=f+13700|0;we=c[se>>2]|0;c[se>>2]=ve;se=f+13696|0;c[se>>2]=(c[se>>2]|0)-we+ve;ve=f+11736|0;we=c[ve>>2]|0;if((we&1|0)==0){wh=we}else{we=f+11744|0;se=f+11824|0;De=f+11556|0;PMa(f,(c[we>>2]|0)-(c[se>>2]|0)|0,c[De>>2]|0);l=f+11748|0;xe=f+11828|0;PMa(f,(c[l>>2]|0)-(c[xe>>2]|0)|0,c[De>>2]|0);De=c[we>>2]|0;c[f+11832>>2]=De;c[se>>2]=De;De=c[l>>2]|0;c[f+11836>>2]=De;c[xe>>2]=De;De=f+13684|0;c[De>>2]=(c[De>>2]|0)+1;wh=c[ve>>2]|0}if((wh&2|0)==0){break}ve=f+11776|0;De=f+11840|0;xe=f+11560|0;PMa(f,(c[ve>>2]|0)-(c[De>>2]|0)|0,c[xe>>2]|0);l=f+11780|0;se=f+11844|0;PMa(f,(c[l>>2]|0)-(c[se>>2]|0)|0,c[xe>>2]|0);xe=c[ve>>2]|0;c[f+11848>>2]=xe;c[De>>2]=xe;xe=c[l>>2]|0;c[f+11852>>2]=xe;c[se>>2]=xe;xe=f+13688|0;c[xe>>2]=(c[xe>>2]|0)+1}else{do{if(Ge){xe=c[f+11736>>2]|0;if((c[f+9984>>2]|0)==0){se=5-xe|0;l=f+784|0;De=f+788|0;if((ze|0)>(se|0)){xh=ze;yh=ye<<se|3}else{ve=fe(3>>>((se-ze|0)>>>0)|ye<<ze|0)|0;we=f+796|0;Fe=c[we>>2]|0;x=ve;a[Fe]=x;x=x>>8;a[Fe+1|0]=x;x=x>>8;a[Fe+2|0]=x;x=x>>8;a[Fe+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;xh=ze+32|0;yh=3}we=xh-se|0;c[l>>2]=yh;c[De>>2]=we;if((c[f+14180>>2]|0)!=0){zh=we;Ah=yh;break}if((we|0)>2){Bh=we-2|0;Ch=yh<<2|1}else{se=fe(1>>>((2-we|0)>>>0)|yh<<we|0)|0;Fe=f+796|0;ve=c[Fe>>2]|0;x=se;a[ve]=x;x=x>>8;a[ve+1|0]=x;x=x>>8;a[ve+2|0]=x;x=x>>8;a[ve+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;Bh=we+30|0;Ch=1}c[l>>2]=Ch;c[De>>2]=Bh;we=c[f+14236>>2]|0;if((Bh|0)>1){Dh=Bh-1|0;Eh=we|Ch<<1}else{Fe=fe(we>>>((1-Bh|0)>>>0)|Ch<<Bh|0)|0;ve=f+796|0;se=c[ve>>2]|0;x=Fe;a[se]=x;x=x>>8;a[se+1|0]=x;x=x>>8;a[se+2|0]=x;x=x>>8;a[se+3|0]=x;c[ve>>2]=(c[ve>>2]|0)+4;Dh=Bh+31|0;Eh=we}c[l>>2]=Eh;c[De>>2]=Dh;zh=Dh;Ah=Eh;break}do{if((xe|0)==1){De=f+784|0;l=f+788|0;if((ze|0)>6){Fh=ze-6|0;Gh=ye<<6|3}else{we=fe(3>>>((6-ze|0)>>>0)|ye<<ze|0)|0;ve=f+796|0;se=c[ve>>2]|0;x=we;a[se]=x;x=x>>8;a[se+1|0]=x;x=x>>8;a[se+2|0]=x;x=x>>8;a[se+3|0]=x;c[ve>>2]=(c[ve>>2]|0)+4;Fh=ze+26|0;Gh=3}c[De>>2]=Gh;c[l>>2]=Fh;if((c[f+14180>>2]|0)!=0){Hh=Gh;Ih=Fh;break}if((Fh|0)>2){Jh=Fh-2|0;Kh=Gh<<2|1}else{ve=fe(1>>>((2-Fh|0)>>>0)|Gh<<Fh|0)|0;se=f+796|0;we=c[se>>2]|0;x=ve;a[we]=x;x=x>>8;a[we+1|0]=x;x=x>>8;a[we+2|0]=x;x=x>>8;a[we+3|0]=x;c[se>>2]=(c[se>>2]|0)+4;Jh=Fh+30|0;Kh=1}c[De>>2]=Kh;c[l>>2]=Jh;se=c[f+14236>>2]|0;if((Jh|0)>1){Lh=Jh-1|0;Mh=se|Kh<<1}else{we=fe(se>>>((1-Jh|0)>>>0)|Kh<<Jh|0)|0;ve=f+796|0;Fe=c[ve>>2]|0;x=we;a[Fe]=x;x=x>>8;a[Fe+1|0]=x;x=x>>8;a[Fe+2|0]=x;x=x>>8;a[Fe+3|0]=x;c[ve>>2]=(c[ve>>2]|0)+4;Lh=Jh+31|0;Mh=se}c[De>>2]=Mh;c[l>>2]=Lh;Hh=Mh;Ih=Lh}else{l=8-xe|0;De=f+784|0;se=f+788|0;if((ze|0)>(l|0)){Nh=ze;Oh=ye<<l|2}else{ve=fe(2>>>((l-ze|0)>>>0)|ye<<ze|0)|0;Fe=f+796|0;we=c[Fe>>2]|0;x=ve;a[we]=x;x=x>>8;a[we+1|0]=x;x=x>>8;a[we+2|0]=x;x=x>>8;a[we+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;Nh=ze+32|0;Oh=2}Fe=Nh-l|0;c[De>>2]=Oh;c[se>>2]=Fe;if((c[f+14180>>2]|0)!=0){Hh=Oh;Ih=Fe;break}if((Fe|0)>2){Ph=Fe-2|0;Qh=Oh<<2|1}else{l=fe(1>>>((2-Fe|0)>>>0)|Oh<<Fe|0)|0;we=f+796|0;ve=c[we>>2]|0;x=l;a[ve]=x;x=x>>8;a[ve+1|0]=x;x=x>>8;a[ve+2|0]=x;x=x>>8;a[ve+3|0]=x;c[we>>2]=(c[we>>2]|0)+4;Ph=Fe+30|0;Qh=1}c[De>>2]=Qh;c[se>>2]=Ph;Fe=c[f+14236>>2]|0;if((Ph|0)>1){Rh=Ph-1|0;Sh=Fe|Qh<<1}else{we=fe(Fe>>>((1-Ph|0)>>>0)|Qh<<Ph|0)|0;ve=f+796|0;l=c[ve>>2]|0;x=we;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[ve>>2]=(c[ve>>2]|0)+4;Rh=Ph+31|0;Sh=Fe}c[De>>2]=Sh;c[se>>2]=Rh;Hh=Sh;Ih=Rh}}while(0);xe=f+784|0;se=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Ih|0)>5){Th=Ih-5|0;Uh=se|Hh<<5}else{De=fe(se>>>((5-Ih|0)>>>0)|Hh<<Ih|0)|0;Fe=f+796|0;ve=c[Fe>>2]|0;x=De;a[ve]=x;x=x>>8;a[ve+1|0]=x;x=x>>8;a[ve+2|0]=x;x=x>>8;a[ve+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;Th=Ih+27|0;Uh=se}c[xe>>2]=Uh;c[f+788>>2]=Th;zh=Th;Ah=Uh;break}else{Fe=d[904944+se|0]|0;if((Ih|0)>5){Vh=Ih-5|0;Wh=Fe|Hh<<5}else{se=fe(Fe>>>((5-Ih|0)>>>0)|Hh<<Ih|0)|0;ve=f+796|0;De=c[ve>>2]|0;x=se;a[De]=x;x=x>>8;a[De+1|0]=x;x=x>>8;a[De+2|0]=x;x=x>>8;a[De+3|0]=x;c[ve>>2]=(c[ve>>2]|0)+4;Vh=Ih+27|0;Wh=Fe}c[xe>>2]=Wh;c[f+788>>2]=Vh;zh=Vh;Ah=Wh;break}}else{xe=5-(c[f+11736>>2]|0)|0;Fe=f+784|0;ve=f+788|0;if((ze|0)>(xe|0)){Xh=ze;Yh=ye<<xe|2}else{De=fe(2>>>((xe-ze|0)>>>0)|ye<<ze|0)|0;se=f+796|0;l=c[se>>2]|0;x=De;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[se>>2]=(c[se>>2]|0)+4;Xh=ze+32|0;Yh=2}se=Xh-xe|0;c[Fe>>2]=Yh;c[ve>>2]=se;if((se|0)>2){Zh=se-2|0;_h=Yh<<2|1}else{xe=fe(1>>>((2-se|0)>>>0)|Yh<<se|0)|0;l=f+796|0;De=c[l>>2]|0;x=xe;a[De]=x;x=x>>8;a[De+1|0]=x;x=x>>8;a[De+2|0]=x;x=x>>8;a[De+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;Zh=se+30|0;_h=1}c[Fe>>2]=_h;c[ve>>2]=Zh;ve=f+9960|0;c[ve>>2]=(c[ve>>2]|0)-(c[f+9984>>2]|0);zh=Zh;Ah=_h}}while(0);ve=f+788|0;Fe=f+796|0;se=c[Fe>>2]|0;l=(se-(c[f+792>>2]|0)<<3)+(32-zh)|0;De=f+13700|0;xe=c[De>>2]|0;c[De>>2]=l;De=f+13696|0;c[De>>2]=(c[De>>2]|0)-xe+l;l=f+11736|0;xe=c[l>>2]|0;if((xe&1|0)==0){$h=xe}else{xe=f+784|0;De=f+11556|0;we=c[f+11808>>2]|0;if((zh|0)>1){ai=zh-1|0;bi=we|Ah<<1}else{pe=se;x=fe(we>>>((1-zh|0)>>>0)|Ah<<zh|0)|0;a[pe]=x;x=x>>8;a[pe+1|0]=x;x=x>>8;a[pe+2|0]=x;x=x>>8;a[pe+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;ai=zh+31|0;bi=we}c[xe>>2]=bi;c[ve>>2]=ai;we=f+11744|0;pe=f+11824|0;PMa(f,(c[we>>2]|0)-(c[pe>>2]|0)|0,c[De>>2]|0);se=f+11748|0;Ce=f+11828|0;PMa(f,(c[se>>2]|0)-(c[Ce>>2]>>1)|0,c[De>>2]|0);c[pe>>2]=c[we>>2];c[Ce>>2]=c[se>>2]<<1;se=c[f+11812>>2]|0;Ce=c[xe>>2]|0;we=c[ve>>2]|0;if((we|0)>1){ci=we-1|0;di=Ce<<1|se}else{pe=fe(se>>>((1-we|0)>>>0)|Ce<<we|0)|0;Ce=c[Fe>>2]|0;x=pe;a[Ce]=x;x=x>>8;a[Ce+1|0]=x;x=x>>8;a[Ce+2|0]=x;x=x>>8;a[Ce+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;ci=we+31|0;di=se}c[xe>>2]=di;c[ve>>2]=ci;xe=f+11752|0;se=f+11832|0;PMa(f,(c[xe>>2]|0)-(c[se>>2]|0)|0,c[De>>2]|0);we=f+11756|0;Ce=f+11836|0;PMa(f,(c[we>>2]|0)-(c[Ce>>2]>>1)|0,c[De>>2]|0);c[se>>2]=c[xe>>2];c[Ce>>2]=c[we>>2]<<1;we=f+13684|0;c[we>>2]=(c[we>>2]|0)+1;$h=c[l>>2]|0}if(($h&2|0)==0){break}l=f+784|0;we=f+11560|0;Ce=c[f+11816>>2]|0;xe=c[l>>2]|0;se=c[ve>>2]|0;if((se|0)>1){ei=se-1|0;fi=xe<<1|Ce}else{De=fe(Ce>>>((1-se|0)>>>0)|xe<<se|0)|0;xe=c[Fe>>2]|0;x=De;a[xe]=x;x=x>>8;a[xe+1|0]=x;x=x>>8;a[xe+2|0]=x;x=x>>8;a[xe+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;ei=se+31|0;fi=Ce}c[l>>2]=fi;c[ve>>2]=ei;Ce=f+11776|0;se=f+11840|0;PMa(f,(c[Ce>>2]|0)-(c[se>>2]|0)|0,c[we>>2]|0);xe=f+11780|0;De=f+11844|0;PMa(f,(c[xe>>2]|0)-(c[De>>2]>>1)|0,c[we>>2]|0);c[se>>2]=c[Ce>>2];c[De>>2]=c[xe>>2]<<1;xe=c[f+11820>>2]|0;De=c[l>>2]|0;Ce=c[ve>>2]|0;if((Ce|0)>1){gi=Ce-1|0;hi=De<<1|xe}else{se=fe(xe>>>((1-Ce|0)>>>0)|De<<Ce|0)|0;De=c[Fe>>2]|0;x=se;a[De]=x;x=x>>8;a[De+1|0]=x;x=x>>8;a[De+2|0]=x;x=x>>8;a[De+3|0]=x;c[Fe>>2]=(c[Fe>>2]|0)+4;gi=Ce+31|0;hi=xe}c[l>>2]=hi;c[ve>>2]=gi;ve=f+11784|0;l=f+11848|0;PMa(f,(c[ve>>2]|0)-(c[l>>2]|0)|0,c[we>>2]|0);xe=f+11788|0;Ce=f+11852|0;PMa(f,(c[xe>>2]|0)-(c[Ce>>2]>>1)|0,c[we>>2]|0);c[l>>2]=c[ve>>2];c[Ce>>2]=c[xe>>2]<<1;xe=f+13688|0;c[xe>>2]=(c[xe>>2]|0)+1}}while(0);Be=f+788|0;xe=c[Be>>2]|0;Ce=f+796|0;ve=c[Ce>>2]|0;l=(ve-(c[f+792>>2]|0)<<3)+(32-xe)|0;we=f+13700|0;Fe=c[we>>2]|0;c[we>>2]=l;we=f+13664|0;c[we>>2]=(c[we>>2]|0)-Fe+l;if(!Ge){Xe=xe;Ye=re;Ze=Be;_e=Ce;$e=0;break}l=f+784|0;if((c[f+14220>>2]|0)!=0){Fe=d[1179961+(ne<<1)|0]|0;we=d[1179960+(ne<<1)|0]|0;De=l|0;se=c[De>>2]|0;if((xe|0)>(Fe|0)){ii=xe;ji=se<<Fe|we}else{pe=ve;x=fe(we>>>((Fe-xe|0)>>>0)|se<<xe|0)|0;a[pe]=x;x=x>>8;a[pe+1|0]=x;x=x>>8;a[pe+2|0]=x;x=x>>8;a[pe+3|0]=x;c[Ce>>2]=(c[Ce>>2]|0)+4;ii=xe+32|0;ji=we}we=ii-Fe|0;c[De>>2]=ji;c[Be>>2]=we;Xe=we;Ye=re;Ze=Be;_e=Ce;$e=ne;break}we=ne>>2;De=d[1179961+(we<<1)|0]|0;Fe=d[1179960+(we<<1)|0]|0;we=l|0;l=c[we>>2]|0;if((xe|0)>(De|0)){ki=xe;li=l<<De|Fe;mi=ve}else{pe=ve;x=fe(Fe>>>((De-xe|0)>>>0)|l<<xe|0)|0;a[pe]=x;x=x>>8;a[pe+1|0]=x;x=x>>8;a[pe+2|0]=x;x=x>>8;a[pe+3|0]=x;pe=(c[Ce>>2]|0)+4|0;c[Ce>>2]=pe;ki=xe+32|0;li=Fe;mi=pe}pe=ki-De|0;c[we>>2]=li;c[Be>>2]=pe;De=ne&3;if((pe|0)>2){ni=pe-2|0;oi=li<<2|De}else{Fe=mi;x=fe(De>>>((2-pe|0)>>>0)|li<<pe|0)|0;a[Fe]=x;x=x>>8;a[Fe+1|0]=x;x=x>>8;a[Fe+2|0]=x;x=x>>8;a[Fe+3|0]=x;c[Ce>>2]=(c[Ce>>2]|0)+4;ni=pe+30|0;oi=De}c[we>>2]=oi;c[Be>>2]=ni;Xe=ni;Ye=re;Ze=Be;_e=Ce;$e=ne}}while(0);ne=f+784|0;ni=f+48|0;oi=f+14196|0;li=0;mi=Xe;while(1){if((1<<7-li&$e|0)==0){pi=mi}else{Xe=g+(li<<7)|0;ki=c[287048]|0;ji=c[f+180+(li<<2)>>2]|0;do{if((c[Ye>>2]|0)==0){ii=b[Xe>>1]|0;gi=ii<<16>>16;if(((ii<<16>>16>-1?gi:-gi|0)|0)!=1){qi=ki;ri=gi;si=-1;ti=0;break}ii=gi>>>31|2;gi=c[ne>>2]|0;if((mi|0)>2){ui=mi-2|0;vi=gi<<2|ii}else{hi=fe(gi<<mi|ii>>>((2-mi|0)>>>0)|0)|0;gi=c[_e>>2]|0;x=hi;a[gi]=x;x=x>>8;a[gi+1|0]=x;x=x>>8;a[gi+2|0]=x;x=x>>8;a[gi+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;ui=mi+30|0;vi=ii}c[ne>>2]=vi;c[Ze>>2]=ui;wi=ki;xi=0;yi=1;Kd=859}else{if((li|0)<4){zi=0}else{zi=(li&1)+1|0}ii=b[Xe>>1]|0;gi=f+9860+(zi<<2)|0;hi=ii-(c[gi>>2]|0)|0;ei=hi+255|0;do{if(ei>>>0>510>>>0){if((hi|0)<0){fi=hi*-2|0;$h=(fi&65280|0)==0;Ai=(d[1191992+($h?fi:fi>>>8)|0]|0)+($h?0:8)|0;Bi=hi-1|0}else{$h=hi<<1;fi=($h&65280|0)==0;Ai=(d[1191992+(fi?$h:hi>>>7&16777215)|0]|0)+(fi?0:8)|0;Bi=hi}if((zi|0)==0){fi=(d[1179904+Ai|0]|0)+Ai|0;$h=(e[1179880+(Ai<<1)>>1]<<Ai)+((1<<Ai)-1&Bi)|0;ci=c[ne>>2]|0;if((mi|0)>(fi|0)){Ci=mi;Di=$h|ci<<fi}else{di=fe($h>>>((fi-mi|0)>>>0)|ci<<mi|0)|0;ci=c[_e>>2]|0;x=di;a[ci]=x;x=x>>8;a[ci+1|0]=x;x=x>>8;a[ci+2|0]=x;x=x>>8;a[ci+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Ci=mi+32|0;Di=$h}c[ne>>2]=Di;c[Ze>>2]=Ci-fi;break}else{fi=(d[1179944+Ai|0]|0)+Ai|0;$h=(e[1179920+(Ai<<1)>>1]<<Ai)+((1<<Ai)-1&Bi)|0;ci=c[ne>>2]|0;if((mi|0)>(fi|0)){Ei=mi;Fi=$h|ci<<fi}else{di=fe($h>>>((fi-mi|0)>>>0)|ci<<mi|0)|0;ci=c[_e>>2]|0;x=di;a[ci]=x;x=x>>8;a[ci+1|0]=x;x=x>>8;a[ci+2|0]=x;x=x>>8;a[ci+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Ei=mi+32|0;Fi=$h}c[ne>>2]=Fi;c[Ze>>2]=Ei-fi;break}}else{if((zi|0)==0){fi=c[4802976+(ei<<2)>>2]|0;$h=fi&255;ci=fi>>>8;fi=c[ne>>2]|0;if((mi|0)>($h|0)){Gi=mi;Hi=fi<<$h|ci}else{di=fe(ci>>>(($h-mi|0)>>>0)|fi<<mi|0)|0;fi=c[_e>>2]|0;x=di;a[fi]=x;x=x>>8;a[fi+1|0]=x;x=x>>8;a[fi+2|0]=x;x=x>>8;a[fi+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Gi=mi+32|0;Hi=ci}c[ne>>2]=Hi;c[Ze>>2]=Gi-$h;break}else{$h=c[4805088+(ei<<2)>>2]|0;ci=$h&255;fi=$h>>>8;$h=c[ne>>2]|0;if((mi|0)>(ci|0)){Ii=mi;Ji=$h<<ci|fi}else{di=fe(fi>>>((ci-mi|0)>>>0)|$h<<mi|0)|0;$h=c[_e>>2]|0;x=di;a[$h]=x;x=x>>8;a[$h+1|0]=x;x=x>>8;a[$h+2|0]=x;x=x>>8;a[$h+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Ii=mi+32|0;Ji=fi}c[ne>>2]=Ji;c[Ze>>2]=Ii-ci;break}}}while(0);c[gi>>2]=ii;wi=(c[oi>>2]|0)==0?ki:c[287e3]|0;xi=0;yi=1;Kd=859}}while(0);while(1){if((Kd|0)==859){Kd=0;if((yi|0)>(ji|0)){break}qi=wi;ri=b[g+(li<<7)+(d[f+368+yi|0]<<1)>>1]|0;si=xi;ti=yi}do{if((ri|0)==0){Ki=si}else{ki=ti-si-1|0;Xe=ri>>31;re=(Xe^ri)-Xe|0;if((re|0)<=(a[4802912+ki|0]|0)){Ge=re-1+(d[4805024+ki|0]|0)|0;ei=e[qi+(Ge<<2)+2>>1]|0;hi=ei+1|0;ci=e[qi+(Ge<<2)>>1]<<1|Xe&1;Xe=c[ne>>2]|0;Ge=c[Ze>>2]|0;if((Ge|0)>(hi|0)){Li=Ge-hi|0;Mi=ci|Xe<<hi}else{fi=fe(ci>>>((hi-Ge|0)>>>0)|Xe<<Ge|0)|0;Xe=c[_e>>2]|0;x=fi;a[Xe]=x;x=x>>8;a[Xe+1|0]=x;x=x>>8;a[Xe+2|0]=x;x=x>>8;a[Xe+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Li=31-ei+Ge|0;Mi=ci}c[ne>>2]=Mi;c[Ze>>2]=Li;Ki=ti;break}ci=e[qi+446>>1]|0;Ge=e[qi+444>>1]|0;ei=c[ne>>2]|0;Xe=c[Ze>>2]|0;if((Xe|0)>(ci|0)){Ni=Xe-ci|0;Oi=ei<<ci|Ge}else{fi=fe(Ge>>>((ci-Xe|0)>>>0)|ei<<Xe|0)|0;ei=c[_e>>2]|0;x=fi;a[ei]=x;x=x>>8;a[ei+1|0]=x;x=x>>8;a[ei+2|0]=x;x=x>>8;a[ei+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Ni=32-ci+Xe|0;Oi=Ge}c[ne>>2]=Oi;c[Ze>>2]=Ni;if((Ni|0)>6){Pi=Ni-6|0;Qi=Oi<<6|ki}else{Ge=fe(ki>>>((6-Ni|0)>>>0)|Oi<<Ni|0)|0;Xe=c[_e>>2]|0;x=Ge;a[Xe]=x;x=x>>8;a[Xe+1|0]=x;x=x>>8;a[Xe+2|0]=x;x=x>>8;a[Xe+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Pi=Ni+26|0;Qi=ki}c[ne>>2]=Qi;c[Ze>>2]=Pi;if((c[ni>>2]|0)!=1){ki=ri&4095;if((Pi|0)>12){Ri=Pi-12|0;Si=Qi<<12|ki}else{Xe=fe(ki>>>((12-Pi|0)>>>0)|Qi<<Pi|0)|0;Ge=c[_e>>2]|0;x=Xe;a[Ge]=x;x=x>>8;a[Ge+1|0]=x;x=x>>8;a[Ge+2|0]=x;x=x>>8;a[Ge+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Ri=Pi+20|0;Si=ki}c[ne>>2]=Si;c[Ze>>2]=Ri;Ki=ti;break}if((re|0)<128){re=ri&255;if((Pi|0)>8){Ti=Pi-8|0;Ui=Qi<<8|re}else{ki=fe(re>>>((8-Pi|0)>>>0)|Qi<<Pi|0)|0;Ge=c[_e>>2]|0;x=ki;a[Ge]=x;x=x>>8;a[Ge+1|0]=x;x=x>>8;a[Ge+2|0]=x;x=x>>8;a[Ge+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Ti=Pi+24|0;Ui=re}c[ne>>2]=Ui;c[Ze>>2]=Ti;Ki=ti;break}if((ri|0)<0){re=ri+33024|0;if((Pi|0)>16){Vi=Pi-16|0;Wi=Qi<<16|re}else{Ge=fe(re>>>((16-Pi|0)>>>0)|Qi<<Pi|0)|0;ki=c[_e>>2]|0;x=Ge;a[ki]=x;x=x>>8;a[ki+1|0]=x;x=x>>8;a[ki+2|0]=x;x=x>>8;a[ki+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Vi=Pi+16|0;Wi=re}c[ne>>2]=Wi;c[Ze>>2]=Vi;Ki=ti;break}else{re=ri&65535;if((Pi|0)>16){Xi=Pi-16|0;Yi=Qi<<16|re}else{ki=fe(re>>>((16-Pi|0)>>>0)|Qi<<Pi|0)|0;Ge=c[_e>>2]|0;x=ki;a[Ge]=x;x=x>>8;a[Ge+1|0]=x;x=x>>8;a[Ge+2|0]=x;x=x>>8;a[Ge+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Xi=Pi+16|0;Yi=re}c[ne>>2]=Yi;c[Ze>>2]=Xi;Ki=ti;break}}}while(0);wi=qi;xi=Ki;yi=ti+1|0;Kd=859}ji=e[wi+450>>1]|0;ii=e[wi+448>>1]|0;gi=c[ne>>2]|0;re=c[Ze>>2]|0;if((re|0)>(ji|0)){Zi=re-ji|0;_i=gi<<ji|ii}else{Ge=fe(ii>>>((ji-re|0)>>>0)|gi<<re|0)|0;gi=c[_e>>2]|0;x=Ge;a[gi]=x;x=x>>8;a[gi+1|0]=x;x=x>>8;a[gi+2|0]=x;x=x>>8;a[gi+3|0]=x;c[_e>>2]=(c[_e>>2]|0)+4;Zi=32-ji+re|0;_i=ii}c[ne>>2]=_i;c[Ze>>2]=Zi;pi=Zi}ii=li+1|0;if((ii|0)<8){li=ii;mi=pi}else{break}}mi=c[_e>>2]|0;c[n>>2]=0;n=(c[Ye>>2]|0)==0;Ye=(mi-(c[f+792>>2]|0)<<3)+(32-pi)|0;pi=f+13700|0;mi=c[pi>>2]|0;c[pi>>2]=Ye;pi=Ye-mi|0;if(n){n=f+13676|0;c[n>>2]=(c[n>>2]|0)+pi;i=k;return}else{n=f+13672|0;c[n>>2]=(c[n>>2]|0)+pi;i=k;return}}}function MMa(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;vMa(b);if(!(a[1179040]|0)){a[1179040]=1;OOa(1148184,6844904);OOa(1147992,6845294);f=c[287053]|0;g=c[287051]|0;h=0;do{a[4802912+h|0]=a[f+h|0]|0;a[4805024+h|0]=a[g+h|0]|0;h=h+1|0;}while((h|0)<64);NMa(1148184,2758360);if((c[b+14196>>2]|0)==0){i=-255}else{NMa(1147992,2750168);i=-255}do{h=(i|0)>-1?i:-i|0;g=h<<1;f=g>>>0>65535>>>0;j=f?h>>>15&65535:g;g=f?16:0;if((j&65280|0)==0){k=g;l=j}else{k=g|8;l=j>>>8}j=(d[1191992+l|0]|0)+k|0;g=(1<<j)-1&(i>>31)+i;f=i+255|0;c[4802976+(f<<2)>>2]=(d[1179904+j|0]|0)+j+(g+((e[1179880+(j<<1)>>1]|0)<<j)<<8);c[4805088+(f<<2)>>2]=(d[1179944+j|0]|0)+j+(((e[1179920+(j<<1)>>1]|0)<<j)+g<<8);i=i+1|0;}while((i|0)<256);i=a[1180089]|0;k=d[1180121]|0;l=1;while(1){g=l-1|0;j=l+1|0;f=j+k&255;h=-4096;while(1){if((h|0)==0){a[h+4096+(4737368+(l*8193|0))|0]=i;h=h+1|0;continue}m=(((h|0)<0?-h|0:h)-1>>g)+1|0;if((m|0)<17){n=(d[1180089+(m<<1)|0]|0)+l&255}else{n=f}a[h+4096+(4737368+(l*8193|0))|0]=n;h=h+1|0;if((h|0)>=4097){break}}if((j|0)<8){l=j}else{break}}TGb(8012200,7,2048)|0;TGb(8012712,6,1024)|0;TGb(8012968,5,512)|0;TGb(8013096,4,256)|0;TGb(8013160,3,128)|0;TGb(8013192,2,64)|0;TGb(8013208,1,32)|0}c[b+12460>>2]=4737368;c[b+11856>>2]=8009128;l=b+13080|0;if((c[b+48>>2]|0)==1){c[l>>2]=-255;c[b+13084>>2]=255}else{c[l>>2]=-2047;c[b+13084>>2]=2047}l=b+13096|0;if((c[b+14196>>2]|0)==0){c[l>>2]=2758360;c[b+13092>>2]=2758360;o=b+13104|0;c[o>>2]=2758360;p=b+13100|0;c[p>>2]=2758360;return}else{c[l>>2]=2750168;c[b+13092>>2]=2750168;o=b+13104|0;c[o>>2]=2758360;p=b+13100|0;c[p>>2]=2758360;return}}function NMa(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=e+28|0;h=e+8|0;i=e+20|0;e=0;do{j=e-64|0;if((j|0)!=0){k=(j|0)>-1?j:64-e|0;j=k-1|0;if((k|0)<128){l=0;do{do{if((k|0)>(a[(c[g>>2]|0)+l|0]|0)){m=c[h>>2]|0;n=8}else{o=j+(d[(c[i>>2]|0)+l|0]|0)|0;p=c[h>>2]|0;if((o|0)>=111){m=p;n=8;break}q=(b[p+(o<<2)+2>>1]&255)+1&255}}while(0);if((n|0)==8){n=0;q=(b[m+446>>1]&255)+14&255}a[f+((l<<7)+e)|0]=q;l=l+1|0;}while((l|0)<64)}else{l=0;do{do{if((k|0)>(a[(c[g>>2]|0)+l|0]|0)){r=c[h>>2]|0;n=14}else{o=j+(d[(c[i>>2]|0)+l|0]|0)|0;p=c[h>>2]|0;if((o|0)>=111){r=p;n=14;break}s=(b[p+(o<<2)+2>>1]&255)+1&255}}while(0);if((n|0)==14){n=0;s=(b[r+446>>1]&255)+22&255}a[f+((l<<7)+e)|0]=s;l=l+1|0;}while((l|0)<64)}}e=e+1|0;}while((e|0)<128);return}function OMa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;b=i;i=i+40|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=b+32|0;j=h;k=c[a+60>>2]|0;do{if((c[a+48>>2]|0)==1){if((c[a+124>>2]|0)<=2800){break}c[a+808>>2]=1}}while(0);if((pPa(a)|0)<0){l=-1;i=b;return l|0}m=d;n=g;c[d>>2]=0;c[d+4>>2]=0;o=k+4|0;p=c[o>>2]|0;q=c[p+104>>2]|0;r=f|0;c[r>>2]=c[p+108>>2];p=f+4|0;c[p>>2]=q;q=e|0;s=e+4|0;t=k+48|0;u=d;v=k+10012|0;w=k+10016|0;x=k+10020|0;y=1;do{c[q>>2]=1;z=1180208+(y<<3)|0;do{c[s>>2]=1;do{jFb(n,e,z);A=c[s>>2]|0;do{if((c[t>>2]|0)==2){B=c[q>>2]|0;C=(A|0)<0|0?-1:0;D=A;E=(B|0)<0|0?-1:0;G=B;H=12}else{if((A|0)!=1){break}if((c[q>>2]|0)==1){C=0;D=1;E=0;G=1;H=12}}}while(0);a:do{if((H|0)==12){H=0;A=GDb(D,C,G,E)|0;if(!((A|0)==1&(F|0)==0)){break}do{if((c[u>>2]|0)!=0){if((mFb(f,m,n)|0)<0){break}if((c[q>>2]|0)!=1){break a}if((c[s>>2]|0)!=1){break a}if((mFb(f,m,n)|0)!=0){break a}}}while(0);A=c[g+4>>2]|0;c[d>>2]=c[g>>2];c[d+4>>2]=A;c[v>>2]=y;c[w>>2]=c[q>>2];c[x>>2]=c[s>>2]}}while(0);A=(c[s>>2]|0)+1|0;c[s>>2]=A;}while((A|0)<33);A=(c[q>>2]|0)+1|0;c[q>>2]=A;}while((A|0)<5);y=y+1|0;if((y|0)>=14){break}}while(!((c[(c[o>>2]|0)+680>>2]|0)>-1&(y|0)>8));y=c[r>>2]|0;r=c[p>>2]|0;p=c[u>>2]|0;u=c[m+4>>2]|0;m=gHb(u,(u|0)<0|0?-1:0,y,(y|0)<0|0?-1:0)|0;q=F;s=gHb(p,(p|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;x=F;do{if((m|0)==(s|0)&(q|0)==(x|0)){if(!((u|0)==0|(r|0)==0)){I=0;break}if((y|0)==0|(p|0)==0){I=-2147483648;break}I=(y>>31)-(p>>31)|0}else{ZGb(m,q,s,x)|0;w=F^((u^r|0)<0|0?-1:0);((w|0)<0|0?-1:0)>>31|((w|0)<0|0?-1:0)<<1;I=w>>31|((w|0)<0|0?-1:0)<<1|1}}while(0);do{if((I|0)!=0){r=a;u=c[a+108>>2]|0;x=c[a+104>>2]|0;if(!((c[k+80>>2]|0)>-2)){yDb(r,32,2064048,(J=i,i=i+16|0,c[J>>2]=u,c[J+8>>2]=x,J)|0);i=J;break}yDb(r,16,2068504,(J=i,i=i+16|0,c[J>>2]=u,c[J+8>>2]=x,J)|0);i=J;l=-1;i=b;return l|0}}while(0);I=a+840|0;x=c[I>>2]|0;u=(c[a+844>>2]|0)==-99;do{if((x|0)==-99){if(u){r=(c[k+14212>>2]|0)==1?4:0;c[I>>2]=r;K=r;H=38;break}yDb(a,16,2060184,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;l=-1;i=b;return l|0}else{if(u){K=x;H=38;break}L=c[a+120>>2]|0}}while(0);b:do{if((H|0)==38){x=a+844|0;do{if((K|0)==0){u=c[a+120>>2]|0;do{if((u|0)<721){if((c[a+124>>2]|0)>=609){break}c[x>>2]=5;L=u;break b}}while(0);c[x>>2]=2;L=u;break b}else if((K|0)!=1){if((c[k+14212>>2]|0)==1){break}yDb(a,16,2055392,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;l=-1;i=b;return l|0}}while(0);I=c[a+120>>2]|0;do{if((I|0)<721){if((c[a+124>>2]|0)>=577){break}c[x>>2]=8;L=I;break b}else{if((I|0)<1441){break}c[x>>2]=4;L=I;break b}}while(0);c[x>>2]=6;L=I}}while(0);K=(L&4095|0)==0;do{if(K){if((c[a+124>>2]&4095|0)!=1){break}yDb(a,16,2044624,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;l=-22;i=b;return l|0}}while(0);do{if((c[k+80>>2]|0)>-1){if(!K){if((c[a+124>>2]&4095|0)!=0){break}}yDb(a,16,2039552,(J=i,i=i+8|0,c[J>>2]=-1,J)|0);i=J;l=-22;i=b;return l|0}}while(0);K=k+14244|0;if((c[K>>2]|0)==0){L=c[a+92>>2]&8192;r=L>>>13;c[K>>2]=r;if((L|0)==0){M=r}else{N=r;H=61}}else{c[K>>2]=1;N=1;H=61}if((H|0)==61){H=k+14264|0;c[H>>2]=c[H>>2]|1;M=N}do{if((M|0)!=0){if((c[v>>2]|0)==4){break}yDb(a,16,2036264,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;l=-1;i=b;return l|0}}while(0);J=k+14256|0;if((c[J>>2]|0)==0){a=(c[o>>2]|0)+616|0;c[a>>2]=0;c[a+4>>2]=0;l=0;i=b;return l|0}a=1180208+(c[v>>2]<<3)|0;v=c[a+4>>2]|0;c[h>>2]=c[a>>2];c[h+4>>2]=v;v=k+14260|0;h=dGb(v,j,c[J>>2]|0,k)|0;if((h|0)<0){l=h;i=b;return l|0}c[K>>2]=c[k+14264>>2]&1;k=c[v>>2]|0;v=(c[o>>2]|0)+616|0;c[v>>2]=k;c[v+4>>2]=(k|0)<0|0?-1:0;l=0;i=b;return l|0}function PMa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;if((e|0)==0){g=d[1180089]|0;h=d[1180088]|0;i=b+784|0;j=c[i>>2]|0;k=b+788|0;l=c[k>>2]|0;if((l|0)>(g|0)){m=l-g|0;n=j<<g|h}else{o=fe(h>>>((g-l|0)>>>0)|j<<l|0)|0;j=b+796|0;p=c[j>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;m=32-g+l|0;n=h}c[i>>2]=n;c[k>>2]=m;return}m=f-1|0;k=1<<m;n=28-f|0;i=e<<n>>n;if((i|0)>-1){n=i-1|0;q=n;r=n&k-1;s=0}else{n=~i;q=n;r=k-1&n;s=1}n=(q>>m)+1|0;q=d[1180089+(n<<1)|0]|0;k=d[1180088+(n<<1)|0]|0;n=b+784|0;i=c[n>>2]|0;e=b+788|0;h=c[e>>2]|0;if((h|0)>(q|0)){t=h-q|0;u=i<<q|k}else{l=fe(k>>>((q-h|0)>>>0)|i<<h|0)|0;i=b+796|0;g=c[i>>2]|0;x=l;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;t=32-q+h|0;u=k}c[n>>2]=u;c[e>>2]=t;if((t|0)>1){v=t-1|0;w=u<<1|s}else{k=fe(s>>>((1-t|0)>>>0)|u<<t|0)|0;u=b+796|0;h=c[u>>2]|0;x=k;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=t+31|0;w=s}c[n>>2]=w;c[e>>2]=v;if((m|0)<=0){return}if((v|0)>(m|0)){y=v-m|0;z=w<<m|r}else{s=fe(w<<v|r>>>((m-v|0)>>>0)|0)|0;m=b+796|0;b=c[m>>2]|0;x=s;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;y=33-f+v|0;z=r}c[n>>2]=z;c[e>>2]=y;return}function QMa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;if((e|0)<1){g=-1094995529;return g|0}h=e>>>0>2147483639>>>0|(b|0)==0;i=h?0:b;b=h?0:e;e=b+8|0;if(h){g=-1094995529;return g|0}h=i;j=(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>3&31;h=e>>>0>5>>>0?5:e;if((j|0)==31){k=i+(h>>>3)|0;l=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(h&7)>>>26;k=h+6|0;m=l+32|0;n=e>>>0>k>>>0?k:e}else{m=j;n=h}h=a|0;c[h>>2]=m;j=i+(n>>>3)|0;k=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(n&7)>>>28;j=n+4|0;n=e>>>0>j>>>0?j:e;c[a+4>>2]=k;if((k|0)==15){j=i+(n>>>3)|0;l=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(n&7)>>>8;j=n+24|0;o=l;p=e>>>0>j>>>0?j:e}else{o=c[1743568+(k<<2)>>2]|0;p=n}n=a+8|0;c[n>>2]=o;k=i+(p>>>3)|0;j=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(p&7);k=j>>>28;l=p+4|0;p=e>>>0>l>>>0?l:e;l=a+12|0;c[l>>2]=k;if((j|0)>-1){c[a+36>>2]=d[1175888+k|0]|0}k=a+16|0;c[k>>2]=-1;j=a+40|0;c[j>>2]=-1;do{if((m|0)==5){q=-1;r=i+(p>>>3)|0;s=p&7;t=14}else if((m|0)==29){u=i+(p>>>3)|0;v=p&7;w=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<v;if((w&1610612736|0)!=0&(w&528482304|0)==0){t=21;break}c[j>>2]=1;q=1;r=u;s=v;t=14}else{t=21}}while(0);do{if((t|0)==14){c[a+20>>2]=5;c[k>>2]=1;v=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<s>>>28;u=p+4|0;w=e>>>0>u>>>0?u:e;c[a+24>>2]=v;if((v|0)==15){u=i+(w>>>3)|0;x=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(w&7)>>>8;u=w+24|0;y=x;z=e>>>0>u>>>0?u:e}else{y=c[1743568+(v<<2)>>2]|0;z=w}c[a+28>>2]=y;w=i+(z>>>3)|0;v=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(z&7)>>>27;w=z+5|0;u=e>>>0>w>>>0?w:e;if((v|0)==31){w=i+(u>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>26;w=u+6|0;A=x+32|0;B=e>>>0>w>>>0?w:e}else{A=v;B=u}c[h>>2]=A;if((A|0)!=22){C=B;D=A;E=5;F=1;G=q;t=22;break}u=i+(B>>>3)|0;v=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(B&7)>>>28;u=B+4|0;c[a+32>>2]=v;H=e>>>0>u>>>0?u:e;I=22;J=q;t=50}else if((t|0)==21){c[a+20>>2]=0;c[a+28>>2]=0;C=p;D=m;E=0;F=-1;G=-1;t=22}}while(0);a:do{if((t|0)==22){if((D|0)==36){m=C+5|0;p=e>>>0>m>>>0?m:e;m=i+(p>>>3)|0;if(((fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)&-256|0)==1095521024){K=p}else{m=-p|0;q=e-p|0;if((m|0)>24){L=m}else{L=(q|0)<24?q:24}K=L+p|0}if((b-K|0)<112){g=-1;return g|0}p=i+(K>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(K&7)&-65536;p=K+16|0;m=e>>>0>p>>>0?p:e;p=i+(m>>>3)|0;B=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>16;p=m+16|0;m=e>>>0>p>>>0?p:e;if((B|q|0)!=1095521024){g=-1;return g|0}q=i+(m>>>3)|0;B=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(m&7)&-65536;q=m+16|0;m=e>>>0>q>>>0?q:e;q=i+(m>>>3)|0;p=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(m&7)>>>16;q=m+16|0;m=e>>>0>q>>>0?q:e;q=p|B;c[n>>2]=q;B=-m|0;p=e-m|0;if((B|0)>32){M=B}else{M=(p|0)<32?p:32}p=M+m|0;c[l>>2]=0;m=i+(p>>>3)|0;B=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>16;m=p+16|0;c[a+36>>2]=B+1;N=K;O=e>>>0>m>>>0?m:e;P=q}else{N=C;O=C;P=o}q=a+20|0;if((E|0)==5|(f|0)==0){H=N;I=D;J=G;t=50;break}if((b-O|0)>15){Q=O}else{H=N;I=D;J=G;t=50;break}while(1){m=i+(Q>>>3)|0;if(((fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(Q&7)&-2097152|0)==1457520640){break}m=((Q|0)<(e|0))+Q|0;if((b-m|0)>15){Q=m}else{H=N;I=D;J=G;t=50;break a}}m=Q+11|0;B=e>>>0>m>>>0?m:e;m=i+(B>>>3)|0;p=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>27;m=B+5|0;B=e>>>0>m>>>0?m:e;if((p|0)==31){m=i+(B>>>3)|0;A=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>26;m=B+6|0;R=A+32|0;S=e>>>0>m>>>0?m:e}else{R=p;S=B}c[q>>2]=R;do{if((R|0)==5){B=((S|0)<(e|0))+S|0;p=(d[i+(S>>>3)|0]|0)<<(S&7)>>>7&1;c[k>>2]=p;if((p|0)==0){T=B;U=0;break}m=i+(B>>>3)|0;A=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>28;m=B+4|0;B=e>>>0>m>>>0?m:e;c[a+24>>2]=A;if((A|0)==15){m=i+(B>>>3)|0;h=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>8;m=B+24|0;V=h;W=e>>>0>m>>>0?m:e}else{V=c[1743568+(A<<2)>>2]|0;W=B}c[a+28>>2]=V;if((V|0)!=(P|0)){T=W;U=p;break}c[k>>2]=-1;T=W;U=-1}else{T=S;U=F}}while(0);do{if((b-T|0)>11){q=i+(T>>>3)|0;p=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(T&7);q=T+11|0;B=e>>>0>q>>>0?q:e;if(!((p&-2097152|0)==-1459617792)){X=G;break}p=(d[i+(B>>>3)|0]|0)<<(B&7)>>>7&1;c[j>>2]=p;X=p}else{X=G}}while(0);if((U|0)!=0){H=N;I=D;J=X;t=50;break}c[j>>2]=0;Y=N;t=51}}while(0);if((t|0)==50){if((J|0)!=-1|(I|0)==2){Y=H;t=51}else{Z=H}}do{if((t|0)==51){if((c[a+36>>2]|0)>>>0>1>>>0){Z=Y;break}else{g=Y}return g|0}}while(0);c[j>>2]=0;g=Z;return g|0}function RMa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;f=b+4|0;g=c[f>>2]|0;h=b+8|0;i=b+12|0;j=c[i>>2]|0;k=j;l=c[h>>2]|0;m=e+8|0;n=c[m>>2]|0;o=e+16|0;p=c[o>>2]|0;q=e|0;e=c[q>>2]|0;r=e+(n>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(n&7)>>>22;r=n+10|0;c[m>>2]=p>>>0>r>>>0?r:p;p=b|0;r=c[p>>2]|0;n=c[f>>2]|0;if((n|0)>10){t=n-10|0;u=r<<10|s;v=e;w=j}else{e=j;x=fe(s>>>((10-n|0)>>>0)|r<<n|0)|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=(c[i>>2]|0)+4|0;c[i>>2]=e;t=n+22|0;u=s;v=c[q>>2]|0;w=e}c[p>>2]=u;c[f>>2]=t;t=c[m>>2]|0;u=c[o>>2]|0;e=v+(t>>>3)|0;s=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(t&7)>>>28;e=t+4|0;c[m>>2]=u>>>0>e>>>0?e:u;u=c[p>>2]|0;e=c[f>>2]|0;if((e|0)>4){y=e-4|0;z=u<<4|s;A=v;B=w}else{v=w;x=fe(s>>>((4-e|0)>>>0)|u<<e|0)|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;v=(c[i>>2]|0)+4|0;c[i>>2]=v;y=e+28|0;z=s;A=c[q>>2]|0;B=v}c[p>>2]=z;c[f>>2]=y;y=c[m>>2]|0;z=c[o>>2]|0;v=A+(y>>>3)|0;e=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(y&7)>>>28;v=y+4|0;c[m>>2]=z>>>0>v>>>0?v:z;z=c[p>>2]|0;v=c[f>>2]|0;if((v|0)>4){C=v-4|0;D=z<<4|e;E=A;F=B}else{A=B;x=fe(e>>>((4-v|0)>>>0)|z<<v|0)|0;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;A=(c[i>>2]|0)+4|0;c[i>>2]=A;C=v+28|0;D=e;E=c[q>>2]|0;F=A}c[p>>2]=D;c[f>>2]=C;C=c[m>>2]|0;D=c[o>>2]|0;A=E+(C>>>3)|0;v=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(C&7)>>>28;A=C+4|0;c[m>>2]=D>>>0>A>>>0?A:D;D=c[p>>2]|0;A=c[f>>2]|0;if((A|0)>4){G=A-4|0;H=D<<4|v;I=E;J=F}else{E=F;x=fe(v>>>((4-A|0)>>>0)|D<<A|0)|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;E=(c[i>>2]|0)+4|0;c[i>>2]=E;G=A+28|0;H=v;I=c[q>>2]|0;J=E}c[p>>2]=H;c[f>>2]=G;G=c[m>>2]|0;H=c[o>>2]|0;E=I+(G>>>3)|0;A=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(G&7)>>>30;E=G+2|0;c[m>>2]=H>>>0>E>>>0?E:H;H=c[p>>2]|0;E=c[f>>2]|0;if((E|0)>2){K=E-2|0;L=H<<2|A;M=I;N=J}else{I=J;x=fe(A>>>((2-E|0)>>>0)|H<<E|0)|0;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;I=(c[i>>2]|0)+4|0;c[i>>2]=I;K=E+30|0;L=A;M=c[q>>2]|0;N=I}c[p>>2]=L;c[f>>2]=K;K=c[m>>2]|0;L=c[o>>2]|0;I=M+(K>>>3)|0;E=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(K&7)>>>29;I=K+3|0;c[m>>2]=L>>>0>I>>>0?I:L;L=c[p>>2]|0;I=c[f>>2]|0;if((I|0)>3){O=I-3|0;P=L<<3|E;Q=M;R=N}else{M=N;x=fe(E>>>((3-I|0)>>>0)|L<<I|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;M=(c[i>>2]|0)+4|0;c[i>>2]=M;O=I+29|0;P=E;Q=c[q>>2]|0;R=M}c[p>>2]=P;c[f>>2]=O;O=E+A|0;A=c[m>>2]|0;E=c[o>>2]|0;P=Q+(A>>>3)|0;M=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(A&7)>>>28;P=A+4|0;c[m>>2]=E>>>0>P>>>0?P:E;E=c[p>>2]|0;P=c[f>>2]|0;if((P|0)>4){S=P-4|0;T=E<<4|M;U=Q;V=R}else{Q=R;x=fe(M>>>((4-P|0)>>>0)|E<<P|0)|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=(c[i>>2]|0)+4|0;c[i>>2]=Q;S=P+28|0;T=M;U=c[q>>2]|0;V=Q}c[p>>2]=T;c[f>>2]=S;S=e+s+v+M|0;M=c[m>>2]|0;v=c[o>>2]|0;s=U+(M>>>3)|0;U=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(M&7)>>>31;s=M+1|0;c[m>>2]=v>>>0>s>>>0?s:v;v=c[p>>2]|0;s=c[f>>2]|0;if((s|0)>1){W=s-1|0;X=v<<1|U;Y=V}else{M=V;x=fe(U>>>((1-s|0)>>>0)|v<<s|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;M=(c[i>>2]|0)+4|0;c[i>>2]=M;W=s+31|0;X=U;Y=M}c[p>>2]=X;c[f>>2]=W;if((U|0)==0){Z=Y}else{U=c[m>>2]|0;W=c[o>>2]|0;X=(c[q>>2]|0)+(U>>>3)|0;M=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(U&7)>>>28;X=U+4|0;c[m>>2]=W>>>0>X>>>0?X:W;W=c[p>>2]|0;X=c[f>>2]|0;if((X|0)>4){_=X-4|0;$=W<<4|M;aa=Y}else{U=Y;x=fe(M>>>((4-X|0)>>>0)|W<<X|0)|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=(c[i>>2]|0)+4|0;c[i>>2]=U;_=X+28|0;$=M;aa=U}c[p>>2]=$;c[f>>2]=_;Z=aa}aa=c[m>>2]|0;_=c[o>>2]|0;$=(c[q>>2]|0)+(aa>>>3)|0;U=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(aa&7)>>>31;$=aa+1|0;c[m>>2]=_>>>0>$>>>0?$:_;_=c[p>>2]|0;$=c[f>>2]|0;if(($|0)>1){ba=$-1|0;ca=_<<1|U;da=Z}else{aa=Z;x=fe(U>>>((1-$|0)>>>0)|_<<$|0)|0;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;aa=(c[i>>2]|0)+4|0;c[i>>2]=aa;ba=$+31|0;ca=U;da=aa}c[p>>2]=ca;c[f>>2]=ba;if((U|0)==0){ea=da}else{U=c[m>>2]|0;ba=c[o>>2]|0;ca=(c[q>>2]|0)+(U>>>3)|0;aa=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(U&7)>>>28;ca=U+4|0;c[m>>2]=ba>>>0>ca>>>0?ca:ba;ba=c[p>>2]|0;ca=c[f>>2]|0;if((ca|0)>4){fa=ca-4|0;ga=ba<<4|aa;ha=da}else{U=da;x=fe(aa>>>((4-ca|0)>>>0)|ba<<ca|0)|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=(c[i>>2]|0)+4|0;c[i>>2]=U;fa=ca+28|0;ga=aa;ha=U}c[p>>2]=ga;c[f>>2]=fa;ea=ha}ha=c[m>>2]|0;fa=c[o>>2]|0;ga=(c[q>>2]|0)+(ha>>>3)|0;U=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ha&7)>>>31;ga=ha+1|0;c[m>>2]=fa>>>0>ga>>>0?ga:fa;fa=c[p>>2]|0;ga=c[f>>2]|0;if((ga|0)>1){ia=ga-1|0;ja=fa<<1|U;ka=ea}else{ha=ea;x=fe(U>>>((1-ga|0)>>>0)|fa<<ga|0)|0;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;ha=(c[i>>2]|0)+4|0;c[i>>2]=ha;ia=ga+31|0;ja=U;ka=ha}c[p>>2]=ja;c[f>>2]=ia;if((U|0)==0){la=ka}else{U=c[m>>2]|0;ia=c[o>>2]|0;ja=(c[q>>2]|0)+(U>>>3)|0;ha=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(U&7)>>>29;ja=U+3|0;c[m>>2]=ia>>>0>ja>>>0?ja:ia;ia=c[p>>2]|0;ja=c[f>>2]|0;if((ja|0)>3){ma=ja-3|0;na=ia<<3|ha;oa=ka}else{U=ka;x=fe(ha>>>((3-ja|0)>>>0)|ia<<ja|0)|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;U=(c[i>>2]|0)+4|0;c[i>>2]=U;ma=ja+29|0;na=ha;oa=U}c[p>>2]=na;c[f>>2]=ma;la=oa}oa=S*5|0;S=oa+(O<<2)|0;if((S|0)>16){ma=O<<2;O=oa+ma|0;na=15-ma-oa|0;U=((na|0)>-17?na:-17)+oa+ma&-16;ma=S;oa=la;while(1){na=c[m>>2]|0;ha=c[o>>2]|0;ja=(c[q>>2]|0)+(na>>>3)|0;ia=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(na&7)>>>16;ja=na+16|0;c[m>>2]=ha>>>0>ja>>>0?ja:ha;ha=c[p>>2]|0;ja=c[f>>2]|0;if((ja|0)>16){pa=ja-16|0;qa=ha<<16|ia;ra=oa}else{na=oa;x=fe(ia>>>((16-ja|0)>>>0)|ha<<ja|0)|0;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;na=(c[i>>2]|0)+4|0;c[i>>2]=na;pa=ja+16|0;qa=ia;ra=na}c[p>>2]=qa;c[f>>2]=pa;na=ma-16|0;if((na|0)>16){ma=na;oa=ra}else{break}}sa=O-16-U|0;ta=ra}else{sa=S;ta=la}if((sa|0)!=0){la=c[m>>2]|0;S=c[o>>2]|0;ra=(c[q>>2]|0)+(la>>>3)|0;U=32-sa|0;O=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(la&7)>>>(U>>>0);ra=la+sa|0;c[m>>2]=S>>>0>ra>>>0?ra:S;S=c[p>>2]|0;ra=c[f>>2]|0;if((ra|0)>(sa|0)){ua=ra-sa|0;va=S<<sa|O}else{la=ta;x=fe(O>>>((sa-ra|0)>>>0)|S<<ra|0)|0;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;ua=ra+U|0;va=O}c[p>>2]=va;c[f>>2]=ua}K_(b);b=c[m>>2]|0;ua=-b&7;va=c[o>>2]|0;if((ua|0)==0){wa=b}else{O=ua+b|0;b=va>>>0>O>>>0?O:va;c[m>>2]=b;wa=b}b=(c[q>>2]|0)+(wa>>>3)|0;O=(fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(wa&7)>>>24;b=wa+8|0;c[m>>2]=va>>>0>b>>>0?b:va;va=c[p>>2]|0;b=c[f>>2]|0;if((b|0)>8){xa=b-8|0;ya=va<<8|O}else{wa=fe(O>>>((8-b|0)>>>0)|va<<b|0)|0;va=c[i>>2]|0;x=wa;a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;xa=b+24|0;ya=O}c[p>>2]=ya;c[f>>2]=xa;if((O|0)==0){za=xa;Aa=c[h>>2]|0;Ba=c[i>>2]|0;Ca=Ba;Da=Aa;Ea=Ca-Da|0;Fa=Ea<<3;Ga=l-k|0;Ha=Ga<<3;Ia=Ha+g|0;Ja=Ia-za|0;Ka=Ja+Fa|0;return Ka|0}else{La=O}while(1){O=c[m>>2]|0;xa=c[o>>2]|0;ya=(c[q>>2]|0)+(O>>>3)|0;b=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(O&7)>>>24;ya=O+8|0;c[m>>2]=xa>>>0>ya>>>0?ya:xa;xa=c[p>>2]|0;ya=c[f>>2]|0;if((ya|0)>8){Ma=ya-8|0;Na=xa<<8|b}else{O=fe(b>>>((8-ya|0)>>>0)|xa<<ya|0)|0;xa=c[i>>2]|0;x=O;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;Ma=ya+24|0;Na=b}c[p>>2]=Na;c[f>>2]=Ma;b=La-1|0;if((b|0)>0){La=b}else{za=Ma;break}}Aa=c[h>>2]|0;Ba=c[i>>2]|0;Ca=Ba;Da=Aa;Ea=Ca-Da|0;Fa=Ea<<3;Ga=l-k|0;Ha=Ga<<3;Ia=Ha+g|0;Ja=Ia-za|0;Ka=Ja+Fa|0;return Ka|0}function SMa(a){a=a|0;var b=0,d=0,e=0;b=c[a+9992>>2]|0;if((b|0)==1){d=16;return d|0}else if((b|0)==2|(b|0)==4){d=(c[a+11556>>2]|0)+15|0;return d|0}else if((b|0)==3){b=c[a+11556>>2]|0;e=c[a+11560>>2]|0;a=(b|0)>(e|0)?b:e;d=(a|0)>2?a+15|0:17;return d|0}else{d=-1;return d|0}return 0}function TMa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+128>>2]|0;d=c[a+12480>>2]|0;e=ba((d<<1)-1|0,b)|0;f=c[a+12476>>2]|0;g=c[a+124>>2]|0;h=f-1+(ba(g,d-1|0)|0)|0;TGb((c[a+9912>>2]|0)+((f<<1)-1+e<<5)|0,0,b<<6|32|0)|0;b=(g<<5)+32|0;TGb((c[a+9916>>2]|0)+(h<<5)|0,0,b|0)|0;TGb((c[a+9920>>2]|0)+(h<<5)|0,0,b|0)|0;c[a+11844>>2]=0;c[a+11840>>2]=0;c[a+11828>>2]=0;c[a+11824>>2]=0;return}function UMa(a){a=a|0;var c=0,d=0,f=0,g=0,h=0;c=a+13874|0;d=a+13872|0;f=0;do{g=f-32|0;h=ba(e[c>>1]|0,g)|0;b[a+11860+(f<<1)>>1]=(h|0)/(e[d>>1]|0|0)|0;h=e[d>>1]|0;b[a+11988+(f<<1)>>1]=(ba((e[c>>1]|0)-h|0,g)|0)/(h|0)|0;f=f+1|0;}while((f|0)<64);return}function VMa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=(ba(c[d+124>>2]|0,c[d+12480>>2]|0)|0)+(c[d+12476>>2]|0)|0;i=c[(c[d+4712>>2]|0)+(h<<2)>>2]|0;if((i&64|0)!=0){c[d+11740>>2]=1;WMa(d,f,g,0);WMa(d,f,g,1);WMa(d,f,g,2);WMa(d,f,g,3);j=61760;return j|0}if((i&128|0)==0){WMa(d,f,g,0);i=c[d+11744>>2]|0;c[d+11768>>2]=i;c[d+11760>>2]=i;c[d+11752>>2]=i;i=c[d+11748>>2]|0;c[d+11772>>2]=i;c[d+11764>>2]=i;c[d+11756>>2]=i;i=c[d+11776>>2]|0;c[d+11800>>2]=i;c[d+11792>>2]=i;c[d+11784>>2]=i;i=c[d+11780>>2]|0;c[d+11804>>2]=i;c[d+11796>>2]=i;c[d+11788>>2]=i;do{if((c[(c[d+4>>2]|0)+676>>2]&512|0)==0){if((c[d+13924>>2]|0)==0){break}c[d+11740>>2]=1;j=61704;return j|0}}while(0);c[d+11740>>2]=0;j=61704;return j|0}c[d+11740>>2]=3;i=h<<2;k=d+4732|0;l=d+14184|0;m=d+13876|0;n=d+13878|0;o=(g|0)==0;if((f|0)==0){p=0;q=0;while(1){r=a[(c[k>>2]|0)+((p<<1)+i)|0]|0;c[d+11808+(p<<2)>>2]=r;c[d+11816+(p<<2)>>2]=p;s=e[m>>1]|0;if((c[l>>2]|0)==0){t=r+q|0;u=t+s&65535;v=t+(e[n>>1]|0)&65535}else{t=p-r|0;u=t+s&65535;v=t+(e[n>>1]|0)&65535}t=c[d+11660+(p<<3)>>2]|0;s=b[t+(h<<2)>>1]|0;r=v&65535;w=u&65535;c[d+11744+(p<<3)>>2]=(ba(s,r)|0)/(w|0)|0;x=b[t+(h<<2)+2>>1]|0;t=((ba(x,r)|0)/(w|0)|0)+g|0;c[d+11744+(p<<3)+4>>2]=t;c[d+11776+(p<<3)>>2]=(ba(s,r-w|0)|0)/(w|0)|0;if(o){y=(ba(x,r-w|0)|0)/(w|0)|0}else{y=t-x|0}c[d+11776+(p<<3)+4>>2]=y;x=p+1|0;t=~p;if((x|0)<2){p=x;q=t}else{j=61840;break}}return j|0}if(o){o=0;q=0;while(1){p=a[(c[k>>2]|0)+((o<<1)+i)|0]|0;c[d+11808+(o<<2)>>2]=p;c[d+11816+(o<<2)>>2]=o;y=e[m>>1]|0;if((c[l>>2]|0)==0){u=p+q|0;z=u+y&65535;A=u+(e[n>>1]|0)&65535}else{u=o-p|0;z=u+y&65535;A=u+(e[n>>1]|0)&65535}u=c[d+11660+(o<<3)>>2]|0;y=b[u+(h<<2)>>1]|0;p=A&65535;v=z&65535;t=((ba(y,p)|0)/(v|0)|0)+f|0;c[d+11744+(o<<3)>>2]=t;x=b[u+(h<<2)+2>>1]|0;c[d+11744+(o<<3)+4>>2]=(ba(x,p)|0)/(v|0)|0;c[d+11776+(o<<3)>>2]=t-y;c[d+11776+(o<<3)+4>>2]=(ba(x,p-v|0)|0)/(v|0)|0;v=o+1|0;p=~o;if((v|0)<2){o=v;q=p}else{j=61840;break}}return j|0}else{q=0;o=0;while(1){z=a[(c[k>>2]|0)+((q<<1)+i)|0]|0;c[d+11808+(q<<2)>>2]=z;c[d+11816+(q<<2)>>2]=q;A=e[m>>1]|0;if((c[l>>2]|0)==0){p=z+o|0;B=p+A&65535;C=p+(e[n>>1]|0)&65535}else{p=q-z|0;B=p+A&65535;C=p+(e[n>>1]|0)&65535}p=c[d+11660+(q<<3)>>2]|0;A=b[p+(h<<2)>>1]|0;z=C&65535;v=B&65535;x=((ba(A,z)|0)/(v|0)|0)+f|0;c[d+11744+(q<<3)>>2]=x;y=b[p+(h<<2)+2>>1]|0;p=((ba(y,z)|0)/(v|0)|0)+g|0;c[d+11744+(q<<3)+4>>2]=p;c[d+11776+(q<<3)>>2]=x-A;c[d+11776+(q<<3)+4>>2]=p-y;y=q+1|0;p=~q;if((y|0)<2){q=y;o=p}else{j=61840;break}}return j|0}return 0}function WMa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=c[a+12496+(f<<2)>>2]|0;h=b[a+13872>>1]|0;i=b[a+13874>>1]|0;j=c[a+4700>>2]|0;k=b[j+(g<<2)>>1]|0;l=k+32|0;if(l>>>0<64>>>0){m=(b[a+11860+(l<<1)>>1]|0)+d|0;c[a+11744+(f<<3)>>2]=m;if((d|0)==0){n=b[a+11988+(l<<1)>>1]|0}else{n=m-k|0}c[a+11776+(f<<3)>>2]=n}else{n=i&65535;m=h&65535;l=((ba(k,n)|0)/(m|0)|0)+d|0;c[a+11744+(f<<3)>>2]=l;if((d|0)==0){o=(ba(k,n-m|0)|0)/(m|0)|0}else{o=l-k|0}c[a+11776+(f<<3)>>2]=o}o=b[j+(g<<2)+2>>1]|0;g=o+32|0;if(g>>>0<64>>>0){j=(b[a+11860+(g<<1)>>1]|0)+e|0;c[a+11744+(f<<3)+4>>2]=j;if((e|0)==0){p=b[a+11988+(g<<1)>>1]|0}else{p=j-o|0}c[a+11776+(f<<3)+4>>2]=p;return}else{p=i&65535;i=h&65535;h=((ba(o,p)|0)/(i|0)|0)+e|0;c[a+11744+(f<<3)+4>>2]=h;if((e|0)==0){q=(ba(o,p-i|0)|0)/(i|0)|0}else{q=h-o|0}c[a+11776+(f<<3)+4>>2]=q;return}}function XMa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=a+20|0;g=c[f>>2]|0;h=a+16|0;a=c[h>>2]|0;a:do{if((g|0)==0){i=a;j=0;while(1){if((j|0)>=(e|0)){k=i;l=0;break a}m=d[b+j|0]|0|i<<8;n=j+1|0;if((m|0)==438){o=1;p=n;q=438;r=4;break}else{i=m;j=n}}}else{o=g;p=0;q=a;r=4}}while(0);b:do{if((r|0)==4){if((e|0)==0){s=0;return s|0}if((p|0)<(e|0)){t=p;u=q}else{k=q;l=o;break}while(1){a=u<<8;if((a|0)==256){break}g=d[b+t|0]|0|a;a=t+1|0;if((a|0)<(e|0)){t=a;u=g}else{k=g;l=o;break b}}c[f>>2]=0;c[h>>2]=-1;s=t-3|0;return s|0}}while(0);c[f>>2]=l;c[h>>2]=k;s=-100;return s|0}function YMa(a){a=a|0;var b=0;b=c[a>>2]|0;eNa();c[b+14824>>2]=1;c[b+13960>>2]=5;c[b+984>>2]=1;c[b+14804>>2]=1;return 0}function ZMa(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;j=i;i=i+56|0;k=j|0;l=j+24|0;m=j+32|0;n=j+40|0;o=j+48|0;c[n>>2]=g;c[o>>2]=h;p=a|0;q=c[p>>2]|0;r=q;s=a+176|0;do{if((c[s>>2]&1|0)==0){t=q+20|0;u=c[t>>2]|0;v=q+16|0;w=c[v>>2]|0;a:do{if((u|0)==0){x=w;y=0;while(1){if((y|0)>=(h|0)){z=x;A=0;B=10;break a}C=d[g+y|0]|0|x<<8;D=y+1|0;if((C|0)==438){E=1;G=D;H=438;B=5;break}else{x=C;y=D}}}else{E=u;G=0;H=w;B=5}}while(0);b:do{if((B|0)==5){if((h|0)==0){I=0;break}if((G|0)<(h|0)){J=G;K=H}else{z=H;A=E;B=10;break}while(1){w=K<<8;if((w|0)==256){break}u=d[g+J|0]|0|w;w=J+1|0;if((w|0)<(h|0)){J=w;K=u}else{z=u;A=E;B=10;break b}}c[t>>2]=0;c[v>>2]=-1;I=J-3|0}}while(0);if((B|0)==10){c[t>>2]=A;c[v>>2]=z;I=-100}if((WRa(r,I,n,o)|0)>=0){L=I;M=c[n>>2]|0;N=c[o>>2]|0;O=c[p>>2]|0;break}c[e>>2]=0;c[f>>2]=0;P=c[o>>2]|0;i=j;return P|0}else{L=h;M=g;N=h;O=q}}while(0);q=O+40|0;h=O+44|0;c[h>>2]=b;c[O+9896>>2]=O+7664;g=c[b+100>>2]|0;do{if((g|0)!=0){if((c[O+14824>>2]|0)==0){break}p=c[b+96>>2]|0;I=g<<3;r=I>>>0>2147483639>>>0|(p|0)==0;z=r?0:p;p=r?0:I;c[k>>2]=z;c[k+12>>2]=p;c[k+16>>2]=p+8;c[k+4>>2]=z+(p>>3);c[k+8>>2]=0;dNa(q,k)|0}}while(0);g=N<<3;N=g>>>0>2147483639>>>0|(M|0)==0;p=N?0:M;M=N?0:g;c[k>>2]=p;c[k+12>>2]=M;c[k+16>>2]=M+8;c[k+4>>2]=p+(M>>3);c[k+8>>2]=0;M=dNa(q,k)|0;k=c[O+48>>2]|0;c:do{if((k|0)==0){Q=M;B=23}else{do{if((c[b+120>>2]|0)!=0){if((c[b+124>>2]|0)==0){break}if((c[b+128>>2]|0)==0){break}if((c[b+132>>2]|0)!=0){Q=M;B=23;break c}}}while(0);v=V$a(b,k,c[O+52>>2]|0)|0;if((v|0)>=0){Q=v;B=23}}}while(0);if((B|0)==23){do{if((c[s>>2]&4096|0)!=0){B=(c[h>>2]|0)+108|0;if(!((c[B>>2]|0)>0&(Q|0)>-1)){break}k=O+13896|0;b=c[k>>2]|0;M=c[k+4>>2]|0;c[l>>2]=1;c[l+4>>2]=c[B>>2];c[m>>2]=1;c[m+4>>2]=12e5;B=KDb(b,M,l,m)|0;M=a+40|0;c[M>>2]=B;c[M+4>>2]=F}}while(0);c[a+32>>2]=c[O+10032>>2];c[O+14824>>2]=0}c[e>>2]=c[n>>2];c[f>>2]=c[o>>2];P=L;i=j;return P|0}function _Ma(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=c[f+9136>>2]|0;k=c[f+9912>>2]|0;l=c[f+12496+(h<<2)>>2]<<4;a:do{if((c[f+176>>2]|0)!=0){m=c[f+12476>>2]|0;if((i|0)==0){n=l-16|0;do{if((m|0)!=0){o=m-1+(ba(c[f+12480>>2]|0,c[f+124>>2]|0)|0)|0;p=c[f+9960>>2]|0;q=j+o|0;o=a[q]|0;if((p|0)==(o<<24>>24|0)){break}if((h|0)==3|(h|0)==1){break}else{r=1;s=o}while(1){o=ba(s<<24>>24,b[k+(r+n<<1)>>1]|0)|0;t=p>>1;u=g+(d[(r<<3)+(f+11184)|0]<<1)|0;b[u>>1]=(e[u>>1]|0)+((((o|0)>0?t:-t|0)+o|0)/(p|0)|0);o=r+1|0;if((o|0)>=8){break a}r=o;s=a[q]|0}}}while(0);n=g+(d[f+11192|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-15<<1)>>1]|0);n=g+(d[f+11200|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-14<<1)>>1]|0);n=g+(d[f+11208|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-13<<1)>>1]|0);n=g+(d[f+11216|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-12<<1)>>1]|0);n=g+(d[f+11224|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-11<<1)>>1]|0);n=g+(d[f+11232|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-10<<1)>>1]|0);n=g+(d[f+11240|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-9<<1)>>1]|0);break}n=c[f+12480>>2]|0;q=c[f+124>>2]|0;p=l-(c[f+12520+(h<<2)>>2]<<4)|0;do{if((n|0)!=0){o=m-q+(ba(q,n)|0)|0;t=c[f+9960>>2]|0;u=j+o|0;o=a[u]|0;if((t|0)==(o<<24>>24|0)){break}if((h-2|0)>>>0<2>>>0){break}v=p|8;w=1;x=o;while(1){o=ba(x<<24>>24,b[k+(v+w<<1)>>1]|0)|0;y=t>>1;z=g+(d[f+11184+w|0]<<1)|0;b[z>>1]=(e[z>>1]|0)+((((o|0)>0?y:-y|0)+o|0)/(t|0)|0);o=w+1|0;if((o|0)>=8){break a}w=o;x=a[u]|0}}}while(0);n=g+(d[f+11185|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|9)<<1)>>1]|0);n=g+(d[f+11186|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|10)<<1)>>1]|0);n=g+(d[f+11187|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|11)<<1)>>1]|0);n=g+(d[f+11188|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|12)<<1)>>1]|0);n=g+(d[f+11189|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|13)<<1)>>1]|0);n=g+(d[f+11190|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|14)<<1)>>1]|0);n=g+(d[f+11191|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|15)<<1)>>1]|0)}}while(0);b[k+((l|1)<<1)>>1]=b[g+(d[f+11192|0]<<1)>>1]|0;b[k+((l|2)<<1)>>1]=b[g+(d[f+11200|0]<<1)>>1]|0;b[k+((l|3)<<1)>>1]=b[g+(d[f+11208|0]<<1)>>1]|0;b[k+((l|4)<<1)>>1]=b[g+(d[f+11216|0]<<1)>>1]|0;b[k+((l|5)<<1)>>1]=b[g+(d[f+11224|0]<<1)>>1]|0;b[k+((l|6)<<1)>>1]=b[g+(d[f+11232|0]<<1)>>1]|0;b[k+((l|7)<<1)>>1]=b[g+(d[f+11240|0]<<1)>>1]|0;b[k+((l|9)<<1)>>1]=b[g+(d[f+11185|0]<<1)>>1]|0;b[k+((l|10)<<1)>>1]=b[g+(d[f+11186|0]<<1)>>1]|0;b[k+((l|11)<<1)>>1]=b[g+(d[f+11187|0]<<1)>>1]|0;b[k+((l|12)<<1)>>1]=b[g+(d[f+11188|0]<<1)>>1]|0;b[k+((l|13)<<1)>>1]=b[g+(d[f+11189|0]<<1)>>1]|0;b[k+((l|14)<<1)>>1]=b[g+(d[f+11190|0]<<1)>>1]|0;b[k+((l|15)<<1)>>1]=b[g+(d[f+11191|0]<<1)>>1]|0;return}function $Ma(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;e=a|0;f=a+144|0;g=(c[f>>2]|0)-1|0;h=g>>>0>65535>>>0;j=h?g>>>16:g;g=h?16:0;if((j&65280|0)==0){k=g;l=j}else{k=g|8;l=j>>>8}j=(d[1191992+l|0]|0)+k|0;k=j+1|0;l=a+14120|0;g=a+14128|0;h=c[g>>2]|0;if((h|0)>((c[a+14132>>2]|0)-20|0)){m=-1;i=b;return m|0}n=l|0;o=0;p=h;while(1){if((o|0)>=32){break}h=d[(c[n>>2]|0)+(p>>>3)|0]|0;q=p+1|0;c[g>>2]=q;if((h&128>>>((p&7)>>>0)|0)==0){o=o+1|0;p=q}else{break}}if((o|0)!=(SMa(e)|0)){yDb(c[a+4>>2]|0,16,2253440,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=-1;i=b;return m|0}e=a+14676|0;o=c[e>>2]|0;p=(o|0)==0;q=c[g>>2]|0;if(p){s=0;t=q;u=c[n>>2]|0}else{h=c[n>>2]|0;v=(d[h+(q>>>3)|0]|0)<<(q&7)>>>7;w=q+1|0;c[g>>2]=w;s=v&1;t=w;u=h}h=u+(t>>>3)|0;w=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(t&7)>>>((31-j|0)>>>0);j=k+t|0;c[g>>2]=j;t=c[f>>2]|0;if((w|0)>=(t|0)){yDb(c[a+4>>2]|0,16,2320656,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=t,r)|0);i=r;m=-1;i=b;return m|0}t=c[a+116>>2]|0;c[a+12476>>2]=(w|0)%(t|0)|0;c[a+12480>>2]=(w|0)/(t|0)|0;do{if((o|0)==2){x=s;y=j}else{t=c[a+13920>>2]|0;w=u+(j>>>3)|0;f=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(j&7)>>>((32-t|0)>>>0);w=j+t|0;c[g>>2]=w;if((f|0)!=0){c[a+9960>>2]=f;c[a+9964>>2]=f}if(!p){x=s;y=w;break}f=(d[u+(w>>>3)|0]|0)<<(w&7)>>>7;t=w+1|0;c[g>>2]=t;x=f&1;y=t}}while(0);do{if((x|0)!=0){s=y;while(1){p=d[u+(s>>>3)|0]|0;z=s+1|0;c[g>>2]=z;if((p&128>>>((s&7)>>>0)|0)==0){break}else{s=z}}p=d[u+(z>>>3)|0]|0;j=s+2|0;c[g>>2]=j;if((p&128>>>((z&7)>>>0)|0)==0){yDb(0,32,2238056,(r=i,i=i+8|0,c[r>>2]=2185200,r)|0);i=r;A=c[g>>2]|0;B=c[n>>2]|0}else{A=j;B=u}j=A+(c[a+14672>>2]|0)|0;c[g>>2]=j;p=d[B+(j>>>3)|0]|0;o=j+1|0;c[g>>2]=o;if((p&128>>>((j&7)>>>0)|0)==0){yDb(0,32,2238056,(r=i,i=i+8|0,c[r>>2]=2108032,r)|0);i=r;C=c[g>>2]|0}else{C=o}c[g>>2]=C+2;if((c[e>>2]|0)==2){break}c[g>>2]=C+5;o=a+9992|0;j=c[o>>2]|0;do{if((j|0)==4){if((c[a+14680>>2]|0)!=2){D=4;break}if((aNa(a,l)|0)<0){m=-1094995529;i=b;return m|0}else{yDb(c[a+4>>2]|0,16,2050440,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;E=c[o>>2]|0;F=30;break}}else{E=j;F=30}}while(0);if((F|0)==30){if((E|0)==1){break}else{D=E}}j=c[g>>2]|0;s=(c[n>>2]|0)+(j>>>3)|0;p=fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;c[g>>2]=j+3;if((p&-536870912>>>((j&7)>>>0)|0)==0){yDb(c[a+4>>2]|0,16,2004896,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;G=c[o>>2]|0}else{G=D}if((G|0)!=3){break}j=c[g>>2]|0;p=(c[n>>2]|0)+(j>>>3)|0;s=fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;c[g>>2]=j+3;if((s&-536870912>>>((j&7)>>>0)|0)!=0){break}yDb(c[a+4>>2]|0,16,1967480,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}}while(0);if((c[a+14728>>2]|0)==0){m=0;i=b;return m|0}G=(c[a+14672>>2]|0)+3|0;a=(G|0)>15?15:G;G=a+(c[g>>2]|0)|0;c[g>>2]=G;D=c[n>>2]|0;n=G+1+((128>>>((G&7)>>>0)&(d[D+(G>>>3)|0]|0)|0)==0?0:a)|0;c[g>>2]=n;a=d[D+(n>>>3)|0]|0;c[g>>2]=n+1;if((128>>>((n&7)>>>0)&a|0)!=0){m=0;i=b;return m|0}yDb(0,32,2238056,(r=i,i=i+8|0,c[r>>2]=2238824,r)|0);i=r;m=0;i=b;return m|0}function aNa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=i;i=i+32|0;g=f|0;h=c[a+13932>>2]|0;j=2<<h;k=3-h|0;l=16>>>((h+1|0)>>>0);h=c[a+8>>2]|0;m=c[a+12>>2]|0;TGb(g|0,0,32)|0;if((h|0)<1|(m|0)<1){n=-1094995529;i=f;return n|0}o=a+14688|0;if((c[o>>2]|0)>0){p=e+8|0;q=a+14748|0;r=a+14752|0;s=c[1071081]|0;t=c[e>>2]|0;e=0;u=c[p>>2]|0;do{v=t+(u>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(u&7)>>>26;v=b[s+(w<<2)>>1]|0;x=b[s+(w<<2)+2>>1]|0;w=x<<16>>16;do{if(x<<16>>16<0){y=u+6|0;z=t+(y>>>3)|0;A=((fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(y&7)>>>((w+32|0)>>>0))+v|0;z=b[s+(A<<2)>>1]|0;B=b[s+(A<<2)+2>>1]|0;A=B<<16>>16;if(!(B<<16>>16<0)){C=A;D=y;E=z;break}B=y-w|0;y=t+(B>>>3)|0;F=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(B&7)>>>((A+32|0)>>>0))+z|0;C=b[s+(F<<2)+2>>1]|0;D=B;E=b[s+(F<<2)>>1]|0}else{C=w;D=u;E=v}}while(0);v=C+D|0;c[p>>2]=v;if((E|0)==0){G=0;H=v}else{w=t+(v>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7);w=(x^-2147483648)>>31;F=v+E|0;c[p>>2]=F;G=((w^x)>>>((32-E|0)>>>0)^w)-w|0;H=F}if((c[q>>2]|0)==500){if((c[r>>2]|0)==413){I=H}else{J=12}}else{J=12}if((J|0)==12){J=0;F=H+1|0;c[p>>2]=F;I=F}F=t+(I>>>3)|0;w=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>26;F=b[s+(w<<2)>>1]|0;x=b[s+(w<<2)+2>>1]|0;w=x<<16>>16;do{if(x<<16>>16<0){v=I+6|0;B=t+(v>>>3)|0;z=((fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7)>>>((w+32|0)>>>0))+F|0;B=b[s+(z<<2)>>1]|0;A=b[s+(z<<2)+2>>1]|0;z=A<<16>>16;if(!(A<<16>>16<0)){K=z;L=v;M=B;break}A=v-w|0;v=t+(A>>>3)|0;y=((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(A&7)>>>((z+32|0)>>>0))+B|0;K=b[s+(y<<2)+2>>1]|0;L=A;M=b[s+(y<<2)>>1]|0}else{K=w;L=I;M=F}}while(0);F=K+L|0;c[p>>2]=F;if((M|0)==0){N=0;O=F}else{w=t+(F>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(F&7);w=(x^-2147483648)>>31;y=F+M|0;c[p>>2]=y;N=((w^x)>>>((32-M|0)>>>0)^w)-w|0;O=y}u=O+1|0;c[p>>2]=u;c[g+(e<<3)>>2]=G;b[a+14692+(e<<2)>>1]=G;c[g+(e<<3)+4>>2]=N;b[a+14692+(e<<2)+2>>1]=N;e=e+1|0;}while((e|0)<(c[o>>2]|0));if((e|0)<4){P=e;J=19}else{Q=0}}else{P=0;J=19}if((J|0)==19){while(1){J=0;b[a+14692+(P<<2)+2>>1]=0;b[a+14692+(P<<2)>>1]=0;e=P+1|0;if((e|0)<4){P=e;J=19}else{Q=0;break}}}while(1){R=1<<Q;if((R|0)<(h|0)){Q=Q+1|0}else{S=0;break}}while(1){T=1<<S;if((T|0)<(m|0)){S=S+1|0}else{break}}do{if((c[a+14748>>2]|0)==500){if((c[a+14752>>2]|0)!=413){J=25;break}P=c[g>>2]|0;e=c[g+4>>2]|0;N=P+(ba(j,h)|0)|0;G=e+(ba(m,j)|0)|0;U=G+(c[g+20>>2]|0)|0;V=(c[g+16>>2]|0)+P|0;W=(c[g+12>>2]|0)+e|0;X=N+(c[g+8>>2]|0)|0;Y=e;Z=P}else{J=25}}while(0);if((J|0)==25){J=j>>1;P=c[g>>2]|0;e=ba(P,J)|0;N=c[g+4>>2]|0;G=ba(N,J)|0;u=ba(P+(h<<1)+(c[g+8>>2]|0)|0,J)|0;p=ba((c[g+12>>2]|0)+N|0,J)|0;O=ba((c[g+16>>2]|0)+P|0,J)|0;U=ba(N+(m<<1)+(c[g+20>>2]|0)|0,J)|0;V=O;W=p;X=u;Y=G;Z=e}e=R<<4;G=h-R|0;u=ba(Z,l)|0;p=((ba(X,l)|0)-(h<<4)<<Q)+(ba(u,G)|0)|0;X=h>>1;O=-X|0;J=((((p|0)>0?X:O)+p|0)/(h|0)|0)+e|0;p=ba(Y,l)|0;g=((ba(W,l)|0)<<Q)+(ba(p,G)|0)|0;G=(((g|0)>0?X:O)+g|0)/(h|0)|0;h=m-T|0;g=((ba(V,l)|0)<<S)+(ba(u,h)|0)|0;u=m>>1;V=((ba(U,l)|0)-(m<<4)<<S)+(ba(p,h)|0)|0;h=c[o>>2]|0;if((h|0)==3){o=-u|0;U=(Q|0)>(S|0)?S:Q;O=R>>U;X=T>>U;W=Q+k+S-U|0;U=-l|0;S=ba(Z,U)|0;N=ba(J+S|0,X)|0;P=ba(((((g|0)>0?u:o)+g|0)/(m|0)|0)+S|0,O)|0;S=1<<W-1;c[a+13884>>2]=(Z<<W)+S;g=ba(Y,U)|0;U=ba(G+g|0,X)|0;M=ba(g+(T<<4)+((((V|0)>0?u:o)+V|0)/(m|0)|0)|0,O)|0;c[a+13888>>2]=(Y<<W)+S;S=ba(l<<1<<Q,X)|0;O=(1<<W+1)-(ba(X,e)|0)|0;c[a+13892>>2]=O+(ba(Z,S)|0)+N+P;c[a+13896>>2]=O+(ba(Y,S)|0)+U+M;S=a+13900|0;c[S>>2]=N;c[a+13904>>2]=P;c[a+13908>>2]=U;c[a+13912>>2]=M;M=a+14708|0;c[M>>2]=W;c[a+14712>>2]=W+2;_=S;$=M}else if((h|0)==0){M=a+13900|0;TGb(a+13884|0,0,16)|0;c[M>>2]=j;c[a+13908>>2]=0;c[a+13904>>2]=0;c[a+13912>>2]=j;c[a+14712>>2]=0;S=a+14708|0;c[S>>2]=0;_=M;$=S}else if((h|0)==2){S=Q+k|0;k=-l|0;Q=J+(ba(Z,k)|0)|0;J=p-G|0;p=1<<S-1;c[a+13884>>2]=(Z<<S)+p;M=G+(ba(Y,k)|0)|0;c[a+13888>>2]=(Y<<S)+p;p=ba(R<<1,l)|0;l=(1<<S+1)-e|0;c[a+13892>>2]=l+(ba(Z,p)|0)+J+Q;c[a+13896>>2]=l+(ba(Y,p)|0)+Q+M;p=a+13900|0;c[p>>2]=Q;c[a+13904>>2]=J;c[a+13908>>2]=M;c[a+13912>>2]=Q;Q=a+14708|0;c[Q>>2]=S;c[a+14712>>2]=S+2;_=p;$=Q}else if((h|0)==1){c[a+13884>>2]=Z;c[a+13888>>2]=Y;c[a+13892>>2]=Z>>1|Z&1;c[a+13896>>2]=Y>>1|Y&1;Y=a+13900|0;c[Y>>2]=j;c[a+13908>>2]=0;c[a+13904>>2]=0;c[a+13912>>2]=j;c[a+14712>>2]=0;Z=a+14708|0;c[Z>>2]=0;_=Y;$=Z}else{_=a+13900|0;$=a+14708|0}Z=c[_>>2]|0;Y=c[$>>2]|0;Q=a+13904|0;p=c[Q>>2]|0;do{if((Z|0)==(j<<Y|0)&(p|0)==0){S=a+13908|0;if((c[S>>2]|0)!=0){aa=0;break}M=a+13912|0;if((c[M>>2]|0)!=(Z|0)){aa=0;break}J=a+13884|0;c[J>>2]=c[J>>2]>>Y;J=a+13888|0;c[J>>2]=c[J>>2]>>Y;J=a+14712|0;l=c[J>>2]|0;e=a+13892|0;c[e>>2]=c[e>>2]>>l;e=a+13896|0;c[e>>2]=c[e>>2]>>l;c[_>>2]=j;c[Q>>2]=0;c[S>>2]=0;c[M>>2]=j;c[$>>2]=0;c[J>>2]=0;c[a+13880>>2]=1;n=0;i=f;return n|0}else{aa=p}}while(0);p=16-Y|0;Y=a+14712|0;j=16-(c[Y>>2]|0)|0;Q=a+13884|0;c[Q>>2]=c[Q>>2]<<p;Q=a+13892|0;c[Q>>2]=c[Q>>2]<<j;c[_>>2]=Z<<p;Z=a+13908|0;c[Z>>2]=c[Z>>2]<<p;c[$>>2]=16;$=a+13888|0;c[$>>2]=c[$>>2]<<p;$=a+13896|0;c[$>>2]=c[$>>2]<<j;c[a+13904>>2]=aa<<p;aa=a+13912|0;c[aa>>2]=c[aa>>2]<<p;c[Y>>2]=16;c[a+13880>>2]=h;n=0;i=f;return n|0}function bNa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;f=i;i=i+32|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=e|0;m=e+9992|0;n=(c[m>>2]|0)==1;o=n?12:8;p=n?96:64;n=e+14084|0;c[n>>2]=1;q=e+12480|0;r=e+120|0;a:do{if((c[q>>2]|0)<(c[r>>2]|0)){s=e+12476|0;t=e+116|0;u=e+124|0;v=e+4|0;w=e+12496|0;x=e+12500|0;y=e+12504|0;z=e+12508|0;A=e+12512|0;B=e+12516|0;C=e+12544|0;D=e+12548|0;E=e+12552|0;F=e+13704|0;G=e+13708|0;H=e+9148|0;I=e+128|0;J=e+14120|0;K=e+14128|0;L=e+9936|0;M=e+12488|0;N=e+9932|0;O=e+14680|0;P=e+13916|0;Q=e+11556|0;R=e+9160|0;S=e+9960|0;T=e+9136|0;U=e+9940|0;V=0;b:while(1){$Oa(l);W=c[s>>2]|0;if((W|0)<(c[t>>2]|0)){X=V;Y=W;while(1){Z=c[q>>2]|0;W=(ba(c[u>>2]|0,Z)|0)+Y|0;_=X+1|0;$=c[v>>2]|0;aa=8>>>((c[$+800>>2]|0)>>>0);ca=(c[w>>2]|0)+2|0;c[w>>2]=ca;c[x>>2]=(c[x>>2]|0)+2;c[y>>2]=(c[y>>2]|0)+2;c[z>>2]=(c[z>>2]|0)+2;c[A>>2]=(c[A>>2]|0)+1;c[B>>2]=(c[B>>2]|0)+1;c[C>>2]=(c[C>>2]|0)+(aa<<1);c[D>>2]=(c[D>>2]|0)+aa;c[E>>2]=(c[E>>2]|0)+aa;do{if((Y|0)==(c[F>>2]|0)){if((Z|0)!=((c[G>>2]|0)+1|0)){break}c[n>>2]=0}}while(0);aa=c[m>>2]|0;c:do{if((aa|0)==1){da=c[J>>2]|0;ea=c[K>>2]|0;do{fa=da+(ea>>>3)|0;ga=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ea&7);if((ga&-8192|0)==-704634880){ha=X;break a}fa=c[1850731]|0;ia=ga>>>26;ga=b[fa+(ia<<2)>>1]|0;ja=b[fa+(ia<<2)+2>>1]|0;ia=ja<<16>>16;if(ja<<16>>16<0){ja=ea+6|0;ka=da+(ja>>>3)|0;la=((fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ja&7)>>>((ia+32|0)>>>0))+ga|0;ma=b[fa+(la<<2)+2>>1]|0;na=ja;oa=b[fa+(la<<2)>>1]|0}else{ma=ia;na=ea;oa=ga}ea=ma+na|0;c[K>>2]=ea;if((oa|0)<0){pa=13;break b}}while((oa|0)==8);a[(c[L>>2]|0)+W|0]=oa&3;c[(c[R>>2]|0)+(W<<2)>>2]=1;c[M>>2]=1;if((oa&4|0)!=0){ea=c[S>>2]|0;da=c[K>>2]|0;ga=(c[J>>2]|0)+(da>>>3)|0;ia=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(da&7)>>>30;c[K>>2]=da+2;cPa(l,(a[645448+ia|0]|0)+ea|0)}a[(c[T>>2]|0)+W|0]=c[S>>2];a[(c[N>>2]|0)+W|0]=1;if((lNa(l,0,h)|0)<0){pa=18;break b}ea=c[h>>2]|0;if((lNa(l,1,h)|0)<0){pa=18;break b}ia=(c[h>>2]|0)!=0|0;if((lNa(l,2,h)|0)<0){pa=18;break b}da=c[h>>2]|0;if((lNa(l,3,h)|0)<0){pa=18;break b}ga=(c[h>>2]|0)!=0|0;if((lNa(l,4,h)|0)<0){pa=18;break b}la=c[h>>2]|0;if((lNa(l,5,h)|0)<0){pa=18;break b}a[(c[U>>2]|0)+W|0]=(c[h>>2]|0)!=0|((la|0)!=0|(ga|((da|0)!=0|(ia|((ea|0)!=0)<<1)<<1)<<1)<<1)<<1}else{ea=c[H>>2]|0;ia=ea+(ca<<2)|0;da=c[I>>2]<<1;ga=c[J>>2]|0;la=c[K>>2]|0;do{fa=ga+(la>>>3)|0;ja=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(la&7)>>>15;if((ja|0)==126977){ha=X;break a}fa=la+1|0;c[K>>2]=fa;if((ja&65536|0)!=0){pa=23;break}ja=c[1850737]|0;ka=ga+(fa>>>3)|0;qa=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(fa&7)>>>25;ka=b[ja+(qa<<2)>>1]|0;ra=b[ja+(qa<<2)+2>>1]|0;qa=ra<<16>>16;if(ra<<16>>16<0){ra=la+8|0;sa=ga+(ra>>>3)|0;ta=((fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ra&7)>>>((qa+32|0)>>>0))+ka|0;ua=b[ja+(ta<<2)+2>>1]|0;va=ra;wa=b[ja+(ta<<2)>>1]|0}else{ua=qa;va=fa;wa=ka}la=ua+va|0;c[K>>2]=la;if((wa|0)<0){pa=32;break b}}while((wa|0)==20);if((pa|0)==23){pa=0;do{if((aa|0)==4){if((c[O>>2]|0)!=2){pa=26;break}c[(c[R>>2]|0)+(W<<2)>>2]=15368;la=iNa(e,0)|0;xa=(iNa(e,1)|0)&65535;ya=la&65535}else{pa=26}}while(0);if((pa|0)==26){pa=0;c[(c[R>>2]|0)+(W<<2)>>2]=14344;xa=0;ya=0}b[ea+(ca<<2)+(da+2<<1)>>1]=ya;b[ea+(ca<<2)+(da<<1)>>1]=ya;b[ea+(ca<<2)+4>>1]=ya;b[ia>>1]=ya;b[ea+(ca<<2)+(da+3<<1)>>1]=xa;b[ea+(ca<<2)+((da|1)<<1)>>1]=xa;b[ea+(ca<<2)+6>>1]=xa;b[ea+(ca<<2)+2>>1]=xa;if((a[(c[N>>2]|0)+W|0]|0)==0){break}XOa(l);break}a[(c[L>>2]|0)+W|0]=wa&11;la=wa&4;c[M>>2]=la>>>2;if((la|0)!=0){c[(c[R>>2]|0)+(W<<2)>>2]=1;a[(c[N>>2]|0)+W|0]=1;b[ea+(ca<<2)+(da+2<<1)>>1]=0;b[ea+(ca<<2)+(da<<1)>>1]=0;b[ea+(ca<<2)+4>>1]=0;b[ia>>1]=0;b[ea+(ca<<2)+(da+3<<1)>>1]=0;b[ea+(ca<<2)+((da|1)<<1)>>1]=0;b[ea+(ca<<2)+6>>1]=0;b[ea+(ca<<2)+2>>1]=0;break}if((a[(c[N>>2]|0)+W|0]|0)!=0){XOa(l)}do{if((c[m>>2]|0)==4){if((c[O>>2]|0)!=2){pa=42;break}if((wa&16|0)!=0){pa=42;break}la=c[K>>2]|0;ga=d[(c[J>>2]|0)+(la>>>3)|0]<<(la&7)>>>7;c[K>>2]=la+1;c[P>>2]=ga&1}else{pa=42}}while(0);do{if((pa|0)==42){pa=0;c[P>>2]=0;if((wa&16|0)==0){break}c[(c[R>>2]|0)+(W<<2)>>2]=12352;ga=Bca(l,0,0,j,k)|0;la=kIa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((la|0)>65534){ha=-1;break a}ka=kIa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((ka|0)>65534){ha=-1;break a}b[ga>>1]=la;b[ga+2>>1]=ka;ka=Bca(l,1,0,j,k)|0;ga=kIa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((ga|0)>65534){ha=-1;break a}la=kIa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((la|0)>65534){ha=-1;break a}b[ka>>1]=ga;b[ka+2>>1]=la;la=Bca(l,2,0,j,k)|0;ka=kIa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((ka|0)>65534){ha=-1;break a}ga=kIa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((ga|0)>65534){ha=-1;break a}b[la>>1]=ka;b[la+2>>1]=ga;ga=Bca(l,3,0,j,k)|0;la=kIa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((la|0)>65534){ha=-1;break a}ka=kIa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((ka|0)>65534){ha=-1;break a}b[ga>>1]=la;b[ga+2>>1]=ka;break c}}while(0);Bca(l,0,0,j,k)|0;if((c[P>>2]|0)==0){ka=kIa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((ka|0)>65534){ha=-1;break a}ga=kIa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((ga|0)>65534){ha=-1;break a}c[(c[R>>2]|0)+(W<<2)>>2]=12296;za=ga&65535;Aa=ka&65535}else{ka=iNa(e,0)|0;ga=iNa(e,1)|0;c[(c[R>>2]|0)+(W<<2)>>2]=13320;za=ga&65535;Aa=ka&65535}b[ea+(ca<<2)+(da+2<<1)>>1]=Aa;b[ea+(ca<<2)+(da<<1)>>1]=Aa;b[ea+(ca<<2)+4>>1]=Aa;b[ia>>1]=Aa;b[ea+(ca<<2)+(da+3<<1)>>1]=za;b[ea+(ca<<2)+((da|1)<<1)>>1]=za;b[ea+(ca<<2)+6>>1]=za;b[ea+(ca<<2)+2>>1]=za}}while(0);ca=(c[s>>2]|0)+1|0;c[s>>2]=ca;if((ca|0)<(c[t>>2]|0)){X=_;Y=ca}else{Ba=_;break}}}else{Ba=V}c[s>>2]=0;X=(c[q>>2]|0)+1|0;c[q>>2]=X;if((X|0)<(c[r>>2]|0)){V=Ba}else{ha=Ba;break a}}if((pa|0)==13){yDb($,16,2240416,(Ca=i,i=i+16|0,c[Ca>>2]=Y,c[Ca+8>>2]=Z,Ca)|0);i=Ca;ha=-1;break}else if((pa|0)==18){V=c[q>>2]|0;yDb(c[v>>2]|0,16,2245608,(Ca=i,i=i+16|0,c[Ca>>2]=c[s>>2],c[Ca+8>>2]=V,Ca)|0);i=Ca;ha=-1;break}else if((pa|0)==32){yDb($,16,2240416,(Ca=i,i=i+16|0,c[Ca>>2]=Y,c[Ca+8>>2]=Z,Ca)|0);i=Ca;ha=-1;break}}else{ha=0}}while(0);if((ha|0)<0){Lkb(e+14424|0,c[e+13704>>2]|0,c[e+13708>>2]|0,c[e+12476>>2]|0,c[q>>2]|0,o);Da=-1;i=f;return Da|0}Z=e+13704|0;Y=c[Z>>2]|0;$=e+13708|0;Ba=c[$>>2]|0;r=e+116|0;za=Y+ha+(ba(c[r>>2]|0,Ba)|0)|0;if((za|0)>(c[e+144>>2]|0)){yDb(c[e+4>>2]|0,16,1939192,(Ca=i,i=i+1|0,i=i+7&-8,c[Ca>>2]=0,Ca)|0);i=Ca;Lkb(e+14424|0,c[Z>>2]|0,c[$>>2]|0,c[e+12476>>2]|0,c[q>>2]|0,o);Da=-1;i=f;return Da|0}c[e+13732>>2]=ha;o=(c[m>>2]|0)==1;za=c[e+14120>>2]|0;Aa=e+14128|0;k=c[Aa>>2]|0;j=za+(k>>>3)|0;wa=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(k&7);do{if(o){if((wa&-8388608|0)==8388608){j=k;while(1){xa=j+9|0;c[Aa>>2]=xa;ya=za+(xa>>>3)|0;if(((fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(xa&7)&-8388608|0)==8388608){j=xa}else{Ea=xa;break}}}else{Ea=k}j=za+(Ea>>>3)|0;s=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(Ea&7);c[Aa>>2]=Ea+19;if((s&-8192|0)==-704634880){break}s=c[q>>2]|0;yDb(c[e+4>>2]|0,16,1914968,(Ca=i,i=i+16|0,c[Ca>>2]=c[e+12476>>2],c[Ca+8>>2]=s,Ca)|0);i=Ca;Da=-1;i=f;return Da|0}else{if((wa&-4194304|0)==4194304){s=k;while(1){j=s+10|0;c[Aa>>2]=j;v=za+(j>>>3)|0;if(((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(j&7)&-4194304|0)==4194304){s=j}else{Fa=j;break}}}else{Fa=k}s=za+(Fa>>>3)|0;j=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(Fa&7);c[Aa>>2]=Fa+17;if((j&-32768|0)==-134184960){break}j=c[q>>2]|0;yDb(c[e+4>>2]|0,16,1894496,(Ca=i,i=i+16|0,c[Ca>>2]=c[e+12476>>2],c[Ca+8>>2]=j,Ca)|0);i=Ca;Da=-1;i=f;return Da|0}}while(0);Fa=e+14424|0;Aa=e+12476|0;Lkb(Fa,Y,Ba,(c[Aa>>2]|0)-1|0,c[q>>2]|0,p);c[Aa>>2]=c[Z>>2];c[n>>2]=1;c[q>>2]=c[$>>2];d:do{if((ha|0)>0){p=e+124|0;Ba=e+4|0;Y=e+12496|0;za=e+12500|0;k=e+12504|0;wa=e+12508|0;Ea=e+12512|0;o=e+12516|0;j=e+12544|0;s=e+12548|0;v=e+12552|0;xa=e+14128|0;ya=e+14120|0;va=e+9936|0;ua=e+9160|0;h=e+9960|0;oa=e+9136|0;na=e+9940|0;ma=0;e:while(1){$Oa(l);if((ma|0)>=(ha|0)){break d}V=ma;Ga=c[Aa>>2]|0;while(1){if((Ga|0)>=(c[r>>2]|0)){break}Ha=c[q>>2]|0;t=(ba(c[p>>2]|0,Ha)|0)+Ga|0;R=V+1|0;Ia=c[Ba>>2]|0;Q=8>>>((c[Ia+800>>2]|0)>>>0);c[Y>>2]=(c[Y>>2]|0)+2;c[za>>2]=(c[za>>2]|0)+2;c[k>>2]=(c[k>>2]|0)+2;c[wa>>2]=(c[wa>>2]|0)+2;c[Ea>>2]=(c[Ea>>2]|0)+1;c[o>>2]=(c[o>>2]|0)+1;c[j>>2]=(c[j>>2]|0)+(Q<<1);c[s>>2]=(c[s>>2]|0)+Q;c[v>>2]=(c[v>>2]|0)+Q;do{if((Ga|0)==(c[Z>>2]|0)){if((Ha|0)!=((c[$>>2]|0)+1|0)){break}c[n>>2]=0}}while(0);do{if((c[m>>2]|0)==1){_=c[xa>>2]|0;Q=c[ya>>2]|0;P=a[Q+(_>>>3)|0]|0;K=_+1|0;c[xa>>2]=K;J=c[1888269]|0;O=Q+(K>>>3)|0;Q=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(K&7)>>>26;O=b[J+(Q<<2)>>1]|0;c[xa>>2]=(b[J+(Q<<2)+2>>1]|0)+K;if(O<<16>>16<0){pa=88;break e}K=(c[va>>2]|0)+t|0;a[K]=a[K]|(O&255)<<2;O=(c[ua>>2]|0)+(t<<2)|0;c[O>>2]=c[O>>2]|(P&255)<<(_&7)>>>7<<9&512}else{_=c[(c[ua>>2]|0)+(t<<2)>>2]|0;if((_&7|0)==0){if((_&2048|0)!=0){a[(c[oa>>2]|0)+t|0]=c[h>>2];a[(c[va>>2]|0)+t|0]=0;break}_=c[1888269]|0;P=c[xa>>2]|0;O=c[ya>>2]|0;K=O+(P>>>3)|0;Q=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(P&7)>>>26;K=b[_+(Q<<2)>>1]|0;J=(b[_+(Q<<2)+2>>1]|0)+P|0;c[xa>>2]=J;if(K<<16>>16<0){pa=101;break e}if(!((a[(c[va>>2]|0)+t|0]&8)==0)){P=c[h>>2]|0;Q=O+(J>>>3)|0;O=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(J&7)>>>30;c[xa>>2]=J+2;cPa(l,(a[645448+O|0]|0)+P|0)}a[(c[oa>>2]|0)+t|0]=c[h>>2];P=(c[va>>2]|0)+t|0;a[P]=a[P]&3;P=(c[va>>2]|0)+t|0;a[P]=a[P]|(K&255)<<2^60;break}K=c[xa>>2]|0;P=c[ya>>2]|0;O=d[P+(K>>>3)|0]<<(K&7)>>>7;J=K+1|0;c[xa>>2]=J;K=c[1888269]|0;Q=P+(J>>>3)|0;_=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(J&7)>>>26;Q=b[K+(_<<2)>>1]|0;N=(b[K+(_<<2)+2>>1]|0)+J|0;c[xa>>2]=N;if(Q<<16>>16<0){pa=92;break e}if(!((a[(c[va>>2]|0)+t|0]&8)==0)){J=c[h>>2]|0;_=P+(N>>>3)|0;P=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(N&7)>>>30;c[xa>>2]=N+2;cPa(l,(a[645448+P|0]|0)+J|0)}a[(c[oa>>2]|0)+t|0]=c[h>>2];if((lNa(l,0,g)|0)<0){pa=96;break e}J=c[g>>2]|0;if((lNa(l,1,g)|0)<0){pa=96;break e}P=(c[g>>2]|0)!=0|0;if((lNa(l,2,g)|0)<0){pa=96;break e}N=c[g>>2]|0;if((lNa(l,3,g)|0)<0){pa=96;break e}_=(c[g>>2]|0)!=0|0;if((lNa(l,4,g)|0)<0){pa=96;break e}K=c[g>>2]|0;if((lNa(l,5,g)|0)<0){pa=96;break e}M=(c[g>>2]|0)!=0|((K|0)!=0|(_|((N|0)!=0|(P|((J|0)!=0)<<1)<<1)<<1)<<1)<<1;J=(c[va>>2]|0)+t|0;a[J]=a[J]&3;J=(c[va>>2]|0)+t|0;a[J]=a[J]|(Q&255)<<2;Q=(c[ua>>2]|0)+(t<<2)|0;c[Q>>2]=c[Q>>2]|O<<9&512;a[(c[na>>2]|0)+t|0]=M}}while(0);t=(c[Aa>>2]|0)+1|0;c[Aa>>2]=t;if((R|0)<(ha|0)){V=R;Ga=t}else{break d}}c[Aa>>2]=0;c[q>>2]=(c[q>>2]|0)+1;if((V|0)<(ha|0)){ma=V}else{break d}}if((pa|0)==88){yDb(Ia,16,2247824,(Ca=i,i=i+16|0,c[Ca>>2]=Ga,c[Ca+8>>2]=Ha,Ca)|0);i=Ca}else if((pa|0)==92){yDb(Ia,16,2246752,(Ca=i,i=i+16|0,c[Ca>>2]=Ga,c[Ca+8>>2]=Ha,Ca)|0);i=Ca}else if((pa|0)==96){ma=c[q>>2]|0;yDb(c[Ba>>2]|0,16,2245608,(Ca=i,i=i+16|0,c[Ca>>2]=c[Aa>>2],c[Ca+8>>2]=ma,Ca)|0);i=Ca}else if((pa|0)==101){yDb(Ia,16,2244552,(Ca=i,i=i+16|0,c[Ca>>2]=Ga,c[Ca+8>>2]=Ha,Ca)|0);i=Ca}if((c[m>>2]|0)!=2){Da=-1;i=f;return Da|0}Lkb(Fa,c[Z>>2]|0,c[$>>2]|0,c[Aa>>2]|0,c[q>>2]|0,4);Da=-1;i=f;return Da|0}}while(0);if((c[m>>2]|0)!=2){Da=0;i=f;return Da|0}Lkb(Fa,c[Z>>2]|0,c[$>>2]|0,(c[Aa>>2]|0)-1|0,c[q>>2]|0,32);Da=0;i=f;return Da|0}function cNa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;d=c[a+60>>2]|0;e=d+14756|0;f=c[e>>2]|0;a:do{if((f|0)==-1){g=d+14748|0;h=(c[g>>2]|0)==-1;if(!h){j=-1;break}b:do{if((c[d+14760>>2]|0)==-1){do{if((c[d+92>>2]|0)!=1145656920){k=c[d+88>>2]|0;if((k|0)==1145656920|(k|0)==1481201240|(k|0)==877677906|(k|0)==877677914|(k|0)==1347438931){break}if(h){break b}else{j=-1;break a}}}while(0);c[e>>2]=0;l=0;m=14;break a}}while(0);if(!((c[d+14760>>2]|0)==-1)){j=-1;break}if((c[d+88>>2]|0)!=1482049860){j=-1;break}if((c[d+13948>>2]|0)!=0){j=-1;break}if((c[d+13952>>2]|0)!=0){j=-1;break}c[g>>2]=400;j=-1}else{if((f|0)>-1){l=f;m=14}else{j=f}}}while(0);do{if((m|0)==14){f=d+14748|0;if(!((c[f>>2]|0)>-1)){j=l;break}c[d+14752>>2]=-1;c[f>>2]=-1;j=l}}while(0);l=d+84|0;f=c[l>>2]|0;do{if((f&1|0)==0){n=f}else{e=c[d+88>>2]|0;if((e|0)==877677909){h=f|8;c[l>>2]=h;o=h}else if((e|0)==1481201240){e=f|4;c[l>>2]=e;o=e}else{o=f}e=c[d+14748>>2]|0;do{if((e|0)>499){h=(c[d+14752>>2]|0)<1814;if(h){k=o|64;c[l>>2]=k;p=k}else{p=o}if((e|0)<503|h^1){q=p;break}h=p|256;c[l>>2]=h;q=h}else{q=o}}while(0);do{if(j>>>0<4>>>0){c[d+14008>>2]=1073741824;if(!(j>>>0<2>>>0)){r=q;m=29;break}g=q|64;c[l>>2]=g;s=g;m=28}else{s=q;m=28}}while(0);if((m|0)==28){if(j>>>0<13>>>0){r=s;m=29}else{t=s}}if((m|0)==29){g=r|1024;c[l>>2]=g;t=g}if(j>>>0<33>>>0){g=t|4096;c[l>>2]=g;u=g}else{u=t}g=c[d+14760>>2]|0;if(g>>>0<4653>>>0){h=u|128;c[l>>2]=h;v=h;m=35}else{if(g>>>0<4655>>>0){v=u;m=35}else{w=u}}if((m|0)==35){h=v|512;c[l>>2]=h;w=h}if(g>>>0<4670>>>0){h=w|1024;c[l>>2]=h;x=h}else{x=w}if(g>>>0<4713>>>0){g=x|4096;c[l>>2]=g;y=g}else{y=x}g=(e|0)>-1;if(!g){n=y;break}h=y|512;c[l>>2]=h;do{if((e|0)==501){if((c[d+14752>>2]|0)!=20020416){z=h;break}c[d+14008>>2]=1073741824;m=44}else{m=44}}while(0);do{if((m|0)==44){if(!(e>>>0<500>>>0)){z=h;break}k=y|1536;c[l>>2]=k;z=k}}while(0);if(!g){n=z;break}h=z|2048;c[l>>2]=h;n=h}}while(0);if((n&128|0)!=0){c[d+10700>>2]=2230;c[d+10956>>2]=1442;c[d+10828>>2]=2002;c[d+10708>>2]=358;c[d+10964>>2]=1392;c[d+10836>>2]=530;c[d+10716>>2]=994;c[d+10972>>2]=814;c[d+10844>>2]=1008;c[d+10724>>2]=712;c[d+10980>>2]=268;c[d+10852>>2]=452;c[d+10732>>2]=12;c[d+10988>>2]=1804;c[d+10860>>2]=292;c[d+10740>>2]=1960;c[d+10996>>2]=810;c[d+10868>>2]=438;c[d+10764>>2]=1636;c[d+11020>>2]=1686;c[d+10892>>2]=2140;c[d+10772>>2]=1116;c[d+11028>>2]=472;c[d+10900>>2]=916;c[d+10780>>2]=934;c[d+11036>>2]=1904;c[d+10908>>2]=374;c[d+10788>>2]=1516;c[d+11044>>2]=238;c[d+10916>>2]=1846;c[d+10796>>2]=474;c[d+11052>>2]=2190;c[d+10924>>2]=824;c[d+10804>>2]=152;c[d+11060>>2]=1972;c[d+10932>>2]=1118}if((c[a+688>>2]&4096|0)==0){i=b;return 0}a=c[d+14760>>2]|0;l=c[d+14748>>2]|0;z=c[d+14752>>2]|0;y=(c[d+14012>>2]|0)!=0?2218480:9203448;yDb(c[d+4>>2]|0,48,2230456,(d=i,i=i+48|0,c[d>>2]=n,c[d+8>>2]=a,c[d+16>>2]=j,c[d+24>>2]=l,c[d+32>>2]=z,c[d+40>>2]=y,d)|0);i=d;i=b;return 0}function dNa(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0;h=i;i=i+320|0;j=h|0;k=h+256|0;l=h+264|0;m=h+272|0;n=h+280|0;o=h+288|0;p=h+296|0;q=f|0;r=g+8|0;s=c[r>>2]|0;t=-s&7;if((t|0)==0){u=s}else{v=t+s|0;c[r>>2]=v;u=v}v=f+88|0;do{if((c[v>>2]|0)==1177638487){s=c[g>>2]|0;t=s+(u>>>3)|0;if(((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(u&7)&-256|0)!=1465266176){w=u;x=6;break}t=u+24|0;c[r>>2]=t;y=s+(t>>>3)|0;s=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(t&7);t=u+32|0;c[r>>2]=t;if(!((s&-16777216|0)==-268435456)){w=t;x=6}}else{w=u;x=6}}while(0);a:do{if((x|0)==6){u=g+12|0;t=c[u>>2]|0;b:do{if((w|0)<(t|0)){s=g|0;y=f+4|0;z=p;A=f+13948|0;B=f+13928|0;C=f+13952|0;D=f+108|0;E=f+13944|0;G=f+14676|0;H=f+14672|0;I=f+14724|0;J=f+14224|0;K=f+14152|0;L=f+14236|0;M=f+14680|0;N=f+14688|0;O=f+13932|0;P=f+14684|0;Q=f+13920|0;R=f+14004|0;S=f+13924|0;T=f+14768|0;U=f+14772|0;V=f+14776|0;W=f+14720|0;X=f+13936|0;Y=f+14728|0;Z=f+14736|0;_=g;$=f+14732|0;aa=f+14716|0;ca=f+8|0;da=f+12|0;ea=f+14420|0;fa=j|0;ga=f+14748|0;ha=f+14752|0;ia=f+14012|0;ja=f+14764|0;ka=f+14760|0;la=f+14756|0;ma=f+13852|0;na=255;oa=w;c:while(1){pa=(c[s>>2]|0)+(oa>>>3)|0;qa=(fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(oa&7)>>>24;pa=oa+8|0;c[r>>2]=pa;ra=na<<8;sa=qa|ra;do{if((ra|0)==256){qa=c[y>>2]|0;if((c[qa+688>>2]&256|0)!=0){yDb(qa,48,2165264,(ta=i,i=i+8|0,c[ta>>2]=sa,ta)|0);i=ta;d:do{if(sa>>>0<288>>>0){yDb(c[y>>2]|0,48,2158552,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}else{if(sa>>>0<304>>>0){yDb(c[y>>2]|0,48,2151472,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}if(sa>>>0<320>>>0){yDb(c[y>>2]|0,48,2144464,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}if(sa>>>0<352>>>0){yDb(c[y>>2]|0,48,2138848,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}if(sa>>>0<432>>>0){yDb(c[y>>2]|0,48,2144464,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}switch(sa|0){case 434:{yDb(c[y>>2]|0,48,2120328,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 432:{yDb(c[y>>2]|0,48,2132544,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 448:{yDb(c[y>>2]|0,48,2036240,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 443:{yDb(c[y>>2]|0,48,2064024,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 436:{yDb(c[y>>2]|0,48,2099912,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 451:{yDb(c[y>>2]|0,48,2024832,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 447:{yDb(c[y>>2]|0,48,2039520,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 438:{yDb(c[y>>2]|0,48,2088024,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 445:{yDb(c[y>>2]|0,48,2055368,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 450:{yDb(c[y>>2]|0,48,2028456,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 439:{yDb(c[y>>2]|0,48,2083496,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 444:{yDb(c[y>>2]|0,48,2060160,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 437:{yDb(c[y>>2]|0,48,2093440,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 435:{yDb(c[y>>2]|0,48,2114224,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 449:{yDb(c[y>>2]|0,48,2032664,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 441:{yDb(c[y>>2]|0,48,2073040,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 440:{yDb(c[y>>2]|0,48,2077864,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 442:{yDb(c[y>>2]|0,48,2068480,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 433:{yDb(c[y>>2]|0,48,2126160,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 446:{yDb(c[y>>2]|0,48,2044592,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};default:{if(sa>>>0<454>>>0){yDb(c[y>>2]|0,48,2021504,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d}if(!(sa>>>0<512>>>0)){break d}yDb(c[y>>2]|0,48,2017656,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d}}}}while(0);yDb(c[y>>2]|0,48,2013616,(ta=i,i=i+8|0,c[ta>>2]=c[r>>2],ta)|0);i=ta}do{if((sa-288|0)>>>0<16>>>0){qa=c[r>>2]|0;ua=qa+1|0;c[r>>2]=ua;va=c[s>>2]|0;wa=va+(ua>>>3)|0;xa=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ua&7)>>>24;c[r>>2]=qa+9;c[A>>2]=xa;xa=c[r>>2]|0;qa=d[va+(xa>>>3)|0]|0;ua=xa+1|0;c[r>>2]=ua;if((qa&128>>>((xa&7)>>>0)|0)==0){ya=1;za=ua}else{qa=va+(ua>>>3)|0;wa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ua&7)>>>28;ua=xa+8|0;c[r>>2]=ua;ya=wa;za=ua}ua=va+(za>>>3)|0;wa=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(za&7)>>>28;c[r>>2]=za+4;c[B>>2]=wa;if((wa|0)==15){ua=c[r>>2]|0;xa=va+(ua>>>3)|0;qa=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(ua&7)>>>24;c[r>>2]=ua+8;ua=c[y>>2]|0;c[ua+224>>2]=qa;qa=c[r>>2]|0;xa=va+(qa>>>3)|0;Aa=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(qa&7)>>>24;c[r>>2]=qa+8;c[ua+228>>2]=Aa;Ba=va}else{va=1210392+(wa<<3)|0;wa=(c[y>>2]|0)+224|0;Aa=c[va+4>>2]|0;c[wa>>2]=c[va>>2];c[wa+4>>2]=Aa;Ba=c[s>>2]|0}Aa=c[r>>2]|0;wa=d[Ba+(Aa>>>3)|0]<<(Aa&7)>>>7;c[r>>2]=Aa+1;Aa=wa&1;c[C>>2]=Aa;do{if((Aa|0)==0){if((c[D>>2]|0)!=0){Ca=Ba;break}c[E>>2]=0;Ca=Ba}else{wa=c[r>>2]|0;va=Ba+(wa>>>3)|0;ua=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(wa&7);va=wa+2|0;c[r>>2]=va;if((ua&-1073741824|0)==1073741824){Da=va;Ea=Ba}else{yDb(c[y>>2]|0,16,2290656,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Da=c[r>>2]|0;Ea=c[s>>2]|0}va=d[Ea+(Da>>>3)|0]<<(Da&7)>>>7;c[r>>2]=Da+1;c[E>>2]=va&1;va=c[r>>2]|0;ua=d[Ea+(va>>>3)|0]|0;c[r>>2]=va+1;if((ua&128>>>((va&7)>>>0)|0)==0){Ca=Ea;break}c[r>>2]=va+80;Ca=Ea}}while(0);Aa=c[r>>2]|0;va=Ca+(Aa>>>3)|0;ua=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(Aa&7)>>>30;c[r>>2]=Aa+2;c[G>>2]=ua;do{if((ua|0)==0){Fa=(ya|0)==1;x=68}else{yDb(c[y>>2]|0,16,2285760,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Aa=(ya|0)==1;if((c[G>>2]|0)!=3|Aa){Fa=Aa;x=68;break}yDb(c[y>>2]|0,16,2283968,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Aa=(c[r>>2]|0)+4|0;c[r>>2]=Aa;Ga=Aa;Ha=0}}while(0);if((x|0)==68){x=0;Ga=c[r>>2]|0;Ha=Fa}ua=c[s>>2]|0;Aa=d[ua+(Ga>>>3)|0]|0;va=Ga+1|0;c[r>>2]=va;if((Aa&128>>>((Ga&7)>>>0)|0)==0){yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=2282616,ta)|0);i=ta;Ia=c[r>>2]|0;Ja=c[s>>2]|0}else{Ia=va;Ja=ua}ua=Ja+(Ia>>>3)|0;va=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(Ia&7)>>>16;c[r>>2]=Ia+16;Ka=c[y>>2]|0;c[Ka+108>>2]=va;if((va|0)==0){x=73;break c}ua=va-1|0;va=ua>>>0>65535>>>0;Aa=va?ua>>>16:ua;ua=va?16:0;if((Aa&65280|0)==0){La=ua;Ma=Aa}else{La=ua|8;Ma=Aa>>>8}Aa=(d[1191992+Ma|0]|0)+La|0;c[H>>2]=(Aa|0)<0?1:Aa+1|0;Aa=c[r>>2]|0;ua=c[s>>2]|0;va=d[ua+(Aa>>>3)|0]|0;wa=Aa+1|0;c[r>>2]=wa;if((va&128>>>((Aa&7)>>>0)|0)==0){yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=2280192,ta)|0);i=ta;Na=c[r>>2]|0;Oa=c[s>>2]|0}else{Na=wa;Oa=ua}ua=d[Oa+(Na>>>3)|0]|0;wa=Na+1|0;c[r>>2]=wa;if((ua&128>>>((Na&7)>>>0)|0)==0){c[(c[y>>2]|0)+104>>2]=1}else{ua=c[H>>2]|0;Aa=Oa+(wa>>>3)|0;va=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(wa&7)>>>((32-ua|0)>>>0);c[r>>2]=ua+wa;c[(c[y>>2]|0)+104>>2]=va}c[I>>2]=0;va=c[G>>2]|0;e:do{if((va|0)==0){wa=c[r>>2]|0;ua=d[Oa+(wa>>>3)|0]|0;Aa=wa+1|0;c[r>>2]=Aa;if((ua&128>>>((wa&7)>>>0)|0)==0){yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=2279176,ta)|0);i=ta;Pa=c[r>>2]|0;Qa=c[s>>2]|0}else{Pa=Aa;Qa=Oa}Aa=Qa+(Pa>>>3)|0;wa=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Pa&7)>>>19;Aa=Pa+13|0;c[r>>2]=Aa;ua=d[Qa+(Aa>>>3)|0]|0;qa=Pa+14|0;c[r>>2]=qa;if((ua&128>>>((Aa&7)>>>0)|0)==0){yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=2278120,ta)|0);i=ta;Ra=c[r>>2]|0;Sa=c[s>>2]|0}else{Ra=qa;Sa=Qa}qa=Sa+(Ra>>>3)|0;Aa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Ra&7)>>>19;qa=Ra+13|0;c[r>>2]=qa;ua=d[Sa+(qa>>>3)|0]|0;c[r>>2]=Ra+14;if((ua&128>>>((qa&7)>>>0)|0)==0){yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=2276928,ta)|0);i=ta}if((wa|0)==0|(Aa|0)==0){x=95;break}qa=c[ca>>2]|0;do{if((qa|0)!=0){if((c[v>>2]|0)==1395937357){x=95;break e}ua=c[da>>2]|0;if((ua|0)==0){break}if((qa|0)==(wa|0)&(ua|0)==(Aa|0)){break}c[ea>>2]=1}}while(0);c[ca>>2]=wa;c[da>>2]=Aa;x=95}else if((va|0)!=2){x=95}}while(0);do{if((x|0)==95){x=0;va=c[r>>2]|0;qa=c[s>>2]|0;ua=d[qa+(va>>>3)|0]<<(va&7)>>>7;c[r>>2]=va+1;va=ua&1^1;c[J>>2]=va;c[K>>2]=va;c[L>>2]=0;va=c[r>>2]|0;ua=d[qa+(va>>>3)|0]|0;qa=va+1|0;c[r>>2]=qa;do{if((ua&128>>>((va&7)>>>0)|0)==0){xa=c[y>>2]|0;if((c[xa+688>>2]&1|0)==0){Ta=qa;break}yDb(xa,32,2274744,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Ta=c[r>>2]|0}else{Ta=qa}}while(0);if(Ha){qa=d[(c[s>>2]|0)+(Ta>>>3)|0]<<(Ta&7)>>>7;c[r>>2]=Ta+1;Ua=qa&1}else{qa=(c[s>>2]|0)+(Ta>>>3)|0;va=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Ta&7)>>>30;c[r>>2]=Ta+2;Ua=va}c[M>>2]=Ua;if((Ua|0)==1){yDb(c[y>>2]|0,16,2269944,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Va=c[M>>2]|0}else{Va=Ua}do{if((Va-1|0)>>>0<2>>>0){va=c[r>>2]|0;if((Va|0)==1){qa=va+56|0;c[r>>2]=qa;Wa=qa}else{Wa=va}va=c[s>>2]|0;qa=va+(Wa>>>3)|0;ua=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Wa&7);Xa=ua>>>26;c[r>>2]=Wa+6;c[N>>2]=Xa;if(ua>>>0>268435455>>>0){x=108;break c}ua=c[r>>2]|0;qa=va+(ua>>>3)|0;Aa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ua&7)>>>30;c[r>>2]=ua+2;c[O>>2]=Aa;Aa=c[r>>2]|0;ua=d[va+(Aa>>>3)|0]<<(Aa&7)>>>7;c[r>>2]=Aa+1;c[P>>2]=ua&1;if((c[M>>2]|0)!=1){Ya=va;break}c[r>>2]=(c[r>>2]|0)+1;Ya=va}else{Ya=c[s>>2]|0}}while(0);va=c[r>>2]|0;ua=d[Ya+(va>>>3)|0]|0;Aa=va+1|0;c[r>>2]=Aa;do{if((ua&128>>>((va&7)>>>0)|0)==0){c[Q>>2]=5}else{qa=Ya+(Aa>>>3)|0;wa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Aa&7)>>>28;c[r>>2]=va+5;c[Q>>2]=wa;wa=c[r>>2]|0;qa=Ya+(wa>>>3)|0;xa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(wa&7);c[r>>2]=wa+4;if(!((xa&-268435456|0)==-2147483648)){yDb(c[y>>2]|0,16,2267304,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}xa=c[Q>>2]|0;if((xa|0)==5){break}yDb(c[y>>2]|0,16,2266072,(ta=i,i=i+8|0,c[ta>>2]=xa,ta)|0);i=ta;if(!(((c[Q>>2]|0)-3|0)>>>0>6>>>0)){break}c[Q>>2]=5}}while(0);va=c[r>>2]|0;Aa=c[s>>2]|0;ua=d[Aa+(va>>>3)|0]<<(va&7)>>>7;c[r>>2]=va+1;va=ua&1;c[R>>2]=va;f:do{if((va|0)!=0){ua=0;do{xa=d[f+11184+ua|0]|0;wa=b[1177024+(ua<<1)>>1]|0;b[f+12560+(xa<<1)>>1]=wa;b[f+12688+(xa<<1)>>1]=wa;wa=b[1176896+(ua<<1)>>1]|0;b[f+12816+(xa<<1)>>1]=wa;b[f+12944+(xa<<1)>>1]=wa;ua=ua+1|0;}while((ua|0)<64);ua=c[r>>2]|0;wa=d[Aa+(ua>>>3)|0]|0;xa=ua+1|0;c[r>>2]=xa;g:do{if((wa&128>>>((ua&7)>>>0)|0)==0){Za=xa}else{qa=0;_a=0;$a=xa;while(1){ab=Aa+($a>>>3)|0;bb=(fe(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<($a&7)>>>24;cb=$a+8|0;c[r>>2]=cb;if((bb|0)==0){break}ab=d[(d[1075976+_a|0]|0)+(f+11184)|0]|0;db=bb&65535;b[f+12560+(ab<<1)>>1]=db;b[f+12688+(ab<<1)>>1]=db;ab=_a+1|0;if((ab|0)<64){qa=db;_a=ab;$a=cb}else{Za=cb;break g}}if((_a|0)<64){eb=_a}else{Za=cb;break}while(1){$a=d[(d[1075976+eb|0]|0)+(f+11184)|0]|0;b[f+12560+($a<<1)>>1]=qa;b[f+12688+($a<<1)>>1]=qa;$a=eb+1|0;if(($a|0)<64){eb=$a}else{Za=cb;break}}}}while(0);xa=d[Aa+(Za>>>3)|0]|0;ua=Za+1|0;c[r>>2]=ua;if((xa&128>>>((Za&7)>>>0)|0)==0){break}else{fb=0;gb=0;hb=ua}while(1){ua=Aa+(hb>>>3)|0;xa=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(hb&7)>>>24;ua=hb+8|0;c[r>>2]=ua;if((xa|0)==0){break}wa=d[(d[1075976+gb|0]|0)+(f+11184)|0]|0;qa=xa&65535;b[f+12816+(wa<<1)>>1]=qa;b[f+12944+(wa<<1)>>1]=qa;wa=gb+1|0;if((wa|0)<64){fb=qa;gb=wa;hb=ua}else{break f}}if((gb|0)<64){ib=gb}else{break}do{ua=d[(d[1075976+ib|0]|0)+(f+11184)|0]|0;b[f+12816+(ua<<1)>>1]=fb;b[f+12944+(ua<<1)>>1]=fb;ib=ib+1|0;}while((ib|0)<64)}}while(0);va=(ya|0)!=1;if(va){ua=c[r>>2]|0;wa=d[Aa+(ua>>>3)|0]<<(ua&7)>>>7;c[r>>2]=ua+1;jb=wa&1}else{jb=0}c[S>>2]=jb;wa=c[r>>2]|0;if(((c[u>>2]|0)-wa|0)<4){x=133;break c}ua=d[Aa+(wa>>>3)|0]|0;qa=wa+1|0;c[r>>2]=qa;do{if((ua&128>>>((wa&7)>>>0)|0)==0){xa=Aa+(qa>>>3)|0;_a=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(qa&7);xa=_a>>>30;$a=wa+3|0;c[r>>2]=$a;if(!((_a|0)>-1)){yDb(c[y>>2]|0,16,2261304,(ta=i,i=i+8|0,c[ta>>2]=xa,ta)|0);i=ta;break}_a=d[Aa+($a>>>3)|0]|0;ab=wa+4|0;c[r>>2]=ab;if((_a&128>>>(($a&7)>>>0)|0)==0){$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=wa+5;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<3&8)+(c[T>>2]|0);_a=c[r>>2]|0;$a=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=_a+1;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<3&8)+(c[T>>2]|0);_a=c[r>>2]|0;$a=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=_a+1;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<3&8)+(c[T>>2]|0);kb=c[r>>2]|0}else{kb=ab}ab=d[Aa+(kb>>>3)|0]|0;_a=kb+1|0;c[r>>2]=_a;if((ab&128>>>((kb&7)>>>0)|0)==0){ab=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=kb+2;c[T>>2]=(ab<<3&8)+(c[T>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0);$a=c[r>>2]|0;ab=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[U>>2]=(ab<<3&8)+(c[U>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[T>>2]=($a<<3&8)+(c[T>>2]|0);lb=c[r>>2]|0}else{lb=_a}_a=d[Aa+(lb>>>3)|0]|0;$a=lb+1|0;c[r>>2]=$a;if((_a&128>>>((lb&7)>>>0)|0)==0){yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=2263856,ta)|0);i=ta;c[r>>2]=qa;x=151;break}_a=d[Aa+($a>>>3)|0]|0;ab=lb+2|0;c[r>>2]=ab;if((_a&128>>>(($a&7)>>>0)|0)==0){$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=lb+3;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<3&8)+(c[T>>2]|0);_a=c[r>>2]|0;$a=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=_a+1;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<2&4)+(c[T>>2]|0);mb=c[r>>2]|0}else{mb=ab}ab=d[Aa+(mb>>>3)|0]|0;_a=mb+1|0;c[r>>2]=_a;if((ab&128>>>((mb&7)>>>0)|0)==0){ab=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=mb+2;c[U>>2]=(ab<<3&8)+(c[U>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0);$a=c[r>>2]|0;ab=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[V>>2]=(ab<<3&8)+(c[V>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0);$a=c[r>>2]|0;ab=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[U>>2]=(ab<<3&8)+(c[U>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0);nb=c[r>>2]|0}else{nb=_a}_a=d[Aa+(nb>>>3)|0]|0;$a=nb+1|0;c[r>>2]=$a;if((_a&128>>>((nb&7)>>>0)|0)==0){yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=2262448,ta)|0);i=ta;c[r>>2]=qa;x=151;break}if((xa|0)!=1){break}xa=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=nb+2;c[T>>2]=(xa<<3&8)+(c[T>>2]|0);xa=c[r>>2]|0;$a=d[Aa+(xa>>>3)|0]<<(xa&7)>>>7;c[r>>2]=xa+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0)}else{x=151}}while(0);if((x|0)==151){x=0;c[V>>2]=0;c[U>>2]=0;c[T>>2]=0}Aa=c[r>>2]|0;qa=c[s>>2]|0;wa=d[qa+(Aa>>>3)|0]<<(Aa&7);c[r>>2]=Aa+1;c[W>>2]=wa>>>7&1^1;wa=c[r>>2]|0;Aa=d[qa+(wa>>>3)|0]<<(wa&7)>>>7;c[r>>2]=wa+1;wa=Aa&1;c[X>>2]=wa;if((wa|0)!=0){wa=c[r>>2]|0;Aa=d[qa+(wa>>>3)|0]<<(wa&7)>>>7;c[r>>2]=wa+1;c[aa>>2]=Aa&1}do{if(va){Aa=c[r>>2]|0;wa=d[qa+(Aa>>>3)|0]<<(Aa&7)>>>7;c[r>>2]=Aa+1;Aa=wa&1;c[Y>>2]=Aa;if((Aa|0)==0){ob=qa;pb=c[r>>2]|0}else{yDb(c[y>>2]|0,16,2260176,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Aa=(c[r>>2]|0)+3|0;c[r>>2]=Aa;ob=c[s>>2]|0;pb=Aa}Aa=d[ob+(pb>>>3)|0]|0;c[r>>2]=pb+1;if((Aa&128>>>((pb&7)>>>0)|0)==0){qb=ob;break}yDb(c[y>>2]|0,16,2259016,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;qb=c[s>>2]|0}else{c[Y>>2]=0;qb=qa}}while(0);qa=c[r>>2]|0;va=d[qb+(qa>>>3)|0]<<(qa&7)>>>7;c[r>>2]=qa+1;qa=va&1;c[Z>>2]=qa;if((qa|0)==0){break}c[z>>2]=c[_>>2];c[z+4>>2]=c[_+4>>2];c[z+8>>2]=c[_+8>>2];c[z+12>>2]=c[_+12>>2];c[z+16>>2]=c[_+16>>2];qa=c[r>>2]|0;va=qa+6|0;c[r>>2]=va;Aa=qb+(va>>>3)|0;wa=fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0;Aa=qa+11|0;c[r>>2]=Aa;ua=qb+(Aa>>>3)|0;$a=fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0;ua=qa+16|0;c[r>>2]=ua;xa=qb+(ua>>>3)|0;_a=fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0;xa=qa+21|0;c[r>>2]=xa;ab=qb+(xa>>>3)|0;db=fe(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0;ab=qa+26|0;c[r>>2]=ab;bb=d[qb+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=qa+27;c[$>>2]=bb&1;if((-134217728>>>((va&7)>>>0)&wa|0)==0|($a&-134217728>>>((Aa&7)>>>0)|0)==0|(_a&-134217728>>>((ua&7)>>>0)|0)==0|(db&-134217728>>>((xa&7)>>>0)|0)==0){c[Z>>2]=0;c[_>>2]=c[z>>2];c[_+4>>2]=c[z+4>>2];c[_+8>>2]=c[z+8>>2];c[_+12>>2]=c[z+12>>2];c[_+16>>2]=c[z+16>>2];break}else{yDb(c[y>>2]|0,16,2254552,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}}}while(0);xa=c[y>>2]|0;if((c[xa+688>>2]&1|0)==0){break}db=c[xa+108>>2]|0;ua=c[H>>2]|0;_a=c[Q>>2]|0;Aa=c[K>>2]|0;$a=(c[Z>>2]|0)!=0?2252016:9203448;wa=(c[S>>2]|0)!=0?2250992:9203448;va=(c[X>>2]|0)!=0?2249936:9203448;bb=(c[aa>>2]|0)!=0?2248856:9203448;yDb(xa,48,2253096,(ta=i,i=i+72|0,c[ta>>2]=c[xa+104>>2],c[ta+8>>2]=db,c[ta+16>>2]=ua,c[ta+24>>2]=_a,c[ta+32>>2]=Aa,c[ta+40>>2]=$a,c[ta+48>>2]=wa,c[ta+56>>2]=va,c[ta+64>>2]=bb,ta)|0);i=ta}else{if((sa|0)==432){bb=c[y>>2]|0;va=c[r>>2]|0;wa=c[s>>2]|0;$a=wa+(va>>>3)|0;Aa=(fe(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(va&7)>>>28;c[r>>2]=va+4;va=bb+840|0;c[va>>2]=Aa;Aa=c[r>>2]|0;$a=wa+(Aa>>>3)|0;wa=(fe(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(Aa&7)>>>28;c[r>>2]=Aa+4;Aa=bb+844|0;c[Aa>>2]=wa;if(!((c[va>>2]|0)==0&(wa|0)==8)){break}c[Aa>>2]=0;break}else if((sa|0)==435){Aa=c[s>>2]|0;wa=c[r>>2]|0;va=Aa+(wa>>>3)|0;bb=fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0;va=wa&7;if((bb&-512>>>(va>>>0)|0)==0){yDb(c[y>>2]|0,24,2303648,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}else{$a=wa+5|0;c[r>>2]=$a;_a=Aa+($a>>>3)|0;ua=(fe(d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0)|0)<<($a&7)>>>26;$a=wa+12|0;c[r>>2]=$a;_a=Aa+($a>>>3)|0;Aa=(fe(d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0)|0)<<($a&7)>>>26;c[r>>2]=wa+18;c[ma>>2]=Aa+((ua+((bb<<va>>>27)*60|0)|0)*60|0);c[r>>2]=(c[r>>2]|0)+2;break}}else if((sa|0)==438){break a}else if((sa|0)==434){c[k>>2]=0;c[l>>2]=0;c[m>>2]=0;c[n>>2]=0;va=c[u>>2]|0;bb=0;ua=c[r>>2]|0;while(1){if((ua|0)>=(va|0)){rb=bb;break}Aa=(c[s>>2]|0)+(ua>>>3)|0;wa=fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0;Aa=ua&7;if((wa&-512>>>(Aa>>>0)|0)==0){rb=bb;break}$a=ua+8|0;c[r>>2]=$a;a[j+bb|0]=wa<<Aa>>>24;Aa=bb+1|0;if((Aa|0)<255){bb=Aa;ua=$a}else{rb=Aa;break}}a[j+rb|0]=0;ua=xd(fa|0,2301576,(ta=i,i=i+24|0,c[ta>>2]=k,c[ta+8>>2]=l,c[ta+16>>2]=o,ta)|0)|0;i=ta;if((ua|0)<2){bb=xd(fa|0,2300024,(ta=i,i=i+24|0,c[ta>>2]=k,c[ta+8>>2]=l,c[ta+16>>2]=o,ta)|0)|0;i=ta;if((bb|0)>1){sb=bb;x=174}}else{sb=ua;x=174}do{if((x|0)==174){x=0;c[ga>>2]=c[k>>2];c[ha>>2]=c[l>>2];if((sb|0)!=3){c[ia>>2]=0;break}ua=(a[o]|0)==112;c[ia>>2]=ua&1;if(!ua){break}if((c[ja>>2]|0)!=0){break}yDb(c[y>>2]|0,32,2298560,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[ja>>2]=1}}while(0);ua=xd(fa|0,2297200,(ta=i,i=i+8|0,c[ta>>2]=l,ta)|0)|0;i=ta;do{if((ua|0)==1){x=185}else{bb=xd(fa|0,2295928,(ta=i,i=i+32|0,c[ta>>2]=k,c[ta+8>>2]=m,c[ta+16>>2]=n,c[ta+24>>2]=l,ta)|0)|0;i=ta;if((bb|0)==4){x=185;break}bb=xd(fa|0,2294632,(ta=i,i=i+24|0,c[ta>>2]=k,c[ta+8>>2]=m,c[ta+16>>2]=n,ta)|0)|0;i=ta;if((bb|0)>0){c[l>>2]=(c[m>>2]<<8)+(c[k>>2]<<16)+(c[n>>2]|0);if((bb|0)==3){x=185;break}}if((QGb(fa,2293408)|0)!=0){break}c[ka>>2]=4600}}while(0);if((x|0)==185){x=0;c[ka>>2]=c[l>>2]}ua=xd(fa|0,2291968,(ta=i,i=i+8|0,c[ta>>2]=l,ta)|0)|0;i=ta;if((ua|0)!=1){break}c[la>>2]=c[l>>2];break}else{break}}}while(0);ua=c[r>>2]|0;bb=-ua&7;if((bb|0)==0){tb=255;ub=ua;break}va=bb+ua|0;c[r>>2]=va;tb=255;ub=va}else{tb=sa;ub=pa}}while(0);pa=c[u>>2]|0;if((ub|0)<(pa|0)){na=tb;oa=ub}else{vb=pa;break b}}if((x|0)==73){yDb(Ka,16,2281272,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[(c[y>>2]|0)+104>>2]=0;wb=-1;i=h;return wb|0}else if((x|0)==108){yDb(c[y>>2]|0,16,2268552,(ta=i,i=i+8|0,c[ta>>2]=Xa,ta)|0);i=ta;c[N>>2]=0;wb=-1;i=h;return wb|0}else if((x|0)==133){yDb(c[y>>2]|0,16,2264928,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;wb=-1;i=h;return wb|0}}else{vb=t}}while(0);do{if((vb|0)==8){if((c[f+14748>>2]|0)>-1){break}if(!((c[f+14756>>2]|0)>-1)){x=11}}else{x=11}}while(0);do{if((x|0)==11){if((c[v>>2]|0)==877677905){break}else{wb=-1}i=h;return wb|0}}while(0);yDb(c[f+4>>2]|0,40,2175640,(ta=i,i=i+8|0,c[ta>>2]=vb,ta)|0);i=ta;wb=100;i=h;return wb|0}}while(0);vb=f+60|0;v=f+13944|0;if((c[vb>>2]&524288|0)==0){xb=(c[v>>2]|0)==0|0}else{c[v>>2]=1;xb=0}v=f+13944|0;Xa=f+4|0;Ka=c[Xa>>2]|0;c[Ka+176>>2]=xb;xb=c[r>>2]|0;ub=g|0;tb=(c[ub>>2]|0)+(xb>>>3)|0;l=(fe(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(xb&7)>>>30;c[r>>2]=xb+2;xb=l+1|0;l=f+9992|0;c[l>>2]=xb;do{if((xb|0)==3){if((c[v>>2]|0)==0){break}if((c[f+13952>>2]|0)!=0){break}if((c[vb>>2]&524288|0)!=0){break}yDb(Ka,16,1882784,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[v>>2]=0}}while(0);Ka=f+13936|0;if((c[Ka>>2]|0)==0){yb=0}else{yb=(c[l>>2]|0)!=3}c[f+13940>>2]=yb&1;c[f+14348>>2]=yb?424:872;yb=c[ub>>2]|0;vb=0;xb=c[r>>2]|0;while(1){tb=d[yb+(xb>>>3)|0]|0;zb=xb+1|0;c[r>>2]=zb;if((tb&128>>>((xb&7)>>>0)|0)==0){break}else{vb=vb+1|0;xb=zb}}tb=d[yb+(zb>>>3)|0]|0;c[r>>2]=xb+2;if((tb&128>>>((zb&7)>>>0)|0)==0){yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=1881528,ta)|0);i=ta}zb=f+14672|0;tb=c[zb>>2]|0;if((tb|0)==0){x=211}else{xb=c[r>>2]|0;yb=(c[ub>>2]|0)+(xb>>>3)|0;if(((fe(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(xb&7)&1<<31-tb|0)==0){x=211}}do{if((x|0)==211){yDb(c[Xa>>2]|0,16,1880200,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[zb>>2]=1;tb=f+14680|0;xb=c[l>>2]|0;h:do{if((xb|0)==2){yb=1;while(1){n=c[r>>2]|0;k=(c[ub>>2]|0)+(n>>>3)|0;if(((fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(n&7)>>>((26-yb|0)>>>0)&55|0)==48){Ab=yb;break h}n=yb+1|0;c[zb>>2]=n;if((n|0)<16){yb=n}else{Ab=n;break}}}else if((xb|0)==4){yb=1;while(1){y=(c[tb>>2]|0)==2;N=c[r>>2]|0;n=(c[ub>>2]|0)+(N>>>3)|0;k=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(N&7);if(y){if((k>>>((26-yb|0)>>>0)&55|0)==48){Ab=yb;break h}}else{if((k>>>((27-yb|0)>>>0)&31|0)==24){Ab=yb;break h}}k=yb+1|0;c[zb>>2]=k;if((k|0)<16){yb=k}else{Ab=k;break}}}else{yb=1;while(1){k=c[r>>2]|0;y=(c[ub>>2]|0)+(k>>>3)|0;if(((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(k&7)>>>((27-yb|0)>>>0)&31|0)==24){Ab=yb;break h}k=yb+1|0;c[zb>>2]=k;if((k|0)<16){yb=k}else{Ab=k;break}}}}while(0);yDb(c[Xa>>2]|0,16,2355840,(ta=i,i=i+8|0,c[ta>>2]=Ab,ta)|0);i=ta;tb=(c[Xa>>2]|0)+108|0;xb=c[tb>>2]|0;if((xb|0)==0){break}yb=1<<c[zb>>2];if((xb<<2|0)>=(yb|0)){break}c[tb>>2]=yb}}while(0);Ab=c[zb>>2]|0;yb=c[r>>2]|0;tb=(c[ub>>2]|0)+(yb>>>3)|0;xb=(fe(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(yb&7)>>>((32-Ab|0)>>>0);c[r>>2]=yb+Ab;do{if((c[l>>2]|0)==3){Ab=(ba(c[(c[Xa>>2]|0)+108>>2]|0,(c[f+13848>>2]|0)+vb|0)|0)+xb|0;yb=Ab;tb=(Ab|0)<0|0?-1:0;Ab=f+13856|0;c[Ab>>2]=yb;c[Ab+4>>2]=tb;k=f+13872|0;y=b[k>>1]|0;N=f+13864|0;n=ZGb(yb,tb,c[N>>2]|0,c[N+4>>2]|0)|0;tb=YGb(n,F,y&65535,0)|0;n=f+13874|0;b[n>>1]=tb;yb=tb&65535;if((y&65535)>>>0<=yb>>>0|(yb|0)==0|y<<16>>16==0){wb=100;i=h;return wb|0}UMa(q);y=f+14724|0;yb=c[y>>2]|0;do{if((yb|0)==0){tb=b[n>>1]|0;m=tb&65535;c[y>>2]=m;if(!(tb<<16>>16==0)){Bb=m;break}c[y>>2]=1;Bb=1}else{Bb=yb}}while(0);yb=c[N>>2]|0;y=c[N+4>>2]|0;n=0;m=(y|0)>(n|0)|(y|0)==(n|0)&yb>>>0>0>>>0;n=Bb>>1;tb=n;o=(n|0)<0|0?-1:0;n=ZGb(0,0,tb,o)|0;sb=F;rb=YGb(m?tb:n,m?o:sb,yb,y)|0;m=Bb;j=(Bb|0)<0|0?-1:0;qb=eHb(rb,F,m,j)|0;rb=F;ob=ZGb(yb,y,e[k>>1]|0,0)|0;y=F;yb=0;pb=(y|0)>(yb|0)|(y|0)==(yb|0)&ob>>>0>0>>>0;yb=YGb(pb?tb:n,pb?o:sb,ob,y)|0;y=eHb(yb,F,m,j)|0;yb=F;ob=ZGb(qb,rb,y,yb)|0;rb=ob<<1|0>>>31;ob=f+13876|0;b[ob>>1]=rb;qb=c[Ab>>2]|0;pb=c[Ab+4>>2]|0;nb=0;mb=(pb|0)>(nb|0)|(pb|0)==(nb|0)&qb>>>0>0>>>0;nb=YGb(mb?tb:n,mb?o:sb,qb,pb)|0;sb=eHb(nb,F,m,j)|0;j=ZGb(sb,F,y,yb)|0;yb=j<<1|0>>>31;j=f+13878|0;b[j>>1]=yb;y=yb&65534;if(!((rb&65534)>>>0<=y>>>0|y>>>0<2>>>0)){Cb=pb;Db=qb;break}b[j>>1]=2;b[ob>>1]=4;if((c[f+14152>>2]|0)==0){wb=100}else{Cb=pb;Db=qb;break}i=h;return wb|0}else{qb=f+13852|0;pb=c[qb>>2]|0;c[f+13848>>2]=pb;ob=pb+vb|0;c[qb>>2]=ob;pb=(c[Xa>>2]|0)+108|0;j=(ba(c[pb>>2]|0,ob)|0)+xb|0;y=j;rb=(j|0)<0|0?-1:0;j=f+13856|0;c[j>>2]=y;c[j+4>>2]=rb;yb=f+13864|0;sb=c[yb>>2]|0;m=c[yb+4>>2]|0;if((c[f+84>>2]&8|0)!=0&((rb|0)<(m|0)|(rb|0)==(m|0)&y>>>0<sb>>>0)){c[qb>>2]=ob+1;ob=c[pb>>2]|0;pb=YGb(ob,(ob|0)<0|0?-1:0,y,rb)|0;ob=F;c[j>>2]=pb;c[j+4>>2]=ob;Eb=ob;Fb=pb}else{Eb=rb;Fb=y}y=ZGb(Fb,Eb,sb,m)|0;b[f+13872>>1]=y;c[yb>>2]=Fb;c[yb+4>>2]=Eb;Cb=Eb;Db=Fb}}while(0);Fb=c[Xa>>2]|0;Eb=c[Fb+104>>2]|0;if((Eb|0)==0){Gb=-2147483648;Hb=0}else{vb=0;Bb=(Cb|0)>(vb|0)|(Cb|0)==(vb|0)&Db>>>0>0>>>0;vb=Eb>>1;q=vb;yb=(vb|0)<0|0?-1:0;vb=ZGb(0,0,q,yb)|0;y=YGb(Bb?q:vb,Bb?yb:F,Db,Cb)|0;Cb=eHb(y,F,Eb,(Eb|0)<0|0?-1:0)|0;Gb=F;Hb=Cb}if((c[Fb+688>>2]&512|0)!=0){yDb(Fb,48,2354584,(ta=i,i=i+16|0,c[ta>>2]=Hb,c[ta+8>>2]=Gb,ta)|0);i=ta}Gb=c[r>>2]|0;Hb=c[ub>>2]|0;Fb=d[Hb+(Gb>>>3)|0]|0;Cb=Gb+1|0;c[r>>2]=Cb;if((Fb&128>>>((Gb&7)>>>0)|0)==0){yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=2348160,ta)|0);i=ta;Ib=c[r>>2]|0;Jb=c[ub>>2]|0}else{Ib=Cb;Jb=Hb}Hb=d[Jb+(Ib>>>3)|0]|0;Cb=Ib+1|0;c[r>>2]=Cb;if((Hb&128>>>((Ib&7)>>>0)|0)==0){Ib=c[Xa>>2]|0;if((c[Ib+688>>2]&1|0)==0){wb=100;i=h;return wb|0}yDb(Ib,16,2346256,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;wb=100;i=h;return wb|0}do{if((c[f+14728>>2]|0)!=0){Ib=(c[zb>>2]|0)+3|0;Hb=(Ib|0)>15?15:Ib;Ib=Hb+Cb|0;c[r>>2]=Ib;Gb=Ib+1+((128>>>((Ib&7)>>>0)&d[Jb+(Ib>>>3)|0]|0)==0?0:Hb)|0;c[r>>2]=Gb;Hb=d[Jb+(Gb>>>3)|0]|0;c[r>>2]=Gb+1;if((128>>>((Gb&7)>>>0)&Hb|0)!=0){break}yDb(0,32,2238056,(ta=i,i=i+8|0,c[ta>>2]=2238824,ta)|0);i=ta}}while(0);Jb=f+14676|0;Cb=c[Jb>>2]|0;do{if((Cb|0)==2){x=249}else{zb=c[l>>2]|0;if((zb|0)==4){if((c[f+14680>>2]|0)!=2){x=249;break}}else if((zb|0)!=2){x=249;break}zb=c[r>>2]|0;Hb=d[(c[ub>>2]|0)+(zb>>>3)|0]<<(zb&7)>>>7;c[r>>2]=zb+1;c[f+12472>>2]=Hb&1;Kb=c[Jb>>2]|0}}while(0);if((x|0)==249){c[f+12472>>2]=0;Kb=Cb}do{if((Kb|0)==0){Lb=c[r>>2]|0;x=258}else{do{if((c[f+14680>>2]|0)==1){if((c[l>>2]|0)!=1){x=255;break}Mb=c[r>>2]|0}else{x=255}}while(0);if((x|0)==255){Ab=(c[r>>2]|0)+55|0;c[r>>2]=Ab;Mb=Ab}Ab=Mb+1|0;c[r>>2]=Ab;k=((d[(c[ub>>2]|0)+(Ab>>>3)|0]&128>>>((Ab&7)>>>0)|0)==0?2:10)+Mb|0;c[r>>2]=k;if((c[Jb>>2]|0)!=2){Lb=k;x=258;break}Nb=c[f+14200>>2]|0;x=266}}while(0);do{if((x|0)==258){Mb=(c[f+14768>>2]|0)+Lb|0;c[r>>2]=Mb;do{if((c[l>>2]|0)==1){Ob=Mb}else{Kb=(c[f+14772>>2]|0)+Mb|0;c[r>>2]=Kb;if((c[l>>2]|0)!=3){Ob=Kb;break}k=(c[f+14776>>2]|0)+Kb|0;c[r>>2]=k;Ob=k}}while(0);if(((c[g+12>>2]|0)-Ob|0)<3){yDb(c[Xa>>2]|0,16,2344816,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;wb=-1;i=h;return wb|0}Mb=c[ub>>2]|0;k=Mb+(Ob>>>3)|0;Kb=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Ob&7)>>>29;c[r>>2]=Ob+3;c[f+14744>>2]=d[1177256+Kb|0]|0;if((c[f+14152>>2]|0)==0){Kb=c[r>>2]|0;k=d[Mb+(Kb>>>3)|0]<<(Kb&7)>>>7;c[r>>2]=Kb+1;c[f+14184>>2]=k&1;k=c[r>>2]|0;Kb=d[Mb+(k>>>3)|0]<<(k&7)>>>7;c[r>>2]=k+1;k=Kb&1;c[f+14200>>2]=k;Nb=k;x=266;break}else{k=f+14200|0;c[k>>2]=0;Pb=k;Qb=f+11184|0;Rb=f+232|0;x=268;break}}}while(0);do{if((x|0)==266){Ob=f+14200|0;Lb=f+11184|0;k=f+232|0;if((Nb|0)==0){Pb=Ob;Qb=Lb;Rb=k;x=268;break}x2(Lb,k,1264880);x2(Lb,f+364|0,1264880);x2(Lb,f+496|0,1264880);x2(Lb,f+628|0,1264880);Sb=Ob}}while(0);if((x|0)==268){x2(Qb,Rb,1075976);x2(Qb,f+364|0,1075976);x2(Qb,f+496|0,1264944);x2(Qb,f+628|0,1264880);Sb=Pb}do{if((c[l>>2]|0)==4){Pb=f+14680|0;if(!(((c[Pb>>2]|0)-1|0)>>>0<2>>>0)){break}if((aNa(f,g)|0)<0){wb=-1094995529;i=h;return wb|0}if((c[f+14684>>2]|0)!=0){yDb(c[Xa>>2]|0,16,2343336,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}if((c[Pb>>2]|0)!=1){break}yDb(c[Xa>>2]|0,16,2341912,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}}while(0);do{if((c[Jb>>2]|0)!=2){Pb=c[f+13920>>2]|0;Qb=c[r>>2]|0;Rb=c[ub>>2]|0;Nb=Rb+(Qb>>>3)|0;Ob=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Qb&7)>>>((32-Pb|0)>>>0);c[r>>2]=Qb+Pb;Pb=f+9960|0;c[Pb>>2]=Ob;c[f+9964>>2]=Ob;if((Ob|0)==0){yDb(c[Xa>>2]|0,16,2340832,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;wb=-1;i=h;return wb|0}do{if((c[l>>2]|0)==1){c[f+11556>>2]=1;x=286}else{Ob=c[r>>2]|0;Qb=Rb+(Ob>>>3)|0;Nb=(fe(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(Ob&7)>>>29;c[r>>2]=Ob+3;Ob=f+11556|0;c[Ob>>2]=Nb;if((Nb|0)==0){yDb(c[Xa>>2]|0,16,2339488,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[Ob>>2]=1;wb=-1;i=h;return wb|0}if((c[l>>2]|0)!=3){x=286;break}Ob=c[r>>2]|0;Nb=Rb+(Ob>>>3)|0;Qb=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Ob&7)>>>29;c[r>>2]=Ob+3;Ob=f+11560|0;c[Ob>>2]=Qb;if((Qb|0)!=0){Tb=Qb;break}yDb(c[Xa>>2]|0,16,2338176,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[Ob>>2]=1;wb=-1;i=h;return wb|0}}while(0);if((x|0)==286){c[f+11560>>2]=1;Tb=1}Rb=c[Xa>>2]|0;if((c[Rb+688>>2]&1|0)!=0){Ob=Rb;Rb=c[Pb>>2]|0;Qb=c[f+11556>>2]|0;Nb=c[l>>2]|0;do{if((Nb|0)==1){Ub=2334160}else{if((Nb|0)==2){Ub=2327912;break}Ub=(Nb|0)==3?2324816:2322960}}while(0);Nb=c[g+12>>2]|0;Pb=c[f+14152>>2]|0;Lb=c[Sb>>2]|0;k=c[f+14184>>2]|0;Kb=(c[f+13924>>2]|0)!=0?2320888:2319168;Mb=c[Ka>>2]|0;Ab=c[f+14720>>2]|0;N=c[f+14688>>2]|0;Cb=c[f+13932>>2]|0;Hb=1-(c[f+12472>>2]|0)|0;zb=c[f+13948>>2]|0;Gb=(c[f+13952>>2]|0)!=0?2317704:2315288;Ib=c[f+14744>>2]|0;Fb=c[f+14768>>2]|0;Eb=c[f+14772>>2]|0;y=c[f+14776>>2]|0;Db=f+13856|0;yb=c[Db>>2]|0;Bb=c[Db+4>>2]|0;yDb(Ob,48,2336720,(ta=i,i=i+184|0,c[ta>>2]=Rb,c[ta+8>>2]=Qb,c[ta+16>>2]=Tb,c[ta+24>>2]=Ub,c[ta+32>>2]=Nb,c[ta+40>>2]=Pb,c[ta+48>>2]=Lb,c[ta+56>>2]=k,c[ta+64>>2]=Kb,c[ta+72>>2]=Mb,c[ta+80>>2]=Ab,c[ta+88>>2]=N,c[ta+96>>2]=Cb,c[ta+104>>2]=Hb,c[ta+112>>2]=zb,c[ta+120>>2]=Gb,c[ta+128>>2]=Ib,c[ta+136>>2]=Fb,c[ta+144>>2]=Eb,c[ta+152>>2]=y,c[ta+160>>2]=yb,c[ta+168>>2]=Bb,c[ta+176>>2]=xb,ta)|0);i=ta}if((c[f+14736>>2]|0)==0){if((c[Jb>>2]|0)==0){break}if((c[l>>2]|0)==1){break}c[r>>2]=(c[r>>2]|0)+1;break}do{if((c[f+14732>>2]|0)!=0){Bb=c[r>>2]|0;yb=d[(c[ub>>2]|0)+(Bb>>>3)|0]|0;c[r>>2]=Bb+1;if((yb&128>>>((Bb&7)>>>0)|0)==0){break}yDb(c[Xa>>2]|0,16,2314104,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}}while(0);c[r>>2]=(c[r>>2]|0)+2}}while(0);do{if((c[f+13948>>2]|0)==0){if((c[f+13952>>2]|0)!=0){break}if(!((c[f+14748>>2]|0)==-1)){break}if((c[f+108>>2]|0)!=0){break}yDb(c[Xa>>2]|0,24,2311824,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[v>>2]=1}}while(0);v=f+108|0;c[v>>2]=(c[v>>2]|0)+1;c[f+9888>>2]=1175896;c[f+9892>>2]=1177264;if((c[f+84>>2]&1024|0)==0){wb=0;i=h;return wb|0}c[f+136>>2]=c[f+8>>2];c[f+140>>2]=c[f+12>>2];wb=0;i=h;return wb|0}function eNa(){var b=0;if(a[1175832]|0){return}OOa(1175928,6843728);OOa(1144616,6844118);OOa(1144424,6844508);c[293994]=6496168;c[293996]=554;b=c[293984]|0;N_(1175972,9,(c[293982]|0)+1|0,b+2|0,4,2,b,4,2,0,0,0,4)|0;if((c[293998]|0)==0){b=0;do{c[1175992+(b<<2)>>2]=6772816+(b*2216|0);b=b+1|0;}while((b|0)<32);POa(1175928)}c[286166]=6491880;c[286168]=1072;b=c[286156]|0;N_(1144660,9,(c[286154]|0)+1|0,b+2|0,4,2,b,4,2,0,0,0,4)|0;if((c[286170]|0)==0){b=0;do{c[1144680+(b<<2)>>2]=6635600+(b*4288|0);b=b+1|0;}while((b|0)<32);POa(1144616)}c[286118]=6487592;c[286120]=1072;b=c[286108]|0;N_(1144468,9,(c[286106]|0)+1|0,b+2|0,4,2,b,4,2,0,0,0,4)|0;if((c[286122]|0)==0){b=0;do{c[1144488+(b<<2)>>2]=6498384+(b*4288|0);b=b+1|0;}while((b|0)<32);POa(1144424)}c[2187423]=6485544;c[2187425]=512;N_(8749688,9,10,1177297,2,1,1177296,2,1,0,0,0,4)|0;c[2187429]=6483496;c[2187431]=512;N_(8749712,9,10,1177329,2,1,1177328,2,1,0,0,0,4)|0;c[1071081]=6482984;c[1071083]=128;N_(4284320,6,15,1135906,4,2,1135904,4,2,0,0,0,4)|0;c[1244305]=6482920;c[1244307]=16;N_(4977216,4,4,1191065,2,1,1191064,2,1,0,0,0,4)|0;a[1175832]=1;return}function fNa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=c[b+60>>2]|0;if((c[f+14012>>2]|0)==0){g=0;return g|0}b=f+14016|0;h=b;if((c[f+14120>>2]|0)==(c[h>>2]|0)){i=0}else{i=c[f+14128>>2]>>3}j=e-i|0;if((j|0)<=7){g=0;return g|0}k=e-4|0;if((i|0)<(k|0)){l=i}else{g=0;return g|0}a:while(1){e=l+1|0;do{if((a[d+l|0]|0)==0){if((a[d+e|0]|0)!=0){break}if((a[d+(l+2)|0]|0)!=1){break}if((a[d+(l+3)|0]|0)==-74){break a}}}while(0);if((e|0)<(k|0)){l=e}else{g=0;m=14;break}}if((m|0)==14){return g|0}if(!((a[d+(l+4)|0]&64)==0)){g=0;return g|0}O$a(b,f+14024|0,j);b=c[h>>2]|0;if((b|0)==0){g=-12;return g|0}UGb(b|0,d+i|0,j)|0;c[f+14020>>2]=j;g=0;return g|0}function gNa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;TGb(b+14748|0,-1|0,16)|0;d=Fca(a)|0;if((d|0)<0){e=d;return e|0}eNa();c[b+32>>2]=1;c[b+13944>>2]=0;c[b+14348>>2]=872;c[b+14672>>2]=4;c[a+400>>2]=1;c[(c[a+64>>2]|0)+4>>2]=1;e=0;return e|0}function hNa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=e;l=e+12476|0;m=c[l>>2]|0;n=e+12480|0;o=c[n>>2]|0;p=e+124|0;q=c[p>>2]|0;r=(ba(q,o)|0)+m|0;s=e+9992|0;t=c[s>>2]|0;a:do{if((t|0)==2|(t|0)==4){u=e+14128|0;v=e+14120|0;w=c[v>>2]|0;x=c[u>>2]|0;while(1){y=d[w+(x>>>3)|0]|0;z=x+1|0;c[u>>2]=z;if((y&128>>>((x&7)>>>0)|0)!=0){A=5;break}y=c[1850737]|0;B=w+(z>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7)>>>25;B=b[y+(C<<2)>>1]|0;D=b[y+(C<<2)+2>>1]|0;C=D<<16>>16;if(D<<16>>16<0){D=x+8|0;E=w+(D>>>3)|0;F=((fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>((C+32|0)>>>0))+B|0;G=b[y+(F<<2)+2>>1]|0;H=D;I=b[y+(F<<2)>>1]|0}else{G=C;H=z;I=B}B=G+H|0;c[u>>2]=B;if((I|0)<0){A=12;break}if((I|0)==20){x=B}else{A=14;break}}if((A|0)==5){c[e+12488>>2]=0;TGb(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;do{if((t|0)==4){if((c[e+14680>>2]|0)!=2){break}c[(c[e+9160>>2]|0)+(r<<2)>>2]=15368;c[e+13916>>2]=1;c[e+11744>>2]=iNa(k,0)|0;c[e+11748>>2]=iNa(k,1)|0;c[e+9924>>2]=0;break a}}while(0);c[(c[e+9160>>2]|0)+(r<<2)>>2]=14344;c[e+13916>>2]=0;c[e+11744>>2]=0;c[e+11748>>2]=0;c[e+9924>>2]=1;break}else if((A|0)==12){yDb(c[e+4>>2]|0,16,1970912,(J=i,i=i+16|0,c[J>>2]=m,c[J+8>>2]=o,J)|0);i=J;K=-1;i=g;return K|0}else if((A|0)==14){me[c[e+10096>>2]&511](c[e+14340>>2]|0);x=I&8;w=I&4;c[e+12488>>2]=w>>>2;if((w|0)!=0){L=I;M=x;N=c[u>>2]|0;O=c[v>>2]|0;A=84;break}do{if((c[s>>2]|0)==4){if((c[e+14680>>2]|0)!=2){A=20;break}if((I&16|0)!=0){A=20;break}w=c[u>>2]|0;B=c[v>>2]|0;z=d[B+(w>>>3)|0]<<(w&7)>>>7;C=w+1|0;c[u>>2]=C;c[e+13916>>2]=z&1;P=C;Q=B}else{A=20}}while(0);if((A|0)==20){c[e+13916>>2]=0;P=c[u>>2]|0;Q=c[v>>2]|0}B=c[1888269]|0;C=Q+(P>>>3)|0;z=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(P&7)>>>26;C=b[B+(z<<2)>>1]|0;w=(b[B+(z<<2)+2>>1]|0)+P|0;c[u>>2]=w;z=C<<2|I&3;C=z^60;if((x|0)!=0){B=c[e+9960>>2]|0;F=Q+(w>>>3)|0;y=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(w&7)>>>30;c[u>>2]=w+2;cPa(e,(a[645448+y|0]|0)+B|0)}B=(c[e+14152>>2]|0)==0;do{if(B){if((z|0)==60){if((c[e+84>>2]&4|0)==0){break}}y=c[u>>2]|0;w=d[(c[v>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[u>>2]=y+1;c[e+14236>>2]=w&1}}while(0);c[e+11736>>2]=1;if((I&16|0)!=0){c[(c[e+9160>>2]|0)+(r<<2)>>2]=12352;c[e+11740>>2]=1;z=e+11556|0;x=Bca(e,0,0,h,j)|0;w=kIa(e,c[h>>2]|0,c[z>>2]|0)|0;if((w|0)>65534){K=-1;i=g;return K|0}y=kIa(e,c[j>>2]|0,c[z>>2]|0)|0;if((y|0)>65534){K=-1;i=g;return K|0}c[e+11744>>2]=w;c[e+11748>>2]=y;b[x>>1]=w;b[x+2>>1]=y;y=Bca(e,1,0,h,j)|0;x=kIa(e,c[h>>2]|0,c[z>>2]|0)|0;if((x|0)>65534){K=-1;i=g;return K|0}w=kIa(e,c[j>>2]|0,c[z>>2]|0)|0;if((w|0)>65534){K=-1;i=g;return K|0}c[e+11752>>2]=x;c[e+11756>>2]=w;b[y>>1]=x;b[y+2>>1]=w;w=Bca(e,2,0,h,j)|0;y=kIa(e,c[h>>2]|0,c[z>>2]|0)|0;if((y|0)>65534){K=-1;i=g;return K|0}x=kIa(e,c[j>>2]|0,c[z>>2]|0)|0;if((x|0)>65534){K=-1;i=g;return K|0}c[e+11760>>2]=y;c[e+11764>>2]=x;b[w>>1]=y;b[w+2>>1]=x;x=Bca(e,3,0,h,j)|0;w=kIa(e,c[h>>2]|0,c[z>>2]|0)|0;if((w|0)>65534){K=-1;i=g;return K|0}y=kIa(e,c[j>>2]|0,c[z>>2]|0)|0;if((y|0)>65534){K=-1;i=g;return K|0}else{c[e+11768>>2]=w;c[e+11772>>2]=y;b[x>>1]=w;b[x+2>>1]=y;R=C;A=77;break}}if((c[e+13916>>2]|0)!=0){c[(c[e+9160>>2]|0)+(r<<2)>>2]=13320;c[e+11740>>2]=0;y=iNa(k,0)|0;x=iNa(k,1)|0;c[e+11744>>2]=y;c[e+11748>>2]=x;R=C;A=77;break}do{if(B){x=c[u>>2]|0;y=c[v>>2]|0;w=d[y+(x>>>3)|0]|0;c[u>>2]=x+1;if((w&128>>>((x&7)>>>0)|0)==0){break}c[(c[e+9160>>2]|0)+(r<<2)>>2]=12432;c[e+11740>>2]=3;x=c[u>>2]|0;w=d[y+(x>>>3)|0]<<(x&7)>>>7;z=x+1|0;c[u>>2]=z;c[e+11808>>2]=w&1;w=d[y+(z>>>3)|0]<<(z&7)>>>7;c[u>>2]=x+2;c[e+11812>>2]=w&1;Bca(e,0,0,h,j)|0;w=e+11556|0;x=kIa(e,c[h>>2]|0,c[w>>2]|0)|0;if((x|0)>65534){K=-1;i=g;return K|0}z=kIa(e,(c[j>>2]|0)/2|0,c[w>>2]|0)|0;if((z|0)>65534){K=-1;i=g;return K|0}c[e+11744>>2]=x;c[e+11748>>2]=z;z=kIa(e,c[h>>2]|0,c[w>>2]|0)|0;if((z|0)>65534){K=-1;i=g;return K|0}x=kIa(e,(c[j>>2]|0)/2|0,c[w>>2]|0)|0;if((x|0)>65534){K=-1;i=g;return K|0}else{c[e+11752>>2]=z;c[e+11756>>2]=x;R=C;A=77;break a}}}while(0);c[(c[e+9160>>2]|0)+(r<<2)>>2]=12296;c[e+11740>>2]=0;Bca(e,0,0,h,j)|0;u=e+11556|0;v=kIa(e,c[h>>2]|0,c[u>>2]|0)|0;if((v|0)>65534){K=-1;i=g;return K|0}B=kIa(e,c[j>>2]|0,c[u>>2]|0)|0;if((B|0)>65534){K=-1;i=g;return K|0}else{c[e+11744>>2]=v;c[e+11748>>2]=B;R=C;A=77;break}}}else if((t|0)==3){c[e+12488>>2]=0;c[e+13916>>2]=0;if((m|0)==0){TGb(e+11824|0,0,32)|0;Z0a((c[e+9852>>2]|0)+1496|0,o,0);S=c[n>>2]|0;T=c[p>>2]|0;U=c[l>>2]|0}else{S=o;T=q;U=m}B=(ba(T,S)|0)+U|0;v=a[(c[e+4720>>2]|0)+B|0]|0;c[e+9924>>2]=v&255;if(!(v<<24>>24==0)){TGb(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11780>>2]=0;c[e+11776>>2]=0;c[e+11748>>2]=0;c[e+11744>>2]=0;c[(c[e+9160>>2]|0)+(r<<2)>>2]=14344;break}v=e+14128|0;B=c[v>>2]|0;u=e+14120|0;x=c[u>>2]|0;z=d[x+(B>>>3)|0]|0;w=B+1|0;c[v>>2]=w;do{if((z&128>>>((B&7)>>>0)|0)==0){y=a[x+(w>>>3)|0]|0;F=B+2|0;c[v>>2]=F;D=c[1244305]|0;E=x+(F>>>3)|0;V=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(F&7)>>>28;E=b[D+(V<<2)>>1]|0;c[v>>2]=(b[D+(V<<2)+2>>1]|0)+F;if(E<<16>>16<0){yDb(c[e+4>>2]|0,16,1962280,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1;i=g;return K|0}F=c[679576+(E<<16>>16<<2)>>2]|0;do{if((y&255&128>>>((w&7)>>>0)|0)==0){me[c[e+10096>>2]&511](c[e+14340>>2]|0);V=c[v>>2]|0;D=c[u>>2]|0;W=D+(V>>>3)|0;X=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(V&7)>>>26;W=V+6|0;c[v>>2]=W;Y=E<<16>>16==0;Z=(X|0)==0;if(Y|Z){_=X;$=Y;aa=Z;break}Z=d[D+(W>>>3)|0]|0;Y=V+7|0;c[v>>2]=Y;if((Z&128>>>((W&7)>>>0)|0)==0){_=X;$=0;aa=0;break}W=c[e+9960>>2]|0;Z=d[D+(Y>>>3)|0]<<(Y&7)>>>7;c[v>>2]=V+8;cPa(e,W-2+(Z<<2&4)|0);_=X;$=0;aa=0}else{_=0;$=E<<16>>16==0;aa=1}}while(0);do{if((c[e+14152>>2]|0)==0){if(!aa){y=c[v>>2]|0;X=d[(c[u>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[v>>2]=y+1;c[e+14236>>2]=X&1}if($){ca=F;break}X=c[v>>2]|0;y=c[u>>2]|0;Z=d[y+(X>>>3)|0]|0;W=X+1|0;c[v>>2]=W;if((Z&128>>>((X&7)>>>0)|0)==0){ca=F;break}Z=F&-153|144;if(E<<16>>16==2){da=W}else{V=d[y+(W>>>3)|0]<<(W&7)>>>7;W=X+2|0;c[v>>2]=W;c[e+11808>>2]=V&1;V=d[y+(W>>>3)|0]<<(W&7)>>>7;W=X+3|0;c[v>>2]=W;c[e+11812>>2]=V&1;if(E<<16>>16==3){ca=Z;break}else{da=W}}W=d[y+(da>>>3)|0]<<(da&7)>>>7;V=da+1|0;c[v>>2]=V;c[e+11816>>2]=W&1;W=d[y+(V>>>3)|0]<<(V&7)>>>7;c[v>>2]=da+2;c[e+11820>>2]=W&1;ca=Z}else{ca=F}}while(0);F=e+11736|0;c[F>>2]=0;do{if((ca&384|0)==0){c[e+11740>>2]=0;if((ca&12288|0)!=0){c[F>>2]=1;E=e+11824|0;Z=e+11556|0;W=kIa(e,c[E>>2]|0,c[Z>>2]|0)|0;V=e+11828|0;y=kIa(e,c[V>>2]|0,c[Z>>2]|0)|0;c[e+11744>>2]=W;c[E>>2]=W;c[e+11832>>2]=W;c[e+11748>>2]=y;c[V>>2]=y;c[e+11836>>2]=y}if((ca&49152|0)==0){break}c[F>>2]=c[F>>2]|2;y=e+11840|0;V=e+11560|0;W=kIa(e,c[y>>2]|0,c[V>>2]|0)|0;E=e+11844|0;Z=kIa(e,c[E>>2]|0,c[V>>2]|0)|0;c[e+11776>>2]=W;c[y>>2]=W;c[e+11848>>2]=W;c[e+11780>>2]=Z;c[E>>2]=Z;c[e+11852>>2]=Z}else{if((ca&256|0)!=0){break}c[e+11740>>2]=3;if((ca&12288|0)!=0){c[F>>2]=1;Z=e+11556|0;E=e+11824|0;W=kIa(e,c[E>>2]|0,c[Z>>2]|0)|0;y=e+11828|0;V=kIa(e,(c[y>>2]|0)/2|0,c[Z>>2]|0)|0;c[e+11744>>2]=W;c[E>>2]=W;c[e+11748>>2]=V;c[y>>2]=V<<1;V=e+11832|0;y=kIa(e,c[V>>2]|0,c[Z>>2]|0)|0;W=e+11836|0;E=kIa(e,(c[W>>2]|0)/2|0,c[Z>>2]|0)|0;c[e+11752>>2]=y;c[V>>2]=y;c[e+11756>>2]=E;c[W>>2]=E<<1}if((ca&49152|0)==0){break}c[F>>2]=c[F>>2]|2;E=e+11560|0;W=e+11840|0;y=kIa(e,c[W>>2]|0,c[E>>2]|0)|0;V=e+11844|0;Z=kIa(e,(c[V>>2]|0)/2|0,c[E>>2]|0)|0;c[e+11776>>2]=y;c[W>>2]=y;c[e+11780>>2]=Z;c[V>>2]=Z<<1;Z=e+11848|0;V=kIa(e,c[Z>>2]|0,c[E>>2]|0)|0;y=e+11852|0;W=kIa(e,(c[y>>2]|0)/2|0,c[E>>2]|0)|0;c[e+11784>>2]=V;c[Z>>2]=V;c[e+11788>>2]=W;c[y>>2]=W<<1}}while(0);if((ca&256|0)==0){ea=ca;fa=_;break}if((ca&2048|0)!=0){ga=0;ha=0;ia=ca;ja=_;ka=F;A=75;break}W=kIa(e,0,1)|0;ga=W;ha=kIa(e,0,1)|0;ia=ca;ja=_;ka=F;A=75}else{ga=0;ha=0;ia=63744;ja=0;ka=e+11736|0;A=75}}while(0);if((A|0)==75){c[ka>>2]=7;ea=VMa(e,ga,ha)|0|ia;fa=ja}c[(c[e+9160>>2]|0)+(r<<2)>>2]=ea;R=fa;A=77}else{v=e+14128|0;u=c[1850731]|0;w=c[e+14120>>2]|0;x=c[v>>2]|0;while(1){B=w+(x>>>3)|0;z=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>26;B=b[u+(z<<2)>>1]|0;C=b[u+(z<<2)+2>>1]|0;z=C<<16>>16;if(C<<16>>16<0){C=x+6|0;W=w+(C>>>3)|0;y=((fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(C&7)>>>((z+32|0)>>>0))+B|0;la=b[u+(y<<2)+2>>1]|0;ma=C;na=b[u+(y<<2)>>1]|0}else{la=z;ma=x;na=B}oa=la+ma|0;c[v>>2]=oa;if((na|0)<0){break}if((na|0)==8){x=oa}else{A=83;break}}if((A|0)==83){c[e+12488>>2]=1;L=na;M=na&4;N=oa;O=w;A=84;break}yDb(c[e+4>>2]|0,16,1959616,(J=i,i=i+16|0,c[J>>2]=m,c[J+8>>2]=o,J)|0);i=J;K=-1;i=g;return K|0}}while(0);do{if((A|0)==77){if((jNa(k,f|0,0,R&32,0,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+128|0,1,R<<1&32,0,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+256|0,2,R<<2&32,0,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+384|0,3,R<<3&32,0,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+512|0,4,R<<4&32,0,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+640|0,5,R<<5&32,0,0)|0)<0){K=-1}else{break}i=g;return K|0}else if((A|0)==84){o=e+14128|0;m=e+14120|0;oa=d[O+(N>>>3)|0]<<(N&7)>>>7;c[o>>2]=N+1;na=oa&1;c[e+176>>2]=na;c[(c[e+9160>>2]|0)+(r<<2)>>2]=na<<9|1;na=c[1888269]|0;oa=c[o>>2]|0;ma=c[m>>2]|0;la=ma+(oa>>>3)|0;fa=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(oa&7)>>>26;la=b[na+(fa<<2)>>1]|0;ea=(b[na+(fa<<2)+2>>1]|0)+oa|0;c[o>>2]=ea;if(la<<16>>16<0){oa=c[n>>2]|0;yDb(c[e+4>>2]|0,16,1957416,(J=i,i=i+16|0,c[J>>2]=c[l>>2],c[J+8>>2]=oa,J)|0);i=J;K=-1;i=g;return K|0}oa=la<<16>>16;la=oa<<2;fa=la|L&3;na=c[e+9960>>2]|0;c[e+14740>>2]=(na|0)<(c[e+14744>>2]|0);if((M|0)!=0){ja=ma+(ea>>>3)|0;ma=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ea&7)>>>30;c[o>>2]=ea+2;cPa(e,(a[645448+ma|0]|0)+na|0)}if((c[e+14152>>2]|0)==0){na=c[o>>2]|0;ma=d[(c[m>>2]|0)+(na>>>3)|0]<<(na&7)>>>7;c[o>>2]=na+1;c[e+14236>>2]=ma&1}me[c[e+10096>>2]&511](c[e+14340>>2]|0);if((jNa(k,f|0,0,la&32,1,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+128|0,1,oa<<3&32,1,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+256|0,2,oa<<4&32,1,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+384|0,3,oa<<5&32,1,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+512|0,4,fa<<4&32,1,0)|0)<0){K=-1;i=g;return K|0}if((jNa(k,f+640|0,5,fa<<5&32,1,0)|0)<0){K=-1}else{break}i=g;return K|0}}while(0);if((c[e+48>>2]|0)!=13){K=0;i=g;return K|0}f=kNa(k)|0;if((f|0)==0){K=0;i=g;return K|0}k=c[l>>2]|0;l=c[n>>2]|0;n=c[e+116>>2]|0;M=k+1|0;L=M+(ba(n,l)|0)|0;do{if((L|0)>(f|0)){if((c[(c[e+4>>2]|0)+696>>2]&262144|0)==0){break}else{K=-1}i=g;return K|0}}while(0);if((L|0)>=(f|0)){K=-2;i=g;return K|0}do{if((c[s>>2]|0)==3){f=(M|0)==(n|0)?2:1;if((f+k|0)<(n|0)){pa=l}else{L=l+1|0;J=(c[e+120>>2]|0)-1|0;pa=(L|0)>(J|0)?J:L}Z0a((c[e+9852>>2]|0)+1496|0,pa,0);if((a[(c[e+4720>>2]|0)+(f+r)|0]|0)==0){break}else{K=0}i=g;return K|0}}while(0);K=-2;i=g;return K|0}function iNa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=1<<(c[a+11556>>2]|0)+4;e=c[a+13932>>2]|0;if((c[a+84>>2]&32|0)==0){f=d}else{f=d>>c[a+13924>>2]}a:do{if((c[a+13880>>2]|0)==1){do{if((c[a+14748>>2]|0)==500){if((c[a+14752>>2]|0)!=413){break}g=(c[a+13884+(b<<2)>>2]|0)/(1<<e-(c[a+13924>>2]|0)|0)|0;break a}}while(0);d=c[a+13884+(b<<2)>>2]<<c[a+13924>>2];g=d+(1<<e>>1)+(((d|0)<1)<<31>>31)>>e}else{d=c[a+14708>>2]|0;h=(b|0)==0;i=1<<e+1+d;j=(c[a+13900+(b<<3)>>2]|0)-(h?i:0)|0;k=(c[a+13900+(b<<3)+4>>2]|0)-(h?0:i)|0;i=ba(c[a+12476>>2]<<4,j)|0;h=c[a+12480>>2]<<4;l=i+(c[a+13884+(b<<2)>>2]|0)|0;i=0;m=0;do{n=l+(ba(m+h|0,k)|0)|0;o=n+j|0;p=o+j|0;q=p+j|0;r=q+j|0;s=r+j|0;t=s+j|0;u=t+j|0;v=u+j|0;w=v+j|0;x=w+j|0;y=x+j|0;z=y+j|0;A=z+j|0;B=A+j|0;i=(B+j>>d)+((B>>d)+((A>>d)+((z>>d)+((y>>d)+((x>>d)+((w>>d)+((v>>d)+((u>>d)+((t>>d)+((s>>d)+((r>>d)+((q>>d)+((p>>d)+((o>>d)+((n>>d)+i)))))))))))))))|0;m=m+1|0;}while((m|0)<16);m=e+8-(c[a+13924>>2]|0)|0;g=(((i|0)<1)<<31>>31)+i+(1<<m>>1)>>m}}while(0);a=-f|0;if((g|0)<(a|0)){return a|0}else{return((g|0)<(f|0)?g:f-1|0)|0}return 0}function jNa(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;l=i;i=i+8|0;m=l|0;n=e|0;o=(j|0)!=0;do{if(o){if((c[e+14740>>2]|0)==0){mNa(n,g,0,m)|0;p=-1}else{do{if((c[e+13940>>2]|0)==0){j=lNa(n,g,m)|0;if((j|0)<0){q=-1}else{r=j&65535;break}i=l;return q|0}else{j=b[(c[e+9876>>2]|0)+(c[e+12496+(g<<2)>>2]<<1)>>1]|0;if((g|0)<4){s=c[e+168>>2]|0;t=(s>>1)+j|0;gHb(t,(t|0)<0|0?-1:0,c[1199552+(s<<2)>>2]|0,0)|0;u=F&65535}else{s=c[e+172>>2]|0;t=(s>>1)+j|0;gHb(t,(t|0)<0|0?-1:0,c[1199552+(s<<2)>>2]|0,0)|0;u=F&65535}s=(ba(c[e+124>>2]|0,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;c[m>>2]=d[(c[e+9940>>2]|0)+s|0]<<g&32;r=u}}while(0);b[f>>1]=r;p=0}if((h|0)==0){v=p;break}s=(k|0)==0;t=s?1175928:1144424;j=s?c[293998]|0:c[286122]|0;if((c[e+176>>2]|0)==0){w=p;x=e+368|0;y=j;z=t;A=0;B=1;C=26;break}if((c[m>>2]|0)==0){w=p;x=e+632|0;y=j;z=t;A=0;B=1;C=26;break}else{w=p;x=e+500|0;y=j;z=t;A=0;B=1;C=26;break}}else{if((h|0)==0){c[e+180+(g<<2)>>2]=-1;q=0;i=l;return q|0}t=(k|0)!=0;j=t?1144616:1210184;s=e+368|0;if((c[e+14004>>2]|0)==0){D=c[e+9960>>2]|0;E=D<<1;G=D-1|1;if(t){w=-1;x=s;y=c[1144680+(D<<2)>>2]|0;z=j;A=G;B=E;C=26;break}else{w=-1;x=s;y=c[1210248+(D<<2)>>2]|0;z=j;A=G;B=E;C=26;break}}else{if(t){w=-1;x=s;y=c[286170]|0;z=j;A=0;B=1;C=26;break}else{w=-1;x=s;y=c[302562]|0;z=j;A=0;B=1;C=26;break}}}}while(0);do{if((C|0)==26){h=e+14128|0;p=(k|0)==0;r=-A|0;u=e+13740|0;j=c[e+14120>>2]|0;s=w;t=c[h>>2]|0;a:while(1){E=j+(t>>>3)|0;G=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(t&7);E=G>>>23;D=b[y+(E<<2)>>1]|0;H=a[y+(E<<2)+2|0]|0;I=H<<24>>24;if(H<<24>>24<0){H=G<<9;J=(H>>>((I+32|0)>>>0))+D|0;K=b[y+(J<<2)>>1]|0;L=J;M=a[y+(J<<2)+2|0]|0;N=H;O=t+9|0}else{K=D;L=E;M=I;N=G;O=t}G=N<<M;I=M+O|0;do{if((K|0)==0){if(!p){if((G|0)>-1){C=32;break a}E=I+8|0;D=j+(E>>>3)|0;H=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7);if((H|0)>-1){C=34;break a}if((H&1015808|0)!=524288){C=36;break a}E=H<<17>>31;D=I+26|0;J=s+1+(G>>>24&63)|0;P=((ba(H>>>20&2047,B)|0)+A^E)-E&65535;if((G&1073741824|0)==0){Q=P;R=J;S=D;break}Q=P;R=J+192|0;S=D;break}if((G|0)>=0){D=G>>>22&511;J=b[y+(D<<2)>>1]|0;P=a[y+(D<<2)+2|0]|0;E=P<<24>>24;if(P<<24>>24<0){P=I+10|0;H=j+(P>>>3)|0;T=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(P&7);H=(T>>>((E+32|0)>>>0))+J|0;U=H;V=a[y+(H<<2)+2|0]|0;W=b[y+(H<<2)>>1]|0;X=T;Y=P}else{U=D;V=E;W=J;X=G<<1;Y=I+1|0}J=d[y+(U<<2)+3|0]|0;E=X<<V>>31;Q=((ba(a[(c[z+28+(J>>>7<<2)>>2]|0)+(J+63&63)|0]|0,B)|0)+W^E)-E&65535;R=J+s|0;S=Y+1+V|0;break}if((G&1073741824|0)==0){J=G>>>21&511;E=b[y+(J<<2)>>1]|0;D=a[y+(J<<2)+2|0]|0;P=D<<24>>24;if(D<<24>>24<0){D=I+11|0;T=j+(D>>>3)|0;H=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(D&7);T=(H>>>((P+32|0)>>>0))+E|0;Z=T;_=b[y+(T<<2)>>1]|0;$=a[y+(T<<2)+2|0]|0;aa=H;ca=D}else{Z=J;_=E;$=P;aa=G<<2;ca=I+2|0}P=d[y+(Z<<2)+3|0]|0;E=aa<<$>>31;Q=(E^_)-E&65535;R=s+1+P+(a[(c[z+36+(P>>>7<<2)>>2]|0)+((_|0)/(B|0)|0)|0]|0)|0;S=ca+1+$|0;break}P=G&536870912;E=G>>>23&63;J=I+9|0;D=j+(J>>>3)|0;H=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(J&7);if((H|0)>-1){C=42;break a}J=H<<1>>20;if((H&262144|0)==0){C=44;break a}H=I+23|0;D=ba(J,B)|0;T=((J|0)>0?A:r)+D|0;D=T&65535;if((T+2048|0)>>>0>4095>>>0){if((c[u>>2]&262146|0)!=0){if((T+2560|0)>>>0>5120>>>0){C=48;break a}}da=(T|0)<0?-2048:2047}else{da=D}D=s+1+E|0;if((P|0)==0){Q=da;R=D;S=H;break}Q=da;R=D+192|0;S=H}else{H=G>>31;Q=(K^H)-H&65535;R=(d[y+(L<<2)+3|0]|0)+s|0;S=I+1|0}}while(0);if((R|0)>62){C=60;break}b[f+(d[x+R|0]<<1)>>1]=Q;s=R;t=S}if((C|0)==32){yDb(c[e+4>>2]|0,16,1955016,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==34){yDb(c[e+4>>2]|0,16,1952808,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==36){yDb(c[e+4>>2]|0,16,1950576,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==42){yDb(c[e+4>>2]|0,16,1948736,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==44){yDb(c[e+4>>2]|0,16,1946704,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==48){yDb(c[e+4>>2]|0,16,1944648,(ea=i,i=i+8|0,c[ea>>2]=c[e+9960>>2],ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==60){t=R-192|0;if(!(t>>>0>63>>>0)){b[f+(d[x+t|0]<<1)>>1]=Q;c[h>>2]=S;v=t;break}t=c[e+12480>>2]|0;yDb(c[e+4>>2]|0,16,1942224,(ea=i,i=i+16|0,c[ea>>2]=c[e+12476>>2],c[ea+8>>2]=t,ea)|0);i=ea;q=-1;i=l;return q|0}}}while(0);if(o){if((c[e+14740>>2]|0)==0){b[f>>1]=mNa(n,g,b[f>>1]|0,m)|0;fa=v-(v>>31)|0}else{fa=v}_Ma(n,f,g,c[m>>2]|0);ga=(c[e+176>>2]|0)==0?fa:63}else{ga=v}c[e+180+(g<<2)>>2]=ga;q=0;i=l;return q|0}function kNa(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;i=i+24|0;f=b|0;g=a|0;h=a+14120|0;j=a+14128|0;k=c[j>>2]|0;l=c[h>>2]|0;m=l+(k>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(k&7);m=n>>>16;do{if((c[a+84>>2]&16|0)!=0){if((c[a+14720>>2]|0)==0){o=0}else{break}i=b;return o|0}}while(0);p=a+13940|0;a:do{if(n>>>0<16777216>>>0){q=c[a+9992>>2]|0;r=k;s=m;t=k;while(1){if((q|0)==3){u=r;v=s;w=t;break a}if((s>>>((8-q|0)>>>0)|0)!=1){u=r;v=s;w=t;break a}if((c[p>>2]|0)!=0){u=r;v=s;w=t;break a}x=q+8+t|0;c[j>>2]=x;y=r+8+q|0;z=l+(x>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7);z=A>>>16;if(A>>>0<16777216>>>0){r=y;s=z;t=x}else{u=y;v=z;w=x;break}}}else{u=k;v=m;w=k}}while(0);k=c[a+14132>>2]|0;do{if((u+8|0)<(k|0)){if((v|0)!=(e[1176120+((u&7)<<1)>>1]|0|0)){break}m=c[a+144>>2]|0;p=m-1|0;n=p>>>0>65535>>>0;t=n?p>>>16:p;p=n?16:0;if((t&65280|0)==0){B=p;C=t}else{B=p|8;C=t>>>8}t=(d[1191992+C|0]|0)+B|0;p=t+1|0;n=f;s=h;c[n>>2]=c[s>>2];c[n+4>>2]=c[s+4>>2];c[n+8>>2]=c[s+8>>2];c[n+12>>2]=c[s+12>>2];c[n+16>>2]=c[s+16>>2];r=w+1|0;q=w&7;if((q|0)==7){D=r}else{D=(q^7)+r|0}c[j>>2]=D;r=0;q=D;while(1){if((r|0)>=32){E=q;break}x=d[l+(q>>>3)|0]|0;z=q+1|0;c[j>>2]=z;if((x&128>>>((q&7)>>>0)|0)==0){r=r+1|0;q=z}else{E=z;break}}q=l+(E>>>3)|0;z=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(E&7)>>>((31-t|0)>>>0);q=p+E|0;c[j>>2]=q;if((z|0)==0|(z|0)>(m|0)){F=22}else{if((q+6|0)>(k|0)){F=22}else{G=z}}if((F|0)==22){G=-1}c[s>>2]=c[n>>2];c[s+4>>2]=c[n+4>>2];c[s+8>>2]=c[n+8>>2];c[s+12>>2]=c[n+12>>2];c[s+16>>2]=c[n+16>>2];if((r|0)<(SMa(g)|0)){break}else{o=G}i=b;return o|0}else{if((127>>>((u&7^7)>>>0)|v>>>8|0)!=127){break}o=c[a+144>>2]|0;i=b;return o|0}}while(0);o=0;i=b;return o|0}function lNa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;h=a+14120|0;if((e|0)<4){j=c[2187423]|0;k=a+14128|0;l=c[k>>2]|0;m=c[h>>2]|0;n=m+(l>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(l&7)>>>23;n=b[j+(o<<2)>>1]|0;p=(b[j+(o<<2)+2>>1]|0)+l|0;c[k>>2]=p;q=n;r=p;s=m}else{m=c[2187429]|0;p=a+14128|0;n=c[p>>2]|0;k=c[h>>2]|0;h=k+(n>>>3)|0;l=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(n&7)>>>23;h=b[m+(l<<2)>>1]|0;o=(b[m+(l<<2)+2>>1]|0)+n|0;c[p>>2]=o;q=h;r=o;s=k}k=q<<16>>16;if((q&65535)>>>0>9>>>0){yDb(c[a+4>>2]|0,16,1929816,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1;i=g;return u|0}do{if(q<<16>>16==0){v=0}else{o=a+14128|0;h=s+(r>>>3)|0;p=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(r&7);h=(p^-2147483648)>>31;n=r+k|0;c[o>>2]=n;l=((h^p)>>>((32-k|0)>>>0)^h)-h|0;if(!(q<<16>>16>8)){v=l;break}h=d[s+(n>>>3)|0]|0;c[o>>2]=n+1;if((h&128>>>((n&7)>>>0)|0)!=0){v=l;break}if((c[a+13740>>2]&131074|0)==0){v=l;break}yDb(c[a+4>>2]|0,16,1928112,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1;i=g;return u|0}}while(0);u=mNa(a,e,v,f)|0;i=g;return u|0}function mNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;h=c[((d|0)<4?a+168|0:a+172|0)>>2]|0;j=c[a+12520+(d<<2)>>2]|0;k=c[a+9876>>2]|0;l=c[a+12496+(d<<2)>>2]|0;m=k+(l<<1)|0;n=b[k+(l-1<<1)>>1]|0;o=b[k+(l+~j<<1)>>1]|0;p=b[k+(l-j<<1)>>1]|0;do{if((c[a+14084>>2]|0)==0|(d|0)==3){q=p;r=o;s=n}else{j=(d|0)==2;l=j?o:1024;k=j?p:1024;if((d|0)==1){q=k;r=l;s=n;break}j=(c[a+12476>>2]|0)==(c[a+13704>>2]|0);q=k;r=j?1024:l;s=j?1024:n}}while(0);n=a+12476|0;do{if((c[n>>2]|0)==(c[a+13704>>2]|0)){if((c[a+12480>>2]|0)!=((c[a+13708>>2]|0)+1|0)){t=r;break}if(!((d|0)==5|(d|0)==4|(d|0)==0)){t=r;break}t=1024}else{t=r}}while(0);r=s-t|0;d=t-q|0;t=(((r|0)>-1?r:-r|0)|0)<(((d|0)>-1?d:-d|0)|0);c[f>>2]=t&1;f=(t?q:s)+(h>>1)|0;gHb(f,(f|0)<0|0?-1:0,c[1199552+(h<<2)>>2]|0,0)|0;f=F+e|0;do{if((c[a+13740>>2]&262146|0)==0){u=ba(f,h)|0}else{if((f|0)<0){e=c[a+12480>>2]|0;yDb(c[a+4>>2]|0,16,1934152,(v=i,i=i+16|0,c[v>>2]=c[n>>2],c[v+8>>2]=e,v)|0);i=v;w=-1;i=g;return w|0}e=ba(f,h)|0;if((e|0)<=(h+2048|0)){u=e;break}e=c[a+12480>>2]|0;yDb(c[a+4>>2]|0,16,1931608,(v=i,i=i+16|0,c[v>>2]=c[n>>2],c[v+8>>2]=e,v)|0);i=v;w=-1;i=g;return w|0}}while(0);v=u&65535;do{if(u>>>0>2047>>>0){if((u|0)<0){x=0;break}x=(c[a+84>>2]&4096|0)==0?2047:v}else{x=v}}while(0);b[m>>1]=x;w=f;i=g;return w|0}function nNa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;h=e;j=e+12476|0;k=e+12480|0;l=(ba(c[e+124>>2]|0,c[k>>2]|0)|0)+(c[j>>2]|0)|0;m=e+9160|0;n=c[(c[m>>2]|0)+(l<<2)>>2]|0;o=e+9936|0;p=d[(c[o>>2]|0)+l|0]|0;q=c[e+9960>>2]|0;c[e+14740>>2]=(q|0)<(c[e+14744>>2]|0);r=a[(c[e+9136>>2]|0)+l|0]|0;if((r|0)!=(q|0)){cPa(e,r)}r=c[e+9992>>2]|0;a:do{if((r|0)==2|(r|0)==4){q=c[e+12496>>2]|0;s=c[e+9148>>2]|0;c[e+11744>>2]=b[s+(q<<2)>>1]|0;c[e+11748>>2]=b[s+(q<<2)+2>>1]|0;q=c[e+12500>>2]|0;c[e+11752>>2]=b[s+(q<<2)>>1]|0;c[e+11756>>2]=b[s+(q<<2)+2>>1]|0;q=c[e+12504>>2]|0;c[e+11760>>2]=b[s+(q<<2)>>1]|0;c[e+11764>>2]=b[s+(q<<2)+2>>1]|0;q=c[e+12508>>2]|0;c[e+11768>>2]=b[s+(q<<2)>>1]|0;c[e+11772>>2]=b[s+(q<<2)+2>>1]|0;q=n&7;c[e+12488>>2]=q;s=n&2048;if((s|0)!=0){TGb(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;do{if((r|0)==4){if((c[e+14680>>2]|0)!=2){break}c[e+13916>>2]=1;c[e+9924>>2]=0;t=s;u=15;break a}}while(0);c[e+13916>>2]=0;c[e+9924>>2]=1;t=s;u=15;break}if((q|0)!=0){c[e+176>>2]=c[(c[m>>2]|0)+(l<<2)>>2]&512;u=16;break}c[e+11736>>2]=1;v=e+11740|0;if((n&64|0)==0){c[v>>2]=0;u=16;break}else{c[v>>2]=1;u=16;break}}else{c[e+12488>>2]=1;c[e+176>>2]=c[(c[m>>2]|0)+(l<<2)>>2]&512;t=n&2048;u=15}}while(0);if((u|0)==15){if((t|0)==0){u=16}}b:do{if((u|0)==16){me[c[e+10096>>2]&511](c[e+14340>>2]|0);t=e+12488|0;n=e+14716|0;do{if((jNa(h,f|0,0,p&32,c[t>>2]|0,c[n>>2]|0)|0)>=0){if((jNa(h,f+128|0,1,p<<1&32,c[t>>2]|0,c[n>>2]|0)|0)<0){break}if((jNa(h,f+256|0,2,p<<2&32,c[t>>2]|0,c[n>>2]|0)|0)<0){break}if((jNa(h,f+384|0,3,p<<3&32,c[t>>2]|0,c[n>>2]|0)|0)<0){break}if((jNa(h,f+512|0,4,p<<4&32,c[t>>2]|0,c[n>>2]|0)|0)<0){break}if((jNa(h,f+640|0,5,p<<5&32,c[t>>2]|0,c[n>>2]|0)|0)>=0){break b}}}while(0);n=c[k>>2]|0;q=c[t>>2]|0;yDb(c[e+4>>2]|0,16,2309440,(s=i,i=i+24|0,c[s>>2]=c[j>>2],c[s+8>>2]=n,c[s+16>>2]=q,s)|0);i=s;w=-1;i=g;return w|0}}while(0);k=e+13732|0;p=(c[k>>2]|0)-1|0;c[k>>2]=p;k=(kNa(h)|0)!=0;if((p|0)<1){w=k?-2:-3;i=g;return w|0}do{if(k){if((a[(c[o>>2]|0)+((((c[j>>2]|0)+1|0)==(c[e+116>>2]|0)?2:1)+l)|0]|0)==0){break}else{w=-2}i=g;return w|0}}while(0);w=0;i=g;return w|0}function oNa(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[d+9136>>2]|0;Klb(d);if((c[d+9992>>2]|0)!=3){return}f=d+144|0;g=c[f>>2]|0;h=(g|0)>0;if(!h){return}i=c[d+12556>>2]|0;j=0;k=0;do{j=(a[e+(c[i+(k<<2)>>2]|0)|0]&1)+j|0;k=k+1|0;}while((k|0)<(g|0));k=(j<<1|0)>(g|0);if(!h){return}h=d+12556|0;g=0;do{j=e+(c[(c[h>>2]|0)+(g<<2)>>2]|0)|0;i=a[j]|0;if(k^(i&1)!=0){l=i+1&255;a[j]=l;m=l}else{m=i}if(m<<24>>24>31){a[j]=31}g=g+1|0;n=c[f>>2]|0;}while((g|0)<(n|0));if((n|0)<=1){return}g=d+12492|0;f=c[d+12556>>2]|0;d=1;m=c[f>>2]|0;while(1){k=c[f+(d<<2)>>2]|0;do{if((a[e+k|0]|0)!=(a[e+m|0]|0)){h=(c[g>>2]|0)+(k<<1)|0;j=b[h>>1]|0;if((j&16)==0){break}b[h>>1]=j|128}}while(0);j=d+1|0;if((j|0)<(n|0)){d=j;m=k}else{break}}return}function pNa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0;j=i;i=i+112|0;k=j|0;l=j+8|0;m=j+16|0;n=j+40|0;o=j+64|0;p=j+88|0;q=c[e+13936>>2]|0;r=(q|0)!=0;s=e+13980|0;t=e+784|0;u=r?s:t;if(r){r=c[e+9992>>2]|0;v=(r|0)==3?t:e+13956|0;if((r|0)==1){w=v;y=3}else{z=s;A=v}}else{w=t;y=3}if((y|0)==3){z=t;A=w}w=c[e+60>>2]|0;v=(q|0)==0&(w&512|0)!=0;if((c[e+12488>>2]|0)!=0){q=e+168|0;s=e+172|0;r=e+12476|0;B=e+13704|0;C=e+12480|0;D=e+13708|0;E=e+84|0;G=c[e+9876>>2]|0;H=c[e+14084>>2]|0;I=0;do{J=b[f+(I<<7)>>1]|0;K=n+(I<<2)|0;L=c[((I|0)<4?q:s)>>2]|0;M=c[e+12520+(I<<2)>>2]|0;N=c[e+12496+(I<<2)>>2]|0;O=G+(N<<1)|0;P=b[G+(N-1<<1)>>1]|0;Q=b[G+(N+~M<<1)>>1]|0;R=b[G+(N-M<<1)>>1]|0;do{if((H|0)==0|(I|0)==3){S=R;T=Q;U=P}else{M=(I|0)==2;N=M?Q:1024;V=M?R:1024;if((I|0)==1){S=V;T=N;U=P;break}M=(c[r>>2]|0)==(c[B>>2]|0);S=V;T=M?1024:N;U=M?1024:P}}while(0);do{if((c[r>>2]|0)==(c[B>>2]|0)){if((c[C>>2]|0)!=((c[D>>2]|0)+1|0)){W=T;break}if(!((I|0)==5|(I|0)==4|(I|0)==0)){W=T;break}W=1024}else{W=T}}while(0);P=U-W|0;R=W-S|0;Q=(((P|0)>-1?P:-P|0)|0)<(((R|0)>-1?R:-R|0)|0);c[K>>2]=Q&1;R=(Q?S:U)+(L>>1)|0;gHb(R,(R|0)<0|0?-1:0,c[1199552+(L<<2)>>2]|0,0)|0;R=J-F|0;Q=ba(L,J)|0;P=Q&65535;do{if(Q>>>0>2047>>>0){if((Q|0)<0){X=0;break}X=(c[E>>2]&4096|0)==0?2047:P}else{X=P}}while(0);b[O>>1]=X;c[m+(I<<2)>>2]=R;I=I+1|0;}while((I|0)<6);if((w&16777216|0)==0){w=e+368|0;c[p>>2]=w;c[p+4>>2]=w;c[p+8>>2]=w;c[p+12>>2]=w;c[p+16>>2]=w;c[p+20>>2]=w}else{w=p|0;I=c[e+9136>>2]|0;X=o;E=e+180|0;c[X>>2]=c[E>>2];c[X+4>>2]=c[E+4>>2];c[X+8>>2]=c[E+8>>2];c[X+12>>2]=c[E+12>>2];c[X+16>>2]=c[E+16>>2];c[X+20>>2]=c[E+20>>2];E=e+9912|0;X=e+632|0;U=e+124|0;S=e+9960|0;W=e+500|0;T=e+13092|0;D=e+13096|0;B=e+13088|0;H=0;G=0;do{s=e+180+(H<<2)|0;q=c[s>>2]|0;if((q|0)<1){Y=0}else{P=1;Q=0;J=0;while(1){L=b[f+(H<<7)+(d[e+368+P|0]<<1)>>1]|0;if(L<<16>>16==0){Z=J;_=Q}else{K=(L<<16>>16)+64|0;do{if(K>>>0<128>>>0){L=(P-J<<7)-128+K|0;if((P|0)<(q|0)){$=d[(c[T>>2]|0)+L|0]|0;break}else{$=d[(c[D>>2]|0)+L|0]|0;break}}else{$=c[B>>2]|0}}while(0);Z=P;_=$+Q|0}K=P+1|0;if((K|0)>(q|0)){Y=_;break}else{P=K;Q=_;J=Z}}}J=G-Y|0;Q=c[E>>2]|0;P=c[e+12496+(H<<2)>>2]<<4;q=c[r>>2]|0;if((c[n+(H<<2)>>2]|0)==0){R=P-16|0;a:do{if((q|0)==0){y=291}else{O=q-1+(ba(c[C>>2]|0,c[U>>2]|0)|0)|0;K=c[S>>2]|0;L=I+O|0;O=a[L]|0;if((K|0)==(O<<24>>24|0)){y=291;break}if((H|0)==3|(H|0)==1){y=291;break}M=P|8;N=K>>1;V=-N|0;aa=1;ca=O;while(1){O=f+(H<<7)+(d[(aa<<3)+(e+11184)|0]<<1)|0;da=b[O>>1]|0;ea=ba(b[Q+(aa+R<<1)>>1]|0,ca<<24>>24)|0;b[O>>1]=(da&65535)-((((ea|0)>0?N:V)+ea|0)/(K|0)|0);b[Q+(aa+P<<1)>>1]=da;b[Q+(aa+M<<1)>>1]=b[f+(H<<7)+(d[e+11184+aa|0]<<1)>>1]|0;da=aa+1|0;if((da|0)>=8){break a}aa=da;ca=a[L]|0}}}while(0);if((y|0)==291){y=0;L=P|8;ca=1;do{aa=f+(H<<7)+(d[(ca<<3)+(e+11184)|0]<<1)|0;M=b[aa>>1]|0;b[aa>>1]=M-(b[Q+(ca+R<<1)>>1]|0);b[Q+(ca+P<<1)>>1]=M;b[Q+(ca+L<<1)>>1]=b[f+(H<<7)+(d[e+11184+ca|0]<<1)>>1]|0;ca=ca+1|0;}while((ca|0)<8)}c[p+(H<<2)>>2]=X;fa=X}else{ca=c[C>>2]|0;L=c[U>>2]|0;R=P-(c[e+12520+(H<<2)>>2]<<4)|0;b:do{if((ca|0)==0){ga=1;y=286}else{M=q-L+(ba(L,ca)|0)|0;aa=c[S>>2]|0;K=I+M|0;M=a[K]|0;if((aa|0)==(M<<24>>24|0)){ga=1;y=286;break}if((H-2|0)>>>0<2>>>0){ga=1;y=286;break}V=aa>>1;N=-V|0;da=1;ea=M;while(1){M=f+(H<<7)+(d[e+11184+da|0]<<1)|0;O=b[M>>1]|0;ha=da+8|0;ia=ba(b[Q+(ha+R<<1)>>1]|0,ea<<24>>24)|0;b[M>>1]=(O&65535)-((((ia|0)>0?V:N)+ia|0)/(aa|0)|0);b[Q+(da+P<<1)>>1]=b[f+(H<<7)+(d[(da<<3)+(e+11184)|0]<<1)>>1]|0;b[Q+(ha+P<<1)>>1]=O;O=da+1|0;if((O|0)>=8){break b}da=O;ea=a[K]|0}}}while(0);if((y|0)==286){while(1){y=0;ca=f+(H<<7)+(d[e+11184+ga|0]<<1)|0;L=b[ca>>1]|0;q=ga+8|0;b[ca>>1]=L-(b[Q+(q+R<<1)>>1]|0);b[Q+(ga+P<<1)>>1]=b[f+(H<<7)+(d[(ga<<3)+(e+11184)|0]<<1)>>1]|0;b[Q+(q+P<<1)>>1]=L;L=ga+1|0;if((L|0)<8){ga=L;y=286}else{break}}}c[p+(H<<2)>>2]=W;fa=W}P=63;while(1){if((P|0)<=0){y=301;break}if((b[f+(H<<7)+(d[fa+P|0]<<1)>>1]|0)==0){P=P-1|0}else{y=303;break}}do{if((y|0)==301){y=0;c[s>>2]=P;ja=0}else if((y|0)==303){y=0;c[s>>2]=P;if((P|0)<1){ja=0;break}else{ka=1;la=0;ma=0}while(1){Q=b[f+(H<<7)+(d[fa+ka|0]<<1)>>1]|0;if(Q<<16>>16==0){na=ma;oa=la}else{R=(Q<<16>>16)+64|0;do{if(R>>>0<128>>>0){Q=(ka-ma<<7)-128+R|0;if((ka|0)<(P|0)){pa=d[(c[T>>2]|0)+Q|0]|0;break}else{pa=d[(c[D>>2]|0)+Q|0]|0;break}}else{pa=c[B>>2]|0}}while(0);na=ka;oa=pa+la|0}R=ka+1|0;if((R|0)>(P|0)){ja=oa;break}else{ka=R;la=oa;ma=na}}}}while(0);G=ja+J|0;H=H+1|0;}while((H|0)<6);if((G|0)<0){qa=1}else{sNa(e,f,n|0,w,o|0);qa=0}c[e+176>>2]=qa}qa=(c[e+180>>2]|0)>0?32:0;w=(c[e+184>>2]|0)>0?qa|16:qa;qa=(c[e+188>>2]|0)>0?w|8:w;w=(c[e+192>>2]|0)>0?qa|4:qa;qa=(c[e+196>>2]|0)>0?w|2:w;w=qa&3|(c[e+200>>2]|0)>0;G=e+9984|0;H=(c[G>>2]|0)!=0;if((c[e+9992>>2]|0)==1){ja=H?w|4:w;na=d[1210736+ja|0]|0;ma=d[1210720+ja|0]|0;ja=t|0;oa=c[ja>>2]|0;la=e+788|0;ka=c[la>>2]|0;if((ka|0)>(na|0)){ra=ka-na|0;sa=oa<<na|ma}else{pa=fe(ma>>>((na-ka|0)>>>0)|oa<<ka|0)|0;oa=e+796|0;B=c[oa>>2]|0;x=pa;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[oa>>2]=(c[oa>>2]|0)+4;ra=32-na+ka|0;sa=ma}c[ja>>2]=sa;c[la>>2]=ra}else{ra=t|0;la=c[ra>>2]|0;sa=e+788|0;ja=c[sa>>2]|0;if((ja|0)>1){ta=ja-1|0;ua=la<<1}else{ma=fe(la<<ja|0)|0;la=e+796|0;ka=c[la>>2]|0;x=ma;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;c[la>>2]=(c[la>>2]|0)+4;ta=ja+31|0;ua=0}c[ra>>2]=ua;c[sa>>2]=ta;ja=(H?w|8:w)|4;w=d[1210784+ja|0]|0;H=d[1210752+ja|0]|0;if((ta|0)>(w|0)){va=ta;wa=ua<<w|H}else{ja=fe(H>>>((w-ta|0)>>>0)|ua<<ta|0)|0;ua=e+796|0;la=c[ua>>2]|0;x=ja;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;c[ua>>2]=(c[ua>>2]|0)+4;va=ta+32|0;wa=H}c[ra>>2]=wa;c[sa>>2]=va-w}w=e+176|0;va=c[w>>2]|0;sa=u|0;wa=c[sa>>2]|0;ra=u+4|0;H=c[ra>>2]|0;if((H|0)>1){xa=H-1|0;ya=wa<<1|va}else{ta=fe(va>>>((1-H|0)>>>0)|wa<<H|0)|0;wa=u+12|0;ua=c[wa>>2]|0;x=ta;a[ua]=x;x=x>>8;a[ua+1|0]=x;x=x>>8;a[ua+2|0]=x;x=x>>8;a[ua+3|0]=x;c[wa>>2]=(c[wa>>2]|0)+4;xa=H+31|0;ya=va}c[sa>>2]=ya;c[ra>>2]=xa;va=qa>>2;qa=d[1211185+(va<<1)|0]|0;H=d[1211184+(va<<1)|0]|0;if((xa|0)>(qa|0)){za=xa;Aa=ya<<qa|H}else{va=fe(H>>>((qa-xa|0)>>>0)|ya<<xa|0)|0;ya=u+12|0;wa=c[ya>>2]|0;x=va;a[wa]=x;x=x>>8;a[wa+1|0]=x;x=x>>8;a[wa+2|0]=x;x=x>>8;a[wa+3|0]=x;c[ya>>2]=(c[ya>>2]|0)+4;za=xa+32|0;Aa=H}c[sa>>2]=Aa;c[ra>>2]=za-qa;qa=c[G>>2]|0;if((qa|0)!=0){G=c[1349864+(qa+2<<2)>>2]|0;qa=z|0;za=c[qa>>2]|0;ra=z+4|0;Aa=c[ra>>2]|0;if((Aa|0)>2){Ba=Aa-2|0;Ca=za<<2|G}else{sa=fe(G>>>((2-Aa|0)>>>0)|za<<Aa|0)|0;za=z+12|0;H=c[za>>2]|0;x=sa;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[za>>2]=(c[za>>2]|0)+4;Ba=Aa+30|0;Ca=G}c[qa>>2]=Ca;c[ra>>2]=Ba}if((c[e+14152>>2]|0)==0){Ba=c[e+14236>>2]|0;ra=z|0;Ca=c[ra>>2]|0;qa=z+4|0;G=c[qa>>2]|0;if((G|0)>1){Da=G-1|0;Ea=Ca<<1|Ba}else{Aa=fe(Ba>>>((1-G|0)>>>0)|Ca<<G|0)|0;Ca=z+12|0;za=c[Ca>>2]|0;x=Aa;a[za]=x;x=x>>8;a[za+1|0]=x;x=x>>8;a[za+2|0]=x;x=x>>8;a[za+3|0]=x;c[Ca>>2]=(c[Ca>>2]|0)+4;Da=G+31|0;Ea=Ba}c[ra>>2]=Ea;c[qa>>2]=Da}if(v){Da=e+788|0;qa=e+792|0;Ea=e+796|0;ra=((c[Ea>>2]|0)-(c[qa>>2]|0)<<3)+(32-(c[Da>>2]|0))|0;Ba=e+13700|0;G=c[Ba>>2]|0;c[Ba>>2]=ra;Ca=e+13696|0;c[Ca>>2]=(c[Ca>>2]|0)-G+ra;ra=p|0;rNa(e,f,m|0,ra,z,A);G=((c[Ea>>2]|0)-(c[qa>>2]|0)<<3)+(32-(c[Da>>2]|0))|0;Da=c[Ba>>2]|0;c[Ba>>2]=G;Ba=e+13672|0;c[Ba>>2]=(c[Ba>>2]|0)-Da+G;Fa=ra}else{ra=p|0;rNa(e,f,m|0,ra,z,A);Fa=ra}ra=e+13680|0;c[ra>>2]=(c[ra>>2]|0)+1;if((c[w>>2]|0)==0){i=j;return}sNa(e,f,n|0,Fa,o|0);i=j;return}if((c[e+9992>>2]|0)==3){o=e+11736|0;Fa=c[o>>2]|0;n=c[1176864+(Fa<<2)>>2]|0;w=c[e+12476>>2]|0;if((w|0)==0){TGb(e+11824|0,0,32)|0}ra=(ba(c[e+124>>2]|0,c[e+12480>>2]|0)|0)+w|0;if((a[(c[e+4720>>2]|0)+ra|0]|0)!=0){ra=e+13692|0;c[ra>>2]=(c[ra>>2]|0)+1;c[e+11780>>2]=0;c[e+11776>>2]=0;c[e+11748>>2]=0;c[e+11744>>2]=0;c[o>>2]=1;ra=e+9960|0;c[ra>>2]=(c[ra>>2]|0)-(c[e+9984>>2]|0);i=j;return}do{if((c[e+14404>>2]&8|0)==0){ra=(c[e+180>>2]>>31)+32&-32;w=(c[e+184>>2]|0)>-1?ra|16:ra;ra=(c[e+188>>2]|0)>-1?w|8:w;w=(c[e+192>>2]|0)>-1?ra|4:ra;ra=(c[e+196>>2]|0)>-1?w|2:w;if(!((c[e+200>>2]|0)>-1)){Ga=ra;break}Ga=ra|1}else{ra=c[e+9972>>2]|0;w=c[e+13112>>2]|0;z=(w|0)<0?w:0;m=w>>31&32;w=c[e+13116>>2]|0;if((w|0)<0){Ha=m|16;Ia=z+w|0}else{Ha=m;Ia=z}z=c[e+13120>>2]|0;if((z|0)<0){Ja=Ha|8;Ka=z+Ia|0}else{Ja=Ha;Ka=Ia}z=c[e+13124>>2]|0;if((z|0)<0){La=Ja|4;Ma=z+Ka|0}else{La=Ja;Ma=Ka}z=c[e+13128>>2]|0;if((z|0)<0){Na=La|2;Oa=z+Ma|0}else{Na=La;Oa=Ma}z=c[e+13132>>2]|0;if((z|0)<0){Pa=z+Oa|0;Qa=Na|1;y=14}else{if((Na|0)==0){Ra=0}else{Pa=Oa;Qa=Na;y=14}}if((y|0)==14){z=(ba((h|g|n|c[e+9984>>2]|0)==0?-10:-6,ra>>>1)|0)>(Pa|0);Ra=z?Qa:0}z=e+10092|0;ra=e+14340|0;m=e+180|0;do{if((c[m>>2]|0)>-1){if((Ra&32|0)!=0){break}c[m>>2]=-1;me[c[z>>2]&511](c[ra>>2]|0)}}while(0);m=e+184|0;do{if((c[m>>2]|0)>-1){if((Ra&16|0)!=0){break}c[m>>2]=-1;me[c[z>>2]&511]((c[ra>>2]|0)+128|0)}}while(0);m=e+188|0;do{if((c[m>>2]|0)>-1){if((Ra&8|0)!=0){break}c[m>>2]=-1;me[c[z>>2]&511]((c[ra>>2]|0)+256|0)}}while(0);m=e+192|0;do{if((c[m>>2]|0)>-1){if((Ra&4|0)!=0){break}c[m>>2]=-1;me[c[z>>2]&511]((c[ra>>2]|0)+384|0)}}while(0);m=e+196|0;do{if((c[m>>2]|0)>-1){if((Ra&2|0)!=0){break}c[m>>2]=-1;me[c[z>>2]&511]((c[ra>>2]|0)+512|0)}}while(0);m=e+200|0;if(!((c[m>>2]|0)>-1)){Ga=Ra;break}if((Ra&1|0)!=0){Ga=Ra;break}c[m>>2]=-1;me[c[z>>2]&511]((c[ra>>2]|0)+640|0);Ga=Ra}}while(0);Ra=t|0;Qa=c[Ra>>2]|0;Pa=e+788|0;Na=c[Pa>>2]|0;Oa=(Na|0)>1;if((h|g|n|Ga|0)==0){if(Oa){Sa=Na-1|0;Ta=Qa<<1|1}else{Ma=fe(1>>>((1-Na|0)>>>0)|Qa<<Na|0)|0;La=e+796|0;Ka=c[La>>2]|0;x=Ma;a[Ka]=x;x=x>>8;a[Ka+1|0]=x;x=x>>8;a[Ka+2|0]=x;x=x>>8;a[Ka+3|0]=x;c[La>>2]=(c[La>>2]|0)+4;Sa=Na+31|0;Ta=1}c[Ra>>2]=Ta;c[Pa>>2]=Sa;if(v){Sa=e+13696|0;c[Sa>>2]=(c[Sa>>2]|0)+1;Sa=e+13700|0;c[Sa>>2]=(c[Sa>>2]|0)+1}Sa=e+13692|0;c[Sa>>2]=(c[Sa>>2]|0)+1;i=j;return}if(Oa){Ua=Na-1|0;Va=Qa<<1}else{Oa=fe(Qa<<Na|0)|0;Qa=e+796|0;Sa=c[Qa>>2]|0;x=Oa;a[Sa]=x;x=x>>8;a[Sa+1|0]=x;x=x>>8;a[Sa+2|0]=x;x=x>>8;a[Sa+3|0]=x;c[Qa>>2]=(c[Qa>>2]|0)+4;Ua=Na+31|0;Va=0}c[Ra>>2]=Va;c[Pa>>2]=Ua;Na=(Ga|0)!=0;Qa=Na&1^1;if((Ua|0)>1){Wa=Ua-1|0;Xa=Va<<1|Qa}else{Sa=fe(Qa>>>((1-Ua|0)>>>0)|Va<<Ua|0)|0;Va=e+796|0;Oa=c[Va>>2]|0;x=Sa;a[Oa]=x;x=x>>8;a[Oa+1|0]=x;x=x>>8;a[Oa+2|0]=x;x=x>>8;a[Oa+3|0]=x;c[Va>>2]=(c[Va>>2]|0)+4;Wa=Ua+31|0;Xa=Qa}c[Ra>>2]=Xa;c[Pa>>2]=Wa;Qa=n+1|0;if((Wa|0)>(Qa|0)){Ya=Wa-Qa|0;Za=Xa<<Qa|1}else{Ua=fe(1>>>((Qa-Wa|0)>>>0)|Xa<<Wa|0)|0;Xa=e+796|0;Qa=c[Xa>>2]|0;x=Ua;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;c[Xa>>2]=(c[Xa>>2]|0)+4;Ya=31-n+Wa|0;Za=1}c[Ra>>2]=Za;c[Pa>>2]=Ya;do{if(Na){if((Ya|0)>6){_a=Ya-6|0;$a=Za<<6|Ga}else{Wa=fe(Za<<Ya|Ga>>>((6-Ya|0)>>>0)|0)|0;n=e+796|0;Xa=c[n>>2]|0;x=Wa;a[Xa]=x;x=x>>8;a[Xa+1|0]=x;x=x>>8;a[Xa+2|0]=x;x=x>>8;a[Xa+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;_a=Ya+26|0;$a=Ga}c[Ra>>2]=$a;c[Pa>>2]=_a;if((Fa|0)==7){ab=$a;bb=_a;y=74;break}n=c[e+9984>>2]|0;if((n|0)==0){if((_a|0)>1){cb=_a-1|0;db=$a<<1}else{Xa=fe($a<<_a|0)|0;Wa=e+796|0;Qa=c[Wa>>2]|0;x=Xa;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;c[Wa>>2]=(c[Wa>>2]|0)+4;cb=_a+31|0;db=0}c[Ra>>2]=db;c[Pa>>2]=cb;eb=db;fb=cb;break}else{Wa=(n>>2)+3|0;if((_a|0)>2){gb=_a-2|0;hb=$a<<2|Wa}else{n=fe($a<<_a|Wa>>>((2-_a|0)>>>0)|0)|0;Qa=e+796|0;Xa=c[Qa>>2]|0;x=n;a[Xa]=x;x=x>>8;a[Xa+1|0]=x;x=x>>8;a[Xa+2|0]=x;x=x>>8;a[Xa+3|0]=x;c[Qa>>2]=(c[Qa>>2]|0)+4;gb=_a+30|0;hb=Wa}c[Ra>>2]=hb;c[Pa>>2]=gb;eb=hb;fb=gb;break}}else{ab=Za;bb=Ya;y=74}}while(0);if((y|0)==74){Ya=e+9960|0;c[Ya>>2]=(c[Ya>>2]|0)-(c[e+9984>>2]|0);eb=ab;fb=bb}do{if((c[e+14152>>2]|0)==0){if(Na){bb=c[e+14236>>2]|0;if((fb|0)>1){ib=fb-1|0;jb=eb<<1|bb}else{ab=fe(bb>>>((1-fb|0)>>>0)|eb<<fb|0)|0;Ya=e+796|0;Za=c[Ya>>2]|0;x=ab;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;c[Ya>>2]=(c[Ya>>2]|0)+4;ib=fb+31|0;jb=bb}c[Ra>>2]=jb;c[Pa>>2]=ib;kb=jb;lb=ib}else{kb=eb;lb=fb}if((Fa|0)==7){mb=lb;nb=kb;break}bb=(c[e+11740>>2]|0)==3|0;if((lb|0)>1){ob=lb-1|0;pb=kb<<1|bb}else{Ya=fe(bb>>>((1-lb|0)>>>0)|kb<<lb|0)|0;Za=e+796|0;ab=c[Za>>2]|0;x=Ya;a[ab]=x;x=x>>8;a[ab+1|0]=x;x=x>>8;a[ab+2|0]=x;x=x>>8;a[ab+3|0]=x;c[Za>>2]=(c[Za>>2]|0)+4;ob=lb+31|0;pb=bb}c[Ra>>2]=pb;c[Pa>>2]=ob;mb=ob;nb=pb}else{mb=fb;nb=eb}}while(0);if(v){eb=((c[e+796>>2]|0)-(c[e+792>>2]|0)<<3)+(32-mb)|0;fb=e+13700|0;pb=c[fb>>2]|0;c[fb>>2]=eb;fb=e+13696|0;c[fb>>2]=(c[fb>>2]|0)-pb+eb}do{if((Fa|0)==7){if((c[e+64>>2]&4|0)==0){Nlb(e,g,1);Nlb(e,h,1)}else{if((g|0)==0){qb=d[1172137]|0}else{qb=(d[1172137+(g<<26>>26<<1)|0]|0)+1|0}if((h|0)==0){rb=d[1172137]|0}else{rb=(d[1172137+(h<<26>>26<<1)|0]|0)+1|0}eb=mb-(rb+qb)|0;pb=e+796|0;c[pb>>2]=(c[pb>>2]|0)+(-(eb>>5<<2)|0);c[Pa>>2]=eb&31}eb=e+13688|0;c[eb>>2]=(c[eb>>2]|0)+1;eb=e+13684|0;c[eb>>2]=(c[eb>>2]|0)+1}else{eb=c[o>>2]|0;pb=(eb&1|0)!=0;if((c[e+11740>>2]|0)!=3){if(pb){fb=e+11744|0;ob=e+11824|0;lb=e+11748|0;kb=e+11828|0;qNa(e,(c[fb>>2]|0)-(c[ob>>2]|0)|0,(c[lb>>2]|0)-(c[kb>>2]|0)|0,c[e+11556>>2]|0);ib=c[fb>>2]|0;c[e+11832>>2]=ib;c[ob>>2]=ib;ib=c[lb>>2]|0;c[e+11836>>2]=ib;c[kb>>2]=ib;ib=e+13684|0;c[ib>>2]=(c[ib>>2]|0)+1;sb=c[o>>2]|0}else{sb=eb}if((sb&2|0)==0){break}ib=e+11776|0;kb=e+11840|0;lb=e+11780|0;ob=e+11844|0;qNa(e,(c[ib>>2]|0)-(c[kb>>2]|0)|0,(c[lb>>2]|0)-(c[ob>>2]|0)|0,c[e+11560>>2]|0);fb=c[ib>>2]|0;c[e+11848>>2]=fb;c[kb>>2]=fb;fb=c[lb>>2]|0;c[e+11852>>2]=fb;c[ob>>2]=fb;fb=e+13688|0;c[fb>>2]=(c[fb>>2]|0)+1;break}if(pb){pb=c[e+11808>>2]|0;if((mb|0)>1){tb=mb-1|0;ub=nb<<1|pb}else{fb=fe(pb>>>((1-mb|0)>>>0)|nb<<mb|0)|0;ob=e+796|0;lb=c[ob>>2]|0;x=fb;a[lb]=x;x=x>>8;a[lb+1|0]=x;x=x>>8;a[lb+2|0]=x;x=x>>8;a[lb+3|0]=x;c[ob>>2]=(c[ob>>2]|0)+4;tb=mb+31|0;ub=pb}c[Ra>>2]=ub;c[Pa>>2]=tb;pb=c[e+11812>>2]|0;if((tb|0)>1){vb=tb-1|0;wb=ub<<1|pb}else{ob=fe(ub<<tb|pb>>>((1-tb|0)>>>0)|0)|0;lb=e+796|0;fb=c[lb>>2]|0;x=ob;a[fb]=x;x=x>>8;a[fb+1|0]=x;x=x>>8;a[fb+2|0]=x;x=x>>8;a[fb+3|0]=x;c[lb>>2]=(c[lb>>2]|0)+4;vb=tb+31|0;wb=pb}c[Ra>>2]=wb;c[Pa>>2]=vb;xb=c[o>>2]|0;yb=wb;zb=vb}else{xb=eb;yb=nb;zb=mb}if((xb&2|0)==0){Ab=xb}else{eb=c[e+11816>>2]|0;if((zb|0)>1){Bb=zb-1|0;Cb=yb<<1|eb}else{pb=fe(eb>>>((1-zb|0)>>>0)|yb<<zb|0)|0;lb=e+796|0;fb=c[lb>>2]|0;x=pb;a[fb]=x;x=x>>8;a[fb+1|0]=x;x=x>>8;a[fb+2|0]=x;x=x>>8;a[fb+3|0]=x;c[lb>>2]=(c[lb>>2]|0)+4;Bb=zb+31|0;Cb=eb}c[Ra>>2]=Cb;c[Pa>>2]=Bb;eb=c[e+11820>>2]|0;if((Bb|0)>1){Db=Bb-1|0;Eb=Cb<<1|eb}else{lb=fe(Cb<<Bb|eb>>>((1-Bb|0)>>>0)|0)|0;fb=e+796|0;pb=c[fb>>2]|0;x=lb;a[pb]=x;x=x>>8;a[pb+1|0]=x;x=x>>8;a[pb+2|0]=x;x=x>>8;a[pb+3|0]=x;c[fb>>2]=(c[fb>>2]|0)+4;Db=Bb+31|0;Eb=eb}c[Ra>>2]=Eb;c[Pa>>2]=Db;Ab=c[o>>2]|0}if((Ab&1|0)==0){Fb=Ab}else{eb=e+11556|0;fb=e+11744|0;pb=e+11824|0;lb=e+11748|0;ob=e+11828|0;qNa(e,(c[fb>>2]|0)-(c[pb>>2]|0)|0,(c[lb>>2]|0)-((c[ob>>2]|0)/2|0)|0,c[eb>>2]|0);c[pb>>2]=c[fb>>2];c[ob>>2]=c[lb>>2]<<1;lb=e+11752|0;ob=e+11832|0;fb=e+11756|0;pb=e+11836|0;qNa(e,(c[lb>>2]|0)-(c[ob>>2]|0)|0,(c[fb>>2]|0)-((c[pb>>2]|0)/2|0)|0,c[eb>>2]|0);c[ob>>2]=c[lb>>2];c[pb>>2]=c[fb>>2]<<1;fb=e+13684|0;c[fb>>2]=(c[fb>>2]|0)+1;Fb=c[o>>2]|0}if((Fb&2|0)==0){break}fb=e+11560|0;pb=e+11776|0;lb=e+11840|0;ob=e+11780|0;eb=e+11844|0;qNa(e,(c[pb>>2]|0)-(c[lb>>2]|0)|0,(c[ob>>2]|0)-((c[eb>>2]|0)/2|0)|0,c[fb>>2]|0);c[lb>>2]=c[pb>>2];c[eb>>2]=c[ob>>2]<<1;ob=e+11784|0;eb=e+11848|0;pb=e+11788|0;lb=e+11852|0;qNa(e,(c[ob>>2]|0)-(c[eb>>2]|0)|0,(c[pb>>2]|0)-((c[lb>>2]|0)/2|0)|0,c[fb>>2]|0);c[eb>>2]=c[ob>>2];c[lb>>2]=c[pb>>2]<<1;pb=e+13688|0;c[pb>>2]=(c[pb>>2]|0)+1}}while(0);if(v){Fb=e+792|0;o=e+796|0;Ab=((c[o>>2]|0)-(c[Fb>>2]|0)<<3)+(32-(c[Pa>>2]|0))|0;Db=e+13700|0;Eb=c[Db>>2]|0;c[Db>>2]=Ab;Ra=e+13664|0;c[Ra>>2]=(c[Ra>>2]|0)-Eb+Ab;rNa(e,f,0,0,0,t);Ab=((c[o>>2]|0)-(c[Fb>>2]|0)<<3)+(32-(c[Pa>>2]|0))|0;Pa=c[Db>>2]|0;c[Db>>2]=Ab;Db=e+13676|0;c[Db>>2]=(c[Db>>2]|0)-Pa+Ab;i=j;return}else{rNa(e,f,0,0,0,t);i=j;return}}do{if((c[e+14404>>2]&8|0)==0){Ab=(c[e+180>>2]>>31)+32&-32;Pa=(c[e+184>>2]|0)>-1?Ab|16:Ab;Ab=(c[e+188>>2]|0)>-1?Pa|8:Pa;Pa=(c[e+192>>2]|0)>-1?Ab|4:Ab;Ab=(c[e+196>>2]|0)>-1?Pa|2:Pa;if(!((c[e+200>>2]|0)>-1)){Gb=Ab;break}Gb=Ab|1}else{Ab=(c[e+11740>>2]|0)==0;Pa=c[e+9984>>2]|0;Db=((Pa|0)!=0?8:0)|(Ab?0:16);Fb=(c[e+9972>>2]|0)>>>1;o=ba(d[1210784+Db|0]|0,Fb)|0;Eb=(o|0)==2147483647;Ra=ba(d[1210784+(Db|1)|0]|0,Fb)|0;Bb=c[e+13132>>2]|0;Cb=Ra+Bb|0;Ra=(Cb|0)<(o|0);zb=Ra?Cb:o;o=ba(d[1210784+(Db|2)|0]|0,Fb)|0;Cb=c[e+13128>>2]|0;yb=o+Cb|0;o=(yb|0)<(zb|0);xb=o?yb:zb;zb=Cb+Bb+(ba(d[1210784+(Db|3)|0]|0,Fb)|0)|0;Db=(zb|0)<(xb|0);Bb=Db?zb:xb;xb=e+13112|0;zb=e+13116|0;Cb=e+13120|0;yb=e+13124|0;mb=2147483647;nb=-1;vb=0;do{wb=ba(d[1211185+((vb^15)<<1)|0]|0,Fb)|0;if((vb&1|0)==0){Hb=wb}else{Hb=(c[yb>>2]|0)+wb|0}if((vb&2|0)==0){Ib=Hb}else{Ib=(c[Cb>>2]|0)+Hb|0}if((vb&4|0)==0){Jb=Ib}else{Jb=(c[zb>>2]|0)+Ib|0}if((vb&8|0)==0){Kb=Jb}else{Kb=(c[xb>>2]|0)+Jb|0}wb=(Kb|0)<(mb|0);mb=wb?Kb:mb;nb=wb?vb:nb;vb=vb+1|0;}while((vb|0)<16);vb=(nb<<2)+(Db?3:o?2:Ra?1:Eb<<31>>31)|0;if((h|g|Pa|0)!=0|Ab^1){Lb=vb}else{Lb=(Bb+(Fb<<1)+mb|0)>-1?0:vb}vb=e+10092|0;xb=e+14340|0;zb=e+180|0;do{if((c[zb>>2]|0)>-1){if((Lb&32|0)!=0){break}c[zb>>2]=-1;me[c[vb>>2]&511](c[xb>>2]|0)}}while(0);zb=e+184|0;do{if((c[zb>>2]|0)>-1){if((Lb&16|0)!=0){break}c[zb>>2]=-1;me[c[vb>>2]&511]((c[xb>>2]|0)+128|0)}}while(0);zb=e+188|0;do{if((c[zb>>2]|0)>-1){if((Lb&8|0)!=0){break}c[zb>>2]=-1;me[c[vb>>2]&511]((c[xb>>2]|0)+256|0)}}while(0);zb=e+192|0;do{if((c[zb>>2]|0)>-1){if((Lb&4|0)!=0){break}c[zb>>2]=-1;me[c[vb>>2]&511]((c[xb>>2]|0)+384|0)}}while(0);zb=e+196|0;do{if((c[zb>>2]|0)>-1){if((Lb&2|0)!=0){break}c[zb>>2]=-1;me[c[vb>>2]&511]((c[xb>>2]|0)+512|0)}}while(0);zb=e+200|0;if(!((c[zb>>2]|0)>-1)){Gb=Lb;break}if((Lb&1|0)!=0){Gb=Lb;break}c[zb>>2]=-1;me[c[vb>>2]&511]((c[xb>>2]|0)+640|0);Gb=Lb}}while(0);Lb=e+9984|0;c:do{if((h|g|Gb|c[Lb>>2]|0)==0){if((c[e+11740>>2]|0)!=0){break}Kb=e+68|0;Jb=c[Kb>>2]|0;do{if((Jb|0)>0){Ib=c[e+12476>>2]<<4;Hb=c[e+12480>>2]<<4;zb=e+148|0;mb=(ba(Hb,c[zb>>2]|0)|0)+Ib|0;Fb=c[e+5400>>2]|0;Bb=Fb+mb|0;Ab=e+9924|0;c[Ab>>2]=1;Pa=e+164|0;Eb=mb+16|0;Ra=Ib+16|0;o=e+8|0;Db=e+12|0;nb=e+9960|0;Cb=Hb+16|0;yb=e+10108|0;ra=0;z=Jb;while(1){if((ra|0)>=(z|0)){y=177;break}wb=ra+1|0;tb=c[(c[Pa>>2]|0)+(wb<<2)>>2]|0;if((tb|0)==0){y=177;break}if((c[tb+88>>2]|0)!=3){y=177;break}ub=c[tb>>2]|0;sb=(c[tb+2196>>2]|0)==0?Eb:mb;tb=c[o>>2]|0;qb=c[Db>>2]|0;if((Ra|0)>(tb|0)|(Cb|0)>(qb|0)){rb=tb-Ib|0;tb=(rb|0)<16?rb:16;rb=qb-Hb|0;qb=(rb|0)<16?rb:16;if((qb|0)>0&(tb|0)>0){rb=0;Fa=0;while(1){pb=ba(c[zb>>2]|0,Fa)|0;lb=rb;ob=0;do{eb=pb+ob|0;fb=(d[Fb+(eb+mb)|0]|0)-(d[ub+(eb+sb)|0]|0)|0;lb=((fb|0)>-1?fb:-fb|0)+lb|0;ob=ob+1|0;}while((ob|0)<(tb|0));ob=Fa+1|0;if((ob|0)<(qb|0)){rb=lb;Fa=ob}else{Mb=lb;break}}}else{Mb=0}Nb=(Mb<<8|0)/(ba(qb,tb)|0)|0}else{Nb=Pe[c[yb>>2]&255](0,Bb,ub+sb|0,c[zb>>2]|0,16)|0}if((Nb|0)>((c[nb>>2]|0)*70|0|0)){y=175;break}ra=wb;z=c[Kb>>2]|0}if((y|0)==175){c[Ab>>2]=0;break c}else if((y|0)==177){if((c[Ab>>2]|0)==1){break}else{break c}}}else{c[e+9924>>2]=1}}while(0);Kb=t|0;Jb=c[Kb>>2]|0;xb=e+788|0;vb=c[xb>>2]|0;if((vb|0)>1){Ob=vb-1|0;Pb=Jb<<1|1}else{z=fe(1>>>((1-vb|0)>>>0)|Jb<<vb|0)|0;Jb=e+796|0;ra=c[Jb>>2]|0;x=z;a[ra]=x;x=x>>8;a[ra+1|0]=x;x=x>>8;a[ra+2|0]=x;x=x>>8;a[ra+3|0]=x;c[Jb>>2]=(c[Jb>>2]|0)+4;Ob=vb+31|0;Pb=1}c[Kb>>2]=Pb;c[xb>>2]=Ob;if(v){xb=e+13696|0;c[xb>>2]=(c[xb>>2]|0)+1;xb=e+13700|0;c[xb>>2]=(c[xb>>2]|0)+1}xb=e+13692|0;c[xb>>2]=(c[xb>>2]|0)+1;i=j;return}}while(0);Ob=t|0;t=c[Ob>>2]|0;Pb=e+788|0;y=c[Pb>>2]|0;if((y|0)>1){Qb=y-1|0;Rb=t<<1}else{Nb=fe(t<<y|0)|0;t=e+796|0;Mb=c[t>>2]|0;x=Nb;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;Qb=y+31|0;Rb=0}c[Ob>>2]=Rb;c[Pb>>2]=Qb;y=Gb&3;t=Gb>>2^15;Mb=c[e+11740>>2]|0;if((Mb|0)==0){Nb=(c[Lb>>2]|0)==0?y:y|8;xb=d[1210784+Nb|0]|0;Kb=d[1210752+Nb|0]|0;if((Qb|0)>(xb|0)){Sb=Qb;Tb=Rb<<xb|Kb}else{Nb=fe(Kb>>>((xb-Qb|0)>>>0)|Rb<<Qb|0)|0;vb=e+796|0;Jb=c[vb>>2]|0;x=Nb;a[Jb]=x;x=x>>8;a[Jb+1|0]=x;x=x>>8;a[Jb+2|0]=x;x=x>>8;a[Jb+3|0]=x;c[vb>>2]=(c[vb>>2]|0)+4;Sb=Qb+32|0;Tb=Kb}c[Ob>>2]=Tb;c[Pb>>2]=Sb-xb;xb=d[1211185+(t<<1)|0]|0;Sb=d[1211184+(t<<1)|0]|0;Tb=u|0;Kb=c[Tb>>2]|0;vb=u+4|0;Jb=c[vb>>2]|0;if((Jb|0)>(xb|0)){Ub=Jb-xb|0;Vb=Kb<<xb|Sb}else{Nb=fe(Sb>>>((xb-Jb|0)>>>0)|Kb<<Jb|0)|0;Kb=u+12|0;ra=c[Kb>>2]|0;x=Nb;a[ra]=x;x=x>>8;a[ra+1|0]=x;x=x>>8;a[ra+2|0]=x;x=x>>8;a[ra+3|0]=x;c[Kb>>2]=(c[Kb>>2]|0)+4;Ub=32-xb+Jb|0;Vb=Sb}c[Tb>>2]=Vb;c[vb>>2]=Ub;Sb=c[Lb>>2]|0;if((Sb|0)==0){Wb=Ub;Xb=Vb}else{Jb=c[1349864+(Sb+2<<2)>>2]|0;if((Ub|0)>2){Yb=Ub-2|0;Zb=Vb<<2|Jb}else{Sb=fe(Vb<<Ub|Jb>>>((2-Ub|0)>>>0)|0)|0;Vb=u+12|0;xb=c[Vb>>2]|0;x=Sb;a[xb]=x;x=x>>8;a[xb+1|0]=x;x=x>>8;a[xb+2|0]=x;x=x>>8;a[xb+3|0]=x;c[Vb>>2]=(c[Vb>>2]|0)+4;Yb=Ub+30|0;Zb=Jb}c[Tb>>2]=Zb;c[vb>>2]=Yb;Wb=Yb;Xb=Zb}if((c[e+14152>>2]|0)==0){if((Gb|0)==0){_b=Wb;$b=Xb}else{Zb=c[e+14236>>2]|0;if((Wb|0)>1){ac=Wb-1|0;bc=Xb<<1|Zb}else{Yb=fe(Zb>>>((1-Wb|0)>>>0)|Xb<<Wb|0)|0;Xb=u+12|0;Jb=c[Xb>>2]|0;x=Yb;a[Jb]=x;x=x>>8;a[Jb+1|0]=x;x=x>>8;a[Jb+2|0]=x;x=x>>8;a[Jb+3|0]=x;c[Xb>>2]=(c[Xb>>2]|0)+4;ac=Wb+31|0;bc=Zb}c[Tb>>2]=bc;c[vb>>2]=ac;_b=ac;$b=bc}if((_b|0)>1){cc=_b-1|0;dc=$b<<1}else{bc=fe($b<<_b|0)|0;$b=u+12|0;ac=c[$b>>2]|0;x=bc;a[ac]=x;x=x>>8;a[ac+1|0]=x;x=x>>8;a[ac+2|0]=x;x=x>>8;a[ac+3|0]=x;c[$b>>2]=(c[$b>>2]|0)+4;cc=_b+31|0;dc=0}c[Tb>>2]=dc;c[vb>>2]=cc}if(v){cc=((c[e+796>>2]|0)-(c[e+792>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;vb=e+13700|0;dc=c[vb>>2]|0;c[vb>>2]=cc;vb=e+13696|0;c[vb>>2]=(c[vb>>2]|0)-dc+cc}Bca(e,0,0,k,l)|0;qNa(e,g-(c[k>>2]|0)|0,h-(c[l>>2]|0)|0,c[e+11556>>2]|0)}else if((Mb|0)==3){Mb=(c[Lb>>2]|0)==0?y:y|8;h=d[1210784+Mb|0]|0;g=d[1210752+Mb|0]|0;if((Qb|0)>(h|0)){ec=Qb;fc=Rb<<h|g}else{Mb=fe(g>>>((h-Qb|0)>>>0)|Rb<<Qb|0)|0;cc=e+796|0;dc=c[cc>>2]|0;x=Mb;a[dc]=x;x=x>>8;a[dc+1|0]=x;x=x>>8;a[dc+2|0]=x;x=x>>8;a[dc+3|0]=x;c[cc>>2]=(c[cc>>2]|0)+4;ec=Qb+32|0;fc=g}c[Ob>>2]=fc;c[Pb>>2]=ec-h;h=d[1211185+(t<<1)|0]|0;ec=d[1211184+(t<<1)|0]|0;fc=u|0;g=c[fc>>2]|0;cc=u+4|0;dc=c[cc>>2]|0;if((dc|0)>(h|0)){gc=dc-h|0;hc=g<<h|ec}else{Mb=fe(ec>>>((h-dc|0)>>>0)|g<<dc|0)|0;g=u+12|0;vb=c[g>>2]|0;x=Mb;a[vb]=x;x=x>>8;a[vb+1|0]=x;x=x>>8;a[vb+2|0]=x;x=x>>8;a[vb+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;gc=32-h+dc|0;hc=ec}c[fc>>2]=hc;c[cc>>2]=gc;ec=c[Lb>>2]|0;if((ec|0)==0){ic=gc;jc=hc}else{Lb=c[1349864+(ec+2<<2)>>2]|0;if((gc|0)>2){kc=gc-2|0;lc=hc<<2|Lb}else{ec=fe(hc<<gc|Lb>>>((2-gc|0)>>>0)|0)|0;hc=u+12|0;dc=c[hc>>2]|0;x=ec;a[dc]=x;x=x>>8;a[dc+1|0]=x;x=x>>8;a[dc+2|0]=x;x=x>>8;a[dc+3|0]=x;c[hc>>2]=(c[hc>>2]|0)+4;kc=gc+30|0;lc=Lb}c[fc>>2]=lc;c[cc>>2]=kc;ic=kc;jc=lc}if((Gb|0)==0){mc=ic;nc=jc}else{lc=c[e+14236>>2]|0;if((ic|0)>1){oc=ic-1|0;pc=jc<<1|lc}else{kc=fe(lc>>>((1-ic|0)>>>0)|jc<<ic|0)|0;jc=u+12|0;Lb=c[jc>>2]|0;x=kc;a[Lb]=x;x=x>>8;a[Lb+1|0]=x;x=x>>8;a[Lb+2|0]=x;x=x>>8;a[Lb+3|0]=x;c[jc>>2]=(c[jc>>2]|0)+4;oc=ic+31|0;pc=lc}c[fc>>2]=pc;c[cc>>2]=oc;mc=oc;nc=pc}if((mc|0)>1){qc=mc-1|0;rc=nc<<1|1}else{pc=fe(1>>>((1-mc|0)>>>0)|nc<<mc|0)|0;nc=u+12|0;oc=c[nc>>2]|0;x=pc;a[oc]=x;x=x>>8;a[oc+1|0]=x;x=x>>8;a[oc+2|0]=x;x=x>>8;a[oc+3|0]=x;c[nc>>2]=(c[nc>>2]|0)+4;qc=mc+31|0;rc=1}c[fc>>2]=rc;c[cc>>2]=qc;if(v){qc=((c[e+796>>2]|0)-(c[e+792>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;cc=e+13700|0;rc=c[cc>>2]|0;c[cc>>2]=qc;cc=e+13696|0;c[cc>>2]=(c[cc>>2]|0)-rc+qc}Bca(e,0,0,k,l)|0;c[l>>2]=(c[l>>2]|0)/2|0;qc=c[e+11808>>2]|0;rc=c[Ob>>2]|0;cc=c[Pb>>2]|0;if((cc|0)>1){sc=cc-1|0;tc=rc<<1|qc}else{fc=fe(qc>>>((1-cc|0)>>>0)|rc<<cc|0)|0;rc=e+796|0;mc=c[rc>>2]|0;x=fc;a[mc]=x;x=x>>8;a[mc+1|0]=x;x=x>>8;a[mc+2|0]=x;x=x>>8;a[mc+3|0]=x;c[rc>>2]=(c[rc>>2]|0)+4;sc=cc+31|0;tc=qc}c[Ob>>2]=tc;c[Pb>>2]=sc;qc=c[e+11812>>2]|0;if((sc|0)>1){uc=sc-1|0;vc=tc<<1|qc}else{cc=fe(tc<<sc|qc>>>((1-sc|0)>>>0)|0)|0;tc=e+796|0;rc=c[tc>>2]|0;x=cc;a[rc]=x;x=x>>8;a[rc+1|0]=x;x=x>>8;a[rc+2|0]=x;x=x>>8;a[rc+3|0]=x;c[tc>>2]=(c[tc>>2]|0)+4;uc=sc+31|0;vc=qc}c[Ob>>2]=vc;c[Pb>>2]=uc;uc=e+11556|0;qNa(e,(c[e+11744>>2]|0)-(c[k>>2]|0)|0,(c[e+11748>>2]|0)-(c[l>>2]|0)|0,c[uc>>2]|0);qNa(e,(c[e+11752>>2]|0)-(c[k>>2]|0)|0,(c[e+11756>>2]|0)-(c[l>>2]|0)|0,c[uc>>2]|0)}else{uc=y|16;y=d[1210784+uc|0]|0;vc=d[1210752+uc|0]|0;if((Qb|0)>(y|0)){wc=Qb;xc=Rb<<y|vc}else{uc=fe(vc>>>((y-Qb|0)>>>0)|Rb<<Qb|0)|0;Rb=e+796|0;qc=c[Rb>>2]|0;x=uc;a[qc]=x;x=x>>8;a[qc+1|0]=x;x=x>>8;a[qc+2|0]=x;x=x>>8;a[qc+3|0]=x;c[Rb>>2]=(c[Rb>>2]|0)+4;wc=Qb+32|0;xc=vc}c[Ob>>2]=xc;c[Pb>>2]=wc-y;y=d[1211185+(t<<1)|0]|0;wc=d[1211184+(t<<1)|0]|0;t=u|0;xc=c[t>>2]|0;Ob=u+4|0;vc=c[Ob>>2]|0;if((vc|0)>(y|0)){yc=vc-y|0;zc=xc<<y|wc}else{Qb=fe(wc>>>((y-vc|0)>>>0)|xc<<vc|0)|0;xc=u+12|0;Rb=c[xc>>2]|0;x=Qb;a[Rb]=x;x=x>>8;a[Rb+1|0]=x;x=x>>8;a[Rb+2|0]=x;x=x>>8;a[Rb+3|0]=x;c[xc>>2]=(c[xc>>2]|0)+4;yc=32-y+vc|0;zc=wc}c[t>>2]=zc;c[Ob>>2]=yc;if(!((c[e+14152>>2]|0)!=0|(Gb|0)==0)){Gb=c[e+14236>>2]|0;if((yc|0)>1){Ac=yc-1|0;Bc=zc<<1|Gb}else{wc=fe(zc<<yc|Gb>>>((1-yc|0)>>>0)|0)|0;zc=u+12|0;u=c[zc>>2]|0;x=wc;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[zc>>2]=(c[zc>>2]|0)+4;Ac=yc+31|0;Bc=Gb}c[t>>2]=Bc;c[Ob>>2]=Ac}if(v){Ac=((c[e+796>>2]|0)-(c[e+792>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;Ob=e+13700|0;Bc=c[Ob>>2]|0;c[Ob>>2]=Ac;Ob=e+13696|0;c[Ob>>2]=(c[Ob>>2]|0)-Bc+Ac}Ac=e+9148|0;Bc=e+11556|0;Bca(e,0,0,k,l)|0;Ob=c[e+12496>>2]|0;t=c[Ac>>2]|0;qNa(e,(b[t+(Ob<<2)>>1]|0)-(c[k>>2]|0)|0,(b[t+(Ob<<2)+2>>1]|0)-(c[l>>2]|0)|0,c[Bc>>2]|0);Bca(e,1,0,k,l)|0;Ob=c[e+12500>>2]|0;t=c[Ac>>2]|0;qNa(e,(b[t+(Ob<<2)>>1]|0)-(c[k>>2]|0)|0,(b[t+(Ob<<2)+2>>1]|0)-(c[l>>2]|0)|0,c[Bc>>2]|0);Bca(e,2,0,k,l)|0;Ob=c[e+12504>>2]|0;t=c[Ac>>2]|0;qNa(e,(b[t+(Ob<<2)>>1]|0)-(c[k>>2]|0)|0,(b[t+(Ob<<2)+2>>1]|0)-(c[l>>2]|0)|0,c[Bc>>2]|0);Bca(e,3,0,k,l)|0;Ob=c[e+12508>>2]|0;t=c[Ac>>2]|0;qNa(e,(b[t+(Ob<<2)>>1]|0)-(c[k>>2]|0)|0,(b[t+(Ob<<2)+2>>1]|0)-(c[l>>2]|0)|0,c[Bc>>2]|0)}if(v){v=e+792|0;Bc=e+796|0;l=((c[Bc>>2]|0)-(c[v>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;Ob=e+13700|0;t=c[Ob>>2]|0;c[Ob>>2]=l;k=e+13664|0;c[k>>2]=(c[k>>2]|0)-t+l;rNa(e,f,0,0,0,A);l=((c[Bc>>2]|0)-(c[v>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;Pb=c[Ob>>2]|0;c[Ob>>2]=l;Ob=e+13676|0;c[Ob>>2]=(c[Ob>>2]|0)-Pb+l}else{rNa(e,f,0,0,0,A)}A=e+13684|0;c[A>>2]=(c[A>>2]|0)+1;i=j;return}function qNa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((c[a+64>>2]&4|0)==0){Nlb(a,b,f);Nlb(a,e,f);return}if((b|0)==0){g=d[1172137]|0}else{h=27-f|0;g=(d[1172137+(((b<<h>>h)-1>>f-1)+1<<1)|0]|0)+f|0}if((e|0)==0){i=d[1172137]|0}else{h=27-f|0;i=(d[1172137+(((e<<h>>h)-1>>f-1)+1<<1)|0]|0)+f|0}f=a+788|0;h=(c[f>>2]|0)-(i+g)|0;g=a+796|0;c[g>>2]=(c[g>>2]|0)+(-(h>>5<<2)|0);c[f>>2]=h&31;return}function rNa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=(c[a+64>>2]&4|0)!=0;if((e|0)==0){i=a+368|0;if(h){j=a+788|0;k=a+796|0;l=DNa(a,b|0,0,0,i)|0;m=(c[j>>2]|0)-l|0;l=m>>5<<2;n=c[k>>2]|0;c[k>>2]=n+(-l|0);o=m&31;c[j>>2]=o;p=DNa(a,b+128|0,1,0,i)|0;q=l+(o-p>>5<<2)|0;c[k>>2]=n+(-q|0);o=m-p|0;p=o&31;c[j>>2]=p;m=DNa(a,b+256|0,2,0,i)|0;l=q+(p-m>>5<<2)|0;c[k>>2]=n+(-l|0);p=o-m|0;m=p&31;c[j>>2]=m;o=DNa(a,b+384|0,3,0,i)|0;q=l+(m-o>>5<<2)|0;c[k>>2]=n+(-q|0);m=p-o|0;o=m&31;c[j>>2]=o;p=DNa(a,b+512|0,4,0,i)|0;l=q+(o-p>>5<<2)|0;c[k>>2]=n+(-l|0);o=m-p|0;p=o&31;c[j>>2]=p;m=DNa(a,b+640|0,5,0,i)|0;c[k>>2]=n+(-(l+(p-m>>5<<2)|0)|0);c[j>>2]=o-m&31;return}else{ENa(a,b|0,0,0,i,f,g);ENa(a,b+128|0,1,0,i,f,g);ENa(a,b+256|0,2,0,i,f,g);ENa(a,b+384|0,3,0,i,f,g);ENa(a,b+512|0,4,0,i,f,g);ENa(a,b+640|0,5,0,i,f,g);return}}else{if(h){h=a+788|0;i=a+796|0;m=DNa(a,b|0,0,c[d>>2]|0,c[e>>2]|0)|0;o=(c[h>>2]|0)-m|0;m=o>>5<<2;j=c[i>>2]|0;c[i>>2]=j+(-m|0);p=o&31;c[h>>2]=p;l=DNa(a,b+128|0,1,c[d+4>>2]|0,c[e+4>>2]|0)|0;n=m+(p-l>>5<<2)|0;c[i>>2]=j+(-n|0);p=o-l|0;l=p&31;c[h>>2]=l;o=DNa(a,b+256|0,2,c[d+8>>2]|0,c[e+8>>2]|0)|0;m=n+(l-o>>5<<2)|0;c[i>>2]=j+(-m|0);l=p-o|0;o=l&31;c[h>>2]=o;p=DNa(a,b+384|0,3,c[d+12>>2]|0,c[e+12>>2]|0)|0;n=m+(o-p>>5<<2)|0;c[i>>2]=j+(-n|0);o=l-p|0;p=o&31;c[h>>2]=p;l=DNa(a,b+512|0,4,c[d+16>>2]|0,c[e+16>>2]|0)|0;m=n+(p-l>>5<<2)|0;c[i>>2]=j+(-m|0);p=o-l|0;l=p&31;c[h>>2]=l;o=DNa(a,b+640|0,5,c[d+20>>2]|0,c[e+20>>2]|0)|0;c[i>>2]=j+(-(m+(l-o>>5<<2)|0)|0);c[h>>2]=p-o&31;return}else{ENa(a,b|0,0,c[d>>2]|0,c[e>>2]|0,f,g);ENa(a,b+128|0,1,c[d+4>>2]|0,c[e+4>>2]|0,f,g);ENa(a,b+256|0,2,c[d+8>>2]|0,c[e+8>>2]|0,f,g);ENa(a,b+384|0,3,c[d+12>>2]|0,c[e+12>>2]|0,f,g);ENa(a,b+512|0,4,c[d+16>>2]|0,c[e+16>>2]|0,f,g);ENa(a,b+640|0,5,c[d+20>>2]|0,c[e+20>>2]|0,f,g);return}}}function sNa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=a+180|0;j=h;c[i>>2]=c[j>>2];c[i+4>>2]=c[j+4>>2];c[i+8>>2]=c[j+8>>2];c[i+12>>2]=c[j+12>>2];c[i+16>>2]=c[j+16>>2];c[i+20>>2]=c[j+20>>2];j=a+9912|0;i=a+368|0;h=0;do{k=c[j>>2]|0;l=c[a+12496+(h<<2)>>2]<<4;c[g+(h<<2)>>2]=i;if((c[f+(h<<2)>>2]|0)==0){b[e+(h<<7)+((d[a+11192|0]|0)<<1)>>1]=b[k+((l|1)<<1)>>1]|0;b[e+(h<<7)+((d[a+11200|0]|0)<<1)>>1]=b[k+((l|2)<<1)>>1]|0;b[e+(h<<7)+((d[a+11208|0]|0)<<1)>>1]=b[k+((l|3)<<1)>>1]|0;b[e+(h<<7)+((d[a+11216|0]|0)<<1)>>1]=b[k+((l|4)<<1)>>1]|0;b[e+(h<<7)+((d[a+11224|0]|0)<<1)>>1]=b[k+((l|5)<<1)>>1]|0;b[e+(h<<7)+((d[a+11232|0]|0)<<1)>>1]=b[k+((l|6)<<1)>>1]|0;b[e+(h<<7)+((d[a+11240|0]|0)<<1)>>1]=b[k+((l|7)<<1)>>1]|0}else{b[e+(h<<7)+((d[a+11185|0]|0)<<1)>>1]=b[k+((l|9)<<1)>>1]|0;b[e+(h<<7)+((d[a+11186|0]|0)<<1)>>1]=b[k+((l|10)<<1)>>1]|0;b[e+(h<<7)+((d[a+11187|0]|0)<<1)>>1]=b[k+((l|11)<<1)>>1]|0;b[e+(h<<7)+((d[a+11188|0]|0)<<1)>>1]=b[k+((l|12)<<1)>>1]|0;b[e+(h<<7)+((d[a+11189|0]|0)<<1)>>1]=b[k+((l|13)<<1)>>1]|0;b[e+(h<<7)+((d[a+11190|0]|0)<<1)>>1]=b[k+((l|14)<<1)>>1]|0;b[e+(h<<7)+((d[a+11191|0]|0)<<1)>>1]=b[k+((l|15)<<1)>>1]|0}h=h+1|0;}while((h|0)<6);return}function tNa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b|0;e=c[d>>2]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)>1){h=g-1|0;i=e<<1}else{j=fe(e<<g|0)|0;e=b+12|0;k=c[e>>2]|0;x=j;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[e>>2]=(c[e>>2]|0)+4;h=g+31|0;i=0}c[d>>2]=i;c[f>>2]=h;g=h&7;if((g|0)==0){return}e=(1<<g)-1|0;if((h|0)>(g|0)){l=h;m=i<<g|e}else{k=fe(i<<h|e>>>((g-h|0)>>>0)|0)|0;i=b+12|0;b=c[i>>2]|0;x=k;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;l=h+32|0;m=e}c[d>>2]=m;c[f>>2]=l-g;return}function uNa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((c[a+9992>>2]|0)==3){UMa(a);return}b=a+13852|0;c[a+13848>>2]=c[b>>2];d=a+13856|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=0;g=c[(c[a+4>>2]|0)+108>>2]|0;if((f|0)>(d|0)|(f|0)==(d|0)&e>>>0>0>>>0){h=f;i=e}else{d=YGb(e,f,1,0)|0;f=ZGb(d,F,g,(g|0)<0|0?-1:0)|0;h=F;i=f}f=eHb(i,h,g,(g|0)<0|0?-1:0)|0;c[b>>2]=f;return}function vNa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;e=i;f=b+9992|0;do{if((c[f>>2]|0)==1){g=b+60|0;do{if((c[g>>2]&4194304|0)==0){h=b+80|0;j=c[h>>2]|0;if((j|0)<2){wNa(b);k=c[h>>2]|0}else{k=j}if(!((k|0)<2|(d|0)==0)){break}xNa(b)}}while(0);if((c[b+84>>2]&8192|0)!=0){break}j=b+784|0;h=c[j>>2]|0;l=b+788|0;m=c[l>>2]|0;if((m|0)>16){n=m-16|0;o=h<<16}else{p=fe(h<<m|0)|0;h=b+796|0;q=c[h>>2]|0;x=p;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;n=m+16|0;o=0}c[j>>2]=o;c[l>>2]=n;if((n|0)>16){r=n-16|0}else{m=fe(435>>>((16-n|0)>>>0)|o<<n|0)|0;h=b+796|0;q=c[h>>2]|0;x=m;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;r=n+16|0}c[j>>2]=435;c[l>>2]=r;h=(c[b+9856>>2]|0)+136|0;q=c[h>>2]|0;m=c[h+4>>2]|0;h=c[(c[b+164>>2]|0)+4>>2]|0;if((h|0)==0){s=m;t=q}else{p=h+136|0;h=c[p>>2]|0;u=c[p+4>>2]|0;p=(m|0)>(u|0)|(m|0)==(u|0)&q>>>0>h>>>0;s=p?u:m;t=p?h:q}q=c[b+4>>2]|0;h=c[q+104>>2]|0;p=gHb(h,(h|0)<0|0?-1:0,t,s)|0;h=F;m=0;u=q+108|0;q=c[u>>2]|0;v=q;w=(q|0)<0|0?-1:0;if((h|0)>(m|0)|(h|0)==(m|0)&p>>>0>0>>>0){m=eHb(p,h,v,w)|0;c[b+13848>>2]=m;y=h;z=p;A=c[u>>2]|0}else{m=ZGb(1,0,v,w)|0;q=YGb(m,F,p,h)|0;m=eHb(q,F,v,w)|0;c[b+13848>>2]=m;m=c[u>>2]|0;u=YGb(p,h,1,0)|0;h=ZGb(u,F,m,(m|0)<0|0?-1:0)|0;y=F;z=h;A=m}m=eHb(z,y,A,(A|0)<0|0?-1:0)|0;h=m;m=(h|0)>0?h:h-59|0;u=(m|0)/60|0;p=((m|0)%60|0)-m+h|0;h=(m|0)>59?u:u-59|0;m=(h|0)/60|0;w=((h|0)%60|0)-h+u|0;u=(h|0)>59?m:m-23|0;h=((u|0)%24|0)-u+m|0;if((r|0)>5){B=r-5|0;C=h|13920}else{m=fe(h>>>((5-r|0)>>>0)|435<<r|0)|0;u=b+796|0;v=c[u>>2]|0;x=m;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;B=r+27|0;C=h}c[j>>2]=C;c[l>>2]=B;if((B|0)>6){D=B-6|0;E=C<<6|w}else{h=fe(w>>>((6-B|0)>>>0)|C<<B|0)|0;u=b+796|0;v=c[u>>2]|0;x=h;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;D=B+26|0;E=w}c[j>>2]=E;c[l>>2]=D;if((D|0)>1){G=D-1|0;H=E<<1|1}else{w=fe(1>>>((1-D|0)>>>0)|E<<D|0)|0;u=b+796|0;v=c[u>>2]|0;x=w;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;G=D+31|0;H=1}c[j>>2]=H;c[l>>2]=G;if((G|0)>6){I=G-6|0;J=H<<6|p}else{u=fe(p>>>((6-G|0)>>>0)|H<<G|0)|0;v=b+796|0;w=c[v>>2]|0;x=u;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;I=G+26|0;J=p}c[j>>2]=J;c[l>>2]=I;p=(c[g>>2]|0)>>>31;if((I|0)>1){K=I-1|0;L=p|J<<1}else{v=fe(p>>>((1-I|0)>>>0)|J<<I|0)|0;w=b+796|0;u=c[w>>2]|0;x=v;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;K=I+31|0;L=p}c[j>>2]=L;c[l>>2]=K;if((K|0)>1){M=K-1|0;N=L<<1}else{p=fe(L<<K|0)|0;w=b+796|0;u=c[w>>2]|0;x=p;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;M=K+31|0;N=0}c[j>>2]=N;c[l>>2]=M;if((M|0)>1){O=M-1|0;P=N<<1}else{w=fe(N<<M|0)|0;u=b+796|0;p=c[u>>2]|0;x=w;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;O=M+31|0;P=0}c[j>>2]=P;c[l>>2]=O;u=O&7;if((u|0)==0){break}p=(1<<u)-1|0;if((O|0)>(u|0)){Q=O;R=p|P<<u}else{w=fe(p>>>((u-O|0)>>>0)|P<<O|0)|0;v=b+796|0;h=c[v>>2]|0;x=w;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;Q=O+32|0;R=p}c[j>>2]=R;c[l>>2]=Q-u}}while(0);if((c[b+13936>>2]|0)==0){S=0}else{S=(c[f>>2]|0)!=3|0}c[b+13940>>2]=S;S=b+784|0;Q=c[S>>2]|0;R=b+788|0;O=c[R>>2]|0;if((O|0)>16){T=O-16|0;U=Q<<16}else{P=fe(Q<<O|0)|0;Q=b+796|0;M=c[Q>>2]|0;x=P;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;T=O+16|0;U=0}c[S>>2]=U;c[R>>2]=T;if((T|0)>16){V=T-16|0}else{O=fe(438>>>((16-T|0)>>>0)|U<<T|0)|0;U=b+796|0;Q=c[U>>2]|0;x=O;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[U>>2]=(c[U>>2]|0)+4;V=T+16|0}c[S>>2]=438;c[R>>2]=V;T=(c[f>>2]|0)-1|0;if((V|0)>2){W=V-2|0;X=T|1752}else{U=fe(T>>>((2-V|0)>>>0)|438<<V|0)|0;Q=b+796|0;O=c[Q>>2]|0;x=U;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;W=V+30|0;X=T}c[S>>2]=X;c[R>>2]=W;T=b+13856|0;V=c[T>>2]|0;Q=c[T+4>>2]|0;T=0;O=c[(c[b+4>>2]|0)+108>>2]|0;U=O;M=(O|0)<0|0?-1:0;if((Q|0)>(T|0)|(Q|0)==(T|0)&V>>>0>0>>>0){T=eHb(V,Q,U,M)|0;Y=Q;Z=V;_=M;$=U;aa=T}else{T=YGb(V,Q,1,0)|0;P=ZGb(T,F,U,M)|0;M=O;U=(O|0)<0|0?-1:0;O=eHb(P,F,M,U)|0;P=ZGb(1,0,M,U)|0;T=YGb(P,F,V,Q)|0;Y=F;Z=T;_=U;$=M;aa=O}O=fHb(Z,Y,$,_)|0;_=ZGb(O,F,Z,Y)|0;Y=YGb(V,Q,_,F)|0;_=Y;Y=c[b+13848>>2]|0;Q=aa-Y|0;if(!((Q|0)>-1)){yDb(0,0,2251480,(V=i,i=i+24|0,c[V>>2]=2320488,c[V+8>>2]=2185112,c[V+16>>2]=1113,V)|0);i=V;Cd()}if((aa|0)==(Y|0)){ba=X;ca=W}else{Y=b+796|0;aa=Q;Q=X;X=W;while(1){W=aa-1|0;if((X|0)>1){da=X-1|0;ea=Q<<1|1}else{V=fe(1>>>((1-X|0)>>>0)|Q<<X|0)|0;Z=c[Y>>2]|0;x=V;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;c[Y>>2]=(c[Y>>2]|0)+4;da=X+31|0;ea=1}c[S>>2]=ea;c[R>>2]=da;if((W|0)==0){ba=ea;ca=da;break}else{aa=W;Q=ea;X=da}}}if((ca|0)>1){fa=ca-1|0;ga=ba<<1}else{da=fe(ba<<ca|0)|0;ba=b+796|0;X=c[ba>>2]|0;x=da;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;c[ba>>2]=(c[ba>>2]|0)+4;fa=ca+31|0;ga=0}c[S>>2]=ga;c[R>>2]=fa;if((fa|0)>1){ha=fa-1|0;ia=ga<<1|1}else{ca=fe(1>>>((1-fa|0)>>>0)|ga<<fa|0)|0;ga=b+796|0;ba=c[ga>>2]|0;x=ca;a[ba]=x;x=x>>8;a[ba+1|0]=x;x=x>>8;a[ba+2|0]=x;x=x>>8;a[ba+3|0]=x;c[ga>>2]=(c[ga>>2]|0)+4;ha=fa+31|0;ia=1}c[S>>2]=ia;c[R>>2]=ha;fa=c[b+13844>>2]|0;if((ha|0)>(fa|0)){ja=ha;ka=ia<<fa|_}else{ga=fe(_>>>((fa-ha|0)>>>0)|ia<<ha|0)|0;ia=b+796|0;ba=c[ia>>2]|0;x=ga;a[ba]=x;x=x>>8;a[ba+1|0]=x;x=x>>8;a[ba+2|0]=x;x=x>>8;a[ba+3|0]=x;c[ia>>2]=(c[ia>>2]|0)+4;ja=ha+32|0;ka=_}_=ja-fa|0;c[S>>2]=ka;c[R>>2]=_;if((_|0)>1){la=_-1|0;ma=ka<<1|1}else{fa=fe(1>>>((1-_|0)>>>0)|ka<<_|0)|0;ka=b+796|0;ja=c[ka>>2]|0;x=fa;a[ja]=x;x=x>>8;a[ja+1|0]=x;x=x>>8;a[ja+2|0]=x;x=x>>8;a[ja+3|0]=x;c[ka>>2]=(c[ka>>2]|0)+4;la=_+31|0;ma=1}c[S>>2]=ma;c[R>>2]=la;if((la|0)>1){na=la-1|0;oa=ma<<1|1}else{_=fe(1>>>((1-la|0)>>>0)|ma<<la|0)|0;ma=b+796|0;ka=c[ma>>2]|0;x=_;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;c[ma>>2]=(c[ma>>2]|0)+4;na=la+31|0;oa=1}c[S>>2]=oa;c[R>>2]=na;if((c[f>>2]|0)==2){la=c[b+12472>>2]|0;if((na|0)>1){pa=na-1|0;qa=oa<<1|la}else{ma=fe(oa<<na|la>>>((1-na|0)>>>0)|0)|0;ka=b+796|0;_=c[ka>>2]|0;x=ma;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;c[ka>>2]=(c[ka>>2]|0)+4;pa=na+31|0;qa=la}c[S>>2]=qa;c[R>>2]=pa;ra=pa;sa=qa}else{ra=na;sa=oa}if((ra|0)>3){ta=ra-3|0;ua=sa<<3}else{oa=fe(sa<<ra|0)|0;sa=b+796|0;na=c[sa>>2]|0;x=oa;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[sa>>2]=(c[sa>>2]|0)+4;ta=ra+29|0;ua=0}c[S>>2]=ua;c[R>>2]=ta;if((c[b+14152>>2]|0)==0){ra=c[(c[b+9856>>2]|0)+300>>2]|0;if((ta|0)>1){va=ta-1|0;wa=ua<<1|ra}else{sa=fe(ua<<ta|ra>>>((1-ta|0)>>>0)|0)|0;na=b+796|0;oa=c[na>>2]|0;x=sa;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;c[na>>2]=(c[na>>2]|0)+4;va=ta+31|0;wa=ra}c[S>>2]=wa;c[R>>2]=va;ra=c[b+14200>>2]|0;if((va|0)>1){xa=va-1|0;ya=wa<<1|ra}else{na=fe(wa<<va|ra>>>((1-va|0)>>>0)|0)|0;wa=b+796|0;oa=c[wa>>2]|0;x=na;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;c[wa>>2]=(c[wa>>2]|0)+4;xa=va+31|0;ya=ra}c[S>>2]=ya;c[R>>2]=xa;za=xa;Aa=ya}else{za=ta;Aa=ua}ua=c[b+9960>>2]|0;if((za|0)>5){Ba=za-5|0;Ca=Aa<<5|ua}else{ta=fe(Aa<<za|ua>>>((5-za|0)>>>0)|0)|0;Aa=b+796|0;ya=c[Aa>>2]|0;x=ta;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;Ba=za+27|0;Ca=ua}c[S>>2]=Ca;c[R>>2]=Ba;ua=c[f>>2]|0;if((ua|0)==1){i=e;return}za=c[b+11556>>2]|0;if((Ba|0)>3){Da=Ba-3|0;Ea=Ca<<3|za;Fa=ua}else{ua=fe(Ca<<Ba|za>>>((3-Ba|0)>>>0)|0)|0;Ca=b+796|0;Aa=c[Ca>>2]|0;x=ua;a[Aa]=x;x=x>>8;a[Aa+1|0]=x;x=x>>8;a[Aa+2|0]=x;x=x>>8;a[Aa+3|0]=x;c[Ca>>2]=(c[Ca>>2]|0)+4;Da=Ba+29|0;Ea=za;Fa=c[f>>2]|0}c[S>>2]=Ea;c[R>>2]=Da;if((Fa|0)!=3){i=e;return}Fa=c[b+11560>>2]|0;if((Da|0)>3){Ga=Da-3|0;Ha=Ea<<3|Fa}else{f=fe(Fa>>>((3-Da|0)>>>0)|Ea<<Da|0)|0;Ea=b+796|0;b=c[Ea>>2]|0;x=f;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[Ea>>2]=(c[Ea>>2]|0)+4;Ga=Da+29|0;Ha=Fa}c[S>>2]=Ha;c[R>>2]=Ga;i=e;return}function wNa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=c[b+4>>2]|0;e=c[d+840>>2]|0;do{if((e|0)==-99){if((c[b+68>>2]|0)!=0){f=240;break}f=(c[b+13924>>2]|0)==0?0:240}else{f=e<<4}}while(0);e=c[d+844>>2]|0;d=((e|0)==-99?1:e)|f;f=(d&-16|0)==240?5:1;e=b+784|0;g=c[e>>2]|0;h=b+788|0;i=c[h>>2]|0;if((i|0)>16){j=i-16|0;k=g<<16}else{l=fe(g<<i|0)|0;g=b+796|0;m=c[g>>2]|0;x=l;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;j=i+16|0;k=0}c[e>>2]=k;c[h>>2]=j;if((j|0)>16){n=j-16|0}else{i=fe(432>>>((16-j|0)>>>0)|k<<j|0)|0;k=b+796|0;g=c[k>>2]|0;x=i;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;n=j+16|0}c[e>>2]=432;c[h>>2]=n;if((n|0)>8){o=n-8|0;p=d|110592}else{j=fe(d>>>((8-n|0)>>>0)|432<<n|0)|0;k=b+796|0;g=c[k>>2]|0;x=j;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;o=n+24|0;p=d}c[e>>2]=p;c[h>>2]=o;if((o|0)>16){q=o-16|0;r=p<<16}else{d=fe(p<<o|0)|0;p=b+796|0;n=c[p>>2]|0;x=d;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;q=o+16|0;r=0}c[e>>2]=r;c[h>>2]=q;if((q|0)>16){s=q-16|0}else{o=fe(437>>>((16-q|0)>>>0)|r<<q|0)|0;r=b+796|0;p=c[r>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;s=q+16|0}c[e>>2]=437;c[h>>2]=s;if((s|0)>1){t=s-1|0;u=875}else{q=fe(1>>>((1-s|0)>>>0)|437<<s|0)|0;r=b+796|0;p=c[r>>2]|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;t=s+31|0;u=1}c[e>>2]=u;c[h>>2]=t;if((t|0)>4){v=t-4|0;w=u<<4|f}else{s=fe(f>>>((4-t|0)>>>0)|u<<t|0)|0;u=b+796|0;r=c[u>>2]|0;x=s;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=t+28|0;w=f}c[e>>2]=w;c[h>>2]=v;if((v|0)>3){y=v-3|0;z=w<<3|1}else{f=fe(1>>>((3-v|0)>>>0)|w<<v|0)|0;w=b+796|0;t=c[w>>2]|0;x=f;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;y=v+29|0;z=1}c[e>>2]=z;c[h>>2]=y;if((y|0)>4){A=y-4|0;B=z<<4|1}else{v=fe(1>>>((4-y|0)>>>0)|z<<y|0)|0;z=b+796|0;w=c[z>>2]|0;x=v;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;A=y+28|0;B=1}c[e>>2]=B;c[h>>2]=A;if((A|0)>1){C=A-1|0;D=B<<1}else{y=fe(B<<A|0)|0;B=b+796|0;z=c[B>>2]|0;x=y;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;C=A+31|0;D=0}c[e>>2]=D;c[h>>2]=C;if((C|0)>1){E=C-1|0;F=D<<1}else{A=fe(D<<C|0)|0;D=b+796|0;B=c[D>>2]|0;x=A;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;E=C+31|0;F=0}c[e>>2]=F;c[h>>2]=E;C=E&7;if((C|0)==0){return}D=(1<<C)-1|0;if((E|0)>(C|0)){G=E;H=D|F<<C}else{B=fe(D>>>((C-E|0)>>>0)|F<<E|0)|0;F=b+796|0;b=c[F>>2]|0;x=B;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[F>>2]=(c[F>>2]|0)+4;G=E+32|0;H=D}c[e>>2]=H;c[h>>2]=G-C;return}function xNa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0;do{if((c[b+68>>2]|0)==0){if((c[b+13924>>2]|0)!=0){d=3;break}c[b+13948>>2]=1;e=1}else{d=3}}while(0);if((d|0)==3){c[b+13948>>2]=17;e=5}d=b+784|0;f=d|0;g=c[f>>2]|0;h=b+788|0;i=c[h>>2]|0;if((i|0)>16){j=i-16|0;k=g<<16}else{l=fe(g<<i|0)|0;g=b+796|0;m=c[g>>2]|0;x=l;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;j=i+16|0;k=0}c[f>>2]=k;c[h>>2]=j;if((j|0)>16){n=j-16|0}else{i=fe(256>>>((16-j|0)>>>0)|k<<j|0)|0;k=b+796|0;g=c[k>>2]|0;x=i;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;n=j+16|0}c[f>>2]=256;c[h>>2]=n;if((n|0)>16){o=n-16|0;p=16777216}else{j=fe(256<<n|0)|0;k=b+796|0;g=c[k>>2]|0;x=j;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;o=n+16|0;p=0}c[f>>2]=p;c[h>>2]=o;if((o|0)>16){q=o-16|0}else{n=fe(288>>>((16-o|0)>>>0)|p<<o|0)|0;p=b+796|0;k=c[p>>2]|0;x=n;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;q=o+16|0}c[f>>2]=288;c[h>>2]=q;if((q|0)>1){r=q-1|0;s=576}else{o=fe(288<<q|0)|0;p=b+796|0;k=c[p>>2]|0;x=o;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;r=q+31|0;s=0}c[f>>2]=s;c[h>>2]=r;q=c[b+13948>>2]|0;if((r|0)>8){t=r-8|0;u=s<<8|q}else{p=fe(s<<r|q>>>((8-r|0)>>>0)|0)|0;s=b+796|0;k=c[s>>2]|0;x=p;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;t=r+24|0;u=q}c[f>>2]=u;c[h>>2]=t;q=b+84|0;r=(t|0)>1;do{if((c[q>>2]&8192|0)==0){if(r){v=t-1|0;w=u<<1|1}else{s=fe(u<<t|1>>>((1-t|0)>>>0)|0)|0;k=b+796|0;p=c[k>>2]|0;x=s;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;v=t+31|0;w=1}c[f>>2]=w;c[h>>2]=v;if((v|0)>4){y=v-4|0;z=w<<4|e}else{k=fe(e>>>((4-v|0)>>>0)|w<<v|0)|0;p=b+796|0;s=c[p>>2]|0;x=k;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;y=v+28|0;z=e}c[f>>2]=z;c[h>>2]=y;if((y|0)>3){A=y-3|0;B=z<<3|1;break}else{p=fe(1>>>((3-y|0)>>>0)|z<<y|0)|0;s=b+796|0;k=c[s>>2]|0;x=p;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;A=y+29|0;B=1;break}}else{if(r){A=t-1|0;B=u<<1;break}else{s=fe(u<<t|0)|0;k=b+796|0;p=c[k>>2]|0;x=s;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;A=t+31|0;B=0;break}}}while(0);c[f>>2]=B;c[h>>2]=A;A=b+4|0;B=Glb((c[A>>2]|0)+224|0)|0;t=b+13928|0;c[t>>2]=B;u=c[f>>2]|0;r=c[h>>2]|0;if((r|0)>4){C=r-4|0;D=u<<4|B;E=B}else{y=fe(B>>>((4-r|0)>>>0)|u<<r|0)|0;u=b+796|0;z=c[u>>2]|0;x=y;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;C=r+28|0;D=B;E=c[t>>2]|0}c[f>>2]=D;c[h>>2]=C;if((E|0)==15){E=c[A>>2]|0;t=E+224|0;B=E+228|0;E=c[t>>2]|0;r=c[B>>2]|0;iFb(t,B,E,(E|0)<0|0?-1:0,r,(r|0)<0|0?-1:0,255,0)|0;r=c[A>>2]|0;E=c[r+224>>2]|0;B=c[f>>2]|0;t=c[h>>2]|0;if((t|0)>8){F=t-8|0;G=B<<8|E;H=r}else{r=fe(E>>>((8-t|0)>>>0)|B<<t|0)|0;B=b+796|0;u=c[B>>2]|0;x=r;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;F=t+24|0;G=E;H=c[A>>2]|0}c[f>>2]=G;c[h>>2]=F;E=c[H+228>>2]|0;if((F|0)>8){I=F-8|0;J=G<<8|E}else{H=fe(G<<F|E>>>((8-F|0)>>>0)|0)|0;G=b+796|0;t=c[G>>2]|0;x=H;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;I=F+24|0;J=E}c[f>>2]=J;c[h>>2]=I;K=J;L=I}else{K=D;L=C}C=(L|0)>1;do{if((c[q>>2]&8192|0)==0){if(C){M=L-1|0;N=K<<1|1}else{D=fe(1>>>((1-L|0)>>>0)|K<<L|0)|0;I=b+796|0;J=c[I>>2]|0;x=D;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;M=L+31|0;N=1}c[f>>2]=N;c[h>>2]=M;if((M|0)>2){O=M-2|0;P=N<<2|1}else{I=fe(1>>>((2-M|0)>>>0)|N<<M|0)|0;J=b+796|0;D=c[J>>2]|0;x=I;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[J>>2]=(c[J>>2]|0)+4;O=M+30|0;P=1}c[f>>2]=P;c[h>>2]=O;J=c[b+13944>>2]|0;if((O|0)>1){Q=O-1|0;R=P<<1|J}else{D=fe(P<<O|J>>>((1-O|0)>>>0)|0)|0;I=b+796|0;E=c[I>>2]|0;x=D;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;Q=O+31|0;R=J}c[f>>2]=R;c[h>>2]=Q;if((Q|0)>1){S=Q-1|0;T=R<<1;break}else{J=fe(R<<Q|0)|0;I=b+796|0;E=c[I>>2]|0;x=J;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;S=Q+31|0;T=0;break}}else{if(C){S=L-1|0;T=K<<1;break}else{I=fe(K<<L|0)|0;E=b+796|0;J=c[E>>2]|0;x=I;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;S=L+31|0;T=0;break}}}while(0);c[f>>2]=T;c[h>>2]=S;if((S|0)>2){U=S-2|0;V=T<<2}else{L=fe(T<<S|0)|0;T=b+796|0;K=c[T>>2]|0;x=L;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[T>>2]=(c[T>>2]|0)+4;U=S+30|0;V=0}c[f>>2]=V;c[h>>2]=U;if((U|0)>1){W=U-1|0;X=V<<1|1}else{S=fe(1>>>((1-U|0)>>>0)|V<<U|0)|0;V=b+796|0;T=c[V>>2]|0;x=S;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[V>>2]=(c[V>>2]|0)+4;W=U+31|0;X=1}c[f>>2]=X;c[h>>2]=W;U=c[(c[A>>2]|0)+108>>2]|0;if((W|0)>16){Y=W-16|0;Z=X<<16|U}else{V=fe(X<<W|U>>>((16-W|0)>>>0)|0)|0;X=b+796|0;T=c[X>>2]|0;x=V;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[X>>2]=(c[X>>2]|0)+4;Y=W+16|0;Z=U}c[f>>2]=Z;c[h>>2]=Y;U=b+13844|0;if((c[U>>2]|0)<1){c[U>>2]=1}if((Y|0)>1){_=Y-1|0;$=Z<<1|1}else{U=fe(1>>>((1-Y|0)>>>0)|Z<<Y|0)|0;Z=b+796|0;W=c[Z>>2]|0;x=U;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;c[Z>>2]=(c[Z>>2]|0)+4;_=Y+31|0;$=1}c[f>>2]=$;c[h>>2]=_;if((_|0)>1){aa=_-1|0;ba=$<<1}else{Y=fe($<<_|0)|0;$=b+796|0;Z=c[$>>2]|0;x=Y;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;c[$>>2]=(c[$>>2]|0)+4;aa=_+31|0;ba=0}c[f>>2]=ba;c[h>>2]=aa;if((aa|0)>1){ca=aa-1|0;da=ba<<1|1}else{_=fe(1>>>((1-aa|0)>>>0)|ba<<aa|0)|0;ba=b+796|0;$=c[ba>>2]|0;x=_;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;c[ba>>2]=(c[ba>>2]|0)+4;ca=aa+31|0;da=1}c[f>>2]=da;c[h>>2]=ca;aa=c[b+8>>2]|0;if((ca|0)>13){ea=ca-13|0;fa=da<<13|aa}else{ba=fe(da<<ca|aa>>>((13-ca|0)>>>0)|0)|0;da=b+796|0;$=c[da>>2]|0;x=ba;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;c[da>>2]=(c[da>>2]|0)+4;ea=ca+19|0;fa=aa}c[f>>2]=fa;c[h>>2]=ea;if((ea|0)>1){ga=ea-1|0;ha=fa<<1|1}else{aa=fe(1>>>((1-ea|0)>>>0)|fa<<ea|0)|0;fa=b+796|0;ca=c[fa>>2]|0;x=aa;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;c[fa>>2]=(c[fa>>2]|0)+4;ga=ea+31|0;ha=1}c[f>>2]=ha;c[h>>2]=ga;ea=c[b+12>>2]|0;if((ga|0)>13){ia=ga-13|0;ja=ha<<13|ea}else{fa=fe(ha<<ga|ea>>>((13-ga|0)>>>0)|0)|0;ha=b+796|0;ca=c[ha>>2]|0;x=fa;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;c[ha>>2]=(c[ha>>2]|0)+4;ia=ga+19|0;ja=ea}c[f>>2]=ja;c[h>>2]=ia;if((ia|0)>1){ka=ia-1|0;la=ja<<1|1}else{ea=fe(1>>>((1-ia|0)>>>0)|ja<<ia|0)|0;ja=b+796|0;ga=c[ja>>2]|0;x=ea;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[ja>>2]=(c[ja>>2]|0)+4;ka=ia+31|0;la=1}c[f>>2]=la;c[h>>2]=ka;ia=(c[b+14152>>2]|0)==0|0;if((ka|0)>1){ma=ka-1|0;na=la<<1|ia}else{ja=fe(ia>>>((1-ka|0)>>>0)|la<<ka|0)|0;la=b+796|0;ga=c[la>>2]|0;x=ja;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;c[la>>2]=(c[la>>2]|0)+4;ma=ka+31|0;na=ia}c[f>>2]=na;c[h>>2]=ma;if((ma|0)>1){oa=ma-1|0;pa=na<<1|1}else{ia=fe(1>>>((1-ma|0)>>>0)|na<<ma|0)|0;na=b+796|0;ka=c[na>>2]|0;x=ia;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;c[na>>2]=(c[na>>2]|0)+4;oa=ma+31|0;pa=1}c[f>>2]=pa;c[h>>2]=oa;do{if((e|0)==1){if((oa|0)>1){qa=oa-1|0;ra=pa<<1;break}else{ma=fe(pa<<oa|0)|0;na=b+796|0;ka=c[na>>2]|0;x=ma;a[ka]=x;x=x>>8;a[ka+1|0]=x;x=x>>8;a[ka+2|0]=x;x=x>>8;a[ka+3|0]=x;c[na>>2]=(c[na>>2]|0)+4;qa=oa+31|0;ra=0;break}}else{if((oa|0)>2){qa=oa-2|0;ra=pa<<2;break}else{na=fe(pa<<oa|0)|0;ka=b+796|0;ma=c[ka>>2]|0;x=na;a[ma]=x;x=x>>8;a[ma+1|0]=x;x=x>>8;a[ma+2|0]=x;x=x>>8;a[ma+3|0]=x;c[ka>>2]=(c[ka>>2]|0)+4;qa=oa+30|0;ra=0;break}}}while(0);c[f>>2]=ra;c[h>>2]=qa;if((qa|0)>1){sa=qa-1|0;ta=ra<<1}else{oa=fe(ra<<qa|0)|0;ra=b+796|0;pa=c[ra>>2]|0;x=oa;a[pa]=x;x=x>>8;a[pa+1|0]=x;x=x>>8;a[pa+2|0]=x;x=x>>8;a[pa+3|0]=x;c[ra>>2]=(c[ra>>2]|0)+4;sa=qa+31|0;ta=0}c[f>>2]=ta;c[h>>2]=sa;qa=b+14004|0;ra=c[qa>>2]|0;if((sa|0)>1){ua=sa-1|0;va=ta<<1|ra;wa=ra}else{pa=fe(ta<<sa|ra>>>((1-sa|0)>>>0)|0)|0;ta=b+796|0;oa=c[ta>>2]|0;x=pa;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;c[ta>>2]=(c[ta>>2]|0)+4;ua=sa+31|0;va=ra;wa=c[qa>>2]|0}c[f>>2]=va;c[h>>2]=ua;if((wa|0)!=0){jPa(d,c[(c[A>>2]|0)+300>>2]|0);jPa(d,c[(c[A>>2]|0)+304>>2]|0)}A=(e|0)!=1;if(A){e=c[b+13924>>2]|0;wa=c[f>>2]|0;ua=c[h>>2]|0;if((ua|0)>1){xa=ua-1|0;ya=wa<<1|e}else{va=fe(e>>>((1-ua|0)>>>0)|wa<<ua|0)|0;wa=b+796|0;qa=c[wa>>2]|0;x=va;a[qa]=x;x=x>>8;a[qa+1|0]=x;x=x>>8;a[qa+2|0]=x;x=x>>8;a[qa+3|0]=x;c[wa>>2]=(c[wa>>2]|0)+4;xa=ua+31|0;ya=e}c[f>>2]=ya;c[h>>2]=xa;za=xa;Aa=ya}else{za=c[h>>2]|0;Aa=c[f>>2]|0}if((za|0)>1){Ba=za-1|0;Ca=Aa<<1|1}else{ya=fe(1>>>((1-za|0)>>>0)|Aa<<za|0)|0;Aa=b+796|0;xa=c[Aa>>2]|0;x=ya;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[Aa>>2]=(c[Aa>>2]|0)+4;Ba=za+31|0;Ca=1}c[f>>2]=Ca;c[h>>2]=Ba;za=(c[b+14252>>2]|0)==0|0;if((Ba|0)>1){Da=Ba-1|0;Ea=Ca<<1|za}else{Aa=fe(za>>>((1-Ba|0)>>>0)|Ca<<Ba|0)|0;Ca=b+796|0;xa=c[Ca>>2]|0;x=Aa;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[Ca>>2]=(c[Ca>>2]|0)+4;Da=Ba+31|0;Ea=za}c[f>>2]=Ea;c[h>>2]=Da;za=b+13936|0;Ba=c[za>>2]|0;Ca=(Ba|0)!=0|0;if((Da|0)>1){Fa=Da-1|0;Ga=Ea<<1|Ca;Ha=Ba}else{Ba=fe(Ca>>>((1-Da|0)>>>0)|Ea<<Da|0)|0;Ea=b+796|0;xa=c[Ea>>2]|0;x=Ba;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[Ea>>2]=(c[Ea>>2]|0)+4;Fa=Da+31|0;Ga=Ca;Ha=c[za>>2]|0}c[f>>2]=Ga;c[h>>2]=Fa;if((Ha|0)==0){Ia=Ga;Ja=Fa}else{if((Fa|0)>1){Ka=Fa-1|0;La=Ga<<1}else{Ha=fe(Ga<<Fa|0)|0;Ga=b+796|0;za=c[Ga>>2]|0;x=Ha;a[za]=x;x=x>>8;a[za+1|0]=x;x=x>>8;a[za+2|0]=x;x=x>>8;a[za+3|0]=x;c[Ga>>2]=(c[Ga>>2]|0)+4;Ka=Fa+31|0;La=0}c[f>>2]=La;c[h>>2]=Ka;Ia=La;Ja=Ka}if(A){if((Ja|0)>1){Ma=Ja-1|0;Na=Ia<<1}else{A=fe(Ia<<Ja|0)|0;Ka=b+796|0;La=c[Ka>>2]|0;x=A;a[La]=x;x=x>>8;a[La+1|0]=x;x=x>>8;a[La+2|0]=x;x=x>>8;a[La+3|0]=x;c[Ka>>2]=(c[Ka>>2]|0)+4;Ma=Ja+31|0;Na=0}c[f>>2]=Na;c[h>>2]=Ma;if((Ma|0)>1){Oa=Ma-1|0;Pa=Na<<1}else{Ka=fe(Na<<Ma|0)|0;Na=b+796|0;La=c[Na>>2]|0;x=Ka;a[La]=x;x=x>>8;a[La+1|0]=x;x=x>>8;a[La+2|0]=x;x=x>>8;a[La+3|0]=x;c[Na>>2]=(c[Na>>2]|0)+4;Oa=Ma+31|0;Pa=0}c[f>>2]=Pa;c[h>>2]=Oa;Qa=Oa;Ra=Pa}else{Qa=Ja;Ra=Ia}if((Qa|0)>1){Sa=Qa-1|0;Ta=Ra<<1}else{Ia=fe(Ra<<Qa|0)|0;Ra=b+796|0;Ja=c[Ra>>2]|0;x=Ia;a[Ja]=x;x=x>>8;a[Ja+1|0]=x;x=x>>8;a[Ja+2|0]=x;x=x>>8;a[Ja+3|0]=x;c[Ra>>2]=(c[Ra>>2]|0)+4;Sa=Qa+31|0;Ta=0}c[f>>2]=Ta;c[h>>2]=Sa;if((Sa|0)>1){Ua=Sa-1|0;Va=Ta<<1}else{Qa=fe(Ta<<Sa|0)|0;Ta=b+796|0;Ra=c[Ta>>2]|0;x=Qa;a[Ra]=x;x=x>>8;a[Ra+1|0]=x;x=x>>8;a[Ra+2|0]=x;x=x>>8;a[Ra+3|0]=x;c[Ta>>2]=(c[Ta>>2]|0)+4;Ua=Sa+31|0;Va=0}c[f>>2]=Va;c[h>>2]=Ua;Sa=Ua&7;if((Sa|0)==0){Wa=Va;Xa=Ua}else{Ta=(1<<Sa)-1|0;if((Ua|0)>(Sa|0)){Ya=Ua;Za=Ta|Va<<Sa}else{Ra=fe(Ta>>>((Sa-Ua|0)>>>0)|Va<<Ua|0)|0;Va=b+796|0;Qa=c[Va>>2]|0;x=Ra;a[Qa]=x;x=x>>8;a[Qa+1|0]=x;x=x>>8;a[Qa+2|0]=x;x=x>>8;a[Qa+3|0]=x;c[Va>>2]=(c[Va>>2]|0)+4;Ya=Ua+32|0;Za=Ta}Ta=Ya-Sa|0;c[f>>2]=Za;c[h>>2]=Ta;Wa=Za;Xa=Ta}if((c[b+60>>2]&8388608|0)!=0){return}if((Xa|0)>16){_a=Xa-16|0;$a=Wa<<16}else{Ta=fe(Wa<<Xa|0)|0;Wa=b+796|0;Za=c[Wa>>2]|0;x=Ta;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;c[Wa>>2]=(c[Wa>>2]|0)+4;_a=Xa+16|0;$a=0}c[f>>2]=$a;c[h>>2]=_a;if((_a|0)>16){ab=_a-16|0}else{Xa=fe(434>>>((16-_a|0)>>>0)|$a<<_a|0)|0;$a=b+796|0;b=c[$a>>2]|0;x=Xa;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[$a>>2]=(c[$a>>2]|0)+4;ab=_a+16|0}c[f>>2]=434;c[h>>2]=ab;L_(d,2132528,0);return}function yNa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+796>>2]|0;d=a+800|0;e=b;f=(c[d>>2]|0)-e|0;g=(((f|0)/3|0)+e&-4)-e|0;e=f-(g<<1)&-4;c[d>>2]=(c[a+792>>2]|0)+g;d=(e|0)<0;f=d?0:b+g|0;h=d?0:e;c[a+13976>>2]=h<<3;c[a+13964>>2]=f;c[a+13972>>2]=f+h;c[a+13968>>2]=f;c[a+13960>>2]=32;c[a+13956>>2]=0;f=(g|0)<0;h=f?0:b+(e+g)|0;e=f?0:g;c[a+14e3>>2]=e<<3;c[a+13988>>2]=h;c[a+13996>>2]=h+e;c[a+13992>>2]=h;c[a+13984>>2]=32;c[a+13980>>2]=0;return}function zNa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;d=b+13984|0;e=b+13988|0;f=b+13992|0;g=((c[f>>2]|0)-(c[e>>2]|0)<<3)+(32-(c[d>>2]|0))|0;h=b+13960|0;i=b+13964|0;j=b+13968|0;k=((c[j>>2]|0)-(c[i>>2]|0)<<3)+(32-(c[h>>2]|0))|0;l=b+784|0;m=b+788|0;n=c[m>>2]|0;o=b+792|0;p=b+796|0;q=c[p>>2]|0;r=(q-(c[o>>2]|0)<<3)+(32-n)|0;s=l|0;t=c[s>>2]|0;if((c[b+9992>>2]|0)==1){if((n|0)>19){u=n-19|0;v=t<<19|438273}else{w=q;x=fe(438273>>>((19-n|0)>>>0)|t<<n|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;u=n+13|0;v=438273}c[s>>2]=v;c[m>>2]=u;u=b+13696|0;c[u>>2]=g+19+r-(c[b+13700>>2]|0)+(c[u>>2]|0);u=b+13672|0;c[u>>2]=(c[u>>2]|0)+k}else{if((n|0)>17){y=n-17|0;z=t<<17|126977}else{u=q;x=fe(126977>>>((17-n|0)>>>0)|t<<n|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;y=n+15|0;z=126977}c[s>>2]=z;c[m>>2]=y;y=b+13696|0;c[y>>2]=g+17+(c[y>>2]|0);y=b+13664|0;c[y>>2]=r-(c[b+13700>>2]|0)+(c[y>>2]|0);y=b+13676|0;c[y>>2]=(c[y>>2]|0)+k}y=c[d>>2]|0;r=b+13980|0;a:do{if((y|0)<32){z=c[r>>2]<<y;c[r>>2]=z;s=z>>>24&255;while(1){z=c[f>>2]|0;c[f>>2]=z+1;a[z]=s;z=c[r>>2]|0;c[r>>2]=z<<8;n=(c[d>>2]|0)+8|0;c[d>>2]=n;if((n|0)>=32){break a}s=z>>>16&255}}}while(0);c[d>>2]=32;c[r>>2]=0;r=c[h>>2]|0;d=b+13956|0;if((r|0)>=32){c[h>>2]=32;c[d>>2]=0;A=b+13996|0;B=c[A>>2]|0;C=c[o>>2]|0;D=B;E=C;F=D-E|0;G=C+F|0;H=b+800|0;c[H>>2]=G;I=c[e>>2]|0;M_(l,I,g);J=c[i>>2]|0;M_(l,J,k);K=c[m>>2]|0;L=c[o>>2]|0;M=c[p>>2]|0;N=M;O=L;P=N-O|0;Q=P<<3;R=32-K|0;S=R+Q|0;T=b+13700|0;c[T>>2]=S;return}f=c[d>>2]<<r;c[d>>2]=f;r=f>>>24&255;while(1){f=c[j>>2]|0;c[j>>2]=f+1;a[f]=r;f=c[d>>2]|0;c[d>>2]=f<<8;y=(c[h>>2]|0)+8|0;c[h>>2]=y;if((y|0)>=32){break}r=f>>>16&255}c[h>>2]=32;c[d>>2]=0;A=b+13996|0;B=c[A>>2]|0;C=c[o>>2]|0;D=B;E=C;F=D-E|0;G=C+F|0;H=b+800|0;c[H>>2]=G;I=c[e>>2]|0;M_(l,I,g);J=c[i>>2]|0;M_(l,J,k);K=c[m>>2]|0;L=c[o>>2]|0;M=c[p>>2]|0;N=M;O=L;P=N-O|0;Q=P<<3;R=32-K|0;S=R+Q|0;T=b+13700|0;c[T>>2]=S;return}function ANa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=(c[b+144>>2]|0)-1|0;f=e>>>0>65535>>>0;g=f?e>>>16:e;e=f?16:0;if((g&65280|0)==0){h=e;i=g}else{h=e|8;i=g>>>8}g=(d[1191992+i|0]|0)+h|0;h=g+1|0;i=SMa(b)|0;e=b+784|0;f=c[e>>2]|0;j=b+788|0;k=c[j>>2]|0;if((k|0)>(i|0)){l=k-i|0;m=f<<i}else{n=fe(f<<k|0)|0;f=b+796|0;o=c[f>>2]|0;x=n;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;l=32-i+k|0;m=0}c[e>>2]=m;c[j>>2]=l;if((l|0)>1){p=l-1|0;q=m<<1|1}else{k=fe(1>>>((1-l|0)>>>0)|m<<l|0)|0;m=b+796|0;i=c[m>>2]|0;x=k;a[i]=x;x=x>>8;a[i+1|0]=x;x=x>>8;a[i+2|0]=x;x=x>>8;a[i+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;p=l+31|0;q=1}c[e>>2]=q;c[j>>2]=p;l=(ba(c[b+116>>2]|0,c[b+12480>>2]|0)|0)+(c[b+12476>>2]|0)|0;if((p|0)>(h|0)){r=p-h|0;s=q<<h|l}else{m=fe(l>>>((h-p|0)>>>0)|q<<p|0)|0;q=b+796|0;h=c[q>>2]|0;x=m;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;r=31-g+p|0;s=l}c[e>>2]=s;c[j>>2]=r;l=c[b+13920>>2]|0;p=c[b+9960>>2]|0;if((r|0)>(l|0)){t=r;u=s<<l|p}else{g=fe(s<<r|p>>>((l-r|0)>>>0)|0)|0;s=b+796|0;q=c[s>>2]|0;x=g;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;t=r+32|0;u=p}p=t-l|0;c[e>>2]=u;c[j>>2]=p;if((p|0)>1){v=p-1|0;w=u<<1;c[e>>2]=w;c[j>>2]=v;return}else{l=fe(u<<p|0)|0;u=b+796|0;b=c[u>>2]|0;x=l;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=p+31|0;w=0;c[e>>2]=w;c[j>>2]=v;return}}function BNa(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=c[d+60>>2]|0;g=f;do{if((c[d+120>>2]|0)<=8191){if((c[d+124>>2]|0)>8191){break}h=pPa(d)|0;if((h|0)<0){j=h;i=e;return j|0}if(!(a[1342960]|0)){a[1342960]=1;h=-256;do{k=-h|0;l=(h|0)>-1?h:k;if((l|0)==0){m=0}else{n=0;o=l;while(1){l=o>>1;p=n+1|0;if((l|0)==0){m=p;break}else{n=p;o=l}}}if((h|0)<0){q=(1<<m)-1^k}else{q=h}o=a[1177296+(m<<1)|0]|0;n=a[1177297+(m<<1)|0]|0;l=(m|0)>0;p=o&255;do{if(l){r=(o&255)<<m|q;s=(n&255)+m|0;if((m|0)<=8){t=s&255;u=r&65535;break}t=s+1&255;u=(r<<1|1)&65535}else{t=n;u=p}}while(0);p=h+256|0;b[2816216+(p<<1)>>1]=u;a[2815704+p|0]=t;n=a[1177328+(m<<1)|0]|0;o=a[1177329+(m<<1)|0]|0;k=n&255;do{if(l){r=(n&255)<<m|q;s=(o&255)+m|0;if((m|0)<=8){v=s&255;w=r&65535;break}v=s+1&255;w=(r<<1|1)&65535}else{v=o;w=k}}while(0);b[2817752+(p<<1)>>1]=w;a[2817240+p|0]=v;h=h+1|0;}while((h|0)<256);OOa(1175928,6843728);CNa(1175928,2602712,2586328);CNa(1210184,2684632,2668248)}c[f+13080>>2]=-2048;c[f+13084>>2]=2047;c[f+13092>>2]=2586328;c[f+13096>>2]=2594520;c[f+13100>>2]=2668248;c[f+13104>>2]=2676440;c[f+13108>>2]=2815704;c[f+13088>>2]=30;c[f+9888>>2]=1175896;c[f+9892>>2]=1177264;if((c[f+60>>2]&4194304|0)==0){j=0;i=e;return j|0}h=WDb(1024)|0;k=f+4|0;c[(c[k>>2]|0)+96>>2]=h;h=c[(c[k>>2]|0)+96>>2]|0;c[f+804>>2]=8192;o=f+792|0;c[o>>2]=h;c[f+800>>2]=h+1024;n=f+796|0;c[n>>2]=h;h=f+788|0;c[h>>2]=32;l=f+784|0;c[l>>2]=0;if((c[f+84>>2]&8192|0)==0){wNa(g)}xNa(g);r=c[h>>2]|0;if((r|0)<32){s=c[l>>2]<<r;c[l>>2]=s;r=s>>>24&255;while(1){s=c[n>>2]|0;c[n>>2]=s+1;a[s]=r;s=c[l>>2]|0;c[l>>2]=s<<8;x=(c[h>>2]|0)+8|0;c[h>>2]=x;if((x|0)<32){r=s>>>16&255}else{break}}}c[h>>2]=32;c[l>>2]=0;c[(c[k>>2]|0)+100>>2]=(c[n>>2]|0)-(c[o>>2]|0)<<3>>3;j=0;i=e;return j|0}}while(0);yDb(d,16,2004792,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;j=-22;i=e;return j|0}function CNa(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;i=f|0;j=f+8|0;k=-64;while(1){if((k|0)==0){k=k+1|0;continue}l=k+64|0;m=(k|0)<0?-k|0:k;n=k>>>31;o=m-1|0;p=k&4095;q=0;do{r=l+(q<<7)|0;s=0;do{t=r+(s<<13)|0;u=h+t|0;a[u]=100;v=f+20+(s<<2)|0;w=d[(c[v>>2]|0)+q|0]|0;x=c[i>>2]|0;if((w|0)<(x|0)){y=(a[(c[f+28+(s<<2)>>2]|0)+q|0]|0)<(m|0)?x:o+w|0}else{y=x}w=c[j>>2]|0;z=(e[w+(y<<2)+2>>1]|0)+1|0;if((y|0)!=(x|0)&z>>>0<100>>>0){c[g+(t<<2)>>2]=e[w+(y<<2)>>1]<<1|n;A=z&255;a[u]=A;B=c[i>>2]|0;C=c[j>>2]|0;D=A}else{B=x;C=w;D=100}w=f+28+(s<<2)|0;x=a[(c[w>>2]|0)+q|0]|0;A=m-x|0;do{if((A|0)>0){z=b[C+(B<<2)+2>>1]|0;E=b[C+(B<<2)>>1]|0;F=d[(c[v>>2]|0)+q|0]|0;if((F|0)>=(B|0)|(x|0)<(A|0)){G=B;H=z;I=E}else{J=A-1+F|0;G=J;H=b[C+(J<<2)+2>>1]|0;I=b[C+(J<<2)>>1]|0}J=H&65535;F=(z&65535)+2+J|0;if((G|0)==(B|0)){K=B;L=C;M=D;break}if((F|0)>=(D&255|0)){K=B;L=C;M=D;break}c[g+(t<<2)>>2]=((E&65535)<<1<<J)+(I&65535)<<1|n;J=F&255;a[u]=J;K=c[i>>2]|0;L=c[j>>2]|0;M=J}else{K=B;L=C;M=D}}while(0);A=q-(a[(c[f+36+(s<<2)>>2]|0)+m|0]|0)|0;do{if((A|0)>0){x=b[L+(K<<2)+2>>1]|0;J=b[L+(K<<2)>>1]|0;F=x&65535;E=A-1|0;z=(J&65535)<<2|2;N=d[(c[v>>2]|0)+E|0]|0;do{if((N|0)<(K|0)){if((a[(c[w>>2]|0)+E|0]|0)<(m|0)){O=K;P=x;Q=J;break}R=o+N|0;O=R;P=b[L+(R<<2)+2>>1]|0;Q=b[L+(R<<2)>>1]|0}else{O=K;P=x;Q=J}}while(0);J=P&65535;x=F+3+J|0;if((O|0)==(K|0)){S=K;T=L;U=M;break}if((x|0)>=(M&255|0)){S=K;T=L;U=M;break}c[g+(t<<2)>>2]=(z<<J)+(Q&65535)<<1|n;J=x&255;a[u]=J;S=c[i>>2]|0;T=c[j>>2]|0;U=J}else{S=K;T=L;U=M}}while(0);w=(e[T+(S<<2)+2>>1]|0)+23|0;if(w>>>0<(U&255)>>>0){c[g+(t<<2)>>2]=(((e[T+(S<<2)>>1]<<3|6)+s<<6)+q<<13|p)<<1|8193;a[u]=w}s=s+1|0;}while((s|0)<2);q=q+1|0;}while((q|0)<64);k=k+1|0;if((k|0)>=64){break}}return}function DNa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c[a+180+(f<<2)>>2]|0;do{if((c[a+12488>>2]|0)==0){if((i|0)<0){j=0}else{k=0;l=2668248;m=0;break}return j|0}else{n=d[((f|0)<4?2815704:2817240)+(g+256)|0]|0;if((i|0)<1){j=n}else{k=1;l=2586328;m=n;break}return j|0}}while(0);g=k-1|0;f=b[e+((d[h+k|0]|0)<<1)>>1]|0;a=f<<16>>16;if((k|0)<(i|0)){n=m;o=g;p=k;q=f;f=a;while(1){if(q<<16>>16==0){r=o;s=n}else{t=f+64|0;if(t>>>0<128>>>0){u=d[l+((p-o<<7)-128+t)|0]|0}else{u=30}r=p;s=u+n|0}t=p+1|0;v=b[e+((d[h+t|0]|0)<<1)>>1]|0;w=v<<16>>16;if((t|0)<(i|0)){n=s;o=r;p=t;q=v;f=w}else{x=s;y=r;z=i;A=w;break}}}else{x=m;y=g;z=k;A=a}a=A+64|0;if(a>>>0<128>>>0){B=d[l+((z-y<<7)+8064+a)|0]|0}else{B=30}j=B+x|0;return j|0}function ENa(f,g,h,i,j,k,l){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;m=c[f+180+(h<<2)>>2]|0;do{if((c[f+12488>>2]|0)==0){if((m|0)>=0){n=0;o=2684632;p=2668248;break}return}else{q=i+256|0;if((h|0)<4){r=d[2815704+q|0]|0;s=e[2816216+(q<<1)>>1]|0;t=k|0;u=c[t>>2]|0;v=k+4|0;w=c[v>>2]|0;if((w|0)>(r|0)){y=w-r|0;z=u<<r|s}else{A=fe(s>>>((r-w|0)>>>0)|u<<w|0)|0;u=k+12|0;B=c[u>>2]|0;x=A;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;y=32-r+w|0;z=s}c[t>>2]=z;c[v>>2]=y}else{v=d[2817240+q|0]|0;t=e[2817752+(q<<1)>>1]|0;q=k|0;s=c[q>>2]|0;w=k+4|0;r=c[w>>2]|0;if((r|0)>(v|0)){C=r-v|0;D=s<<v|t}else{u=fe(t>>>((v-r|0)>>>0)|s<<r|0)|0;s=k+12|0;B=c[s>>2]|0;x=u;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;C=32-v+r|0;D=t}c[q>>2]=D;c[w>>2]=C}if((m|0)>=1){n=1;o=2602712;p=2586328;break}return}}while(0);C=n-1|0;D=b[g+((d[j+n|0]|0)<<1)>>1]|0;k=D<<16>>16;if((n|0)<(m|0)){y=l|0;z=l+4|0;h=l+12|0;i=C;f=n;w=D;D=k;while(1){do{if(w<<16>>16==0){E=i}else{q=f-i-1|0;t=D+64|0;if(t>>>0<128>>>0){r=t+(q<<7)|0;t=d[p+r|0]|0;v=c[o+(r<<2)>>2]|0;r=c[y>>2]|0;s=c[z>>2]|0;if((s|0)>(t|0)){F=s-t|0;G=r<<t|v}else{B=fe(v>>>((t-s|0)>>>0)|r<<s|0)|0;r=c[h>>2]|0;x=B;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;F=32-t+s|0;G=v}c[y>>2]=G;c[z>>2]=F;E=f;break}else{v=(q<<14)+31465472|D<<1&8190|1;q=c[y>>2]|0;s=c[z>>2]|0;if((s|0)>30){H=s-30|0;I=q<<30|v}else{t=fe(v>>>((30-s|0)>>>0)|q<<s|0)|0;q=c[h>>2]|0;x=t;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;H=s+2|0;I=v}c[y>>2]=I;c[z>>2]=H;E=f;break}}}while(0);v=f+1|0;s=b[g+((d[j+v|0]|0)<<1)>>1]|0;q=s<<16>>16;if((v|0)<(m|0)){i=E;f=v;w=s;D=q}else{J=E;K=m;L=q;break}}}else{J=C;K=n;L=k}k=K-J-1|0;J=L+64|0;if(J>>>0<128>>>0){K=(k<<7)+8192+J|0;J=d[p+K|0]|0;p=c[o+(K<<2)>>2]|0;K=l|0;o=c[K>>2]|0;n=l+4|0;C=c[n>>2]|0;if((C|0)>(J|0)){M=C-J|0;N=o<<J|p}else{m=fe(p>>>((J-C|0)>>>0)|o<<C|0)|0;o=l+12|0;E=c[o>>2]|0;x=m;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;M=32-J+C|0;N=p}c[K>>2]=N;c[n>>2]=M;return}else{M=(k<<14)+32514048|L<<1&8190|1;L=l|0;k=c[L>>2]|0;n=l+4|0;N=c[n>>2]|0;if((N|0)>30){O=N-30|0;P=k<<30|M}else{K=fe(M>>>((30-N|0)>>>0)|k<<N|0)|0;k=l+12|0;l=c[k>>2]|0;x=K;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;O=N+2|0;P=M}c[L>>2]=P;c[n>>2]=O;return}}function FNa(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;j=i;i=i+56|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=j+48|0;c[k>>2]=g;c[l>>2]=h;g=c[a>>2]|0;r=g;s=g+16|0;t=c[s>>2]|0;a:do{if((h|0)>0){u=g+40|0;v=g+48|0;w=g+44|0;x=b+48|0;y=b+412|0;z=b+416|0;A=a+304|0;B=g+52|0;C=b+72|0;D=0;E=t;F=h;while(1){G=c[u>>2]|0;b:do{if((G|0)==0){if((D|0)<(F|0)){H=D;I=E}else{J=E;K=D;break}while(1){L=I<<8;M=H+1|0;N=d[(c[k>>2]|0)+H|0]|0|L;O=$Na(N,m,n,p,o,q)|0;if((O|0)>=4){break}if((M|0)>4){c[v>>2]=-2}if((M|0)<(c[l>>2]|0)){H=M;I=N}else{J=N;K=M;break b}}P=c[w>>2]|0;if(((P^L)&-128e3|0)==0|(P|0)==0){Q=(c[v>>2]|0)+1|0}else{c[v>>2]=-3;Q=-2}c[w>>2]=N;c[v>>2]=Q;c[u>>2]=O-4;P=c[x>>2]|0;if((P|0)==0){R=0}else{R=(P|0)!=(c[q>>2]|0)|0}if((Q|0)<=(R|0)){J=N;K=M;break}c[y>>2]=c[m>>2];c[z>>2]=c[n>>2];c[A>>2]=c[p>>2];c[x>>2]=c[q>>2];if((c[B>>2]|0)==0){if((c[C>>2]|0)!=0){J=N;K=M;break}}c[B>>2]=1;P=c[C>>2]|0;c[C>>2]=(((c[o>>2]|0)-P|0)/(c[v>>2]|0)|0)+P;J=N;K=M}else{P=F-D|0;S=(P|0)>(G|0)?G:P;P=S+D|0;c[u>>2]=G-S;if((G|0)==(S|0)){T=0;U=P;break a}else{J=0;K=P}}}while(0);G=c[l>>2]|0;if((K|0)<(G|0)){D=K;E=J;F=G}else{T=J;U=-100;break}}}else{T=t;U=-100}}while(0);c[s>>2]=T;if((WRa(r,U,k,l)|0)<0){c[e>>2]=0;c[f>>2]=0;V=c[l>>2]|0;i=j;return V|0}else{c[e>>2]=c[k>>2];c[f>>2]=c[l>>2];V=U;i=j;return V|0}return 0}function GNa(e){e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0,D=0.0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=i;i=i+1544|0;h=f|0;j=f+8|0;k=f+520|0;l=c[e+60>>2]|0;if(!(a[1403288]|0)){m=j|0;n=k;o=0;while(1){b[4313104+(o<<1)>>1]=(o|0)%3|0|((o|0)/3|0)<<2;p=o+1|0;if((p|0)<64){o=p}else{q=0;break}}do{o=q+2|0;p=_Gb(8388608,0,o|0)|0;r=(1<<o)-1|0;o=eHb(p,F,r,(r|0)<0|0?-1:0)|0;r=o;p=r;s=(r|0)<0|0?-1:0;c[4312792+(q*12|0)>>2]=o<<1|0>>>31;o=gHb(p,s,13316085,0)|0;c[4312796+(q*12|0)>>2]=o>>>23|F<<9;o=gHb(p,s,10568984,0)|0;c[4312800+(q*12|0)>>2]=o>>>23|F<<9;q=q+1|0;}while((q|0)<15);eOa(6870480);q=0;o=1;while(1){TGb(m|0,0,512)|0;TGb(n|0,0,1024)|0;s=c[670600+(o*12|0)>>2]|0;p=(s|0)>1?s:1;r=c[670604+(o*12|0)>>2]|0;t=c[670608+(o*12|0)>>2]|0;u=0;v=0;while(1){w=u<<5;if((u|0)==0){x=0;y=v;while(1){z=x|w;a[j+z|0]=a[r+y|0]|0;b[k+(z<<1)>>1]=b[t+(y<<1)>>1]|0;z=x+1|0;if((z|0)<(s|0)){x=z;y=y+1|0}else{break}}}else{y=0;x=v;while(1){z=y|w|((y|0)!=0)<<4;a[j+z|0]=a[r+x|0]|0;b[k+(z<<1)>>1]=b[t+(x<<1)>>1]|0;z=y+1|0;if((z|0)<(s|0)){y=z;x=x+1|0}else{break}}}x=u+1|0;if((x|0)<(s|0)){u=x;v=v+p|0}else{break}}c[5129684+(o*20|0)>>2]=5114376+(q<<2);p=c[919968+(o<<2)>>2]|0;c[5129692+(o*20|0)>>2]=p;N_(5129680+(o*20|0)|0,7,512,m,1,1,n,2,2,0,0,0,4)|0;v=o+1|0;if((v|0)<16){q=p+q|0;o=v}else{break}}c[1282815]=5130640;c[1282817]=128;N_(5131256,7,16,661928,1,1,661864,1,1,0,0,0,4)|0;c[1282820]=5131152;c[1282822]=16;N_(5131276,4,16,661944,1,1,661880,1,1,0,0,0,4)|0;o=0;q=0;n=0;while(1){b[8878640+(q<<1)>>1]=n;m=(d[1738704+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439342]=576;n=0;q=0;o=0;while(1){b[8878686+(q<<1)>>1]=o;m=(d[1738726+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4439365]=576;o=0;q=0;n=0;while(1){b[8878732+(q<<1)>>1]=n;m=(d[1738748+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439388]=576;n=0;q=0;o=0;while(1){b[8878778+(q<<1)>>1]=o;m=(d[1738770+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4439411]=576;o=0;q=0;n=0;while(1){b[8878824+(q<<1)>>1]=n;m=(d[1738792+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439434]=576;n=0;q=0;o=0;while(1){b[8878870+(q<<1)>>1]=o;m=(d[1738814+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4439457]=576;o=0;q=0;n=0;while(1){b[8878916+(q<<1)>>1]=n;m=(d[1738836+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439480]=576;n=0;q=0;o=0;while(1){b[8878962+(q<<1)>>1]=o;m=(d[1738858+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4439503]=576;o=0;q=0;n=0;while(1){b[8879008+(q<<1)>>1]=n;m=(d[1738880+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439526]=576;n=1;while(1){A=+((n|0)/4|0|0);B=A/1.759*+S(+A,+.3333333333333333);q=~~(+Qc(+(B*+Wc(+(+(n&3|0)*.25))),h|0)*2147483648.0+.5);o=c[h>>2]|0;c[h>>2]=o-103;c[4077312+(n<<2)>>2]=q;a[4241456+n|0]=103-o;o=n+1|0;if((o|0)<32828){n=o}else{C=0;break}}do{B=+Wc(+(+(C-400|0)*.25+23.0+5.0));n=0;do{A=+(n|0);D=B*A*+S(+A,+.3333333333333333)/1.759;if(D<4294967295.0){A=+P(D+.5);h=~~+A>>>0;E=+A,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0;G=h}else{G=-1}c[8117688+(C<<6)+(n<<2)>>2]=G;g[8052152+(C<<6)+(n<<2)>>2]=D;n=n+1|0;}while((n|0)<16);c[8154040+(C<<2)>>2]=c[8117692+(C<<6)>>2];C=C+1|0;}while((C|0)<512);C=c[295200]|0;do{if((C|0)<0){G=1<<1-C;if((G|0)<=0){break}n=c[295182]|0;h=0;do{o=(h|0)/(n|0)|0;b[8523960+(h<<1)>>1]=(((o|0)%(n|0)|0)<<4)+((h|0)%(n|0)|0)+(((o|0)/(n|0)|0)<<8);h=h+1|0;}while((h|0)<(G|0))}}while(0);C=c[295201]|0;do{if((C|0)<0){G=1<<1-C;if((G|0)<=0){break}h=c[295183]|0;n=0;do{o=(n|0)/(h|0)|0;b[8523320+(n<<1)>>1]=(((o|0)%(h|0)|0)<<4)+((n|0)%(h|0)|0)+(((o|0)/(h|0)|0)<<8);n=n+1|0;}while((n|0)<(G|0))}}while(0);C=c[295202]|0;do{if((C|0)<0){G=1<<1-C;if((G|0)<=0){break}n=c[295184]|0;h=0;do{o=(h|0)/(n|0)|0;b[h<<1>>1]=(((o|0)%(n|0)|0)<<4)+((h|0)%(n|0)|0)+(((o|0)/(n|0)|0)<<8);h=h+1|0;}while((h|0)<(G|0))}}while(0);C=c[295203]|0;do{if((C|0)<0){G=1<<1-C;if((G|0)<=0){H=0;break}h=c[295185]|0;n=0;while(1){o=(n|0)/(h|0)|0;b[8518712+(n<<1)>>1]=(((o|0)%(h|0)|0)<<4)+((n|0)%(h|0)|0)+(((o|0)/(h|0)|0)<<8);o=n+1|0;if((o|0)<(G|0)){n=o}else{H=0;break}}}else{H=0}}while(0);do{if((H|0)==6){I=8388608}else{B=+V(+(H|0)*3.141592653589793/12.0);I=~~(B/(B+1.0)*8388608.0+.5)}c[5016216+(H<<2)>>2]=I;c[5016280+(6-H<<2)>>2]=I;H=H+1|0;}while((H|0)<7);TGb(5016244,0,36)|0;TGb(5016308,0,36)|0;H=0;while(1){I=H+1|0;C=I>>1;n=H&1;G=n^1;c[5015832+(G<<6)+(H<<2)>>2]=~~(+Wc(+(+(-C|0)*.25))*8388608.0+.5);c[5015832+(n<<6)+(H<<2)>>2]=8388608;c[5015960+(G<<6)+(H<<2)>>2]=~~(+Wc(+(+(C*-2|0|0)*.25))*8388608.0+.5);c[5015960+(n<<6)+(H<<2)>>2]=8388608;if((I|0)<16){H=I}else{J=0;break}}do{B=+g[1485792+(J<<2)>>2];D=1.0/+R(B*B+1.0);H=~~(D*.25*4294967296.0+.5);c[8749984+(J<<4)>>2]=H;I=~~(B*D*.25*4294967296.0+.5);c[8749988+(J<<4)>>2]=I;c[8749992+(J<<4)>>2]=I+H;c[8749996+(J<<4)>>2]=I-H;J=J+1|0;}while((J|0)<8);a[1403288]=1}c[l+32940>>2]=e;fCb(l+32968|0,c[e+88>>2]&8388608);bOa(l+32944|0);J=c[e+48>>2]|0;do{if((c[e+468>>2]|0)==1){if((J|0)==86030){K=86030;L=63;break}c[e+420>>2]=1;M=J}else{K=J;L=63}}while(0);if((L|0)==63){c[e+420>>2]=6;M=K}c[l+32936>>2]=c[e+696>>2];if((M|0)!=86029){i=f;return 0}c[l+32928>>2]=1;i=f;return 0}function HNa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=g+28|0;k=c[j>>2]|0;l=c[b+60>>2]|0;m=l;if((k|0)==0){n=-1094995529;i=h;return n|0}o=k;k=c[g+24>>2]|0;while(1){if((a[k]|0)!=0){break}g=o-1|0;if((g|0)==0){n=-1094995529;p=22;break}else{o=g;k=k+1|0}}if((p|0)==22){i=h;return n|0}if((o|0)<4){n=-1094995529;i=h;return n|0}p=k;g=fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if((g&-256|0)==1413564160){yDb(b,48,2083472,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=o;i=h;return n|0}if((g&-2097152|0)!=-2097152|(g&393216|0)==0|(g&61440|0)==61440|(g&3072|0)==3072){yDb(b,16,2077848,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}if((_Na(l,g)|0)==1){c[l>>2]=-1;n=-1094995529;i=h;return n|0}g=l+24|0;c[b+416>>2]=c[g>>2];p=(c[g>>2]|0)==1;g=b+448|0;c[g>>2]=p?4:3;c[g+4>>2]=p?0:0;p=b+72|0;if((c[p>>2]|0)==0){c[p>>2]=c[l+20>>2]}p=l;g=c[p>>2]|0;if((g|0)<1|(g|0)>(o|0)){yDb(b,16,2073016,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}if((g|0)<(o|0)){yDb(b,48,2068424,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=c[p>>2]|0}else{r=o}o=l+33004|0;c[o>>2]=e;e=ONa(m,0,k,r)|0;do{if((e|0)>-1){c[(c[o>>2]|0)+76>>2]=c[b+424>>2];c[f>>2]=1;c[b+412>>2]=c[l+12>>2]}else{yDb(b,16,2093400,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[f>>2]=0;if((r|0)!=(c[j>>2]|0)&(e|0)==-1094995529){break}else{n=e}i=h;return n|0}}while(0);c[p>>2]=0;n=r;i=h;return n|0}function INa(a){a=a|0;var b=0;b=c[a+60>>2]|0;TGb(b+1152|0,0,8192)|0;c[b+1088>>2]=0;return}function JNa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;f=c[a+60>>2]|0;if((j|0)<4){yDb(a,16,2114200,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}m=h;n=fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;if((n&393216|0)==0|(n&61440|0)==61440|(n&3072|0)==3072){yDb(a,16,2099888,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}_Na(f,n|-2097152)|0;c[a+412>>2]=c[f+12>>2];n=f+24|0;c[a+416>>2]=c[n>>2];m=(c[n>>2]|0)==1;n=a+448|0;c[n>>2]=m?4:3;c[n+4>>2]=m?0:0;m=a+72|0;if((c[m>>2]|0)==0){c[m>>2]=c[f+20>>2]}c[f>>2]=(j|0)>1792?1792:j;c[f+33004>>2]=b;b=ONa(f,0,h,j)|0;if((b|0)<0){yDb(a,16,2093400,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=b;i=g;return l|0}else{c[e>>2]=1;l=j;i=g;return l|0}return 0}function KNa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+48|0;f=e|0;g=a+60|0;h=c[g>>2]|0;j=c[a+100>>2]|0;do{if((j|0)>=2){k=c[a+96>>2]|0;if((k|0)==0){break}QMa(f,k,j<<3,1)|0;k=f+12|0;l=c[k>>2]|0;if((l|0)==0|(l|0)>7){yDb(a,16,2120296,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}o=h;c[o>>2]=d[671104+l|0]|0;l=c[k>>2]|0;c[h+8>>2]=1493352+(l*5|0);c[a+416>>2]=d[1175888+l|0]|0;k=b[1493408+(l<<1)>>1]|0;l=a+448|0;c[l>>2]=k<<16>>16;c[l+4>>2]=k<<16>>16<0|0?-1:0;c[h+4>>2]=(c[f+8>>2]|0)<16e3?-2097152:-1048576;k=cEb(33024)|0;l=h+12|0;p=l;q=l;c[q>>2]=k;a:do{if((k|0)!=0){c[g>>2]=k;GNa(a)|0;c[g>>2]=h;c[(c[q>>2]|0)+32928>>2]=1;if((c[o>>2]|0)>1){r=1}else{n=0;i=e;return n|0}while(1){l=cEb(33024)|0;s=p+(r<<2)|0;c[s>>2]=l;if((l|0)==0){break a}c[l+32928>>2]=1;c[l+32940>>2]=a;l=(c[s>>2]|0)+32944|0;s=(c[q>>2]|0)+32944|0;c[l>>2]=c[s>>2];c[l+4>>2]=c[s+4>>2];c[l+8>>2]=c[s+8>>2];c[l+12>>2]=c[s+12>>2];c[l+16>>2]=c[s+16>>2];c[l+20>>2]=c[s+20>>2];s=r+1|0;if((s|0)<(c[o>>2]|0)){r=s}else{n=0;break}}i=e;return n|0}}while(0);o=c[g>>2]|0;q=o;if((c[q>>2]|0)<=0){n=-12;i=e;return n|0}p=o+12|0;o=0;while(1){ZDb(c[p+(o<<2)>>2]|0);k=o+1|0;if((k|0)<(c[q>>2]|0)){o=k}else{n=-12;break}}i=e;return n|0}}while(0);yDb(a,16,2126120,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}function LNa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+8|0;h=g|0;j=c[f+24>>2]|0;k=c[f+28>>2]|0;f=c[a+60>>2]|0;l=b+76|0;c[l>>2]=1152;m=_$a(a,b,0)|0;if((m|0)<0){n=m;i=g;return n|0}m=c[b+64>>2]|0;if((k|0)<4){n=-1094995529;i=g;return n|0}b=a+72|0;c[b>>2]=0;o=f;a:do{if((c[o>>2]|0)>0){p=f+12|0;q=f+4|0;r=a+416|0;s=f+8|0;t=h|0;u=h+4|0;v=a;w=k;x=0;y=j;z=0;A=0;while(1){B=y;C=((de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;B=(C|0)>(w|0)?w:C;C=(B|0)>1792?1792:B;B=c[p+(z<<2)>>2]|0;if((C|0)<4){D=7;break}E=y;F=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)&1048575;E=c[q>>2]|0;G=F|E;if((E&-2097152|0)!=-2097152|(G&393216|0)==0|(G&61440|0)==61440|(G&3072|0)==3072){D=9;break}_Na(B,G)|0;G=B+24|0;E=c[G>>2]|0;F=E+A|0;H=c[r>>2]|0;if((F|0)>(H|0)){D=12;break}I=d[(c[s>>2]|0)+z|0]|0;if((I+E|0)>(H|0)){D=12;break}c[t>>2]=c[m+(I<<2)>>2];if((E|0)>1){c[u>>2]=c[m+((d[(c[s>>2]|0)+z|0]|0)+1<<2)>>2]}E=ONa(B,t,y,C)|0;if((E|0)<0){yDb(v,16,2230408,(J=i,i=i+8|0,c[J>>2]=F,J)|0);i=J;TGb(c[t>>2]|0,0,2304)|0;I=c[G>>2]|0;if((I|0)>1){TGb(c[u>>2]|0,0,2304)|0;K=c[G>>2]|0}else{K=I}L=K*2304|0}else{L=E}E=L+x|0;c[b>>2]=(c[b>>2]|0)+(c[B+20>>2]|0);B=z+1|0;if((B|0)<(c[o>>2]|0)){w=w-C|0;x=E;y=y+C|0;z=B;A=F}else{M=E;N=F;O=r;break a}}if((D|0)==7){yDb(v,16,2272544,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}else if((D|0)==9){yDb(v,16,2257184,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}else if((D|0)==12){yDb(v,16,2242864,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}}else{M=0;N=0;O=a+416|0}}while(0);if((N|0)==(c[O>>2]|0)){c[a+412>>2]=c[(c[f+12>>2]|0)+12>>2];c[l>>2]=(M>>>0)/(N<<1>>>0)|0;c[e>>2]=1;n=k;i=g;return n|0}else{yDb(a,16,2218392,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}return 0}function MNa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;a=b;if((c[a>>2]|0)<=0){return 0}d=b+12|0;b=0;do{ZDb(c[d+(b<<2)>>2]|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function NNa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b;if((c[a>>2]|0)<=0){return}d=b+12|0;b=0;do{e=c[d+(b<<2)>>2]|0;TGb(e+1152|0,0,8192)|0;c[e+1088>>2]=0;b=b+1|0;}while((b|0)<(c[a>>2]|0));return}function ONa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0;k=i;i=i+3808|0;l=k|0;m=k+192|0;n=k+256|0;o=k+320|0;p=k+336|0;q=k+2640|0;r=k+3792|0;s=f+1096|0;t=h+4|0;h=j-4|0;j=h<<3;u=j>>>0>2147483639>>>0|(t|0)==0;v=u?0:t;t=u?0:j;j=s|0;c[j>>2]=v;u=f+1108|0;c[u>>2]=t;w=t+8|0;x=f+1112|0;c[x>>2]=w;y=f+1100|0;c[y>>2]=v+(t>>3);t=f+1104|0;c[t>>2]=0;if((c[f+4>>2]|0)==0){z=0}else{A=w>>>0>16>>>0?16:w;c[t>>2]=A;z=A}A=c[f+8>>2]|0;if((A|0)==1){c[(c[f+32940>>2]|0)+424>>2]=384;if((c[f+28>>2]|0)==1){B=(c[f+32>>2]<<2)+4|0;if((B|0)>0){C=B;D=7}else{E=0;G=B;D=11}}else{C=32;D=7}if((D|0)==7){B=c[f+24>>2]|0;H=(B|0)>0;I=0;do{if(H){J=c[x>>2]|0;K=0;L=c[t>>2]|0;do{M=v+(L>>>3)|0;N=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(L&7)>>>28;M=L+4|0;L=J>>>0>M>>>0?M:J;c[t>>2]=L;a[m+(K<<5)+I|0]=N;K=K+1|0;}while((K|0)<(B|0))}I=I+1|0;}while((I|0)<(C|0));if((C|0)<32){E=1;G=C;D=11}else{O=0;P=C;Q=B;D=17}}do{if((D|0)==11){B=f+1096|0;C=c[x>>2]|0;I=G;H=c[t>>2]|0;do{K=v+(H>>>3)|0;L=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(H&7)>>>28;K=H+4|0;H=C>>>0>K>>>0?K:C;c[t>>2]=H;a[m+I|0]=L;I=I+1|0;}while((I|0)<32);if(!E){R=0;S=G;T=B;D=16;break}O=1;P=G;Q=c[f+24>>2]|0;D=17}}while(0);if((D|0)==17){G=f+1096|0;E=(Q|0)>0;I=0;do{if(E){H=0;do{if((a[m+(H<<5)+I|0]|0)!=0){C=c[t>>2]|0;L=c[x>>2]|0;K=v+(C>>>3)|0;J=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(C&7)>>>26;K=C+6|0;c[t>>2]=L>>>0>K>>>0?K:L;a[n+(H<<5)+I|0]=J}H=H+1|0;}while((H|0)<(Q|0))}I=I+1|0;}while((I|0)<(P|0));if(O){R=1;S=P;T=G;D=16}else{U=1;V=P;W=0;X=G}}if((D|0)==16){G=S;while(1){if((a[m+G|0]|0)!=0){P=c[t>>2]|0;O=c[x>>2]|0;I=c[T>>2]|0;Q=I+(P>>>3)|0;E=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(P&7)>>>26;Q=P+6|0;P=O>>>0>Q>>>0?Q:O;c[t>>2]=P;a[n+G|0]=E;E=I+(P>>>3)|0;I=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(P&7)>>>26;E=P+6|0;c[t>>2]=O>>>0>E>>>0?E:O;a[n+32+G|0]=I}I=G+1|0;if((I|0)<32){G=I}else{U=R;V=S;W=1;X=T;break}}}T=f+24|0;S=0;while(1){if(U){R=0;G=c[T>>2]|0;while(1){if((G|0)>0){I=0;while(1){O=a[m+(I<<5)+R|0]|0;E=O&255;if(O<<24>>24==0){Y=0}else{O=c[t>>2]|0;P=c[x>>2]|0;Q=(c[X>>2]|0)+(O>>>3)|0;H=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>((31-E|0)>>>0);Q=E+1+O|0;c[t>>2]=P>>>0>Q>>>0?Q:P;P=e[4313104+(d[n+(I<<5)+R|0]<<1)>>1]|0;Q=(-1<<E)+1+H|0;H=c[4312792+((E-1|0)*12|0)+((P&3)<<2)>>2]|0;O=gHb(H,(H|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;Q=F;H=(P>>>2)+E|0;E=_Gb(1,0,H-1|0)|0;P=YGb(E,F,O,Q)|0;Q=aHb(P|0,F|0,H|0)|0;Y=Q}c[f+9376+(I*4608|0)+(S<<7)+(R<<2)>>2]=Y;Q=I+1|0;H=c[T>>2]|0;if((Q|0)<(H|0)){I=Q}else{Z=H;break}}}else{Z=G}I=R+1|0;if((I|0)<(V|0)){R=I;G=Z}else{break}}}if(W){G=V;do{R=a[m+G|0]|0;I=R&255;if(R<<24>>24==0){c[f+9376+(S<<7)+(G<<2)>>2]=0;c[f+13984+(S<<7)+(G<<2)>>2]=0}else{R=c[t>>2]|0;H=c[x>>2]|0;Q=(c[X>>2]|0)+(R>>>3)|0;P=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(R&7)>>>((31-I|0)>>>0);Q=I+1+R|0;c[t>>2]=H>>>0>Q>>>0?Q:H;H=e[4313104+(d[n+G|0]<<1)>>1]|0;Q=(-1<<I)+1+P|0;P=Q;R=(Q|0)<0|0?-1:0;Q=I-1|0;O=c[4312792+(Q*12|0)+((H&3)<<2)>>2]|0;E=gHb(O,(O|0)<0|0?-1:0,P,R)|0;O=F;B=(H>>>2)+I|0;H=_Gb(1,0,B-1|0)|0;J=YGb(H,F,E,O)|0;O=aHb(J|0,F|0,B|0)|0;c[f+9376+(S<<7)+(G<<2)>>2]=O;O=e[4313104+(d[n+32+G|0]<<1)>>1]|0;B=c[4312792+(Q*12|0)+((O&3)<<2)>>2]|0;Q=gHb(B,(B|0)<0|0?-1:0,P,R)|0;R=F;P=(O>>>2)+I|0;I=_Gb(1,0,P-1|0)|0;O=YGb(I,F,Q,R)|0;R=aHb(O|0,F|0,P|0)|0;c[f+13984+(S<<7)+(G<<2)>>2]=R}G=G+1|0;}while((G|0)<32)}G=S+1|0;if((G|0)<12){S=G}else{_=12;break}}}else if((A|0)==2){c[(c[f+32940>>2]|0)+424>>2]=1152;S=f+24|0;X=Nmb((c[f+20>>2]|0)/1e3|0,c[S>>2]|0,c[f+12>>2]|0,c[f+36>>2]|0)|0;V=c[1180704+(X<<2)>>2]|0;W=c[1181904+(X<<2)>>2]|0;if((c[f+28>>2]|0)==1){$=(c[f+32>>2]<<2)+4|0}else{$=V}X=($|0)>(V|0)?V:$;$=(X|0)>0;if($){Z=f+1096|0;T=c[S>>2]|0;Y=(T|0)>0;U=0;G=0;while(1){R=d[W+U|0]|0;if(Y){P=32-R|0;O=c[x>>2]|0;Q=c[Z>>2]|0;I=0;B=c[t>>2]|0;do{J=Q+(B>>>3)|0;E=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(B&7)>>>(P>>>0);J=B+R|0;B=O>>>0>J>>>0?J:O;c[t>>2]=B;a[m+(I<<5)+G|0]=E;I=I+1|0;}while((I|0)<(T|0))}I=(1<<R)+U|0;B=G+1|0;if((B|0)<(X|0)){U=I;G=B}else{aa=I;break}}}else{aa=0}G=(X|0)<(V|0);if(G){U=c[x>>2]|0;T=c[f+1096>>2]|0;Z=aa;aa=X;Y=c[t>>2]|0;while(1){I=d[W+Z|0]|0;B=T+(Y>>>3)|0;O=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(Y&7)>>>((32-I|0)>>>0);B=I+Y|0;P=U>>>0>B>>>0?B:U;c[t>>2]=P;B=O&255;a[m+aa|0]=B;a[m+32+aa|0]=B;B=aa+1|0;if((B|0)<(V|0)){Z=(1<<I)+Z|0;aa=B;Y=P}else{break}}}Y=f+1096|0;if((V|0)>0){aa=c[S>>2]|0;Z=(aa|0)>0;U=0;while(1){if(Z){T=0;do{if((a[m+(T<<5)+U|0]|0)!=0){P=c[t>>2]|0;B=c[x>>2]|0;I=(c[Y>>2]|0)+(P>>>3)|0;O=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(P&7)>>>30;I=P+2|0;c[t>>2]=B>>>0>I>>>0?I:B;a[n+(T<<5)+U|0]=O}T=T+1|0;}while((T|0)<(aa|0))}T=U+1|0;if((T|0)<(V|0)){U=T}else{ca=0;break}}do{if(Z){U=0;do{do{if((a[m+(U<<5)+ca|0]|0)!=0){T=l+(U*96|0)+(ca*3|0)|0;R=d[n+(U<<5)+ca|0]|0;if((R|0)==3){O=c[t>>2]|0;B=c[x>>2]|0;I=c[Y>>2]|0;P=I+(O>>>3)|0;Q=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(O&7)>>>26;P=O+6|0;O=B>>>0>P>>>0?P:B;c[t>>2]=O;a[T]=Q;Q=I+(O>>>3)|0;I=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>26;Q=O+6|0;c[t>>2]=B>>>0>Q>>>0?Q:B;B=I&255;a[l+(U*96|0)+(ca*3|0)+2|0]=B;a[l+(U*96|0)+(ca*3|0)+1|0]=B;break}else if((R|0)==2){B=c[t>>2]|0;I=c[x>>2]|0;Q=(c[Y>>2]|0)+(B>>>3)|0;O=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(B&7)>>>26;Q=B+6|0;c[t>>2]=I>>>0>Q>>>0?Q:I;I=O&255;a[T]=I;a[l+(U*96|0)+(ca*3|0)+1|0]=I;a[l+(U*96|0)+(ca*3|0)+2|0]=I;break}else if((R|0)==1){R=c[t>>2]|0;I=c[x>>2]|0;O=c[Y>>2]|0;Q=O+(R>>>3)|0;B=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(R&7)>>>26;Q=R+6|0;R=I>>>0>Q>>>0?Q:I;c[t>>2]=R;Q=B&255;a[T]=Q;B=O+(R>>>3)|0;O=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(R&7)>>>26;B=R+6|0;c[t>>2]=I>>>0>B>>>0?B:I;a[l+(U*96|0)+(ca*3|0)+2|0]=O;a[l+(U*96|0)+(ca*3|0)+1|0]=Q;break}else{Q=c[t>>2]|0;O=c[x>>2]|0;I=c[Y>>2]|0;B=I+(Q>>>3)|0;R=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(Q&7)>>>26;B=Q+6|0;Q=O>>>0>B>>>0?B:O;c[t>>2]=Q;a[T]=R;R=I+(Q>>>3)|0;T=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Q&7)>>>26;R=Q+6|0;Q=O>>>0>R>>>0?R:O;c[t>>2]=Q;a[l+(U*96|0)+(ca*3|0)+1|0]=T;T=I+(Q>>>3)|0;I=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(Q&7)>>>26;T=Q+6|0;c[t>>2]=O>>>0>T>>>0?T:O;a[l+(U*96|0)+(ca*3|0)+2|0]=I;break}}}while(0);U=U+1|0;}while((U|0)<(aa|0))}ca=ca+1|0;}while((ca|0)<(V|0))}ca=(V|0)<32;aa=0;while(1){n=aa*12|0;Z=0;do{if($){U=Z+n|0;I=U+1|0;O=U+2|0;T=0;Q=0;R=c[S>>2]|0;while(1){B=d[W+T|0]|0;if((R|0)>0){P=0;while(1){E=a[m+(P<<5)+Q|0]|0;do{if(E<<24>>24==0){c[f+9376+(P*4608|0)+(U<<7)+(Q<<2)>>2]=0;c[f+9376+(P*4608|0)+(I<<7)+(Q<<2)>>2]=0;c[f+9376+(P*4608|0)+(O<<7)+(Q<<2)>>2]=0}else{J=d[l+(P*96|0)+(Q*3|0)+aa|0]|0;H=d[W+((E&255)+T)|0]|0;L=c[1180800+(H<<2)>>2]|0;if((L|0)>=0){K=32-L|0;C=L-1|0;N=(-1<<C)+1|0;M=c[t>>2]|0;da=c[x>>2]|0;ea=(c[Y>>2]|0)+(M>>>3)|0;fa=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(M&7)>>>(K>>>0);ea=M+L|0;c[t>>2]=da>>>0>ea>>>0?ea:da;da=e[4313104+(J<<1)>>1]|0;ea=fa+N|0;fa=4312792+((L-2|0)*12|0)+((da&3)<<2)|0;M=c[fa>>2]|0;ga=gHb(ea,(ea|0)<0|0?-1:0,M,(M|0)<0|0?-1:0)|0;M=F;ea=(da>>>2)+C|0;C=_Gb(1,0,ea-1|0)|0;da=F;ha=YGb(C,da,ga,M)|0;M=ea;ea=aHb(ha|0,F|0,M|0)|0;c[f+9376+(P*4608|0)+(U<<7)+(Q<<2)>>2]=ea;ea=c[t>>2]|0;ha=c[x>>2]|0;ga=(c[Y>>2]|0)+(ea>>>3)|0;ia=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ea&7)>>>(K>>>0);ga=ea+L|0;c[t>>2]=ha>>>0>ga>>>0?ga:ha;ha=ia+N|0;ia=c[fa>>2]|0;ga=gHb(ha,(ha|0)<0|0?-1:0,ia,(ia|0)<0|0?-1:0)|0;ia=YGb(ga,F,C,da)|0;ga=aHb(ia|0,F|0,M|0)|0;c[f+9376+(P*4608|0)+(I<<7)+(Q<<2)>>2]=ga;ga=c[t>>2]|0;ia=c[x>>2]|0;ha=(c[Y>>2]|0)+(ga>>>3)|0;ea=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ga&7)>>>(K>>>0);K=ga+L|0;c[t>>2]=ia>>>0>K>>>0?K:ia;ia=ea+N|0;N=c[fa>>2]|0;fa=gHb(ia,(ia|0)<0|0?-1:0,N,(N|0)<0|0?-1:0)|0;N=YGb(fa,F,C,da)|0;da=aHb(N|0,F|0,M|0)|0;c[f+9376+(P*4608|0)+(O<<7)+(Q<<2)>>2]=da;break}da=c[t>>2]|0;M=c[x>>2]|0;N=(c[Y>>2]|0)+(da>>>3)|0;C=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(da&7)>>>((L+32|0)>>>0);N=da-L|0;c[t>>2]=M>>>0>N>>>0?N:M;M=b[(c[1360424+(H<<2)>>2]|0)+(C<<1)>>1]|0;C=c[1180728+(H<<2)>>2]|0;H=e[4313104+(J<<1)>>1]|0;J=H>>>2;N=C>>1;L=c[479776+((C>>2)*12|0)+((H&3)<<2)>>2]|0;H=ba(L,(M&15)-N|0)|0;if((J|0)==0){c[f+9376+(P*4608|0)+(U<<7)+(Q<<2)>>2]=H;c[f+9376+(P*4608|0)+(I<<7)+(Q<<2)>>2]=ba((M>>>4&15)-N|0,L)|0;ja=ba(L,(M>>8)-N|0)|0}else{C=1<<J-1;c[f+9376+(P*4608|0)+(U<<7)+(Q<<2)>>2]=C+H>>J;c[f+9376+(P*4608|0)+(I<<7)+(Q<<2)>>2]=C+(ba((M>>>4&15)-N|0,L)|0)>>J;ja=C+(ba(L,(M>>8)-N|0)|0)>>J}c[f+9376+(P*4608|0)+(O<<7)+(Q<<2)>>2]=ja}}while(0);E=P+1|0;J=c[S>>2]|0;if((E|0)<(J|0)){P=E}else{ka=J;break}}}else{ka=R}P=(1<<B)+T|0;J=Q+1|0;if((J|0)<(X|0)){T=P;Q=J;R=ka}else{la=P;break}}}else{la=0}if(G){R=Z+n|0;Q=R+1|0;T=R+2|0;O=la;I=X;while(1){U=d[W+O|0]|0;P=a[m+I|0]|0;do{if(P<<24>>24==0){c[f+9376+(R<<7)+(I<<2)>>2]=0;c[f+9376+(Q<<7)+(I<<2)>>2]=0;c[f+9376+(T<<7)+(I<<2)>>2]=0;c[f+13984+(R<<7)+(I<<2)>>2]=0;c[f+13984+(Q<<7)+(I<<2)>>2]=0;c[f+13984+(T<<7)+(I<<2)>>2]=0}else{J=d[l+(I*3|0)+aa|0]|0;E=d[l+96+(I*3|0)+aa|0]|0;N=d[W+((P&255)+O)|0]|0;M=c[1180800+(N<<2)>>2]|0;if((M|0)>=0){L=32-M|0;C=M-1|0;H=(-1<<C)+1|0;da=M-2|0;fa=b[4313104+(E<<1)>>1]|0;ia=e[4313104+(J<<1)>>1]|0;ea=4312792+(da*12|0)+((ia&3)<<2)|0;K=(ia>>>2)+C|0;ia=_Gb(1,0,K-1|0)|0;ga=F;ha=K;K=fa&65535;fa=4312792+(da*12|0)+((K&3)<<2)|0;da=(K>>>2)+C|0;C=_Gb(1,0,da-1|0)|0;K=F;ma=da;da=c[t>>2]|0;na=c[x>>2]|0;oa=(c[Y>>2]|0)+(da>>>3)|0;pa=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(da&7)>>>(L>>>0);oa=da+M|0;c[t>>2]=na>>>0>oa>>>0?oa:na;na=H+pa|0;pa=na;oa=(na|0)<0|0?-1:0;na=c[ea>>2]|0;da=gHb(pa,oa,na,(na|0)<0|0?-1:0)|0;na=YGb(da,F,ia,ga)|0;da=aHb(na|0,F|0,ha|0)|0;c[f+9376+(R<<7)+(I<<2)>>2]=da;da=c[fa>>2]|0;na=gHb(pa,oa,da,(da|0)<0|0?-1:0)|0;da=YGb(na,F,C,K)|0;na=aHb(da|0,F|0,ma|0)|0;c[f+13984+(R<<7)+(I<<2)>>2]=na;na=c[t>>2]|0;da=c[x>>2]|0;oa=(c[Y>>2]|0)+(na>>>3)|0;pa=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(na&7)>>>(L>>>0);oa=na+M|0;c[t>>2]=da>>>0>oa>>>0?oa:da;da=H+pa|0;pa=da;oa=(da|0)<0|0?-1:0;da=c[ea>>2]|0;na=gHb(pa,oa,da,(da|0)<0|0?-1:0)|0;da=YGb(na,F,ia,ga)|0;na=aHb(da|0,F|0,ha|0)|0;c[f+9376+(Q<<7)+(I<<2)>>2]=na;na=c[fa>>2]|0;da=gHb(pa,oa,na,(na|0)<0|0?-1:0)|0;na=YGb(da,F,C,K)|0;da=aHb(na|0,F|0,ma|0)|0;c[f+13984+(Q<<7)+(I<<2)>>2]=da;da=c[t>>2]|0;na=c[x>>2]|0;oa=(c[Y>>2]|0)+(da>>>3)|0;pa=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(da&7)>>>(L>>>0);L=da+M|0;c[t>>2]=na>>>0>L>>>0?L:na;na=H+pa|0;pa=na;H=(na|0)<0|0?-1:0;na=c[ea>>2]|0;ea=gHb(pa,H,na,(na|0)<0|0?-1:0)|0;na=YGb(ea,F,ia,ga)|0;ga=aHb(na|0,F|0,ha|0)|0;c[f+9376+(T<<7)+(I<<2)>>2]=ga;ga=c[fa>>2]|0;fa=gHb(pa,H,ga,(ga|0)<0|0?-1:0)|0;ga=YGb(fa,F,C,K)|0;K=aHb(ga|0,F|0,ma|0)|0;c[f+13984+(T<<7)+(I<<2)>>2]=K;break}K=c[t>>2]|0;ma=c[x>>2]|0;ga=(c[Y>>2]|0)+(K>>>3)|0;C=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(K&7)>>>((M+32|0)>>>0);ga=K-M|0;c[t>>2]=ma>>>0>ga>>>0?ga:ma;ma=c[1180728+(N<<2)>>2]|0;N=(C|0)/(ma|0)|0;ga=e[4313104+(J<<1)>>1]|0;J=ga>>>2;M=ma>>1;K=((C|0)%(ma|0)|0)-M|0;C=ma>>2;fa=c[479776+(C*12|0)+((ga&3)<<2)>>2]|0;ga=ba(fa,K)|0;H=(J|0)==0;if(H){qa=ga}else{qa=(1<<J-1)+ga>>J}c[f+9376+(R<<7)+(I<<2)>>2]=qa;ga=e[4313104+(E<<1)>>1]|0;E=ga>>>2;pa=c[479776+(C*12|0)+((ga&3)<<2)>>2]|0;ga=ba(pa,K)|0;K=(E|0)==0;if(K){ra=ga}else{ra=(1<<E-1)+ga>>E}c[f+13984+(R<<7)+(I<<2)>>2]=ra;ga=((N|0)%(ma|0)|0)-M|0;C=ba(ga,fa)|0;if(H){sa=C}else{sa=C+(1<<J-1)>>J}c[f+9376+(Q<<7)+(I<<2)>>2]=sa;C=ba(ga,pa)|0;if(K){ta=C}else{ta=C+(1<<E-1)>>E}c[f+13984+(Q<<7)+(I<<2)>>2]=ta;C=((N|0)/(ma|0)|0)-M|0;M=ba(C,fa)|0;if(H){ua=M}else{ua=M+(1<<J-1)>>J}c[f+9376+(T<<7)+(I<<2)>>2]=ua;J=ba(C,pa)|0;if(K){va=J}else{va=J+(1<<E-1)>>E}c[f+13984+(T<<7)+(I<<2)>>2]=va}}while(0);P=I+1|0;if((P|0)<(V|0)){O=(1<<U)+O|0;I=P}else{break}}}if(ca){I=Z+n|0;O=I+1|0;T=I+2|0;Q=V;R=c[S>>2]|0;while(1){if((R|0)>0){P=0;while(1){c[f+9376+(P*4608|0)+(I<<7)+(Q<<2)>>2]=0;c[f+9376+(P*4608|0)+(O<<7)+(Q<<2)>>2]=0;c[f+9376+(P*4608|0)+(T<<7)+(Q<<2)>>2]=0;B=P+1|0;E=c[S>>2]|0;if((B|0)<(E|0)){P=B}else{wa=E;break}}}else{wa=R}P=Q+1|0;if((P|0)<32){Q=P;R=wa}else{break}}}Z=Z+3|0;}while((Z|0)<12);Z=aa+1|0;if((Z|0)<3){aa=Z}else{_=36;break}}}else if((A|0)==3){A=f+36|0;c[(c[f+32940>>2]|0)+424>>2]=(c[A>>2]|0)!=0?576:1152;xa=c[t>>2]|0;ya=c[x>>2]|0;za=A;D=112}else{xa=z;ya=w;za=f+36|0;D=112}do{if((D|0)==112){w=(c[za>>2]|0)==0;z=v+(xa>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(xa&7);do{if(w){z=A>>>23;aa=xa+9|0;wa=ya>>>0>aa>>>0?aa:ya;c[t>>2]=wa;aa=c[f+24>>2]|0;if((aa|0)==2){S=wa+3|0;V=ya>>>0>S>>>0?S:ya;c[t>>2]=V;Aa=0;Ba=V}else{V=wa+5|0;wa=ya>>>0>V>>>0?V:ya;c[t>>2]=wa;if((aa|0)>0){Aa=0;Ba=wa}else{Ca=2;Da=z;Ea=aa;break}}while(1){a[f+23200+(Aa*4864|0)|0]=0;wa=v+(Ba>>>3)|0;V=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Ba&7)>>>28;wa=Ba+4|0;S=ya>>>0>wa>>>0?wa:ya;c[t>>2]=S;a[f+23200+(Aa*4864|0)+2432|0]=V;V=Aa+1|0;if((V|0)<(aa|0)){Aa=V;Ba=S}else{Ca=2;Da=z;Ea=aa;break}}}else{aa=xa+8|0;z=c[f+24>>2]|0;S=z+(ya>>>0>aa>>>0?aa:ya)|0;c[t>>2]=ya>>>0>S>>>0?S:ya;Ca=1;Da=A>>>24;Ea=z}}while(0);A=f+24|0;w=f+32|0;z=f+16|0;S=f+32940|0;aa=0;V=Ea;wa=ya;ca=v;a:while(1){if((V|0)>0){va=0;ua=wa;ta=ca;while(1){sa=c[t>>2]|0;ra=ta+(sa>>>3)|0;qa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>20;ra=sa+12|0;sa=ua>>>0>ra>>>0?ra:ua;c[t>>2]=sa;c[f+23200+(va*4864|0)+(aa*2432|0)+4>>2]=qa;qa=ta+(sa>>>3)|0;ra=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(sa&7);qa=ra>>>23;Y=sa+9|0;sa=ua>>>0>Y>>>0?Y:ua;c[t>>2]=sa;c[f+23200+(va*4864|0)+(aa*2432|0)+8>>2]=qa;if(ra>>>0>2424307711>>>0){D=121;break a}ra=ta+(sa>>>3)|0;Y=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>24;ra=sa+8|0;sa=ua>>>0>ra>>>0?ra:ua;c[t>>2]=sa;ra=f+23200+(va*4864|0)+(aa*2432|0)+12|0;c[ra>>2]=Y;if((c[w>>2]&3|0)==2){c[ra>>2]=Y-2}Y=c[za>>2]|0;ra=ta+(sa>>>3)|0;W=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7);if((Y|0)==0){ra=sa+4|0;l=ua>>>0>ra>>>0?ra:ua;c[t>>2]=l;c[f+23200+(va*4864|0)+(aa*2432|0)+16>>2]=W>>>28;Fa=l}else{l=sa+9|0;sa=ua>>>0>l>>>0?l:ua;c[t>>2]=sa;c[f+23200+(va*4864|0)+(aa*2432|0)+16>>2]=W>>>23;Fa=sa}sa=d[ta+(Fa>>>3)|0]|0;W=((Fa|0)<(ua|0))+Fa|0;c[t>>2]=W;if((sa&128>>>((Fa&7)>>>0)|0)==0){a[f+23200+(va*4864|0)+(aa*2432|0)+20|0]=0;a[f+23200+(va*4864|0)+(aa*2432|0)+21|0]=0;sa=ta+(W>>>3)|0;l=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(W&7)>>>27;sa=W+5|0;ra=ua>>>0>sa>>>0?sa:ua;c[t>>2]=ra;c[f+23200+(va*4864|0)+(aa*2432|0)+24>>2]=l;l=ta+(ra>>>3)|0;sa=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(ra&7)>>>27;l=ra+5|0;ra=ua>>>0>l>>>0?l:ua;c[t>>2]=ra;c[f+23200+(va*4864|0)+(aa*2432|0)+28>>2]=sa;sa=ta+(ra>>>3)|0;l=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ra&7)>>>27;sa=ra+5|0;ra=ua>>>0>sa>>>0?sa:ua;c[t>>2]=ra;c[f+23200+(va*4864|0)+(aa*2432|0)+32>>2]=l;l=ta+(ra>>>3)|0;sa=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(ra&7)>>>28;l=ra+4|0;ra=ua>>>0>l>>>0?l:ua;c[t>>2]=ra;l=ta+(ra>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(ra&7)>>>29;l=ra+3|0;c[t>>2]=ua>>>0>l>>>0?l:ua;l=c[z>>2]|0;ra=(e[8878640+(l*46|0)+(sa+1<<1)>>1]|0)>>>1;X=f+23200+(va*4864|0)+(aa*2432|0)+52|0;c[X>>2]=ra;la=sa+2+m|0;m=(e[8878640+(l*46|0)+(((la|0)>22?22:la)<<1)>>1]|0)>>>1;c[f+23200+(va*4864|0)+(aa*2432|0)+56>>2]=m;Ga=ra;Ha=m;Ia=0;Ja=0;Ka=l;La=X}else{X=ta+(W>>>3)|0;l=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(W&7)>>>30;X=W+2|0;W=ua>>>0>X>>>0?X:ua;c[t>>2]=W;X=l&255;a[f+23200+(va*4864|0)+(aa*2432|0)+20|0]=X;if((l|0)==0){D=129;break a}l=d[ta+(W>>>3)|0]<<(W&7)>>>7;m=((W|0)<(ua|0))+W|0;c[t>>2]=m;W=l&1;a[f+23200+(va*4864|0)+(aa*2432|0)+21|0]=W;l=ta+(m>>>3)|0;ra=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>27;l=m+5|0;m=ua>>>0>l>>>0?l:ua;c[t>>2]=m;c[f+23200+(va*4864|0)+(aa*2432|0)+24>>2]=ra;ra=ta+(m>>>3)|0;l=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(m&7)>>>27;ra=m+5|0;m=ua>>>0>ra>>>0?ra:ua;c[t>>2]=m;c[f+23200+(va*4864|0)+(aa*2432|0)+28>>2]=l;l=ta+(m>>>3)|0;ra=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>29;l=m+3|0;m=ua>>>0>l>>>0?l:ua;c[t>>2]=m;c[f+23200+(va*4864|0)+(aa*2432|0)+36>>2]=ra;ra=ta+(m>>>3)|0;l=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(m&7)>>>29;ra=m+3|0;m=ua>>>0>ra>>>0?ra:ua;c[t>>2]=m;c[f+23200+(va*4864|0)+(aa*2432|0)+40>>2]=l;l=(c[j>>2]|0)+(m>>>3)|0;ra=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>29;l=m+3|0;c[t>>2]=ua>>>0>l>>>0?l:ua;c[f+23200+(va*4864|0)+(aa*2432|0)+44>>2]=ra;ra=c[z>>2]|0;l=X<<24>>24==2;do{if(l){X=f+23200+(va*4864|0)+(aa*2432|0)+52|0;if((ra|0)==8){c[X>>2]=36;Ma=36;break}else{c[X>>2]=18;Ma=18;break}}else{if((ra|0)<3){c[f+23200+(va*4864|0)+(aa*2432|0)+52>>2]=18;Ma=18;break}X=f+23200+(va*4864|0)+(aa*2432|0)+52|0;if((ra|0)==8){c[X>>2]=54;Ma=54;break}else{c[X>>2]=27;Ma=27;break}}}while(0);c[f+23200+(va*4864|0)+(aa*2432|0)+56>>2]=288;Ga=Ma;Ha=288;Ia=l;Ja=W;Ka=ra;La=f+23200+(va*4864|0)+(aa*2432|0)+52|0}X=(Ga|0)>(qa|0)?qa:Ga;c[La>>2]=X;m=Ha>>>0>qa>>>0?qa:Ha;c[f+23200+(va*4864|0)+(aa*2432|0)+56>>2]=m-X;c[f+23200+(va*4864|0)+(aa*2432|0)+60>>2]=(qa>>>0<288>>>0?qa:288)-m;do{if(Ia){if(Ja<<24>>24==0){c[f+23200+(va*4864|0)+(aa*2432|0)+72>>2]=0;c[f+23200+(va*4864|0)+(aa*2432|0)+68>>2]=0;Na=Y;break}if((Ka|0)==8){DDb(c[S>>2]|0,2132504,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Pa=c[z>>2]|0;Qa=c[za>>2]|0}else{Pa=Ka;Qa=Y}c[f+23200+(va*4864|0)+(aa*2432|0)+72>>2]=(Pa|0)<3?8:6;c[f+23200+(va*4864|0)+(aa*2432|0)+68>>2]=3;Na=Qa}else{c[f+23200+(va*4864|0)+(aa*2432|0)+68>>2]=13;c[f+23200+(va*4864|0)+(aa*2432|0)+72>>2]=22;Na=Y}}while(0);Y=f+23200+(va*4864|0)+(aa*2432|0)+64|0;c[Y>>2]=0;qa=c[t>>2]|0;if((Na|0)==0){ra=c[j>>2]|0;W=d[ra+(qa>>>3)|0]<<(qa&7)>>>7;l=c[x>>2]|0;m=((qa|0)<(l|0))+qa|0;c[t>>2]=m;c[Y>>2]=W&1;Ra=m;Sa=ra;Ta=l}else{Ra=qa;Sa=c[j>>2]|0;Ta=c[x>>2]|0}qa=d[Sa+(Ra>>>3)|0]<<(Ra&7)>>>7;c[t>>2]=((Ra|0)<(Ta|0))+Ra;a[f+23200+(va*4864|0)+(aa*2432|0)+48|0]=qa&1;qa=c[t>>2]|0;l=d[Sa+(qa>>>3)|0]<<(qa&7)>>>7;c[t>>2]=((qa|0)<(Ta|0))+qa;a[f+23200+(va*4864|0)+(aa*2432|0)+49|0]=l&1;l=va+1|0;qa=c[A>>2]|0;if((l|0)<(qa|0)){va=l;ua=Ta;ta=Sa}else{Ua=qa;Va=Ta;Wa=Sa;break}}}else{Ua=V;Va=wa;Wa=ca}ta=aa+1|0;if((ta|0)<(Ca|0)){aa=ta;V=Ua;wa=Va;ca=Wa}else{D=153;break}}if((D|0)==121){yDb(c[S>>2]|0,16,2158424,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Xa=-1094995529}else if((D|0)==129){yDb(c[S>>2]|0,16,2151424,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Xa=-1094995529}else if((D|0)==153){do{if((c[f+32928>>2]|0)==0){ca=c[t>>2]|0;wa=(c[u>>2]|0)-ca>>3;if((wa|0)<0){Ya=0}else{Ya=(wa|0)>24?24:wa}wa=f+40|0;V=f+1088|0;UGb((c[V>>2]|0)+(f+40)|0,Wa+(ca>>3)|0,Ya)|0;ca=f+1116|0;aa=ca;ta=s;c[aa>>2]=c[ta>>2];c[aa+4>>2]=c[ta+4>>2];c[aa+8>>2]=c[ta+8>>2];c[aa+12>>2]=c[ta+12>>2];c[aa+16>>2]=c[ta+16>>2];ua=c[V>>2]|0;va=ua<<3;qa=va>>>0>2147483639>>>0|(wa|0)==0;l=qa?0:wa;wa=qa?0:va;c[j>>2]=l;c[u>>2]=wa;c[y>>2]=l+(wa>>3);c[t>>2]=0;l=1048-ua|0;c[x>>2]=wa+8+(((Ya|0)>(l|0)?Ya:l)<<3);c[V>>2]=va;l=0;wa=va;while(1){if((wa>>3|0)>=(Da|0)){Za=l;_a=wa;break}if((c[A>>2]|0)>0){va=l*18|0;ua=0;qa=wa;while(1){c[V>>2]=(c[f+23200+(ua*4864|0)+(l*2432|0)+4>>2]|0)+qa;TGb(f+23200+(ua*4864|0)+(l*2432|0)+128|0,0,2304)|0;PNa(f,f+23200+(ua*4864|0)+(l*2432|0)|0,f+9376+(ua*4608|0)+(va<<7)|0,f+18592+(ua*2304|0)|0);ra=ua+1|0;m=c[V>>2]|0;if((ra|0)<(c[A>>2]|0)){ua=ra;qa=m}else{$a=m;break}}}else{$a=wa}qa=l+1|0;if((qa|0)<(Ca|0)){l=qa;wa=$a}else{Za=qa;_a=$a;break}}wa=_a-(Da<<3)|0;l=c[u>>2]|0;do{if((wa|0)<(l|0)){D=168}else{V=ca|0;if((c[V>>2]|0)==0){D=168;break}qa=wa-l|0;ua=f+1124|0;va=c[ua>>2]|0;m=-va|0;ra=(c[f+1132>>2]|0)-va|0;if((qa|0)<(m|0)){ab=m}else{ab=(ra|0)<(qa|0)?ra:qa}c[ua>>2]=ab+va;c[ta>>2]=c[aa>>2];c[ta+4>>2]=c[aa+4>>2];c[ta+8>>2]=c[aa+8>>2];c[ta+12>>2]=c[aa+12>>2];c[ta+16>>2]=c[aa+16>>2];c[V>>2]=0}}while(0);if((D|0)==168){l=c[t>>2]|0;V=-l|0;va=(c[x>>2]|0)-l|0;if((wa|0)<(V|0)){bb=V}else{bb=(va|0)<(wa|0)?va:wa}c[t>>2]=bb+l}if((Za|0)>=(Ca|0)){break}cb=Za;db=c[A>>2]|0;eb=ca;fb=ta;gb=aa;D=173}else{l=f+1116|0;cb=0;db=Ua;eb=l;fb=s;gb=l;D=173}}while(0);if((D|0)==173){l=f+28|0;va=o|0;V=o+4|0;ua=o+8|0;qa=p;ra=p|0;m=q|0;W=eb|0;Y=f+32936|0;X=r|0;la=r+12|0;sa=r+8|0;G=r+4|0;ka=cb;ja=0;$=db;while(1){Z=ja+cb|0;if(($|0)>0){n=0;R=c[t>>2]|0;while(1){Q=f+23200+(n*4864|0)+(Z*2432|0)+76|0;do{if((c[za>>2]|0)==0){T=c[f+23200+(n*4864|0)+(ka*2432|0)+16>>2]|0;O=a[435824+T|0]|0;I=O&255;P=a[435840+T|0]|0;T=P&255;if((a[f+23200+(n*4864|0)+(ka*2432|0)+20|0]|0)==2){U=(a[f+23200+(n*4864|0)+(ka*2432|0)+21|0]|0)!=0?17:18;b:do{if(O<<24>>24==0){TGb(Q|0,0,U|0)|0}else{E=32-I|0;B=0;J=R;while(1){K=c[x>>2]|0;pa=(c[j>>2]|0)+(J>>>3)|0;C=(fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(J&7)>>>(E>>>0);pa=J+I|0;c[t>>2]=K>>>0>pa>>>0?pa:K;K=B+1|0;a[f+23200+(n*4864|0)+(ka*2432|0)+76+B|0]=C;if((K|0)>=(U|0)){break b}B=K;J=c[t>>2]|0}}}while(0);if(P<<24>>24==0){TGb(f+23200+(n*4864|0)+(Z*2432|0)+76+U|0,0,21)|0;break}O=32-T|0;J=U;B=0;while(1){E=c[t>>2]|0;K=c[x>>2]|0;C=(c[j>>2]|0)+(E>>>3)|0;pa=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>(O>>>0);C=E+T|0;c[t>>2]=K>>>0>C>>>0?C:K;a[f+23200+(n*4864|0)+(ka*2432|0)+76+J|0]=pa;pa=B+1|0;if((pa|0)<18){J=J+1|0;B=pa}else{break}}TGb(U+18+(f+23200+(n*4864|0)+(Z*2432|0)+76)|0,0,3)|0;break}else{B=f+23200+(n*4864|0)+(ka*2432|0)|0;J=0;O=0;while(1){P=(J|0)==0?6:5;c:do{if((d[B]&8>>>(J>>>0)|0)==0){pa=(J|0)<2?I:T;if((pa|0)==0){TGb(f+23200+(n*4864|0)+(Z*2432|0)+76+O|0,0,P|0)|0;break}K=32-pa|0;C=O;E=1;while(1){M=c[t>>2]|0;H=c[x>>2]|0;fa=(c[j>>2]|0)+(M>>>3)|0;ma=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(M&7)>>>(K>>>0);fa=M+pa|0;c[t>>2]=H>>>0>fa>>>0?fa:H;a[f+23200+(n*4864|0)+(ka*2432|0)+76+C|0]=ma;if((E|0)>=(P|0)){break c}C=C+1|0;E=E+1|0}}else{E=O;C=0;while(1){a[f+23200+(n*4864|0)+(ka*2432|0)+76+E|0]=a[f+23200+(n*4864|0)+76+E|0]|0;pa=C+1|0;if((pa|0)<(P|0)){E=E+1|0;C=pa}else{break}}}}while(0);C=J+1|0;if((C|0)<4){J=C;O=P+O|0}else{break}}a[f+23200+(n*4864|0)+(ka*2432|0)+97|0]=0;break}}else{if((a[f+23200+(n*4864|0)+(ka*2432|0)+20|0]|0)==2){hb=(a[f+23200+(n*4864|0)+(ka*2432|0)+21|0]|0)!=0?2:1}else{hb=0}O=c[f+23200+(n*4864|0)+(ka*2432|0)+16>>2]|0;do{if((c[w>>2]&1|0)!=0&(n|0)==1){J=O>>1;if((J|0)<180){c[la>>2]=0;T=(J*171|0)>>10;c[sa>>2]=(T*-6|0)+J;I=(T*171|0)>>10;c[G>>2]=(I*-6|0)+T;c[X>>2]=I;ib=3;jb=I;break}if((J|0)<244){I=J-180|0;c[la>>2]=0;c[sa>>2]=I&3;c[G>>2]=I>>>2&3;T=I>>4;c[X>>2]=T;ib=4;jb=T;break}else{T=J-244|0;c[la>>2]=0;c[sa>>2]=0;J=(T*171|0)>>9;c[G>>2]=(J*-3|0)+T;c[X>>2]=J;ib=5;jb=J;break}}else{if((O|0)<400){c[la>>2]=O&3;c[sa>>2]=O>>>2&3;J=O>>4;T=(J*205|0)>>10;c[G>>2]=(T*-5|0)+J;c[X>>2]=T;ib=0;jb=T;break}if((O|0)<500){T=O-400|0;c[la>>2]=0;c[sa>>2]=T&3;J=T>>2;T=(J*205|0)>>10;c[G>>2]=(T*-5|0)+J;c[X>>2]=T;ib=1;jb=T;break}else{T=O-500|0;c[la>>2]=0;c[sa>>2]=0;J=(T*171|0)>>9;c[G>>2]=(J*-3|0)+T;c[X>>2]=J;c[f+23200+(n*4864|0)+(ka*2432|0)+64>>2]=1;ib=2;jb=J;break}}}while(0);O=0;J=0;T=jb;while(1){I=a[730872+(ib*12|0)+(hb<<2)+O|0]|0;B=I&255;U=I<<24>>24==0;do{if((T|0)==0){if(U){kb=J;break}I=B>>>0>1>>>0?B:1;TGb(f+23200+(n*4864|0)+(Z*2432|0)+76+J|0,0,I|0)|0;kb=I+J|0}else{if(U){kb=J;break}I=32-T|0;C=B>>>0>1>>>0;E=J;pa=1;while(1){K=c[t>>2]|0;ma=c[x>>2]|0;H=(c[j>>2]|0)+(K>>>3)|0;fa=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(K&7)>>>(I>>>0);H=K+T|0;c[t>>2]=ma>>>0>H>>>0?H:ma;a[f+23200+(n*4864|0)+(ka*2432|0)+76+E|0]=fa;if((pa|0)>=(B|0)){break}E=E+1|0;pa=pa+1|0}kb=(C?B:1)+J|0}}while(0);B=O+1|0;if((B|0)>=4){break}O=B;J=kb;T=c[r+(B<<2)>>2]|0}if((kb|0)>=40){break}TGb(f+23200+(n*4864|0)+(Z*2432|0)+76+kb|0,0,40-kb|0)|0}}while(0);Q=c[z>>2]|0;T=c[f+23200+(n*4864|0)+(ka*2432|0)+12>>2]|0;J=(d[f+23200+(n*4864|0)+(ka*2432|0)+48|0]|0)+1|0;O=c[f+23200+(n*4864|0)+(ka*2432|0)+64>>2]|0;B=c[f+23200+(n*4864|0)+(ka*2432|0)+72>>2]|0;if((B|0)>0){U=T+190|0;P=0;pa=m;while(1){E=a[1738704+(Q*22|0)+P|0]|0;if(E<<24>>24==0){lb=pa}else{I=E&255;E=U-((d[f+23200+(n*4864|0)+(ka*2432|0)+76+P|0]|0)+(d[662008+(O*22|0)+P|0]|0)<<J)&65535;fa=-I|0;ma=I;H=pa;while(1){b[H>>1]=E;K=ma-1|0;if((K|0)>0){ma=K;H=H+2|0}else{break}}lb=pa+(I+1+((fa|0)>-1?fa:-1)<<1)|0}H=P+1|0;if((H|0)<(B|0)){P=H;pa=lb}else{mb=lb;break}}}else{mb=m}pa=c[f+23200+(n*4864|0)+(ka*2432|0)+68>>2]|0;if((pa|0)<13){P=T+190|0;O=P-(c[f+23200+(n*4864|0)+(ka*2432|0)+36>>2]<<3)|0;U=P-(c[f+23200+(n*4864|0)+(ka*2432|0)+40>>2]<<3)|0;H=P-(c[f+23200+(n*4864|0)+(ka*2432|0)+44>>2]<<3)|0;P=pa;pa=B;ma=mb;while(1){E=a[1738384+(Q*13|0)+P|0]|0;K=E&255;M=-K|0;N=(M|0)>-1?M:-1;M=pa+1|0;if(E<<24>>24==0){nb=ma}else{E=O-(d[f+23200+(n*4864|0)+(ka*2432|0)+76+pa|0]<<J)&65535;ga=K;ha=ma;while(1){b[ha>>1]=E;na=ga-1|0;if((na|0)>0){ga=na;ha=ha+2|0}else{break}}ha=K+1+N|0;ga=U-(d[f+23200+(n*4864|0)+(ka*2432|0)+76+M|0]<<J)&65535;E=K;fa=ma+(ha<<1)|0;while(1){b[fa>>1]=ga;I=E-1|0;if((I|0)>0){E=I;fa=fa+2|0}else{break}}fa=ha<<1;E=H-(d[pa+2+(f+23200+(n*4864|0)+(ka*2432|0)+76)|0]<<J)&65535;ga=K;M=ma+(fa<<1)|0;while(1){b[M>>1]=E;N=ga-1|0;if((N|0)>0){ga=N;M=M+2|0}else{break}}nb=ma+(fa+ha<<1)|0}M=P+1|0;if((M|0)<13){P=M;pa=pa+3|0;ma=nb}else{break}}}ma=(c[f+23200+(n*4864|0)+(ka*2432|0)+4>>2]|0)+R|0;pa=c[u>>2]|0;P=ma;J=(pa|0)<(ma|0)?pa:ma;ma=0;pa=0;while(1){H=c[f+23200+(n*4864|0)+(ka*2432|0)+52+(ma<<2)>>2]|0;d:do{if((H|0)==0){ob=pa;pb=J;qb=P}else{U=c[f+23200+(n*4864|0)+(ka*2432|0)+24+(ma<<2)>>2]|0;O=d[670856+(U<<1)|0]|0;Q=d[670857+(U<<1)|0]|0;if((16401>>>(U>>>0)&1|0)!=0){TGb(f+23200+(n*4864|0)+(ka*2432|0)+128+(pa<<2)|0,0,H<<3|0)|0;ob=(H<<1)+pa|0;pb=J;qb=P;break}if((H|0)<=0){ob=pa;pb=J;qb=P;break}B=5129684+(O*20|0)|0;O=U>>>0<16>>>0;U=32-Q|0;T=P;M=J;ga=H;E=pa;while(1){K=c[t>>2]|0;if((K|0)<(M|0)){rb=M;sb=T;tb=K}else{do{if((c[W>>2]|0)==0){ub=K;vb=M;wb=T}else{if((K|0)<(c[u>>2]|0)){ub=K;vb=M;wb=T;break}c[fb>>2]=c[gb>>2];c[fb+4>>2]=c[gb+4>>2];c[fb+8>>2]=c[gb+8>>2];c[fb+12>>2]=c[gb+12>>2];c[fb+16>>2]=c[gb+16>>2];c[W>>2]=0;N=K-M|0;I=c[t>>2]|0;na=-I|0;ia=(c[x>>2]|0)-I|0;if((N|0)<(na|0)){xb=na}else{xb=(ia|0)<(N|0)?ia:N}N=xb+I|0;c[t>>2]=N;I=N+(T-K)|0;ub=N;vb=I;wb=I}}while(0);if((ub|0)<(vb|0)){rb=vb;sb=wb;tb=ub}else{ob=E;pb=vb;qb=wb;break d}}K=c[B>>2]|0;C=c[x>>2]|0;I=c[j>>2]|0;N=I+(tb>>>3)|0;ia=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(tb&7)>>>25;N=b[K+(ia<<2)>>1]|0;na=b[K+(ia<<2)+2>>1]|0;ia=na<<16>>16;do{if(na<<16>>16<0){ea=tb+7|0;L=C>>>0>ea>>>0?ea:C;ea=I+(L>>>3)|0;da=((fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(L&7)>>>((ia+32|0)>>>0))+N|0;ea=b[K+(da<<2)>>1]|0;oa=b[K+(da<<2)+2>>1]|0;da=oa<<16>>16;if(!(oa<<16>>16<0)){yb=da;zb=ea;Ab=L;break}oa=L-ia|0;L=C>>>0>oa>>>0?oa:C;oa=I+(L>>>3)|0;Bb=((fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(L&7)>>>((da+32|0)>>>0))+ea|0;yb=b[K+(Bb<<2)+2>>1]|0;zb=b[K+(Bb<<2)>>1]|0;Ab=L}else{yb=ia;zb=N;Ab=tb}}while(0);N=yb+Ab|0;ia=C>>>0>N>>>0?N:C;c[t>>2]=ia;do{if((zb|0)==0){c[f+23200+(n*4864|0)+(ka*2432|0)+128+(E+1<<2)>>2]=0;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(E<<2)>>2]=0}else{N=b[q+(E<<1)>>1]|0;K=zb>>5;na=zb&15;if((zb&16|0)==0){L=K+na|0;if((L|0)<15){Bb=d[I+(ia>>>3)|0]<<(ia&7)>>>7;c[t>>2]=((ia|0)<(C|0))+ia;ea=Bb&1;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(((na|0)!=0)+E<<2)>>2]=(c[8117688+(N<<6)+(L<<2)>>2]^-ea)+ea}else{if(O){Cb=0;Db=ia}else{ea=I+(ia>>>3)|0;Bb=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ia&7)>>>(U>>>0);ea=ia+Q|0;da=C>>>0>ea>>>0?ea:C;c[t>>2]=da;Cb=Bb;Db=da}da=Cb+L<<2|N&3;L=(a[4241456+da|0]|0)-(N>>2)|0;if((L|0)>31){Eb=0}else{Eb=((c[4077312+(da<<2)>>2]|0)+(1<<L-1)|0)>>>(L>>>0)}L=d[I+(Db>>>3)|0]|0;c[t>>2]=((Db|0)<(C|0))+Db;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(((na|0)!=0)+E<<2)>>2]=(L&128>>>((Db&7)>>>0)|0)==0?Eb:-Eb|0}c[f+23200+(n*4864|0)+(ka*2432|0)+128+(((na|0)==0)+E<<2)>>2]=0;break}if((K|0)<15){L=d[I+(ia>>>3)|0]<<(ia&7)>>>7;c[t>>2]=((ia|0)<(C|0))+ia;da=L&1;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(E<<2)>>2]=(c[8117688+(N<<6)+(K<<2)>>2]^-da)+da}else{if(O){Fb=0;Gb=ia}else{da=I+(ia>>>3)|0;L=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ia&7)>>>(U>>>0);da=ia+Q|0;Bb=C>>>0>da>>>0?da:C;c[t>>2]=Bb;Fb=L;Gb=Bb}Bb=Fb+K<<2|N&3;K=(a[4241456+Bb|0]|0)-(N>>2)|0;if((K|0)>31){Hb=0}else{Hb=((c[4077312+(Bb<<2)>>2]|0)+(1<<K-1)|0)>>>(K>>>0)}K=d[I+(Gb>>>3)|0]|0;c[t>>2]=((Gb|0)<(C|0))+Gb;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(E<<2)>>2]=(K&128>>>((Gb&7)>>>0)|0)==0?Hb:-Hb|0}if((na|0)!=15){K=c[t>>2]|0;Bb=d[I+(K>>>3)|0]<<(K&7)>>>7;c[t>>2]=((K|0)<(c[x>>2]|0))+K;K=Bb&1;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(E+1<<2)>>2]=(c[8117688+(N<<6)+(na<<2)>>2]^-K)+K;break}if(O){Ib=60}else{K=c[t>>2]|0;na=c[x>>2]|0;Bb=I+(K>>>3)|0;L=(fe(d[Bb]|d[Bb+1|0]<<8|d[Bb+2|0]<<16|d[Bb+3|0]<<24|0)|0)<<(K&7)>>>(U>>>0);Bb=K+Q|0;c[t>>2]=na>>>0>Bb>>>0?Bb:na;Ib=(L<<2)+60|0}L=Ib|N&3;na=(a[4241456+L|0]|0)-(N>>2)|0;if((na|0)>31){Jb=0}else{Jb=((c[4077312+(L<<2)>>2]|0)+(1<<na-1)|0)>>>(na>>>0)}na=c[t>>2]|0;L=d[I+(na>>>3)|0]|0;c[t>>2]=((na|0)<(c[x>>2]|0))+na;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(E+1<<2)>>2]=(L&128>>>((na&7)>>>0)|0)==0?Jb:-Jb|0}}while(0);I=E+2|0;C=ga-1|0;if((C|0)>0){T=sb;M=rb;ga=C;E=I}else{ob=I;pb=rb;qb=sb;break}}}}while(0);H=ma+1|0;if((H|0)<3){P=qb;J=pb;ma=H;pa=ob}else{break}}pa=d[f+23200+(n*4864|0)+(ka*2432|0)+49|0]|0;e:do{if((ob|0)<573){ma=5131260+(pa*20|0)|0;J=5131256+(pa*20|0)|0;P=qb;H=pb;ha=0;fa=ob;while(1){Kb=c[t>>2]|0;if((Kb|0)<(H|0)){Lb=Kb;Mb=H;Nb=P}else{if(!((Kb|0)<=(P|0)|(ha|0)==0)){break}do{if((c[W>>2]|0)==0){Ob=Kb;Pb=H;Qb=P}else{if((Kb|0)<(c[u>>2]|0)){Ob=Kb;Pb=H;Qb=P;break}c[fb>>2]=c[gb>>2];c[fb+4>>2]=c[gb+4>>2];c[fb+8>>2]=c[gb+8>>2];c[fb+12>>2]=c[gb+12>>2];c[fb+16>>2]=c[gb+16>>2];c[W>>2]=0;E=Kb-H|0;ga=c[t>>2]|0;M=-ga|0;T=(c[x>>2]|0)-ga|0;if((E|0)<(M|0)){Rb=M}else{Rb=(T|0)<(E|0)?T:E}E=Rb+ga|0;c[t>>2]=E;ga=E+(P-Kb)|0;Ob=E;Pb=ga;Qb=ga}}while(0);if((Ob|0)<(Pb|0)){Lb=Ob;Mb=Pb;Nb=Qb}else{Sb=fa;Tb=Pb;Ub=Qb;break e}}ga=c[ma>>2]|0;E=c[J>>2]|0;T=c[x>>2]|0;M=c[j>>2]|0;Q=M+(Lb>>>3)|0;U=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(Lb&7)>>>((32-E|0)>>>0);E=b[ga+(U<<2)>>1]|0;Q=(b[ga+(U<<2)+2>>1]|0)+Lb|0;c[t>>2]=T>>>0>Q>>>0?Q:T;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(fa+3<<2)>>2]=0;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(fa+2<<2)>>2]=0;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(fa+1<<2)>>2]=0;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(fa<<2)>>2]=0;if(!(E<<16>>16==0)){T=E<<16>>16;while(1){E=c[918880+(T<<2)>>2]|0;Q=E+fa|0;U=8>>>(E>>>0);E=c[t>>2]|0;ga=d[M+(E>>>3)|0]<<(E&7)>>>7;c[t>>2]=((E|0)<(c[x>>2]|0))+E;E=ga&1;c[f+23200+(n*4864|0)+(ka*2432|0)+128+(Q<<2)>>2]=(c[8154040+(b[q+(Q<<1)>>1]<<2)>>2]^-E)+E;if((U|0)==(T|0)){break}else{T=U^T}}}T=fa+4|0;if((T|0)<573){P=Nb;H=Mb;ha=Lb;fa=T}else{Sb=T;Tb=Mb;Ub=Nb;break e}}J=ha-Kb|0;ma=-Kb|0;T=(c[x>>2]|0)-Kb|0;if((J|0)<(ma|0)){Vb=ma}else{Vb=(T|0)<(J|0)?T:J}c[t>>2]=Vb+Kb;yDb(c[S>>2]|0,32,2144408,(Oa=i,i=i+24|0,c[Oa>>2]=J,c[Oa+8>>2]=H-Kb,c[Oa+16>>2]=P-Kb,Oa)|0);i=Oa;Sb=(c[Y>>2]&131074|0)==0?fa-4|0:0;Tb=H;Ub=P}else{Sb=ob;Tb=pb;Ub=qb}}while(0);pa=Ub-(c[t>>2]|0)|0;do{if((pa|0)<0){if((c[Y>>2]&131076|0)==0){D=305;break}yDb(c[S>>2]|0,16,2138768,(Oa=i,i=i+8|0,c[Oa>>2]=pa,Oa)|0);i=Oa;Wb=0}else{D=305}}while(0);do{if((D|0)==305){D=0;if((pa|0)<=0){Wb=Sb;break}if((c[Y>>2]&262148|0)==0){Wb=Sb;break}yDb(c[S>>2]|0,16,2138768,(Oa=i,i=i+8|0,c[Oa>>2]=pa,Oa)|0);i=Oa;Wb=0}}while(0);TGb(f+23200+(n*4864|0)+(ka*2432|0)+128+(Wb<<2)|0,0,576-Wb<<2|0)|0;J=c[t>>2]|0;T=-J|0;ma=(c[x>>2]|0)-J|0;if((pa|0)<(T|0)){Xb=T}else{Xb=(ma|0)<(pa|0)?ma:pa}ma=Xb+J|0;c[t>>2]=ma;do{if((c[W>>2]|0)==0){Yb=ma}else{if((ma|0)<(c[u>>2]|0)){Yb=ma;break}c[fb>>2]=c[gb>>2];c[fb+4>>2]=c[gb+4>>2];c[fb+8>>2]=c[gb+8>>2];c[fb+12>>2]=c[gb+12>>2];c[fb+16>>2]=c[gb+16>>2];c[W>>2]=0;J=ma-Tb|0;T=c[t>>2]|0;M=-T|0;U=(c[x>>2]|0)-T|0;if((J|0)<(M|0)){Zb=M}else{Zb=(U|0)<(J|0)?U:J}J=Zb+T|0;c[t>>2]=J;Yb=J}}while(0);ma=n+1|0;if((ma|0)<(c[A>>2]|0)){n=ma;R=Yb}else{break}}}f:do{if((c[l>>2]|0)==1){R=c[w>>2]|0;if((R&1|0)==0){if((R&2|0)==0){break}else{_b=0}while(1){R=f+23200+(ka*2432|0)+128+(_b<<2)|0;n=c[R>>2]|0;Z=f+28064+(ka*2432|0)+128+(_b<<2)|0;aa=c[Z>>2]|0;c[R>>2]=aa+n;c[Z>>2]=n-aa;_b=_b+1|0;if((_b|0)>=576){break f}}}if((c[za>>2]|0)==0){$b=5016216;ac=7}else{$b=5015832+((c[f+28064+(ka*2432|0)+16>>2]&1)<<7)|0;ac=16}aa=f+23200+(ka*2432|0)+2432|0;n=f+28064+(ka*2432|0)+2432|0;c[va>>2]=0;c[V>>2]=0;c[ua>>2]=0;Z=f+28064+(ka*2432|0)+68|0;R=c[Z>>2]|0;ta=f+28064+(ka*2432|0)+72|0;if((R|0)>12){bc=aa;cc=n}else{ca=12;wa=((13-R|0)*3|0)-3+(c[ta>>2]|0)|0;R=aa;aa=n;while(1){n=(ca|0)==11?wa:wa-3|0;ma=a[1738384+((c[z>>2]|0)*13|0)+ca|0]|0;pa=ma&255;J=-pa|0;T=ma<<24>>24==0;ma=2;U=R;M=aa;while(1){E=U+(J<<2)|0;Q=M+(J<<2)|0;ga=o+(ma<<2)|0;do{if((c[ga>>2]|0)==0){O=0;while(1){if((O|0)>=(pa|0)){break}if((c[M+(O-pa<<2)>>2]|0)==0){O=O+1|0}else{D=326;break}}if((D|0)==326){D=0;c[ga>>2]=1;D=331;break}O=d[ma+n+(f+28064+(ka*2432|0)+76)|0]|0;if(!(O>>>0<ac>>>0)){D=331;break}if(T){break}B=c[$b+64+(O<<2)>>2]|0;I=c[$b+(O<<2)>>2]|0;O=I;C=(I|0)<0|0?-1:0;I=B;ia=(B|0)<0|0?-1:0;B=0;do{na=B-pa|0;L=U+(na<<2)|0;N=c[L>>2]|0;Bb=N;K=(N|0)<0|0?-1:0;N=gHb(Bb,K,O,C)|0;c[L>>2]=N>>>23|F<<9;N=gHb(Bb,K,I,ia)|0;c[M+(na<<2)>>2]=N>>>23|F<<9;B=B+1|0;}while((B|0)<(pa|0))}else{D=331}}while(0);do{if((D|0)==331){D=0;if((c[w>>2]&2|0)==0|T){break}else{dc=0}do{ga=dc-pa|0;B=U+(ga<<2)|0;ia=c[B>>2]|0;I=M+(ga<<2)|0;ga=c[I>>2]|0;C=ga+ia|0;O=gHb(C,(C|0)<0|0?-1:0,5931642,0)|0;c[B>>2]=O>>>23|F<<9;O=ia-ga|0;ga=gHb(O,(O|0)<0|0?-1:0,5931642,0)|0;c[I>>2]=ga>>>23|F<<9;dc=dc+1|0;}while((dc|0)<(pa|0))}}while(0);if((ma|0)<=0){break}ma=ma-1|0;U=E;M=Q}M=pa*-3|0;U=aa+(M<<2)|0;ma=R+(M<<2)|0;M=ca-1|0;if((M|0)<(c[Z>>2]|0)){bc=ma;cc=U;break}else{ca=M;wa=n;R=ma;aa=U}}}aa=c[ta>>2]|0;if((aa|0)<=0){break}R=c[va>>2]|c[V>>2]|c[ua>>2];wa=bc;ca=cc;Z=aa;while(1){aa=(R|0)==0;U=wa;ma=ca;M=Z;g:while(1){ec=M-1|0;fc=a[1738704+((c[z>>2]|0)*22|0)+ec|0]|0;gc=fc&255;T=-gc|0;hc=U+(T<<2)|0;ic=ma+(T<<2)|0;if(aa){jc=0}else{kc=R;break}while(1){if((jc|0)>=(gc|0)){break}if((c[ma+(jc-gc<<2)>>2]|0)==0){jc=jc+1|0}else{kc=1;break g}}Q=d[((ec|0)==21?20:ec)+(f+28064+(ka*2432|0)+76)|0]|0;if(!(Q>>>0<ac>>>0)){kc=R;break}if(!(fc<<24>>24==0)){E=c[$b+64+(Q<<2)>>2]|0;T=c[$b+(Q<<2)>>2]|0;Q=T;J=(T|0)<0|0?-1:0;T=E;P=(E|0)<0|0?-1:0;E=0;do{H=E-gc|0;fa=U+(H<<2)|0;ha=c[fa>>2]|0;ga=ha;I=(ha|0)<0|0?-1:0;ha=gHb(ga,I,Q,J)|0;c[fa>>2]=ha>>>23|F<<9;ha=gHb(ga,I,T,P)|0;c[ma+(H<<2)>>2]=ha>>>23|F<<9;E=E+1|0;}while((E|0)<(gc|0))}if((ec|0)>0){U=hc;ma=ic;M=ec}else{break f}}if(!((c[w>>2]&2|0)==0|fc<<24>>24==0)){M=0;do{aa=M-gc|0;n=U+(aa<<2)|0;pa=c[n>>2]|0;E=ma+(aa<<2)|0;aa=c[E>>2]|0;P=aa+pa|0;T=gHb(P,(P|0)<0|0?-1:0,5931642,0)|0;c[n>>2]=T>>>23|F<<9;T=pa-aa|0;aa=gHb(T,(T|0)<0|0?-1:0,5931642,0)|0;c[E>>2]=aa>>>23|F<<9;M=M+1|0;}while((M|0)<(gc|0))}if((ec|0)>0){R=kc;wa=hc;ca=ic;Z=ec}else{break}}}}while(0);Z=c[A>>2]|0;if((Z|0)>0){ca=ka*18|0;wa=0;while(1){R=f+23200+(wa*4864|0)+(ka*2432|0)|0;ta=f+23200+(wa*4864|0)+(ka*2432|0)+20|0;do{if((a[ta]|0)==2){M=f+23200+(wa*4864|0)+(ka*2432|0)+21|0;ma=a[M]|0;do{if(ma<<24>>24==0){lc=f+23200+(wa*4864|0)+(ka*2432|0)+128|0}else{if((c[z>>2]|0)==8){lc=f+23200+(wa*4864|0)+(ka*2432|0)+416|0;break}else{lc=f+23200+(wa*4864|0)+(ka*2432|0)+272|0;break}}}while(0);U=c[f+23200+(wa*4864|0)+(ka*2432|0)+68>>2]|0;if((U|0)<13){aa=lc;E=U;while(1){U=a[1738384+((c[z>>2]|0)*13|0)+E|0]|0;T=U&255;pa=T<<1;if(U<<24>>24==0){mc=aa}else{U=-T|0;n=T;P=aa;J=ra;while(1){c[J>>2]=c[P>>2];c[J+4>>2]=c[P+(T<<2)>>2];c[J+8>>2]=c[P+(pa<<2)>>2];Q=n-1|0;if((Q|0)>0){n=Q;P=P+4|0;J=J+12|0}else{break}}mc=aa+(T+1+((U|0)>-1?U:-1)<<2)|0}UGb(aa|0,qa|0,T*12|0)|0;J=E+1|0;if((J|0)>=13){break}aa=mc+(pa<<2)|0;E=J}if((a[ta]|0)!=2){nc=31;D=370;break}oc=a[M]|0}else{oc=ma}if(!(oc<<24>>24==0)){nc=1;D=370}}else{nc=31;D=370}}while(0);if((D|0)==370){D=0;ta=nc;E=f+23200+(wa*4864|0)+(ka*2432|0)+200|0;while(1){aa=E-4|0;J=c[aa>>2]|0;P=c[E>>2]|0;n=P+J|0;Q=c[2187496]|0;gHb(Q,(Q|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=F;Q=c[2187498]|0;gHb(Q,(Q|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;c[aa>>2]=n-F<<2;aa=c[2187499]|0;gHb(aa,(aa|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[E>>2]=F+n<<2;n=E-8|0;J=c[n>>2]|0;aa=E+4|0;P=c[aa>>2]|0;Q=P+J|0;ha=c[2187500]|0;gHb(ha,(ha|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;Q=F;ha=c[2187502]|0;gHb(ha,(ha|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;c[n>>2]=Q-F<<2;n=c[2187503]|0;gHb(n,(n|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[aa>>2]=F+Q<<2;Q=E-12|0;aa=c[Q>>2]|0;J=E+8|0;n=c[J>>2]|0;P=n+aa|0;ha=c[2187504]|0;gHb(ha,(ha|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;P=F;ha=c[2187506]|0;gHb(ha,(ha|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;c[Q>>2]=P-F<<2;Q=c[2187507]|0;gHb(Q,(Q|0)<0|0?-1:0,aa,(aa|0)<0|0?-1:0)|0;c[J>>2]=F+P<<2;P=E-16|0;J=c[P>>2]|0;aa=E+12|0;Q=c[aa>>2]|0;n=Q+J|0;ha=c[2187508]|0;gHb(ha,(ha|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=F;ha=c[2187510]|0;gHb(ha,(ha|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;c[P>>2]=n-F<<2;P=c[2187511]|0;gHb(P,(P|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[aa>>2]=F+n<<2;n=E-20|0;aa=c[n>>2]|0;J=E+16|0;P=c[J>>2]|0;Q=P+aa|0;ha=c[2187512]|0;gHb(ha,(ha|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;Q=F;ha=c[2187514]|0;gHb(ha,(ha|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;c[n>>2]=Q-F<<2;n=c[2187515]|0;gHb(n,(n|0)<0|0?-1:0,aa,(aa|0)<0|0?-1:0)|0;c[J>>2]=F+Q<<2;Q=E-24|0;J=c[Q>>2]|0;aa=E+20|0;n=c[aa>>2]|0;P=n+J|0;ha=c[2187516]|0;gHb(ha,(ha|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;P=F;ha=c[2187518]|0;gHb(ha,(ha|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;c[Q>>2]=P-F<<2;Q=c[2187519]|0;gHb(Q,(Q|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[aa>>2]=F+P<<2;P=E-28|0;aa=c[P>>2]|0;J=E+24|0;Q=c[J>>2]|0;n=Q+aa|0;ha=c[2187520]|0;gHb(ha,(ha|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=F;ha=c[2187522]|0;gHb(ha,(ha|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;c[P>>2]=n-F<<2;P=c[2187523]|0;gHb(P,(P|0)<0|0?-1:0,aa,(aa|0)<0|0?-1:0)|0;c[J>>2]=F+n<<2;n=E-32|0;J=c[n>>2]|0;aa=E+28|0;P=c[aa>>2]|0;Q=P+J|0;ha=c[2187524]|0;gHb(ha,(ha|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;Q=F;ha=c[2187526]|0;gHb(ha,(ha|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;c[n>>2]=Q-F<<2;n=c[2187527]|0;gHb(n,(n|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[aa>>2]=F+Q<<2;Q=ta-1|0;if((Q|0)>0){ta=Q;E=E+72|0}else{break}}}PNa(f,R,f+9376+(wa*4608|0)+(ca<<7)|0,f+18592+(wa*2304|0)|0);E=wa+1|0;ta=c[A>>2]|0;if((E|0)<(ta|0)){wa=E}else{pc=ta;break}}}else{pc=Z}wa=ka+1|0;if((wa|0)<(Ca|0)){ka=wa;ja=ja+1|0;$=pc}else{break}}}$=c[t>>2]|0;if(($|0)<0){ja=-$|0;ka=(c[x>>2]|0)-$|0;c[t>>2]=((ka|0)<(ja|0)?ka:ja)+$}Xa=Ca*18|0}$=f+1088|0;c[$>>2]=0;ja=f+1116|0;ka=ja|0;if((c[ka>>2]|0)!=0){A=c[t>>2]|0;qa=-A&7;if((qa|0)==0){qc=A}else{ra=c[x>>2]|0;z=qa+A|0;A=ra>>>0>z>>>0?z:ra;c[t>>2]=A;qc=A}A=(c[u>>2]|0)-qc>>3;if(A>>>0<513>>>0){VGb(f+40|0,(c[j>>2]|0)+(qc>>3)|0,A|0)|0;c[$>>2]=A}else{yDb(c[S>>2]|0,16,2209112,(Oa=i,i=i+8|0,c[Oa>>2]=A,Oa)|0);i=Oa}A=s;ra=ja;c[A>>2]=c[ra>>2];c[A+4>>2]=c[ra+4>>2];c[A+8>>2]=c[ra+8>>2];c[A+12>>2]=c[ra+12>>2];c[A+16>>2]=c[ra+16>>2];c[ka>>2]=0}ka=c[t>>2]|0;ra=-ka&7;if((ra|0)==0){rc=ka}else{A=c[x>>2]|0;ja=ra+ka|0;ka=A>>>0>ja>>>0?ja:A;c[t>>2]=ka;rc=ka}ka=(c[u>>2]|0)-rc>>3;A=(Xa|0)<0;if(ka>>>0>512>>>0|A){if((ka|0)<0){yDb(c[S>>2]|0,16,2200488,(Oa=i,i=i+8|0,c[Oa>>2]=ka,Oa)|0);i=Oa}sc=(h|0)<512?h:512}else{sc=ka}UGb((c[$>>2]|0)+(f+40)|0,(c[j>>2]|0)+(h-sc)|0,sc)|0;c[$>>2]=(c[$>>2]|0)+sc;if(A){tc=Xa}else{_=Xa;break}i=k;return tc|0}}while(0);do{if((g|0)==0){Xa=f+33004|0;sc=c[Xa>>2]|0;if((sc|0)==0){yDb(0,0,2192e3,(Oa=i,i=i+24|0,c[Oa>>2]=2175520,c[Oa+8>>2]=2165200,c[Oa+16>>2]=1606,Oa)|0);i=Oa;Cd();return 0}h=c[f+32940>>2]|0;c[sc+76>>2]=c[h+424>>2];j=_$a(h,sc,0)|0;if((j|0)<0){tc=j;i=k;return tc|0}else{uc=c[(c[Xa>>2]|0)+64>>2]|0;break}}else{uc=g}}while(0);g=f+24|0;Oa=c[g>>2]|0;if((Oa|0)>0){Xa=f+32940|0;j=(_|0)>0;sc=f+32944|0;h=f+32932|0;rc=0;u=Oa;while(1){if((c[(c[Xa>>2]|0)+420>>2]|0)==6){vc=1;wc=c[uc+(rc<<2)>>2]|0}else{vc=u;wc=(c[uc>>2]|0)+(rc<<1)|0}if(j){t=f+1152+(rc<<12)|0;x=f+9344+(rc<<2)|0;s=vc<<5;qc=0;Ca=wc;while(1){dOa(sc,t,x,6870480,h,Ca,vc,f+9376+(rc*4608|0)+(qc<<7)|0);pc=qc+1|0;if((pc|0)<(_|0)){qc=pc;Ca=Ca+(s<<1)|0}else{break}}xc=c[g>>2]|0}else{xc=u}s=rc+1|0;if((s|0)<(xc|0)){rc=s;u=xc}else{yc=xc;break}}}else{yc=Oa}tc=ba(_<<6,yc)|0;i=k;return tc|0}function PNa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+48|0;j=h|0;k=e+128|0;l=e+272|0;m=e+2432|0;while(1){if(m>>>0<l>>>0){n=m;break}o=m-24|0;if((c[m-20>>2]|c[o>>2]|c[m-16>>2]|c[m-12>>2]|c[m-8>>2]|c[m-4>>2]|0)==0){m=o}else{n=o;break}}m=((n-k>>2|0)/18|0)+1|0;n=a[e+20|0]|0;l=e+21|0;if(n<<24>>24==2){p=(a[l]|0)==0?0:2}else{p=m}Se[c[b+32964>>2]&511](f,g,k,p,d[l]|0,n&255);n=g+(((p>>2)*72|0|p&3)<<2)|0;if((p|0)<(m|0)){g=j|0;l=j+40|0;k=j+28|0;b=j+16|0;o=j+4|0;q=j+36|0;r=j+32|0;s=j+12|0;t=j+8|0;u=j+20|0;v=j+44|0;w=j+24|0;x=n;y=p;z=e+128+((p*18|0)<<2)|0;e=f+(p+192<<2)|0;A=f+(p+384<<2)|0;while(1){c[f+(y<<2)>>2]=c[x>>2];c[f+(y+32<<2)>>2]=c[x+16>>2];c[f+(y+64<<2)>>2]=c[x+32>>2];c[f+(y+96<<2)>>2]=c[x+48>>2];c[f+(y+128<<2)>>2]=c[x+64>>2];c[f+(y+160<<2)>>2]=c[x+80>>2];p=-(y&1)&4|2;B=c[z>>2]|0;C=c[z+12>>2]|0;D=C+B|0;E=c[z+24>>2]|0;G=c[z+36>>2]|0;H=G+E|0;I=c[z+48>>2]|0;J=I+G|0;G=H+I+(c[z+60>>2]|0)|0;I=E+C<<1;gHb(I,(I|0)<0|0?-1:0,1859775393,0)|0;I=F;C=H+D<<2;gHb(C,(C|0)<0|0?-1:0,1859775393,0)|0;C=F;H=B-J|0;E=D-G<<1;gHb(E,(E|0)<0|0?-1:0,1518500250,0)|0;E=F;K=E+H|0;c[l>>2]=K;c[k>>2]=K;K=H-E|0;c[b>>2]=K;c[o>>2]=K;K=(J>>1)+B|0;B=I+K|0;J=G+(D<<1)|0;D=C+J|0;gHb(D,(D|0)<0|0?-1:0,1111619334,0)|0;D=F;G=D+B|0;c[q>>2]=G;c[r>>2]=G;G=B-D|0;c[s>>2]=G;c[t>>2]=G;G=K-I|0;I=J-C<<1;gHb(I,(I|0)<0|0?-1:0,2074309917,0)|0;I=F;C=G-I|0;c[u>>2]=C;c[g>>2]=C;J=I+G|0;c[v>>2]=J;c[w>>2]=J;J=0;G=e;I=C;while(1){C=c[6874832+(p*160|0)+(J<<2)>>2]|0;gHb(C,(C|0)<0|0?-1:0,I,(I|0)<0|0?-1:0)|0;C=J+6|0;c[G>>2]=F+(c[x+(C<<2<<2)>>2]|0);K=c[j+(C<<2)>>2]|0;D=c[6874832+(p*160|0)+(C<<2)>>2]|0;gHb(D,(D|0)<0|0?-1:0,K,(K|0)<0|0?-1:0)|0;c[x+((J<<2)+48<<2)>>2]=F;K=J+1|0;if((K|0)>=6){break}J=K;G=G+128|0;I=c[j+(K<<2)>>2]|0}I=c[z+4>>2]|0;G=c[z+16>>2]|0;J=G+I|0;K=c[z+28>>2]|0;D=c[z+40>>2]|0;C=D+K|0;B=c[z+52>>2]|0;E=B+D|0;D=C+B+(c[z+64>>2]|0)|0;B=K+G<<1;gHb(B,(B|0)<0|0?-1:0,1859775393,0)|0;B=F;G=C+J<<2;gHb(G,(G|0)<0|0?-1:0,1859775393,0)|0;G=F;C=I-E|0;K=J-D<<1;gHb(K,(K|0)<0|0?-1:0,1518500250,0)|0;K=F;H=K+C|0;c[l>>2]=H;c[k>>2]=H;H=C-K|0;c[b>>2]=H;c[o>>2]=H;H=(E>>1)+I|0;I=B+H|0;E=D+(J<<1)|0;J=G+E|0;gHb(J,(J|0)<0|0?-1:0,1111619334,0)|0;J=F;D=J+I|0;c[q>>2]=D;c[r>>2]=D;D=I-J|0;c[s>>2]=D;c[t>>2]=D;D=H-B|0;B=E-G<<1;gHb(B,(B|0)<0|0?-1:0,2074309917,0)|0;B=F;G=D-B|0;c[u>>2]=G;c[g>>2]=G;E=B+D|0;c[v>>2]=E;c[w>>2]=E;E=0;D=A;B=G;while(1){G=c[6874832+(p*160|0)+(E<<2)>>2]|0;gHb(G,(G|0)<0|0?-1:0,B,(B|0)<0|0?-1:0)|0;G=E<<2;c[D>>2]=F+(c[x+(G+48<<2)>>2]|0);H=E+6|0;J=c[j+(H<<2)>>2]|0;I=c[6874832+(p*160|0)+(H<<2)>>2]|0;gHb(I,(I|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[x+(G<<2)>>2]=F;G=E+1|0;if((G|0)>=6){break}E=G;D=D+128|0;B=c[j+(G<<2)>>2]|0}B=c[z+8>>2]|0;D=c[z+20>>2]|0;E=D+B|0;G=c[z+32>>2]|0;J=c[z+44>>2]|0;I=J+G|0;H=c[z+56>>2]|0;K=H+J|0;J=I+H+(c[z+68>>2]|0)|0;H=G+D<<1;gHb(H,(H|0)<0|0?-1:0,1859775393,0)|0;H=F;D=I+E<<2;gHb(D,(D|0)<0|0?-1:0,1859775393,0)|0;D=F;I=B-K|0;G=E-J<<1;gHb(G,(G|0)<0|0?-1:0,1518500250,0)|0;G=F;C=G+I|0;c[l>>2]=C;c[k>>2]=C;C=I-G|0;c[b>>2]=C;c[o>>2]=C;C=(K>>1)+B|0;B=H+C|0;K=J+(E<<1)|0;E=D+K|0;gHb(E,(E|0)<0|0?-1:0,1111619334,0)|0;E=F;J=E+B|0;c[q>>2]=J;c[r>>2]=J;J=B-E|0;c[s>>2]=J;c[t>>2]=J;J=C-H|0;H=K-D<<1;gHb(H,(H|0)<0|0?-1:0,2074309917,0)|0;H=F;D=J-H|0;c[u>>2]=D;c[g>>2]=D;K=H+J|0;c[v>>2]=K;c[w>>2]=K;K=0;J=D;while(1){D=c[6874832+(p*160|0)+(K<<2)>>2]|0;gHb(D,(D|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;D=K<<2;H=x+(D<<2)|0;c[H>>2]=F+(c[H>>2]|0);H=K+6|0;C=c[j+(H<<2)>>2]|0;E=c[6874832+(p*160|0)+(H<<2)>>2]|0;gHb(E,(E|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;c[x+(H<<2<<2)>>2]=F;c[x+(D+48<<2)>>2]=0;D=K+1|0;if((D|0)>=6){break}K=D;J=c[j+(D<<2)>>2]|0}J=x+(((y&3|0)!=3?1:69)<<2)|0;K=y+1|0;if((K|0)<(m|0)){x=J;y=K;z=z+72|0;e=e+4|0;A=A+4|0}else{L=J;break}}}else{L=n}if((m|0)<32){M=L;N=m}else{i=h;return}while(1){c[f+(N<<2)>>2]=c[M>>2];c[M>>2]=0;m=M+16|0;c[f+(N+32<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+32|0;c[f+(N+64<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+48|0;c[f+(N+96<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+64|0;c[f+(N+128<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+80|0;c[f+(N+160<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+96|0;c[f+(N+192<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+112|0;c[f+(N+224<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+128|0;c[f+(N+256<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+144|0;c[f+(N+288<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+160|0;c[f+(N+320<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+176|0;c[f+(N+352<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+192|0;c[f+(N+384<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+208|0;c[f+(N+416<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+224|0;c[f+(N+448<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+240|0;c[f+(N+480<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+256|0;c[f+(N+512<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+272|0;c[f+(N+544<<2)>>2]=c[m>>2];c[m>>2]=0;m=N+1|0;if((m|0)<32){M=M+(((N&3|0)!=3?1:69)<<2)|0;N=m}else{break}}i=h;return}function QNa(e){e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0.0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+1544|0;h=f|0;j=f+8|0;k=f+520|0;l=c[e+60>>2]|0;if(!(a[1403280]|0)){m=j|0;n=k;o=0;while(1){b[4312976+(o<<1)>>1]=(o|0)%3|0|((o|0)/3|0)<<2;p=o+1|0;if((p|0)<64){o=p}else{q=0;break}}do{o=q+2|0;p=_Gb(8388608,0,o|0)|0;r=(1<<o)-1|0;o=eHb(p,F,r,(r|0)<0|0?-1:0)|0;s=+(o|0);c[4312608+(q*12|0)>>2]=~~(s*2.0);c[4312612+(q*12|0)>>2]=~~(s*1.587401032447815);c[4312616+(q*12|0)>>2]=~~(s*1.2599210739135742);q=q+1|0;}while((q|0)<15);jOa(6867408);q=0;o=1;while(1){TGb(m|0,0,512)|0;TGb(n|0,0,1024)|0;r=c[670408+(o*12|0)>>2]|0;p=(r|0)>1?r:1;t=c[670412+(o*12|0)>>2]|0;u=c[670416+(o*12|0)>>2]|0;v=0;w=0;while(1){x=v<<5;if((v|0)==0){y=0;z=w;while(1){A=y|x;a[j+A|0]=a[t+z|0]|0;b[k+(A<<1)>>1]=b[u+(z<<1)>>1]|0;A=y+1|0;if((A|0)<(r|0)){y=A;z=z+1|0}else{break}}}else{z=0;y=w;while(1){A=z|x|((z|0)!=0)<<4;a[j+A|0]=a[t+y|0]|0;b[k+(A<<1)>>1]=b[u+(y<<1)>>1]|0;A=z+1|0;if((A|0)<(r|0)){z=A;y=y+1|0}else{break}}}y=v+1|0;if((y|0)<(r|0)){v=y;w=w+p|0}else{break}}c[5129364+(o*20|0)>>2]=5099392+(q<<2);p=c[919904+(o<<2)>>2]|0;c[5129372+(o*20|0)>>2]=p;N_(5129360+(o*20|0)|0,7,512,m,1,1,n,2,2,0,0,0,4)|0;w=o+1|0;if((w|0)<16){q=p+q|0;o=w}else{break}}c[1282805]=5130064;c[1282807]=128;N_(5131216,7,16,661896,1,1,661832,1,1,0,0,0,4)|0;c[1282810]=5130576;c[1282812]=16;N_(5131236,4,16,661912,1,1,661848,1,1,0,0,0,4)|0;o=0;q=0;n=0;while(1){b[8878224+(q<<1)>>1]=n;m=(d[1738504+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439134]=576;n=0;q=0;o=0;while(1){b[8878270+(q<<1)>>1]=o;m=(d[1738526+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4439157]=576;o=0;q=0;n=0;while(1){b[8878316+(q<<1)>>1]=n;m=(d[1738548+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439180]=576;n=0;q=0;o=0;while(1){b[8878362+(q<<1)>>1]=o;m=(d[1738570+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4439203]=576;o=0;q=0;n=0;while(1){b[8878408+(q<<1)>>1]=n;m=(d[1738592+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439226]=576;n=0;q=0;o=0;while(1){b[8878454+(q<<1)>>1]=o;m=(d[1738614+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4439249]=576;o=0;q=0;n=0;while(1){b[8878500+(q<<1)>>1]=n;m=(d[1738636+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439272]=576;n=0;q=0;o=0;while(1){b[8878546+(q<<1)>>1]=o;m=(d[1738658+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4439295]=576;o=0;q=0;n=0;while(1){b[8878592+(q<<1)>>1]=n;m=(d[1738680+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4439318]=576;n=1;while(1){s=+((n|0)/4|0|0);B=s/1.759*+S(+s,+.3333333333333333);q=~~(+Qc(+(B*+Wc(+(+(n&3|0)*.25))),h|0)*2147483648.0+.5);o=c[h>>2]|0;c[h>>2]=o-103;c[3946e3+(n<<2)>>2]=q;a[4208624+n|0]=103-o;o=n+1|0;if((o|0)<32828){n=o}else{C=0;break}}do{B=+Wc(+(+(C-400|0)*.25+23.0+5.0));n=0;do{s=+(n|0);D=B*s*+S(+s,+.3333333333333333)/1.759;if(D<4294967295.0){s=+P(D+.5);h=~~+s>>>0;E=+s,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0;G=h}else{G=-1}c[8084920+(C<<6)+(n<<2)>>2]=G;g[8019384+(C<<6)+(n<<2)>>2]=D;n=n+1|0;}while((n|0)<16);g[8151992+(C<<2)>>2]=+g[8019388+(C<<6)>>2];C=C+1|0;}while((C|0)<512);C=c[295200]|0;do{if((C|0)<0){G=1<<1-C;if((G|0)<=0){break}n=c[295182]|0;h=0;do{o=(h|0)/(n|0)|0;b[8523832+(h<<1)>>1]=(((o|0)%(n|0)|0)<<4)+((h|0)%(n|0)|0)+(((o|0)/(n|0)|0)<<8);h=h+1|0;}while((h|0)<(G|0))}}while(0);C=c[295201]|0;do{if((C|0)<0){G=1<<1-C;if((G|0)<=0){break}h=c[295183]|0;n=0;do{o=(n|0)/(h|0)|0;b[8522808+(n<<1)>>1]=(((o|0)%(h|0)|0)<<4)+((n|0)%(h|0)|0)+(((o|0)/(h|0)|0)<<8);n=n+1|0;}while((n|0)<(G|0))}}while(0);C=c[295202]|0;do{if((C|0)<0){G=1<<1-C;if((G|0)<=0){break}n=c[295184]|0;h=0;do{o=(h|0)/(n|0)|0;b[h<<1>>1]=(((o|0)%(n|0)|0)<<4)+((h|0)%(n|0)|0)+(((o|0)/(n|0)|0)<<8);h=h+1|0;}while((h|0)<(G|0))}}while(0);C=c[295203]|0;do{if((C|0)<0){G=1<<1-C;if((G|0)<=0){break}h=c[295185]|0;n=0;do{o=(n|0)/(h|0)|0;b[8514616+(n<<1)>>1]=(((o|0)%(h|0)|0)<<4)+((n|0)%(h|0)|0)+(((o|0)/(h|0)|0)<<8);n=n+1|0;}while((n|0)<(G|0))}}while(0);g[1254022]=0.0;g[1254044]=0.0;g[1254023]=.21132487058639526;g[1254043]=.21132487058639526;g[1254024]=.3660253882408142;g[1254042]=.3660253882408142;g[1254025]=.5;g[1254041]=.5;g[1254026]=.6339746117591858;g[1254040]=.6339746117591858;g[1254027]=.7886751294136047;g[1254039]=.7886751294136047;g[1254028]=1.0;g[1254038]=1.0;TGb(5016116,0,36)|0;TGb(5016180,0,36)|0;C=0;while(1){G=C+1|0;n=G>>1;h=C&1;o=h^1;g[5015576+(o<<6)+(C<<2)>>2]=+Wc(+(+(-n|0)*.25));g[5015576+(h<<6)+(C<<2)>>2]=1.0;g[5015704+(o<<6)+(C<<2)>>2]=+Wc(+(+(n*-2|0|0)*.25));g[5015704+(h<<6)+(C<<2)>>2]=1.0;if((G|0)<16){C=G}else{H=0;break}}do{B=+g[1485760+(H<<2)>>2];D=1.0/+R(B*B+1.0);s=B*D;g[8749856+(H<<4)>>2]=D;g[8749860+(H<<4)>>2]=s;g[8749864+(H<<4)>>2]=D+s;g[8749868+(H<<4)>>2]=s-D;H=H+1|0;}while((H|0)<8);a[1403280]=1}c[l+32940>>2]=e;fCb(l+32968|0,c[e+88>>2]&8388608);bOa(l+32944|0);H=c[e+48>>2]|0;do{if((c[e+468>>2]|0)==3){if((H|0)==86030){I=86030;J=60;break}c[e+420>>2]=3;K=H}else{I=H;J=60}}while(0);if((J|0)==60){c[e+420>>2]=8;K=I}c[l+32936>>2]=c[e+696>>2];if((K|0)!=86029){i=f;return 0}c[l+32928>>2]=1;i=f;return 0}function RNa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=g+28|0;k=c[j>>2]|0;l=c[b+60>>2]|0;m=l;if((k|0)==0){n=-1094995529;i=h;return n|0}o=k;k=c[g+24>>2]|0;while(1){if((a[k]|0)!=0){break}g=o-1|0;if((g|0)==0){n=-1094995529;p=22;break}else{o=g;k=k+1|0}}if((p|0)==22){i=h;return n|0}if((o|0)<4){n=-1094995529;i=h;return n|0}p=k;g=fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if((g&-256|0)==1413564160){yDb(b,48,2083448,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=o;i=h;return n|0}if((g&-2097152|0)!=-2097152|(g&393216|0)==0|(g&61440|0)==61440|(g&3072|0)==3072){yDb(b,16,2077832,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}if((_Na(l,g)|0)==1){c[l>>2]=-1;n=-1094995529;i=h;return n|0}g=l+24|0;c[b+416>>2]=c[g>>2];p=(c[g>>2]|0)==1;g=b+448|0;c[g>>2]=p?4:3;c[g+4>>2]=p?0:0;p=b+72|0;if((c[p>>2]|0)==0){c[p>>2]=c[l+20>>2]}p=l;g=c[p>>2]|0;if((g|0)<1|(g|0)>(o|0)){yDb(b,16,2072992,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}if((g|0)<(o|0)){yDb(b,48,2068368,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=c[p>>2]|0}else{r=o}o=l+33004|0;c[o>>2]=e;e=YNa(m,0,k,r)|0;do{if((e|0)>-1){c[(c[o>>2]|0)+76>>2]=c[b+424>>2];c[f>>2]=1;c[b+412>>2]=c[l+12>>2]}else{yDb(b,16,2093360,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[f>>2]=0;if((r|0)!=(c[j>>2]|0)&(e|0)==-1094995529){break}else{n=e}i=h;return n|0}}while(0);c[p>>2]=0;n=r;i=h;return n|0}function SNa(a){a=a|0;var b=0;b=c[a+60>>2]|0;TGb(b+1152|0,0,8192)|0;c[b+1088>>2]=0;return}function TNa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;f=c[a+60>>2]|0;if((j|0)<4){yDb(a,16,2114176,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}m=h;n=fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;if((n&393216|0)==0|(n&61440|0)==61440|(n&3072|0)==3072){yDb(a,16,2099864,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}_Na(f,n|-2097152)|0;c[a+412>>2]=c[f+12>>2];n=f+24|0;c[a+416>>2]=c[n>>2];m=(c[n>>2]|0)==1;n=a+448|0;c[n>>2]=m?4:3;c[n+4>>2]=m?0:0;m=a+72|0;if((c[m>>2]|0)==0){c[m>>2]=c[f+20>>2]}c[f>>2]=(j|0)>1792?1792:j;c[f+33004>>2]=b;b=YNa(f,0,h,j)|0;if((b|0)<0){yDb(a,16,2093360,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=b;i=g;return l|0}else{c[e>>2]=1;l=j;i=g;return l|0}return 0}function UNa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+48|0;f=e|0;g=a+60|0;h=c[g>>2]|0;j=c[a+100>>2]|0;do{if((j|0)>=2){k=c[a+96>>2]|0;if((k|0)==0){break}QMa(f,k,j<<3,1)|0;k=f+12|0;l=c[k>>2]|0;if((l|0)==0|(l|0)>7){yDb(a,16,2120264,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}o=h;c[o>>2]=d[671096+l|0]|0;l=c[k>>2]|0;c[h+8>>2]=1493312+(l*5|0);c[a+416>>2]=d[1175888+l|0]|0;k=b[1493392+(l<<1)>>1]|0;l=a+448|0;c[l>>2]=k<<16>>16;c[l+4>>2]=k<<16>>16<0|0?-1:0;c[h+4>>2]=(c[f+8>>2]|0)<16e3?-2097152:-1048576;k=cEb(33024)|0;l=h+12|0;p=l;q=l;c[q>>2]=k;a:do{if((k|0)!=0){c[g>>2]=k;QNa(a)|0;c[g>>2]=h;c[(c[q>>2]|0)+32928>>2]=1;if((c[o>>2]|0)>1){r=1}else{n=0;i=e;return n|0}while(1){l=cEb(33024)|0;s=p+(r<<2)|0;c[s>>2]=l;if((l|0)==0){break a}c[l+32928>>2]=1;c[l+32940>>2]=a;l=(c[s>>2]|0)+32944|0;s=(c[q>>2]|0)+32944|0;c[l>>2]=c[s>>2];c[l+4>>2]=c[s+4>>2];c[l+8>>2]=c[s+8>>2];c[l+12>>2]=c[s+12>>2];c[l+16>>2]=c[s+16>>2];c[l+20>>2]=c[s+20>>2];s=r+1|0;if((s|0)<(c[o>>2]|0)){r=s}else{n=0;break}}i=e;return n|0}}while(0);o=c[g>>2]|0;q=o;if((c[q>>2]|0)<=0){n=-12;i=e;return n|0}p=o+12|0;o=0;while(1){ZDb(c[p+(o<<2)>>2]|0);k=o+1|0;if((k|0)<(c[q>>2]|0)){o=k}else{n=-12;break}}i=e;return n|0}}while(0);yDb(a,16,2126080,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}function VNa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+8|0;h=g|0;j=c[f+24>>2]|0;k=c[f+28>>2]|0;f=c[a+60>>2]|0;l=b+76|0;c[l>>2]=1152;m=_$a(a,b,0)|0;if((m|0)<0){n=m;i=g;return n|0}m=c[b+64>>2]|0;if((k|0)<4){n=-1094995529;i=g;return n|0}b=a+72|0;c[b>>2]=0;o=f;a:do{if((c[o>>2]|0)>0){p=f+12|0;q=f+4|0;r=a+416|0;s=f+8|0;t=h|0;u=h+4|0;v=a;w=k;x=0;y=j;z=0;A=0;while(1){B=y;C=((de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;B=(C|0)>(w|0)?w:C;C=(B|0)>1792?1792:B;B=c[p+(z<<2)>>2]|0;if((C|0)<4){D=7;break}E=y;F=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)&1048575;E=c[q>>2]|0;G=F|E;if((E&-2097152|0)!=-2097152|(G&393216|0)==0|(G&61440|0)==61440|(G&3072|0)==3072){D=9;break}_Na(B,G)|0;G=B+24|0;E=c[G>>2]|0;F=E+A|0;H=c[r>>2]|0;if((F|0)>(H|0)){D=12;break}I=d[(c[s>>2]|0)+z|0]|0;if((I+E|0)>(H|0)){D=12;break}c[t>>2]=c[m+(I<<2)>>2];if((E|0)>1){c[u>>2]=c[m+((d[(c[s>>2]|0)+z|0]|0)+1<<2)>>2]}E=YNa(B,t,y,C)|0;if((E|0)<0){yDb(v,16,2230376,(J=i,i=i+8|0,c[J>>2]=F,J)|0);i=J;TGb(c[t>>2]|0,0,4608)|0;I=c[G>>2]|0;if((I|0)>1){TGb(c[u>>2]|0,0,4608)|0;K=c[G>>2]|0}else{K=I}L=K*4608|0}else{L=E}E=L+x|0;c[b>>2]=(c[b>>2]|0)+(c[B+20>>2]|0);B=z+1|0;if((B|0)<(c[o>>2]|0)){w=w-C|0;x=E;y=y+C|0;z=B;A=F}else{M=E;N=F;O=r;break a}}if((D|0)==7){yDb(v,16,2272504,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}else if((D|0)==9){yDb(v,16,2257152,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}else if((D|0)==12){yDb(v,16,2242808,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}}else{M=0;N=0;O=a+416|0}}while(0);if((N|0)==(c[O>>2]|0)){c[a+412>>2]=c[(c[f+12>>2]|0)+12>>2];c[l>>2]=(M>>>0)/(N<<2>>>0)|0;c[e>>2]=1;n=k;i=g;return n|0}else{yDb(a,16,2218352,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}return 0}function WNa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;a=b;if((c[a>>2]|0)<=0){return 0}d=b+12|0;b=0;do{ZDb(c[d+(b<<2)>>2]|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function XNa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b;if((c[a>>2]|0)<=0){return}d=b+12|0;b=0;do{e=c[d+(b<<2)>>2]|0;TGb(e+1152|0,0,8192)|0;c[e+1088>>2]=0;b=b+1|0;}while((b|0)<(c[a>>2]|0));return}function YNa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0.0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0.0,ic=0,jc=0.0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0;l=i;i=i+3808|0;m=l|0;n=l+192|0;o=l+256|0;p=l+320|0;q=l+336|0;r=l+2640|0;s=l+3792|0;t=f+1096|0;u=j+4|0;j=k-4|0;k=j<<3;v=k>>>0>2147483639>>>0|(u|0)==0;w=v?0:u;u=v?0:k;k=t|0;c[k>>2]=w;v=f+1108|0;c[v>>2]=u;x=u+8|0;y=f+1112|0;c[y>>2]=x;z=f+1100|0;c[z>>2]=w+(u>>3);u=f+1104|0;c[u>>2]=0;if((c[f+4>>2]|0)==0){A=0}else{B=x>>>0>16>>>0?16:x;c[u>>2]=B;A=B}B=c[f+8>>2]|0;if((B|0)==1){c[(c[f+32940>>2]|0)+424>>2]=384;if((c[f+28>>2]|0)==1){C=(c[f+32>>2]<<2)+4|0;if((C|0)>0){D=C;E=7}else{G=0;H=C;E=11}}else{D=32;E=7}if((E|0)==7){C=c[f+24>>2]|0;I=(C|0)>0;J=0;do{if(I){K=c[y>>2]|0;L=0;M=c[u>>2]|0;do{N=w+(M>>>3)|0;O=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(M&7)>>>28;N=M+4|0;M=K>>>0>N>>>0?N:K;c[u>>2]=M;a[n+(L<<5)+J|0]=O;L=L+1|0;}while((L|0)<(C|0))}J=J+1|0;}while((J|0)<(D|0));if((D|0)<32){G=1;H=D;E=11}else{P=0;Q=D;R=C;E=17}}do{if((E|0)==11){C=f+1096|0;D=c[y>>2]|0;J=H;I=c[u>>2]|0;do{L=w+(I>>>3)|0;M=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(I&7)>>>28;L=I+4|0;I=D>>>0>L>>>0?L:D;c[u>>2]=I;a[n+J|0]=M;J=J+1|0;}while((J|0)<32);if(!G){S=0;T=H;U=C;E=16;break}P=1;Q=H;R=c[f+24>>2]|0;E=17}}while(0);if((E|0)==17){H=f+1096|0;G=(R|0)>0;J=0;do{if(G){I=0;do{if((a[n+(I<<5)+J|0]|0)!=0){D=c[u>>2]|0;M=c[y>>2]|0;L=w+(D>>>3)|0;K=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(D&7)>>>26;L=D+6|0;c[u>>2]=M>>>0>L>>>0?L:M;a[o+(I<<5)+J|0]=K}I=I+1|0;}while((I|0)<(R|0))}J=J+1|0;}while((J|0)<(Q|0));if(P){S=1;T=Q;U=H;E=16}else{V=1;W=Q;X=0;Y=H}}if((E|0)==16){H=T;while(1){if((a[n+H|0]|0)!=0){Q=c[u>>2]|0;P=c[y>>2]|0;J=c[U>>2]|0;R=J+(Q>>>3)|0;G=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Q&7)>>>26;R=Q+6|0;Q=P>>>0>R>>>0?R:P;c[u>>2]=Q;a[o+H|0]=G;G=J+(Q>>>3)|0;J=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(Q&7)>>>26;G=Q+6|0;c[u>>2]=P>>>0>G>>>0?G:P;a[o+32+H|0]=J}J=H+1|0;if((J|0)<32){H=J}else{V=S;W=T;X=1;Y=U;break}}}U=f+24|0;T=0;while(1){if(V){S=0;H=c[U>>2]|0;while(1){if((H|0)>0){J=0;while(1){P=a[n+(J<<5)+S|0]|0;G=P&255;if(P<<24>>24==0){Z=0.0}else{P=c[u>>2]|0;Q=c[y>>2]|0;R=(c[Y>>2]|0)+(P>>>3)|0;I=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(P&7)>>>((31-G|0)>>>0);R=G+1+P|0;c[u>>2]=Q>>>0>R>>>0?R:Q;Q=e[4312976+(d[o+(J<<5)+S|0]<<1)>>1]|0;R=(-1<<G)+1+I|0;I=c[4312608+((G-1|0)*12|0)+((Q&3)<<2)>>2]|0;P=gHb(I,(I|0)<0|0?-1:0,R,(R|0)<0|0?-1:0)|0;R=F;I=(Q>>>2)+G|0;G=_Gb(1,0,I-1|0)|0;Q=YGb(G,F,P,R)|0;R=aHb(Q|0,F|0,I|0)|0;Z=+(R|0)}g[f+9376+(J*4608|0)+(T<<7)+(S<<2)>>2]=Z;R=J+1|0;I=c[U>>2]|0;if((R|0)<(I|0)){J=R}else{_=I;break}}}else{_=H}J=S+1|0;if((J|0)<(W|0)){S=J;H=_}else{break}}}if(X){H=W;do{S=a[n+H|0]|0;J=S&255;if(S<<24>>24==0){g[f+9376+(T<<7)+(H<<2)>>2]=0.0;g[f+13984+(T<<7)+(H<<2)>>2]=0.0}else{S=c[u>>2]|0;I=c[y>>2]|0;R=(c[Y>>2]|0)+(S>>>3)|0;Q=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(S&7)>>>((31-J|0)>>>0);R=J+1+S|0;c[u>>2]=I>>>0>R>>>0?R:I;I=e[4312976+(d[o+H|0]<<1)>>1]|0;R=(-1<<J)+1+Q|0;Q=R;S=(R|0)<0|0?-1:0;R=J-1|0;P=c[4312608+(R*12|0)+((I&3)<<2)>>2]|0;G=gHb(P,(P|0)<0|0?-1:0,Q,S)|0;P=F;C=(I>>>2)+J|0;I=_Gb(1,0,C-1|0)|0;K=YGb(I,F,G,P)|0;P=aHb(K|0,F|0,C|0)|0;g[f+9376+(T<<7)+(H<<2)>>2]=+(P|0);P=e[4312976+(d[o+32+H|0]<<1)>>1]|0;C=c[4312608+(R*12|0)+((P&3)<<2)>>2]|0;R=gHb(C,(C|0)<0|0?-1:0,Q,S)|0;S=F;Q=(P>>>2)+J|0;J=_Gb(1,0,Q-1|0)|0;P=YGb(J,F,R,S)|0;S=aHb(P|0,F|0,Q|0)|0;g[f+13984+(T<<7)+(H<<2)>>2]=+(S|0)}H=H+1|0;}while((H|0)<32)}H=T+1|0;if((H|0)<12){T=H}else{$=12;break}}}else if((B|0)==2){c[(c[f+32940>>2]|0)+424>>2]=1152;T=f+24|0;Y=Nmb((c[f+20>>2]|0)/1e3|0,c[T>>2]|0,c[f+12>>2]|0,c[f+36>>2]|0)|0;W=c[1180704+(Y<<2)>>2]|0;X=c[1181904+(Y<<2)>>2]|0;if((c[f+28>>2]|0)==1){aa=(c[f+32>>2]<<2)+4|0}else{aa=W}Y=(aa|0)>(W|0)?W:aa;aa=(Y|0)>0;if(aa){_=f+1096|0;U=c[T>>2]|0;V=(U|0)>0;H=0;S=0;while(1){Q=d[X+H|0]|0;if(V){P=32-Q|0;R=c[y>>2]|0;J=c[_>>2]|0;C=0;K=c[u>>2]|0;do{G=J+(K>>>3)|0;I=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(K&7)>>>(P>>>0);G=K+Q|0;K=R>>>0>G>>>0?G:R;c[u>>2]=K;a[n+(C<<5)+S|0]=I;C=C+1|0;}while((C|0)<(U|0))}C=(1<<Q)+H|0;K=S+1|0;if((K|0)<(Y|0)){H=C;S=K}else{ca=C;break}}}else{ca=0}S=(Y|0)<(W|0);if(S){H=c[y>>2]|0;U=c[f+1096>>2]|0;_=ca;ca=Y;V=c[u>>2]|0;while(1){C=d[X+_|0]|0;K=U+(V>>>3)|0;R=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(V&7)>>>((32-C|0)>>>0);K=C+V|0;P=H>>>0>K>>>0?K:H;c[u>>2]=P;K=R&255;a[n+ca|0]=K;a[n+32+ca|0]=K;K=ca+1|0;if((K|0)<(W|0)){_=(1<<C)+_|0;ca=K;V=P}else{break}}}V=f+1096|0;if((W|0)>0){ca=c[T>>2]|0;_=(ca|0)>0;H=0;while(1){if(_){U=0;do{if((a[n+(U<<5)+H|0]|0)!=0){P=c[u>>2]|0;K=c[y>>2]|0;C=(c[V>>2]|0)+(P>>>3)|0;R=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(P&7)>>>30;C=P+2|0;c[u>>2]=K>>>0>C>>>0?C:K;a[o+(U<<5)+H|0]=R}U=U+1|0;}while((U|0)<(ca|0))}U=H+1|0;if((U|0)<(W|0)){H=U}else{da=0;break}}do{if(_){H=0;do{do{if((a[n+(H<<5)+da|0]|0)!=0){U=m+(H*96|0)+(da*3|0)|0;Q=d[o+(H<<5)+da|0]|0;if((Q|0)==2){R=c[u>>2]|0;K=c[y>>2]|0;C=(c[V>>2]|0)+(R>>>3)|0;P=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(R&7)>>>26;C=R+6|0;c[u>>2]=K>>>0>C>>>0?C:K;K=P&255;a[U]=K;a[m+(H*96|0)+(da*3|0)+1|0]=K;a[m+(H*96|0)+(da*3|0)+2|0]=K;break}else if((Q|0)==1){K=c[u>>2]|0;P=c[y>>2]|0;C=c[V>>2]|0;R=C+(K>>>3)|0;J=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(K&7)>>>26;R=K+6|0;K=P>>>0>R>>>0?R:P;c[u>>2]=K;R=J&255;a[U]=R;J=C+(K>>>3)|0;C=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(K&7)>>>26;J=K+6|0;c[u>>2]=P>>>0>J>>>0?J:P;a[m+(H*96|0)+(da*3|0)+2|0]=C;a[m+(H*96|0)+(da*3|0)+1|0]=R;break}else if((Q|0)==3){Q=c[u>>2]|0;R=c[y>>2]|0;C=c[V>>2]|0;P=C+(Q>>>3)|0;J=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Q&7)>>>26;P=Q+6|0;Q=R>>>0>P>>>0?P:R;c[u>>2]=Q;a[U]=J;J=C+(Q>>>3)|0;C=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(Q&7)>>>26;J=Q+6|0;c[u>>2]=R>>>0>J>>>0?J:R;R=C&255;a[m+(H*96|0)+(da*3|0)+2|0]=R;a[m+(H*96|0)+(da*3|0)+1|0]=R;break}else{R=c[u>>2]|0;C=c[y>>2]|0;J=c[V>>2]|0;Q=J+(R>>>3)|0;P=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(R&7)>>>26;Q=R+6|0;R=C>>>0>Q>>>0?Q:C;c[u>>2]=R;a[U]=P;P=J+(R>>>3)|0;U=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(R&7)>>>26;P=R+6|0;R=C>>>0>P>>>0?P:C;c[u>>2]=R;a[m+(H*96|0)+(da*3|0)+1|0]=U;U=J+(R>>>3)|0;J=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(R&7)>>>26;U=R+6|0;c[u>>2]=C>>>0>U>>>0?U:C;a[m+(H*96|0)+(da*3|0)+2|0]=J;break}}}while(0);H=H+1|0;}while((H|0)<(ca|0))}da=da+1|0;}while((da|0)<(W|0))}da=(W|0)<32;ca=0;while(1){o=ca*12|0;_=0;do{if(aa){H=_+o|0;J=H+1|0;C=H+2|0;U=0;R=0;P=c[T>>2]|0;while(1){Q=d[X+U|0]|0;if((P|0)>0){K=0;while(1){I=a[n+(K<<5)+R|0]|0;do{if(I<<24>>24==0){g[f+9376+(K*4608|0)+(H<<7)+(R<<2)>>2]=0.0;g[f+9376+(K*4608|0)+(J<<7)+(R<<2)>>2]=0.0;g[f+9376+(K*4608|0)+(C<<7)+(R<<2)>>2]=0.0}else{G=d[m+(K*96|0)+(R*3|0)+ca|0]|0;M=d[X+((I&255)+U)|0]|0;L=c[1180800+(M<<2)>>2]|0;if((L|0)>=0){D=32-L|0;O=L-1|0;N=(-1<<O)+1|0;ea=c[u>>2]|0;fa=c[y>>2]|0;ga=(c[V>>2]|0)+(ea>>>3)|0;ha=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ea&7)>>>(D>>>0);ga=ea+L|0;c[u>>2]=fa>>>0>ga>>>0?ga:fa;fa=e[4312976+(G<<1)>>1]|0;ga=ha+N|0;ha=4312608+((L-2|0)*12|0)+((fa&3)<<2)|0;ea=c[ha>>2]|0;ia=gHb(ga,(ga|0)<0|0?-1:0,ea,(ea|0)<0|0?-1:0)|0;ea=F;ga=(fa>>>2)+O|0;O=_Gb(1,0,ga-1|0)|0;fa=F;ja=YGb(O,fa,ia,ea)|0;ea=ga;ga=aHb(ja|0,F|0,ea|0)|0;g[f+9376+(K*4608|0)+(H<<7)+(R<<2)>>2]=+(ga|0);ga=c[u>>2]|0;ja=c[y>>2]|0;ia=(c[V>>2]|0)+(ga>>>3)|0;ka=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(ga&7)>>>(D>>>0);ia=ga+L|0;c[u>>2]=ja>>>0>ia>>>0?ia:ja;ja=ka+N|0;ka=c[ha>>2]|0;ia=gHb(ja,(ja|0)<0|0?-1:0,ka,(ka|0)<0|0?-1:0)|0;ka=YGb(ia,F,O,fa)|0;ia=aHb(ka|0,F|0,ea|0)|0;g[f+9376+(K*4608|0)+(J<<7)+(R<<2)>>2]=+(ia|0);ia=c[u>>2]|0;ka=c[y>>2]|0;ja=(c[V>>2]|0)+(ia>>>3)|0;ga=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ia&7)>>>(D>>>0);D=ia+L|0;c[u>>2]=ka>>>0>D>>>0?D:ka;ka=ga+N|0;N=c[ha>>2]|0;ha=gHb(ka,(ka|0)<0|0?-1:0,N,(N|0)<0|0?-1:0)|0;N=YGb(ha,F,O,fa)|0;fa=aHb(N|0,F|0,ea|0)|0;g[f+9376+(K*4608|0)+(C<<7)+(R<<2)>>2]=+(fa|0);break}fa=c[u>>2]|0;ea=c[y>>2]|0;N=(c[V>>2]|0)+(fa>>>3)|0;O=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(fa&7)>>>((L+32|0)>>>0);N=fa-L|0;c[u>>2]=ea>>>0>N>>>0?N:ea;ea=b[(c[1360408+(M<<2)>>2]|0)+(O<<1)>>1]|0;O=c[1180728+(M<<2)>>2]|0;M=e[4312976+(G<<1)>>1]|0;G=M>>>2;N=O>>1;L=c[479736+((O>>2)*12|0)+((M&3)<<2)>>2]|0;M=ba(L,(ea&15)-N|0)|0;O=(G|0)==0;if(O){la=M}else{la=(1<<G-1)+M>>G}g[f+9376+(K*4608|0)+(H<<7)+(R<<2)>>2]=+(la|0);M=ba((ea>>>4&15)-N|0,L)|0;if(O){g[f+9376+(K*4608|0)+(J<<7)+(R<<2)>>2]=+(M|0);ma=ba(L,(ea>>8)-N|0)|0}else{O=1<<G-1;g[f+9376+(K*4608|0)+(J<<7)+(R<<2)>>2]=+(O+M>>G|0);ma=O+(ba(L,(ea>>8)-N|0)|0)>>G}g[f+9376+(K*4608|0)+(C<<7)+(R<<2)>>2]=+(ma|0)}}while(0);I=K+1|0;G=c[T>>2]|0;if((I|0)<(G|0)){K=I}else{na=G;break}}}else{na=P}K=(1<<Q)+U|0;G=R+1|0;if((G|0)<(Y|0)){U=K;R=G;P=na}else{oa=K;break}}}else{oa=0}if(S){P=_+o|0;R=P+1|0;U=P+2|0;C=oa;J=Y;while(1){H=d[X+C|0]|0;K=a[n+J|0]|0;do{if(K<<24>>24==0){g[f+9376+(P<<7)+(J<<2)>>2]=0.0;g[f+9376+(R<<7)+(J<<2)>>2]=0.0;g[f+9376+(U<<7)+(J<<2)>>2]=0.0;g[f+13984+(P<<7)+(J<<2)>>2]=0.0;g[f+13984+(R<<7)+(J<<2)>>2]=0.0;g[f+13984+(U<<7)+(J<<2)>>2]=0.0}else{G=d[m+(J*3|0)+ca|0]|0;I=d[m+96+(J*3|0)+ca|0]|0;N=d[X+((K&255)+C)|0]|0;ea=c[1180800+(N<<2)>>2]|0;if((ea|0)>=0){L=32-ea|0;O=ea-1|0;M=(-1<<O)+1|0;fa=ea-2|0;ha=b[4312976+(I<<1)>>1]|0;ka=e[4312976+(G<<1)>>1]|0;ga=4312608+(fa*12|0)+((ka&3)<<2)|0;D=(ka>>>2)+O|0;ka=_Gb(1,0,D-1|0)|0;ia=F;ja=D;D=ha&65535;ha=4312608+(fa*12|0)+((D&3)<<2)|0;fa=(D>>>2)+O|0;O=_Gb(1,0,fa-1|0)|0;D=F;pa=fa;fa=c[u>>2]|0;qa=c[y>>2]|0;ra=(c[V>>2]|0)+(fa>>>3)|0;sa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(fa&7)>>>(L>>>0);ra=fa+ea|0;c[u>>2]=qa>>>0>ra>>>0?ra:qa;qa=M+sa|0;sa=qa;ra=(qa|0)<0|0?-1:0;qa=c[ga>>2]|0;fa=gHb(sa,ra,qa,(qa|0)<0|0?-1:0)|0;qa=YGb(fa,F,ka,ia)|0;fa=aHb(qa|0,F|0,ja|0)|0;g[f+9376+(P<<7)+(J<<2)>>2]=+(fa|0);fa=c[ha>>2]|0;qa=gHb(sa,ra,fa,(fa|0)<0|0?-1:0)|0;fa=YGb(qa,F,O,D)|0;qa=aHb(fa|0,F|0,pa|0)|0;g[f+13984+(P<<7)+(J<<2)>>2]=+(qa|0);qa=c[u>>2]|0;fa=c[y>>2]|0;ra=(c[V>>2]|0)+(qa>>>3)|0;sa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(qa&7)>>>(L>>>0);ra=qa+ea|0;c[u>>2]=fa>>>0>ra>>>0?ra:fa;fa=M+sa|0;sa=fa;ra=(fa|0)<0|0?-1:0;fa=c[ga>>2]|0;qa=gHb(sa,ra,fa,(fa|0)<0|0?-1:0)|0;fa=YGb(qa,F,ka,ia)|0;qa=aHb(fa|0,F|0,ja|0)|0;g[f+9376+(R<<7)+(J<<2)>>2]=+(qa|0);qa=c[ha>>2]|0;fa=gHb(sa,ra,qa,(qa|0)<0|0?-1:0)|0;qa=YGb(fa,F,O,D)|0;fa=aHb(qa|0,F|0,pa|0)|0;g[f+13984+(R<<7)+(J<<2)>>2]=+(fa|0);fa=c[u>>2]|0;qa=c[y>>2]|0;ra=(c[V>>2]|0)+(fa>>>3)|0;sa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(fa&7)>>>(L>>>0);L=fa+ea|0;c[u>>2]=qa>>>0>L>>>0?L:qa;qa=M+sa|0;sa=qa;M=(qa|0)<0|0?-1:0;qa=c[ga>>2]|0;ga=gHb(sa,M,qa,(qa|0)<0|0?-1:0)|0;qa=YGb(ga,F,ka,ia)|0;ia=aHb(qa|0,F|0,ja|0)|0;g[f+9376+(U<<7)+(J<<2)>>2]=+(ia|0);ia=c[ha>>2]|0;ha=gHb(sa,M,ia,(ia|0)<0|0?-1:0)|0;ia=YGb(ha,F,O,D)|0;D=aHb(ia|0,F|0,pa|0)|0;g[f+13984+(U<<7)+(J<<2)>>2]=+(D|0);break}D=c[u>>2]|0;pa=c[y>>2]|0;ia=(c[V>>2]|0)+(D>>>3)|0;O=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(D&7)>>>((ea+32|0)>>>0);ia=D-ea|0;c[u>>2]=pa>>>0>ia>>>0?ia:pa;pa=c[1180728+(N<<2)>>2]|0;N=(O|0)/(pa|0)|0;ia=e[4312976+(G<<1)>>1]|0;G=ia>>>2;ea=pa>>1;D=((O|0)%(pa|0)|0)-ea|0;O=pa>>2;ha=c[479736+(O*12|0)+((ia&3)<<2)>>2]|0;ia=ba(ha,D)|0;M=(G|0)==0;if(M){ta=ia}else{ta=(1<<G-1)+ia>>G}g[f+9376+(P<<7)+(J<<2)>>2]=+(ta|0);ia=e[4312976+(I<<1)>>1]|0;I=ia>>>2;sa=c[479736+(O*12|0)+((ia&3)<<2)>>2]|0;ia=ba(sa,D)|0;D=(I|0)==0;if(D){ua=ia}else{ua=(1<<I-1)+ia>>I}g[f+13984+(P<<7)+(J<<2)>>2]=+(ua|0);ia=((N|0)%(pa|0)|0)-ea|0;O=ba(ia,ha)|0;if(M){va=O}else{va=O+(1<<G-1)>>G}g[f+9376+(R<<7)+(J<<2)>>2]=+(va|0);O=ba(ia,sa)|0;if(D){wa=O}else{wa=O+(1<<I-1)>>I}g[f+13984+(R<<7)+(J<<2)>>2]=+(wa|0);O=((N|0)/(pa|0)|0)-ea|0;ea=ba(O,ha)|0;if(M){xa=ea}else{xa=ea+(1<<G-1)>>G}g[f+9376+(U<<7)+(J<<2)>>2]=+(xa|0);G=ba(O,sa)|0;if(D){ya=G}else{ya=G+(1<<I-1)>>I}g[f+13984+(U<<7)+(J<<2)>>2]=+(ya|0)}}while(0);K=J+1|0;if((K|0)<(W|0)){C=(1<<H)+C|0;J=K}else{break}}}if(da){J=_+o|0;C=J+1|0;U=J+2|0;R=W;P=c[T>>2]|0;while(1){if((P|0)>0){K=0;while(1){g[f+9376+(K*4608|0)+(J<<7)+(R<<2)>>2]=0.0;g[f+9376+(K*4608|0)+(C<<7)+(R<<2)>>2]=0.0;g[f+9376+(K*4608|0)+(U<<7)+(R<<2)>>2]=0.0;Q=K+1|0;I=c[T>>2]|0;if((Q|0)<(I|0)){K=Q}else{za=I;break}}}else{za=P}K=R+1|0;if((K|0)<32){R=K;P=za}else{break}}}_=_+3|0;}while((_|0)<12);_=ca+1|0;if((_|0)<3){ca=_}else{$=36;break}}}else if((B|0)==3){B=f+36|0;c[(c[f+32940>>2]|0)+424>>2]=(c[B>>2]|0)!=0?576:1152;Aa=c[u>>2]|0;Ba=c[y>>2]|0;Ca=B;E=114}else{Aa=A;Ba=x;Ca=f+36|0;E=114}do{if((E|0)==114){x=(c[Ca>>2]|0)==0;A=w+(Aa>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(Aa&7);do{if(x){A=B>>>23;ca=Aa+9|0;za=Ba>>>0>ca>>>0?ca:Ba;c[u>>2]=za;ca=c[f+24>>2]|0;if((ca|0)==2){T=za+3|0;W=Ba>>>0>T>>>0?T:Ba;c[u>>2]=W;Da=0;Ea=W}else{W=za+5|0;za=Ba>>>0>W>>>0?W:Ba;c[u>>2]=za;if((ca|0)>0){Da=0;Ea=za}else{Fa=2;Ga=A;Ha=ca;break}}while(1){a[f+23200+(Da*4864|0)|0]=0;za=w+(Ea>>>3)|0;W=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Ea&7)>>>28;za=Ea+4|0;T=Ba>>>0>za>>>0?za:Ba;c[u>>2]=T;a[f+23200+(Da*4864|0)+2432|0]=W;W=Da+1|0;if((W|0)<(ca|0)){Da=W;Ea=T}else{Fa=2;Ga=A;Ha=ca;break}}}else{ca=Aa+8|0;A=c[f+24>>2]|0;T=A+(Ba>>>0>ca>>>0?ca:Ba)|0;c[u>>2]=Ba>>>0>T>>>0?T:Ba;Fa=1;Ga=B>>>24;Ha=A}}while(0);B=f+24|0;x=f+32|0;A=f+16|0;T=f+32940|0;ca=0;W=Ha;za=Ba;da=w;a:while(1){if((W|0)>0){ya=0;xa=za;wa=da;while(1){va=c[u>>2]|0;ua=wa+(va>>>3)|0;ta=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(va&7)>>>20;ua=va+12|0;va=xa>>>0>ua>>>0?ua:xa;c[u>>2]=va;c[f+23200+(ya*4864|0)+(ca*2432|0)+4>>2]=ta;ta=wa+(va>>>3)|0;ua=(fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(va&7);ta=ua>>>23;V=va+9|0;va=xa>>>0>V>>>0?V:xa;c[u>>2]=va;c[f+23200+(ya*4864|0)+(ca*2432|0)+8>>2]=ta;if(ua>>>0>2424307711>>>0){E=123;break a}ua=wa+(va>>>3)|0;V=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(va&7)>>>24;ua=va+8|0;va=xa>>>0>ua>>>0?ua:xa;c[u>>2]=va;ua=f+23200+(ya*4864|0)+(ca*2432|0)+12|0;c[ua>>2]=V;if((c[x>>2]&3|0)==2){c[ua>>2]=V-2}V=c[Ca>>2]|0;ua=wa+(va>>>3)|0;X=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(va&7);if((V|0)==0){ua=va+4|0;m=xa>>>0>ua>>>0?ua:xa;c[u>>2]=m;c[f+23200+(ya*4864|0)+(ca*2432|0)+16>>2]=X>>>28;Ia=m}else{m=va+9|0;va=xa>>>0>m>>>0?m:xa;c[u>>2]=va;c[f+23200+(ya*4864|0)+(ca*2432|0)+16>>2]=X>>>23;Ia=va}va=d[wa+(Ia>>>3)|0]|0;X=((Ia|0)<(xa|0))+Ia|0;c[u>>2]=X;if((va&128>>>((Ia&7)>>>0)|0)==0){a[f+23200+(ya*4864|0)+(ca*2432|0)+20|0]=0;a[f+23200+(ya*4864|0)+(ca*2432|0)+21|0]=0;va=wa+(X>>>3)|0;m=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(X&7)>>>27;va=X+5|0;ua=xa>>>0>va>>>0?va:xa;c[u>>2]=ua;c[f+23200+(ya*4864|0)+(ca*2432|0)+24>>2]=m;m=wa+(ua>>>3)|0;va=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(ua&7)>>>27;m=ua+5|0;ua=xa>>>0>m>>>0?m:xa;c[u>>2]=ua;c[f+23200+(ya*4864|0)+(ca*2432|0)+28>>2]=va;va=wa+(ua>>>3)|0;m=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(ua&7)>>>27;va=ua+5|0;ua=xa>>>0>va>>>0?va:xa;c[u>>2]=ua;c[f+23200+(ya*4864|0)+(ca*2432|0)+32>>2]=m;m=wa+(ua>>>3)|0;va=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(ua&7)>>>28;m=ua+4|0;ua=xa>>>0>m>>>0?m:xa;c[u>>2]=ua;m=wa+(ua>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(ua&7)>>>29;m=ua+3|0;c[u>>2]=xa>>>0>m>>>0?m:xa;m=c[A>>2]|0;ua=(e[8878224+(m*46|0)+(va+1<<1)>>1]|0)>>>1;Y=f+23200+(ya*4864|0)+(ca*2432|0)+52|0;c[Y>>2]=ua;oa=va+2+n|0;n=(e[8878224+(m*46|0)+(((oa|0)>22?22:oa)<<1)>>1]|0)>>>1;c[f+23200+(ya*4864|0)+(ca*2432|0)+56>>2]=n;Ja=ua;Ka=n;La=0;Ma=0;Na=m;Oa=Y}else{Y=wa+(X>>>3)|0;m=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(X&7)>>>30;Y=X+2|0;X=xa>>>0>Y>>>0?Y:xa;c[u>>2]=X;Y=m&255;a[f+23200+(ya*4864|0)+(ca*2432|0)+20|0]=Y;if((m|0)==0){E=131;break a}m=d[wa+(X>>>3)|0]<<(X&7)>>>7;n=((X|0)<(xa|0))+X|0;c[u>>2]=n;X=m&1;a[f+23200+(ya*4864|0)+(ca*2432|0)+21|0]=X;m=wa+(n>>>3)|0;ua=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(n&7)>>>27;m=n+5|0;n=xa>>>0>m>>>0?m:xa;c[u>>2]=n;c[f+23200+(ya*4864|0)+(ca*2432|0)+24>>2]=ua;ua=wa+(n>>>3)|0;m=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(n&7)>>>27;ua=n+5|0;n=xa>>>0>ua>>>0?ua:xa;c[u>>2]=n;c[f+23200+(ya*4864|0)+(ca*2432|0)+28>>2]=m;m=wa+(n>>>3)|0;ua=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(n&7)>>>29;m=n+3|0;n=xa>>>0>m>>>0?m:xa;c[u>>2]=n;c[f+23200+(ya*4864|0)+(ca*2432|0)+36>>2]=ua;ua=wa+(n>>>3)|0;m=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(n&7)>>>29;ua=n+3|0;n=xa>>>0>ua>>>0?ua:xa;c[u>>2]=n;c[f+23200+(ya*4864|0)+(ca*2432|0)+40>>2]=m;m=(c[k>>2]|0)+(n>>>3)|0;ua=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(n&7)>>>29;m=n+3|0;c[u>>2]=xa>>>0>m>>>0?m:xa;c[f+23200+(ya*4864|0)+(ca*2432|0)+44>>2]=ua;ua=c[A>>2]|0;m=Y<<24>>24==2;do{if(m){Y=f+23200+(ya*4864|0)+(ca*2432|0)+52|0;if((ua|0)==8){c[Y>>2]=36;Pa=36;break}else{c[Y>>2]=18;Pa=18;break}}else{if((ua|0)<3){c[f+23200+(ya*4864|0)+(ca*2432|0)+52>>2]=18;Pa=18;break}Y=f+23200+(ya*4864|0)+(ca*2432|0)+52|0;if((ua|0)==8){c[Y>>2]=54;Pa=54;break}else{c[Y>>2]=27;Pa=27;break}}}while(0);c[f+23200+(ya*4864|0)+(ca*2432|0)+56>>2]=288;Ja=Pa;Ka=288;La=m;Ma=X;Na=ua;Oa=f+23200+(ya*4864|0)+(ca*2432|0)+52|0}Y=(Ja|0)>(ta|0)?ta:Ja;c[Oa>>2]=Y;n=Ka>>>0>ta>>>0?ta:Ka;c[f+23200+(ya*4864|0)+(ca*2432|0)+56>>2]=n-Y;c[f+23200+(ya*4864|0)+(ca*2432|0)+60>>2]=(ta>>>0<288>>>0?ta:288)-n;do{if(La){if(Ma<<24>>24==0){c[f+23200+(ya*4864|0)+(ca*2432|0)+72>>2]=0;c[f+23200+(ya*4864|0)+(ca*2432|0)+68>>2]=0;Qa=V;break}if((Na|0)==8){DDb(c[T>>2]|0,2132480,(Ra=i,i=i+1|0,i=i+7&-8,c[Ra>>2]=0,Ra)|0);i=Ra;Sa=c[A>>2]|0;Ta=c[Ca>>2]|0}else{Sa=Na;Ta=V}c[f+23200+(ya*4864|0)+(ca*2432|0)+72>>2]=(Sa|0)<3?8:6;c[f+23200+(ya*4864|0)+(ca*2432|0)+68>>2]=3;Qa=Ta}else{c[f+23200+(ya*4864|0)+(ca*2432|0)+68>>2]=13;c[f+23200+(ya*4864|0)+(ca*2432|0)+72>>2]=22;Qa=V}}while(0);V=f+23200+(ya*4864|0)+(ca*2432|0)+64|0;c[V>>2]=0;ta=c[u>>2]|0;if((Qa|0)==0){ua=c[k>>2]|0;X=d[ua+(ta>>>3)|0]<<(ta&7)>>>7;m=c[y>>2]|0;n=((ta|0)<(m|0))+ta|0;c[u>>2]=n;c[V>>2]=X&1;Ua=n;Va=ua;Wa=m}else{Ua=ta;Va=c[k>>2]|0;Wa=c[y>>2]|0}ta=d[Va+(Ua>>>3)|0]<<(Ua&7)>>>7;c[u>>2]=((Ua|0)<(Wa|0))+Ua;a[f+23200+(ya*4864|0)+(ca*2432|0)+48|0]=ta&1;ta=c[u>>2]|0;m=d[Va+(ta>>>3)|0]<<(ta&7)>>>7;c[u>>2]=((ta|0)<(Wa|0))+ta;a[f+23200+(ya*4864|0)+(ca*2432|0)+49|0]=m&1;m=ya+1|0;ta=c[B>>2]|0;if((m|0)<(ta|0)){ya=m;xa=Wa;wa=Va}else{Xa=ta;Ya=Wa;Za=Va;break}}}else{Xa=W;Ya=za;Za=da}wa=ca+1|0;if((wa|0)<(Fa|0)){ca=wa;W=Xa;za=Ya;da=Za}else{E=155;break}}if((E|0)==123){yDb(c[T>>2]|0,16,2158400,(Ra=i,i=i+1|0,i=i+7&-8,c[Ra>>2]=0,Ra)|0);i=Ra;_a=-1094995529}else if((E|0)==131){yDb(c[T>>2]|0,16,2151400,(Ra=i,i=i+1|0,i=i+7&-8,c[Ra>>2]=0,Ra)|0);i=Ra;_a=-1094995529}else if((E|0)==155){do{if((c[f+32928>>2]|0)==0){da=c[u>>2]|0;za=(c[v>>2]|0)-da>>3;if((za|0)<0){$a=0}else{$a=(za|0)>24?24:za}za=f+40|0;W=f+1088|0;UGb((c[W>>2]|0)+(f+40)|0,Za+(da>>3)|0,$a)|0;da=f+1116|0;ca=da;wa=t;c[ca>>2]=c[wa>>2];c[ca+4>>2]=c[wa+4>>2];c[ca+8>>2]=c[wa+8>>2];c[ca+12>>2]=c[wa+12>>2];c[ca+16>>2]=c[wa+16>>2];xa=c[W>>2]|0;ya=xa<<3;ta=ya>>>0>2147483639>>>0|(za|0)==0;m=ta?0:za;za=ta?0:ya;c[k>>2]=m;c[v>>2]=za;c[z>>2]=m+(za>>3);c[u>>2]=0;m=1048-xa|0;c[y>>2]=za+8+((($a|0)>(m|0)?$a:m)<<3);c[W>>2]=ya;m=0;za=ya;while(1){if((za>>3|0)>=(Ga|0)){ab=m;bb=za;break}if((c[B>>2]|0)>0){ya=m*18|0;xa=0;ta=za;while(1){c[W>>2]=(c[f+23200+(xa*4864|0)+(m*2432|0)+4>>2]|0)+ta;TGb(f+23200+(xa*4864|0)+(m*2432|0)+128|0,0,2304)|0;ZNa(f,f+23200+(xa*4864|0)+(m*2432|0)|0,f+9376+(xa*4608|0)+(ya<<7)|0,f+18592+(xa*2304|0)|0);ua=xa+1|0;n=c[W>>2]|0;if((ua|0)<(c[B>>2]|0)){xa=ua;ta=n}else{cb=n;break}}}else{cb=za}ta=m+1|0;if((ta|0)<(Fa|0)){m=ta;za=cb}else{ab=ta;bb=cb;break}}za=bb-(Ga<<3)|0;m=c[v>>2]|0;do{if((za|0)<(m|0)){E=170}else{W=da|0;if((c[W>>2]|0)==0){E=170;break}ta=za-m|0;xa=f+1124|0;ya=c[xa>>2]|0;n=-ya|0;ua=(c[f+1132>>2]|0)-ya|0;if((ta|0)<(n|0)){db=n}else{db=(ua|0)<(ta|0)?ua:ta}c[xa>>2]=db+ya;c[wa>>2]=c[ca>>2];c[wa+4>>2]=c[ca+4>>2];c[wa+8>>2]=c[ca+8>>2];c[wa+12>>2]=c[ca+12>>2];c[wa+16>>2]=c[ca+16>>2];c[W>>2]=0}}while(0);if((E|0)==170){m=c[u>>2]|0;W=-m|0;ya=(c[y>>2]|0)-m|0;if((za|0)<(W|0)){eb=W}else{eb=(ya|0)<(za|0)?ya:za}c[u>>2]=eb+m}if((ab|0)>=(Fa|0)){break}fb=ab;gb=c[B>>2]|0;hb=da;ib=wa;jb=ca;E=175}else{m=f+1116|0;fb=0;gb=Xa;hb=m;ib=t;jb=m;E=175}}while(0);if((E|0)==175){m=f+28|0;ya=f+32996|0;W=p|0;xa=p+4|0;ta=p+8|0;ua=q;n=q|0;X=r|0;V=hb|0;Y=f+32936|0;oa=s|0;va=s+12|0;S=s+8|0;na=s+4|0;ma=fb;la=0;aa=gb;while(1){_=la+fb|0;if((aa|0)>0){o=0;P=c[u>>2]|0;while(1){R=f+23200+(o*4864|0)+(_*2432|0)+76|0;do{if((c[Ca>>2]|0)==0){U=c[f+23200+(o*4864|0)+(ma*2432|0)+16>>2]|0;C=a[435792+U|0]|0;J=C&255;K=a[435808+U|0]|0;U=K&255;if((a[f+23200+(o*4864|0)+(ma*2432|0)+20|0]|0)==2){H=(a[f+23200+(o*4864|0)+(ma*2432|0)+21|0]|0)!=0?17:18;b:do{if(C<<24>>24==0){TGb(R|0,0,H|0)|0}else{I=32-J|0;Q=0;G=P;while(1){D=c[y>>2]|0;sa=(c[k>>2]|0)+(G>>>3)|0;O=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(G&7)>>>(I>>>0);sa=G+J|0;c[u>>2]=D>>>0>sa>>>0?sa:D;D=Q+1|0;a[f+23200+(o*4864|0)+(ma*2432|0)+76+Q|0]=O;if((D|0)>=(H|0)){break b}Q=D;G=c[u>>2]|0}}}while(0);if(K<<24>>24==0){TGb(f+23200+(o*4864|0)+(_*2432|0)+76+H|0,0,21)|0;break}C=32-U|0;G=H;Q=0;while(1){I=c[u>>2]|0;D=c[y>>2]|0;O=(c[k>>2]|0)+(I>>>3)|0;sa=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(I&7)>>>(C>>>0);O=I+U|0;c[u>>2]=D>>>0>O>>>0?O:D;a[f+23200+(o*4864|0)+(ma*2432|0)+76+G|0]=sa;sa=Q+1|0;if((sa|0)<18){G=G+1|0;Q=sa}else{break}}TGb(H+18+(f+23200+(o*4864|0)+(_*2432|0)+76)|0,0,3)|0;break}else{Q=f+23200+(o*4864|0)+(ma*2432|0)|0;G=0;C=0;while(1){K=(G|0)==0?6:5;c:do{if((d[Q]&8>>>(G>>>0)|0)==0){sa=(G|0)<2?J:U;if((sa|0)==0){TGb(f+23200+(o*4864|0)+(_*2432|0)+76+C|0,0,K|0)|0;break}D=32-sa|0;O=C;I=1;while(1){ea=c[u>>2]|0;M=c[y>>2]|0;ha=(c[k>>2]|0)+(ea>>>3)|0;pa=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ea&7)>>>(D>>>0);ha=ea+sa|0;c[u>>2]=M>>>0>ha>>>0?ha:M;a[f+23200+(o*4864|0)+(ma*2432|0)+76+O|0]=pa;if((I|0)>=(K|0)){break c}O=O+1|0;I=I+1|0}}else{I=C;O=0;while(1){a[f+23200+(o*4864|0)+(ma*2432|0)+76+I|0]=a[f+23200+(o*4864|0)+76+I|0]|0;sa=O+1|0;if((sa|0)<(K|0)){I=I+1|0;O=sa}else{break}}}}while(0);O=G+1|0;if((O|0)<4){G=O;C=K+C|0}else{break}}a[f+23200+(o*4864|0)+(ma*2432|0)+97|0]=0;break}}else{if((a[f+23200+(o*4864|0)+(ma*2432|0)+20|0]|0)==2){kb=(a[f+23200+(o*4864|0)+(ma*2432|0)+21|0]|0)!=0?2:1}else{kb=0}C=c[f+23200+(o*4864|0)+(ma*2432|0)+16>>2]|0;do{if((c[x>>2]&1|0)!=0&(o|0)==1){G=C>>1;if((G|0)<180){c[va>>2]=0;U=(G*171|0)>>10;c[S>>2]=(U*-6|0)+G;J=(U*171|0)>>10;c[na>>2]=(J*-6|0)+U;c[oa>>2]=J;lb=3;mb=J;break}if((G|0)<244){J=G-180|0;c[va>>2]=0;c[S>>2]=J&3;c[na>>2]=J>>>2&3;U=J>>4;c[oa>>2]=U;lb=4;mb=U;break}else{U=G-244|0;c[va>>2]=0;c[S>>2]=0;G=(U*171|0)>>9;c[na>>2]=(G*-3|0)+U;c[oa>>2]=G;lb=5;mb=G;break}}else{if((C|0)<400){c[va>>2]=C&3;c[S>>2]=C>>>2&3;G=C>>4;U=(G*205|0)>>10;c[na>>2]=(U*-5|0)+G;c[oa>>2]=U;lb=0;mb=U;break}if((C|0)<500){U=C-400|0;c[va>>2]=0;c[S>>2]=U&3;G=U>>2;U=(G*205|0)>>10;c[na>>2]=(U*-5|0)+G;c[oa>>2]=U;lb=1;mb=U;break}else{U=C-500|0;c[va>>2]=0;c[S>>2]=0;G=(U*171|0)>>9;c[na>>2]=(G*-3|0)+U;c[oa>>2]=G;c[f+23200+(o*4864|0)+(ma*2432|0)+64>>2]=1;lb=2;mb=G;break}}}while(0);C=0;G=0;U=mb;while(1){J=a[730800+(lb*12|0)+(kb<<2)+C|0]|0;Q=J&255;H=J<<24>>24==0;do{if((U|0)==0){if(H){nb=G;break}J=Q>>>0>1>>>0?Q:1;TGb(f+23200+(o*4864|0)+(_*2432|0)+76+G|0,0,J|0)|0;nb=J+G|0}else{if(H){nb=G;break}J=32-U|0;O=Q>>>0>1>>>0;I=G;sa=1;while(1){D=c[u>>2]|0;pa=c[y>>2]|0;M=(c[k>>2]|0)+(D>>>3)|0;ha=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(D&7)>>>(J>>>0);M=D+U|0;c[u>>2]=pa>>>0>M>>>0?M:pa;a[f+23200+(o*4864|0)+(ma*2432|0)+76+I|0]=ha;if((sa|0)>=(Q|0)){break}I=I+1|0;sa=sa+1|0}nb=(O?Q:1)+G|0}}while(0);Q=C+1|0;if((Q|0)>=4){break}C=Q;G=nb;U=c[s+(Q<<2)>>2]|0}if((nb|0)>=40){break}TGb(f+23200+(o*4864|0)+(_*2432|0)+76+nb|0,0,40-nb|0)|0}}while(0);R=c[A>>2]|0;U=c[f+23200+(o*4864|0)+(ma*2432|0)+12>>2]|0;G=(d[f+23200+(o*4864|0)+(ma*2432|0)+48|0]|0)+1|0;C=c[f+23200+(o*4864|0)+(ma*2432|0)+64>>2]|0;Q=c[f+23200+(o*4864|0)+(ma*2432|0)+72>>2]|0;if((Q|0)>0){H=U+190|0;K=0;sa=X;while(1){I=a[1738504+(R*22|0)+K|0]|0;if(I<<24>>24==0){ob=sa}else{J=I&255;I=H-((d[f+23200+(o*4864|0)+(ma*2432|0)+76+K|0]|0)+(d[661960+(C*22|0)+K|0]|0)<<G)&65535;ha=-J|0;pa=J;M=sa;while(1){b[M>>1]=I;D=pa-1|0;if((D|0)>0){pa=D;M=M+2|0}else{break}}ob=sa+(J+1+((ha|0)>-1?ha:-1)<<1)|0}M=K+1|0;if((M|0)<(Q|0)){K=M;sa=ob}else{pb=ob;break}}}else{pb=X}sa=c[f+23200+(o*4864|0)+(ma*2432|0)+68>>2]|0;if((sa|0)<13){K=U+190|0;C=K-(c[f+23200+(o*4864|0)+(ma*2432|0)+36>>2]<<3)|0;H=K-(c[f+23200+(o*4864|0)+(ma*2432|0)+40>>2]<<3)|0;M=K-(c[f+23200+(o*4864|0)+(ma*2432|0)+44>>2]<<3)|0;K=sa;sa=Q;pa=pb;while(1){I=a[1738264+(R*13|0)+K|0]|0;D=I&255;ea=-D|0;N=(ea|0)>-1?ea:-1;ea=sa+1|0;if(I<<24>>24==0){qb=pa}else{I=C-(d[f+23200+(o*4864|0)+(ma*2432|0)+76+sa|0]<<G)&65535;ia=D;ja=pa;while(1){b[ja>>1]=I;qa=ia-1|0;if((qa|0)>0){ia=qa;ja=ja+2|0}else{break}}ja=D+1+N|0;ia=H-(d[f+23200+(o*4864|0)+(ma*2432|0)+76+ea|0]<<G)&65535;I=D;ha=pa+(ja<<1)|0;while(1){b[ha>>1]=ia;J=I-1|0;if((J|0)>0){I=J;ha=ha+2|0}else{break}}ha=ja<<1;I=M-(d[sa+2+(f+23200+(o*4864|0)+(ma*2432|0)+76)|0]<<G)&65535;ia=D;ea=pa+(ha<<1)|0;while(1){b[ea>>1]=I;N=ia-1|0;if((N|0)>0){ia=N;ea=ea+2|0}else{break}}qb=pa+(ha+ja<<1)|0}ea=K+1|0;if((ea|0)<13){K=ea;sa=sa+3|0;pa=qb}else{break}}}pa=(c[f+23200+(o*4864|0)+(ma*2432|0)+4>>2]|0)+P|0;sa=c[v>>2]|0;K=pa;G=(sa|0)<(pa|0)?sa:pa;pa=0;sa=0;while(1){M=c[f+23200+(o*4864|0)+(ma*2432|0)+52+(pa<<2)>>2]|0;d:do{if((M|0)==0){rb=sa;sb=G;tb=K}else{H=c[f+23200+(o*4864|0)+(ma*2432|0)+24+(pa<<2)>>2]|0;C=d[670792+(H<<1)|0]|0;R=d[670793+(H<<1)|0]|0;if((16401>>>(H>>>0)&1|0)!=0){TGb(f+23200+(o*4864|0)+(ma*2432|0)+128+(sa<<2)|0,0,M<<3|0)|0;rb=(M<<1)+sa|0;sb=G;tb=K;break}if((M|0)<=0){rb=sa;sb=G;tb=K;break}Q=5129364+(C*20|0)|0;C=H>>>0<16>>>0;H=32-R|0;U=K;ea=G;ia=M;I=sa;while(1){D=c[u>>2]|0;if((D|0)<(ea|0)){ub=ea;vb=U;wb=D}else{do{if((c[V>>2]|0)==0){xb=D;yb=ea;zb=U}else{if((D|0)<(c[v>>2]|0)){xb=D;yb=ea;zb=U;break}c[ib>>2]=c[jb>>2];c[ib+4>>2]=c[jb+4>>2];c[ib+8>>2]=c[jb+8>>2];c[ib+12>>2]=c[jb+12>>2];c[ib+16>>2]=c[jb+16>>2];c[V>>2]=0;N=D-ea|0;J=c[u>>2]|0;qa=-J|0;ka=(c[y>>2]|0)-J|0;if((N|0)<(qa|0)){Ab=qa}else{Ab=(ka|0)<(N|0)?ka:N}N=Ab+J|0;c[u>>2]=N;J=N+(U-D)|0;xb=N;yb=J;zb=J}}while(0);if((xb|0)<(yb|0)){ub=yb;vb=zb;wb=xb}else{rb=I;sb=yb;tb=zb;break d}}D=c[Q>>2]|0;O=c[y>>2]|0;J=c[k>>2]|0;N=J+(wb>>>3)|0;ka=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(wb&7)>>>25;N=b[D+(ka<<2)>>1]|0;qa=b[D+(ka<<2)+2>>1]|0;ka=qa<<16>>16;do{if(qa<<16>>16<0){ga=wb+7|0;L=O>>>0>ga>>>0?ga:O;ga=J+(L>>>3)|0;fa=((fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(L&7)>>>((ka+32|0)>>>0))+N|0;ga=b[D+(fa<<2)>>1]|0;ra=b[D+(fa<<2)+2>>1]|0;fa=ra<<16>>16;if(!(ra<<16>>16<0)){Bb=fa;Cb=ga;Db=L;break}ra=L-ka|0;L=O>>>0>ra>>>0?ra:O;ra=J+(L>>>3)|0;Eb=((fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(L&7)>>>((fa+32|0)>>>0))+ga|0;Bb=b[D+(Eb<<2)+2>>1]|0;Cb=b[D+(Eb<<2)>>1]|0;Db=L}else{Bb=ka;Cb=N;Db=wb}}while(0);N=Bb+Db|0;ka=O>>>0>N>>>0?N:O;c[u>>2]=ka;do{if((Cb|0)==0){g[f+23200+(o*4864|0)+(ma*2432|0)+128+(I+1<<2)>>2]=0.0;g[f+23200+(o*4864|0)+(ma*2432|0)+128+(I<<2)>>2]=0.0}else{N=b[r+(I<<1)>>1]|0;D=Cb>>5;qa=Cb&15;if((Cb&16|0)==0){L=D+qa|0;if((L|0)<15){Eb=c[8019384+(N<<6)+(L<<2)>>2]|0;ga=d[J+(ka>>>3)|0]<<(ka&7)>>>7;c[u>>2]=((ka|0)<(O|0))+ka;c[f+23200+(o*4864|0)+(ma*2432|0)+128+(((qa|0)!=0)+I<<2)>>2]=ga<<31^Eb}else{if(C){Fb=0;Gb=ka}else{Eb=J+(ka>>>3)|0;ga=(fe(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(ka&7)>>>(H>>>0);Eb=ka+R|0;fa=O>>>0>Eb>>>0?Eb:O;c[u>>2]=fa;Fb=ga;Gb=fa}fa=Fb+L<<2|N&3;L=(a[4208624+fa|0]|0)-(N>>2)|0;if((L|0)>31){Hb=0}else{Hb=((c[3946e3+(fa<<2)>>2]|0)+(1<<L-1)|0)>>>(L>>>0)}L=d[J+(Gb>>>3)|0]|0;c[u>>2]=((Gb|0)<(O|0))+Gb;g[f+23200+(o*4864|0)+(ma*2432|0)+128+(((qa|0)!=0)+I<<2)>>2]=+(((L&128>>>((Gb&7)>>>0)|0)==0?Hb:-Hb|0)|0)}g[f+23200+(o*4864|0)+(ma*2432|0)+128+(((qa|0)==0)+I<<2)>>2]=0.0;break}if((D|0)<15){L=c[8019384+(N<<6)+(D<<2)>>2]|0;fa=d[J+(ka>>>3)|0]<<(ka&7)>>>7;c[u>>2]=((ka|0)<(O|0))+ka;c[f+23200+(o*4864|0)+(ma*2432|0)+128+(I<<2)>>2]=fa<<31^L}else{if(C){Ib=0;Jb=ka}else{L=J+(ka>>>3)|0;fa=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(ka&7)>>>(H>>>0);L=ka+R|0;ga=O>>>0>L>>>0?L:O;c[u>>2]=ga;Ib=fa;Jb=ga}ga=Ib+D<<2|N&3;D=(a[4208624+ga|0]|0)-(N>>2)|0;if((D|0)>31){Kb=0}else{Kb=((c[3946e3+(ga<<2)>>2]|0)+(1<<D-1)|0)>>>(D>>>0)}D=d[J+(Jb>>>3)|0]|0;c[u>>2]=((Jb|0)<(O|0))+Jb;g[f+23200+(o*4864|0)+(ma*2432|0)+128+(I<<2)>>2]=+(((D&128>>>((Jb&7)>>>0)|0)==0?Kb:-Kb|0)|0)}if((qa|0)!=15){D=c[8019384+(N<<6)+(qa<<2)>>2]|0;qa=c[u>>2]|0;ga=d[(c[k>>2]|0)+(qa>>>3)|0]<<(qa&7)>>>7;c[u>>2]=((qa|0)<(c[y>>2]|0))+qa;c[f+23200+(o*4864|0)+(ma*2432|0)+128+(I+1<<2)>>2]=ga<<31^D;break}if(C){Lb=60}else{D=c[u>>2]|0;ga=c[y>>2]|0;qa=(c[k>>2]|0)+(D>>>3)|0;fa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(D&7)>>>(H>>>0);qa=D+R|0;c[u>>2]=ga>>>0>qa>>>0?qa:ga;Lb=(fa<<2)+60|0}fa=Lb|N&3;ga=(a[4208624+fa|0]|0)-(N>>2)|0;if((ga|0)>31){Mb=0}else{Mb=((c[3946e3+(fa<<2)>>2]|0)+(1<<ga-1)|0)>>>(ga>>>0)}ga=c[u>>2]|0;fa=d[(c[k>>2]|0)+(ga>>>3)|0]|0;c[u>>2]=((ga|0)<(c[y>>2]|0))+ga;g[f+23200+(o*4864|0)+(ma*2432|0)+128+(I+1<<2)>>2]=+(((fa&128>>>((ga&7)>>>0)|0)==0?Mb:-Mb|0)|0)}}while(0);O=I+2|0;J=ia-1|0;if((J|0)>0){U=vb;ea=ub;ia=J;I=O}else{rb=O;sb=ub;tb=vb;break}}}}while(0);M=pa+1|0;if((M|0)<3){K=tb;G=sb;pa=M;sa=rb}else{break}}sa=d[f+23200+(o*4864|0)+(ma*2432|0)+49|0]|0;e:do{if((rb|0)<573){pa=5131220+(sa*20|0)|0;G=5131216+(sa*20|0)|0;K=tb;M=sb;ja=0;ha=rb;while(1){Nb=c[u>>2]|0;if((Nb|0)<(M|0)){Ob=Nb;Pb=M;Qb=K}else{if(!((Nb|0)<=(K|0)|(ja|0)==0)){break}do{if((c[V>>2]|0)==0){Rb=Nb;Sb=M;Tb=K}else{if((Nb|0)<(c[v>>2]|0)){Rb=Nb;Sb=M;Tb=K;break}c[ib>>2]=c[jb>>2];c[ib+4>>2]=c[jb+4>>2];c[ib+8>>2]=c[jb+8>>2];c[ib+12>>2]=c[jb+12>>2];c[ib+16>>2]=c[jb+16>>2];c[V>>2]=0;I=Nb-M|0;ia=c[u>>2]|0;ea=-ia|0;U=(c[y>>2]|0)-ia|0;if((I|0)<(ea|0)){Ub=ea}else{Ub=(U|0)<(I|0)?U:I}I=Ub+ia|0;c[u>>2]=I;ia=I+(K-Nb)|0;Rb=I;Sb=ia;Tb=ia}}while(0);if((Rb|0)<(Sb|0)){Ob=Rb;Pb=Sb;Qb=Tb}else{Vb=ha;Wb=Sb;Xb=Tb;break e}}ia=c[pa>>2]|0;I=c[G>>2]|0;U=c[y>>2]|0;ea=c[k>>2]|0;R=ea+(Ob>>>3)|0;H=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Ob&7)>>>((32-I|0)>>>0);I=b[ia+(H<<2)>>1]|0;R=(b[ia+(H<<2)+2>>1]|0)+Ob|0;H=U>>>0>R>>>0?R:U;c[u>>2]=H;g[f+23200+(o*4864|0)+(ma*2432|0)+128+(ha+3<<2)>>2]=0.0;g[f+23200+(o*4864|0)+(ma*2432|0)+128+(ha+2<<2)>>2]=0.0;g[f+23200+(o*4864|0)+(ma*2432|0)+128+(ha+1<<2)>>2]=0.0;g[f+23200+(o*4864|0)+(ma*2432|0)+128+(ha<<2)>>2]=0.0;f:do{if(!(I<<16>>16==0)){R=I<<16>>16;ia=H;C=ea;Q=U;while(1){O=c[918816+(R<<2)>>2]|0;J=O+ha|0;ka=8>>>(O>>>0);O=c[8151992+(b[r+(J<<1)>>1]<<2)>>2]|0;ga=d[C+(ia>>>3)|0]<<(ia&7)>>>7;c[u>>2]=((ia|0)<(Q|0))+ia;c[f+23200+(o*4864|0)+(ma*2432|0)+128+(J<<2)>>2]=ga<<31^O;if((ka|0)==(R|0)){break f}R=ka^R;ia=c[u>>2]|0;C=c[k>>2]|0;Q=c[y>>2]|0}}}while(0);U=ha+4|0;if((U|0)<573){K=Qb;M=Pb;ja=Ob;ha=U}else{Vb=U;Wb=Pb;Xb=Qb;break e}}G=ja-Nb|0;pa=-Nb|0;U=(c[y>>2]|0)-Nb|0;if((G|0)<(pa|0)){Yb=pa}else{Yb=(U|0)<(G|0)?U:G}c[u>>2]=Yb+Nb;yDb(c[T>>2]|0,32,2144368,(Ra=i,i=i+24|0,c[Ra>>2]=G,c[Ra+8>>2]=M-Nb,c[Ra+16>>2]=K-Nb,Ra)|0);i=Ra;Vb=(c[Y>>2]&131074|0)==0?ha-4|0:0;Wb=M;Xb=K}else{Vb=rb;Wb=sb;Xb=tb}}while(0);sa=Xb-(c[u>>2]|0)|0;do{if((sa|0)<0){if((c[Y>>2]&131076|0)==0){E=308;break}yDb(c[T>>2]|0,16,2138752,(Ra=i,i=i+8|0,c[Ra>>2]=sa,Ra)|0);i=Ra;Zb=0}else{E=308}}while(0);do{if((E|0)==308){E=0;if((sa|0)<=0){Zb=Vb;break}if((c[Y>>2]&262148|0)==0){Zb=Vb;break}yDb(c[T>>2]|0,16,2138752,(Ra=i,i=i+8|0,c[Ra>>2]=sa,Ra)|0);i=Ra;Zb=0}}while(0);TGb(f+23200+(o*4864|0)+(ma*2432|0)+128+(Zb<<2)|0,0,576-Zb<<2|0)|0;G=c[u>>2]|0;U=-G|0;pa=(c[y>>2]|0)-G|0;if((sa|0)<(U|0)){_b=U}else{_b=(pa|0)<(sa|0)?pa:sa}pa=_b+G|0;c[u>>2]=pa;do{if((c[V>>2]|0)==0){$b=pa}else{if((pa|0)<(c[v>>2]|0)){$b=pa;break}c[ib>>2]=c[jb>>2];c[ib+4>>2]=c[jb+4>>2];c[ib+8>>2]=c[jb+8>>2];c[ib+12>>2]=c[jb+12>>2];c[ib+16>>2]=c[jb+16>>2];c[V>>2]=0;G=pa-Wb|0;U=c[u>>2]|0;ea=-U|0;H=(c[y>>2]|0)-U|0;if((G|0)<(ea|0)){ac=ea}else{ac=(H|0)<(G|0)?H:G}G=ac+U|0;c[u>>2]=G;$b=G}}while(0);pa=o+1|0;sa=c[B>>2]|0;if((pa|0)<(sa|0)){o=pa;P=$b}else{bc=sa;break}}}else{bc=aa}g:do{if((c[m>>2]|0)==1){P=c[x>>2]|0;if((P&1|0)==0){if((P&2|0)==0){cc=bc;break}Xe[c[ya>>2]&4095](f+23200+(ma*2432|0)+128|0,f+28064+(ma*2432|0)+128|0,576);cc=c[B>>2]|0;break}if((c[Ca>>2]|0)==0){dc=5016088;ec=7}else{dc=5015576+((c[f+28064+(ma*2432|0)+16>>2]&1)<<7)|0;ec=16}o=f+23200+(ma*2432|0)+2432|0;_=f+28064+(ma*2432|0)+2432|0;c[W>>2]=0;c[xa>>2]=0;c[ta>>2]=0;ca=c[f+28064+(ma*2432|0)+68>>2]|0;wa=c[f+28064+(ma*2432|0)+72>>2]|0;if((ca|0)>12){fc=o;gc=_}else{da=c[A>>2]|0;za=(P&2|0)==0;sa=12;pa=wa-3+((13-ca|0)*3|0)|0;G=o;o=_;while(1){_=(sa|0)==11?pa:pa-3|0;U=a[1738264+(da*13|0)+sa|0]|0;H=U&255;ea=-H|0;I=U<<24>>24==0;U=za|I;Q=2;C=G;ia=o;while(1){R=C+(ea<<2)|0;ka=ia+(ea<<2)|0;O=p+(Q<<2)|0;do{if((c[O>>2]|0)==0){ga=0;while(1){if((ga|0)>=(H|0)){break}if(+g[ia+(ga-H<<2)>>2]!=0.0){E=329;break}else{ga=ga+1|0}}if((E|0)==329){E=0;c[O>>2]=1;E=333;break}ga=d[Q+_+(f+28064+(ma*2432|0)+76)|0]|0;if(!(ga>>>0<ec>>>0)){E=333;break}Z=+g[dc+(ga<<2)>>2];hc=+g[dc+64+(ga<<2)>>2];if(I){break}else{ic=0}do{ga=ic-H|0;J=C+(ga<<2)|0;jc=+g[J>>2];g[J>>2]=Z*jc;g[ia+(ga<<2)>>2]=hc*jc;ic=ic+1|0;}while((ic|0)<(H|0))}else{E=333}}while(0);do{if((E|0)==333){E=0;if(U){break}else{kc=0}do{O=kc-H|0;ga=C+(O<<2)|0;hc=+g[ga>>2];J=ia+(O<<2)|0;Z=+g[J>>2];g[ga>>2]=(hc+Z)*.7071067690849304;g[J>>2]=(hc-Z)*.7071067690849304;kc=kc+1|0;}while((kc|0)<(H|0))}}while(0);if((Q|0)<=0){break}Q=Q-1|0;C=R;ia=ka}ia=H*-3|0;C=o+(ia<<2)|0;Q=G+(ia<<2)|0;ia=sa-1|0;if((ia|0)<(ca|0)){fc=Q;gc=C;break}else{sa=ia;pa=_;G=Q;o=C}}}if((wa|0)<=0){cc=bc;break}o=c[A>>2]|0;G=(P&2|0)==0;pa=c[W>>2]|c[xa>>2]|c[ta>>2];sa=fc;ca=gc;za=wa;while(1){da=(pa|0)==0;C=sa;Q=ca;ia=za;h:while(1){lc=ia-1|0;mc=a[1738504+(o*22|0)+lc|0]|0;nc=mc&255;U=-nc|0;oc=C+(U<<2)|0;pc=Q+(U<<2)|0;if(da){qc=0}else{rc=pa;break}while(1){if((qc|0)>=(nc|0)){break}if(+g[Q+(qc-nc<<2)>>2]!=0.0){rc=1;break h}else{qc=qc+1|0}}ka=d[((lc|0)==21?20:lc)+(f+28064+(ma*2432|0)+76)|0]|0;if(!(ka>>>0<ec>>>0)){rc=pa;break}Z=+g[dc+(ka<<2)>>2];hc=+g[dc+64+(ka<<2)>>2];if(!(mc<<24>>24==0)){ka=0;do{R=ka-nc|0;U=C+(R<<2)|0;jc=+g[U>>2];g[U>>2]=Z*jc;g[Q+(R<<2)>>2]=hc*jc;ka=ka+1|0;}while((ka|0)<(nc|0))}if((lc|0)>0){C=oc;Q=pc;ia=lc}else{cc=bc;break g}}if(!(G|mc<<24>>24==0)){ia=0;do{da=ia-nc|0;_=C+(da<<2)|0;hc=+g[_>>2];H=Q+(da<<2)|0;Z=+g[H>>2];g[_>>2]=(hc+Z)*.7071067690849304;g[H>>2]=(hc-Z)*.7071067690849304;ia=ia+1|0;}while((ia|0)<(nc|0))}if((lc|0)>0){pa=rc;sa=oc;ca=pc;za=lc}else{cc=bc;break}}}else{cc=bc}}while(0);if((cc|0)>0){za=ma*18|0;ca=0;while(1){sa=f+23200+(ca*4864|0)+(ma*2432|0)|0;pa=f+23200+(ca*4864|0)+(ma*2432|0)+20|0;do{if((a[pa]|0)==2){G=f+23200+(ca*4864|0)+(ma*2432|0)+21|0;o=a[G]|0;do{if(o<<24>>24==0){sc=f+23200+(ca*4864|0)+(ma*2432|0)+128|0}else{if((c[A>>2]|0)==8){sc=f+23200+(ca*4864|0)+(ma*2432|0)+416|0;break}else{sc=f+23200+(ca*4864|0)+(ma*2432|0)+272|0;break}}}while(0);wa=c[f+23200+(ca*4864|0)+(ma*2432|0)+68>>2]|0;if((wa|0)<13){P=sc;ia=wa;while(1){wa=a[1738264+((c[A>>2]|0)*13|0)+ia|0]|0;Q=wa&255;C=Q<<1;if(wa<<24>>24==0){tc=P}else{wa=-Q|0;H=Q;_=P;da=n;while(1){g[da>>2]=+g[_>>2];g[da+4>>2]=+g[_+(Q<<2)>>2];g[da+8>>2]=+g[_+(C<<2)>>2];ka=H-1|0;if((ka|0)>0){H=ka;_=_+4|0;da=da+12|0}else{break}}tc=P+(Q+1+((wa|0)>-1?wa:-1)<<2)|0}UGb(P|0,ua|0,Q*12|0)|0;da=ia+1|0;if((da|0)>=13){break}P=tc+(C<<2)|0;ia=da}if((a[pa]|0)!=2){uc=31;E=371;break}vc=a[G]|0}else{vc=o}if(!(vc<<24>>24==0)){uc=1;E=371}}else{uc=31;E=371}}while(0);if((E|0)==371){E=0;pa=uc;ia=f+23200+(ca*4864|0)+(ma*2432|0)+200|0;while(1){P=ia-4|0;Z=+g[P>>2];hc=+g[ia>>2];g[P>>2]=Z*+g[2187464]-hc*+g[2187465];g[ia>>2]=Z*+g[2187465]+hc*+g[2187464];P=ia-8|0;hc=+g[P>>2];da=ia+4|0;Z=+g[da>>2];g[P>>2]=hc*+g[2187468]-Z*+g[2187469];g[da>>2]=hc*+g[2187469]+Z*+g[2187468];da=ia-12|0;Z=+g[da>>2];P=ia+8|0;hc=+g[P>>2];g[da>>2]=Z*+g[2187472]-hc*+g[2187473];g[P>>2]=Z*+g[2187473]+hc*+g[2187472];P=ia-16|0;hc=+g[P>>2];da=ia+12|0;Z=+g[da>>2];g[P>>2]=hc*+g[2187476]-Z*+g[2187477];g[da>>2]=hc*+g[2187477]+Z*+g[2187476];da=ia-20|0;Z=+g[da>>2];P=ia+16|0;hc=+g[P>>2];g[da>>2]=Z*+g[2187480]-hc*+g[2187481];g[P>>2]=Z*+g[2187481]+hc*+g[2187480];P=ia-24|0;hc=+g[P>>2];da=ia+20|0;Z=+g[da>>2];g[P>>2]=hc*+g[2187484]-Z*+g[2187485];g[da>>2]=hc*+g[2187485]+Z*+g[2187484];da=ia-28|0;Z=+g[da>>2];P=ia+24|0;hc=+g[P>>2];g[da>>2]=Z*+g[2187488]-hc*+g[2187489];g[P>>2]=Z*+g[2187489]+hc*+g[2187488];P=ia-32|0;hc=+g[P>>2];da=ia+28|0;Z=+g[da>>2];g[P>>2]=hc*+g[2187492]-Z*+g[2187493];g[da>>2]=hc*+g[2187493]+Z*+g[2187492];da=pa-1|0;if((da|0)>0){pa=da;ia=ia+72|0}else{break}}}ZNa(f,sa,f+9376+(ca*4608|0)+(za<<7)|0,f+18592+(ca*2304|0)|0);ia=ca+1|0;pa=c[B>>2]|0;if((ia|0)<(pa|0)){ca=ia}else{wc=pa;break}}}else{wc=cc}ca=ma+1|0;if((ca|0)<(Fa|0)){ma=ca;la=la+1|0;aa=wc}else{break}}}aa=c[u>>2]|0;if((aa|0)<0){la=-aa|0;ma=(c[y>>2]|0)-aa|0;c[u>>2]=((ma|0)<(la|0)?ma:la)+aa}_a=Fa*18|0}aa=f+1088|0;c[aa>>2]=0;la=f+1116|0;ma=la|0;if((c[ma>>2]|0)!=0){B=c[u>>2]|0;ua=-B&7;if((ua|0)==0){xc=B}else{n=c[y>>2]|0;A=ua+B|0;B=n>>>0>A>>>0?A:n;c[u>>2]=B;xc=B}B=(c[v>>2]|0)-xc>>3;if(B>>>0<513>>>0){VGb(f+40|0,(c[k>>2]|0)+(xc>>3)|0,B|0)|0;c[aa>>2]=B}else{yDb(c[T>>2]|0,16,2209048,(Ra=i,i=i+8|0,c[Ra>>2]=B,Ra)|0);i=Ra}B=t;n=la;c[B>>2]=c[n>>2];c[B+4>>2]=c[n+4>>2];c[B+8>>2]=c[n+8>>2];c[B+12>>2]=c[n+12>>2];c[B+16>>2]=c[n+16>>2];c[ma>>2]=0}ma=c[u>>2]|0;n=-ma&7;if((n|0)==0){yc=ma}else{B=c[y>>2]|0;la=n+ma|0;ma=B>>>0>la>>>0?la:B;c[u>>2]=ma;yc=ma}ma=(c[v>>2]|0)-yc>>3;B=(_a|0)<0;if(ma>>>0>512>>>0|B){if((ma|0)<0){yDb(c[T>>2]|0,16,2200440,(Ra=i,i=i+8|0,c[Ra>>2]=ma,Ra)|0);i=Ra}zc=(j|0)<512?j:512}else{zc=ma}UGb((c[aa>>2]|0)+(f+40)|0,(c[k>>2]|0)+(j-zc)|0,zc)|0;c[aa>>2]=(c[aa>>2]|0)+zc;if(B){Ac=_a}else{$=_a;break}i=l;return Ac|0}}while(0);do{if((h|0)==0){_a=f+33004|0;zc=c[_a>>2]|0;if((zc|0)==0){yDb(0,0,2191960,(Ra=i,i=i+24|0,c[Ra>>2]=2175488,c[Ra+8>>2]=2165120,c[Ra+16>>2]=1606,Ra)|0);i=Ra;Cd();return 0}j=c[f+32940>>2]|0;c[zc+76>>2]=c[j+424>>2];k=_$a(j,zc,0)|0;if((k|0)<0){Ac=k;i=l;return Ac|0}else{Bc=c[(c[_a>>2]|0)+64>>2]|0;break}}else{Bc=h}}while(0);h=f+24|0;Ra=c[h>>2]|0;if((Ra|0)>0){_a=f+32940|0;k=($|0)>0;zc=f+32944|0;j=f+32932|0;yc=0;v=Ra;while(1){if((c[(c[_a>>2]|0)+420>>2]|0)==8){Cc=1;Dc=c[Bc+(yc<<2)>>2]|0}else{Cc=v;Dc=(c[Bc>>2]|0)+(yc<<2)|0}if(k){u=f+1152+(yc<<12)|0;y=f+9344+(yc<<2)|0;t=Cc<<5;xc=0;Fa=Dc;while(1){iOa(zc,u,y,6867408,j,Fa,Cc,f+9376+(yc*4608|0)+(xc<<7)|0);wc=xc+1|0;if((wc|0)<($|0)){xc=wc;Fa=Fa+(t<<2)|0}else{break}}Ec=c[h>>2]|0}else{Ec=v}t=yc+1|0;if((t|0)<(Ec|0)){yc=t;v=Ec}else{Fc=Ec;break}}}else{Fc=Ra}Ac=ba($<<7,Fc)|0;i=l;return Ac|0}function ZNa(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;j=i;i=i+48|0;k=j|0;l=e+128|0;m=e+272|0;n=e+2432|0;while(1){if(n>>>0<m>>>0){o=n;break}p=n-24|0;if((c[n-20>>2]|c[p>>2]|c[n-16>>2]|c[n-12>>2]|c[n-8>>2]|c[n-4>>2]|0)==0){n=p}else{o=p;break}}n=((o-l>>2|0)/18|0)+1|0;o=a[e+20|0]|0;m=e+21|0;if(o<<24>>24==2){q=(a[m]|0)==0?0:2}else{q=n}Se[c[b+32960>>2]&511](f,h,l,q,d[m]|0,o&255);o=h+(((q>>2)*72|0|q&3)<<2)|0;if((q|0)<(n|0)){h=k|0;m=k+40|0;l=k+28|0;b=k+16|0;p=k+4|0;r=k+36|0;s=k+32|0;t=k+12|0;u=k+8|0;v=k+20|0;w=k+44|0;x=k+24|0;y=o;z=q;A=e+128+((q*18|0)<<2)|0;e=f+(q+192<<2)|0;B=f+(q+384<<2)|0;while(1){g[f+(z<<2)>>2]=+g[y>>2];q=y+16|0;g[f+(z+32<<2)>>2]=+g[q>>2];C=y+32|0;g[f+(z+64<<2)>>2]=+g[C>>2];D=y+48|0;g[f+(z+96<<2)>>2]=+g[D>>2];E=y+64|0;g[f+(z+128<<2)>>2]=+g[E>>2];F=y+80|0;g[f+(z+160<<2)>>2]=+g[F>>2];G=-(z&1)&4|2;H=+g[A>>2];I=+g[A+12>>2];J=H+I;K=+g[A+24>>2];L=+g[A+36>>2];M=K+L;N=+g[A+48>>2];O=L+N;L=M+(N+ +g[A+60>>2]);N=(I+K)*.8660253882408142;K=(J+M)*1.7320507764816284;M=H-O;I=(J-L)*.7071067690849304;P=M+I;g[m>>2]=P;g[l>>2]=P;P=M-I;g[b>>2]=P;g[p>>2]=P;P=H+O*.5;O=N+P;H=J*2.0+L;L=(K+H)*.258819043636322;J=O+L;g[r>>2]=J;g[s>>2]=J;J=O-L;g[t>>2]=J;g[u>>2]=J;J=P-N;N=(H-K)*.9659258127212524;K=J-N;g[v>>2]=K;g[h>>2]=K;H=J+N;g[w>>2]=H;g[x>>2]=H;Q=6873552+(G*160|0)|0;g[e>>2]=+g[Q>>2]*K+ +g[y+96>>2];R=6873576+(G*160|0)|0;S=y+192|0;g[S>>2]=+g[R>>2]*+g[x>>2];T=6873556+(G*160|0)|0;g[e+128>>2]=+g[T>>2]*+g[p>>2]+ +g[y+112>>2];U=6873580+(G*160|0)|0;V=y+208|0;g[V>>2]=+g[U>>2]*+g[l>>2];W=6873560+(G*160|0)|0;g[e+256>>2]=+g[W>>2]*+g[u>>2]+ +g[y+128>>2];X=6873584+(G*160|0)|0;Y=y+224|0;g[Y>>2]=+g[X>>2]*+g[s>>2];Z=6873564+(G*160|0)|0;g[e+384>>2]=+g[Z>>2]*+g[t>>2]+ +g[y+144>>2];_=6873588+(G*160|0)|0;$=y+240|0;g[$>>2]=+g[_>>2]*+g[r>>2];aa=6873568+(G*160|0)|0;g[e+512>>2]=+g[aa>>2]*+g[b>>2]+ +g[y+160>>2];ba=6873592+(G*160|0)|0;ca=y+256|0;g[ca>>2]=+g[ba>>2]*+g[m>>2];da=6873572+(G*160|0)|0;g[e+640>>2]=+g[da>>2]*+g[v>>2]+ +g[y+176>>2];ea=6873596+(G*160|0)|0;fa=y+272|0;g[fa>>2]=+g[ea>>2]*+g[w>>2];K=+g[A+4>>2];H=+g[A+16>>2];N=K+H;J=+g[A+28>>2];P=+g[A+40>>2];L=J+P;O=+g[A+52>>2];I=P+O;P=L+(O+ +g[A+64>>2]);O=(H+J)*.8660253882408142;J=(N+L)*1.7320507764816284;L=K-I;H=(N-P)*.7071067690849304;M=L+H;g[m>>2]=M;g[l>>2]=M;M=L-H;g[b>>2]=M;g[p>>2]=M;M=K+I*.5;I=O+M;K=N*2.0+P;P=(J+K)*.258819043636322;N=I+P;g[r>>2]=N;g[s>>2]=N;N=I-P;g[t>>2]=N;g[u>>2]=N;N=M-O;O=(K-J)*.9659258127212524;J=N-O;g[v>>2]=J;g[h>>2]=J;K=N+O;g[w>>2]=K;g[x>>2]=K;g[B>>2]=+g[Q>>2]*J+ +g[S>>2];g[y>>2]=+g[R>>2]*+g[x>>2];g[B+128>>2]=+g[T>>2]*+g[p>>2]+ +g[V>>2];g[q>>2]=+g[U>>2]*+g[l>>2];g[B+256>>2]=+g[W>>2]*+g[u>>2]+ +g[Y>>2];g[C>>2]=+g[X>>2]*+g[s>>2];g[B+384>>2]=+g[Z>>2]*+g[t>>2]+ +g[$>>2];g[D>>2]=+g[_>>2]*+g[r>>2];g[B+512>>2]=+g[aa>>2]*+g[b>>2]+ +g[ca>>2];g[E>>2]=+g[ba>>2]*+g[m>>2];g[B+640>>2]=+g[da>>2]*+g[v>>2]+ +g[fa>>2];g[F>>2]=+g[ea>>2]*+g[w>>2];J=+g[A+8>>2];K=+g[A+20>>2];O=J+K;N=+g[A+32>>2];M=+g[A+44>>2];P=N+M;I=+g[A+56>>2];H=M+I;M=P+(I+ +g[A+68>>2]);I=(K+N)*.8660253882408142;N=(O+P)*1.7320507764816284;P=J-H;K=(O-M)*.7071067690849304;L=P+K;g[m>>2]=L;g[l>>2]=L;L=P-K;g[b>>2]=L;g[p>>2]=L;L=J+H*.5;H=I+L;J=O*2.0+M;M=(N+J)*.258819043636322;O=H+M;g[r>>2]=O;g[s>>2]=O;O=H-M;g[t>>2]=O;g[u>>2]=O;O=L-I;I=(J-N)*.9659258127212524;N=O-I;g[v>>2]=N;g[h>>2]=N;J=O+I;g[w>>2]=J;g[x>>2]=J;ea=0;J=N;while(1){F=ea<<2;fa=y+(F<<2)|0;g[fa>>2]=+g[6873552+(G*160|0)+(ea<<2)>>2]*J+ +g[fa>>2];fa=ea+6|0;g[y+(fa<<2<<2)>>2]=+g[6873552+(G*160|0)+(fa<<2)>>2]*+g[k+(fa<<2)>>2];g[y+(F+48<<2)>>2]=0.0;F=ea+1|0;if((F|0)>=6){break}ea=F;J=+g[k+(F<<2)>>2]}ea=y+(((z&3|0)!=3?1:69)<<2)|0;G=z+1|0;if((G|0)<(n|0)){y=ea;z=G;A=A+72|0;e=e+4|0;B=B+4|0}else{ga=ea;break}}}else{ga=o}if((n|0)<32){ha=ga;ia=n}else{i=j;return}while(1){g[f+(ia<<2)>>2]=+g[ha>>2];g[ha>>2]=0.0;n=ha+16|0;g[f+(ia+32<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+32|0;g[f+(ia+64<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+48|0;g[f+(ia+96<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+64|0;g[f+(ia+128<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+80|0;g[f+(ia+160<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+96|0;g[f+(ia+192<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+112|0;g[f+(ia+224<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+128|0;g[f+(ia+256<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+144|0;g[f+(ia+288<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+160|0;g[f+(ia+320<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+176|0;g[f+(ia+352<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+192|0;g[f+(ia+384<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+208|0;g[f+(ia+416<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+224|0;g[f+(ia+448<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+240|0;g[f+(ia+480<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+256|0;g[f+(ia+512<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+272|0;g[f+(ia+544<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ia+1|0;if((n|0)<32){ha=ha+(((ia&3|0)!=3?1:69)<<2)|0;ia=n}else{break}}i=j;return}function _Na(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((b&1048576|0)==0){c[a+36>>2]=1;d=1;f=1}else{g=b>>>19&1^1;c[a+36>>2]=g;d=0;f=g}g=4-(b>>>17&3)|0;c[a+8>>2]=g;h=b>>>10&3;i=f+d|0;d=(e[1743632+(h<<1)>>1]|0)>>>(i>>>0);c[a+16>>2]=(i*3|0)+h;c[a+4>>2]=b>>>16&1^1;c[a+12>>2]=d;h=b>>>12&15;i=b>>>9&1;j=b>>>6&3;c[a+28>>2]=j;c[a+32>>2]=b>>>4&3;c[a+24>>2]=(j|0)==3?1:2;if((h|0)==0){k=1;return k|0}j=e[1743640+(f*90|0)+((g-1|0)*30|0)+(h<<1)>>1]|0;c[a+20>>2]=j*1e3|0;if((g|0)==2){l=((j*144e3|0|0)/(d|0)|0)+i|0}else if((g|0)==1){l=((j*12e3|0|0)/(d|0)|0)+i<<2}else{l=((j*144e3|0|0)/(d<<f|0)|0)+i|0}c[a>>2]=l;k=0;return k|0}function $Na(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+40|0;j=h|0;if((a&-2097152|0)!=-2097152|(a&393216|0)==0|(a&61440|0)==61440|(a&3072|0)==3072){k=-1;i=h;return k|0}if((_Na(j,a)|0)!=0){k=-1;i=h;return k|0}a=c[j+8>>2]|0;do{if((a|0)==2){c[g>>2]=86016;c[e>>2]=1152}else if((a|0)==1){c[g>>2]=86059;c[e>>2]=384}else{c[g>>2]=86017;if((c[j+36>>2]|0)==0){c[e>>2]=1152;break}else{c[e>>2]=576;break}}}while(0);c[b>>2]=c[j+12>>2];c[d>>2]=c[j+24>>2];c[f>>2]=c[j+20>>2];k=c[j>>2]|0;i=h;return k|0}function aOa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;i=i+40|0;j=h|0;k=a+48|0;if((b&-2097152|0)!=-2097152|(b&393216|0)==0|(b&61440|0)==61440|(b&3072|0)==3072){l=-1;i=h;return l|0}if((_Na(j,b)|0)!=0){l=-1;i=h;return l|0}b=c[j+8>>2]|0;do{if((b|0)==1){c[k>>2]=86059;c[f>>2]=384}else if((b|0)==2){c[k>>2]=86016;c[f>>2]=1152}else{c[k>>2]=86017;if((c[j+36>>2]|0)==0){c[f>>2]=1152;break}else{c[f>>2]=576;break}}}while(0);c[d>>2]=c[j+12>>2];c[e>>2]=c[j+24>>2];c[g>>2]=c[j+20>>2];l=c[j>>2]|0;i=h;return l|0}function bOa(a){a=a|0;var b=0,d=0;b=i;i=i+112|0;d=b|0;U0(d,5,0)|0;kOa();fOa();c[a>>2]=40;c[a+4>>2]=130;c[a+8>>2]=c[d+108>>2];c[a+12>>2]=216;c[a+16>>2]=32;c[a+20>>2]=178;i=b;return}function cOa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0;UGb(a+2048|0,a|0,128)|0;h=c[e>>2]|0;i=c[d>>2]|0;j=c[a+64>>2]|0;k=gHb(j,(j|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=YGb(k,F,h,(h|0)<0|0?-1:0)|0;h=F;k=c[d+256>>2]|0;j=c[a+320>>2]|0;l=gHb(j,(j|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=YGb(i,h,l,F)|0;l=F;h=c[d+512>>2]|0;i=c[a+576>>2]|0;j=gHb(i,(i|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=YGb(k,l,j,F)|0;j=F;l=c[d+768>>2]|0;k=c[a+832>>2]|0;i=gHb(k,(k|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=YGb(h,j,i,F)|0;i=F;j=c[d+1024>>2]|0;h=c[a+1088>>2]|0;k=gHb(h,(h|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=YGb(l,i,k,F)|0;k=F;i=c[d+1280>>2]|0;l=c[a+1344>>2]|0;h=gHb(l,(l|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=YGb(j,k,h,F)|0;h=F;k=c[d+1536>>2]|0;j=c[a+1600>>2]|0;l=gHb(j,(j|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=YGb(i,h,l,F)|0;l=F;h=c[d+1792>>2]|0;i=c[a+1856>>2]|0;j=gHb(i,(i|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=YGb(k,l,j,F)|0;j=F;l=c[d+128>>2]|0;k=c[a+192>>2]|0;i=gHb(k,(k|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=ZGb(h,j,i,F)|0;i=F;j=c[d+384>>2]|0;h=c[a+448>>2]|0;k=gHb(h,(h|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=ZGb(l,i,k,F)|0;k=F;i=c[d+640>>2]|0;l=c[a+704>>2]|0;h=gHb(l,(l|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=ZGb(j,k,h,F)|0;h=F;k=c[d+896>>2]|0;j=c[a+960>>2]|0;l=gHb(j,(j|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=ZGb(i,h,l,F)|0;l=F;h=c[d+1152>>2]|0;i=c[a+1216>>2]|0;j=gHb(i,(i|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=ZGb(k,l,j,F)|0;j=F;l=c[d+1408>>2]|0;k=c[a+1472>>2]|0;i=gHb(k,(k|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=ZGb(h,j,i,F)|0;i=F;j=c[d+1664>>2]|0;h=c[a+1728>>2]|0;k=gHb(h,(h|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=ZGb(l,i,k,F)|0;k=F;i=c[d+1920>>2]|0;l=c[a+1984>>2]|0;h=gHb(l,(l|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=ZGb(j,k,h,F)|0;h=F;k=i>>>24|h<<8;j=k;if((j+32768|0)>>>0>65535>>>0){m=(j>>31^32767)&65535}else{m=k&65535}b[f>>1]=m;m=-g|0;k=f+(g<<4<<1)|0;j=1;l=f+((g*31|0)<<1)|0;n=d+124|0;o=h&0;h=i&16777215;i=f;f=d;while(1){p=i+(g<<1)|0;q=f+4|0;r=c[a+(j+16<<2)>>2]|0;s=c[q>>2]|0;t=r;u=(r|0)<0|0?-1:0;r=gHb(s,(s|0)<0|0?-1:0,t,u)|0;s=YGb(r,F,h,o)|0;r=F;v=c[n>>2]|0;w=ZGb(0,0,t,u)|0;u=gHb(v,(v|0)<0|0?-1:0,w,F)|0;w=F;v=c[a+(j+80<<2)>>2]|0;t=c[f+260>>2]|0;x=v;y=(v|0)<0|0?-1:0;v=gHb(t,(t|0)<0|0?-1:0,x,y)|0;t=YGb(s,r,v,F)|0;v=F;r=c[n+256>>2]|0;s=gHb(r,(r|0)<0|0?-1:0,x,y)|0;y=ZGb(u,w,s,F)|0;s=F;w=c[a+(j+144<<2)>>2]|0;u=c[f+516>>2]|0;x=w;r=(w|0)<0|0?-1:0;w=gHb(u,(u|0)<0|0?-1:0,x,r)|0;u=YGb(t,v,w,F)|0;w=F;v=c[n+512>>2]|0;t=gHb(v,(v|0)<0|0?-1:0,x,r)|0;r=ZGb(y,s,t,F)|0;t=F;s=c[a+(j+208<<2)>>2]|0;y=c[f+772>>2]|0;x=s;v=(s|0)<0|0?-1:0;s=gHb(y,(y|0)<0|0?-1:0,x,v)|0;y=YGb(u,w,s,F)|0;s=F;w=c[n+768>>2]|0;u=gHb(w,(w|0)<0|0?-1:0,x,v)|0;v=ZGb(r,t,u,F)|0;u=F;t=c[a+(j+272<<2)>>2]|0;r=c[f+1028>>2]|0;x=t;w=(t|0)<0|0?-1:0;t=gHb(r,(r|0)<0|0?-1:0,x,w)|0;r=YGb(y,s,t,F)|0;t=F;s=c[n+1024>>2]|0;y=gHb(s,(s|0)<0|0?-1:0,x,w)|0;w=ZGb(v,u,y,F)|0;y=F;u=c[a+(j+336<<2)>>2]|0;v=c[f+1284>>2]|0;x=u;s=(u|0)<0|0?-1:0;u=gHb(v,(v|0)<0|0?-1:0,x,s)|0;v=YGb(r,t,u,F)|0;u=F;t=c[n+1280>>2]|0;r=gHb(t,(t|0)<0|0?-1:0,x,s)|0;s=ZGb(w,y,r,F)|0;r=F;y=c[a+(j+400<<2)>>2]|0;w=c[f+1540>>2]|0;x=y;t=(y|0)<0|0?-1:0;y=gHb(w,(w|0)<0|0?-1:0,x,t)|0;w=YGb(v,u,y,F)|0;y=F;u=c[n+1536>>2]|0;v=gHb(u,(u|0)<0|0?-1:0,x,t)|0;t=ZGb(s,r,v,F)|0;v=F;r=c[a+(j+464<<2)>>2]|0;s=c[f+1796>>2]|0;x=r;u=(r|0)<0|0?-1:0;r=gHb(s,(s|0)<0|0?-1:0,x,u)|0;s=YGb(w,y,r,F)|0;r=F;y=c[n+1792>>2]|0;w=gHb(y,(y|0)<0|0?-1:0,x,u)|0;u=ZGb(t,v,w,F)|0;w=F;v=48-j|0;t=c[a+(v<<2)>>2]|0;x=c[f+132>>2]|0;y=t;z=(t|0)<0|0?-1:0;t=gHb(x,(x|0)<0|0?-1:0,y,z)|0;x=ZGb(s,r,t,F)|0;t=F;r=c[n+128>>2]|0;s=gHb(r,(r|0)<0|0?-1:0,y,z)|0;z=ZGb(u,w,s,F)|0;s=F;w=c[a+(v+64<<2)>>2]|0;u=c[f+388>>2]|0;y=w;r=(w|0)<0|0?-1:0;w=gHb(u,(u|0)<0|0?-1:0,y,r)|0;u=ZGb(x,t,w,F)|0;w=F;t=c[n+384>>2]|0;x=gHb(t,(t|0)<0|0?-1:0,y,r)|0;r=ZGb(z,s,x,F)|0;x=F;s=c[a+(v+128<<2)>>2]|0;z=c[f+644>>2]|0;y=s;t=(s|0)<0|0?-1:0;s=gHb(z,(z|0)<0|0?-1:0,y,t)|0;z=ZGb(u,w,s,F)|0;s=F;w=c[n+640>>2]|0;u=gHb(w,(w|0)<0|0?-1:0,y,t)|0;t=ZGb(r,x,u,F)|0;u=F;x=c[a+(v+192<<2)>>2]|0;r=c[f+900>>2]|0;y=x;w=(x|0)<0|0?-1:0;x=gHb(r,(r|0)<0|0?-1:0,y,w)|0;r=ZGb(z,s,x,F)|0;x=F;s=c[n+896>>2]|0;z=gHb(s,(s|0)<0|0?-1:0,y,w)|0;w=ZGb(t,u,z,F)|0;z=F;u=c[a+(v+256<<2)>>2]|0;t=c[f+1156>>2]|0;y=u;s=(u|0)<0|0?-1:0;u=gHb(t,(t|0)<0|0?-1:0,y,s)|0;t=ZGb(r,x,u,F)|0;u=F;x=c[n+1152>>2]|0;r=gHb(x,(x|0)<0|0?-1:0,y,s)|0;s=ZGb(w,z,r,F)|0;r=F;z=c[a+(v+320<<2)>>2]|0;w=c[f+1412>>2]|0;y=z;x=(z|0)<0|0?-1:0;z=gHb(w,(w|0)<0|0?-1:0,y,x)|0;w=ZGb(t,u,z,F)|0;z=F;u=c[n+1408>>2]|0;t=gHb(u,(u|0)<0|0?-1:0,y,x)|0;x=ZGb(s,r,t,F)|0;t=F;r=c[a+(v+384<<2)>>2]|0;s=c[f+1668>>2]|0;y=r;u=(r|0)<0|0?-1:0;r=gHb(s,(s|0)<0|0?-1:0,y,u)|0;s=ZGb(w,z,r,F)|0;r=F;z=c[n+1664>>2]|0;w=gHb(z,(z|0)<0|0?-1:0,y,u)|0;u=ZGb(x,t,w,F)|0;w=F;t=c[a+(v+448<<2)>>2]|0;v=c[f+1924>>2]|0;x=t;y=(t|0)<0|0?-1:0;t=gHb(v,(v|0)<0|0?-1:0,x,y)|0;v=ZGb(s,r,t,F)|0;t=F;r=c[n+1920>>2]|0;s=gHb(r,(r|0)<0|0?-1:0,x,y)|0;y=ZGb(u,w,s,F)|0;s=F;w=v>>>24|t<<8;u=w;if((u+32768|0)>>>0>65535>>>0){A=(u>>31^32767)&65535}else{A=w&65535}b[p>>1]=A;w=YGb(y,s,v&16777215,t&0)|0;u=w>>>24|F<<8;w=u;if((w+32768|0)>>>0>65535>>>0){B=(w>>31^32767)&65535}else{B=u&65535}b[l>>1]=B;u=j+1|0;w=YGb(v,t,y,s)|0;C=w&16777215;D=F&0;if((u|0)<16){j=u;l=l+(m<<1)|0;n=n-4|0;o=D;h=C;i=p;f=q}else{break}}f=c[d+192>>2]|0;i=c[a+128>>2]|0;h=gHb(i,(i|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=ZGb(C,D,h,F)|0;h=F;D=c[d+448>>2]|0;C=c[a+384>>2]|0;i=gHb(C,(C|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;D=ZGb(f,h,i,F)|0;i=F;h=c[d+704>>2]|0;f=c[a+640>>2]|0;C=gHb(f,(f|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=ZGb(D,i,C,F)|0;C=F;i=c[d+960>>2]|0;D=c[a+896>>2]|0;f=gHb(D,(D|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=ZGb(h,C,f,F)|0;f=F;C=c[d+1216>>2]|0;h=c[a+1152>>2]|0;D=gHb(h,(h|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;C=ZGb(i,f,D,F)|0;D=F;f=c[d+1472>>2]|0;i=c[a+1408>>2]|0;h=gHb(i,(i|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=ZGb(C,D,h,F)|0;h=F;D=c[d+1728>>2]|0;C=c[a+1664>>2]|0;i=gHb(C,(C|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;D=ZGb(f,h,i,F)|0;i=F;h=c[d+1984>>2]|0;d=c[a+1920>>2]|0;a=gHb(d,(d|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=ZGb(D,i,a,F)|0;a=h>>>24|F<<8;i=a;if(!((i+32768|0)>>>0>65535>>>0)){E=a&65535;b[k>>1]=E;G=h;H=G;I=H&16777215;c[e>>2]=I;return}E=(i>>31^32767)&65535;b[k>>1]=E;G=h;H=G;I=H&16777215;c[e>>2]=I;return}function dOa(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=c[d>>2]|0;k=b+(j<<2)|0;ne[c[a+12>>2]&1023](k,i);le[c[a+4>>2]&1023](k,e,f,g,h);c[d>>2]=j+480&511;return}function eOa(a){a=a|0;var b=0,d=0,e=0,f=0;b=0;while(1){d=c[1180872+(b<<2)>>2]|0;c[a+(b<<2)>>2]=d;if((b|0)==0){b=b+1|0;continue}else{c[a+(512-b<<2)>>2]=(b&63|0)==0?d:-d|0;d=b+1|0;if((d|0)<257){b=d;continue}else{e=0;break}}}while(1){b=e<<6|32;d=e<<4;c[a+(d+512<<2)>>2]=c[a+(b<<2)>>2];c[a+(d+513<<2)>>2]=c[a+(b-1<<2)>>2];c[a+(d+514<<2)>>2]=c[a+(b-2<<2)>>2];c[a+(d+515<<2)>>2]=c[a+(b-3<<2)>>2];c[a+(d+516<<2)>>2]=c[a+(b-4<<2)>>2];c[a+(d+517<<2)>>2]=c[a+(b-5<<2)>>2];c[a+(d+518<<2)>>2]=c[a+(b-6<<2)>>2];c[a+(d+519<<2)>>2]=c[a+(b-7<<2)>>2];c[a+(d+520<<2)>>2]=c[a+(b-8<<2)>>2];c[a+(d+521<<2)>>2]=c[a+(b-9<<2)>>2];c[a+(d+522<<2)>>2]=c[a+(b-10<<2)>>2];c[a+(d+523<<2)>>2]=c[a+(b-11<<2)>>2];c[a+(d+524<<2)>>2]=c[a+(b-12<<2)>>2];c[a+(d+525<<2)>>2]=c[a+(b-13<<2)>>2];c[a+(d+526<<2)>>2]=c[a+(b-14<<2)>>2];c[a+(d+527<<2)>>2]=c[a+(b-15<<2)>>2];b=e+1|0;if((b|0)<8){e=b}else{f=0;break}}do{e=f<<6|48;b=f<<4;c[a+(b+640<<2)>>2]=c[a+(e<<2)>>2];c[a+(b+641<<2)>>2]=c[a+(e-1<<2)>>2];c[a+(b+642<<2)>>2]=c[a+(e-2<<2)>>2];c[a+(b+643<<2)>>2]=c[a+(e-3<<2)>>2];c[a+(b+644<<2)>>2]=c[a+(e-4<<2)>>2];c[a+(b+645<<2)>>2]=c[a+(e-5<<2)>>2];c[a+(b+646<<2)>>2]=c[a+(e-6<<2)>>2];c[a+(b+647<<2)>>2]=c[a+(e-7<<2)>>2];c[a+(b+648<<2)>>2]=c[a+(e-8<<2)>>2];c[a+(b+649<<2)>>2]=c[a+(e-9<<2)>>2];c[a+(b+650<<2)>>2]=c[a+(e-10<<2)>>2];c[a+(b+651<<2)>>2]=c[a+(e-11<<2)>>2];c[a+(b+652<<2)>>2]=c[a+(e-12<<2)>>2];c[a+(b+653<<2)>>2]=c[a+(e-13<<2)>>2];c[a+(b+654<<2)>>2]=c[a+(e-14<<2)>>2];c[a+(b+655<<2)>>2]=c[a+(e-15<<2)>>2];f=f+1|0;}while((f|0)<8);return}function fOa(){var a=0,b=0,d=0.0,e=0.0,f=0,g=0,h=0,i=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0,C=0,D=0;a=0;while(1){b=((a|0)%3|0|0)==1;d=(+(a|0)+.5)*3.141592653589793/36.0;e=+((a<<1)+19|0)*3.141592653589793/72.0;f=(a|0)/3|0;g=(a|0)<18;h=g?a:a+2|0;i=(a|0)>29;j=(a|0)>23;k=(+(a-18|0)+.5)*3.141592653589793/12.0;l=(a|0)>17;m=(+(a-6|0)+.5)*3.141592653589793/12.0;if((a|0)<6){n=0;while(1){o=(n|0)==2;a:do{if(o){if(!b){p=16;break}q=+U(d);p=14}else{r=+U(d);if((n|0)==1){p=7}else if((n|0)==3){s=.8795/+T(e)*0.0;p=17;break}else{t=r}do{if((p|0)==7){p=0;if(i){t=0.0;break}if(j){q=+U(k);p=14;break a}else{q=l?1.0:r;p=14;break a}}}while(0);s=t*(.8795/+T(e));p=17}}while(0);do{if((p|0)==14){p=0;r=q*(.8795/+T(e));if(!o){s=r;p=17;break}c[6875152+(f<<2)>>2]=~~(r*.03125*4294967296.0+.5);p=16}}while(0);if((p|0)==16){p=0;n=n+1|0;continue}else if((p|0)==17){p=0;c[6874832+(n*160|0)+(h<<2)>>2]=~~(s*.03125*4294967296.0+.5);o=n+1|0;if((o|0)<4){n=o;continue}else{break}}}}else{if((a|0)<12){n=0;while(1){o=(n|0)==2;do{if(o){if(!b){p=30;break}u=+U(d);p=28}else{r=+U(d);if((n|0)==3){v=+U(m)}else if((n|0)==1){if(i){u=0.0;p=28;break}if(j){u=+U(k);p=28;break}else{u=l?1.0:r;p=28;break}}else{v=r}w=v*(.8795/+T(e));p=31}}while(0);do{if((p|0)==28){p=0;r=u*(.8795/+T(e));if(!o){w=r;p=31;break}c[6875152+(f<<2)>>2]=~~(r*.03125*4294967296.0+.5);p=30}}while(0);if((p|0)==30){p=0;n=n+1|0;continue}else if((p|0)==31){p=0;c[6874832+(n*160|0)+(h<<2)>>2]=~~(w*.03125*4294967296.0+.5);o=n+1|0;if((o|0)<4){n=o;continue}else{break}}}}else{n=0;while(1){o=(n|0)==2;b:do{if(o){if(!b){p=44;break}x=+U(d);p=42}else{m=+U(d);if((n|0)==1){p=36}else if((n|0)==3){x=g?1.0:m;p=42;break}else{y=m}do{if((p|0)==36){p=0;if(i){y=0.0;break}if(j){x=+U(k);p=42;break b}else{x=l?1.0:m;p=42;break b}}}while(0);z=y*(.8795/+T(e));p=45}}while(0);do{if((p|0)==42){p=0;m=x*(.8795/+T(e));if(!o){z=m;p=45;break}c[6875152+(f<<2)>>2]=~~(m*.03125*4294967296.0+.5);p=44}}while(0);if((p|0)==44){p=0;n=n+1|0;continue}else if((p|0)==45){p=0;c[6874832+(n*160|0)+(h<<2)>>2]=~~(z*.03125*4294967296.0+.5);o=n+1|0;if((o|0)<4){n=o;continue}else{break}}}}}n=a+1|0;if((n|0)<36){a=n}else{A=0;break}}while(1){c[6875472+(A<<2)>>2]=c[6874832+(A<<2)>>2];a=A|1;c[6875472+(a<<2)>>2]=-(c[6874832+(a<<2)>>2]|0);a=A+2|0;if((a|0)<40){A=a}else{B=0;break}}while(1){c[6875632+(B<<2)>>2]=c[6874992+(B<<2)>>2];A=B|1;c[6875632+(A<<2)>>2]=-(c[6874992+(A<<2)>>2]|0);A=B+2|0;if((A|0)<40){B=A}else{C=0;break}}while(1){c[6875792+(C<<2)>>2]=c[6875152+(C<<2)>>2];B=C|1;c[6875792+(B<<2)>>2]=-(c[6875152+(B<<2)>>2]|0);B=C+2|0;if((B|0)<40){C=B}else{D=0;break}}do{c[6875952+(D<<2)>>2]=c[6875312+(D<<2)>>2];C=D|1;c[6875952+(C<<2)>>2]=-(c[6875312+(C<<2)>>2]|0);D=D+2|0;}while((D|0)<40);return}function gOa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0;h=i;i=i+72|0;j=h|0;if((e|0)<=0){i=h;return}k=(f|0)!=0;f=j+64|0;l=j+68|0;m=d;d=0;n=b;b=a;while(1){a=-(d&1)&4;o=m+68|0;p=m+64|0;q=c[p>>2]|0;r=q+(c[o>>2]|0)|0;s=m+60|0;t=c[s>>2]|0;c[p>>2]=t+q;q=m+56|0;p=c[q>>2]|0;u=p+t|0;t=m+52|0;v=c[t>>2]|0;c[q>>2]=v+p;p=m+48|0;q=c[p>>2]|0;w=q+v|0;v=m+44|0;x=c[v>>2]|0;c[p>>2]=x+q;q=m+40|0;p=c[q>>2]|0;y=p+x|0;x=m+36|0;z=c[x>>2]|0;c[q>>2]=z+p;p=m+32|0;q=c[p>>2]|0;A=q+z|0;z=m+28|0;B=c[z>>2]|0;c[p>>2]=B+q;q=m+24|0;p=c[q>>2]|0;C=p+B|0;B=m+20|0;D=c[B>>2]|0;c[q>>2]=D+p;p=m+16|0;q=c[p>>2]|0;E=q+D|0;D=m+12|0;G=c[D>>2]|0;c[p>>2]=G+q;q=m+8|0;p=c[q>>2]|0;H=p+G|0;G=m+4|0;I=c[G>>2]|0;c[q>>2]=I+p;p=c[m>>2]|0;q=p+I|0;c[G>>2]=q;G=k&(d|0)<2?0:g;c[o>>2]=r+u;c[s>>2]=w+u;c[t>>2]=y+w;c[v>>2]=A+y;c[x>>2]=C+A;c[z>>2]=E+C;c[B>>2]=H+E;c[D>>2]=q+H;H=0;q=p;while(1){p=H+8|0;D=c[m+(p<<2)>>2]|0;E=H+16|0;B=c[m+(E<<2)>>2]|0;C=H+4|0;z=c[m+(C<<2)>>2]|0;A=B+D-z|0;x=H+12|0;y=c[m+(x<<2)>>2]|0;v=(y>>1)+q|0;w=q-y|0;y=H+6|0;c[j+(y<<2)>>2]=w-(A>>1);c[j+(E<<2)>>2]=w+A;A=z+D<<1;gHb(A,(A|0)<0|0?-1:0,2017974537,0)|0;A=F;w=D-B|0;gHb(w,(w|0)<0|0?-1:0,-745813244,-1)|0;w=F;D=z+B<<1;gHb(D,(D|0)<0|0?-1:0,-1645067915,-1)|0;D=F;B=H+10|0;c[j+(B<<2)>>2]=v-A-D;z=H+2|0;c[j+(z<<2)>>2]=w+v+A;A=H+14|0;c[j+(A<<2)>>2]=v-w+D;D=c[m+(B<<2)>>2]|0;B=c[m+(A<<2)>>2]|0;A=c[m+(z<<2)>>2]|0;z=B+D-A<<1;gHb(z,(z|0)<0|0?-1:0,-1859775393,-1)|0;c[j+(C<<2)>>2]=F;C=A+D<<1;gHb(C,(C|0)<0|0?-1:0,2114858546,0)|0;C=F;z=D-B|0;gHb(z,(z|0)<0|0?-1:0,-1468965330,-1)|0;z=F;D=c[m+(y<<2)>>2]<<1;gHb(D,(D|0)<0|0?-1:0,1859775393,0)|0;D=F;y=A+B<<1;gHb(y,(y|0)<0|0?-1:0,-1380375881,-1)|0;y=F;c[j+(H<<2)>>2]=C+z+D;c[j+(x<<2)>>2]=y+C-D;c[j+(p<<2)>>2]=z-y-D;D=H+1|0;if((D|0)>=2){break}H=D;q=c[m+(D<<2)>>2]|0}q=G+a|0;H=0;D=0;while(1){y=c[j+(D<<2)>>2]|0;z=c[j+((D|2)<<2)>>2]|0;p=z+y|0;C=z-y|0;y=c[j+((D|1)<<2)>>2]|0;z=c[j+((D|3)<<2)>>2]|0;x=z+y<<1;B=c[918376+(H<<2)>>2]|0;gHb(x,(x|0)<0|0?-1:0,B,(B|0)<0|0?-1:0)|0;B=F;x=z-y|0;y=8-H|0;z=c[918456+(y<<2)>>2]|0;A=gHb(z,(z|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=A>>>23|F<<9;A=B+p|0;z=p-B|0;B=H+9|0;p=c[6874832+(q*160|0)+(B<<2)>>2]|0;w=z;v=(z|0)<0|0?-1:0;gHb(w,v,p,(p|0)<0|0?-1:0)|0;p=n+(B<<2<<2)|0;c[b+(B<<5<<2)>>2]=F+(c[p>>2]|0);B=c[6874832+(q*160|0)+(y<<2)>>2]|0;gHb(w,v,B,(B|0)<0|0?-1:0)|0;B=n+(y<<2<<2)|0;c[b+(y<<5<<2)>>2]=F+(c[B>>2]|0);y=c[6874832+(q*160|0)+(H+29<<2)>>2]|0;v=A;w=(A|0)<0|0?-1:0;gHb(y,(y|0)<0|0?-1:0,v,w)|0;c[p>>2]=F;p=c[6874832+(q*160|0)+(28-H<<2)>>2]|0;gHb(p,(p|0)<0|0?-1:0,v,w)|0;c[B>>2]=F;B=x+C|0;w=C-x|0;x=17-H|0;C=c[6874832+(q*160|0)+(x<<2)>>2]|0;v=w;p=(w|0)<0|0?-1:0;gHb(C,(C|0)<0|0?-1:0,v,p)|0;C=n+(x<<2<<2)|0;c[b+(x<<5<<2)>>2]=F+(c[C>>2]|0);x=c[6874832+(q*160|0)+(H<<2)>>2]|0;gHb(x,(x|0)<0|0?-1:0,v,p)|0;p=n+(H<<2<<2)|0;c[b+(H<<5<<2)>>2]=F+(c[p>>2]|0);v=c[6874832+(q*160|0)+(37-H<<2)>>2]|0;x=B;w=(B|0)<0|0?-1:0;gHb(v,(v|0)<0|0?-1:0,x,w)|0;c[C>>2]=F;C=c[6874832+(q*160|0)+(H+20<<2)>>2]|0;gHb(C,(C|0)<0|0?-1:0,x,w)|0;c[p>>2]=F;p=H+1|0;if((p|0)<4){H=p;D=D+4|0}else{break}}D=c[f>>2]|0;H=c[l>>2]<<1;gHb(H,(H|0)<0|0?-1:0,1518500250,0)|0;H=F;a=H+D|0;G=D-H|0;H=c[6874884+(q*160|0)>>2]|0;D=G;p=(G|0)<0|0?-1:0;gHb(D,p,H,(H|0)<0|0?-1:0)|0;H=n+208|0;c[b+1664>>2]=F+(c[H>>2]|0);G=c[6874848+(q*160|0)>>2]|0;gHb(D,p,G,(G|0)<0|0?-1:0)|0;G=n+64|0;c[b+512>>2]=F+(c[G>>2]|0);p=c[6874964+(q*160|0)>>2]|0;D=a;w=(a|0)<0|0?-1:0;gHb(D,w,p,(p|0)<0|0?-1:0)|0;c[H>>2]=F;H=c[6874928+(q*160|0)>>2]|0;gHb(H,(H|0)<0|0?-1:0,D,w)|0;c[G>>2]=F;G=n+(((d&3|0)!=3?1:69)<<2)|0;w=d+1|0;if((w|0)<(e|0)){m=m+72|0;d=w;n=G;b=b+4|0}else{break}}i=h;return}function hOa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0;UGb(a+2048|0,a|0,128)|0;g[e>>2]=+(c[d>>2]|0)+ +g[b>>2]*+g[a+64>>2]+ +g[b+256>>2]*+g[a+320>>2]+ +g[b+512>>2]*+g[a+576>>2]+ +g[b+768>>2]*+g[a+832>>2]+ +g[b+1024>>2]*+g[a+1088>>2]+ +g[b+1280>>2]*+g[a+1344>>2]+ +g[b+1536>>2]*+g[a+1600>>2]+ +g[b+1792>>2]*+g[a+1856>>2]- +g[b+128>>2]*+g[a+192>>2]- +g[b+384>>2]*+g[a+448>>2]- +g[b+640>>2]*+g[a+704>>2]- +g[b+896>>2]*+g[a+960>>2]- +g[b+1152>>2]*+g[a+1216>>2]- +g[b+1408>>2]*+g[a+1472>>2]- +g[b+1664>>2]*+g[a+1728>>2]- +g[b+1920>>2]*+g[a+1984>>2];h=-f|0;i=e+(f<<4<<2)|0;j=1;k=e+((f*31|0)<<2)|0;l=b+124|0;m=e;e=b;while(1){n=m+(f<<2)|0;o=e+4|0;p=+g[a+(j+16<<2)>>2];q=+g[a+(j+80<<2)>>2];r=+g[a+(j+144<<2)>>2];s=+g[a+(j+208<<2)>>2];t=+g[a+(j+272<<2)>>2];u=+g[a+(j+336<<2)>>2];v=+g[a+(j+400<<2)>>2];w=+g[a+(j+464<<2)>>2];x=48-j|0;y=+g[a+(x<<2)>>2];z=+g[a+(x+64<<2)>>2];A=+g[a+(x+128<<2)>>2];B=+g[a+(x+192<<2)>>2];C=+g[a+(x+256<<2)>>2];D=+g[a+(x+320<<2)>>2];E=+g[a+(x+384<<2)>>2];F=+g[a+(x+448<<2)>>2];G=0.0-p*+g[l>>2]-q*+g[l+256>>2]-r*+g[l+512>>2]-s*+g[l+768>>2]-t*+g[l+1024>>2]-u*+g[l+1280>>2]-v*+g[l+1536>>2]-w*+g[l+1792>>2]-y*+g[l+128>>2]-z*+g[l+384>>2]-A*+g[l+640>>2]-B*+g[l+896>>2]-C*+g[l+1152>>2]-D*+g[l+1408>>2]-E*+g[l+1664>>2]-F*+g[l+1920>>2];g[n>>2]=p*+g[o>>2]+0.0+q*+g[e+260>>2]+r*+g[e+516>>2]+s*+g[e+772>>2]+t*+g[e+1028>>2]+u*+g[e+1284>>2]+v*+g[e+1540>>2]+w*+g[e+1796>>2]-y*+g[e+132>>2]-z*+g[e+388>>2]-A*+g[e+644>>2]-B*+g[e+900>>2]-C*+g[e+1156>>2]-D*+g[e+1412>>2]-E*+g[e+1668>>2]-F*+g[e+1924>>2];g[k>>2]=G+0.0;x=j+1|0;if((x|0)<16){j=x;k=k+(h<<2)|0;l=l-4|0;m=n;e=o}else{break}}g[i>>2]=0.0- +g[b+192>>2]*+g[a+128>>2]- +g[b+448>>2]*+g[a+384>>2]- +g[b+704>>2]*+g[a+640>>2]- +g[b+960>>2]*+g[a+896>>2]- +g[b+1216>>2]*+g[a+1152>>2]- +g[b+1472>>2]*+g[a+1408>>2]- +g[b+1728>>2]*+g[a+1664>>2]- +g[b+1984>>2]*+g[a+1920>>2];c[d>>2]=0;return}function iOa(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=c[d>>2]|0;k=b+(j<<2)|0;ne[c[a+8>>2]&1023](k,i);le[c[a>>2]&1023](k,e,f,g,h);c[d>>2]=j+480&511;return}function jOa(a){a=a|0;var b=0,d=0.0,e=0.0,f=0,h=0,i=0;b=0;while(1){d=+(c[1180872+(b<<2)>>2]|0)*1.8189894035458565e-12;g[a+(b<<2)>>2]=d;if((b&63|0)==0){e=d}else{e=-0.0-d}if((b|0)==0){b=b+1|0;continue}else{g[a+(512-b<<2)>>2]=e;f=b+1|0;if((f|0)<257){b=f;continue}else{h=0;break}}}while(1){b=h<<6|32;f=h<<4;g[a+(f+512<<2)>>2]=+g[a+(b<<2)>>2];g[a+(f+513<<2)>>2]=+g[a+(b-1<<2)>>2];g[a+(f+514<<2)>>2]=+g[a+(b-2<<2)>>2];g[a+(f+515<<2)>>2]=+g[a+(b-3<<2)>>2];g[a+(f+516<<2)>>2]=+g[a+(b-4<<2)>>2];g[a+(f+517<<2)>>2]=+g[a+(b-5<<2)>>2];g[a+(f+518<<2)>>2]=+g[a+(b-6<<2)>>2];g[a+(f+519<<2)>>2]=+g[a+(b-7<<2)>>2];g[a+(f+520<<2)>>2]=+g[a+(b-8<<2)>>2];g[a+(f+521<<2)>>2]=+g[a+(b-9<<2)>>2];g[a+(f+522<<2)>>2]=+g[a+(b-10<<2)>>2];g[a+(f+523<<2)>>2]=+g[a+(b-11<<2)>>2];g[a+(f+524<<2)>>2]=+g[a+(b-12<<2)>>2];g[a+(f+525<<2)>>2]=+g[a+(b-13<<2)>>2];g[a+(f+526<<2)>>2]=+g[a+(b-14<<2)>>2];g[a+(f+527<<2)>>2]=+g[a+(b-15<<2)>>2];b=h+1|0;if((b|0)<8){h=b}else{i=0;break}}do{h=i<<6|48;b=i<<4;g[a+(b+640<<2)>>2]=+g[a+(h<<2)>>2];g[a+(b+641<<2)>>2]=+g[a+(h-1<<2)>>2];g[a+(b+642<<2)>>2]=+g[a+(h-2<<2)>>2];g[a+(b+643<<2)>>2]=+g[a+(h-3<<2)>>2];g[a+(b+644<<2)>>2]=+g[a+(h-4<<2)>>2];g[a+(b+645<<2)>>2]=+g[a+(h-5<<2)>>2];g[a+(b+646<<2)>>2]=+g[a+(h-6<<2)>>2];g[a+(b+647<<2)>>2]=+g[a+(h-7<<2)>>2];g[a+(b+648<<2)>>2]=+g[a+(h-8<<2)>>2];g[a+(b+649<<2)>>2]=+g[a+(h-9<<2)>>2];g[a+(b+650<<2)>>2]=+g[a+(h-10<<2)>>2];g[a+(b+651<<2)>>2]=+g[a+(h-11<<2)>>2];g[a+(b+652<<2)>>2]=+g[a+(h-12<<2)>>2];g[a+(b+653<<2)>>2]=+g[a+(h-13<<2)>>2];g[a+(b+654<<2)>>2]=+g[a+(h-14<<2)>>2];g[a+(b+655<<2)>>2]=+g[a+(h-15<<2)>>2];i=i+1|0;}while((i|0)<8);return}function kOa(){var a=0,b=0,c=0.0,d=0.0,e=0,f=0,h=0,i=0,j=0,k=0.0,l=0,m=0.0,n=0.0,o=0.0,p=0.0,q=0,r=0,s=0,t=0;a=0;while(1){b=((a|0)%3|0|0)==1;c=(+(a|0)+.5)*3.141592653589793/36.0;d=+((a<<1)+19|0)*3.141592653589793/72.0;e=(a|0)/3|0;f=(a|0)<18;h=f?a:a+2|0;i=(a|0)>29;j=(a|0)>23;k=(+(a-18|0)+.5)*3.141592653589793/12.0;l=(a|0)>17;m=(+(a-6|0)+.5)*3.141592653589793/12.0;g[6873552+(h<<2)>>2]=+U(c)*(.8795/+T(d))*.03125;n=+U(c);do{if((a|0)<6){g[6873712+(h<<2)>>2]=(l?1.0:n)*(.8795/+T(d))*.03125;if(b){g[6873872+(e<<2)>>2]=+U(c)*(.8795/+T(d))*.03125}g[6874032+(h<<2)>>2]=.8795/+T(d)*0.0*.03125}else{if((a|0)<12){g[6873712+(h<<2)>>2]=(l?1.0:n)*(.8795/+T(d))*.03125;if(b){g[6873872+(e<<2)>>2]=+U(c)*(.8795/+T(d))*.03125}g[6874032+(h<<2)>>2]=+U(m)*(.8795/+T(d))*.03125;break}do{if(i){o=0.0}else{if(j){o=+U(k);break}else{o=l?1.0:n;break}}}while(0);g[6873712+(h<<2)>>2]=o*(.8795/+T(d))*.03125;if(b){g[6873872+(e<<2)>>2]=+U(c)*(.8795/+T(d))*.03125}p=+U(c);g[6874032+(h<<2)>>2]=(f?1.0:p)*(.8795/+T(d))*.03125}}while(0);f=a+1|0;if((f|0)<36){a=f}else{q=0;break}}while(1){g[6874192+(q<<2)>>2]=+g[6873552+(q<<2)>>2];a=q|1;g[6874192+(a<<2)>>2]=-0.0- +g[6873552+(a<<2)>>2];a=q+2|0;if((a|0)<40){q=a}else{r=0;break}}while(1){g[6874352+(r<<2)>>2]=+g[6873712+(r<<2)>>2];q=r|1;g[6874352+(q<<2)>>2]=-0.0- +g[6873712+(q<<2)>>2];q=r+2|0;if((q|0)<40){r=q}else{s=0;break}}while(1){g[6874512+(s<<2)>>2]=+g[6873872+(s<<2)>>2];r=s|1;g[6874512+(r<<2)>>2]=-0.0- +g[6873872+(r<<2)>>2];r=s+2|0;if((r|0)<40){s=r}else{t=0;break}}do{g[6874672+(t<<2)>>2]=+g[6874032+(t<<2)>>2];s=t|1;g[6874672+(s<<2)>>2]=-0.0- +g[6874032+(s<<2)>>2];t=t+2|0;}while((t|0)<40);return}function lOa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0.0,v=0,w=0.0,x=0,y=0.0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0,G=0.0,H=0,I=0.0;h=i;i=i+72|0;j=h|0;if((d|0)<=0){i=h;return}k=(e|0)!=0;e=j+64|0;l=j+68|0;m=c;c=0;n=b;b=a;while(1){a=-(c&1)&4;o=m+68|0;p=m+64|0;q=+g[p>>2];r=+g[o>>2]+q;s=m+60|0;t=+g[s>>2];g[p>>2]=q+t;p=m+56|0;q=+g[p>>2];u=t+q;v=m+52|0;t=+g[v>>2];g[p>>2]=q+t;p=m+48|0;q=+g[p>>2];w=t+q;x=m+44|0;t=+g[x>>2];g[p>>2]=q+t;p=m+40|0;q=+g[p>>2];y=t+q;z=m+36|0;t=+g[z>>2];g[p>>2]=q+t;p=m+32|0;q=+g[p>>2];A=t+q;B=m+28|0;t=+g[B>>2];g[p>>2]=q+t;p=m+24|0;q=+g[p>>2];C=t+q;D=m+20|0;t=+g[D>>2];g[p>>2]=q+t;p=m+16|0;q=+g[p>>2];E=t+q;F=m+12|0;t=+g[F>>2];g[p>>2]=q+t;p=m+8|0;q=+g[p>>2];G=t+q;H=m+4|0;t=+g[H>>2];g[p>>2]=q+t;q=+g[m>>2];I=t+q;g[H>>2]=I;H=k&(c|0)<2?0:f;g[o>>2]=u+r;g[s>>2]=u+w;g[v>>2]=w+y;g[x>>2]=y+A;g[z>>2]=A+C;g[B>>2]=C+E;g[D>>2]=E+G;g[F>>2]=G+I;F=0;I=q;while(1){D=F+8|0;q=+g[m+(D<<2)>>2];B=F+16|0;G=+g[m+(B<<2)>>2];z=F+4|0;E=+g[m+(z<<2)>>2];C=q+G-E;x=F+12|0;A=+g[m+(x<<2)>>2];y=I+A*.5;w=I-A;v=F+6|0;g[j+(v<<2)>>2]=w-C*.5;g[j+(B<<2)>>2]=C+w;w=(q+E)*.9396926164627075;C=(q-G)*-.1736481785774231;q=(G+E)*-.7660444378852844;B=F+10|0;g[j+(B<<2)>>2]=y-w-q;s=F+2|0;g[j+(s<<2)>>2]=C+(w+y);o=F+14|0;g[j+(o<<2)>>2]=q+y-C;C=+g[m+(B<<2)>>2];y=+g[m+(o<<2)>>2];q=+g[m+(s<<2)>>2];g[j+(z<<2)>>2]=(C+y-q)*-.8660253882408142;w=(C+q)*.9848077297210693;E=(C-y)*-.3420201539993286;C=+g[m+(v<<2)>>2]*.8660253882408142;G=(y+q)*-.6427876353263855;g[j+(F<<2)>>2]=C+(E+w);g[j+(x<<2)>>2]=w+G-C;g[j+(D<<2)>>2]=E-G-C;D=F+1|0;if((D|0)>=2){break}F=D;I=+g[m+(D<<2)>>2]}F=H+a|0;D=0;x=0;while(1){I=+g[j+(x<<2)>>2];C=+g[j+((x|2)<<2)>>2];G=I+C;E=C-I;I=+g[j+((x|1)<<2)>>2];C=+g[j+((x|3)<<2)>>2];w=(I+C)*+g[918336+(D<<2)>>2]*2.0;v=8-D|0;q=(C-I)*+g[918416+(v<<2)>>2];I=G+w;C=G-w;z=D+9|0;s=n+(z<<2<<2)|0;g[b+(z<<5<<2)>>2]=+g[s>>2]+ +g[6873552+(F*160|0)+(z<<2)>>2]*C;z=n+(v<<2<<2)|0;g[b+(v<<5<<2)>>2]=C*+g[6873552+(F*160|0)+(v<<2)>>2]+ +g[z>>2];g[s>>2]=I*+g[6873552+(F*160|0)+(D+29<<2)>>2];g[z>>2]=I*+g[6873552+(F*160|0)+(28-D<<2)>>2];I=E+q;C=E-q;z=17-D|0;s=n+(z<<2<<2)|0;g[b+(z<<5<<2)>>2]=C*+g[6873552+(F*160|0)+(z<<2)>>2]+ +g[s>>2];z=n+(D<<2<<2)|0;g[b+(D<<5<<2)>>2]=C*+g[6873552+(F*160|0)+(D<<2)>>2]+ +g[z>>2];g[s>>2]=I*+g[6873552+(F*160|0)+(37-D<<2)>>2];g[z>>2]=I*+g[6873552+(F*160|0)+(D+20<<2)>>2];z=D+1|0;if((z|0)<4){D=z;x=x+4|0}else{break}}I=+g[e>>2];C=+g[l>>2]*.7071067690849304;q=I+C;E=I-C;x=n+208|0;g[b+1664>>2]=+g[x>>2]+ +g[6873604+(F*160|0)>>2]*E;D=n+64|0;g[b+512>>2]=E*+g[6873568+(F*160|0)>>2]+ +g[D>>2];g[x>>2]=q*+g[6873684+(F*160|0)>>2];g[D>>2]=q*+g[6873648+(F*160|0)>>2];D=n+(((c&3|0)!=3?1:69)<<2)|0;x=c+1|0;if((x|0)<(d|0)){m=m+72|0;c=x;n=D;b=b+4|0}else{break}}i=h;return}function mOa(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0;f=i;g=c[d+60>>2]|0;h=c[d+412>>2]|0;j=c[d+416>>2]|0;if((j-1|0)>>>0>1>>>0){yDb(d,16,1939112,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;l=-22;i=f;return l|0}m=(c[d+72>>2]|0)/1e3|0;n=g+24|0;c[n>>2]=j;c[d+424>>2]=1152;c[d+116>>2]=481;j=g+28|0;c[j>>2]=0;o=0;while(1){if((o|0)>=3){p=0;break}q=e[1743632+(o<<1)>>1]|0;if((q|0)==(h|0)){p=0;break}if((q>>>1|0)==(h|0)){r=7;break}else{o=o+1|0}}if((r|0)==7){c[j>>2]=1;p=1}if((o|0)==3){yDb(d,16,1914824,(k=i,i=i+8|0,c[k>>2]=h,k)|0);i=k;l=-22;i=f;return l|0}c[g+36>>2]=o;o=0;while(1){if((o|0)>=15){break}if((e[1743670+(p*90|0)+(o<<1)>>1]|0|0)==(m|0)){break}else{o=o+1|0}}if((o|0)==15){yDb(d,16,1894280,(k=i,i=i+8|0,c[k>>2]=m,k)|0);i=k;l=-22;i=f;return l|0}c[g+32>>2]=o;s=+(ba(m,1152e3)|0)/(+(h|0)*8.0);c[g+40>>2]=~~s<<3;c[g+44>>2]=0;c[g+48>>2]=~~((s- +P(s))*65536.0);o=Nmb(m,c[n>>2]|0,h,p)|0;c[g+25920>>2]=c[1180704+(o<<2)>>2];c[g+25924>>2]=c[1181904+(o<<2)>>2];if((c[n>>2]|0)>0){o=g+16440|0;p=0;do{c[o+(p<<2)>>2]=0;p=p+1|0;}while((p|0)<(c[n>>2]|0))}n=g+25928|0;p=0;while(1){o=(c[1180872+(p<<2)>>2]|0)+2>>2;h=o&65535;b[n+(p<<1)>>1]=h;if((p&63|0)==0){t=h}else{t=-o&65535}if((p|0)==0){p=p+1|0;continue}else{b[n+(512-p<<1)>>1]=t;o=p+1|0;if((o|0)<257){p=o;continue}else{break}}}p=g+26952|0;t=g+27400|0;n=0;while(1){o=~~(+Wc(+(+(3-n|0)/3.0))*1048576.0);c[p+(n<<2)>>2]=(o|0)<1?1:o;a[g+(n+27336)|0]=6-((n|0)/3|0);b[t+(n<<1)>>1]=~~(+Wc(+(+((n|0)%3|0|0)/3.0))*32768.0);o=n+1|0;if((o|0)<64){n=o}else{u=0;break}}do{n=u-64|0;do{if((n|0)<-2){v=0}else{if((n|0)<0){v=1;break}if((n|0)==0){v=2;break}v=(n|0)<3?3:4}}while(0);a[g+(u+27208)|0]=v;u=u+1|0;}while((u|0)<128);u=g+27528|0;g=0;while(1){v=c[1180800+(g<<2)>>2]|0;if((v|0)<0){w=-v|0}else{w=v*3|0}b[u+(g<<1)>>1]=w*12|0;v=g+1|0;if((v|0)<17){g=v}else{l=0;break}}i=f;return l|0}function nOa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0;l=i;i=i+776|0;m=l|0;n=l+128|0;o=l+192|0;p=l+200|0;q=l+456|0;r=l+584|0;s=l+712|0;t=c[f+60>>2]|0;u=t;v=c[j>>2]|0;w=t+24|0;y=c[w>>2]|0;do{if((y|0)>0){z=t+25928|0;A=p+64|0;B=q|0;C=q+116|0;D=q+124|0;E=q+108|0;G=q+100|0;H=q+92|0;I=q+84|0;J=q+76|0;K=q+68|0;L=q+60|0;M=q+52|0;N=q+44|0;O=q+36|0;P=q+28|0;Q=q+20|0;R=q+12|0;S=q+4|0;T=q+120|0;U=q+104|0;V=q+88|0;W=q+72|0;X=q+56|0;Y=q+40|0;Z=q+24|0;_=q+8|0;$=q+112|0;aa=q+16|0;ca=q+80|0;da=q+48|0;ea=q+32|0;fa=0;ga=y;do{ha=u+16440+(fa<<2)|0;ia=u+56+(fa<<13)+7232|0;ja=u+56+(fa<<13)|0;ka=ga<<5;la=v+(fa<<1)|0;ma=c[ha>>2]|0;na=0;oa=u+16448+(fa*4608|0)|0;while(1){pa=ma+31|0;qa=la;ra=0;while(1){b[u+56+(fa<<13)+(pa-ra<<1)>>1]=b[qa>>1]|0;sa=ra+1|0;if((sa|0)<32){qa=qa+(ga<<1)|0;ra=sa}else{break}}ra=u+56+(fa<<13)+(ma<<1)|0;qa=z;pa=0;while(1){sa=ba(b[qa>>1]|0,b[ra>>1]|0)|0;ta=(ba(b[qa+128>>1]|0,b[ra+128>>1]|0)|0)+sa|0;sa=ta+(ba(b[qa+256>>1]|0,b[ra+256>>1]|0)|0)|0;ta=sa+(ba(b[qa+384>>1]|0,b[ra+384>>1]|0)|0)|0;sa=ta+(ba(b[qa+512>>1]|0,b[ra+512>>1]|0)|0)|0;ta=sa+(ba(b[qa+640>>1]|0,b[ra+640>>1]|0)|0)|0;sa=ta+(ba(b[qa+768>>1]|0,b[ra+768>>1]|0)|0)|0;c[p+(pa<<2)>>2]=sa+(ba(b[qa+896>>1]|0,b[ra+896>>1]|0)|0);sa=pa+1|0;if((sa|0)<64){ra=ra+2|0;qa=qa+2|0;pa=sa}else{break}}c[B>>2]=c[A>>2]>>14;pa=1;while(1){c[q+(pa<<2)>>2]=(c[p+(16-pa<<2)>>2]|0)+(c[p+(pa+16<<2)>>2]|0)>>14;qa=pa+1|0;if((qa|0)<17){pa=qa}else{ua=17;break}}do{c[q+(ua<<2)>>2]=(c[p+(ua+16<<2)>>2]|0)-(c[p+(80-ua<<2)>>2]|0)>>14;ua=ua+1|0;}while((ua|0)<32);pa=c[C>>2]|0;qa=(c[D>>2]|0)+pa|0;ra=c[E>>2]|0;sa=c[G>>2]|0;ta=sa+ra|0;va=c[H>>2]|0;c[G>>2]=va+sa;sa=c[I>>2]|0;wa=sa+va|0;va=c[J>>2]|0;xa=va+sa|0;sa=c[K>>2]|0;ya=sa+va|0;va=c[L>>2]|0;c[K>>2]=va+sa;sa=c[M>>2]|0;za=sa+va|0;va=c[N>>2]|0;Aa=va+sa|0;sa=c[O>>2]|0;Ba=sa+va|0;va=c[P>>2]|0;c[O>>2]=va+sa;sa=c[Q>>2]|0;Ca=sa+va|0;va=c[R>>2]|0;Da=va+sa|0;c[Q>>2]=Da;sa=(c[S>>2]|0)+va|0;va=c[U>>2]|0;Ea=(c[T>>2]|0)+va|0;Fa=c[V>>2]|0;c[U>>2]=Fa+va;va=c[W>>2]|0;Ga=va+Fa|0;Fa=ya+wa|0;Ha=c[X>>2]|0;c[W>>2]=Ha+va;va=c[Y>>2]|0;Ia=va+Ha|0;Ha=Ba+za|0;Ja=c[Z>>2]|0;c[Y>>2]=Ja+va;va=(c[_>>2]|0)+Ja|0;Ja=sa+Ca|0;c[P>>2]=Ja;Ka=c[ca>>2]|0;La=(c[$>>2]|0)+Ka|0;c[T>>2]=Ea+Ga;Ea=c[da>>2]|0;c[ca>>2]=Ea+Ka;c[I>>2]=Aa+xa;c[H>>2]=Ha+Fa;Ka=Ea+(c[aa>>2]|0)|0;c[X>>2]=va+Ia;c[R>>2]=-sa;c[Z>>2]=-va;c[N>>2]=-(Ba+Ca|0);c[da>>2]=-Ka;c[M>>2]=-(Aa+Da|0);c[L>>2]=-(Ha+Ja|0);c[J>>2]=-(za+ya|0);c[V>>2]=-(Ga+Ia|0);c[E>>2]=-(wa+ta|0);c[$>>2]=-La;c[C>>2]=-(ra+pa+xa|0);c[D>>2]=-(qa+ta+Fa|0);Fa=B;while(1){ta=Fa+64|0;qa=c[ta>>2]|0;xa=gHb(qa,(qa|0)<0|0?-1:0,23170,0)|0;qa=xa>>>15|F<<17;xa=c[Fa>>2]|0;pa=xa-qa|0;ra=qa+xa|0;xa=Fa+96|0;qa=Fa+32|0;La=c[qa>>2]|0;wa=-((c[xa>>2]|0)+La|0)|0;Ia=gHb(wa,(wa|0)<0|0?-1:0,23170,0)|0;wa=Ia>>>15|F<<17;Ia=La-wa|0;Ga=gHb(Ia,(Ia|0)<0|0?-1:0,17733,0)|0;Ia=Ga>>>15|F<<17;Ga=wa+La|0;La=gHb(Ga,(Ga|0)<0|0?-1:0,42813,0)|0;Ga=La>>>15|F<<17;c[Fa>>2]=Ia+ra;c[qa>>2]=pa-Ga;c[ta>>2]=Ga+pa;c[xa>>2]=ra-Ia;Ia=Fa+4|0;if((Ia|0)==(ea|0)){Ma=B;break}else{Fa=Ia}}while(1){Fa=Ma+112|0;Ia=c[Fa>>2]|0;ra=gHb(Ia,(Ia|0)<0|0?-1:0,16704,0)|0;Ia=ra>>>15|F<<17;ra=c[Ma>>2]|0;c[Fa>>2]=ra-Ia;c[Ma>>2]=Ia+ra;ra=Ma+16|0;Ia=c[ra>>2]|0;Fa=gHb(Ia,(Ia|0)<0|0?-1:0,83981,0)|0;Ia=Fa>>>15|F<<17;Fa=Ma+96|0;xa=c[Fa>>2]|0;c[ra>>2]=xa-Ia;c[Fa>>2]=Ia+xa;xa=Ma+80|0;Ia=c[xa>>2]|0;Fa=gHb(Ia,(Ia|0)<0|0?-1:0,29490,0)|0;Ia=Fa>>>15|F<<17;Fa=Ma+32|0;ra=c[Fa>>2]|0;c[xa>>2]=ra-Ia;c[Fa>>2]=Ia+ra;ra=Ma+48|0;Ia=c[ra>>2]|0;Fa=gHb(Ia,(Ia|0)<0|0?-1:0,19704,0)|0;Ia=Fa>>>15|F<<17;Fa=Ma+64|0;xa=c[Fa>>2]|0;c[ra>>2]=xa-Ia;c[Fa>>2]=Ia+xa;xa=Ma+4|0;if((xa|0)==(aa|0)){Na=1419208;Oa=0;break}else{Ma=xa}}while(1){xa=Oa<<2;Ia=q+(30-xa<<2)|0;Fa=c[Ia>>2]|0;ra=c[Na>>2]|0;pa=gHb(ra,(ra|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=pa>>>15|F<<17;pa=q+(xa<<2)|0;c[Ia>>2]=(c[pa>>2]|0)-Fa;c[pa>>2]=Fa+(c[pa>>2]|0);pa=q+((xa|2)<<2)|0;Fa=c[pa>>2]|0;Ia=Na+4|0;ra=c[Ia>>2]|0;Ga=gHb(ra,(ra|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=Ga>>>15|F<<17;Ga=q+(28-xa<<2)|0;c[pa>>2]=(c[Ga>>2]|0)-Fa;c[Ga>>2]=Fa+(c[Ga>>2]|0);Ga=q+(31-xa<<2)|0;Fa=c[Ga>>2]|0;pa=c[Na>>2]|0;ra=gHb(pa,(pa|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=ra>>>15|F<<17;ra=q+((xa|1)<<2)|0;c[Ga>>2]=(c[ra>>2]|0)-Fa;c[ra>>2]=Fa+(c[ra>>2]|0);ra=q+((xa|3)<<2)|0;Fa=c[ra>>2]|0;Ga=c[Ia>>2]|0;Ia=gHb(Ga,(Ga|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=Ia>>>15|F<<17;Ia=q+(29-xa<<2)|0;c[ra>>2]=(c[Ia>>2]|0)-Fa;c[Ia>>2]=Fa+(c[Ia>>2]|0);Ia=Oa+1|0;if((Ia|0)<4){Na=Na+8|0;Oa=Ia}else{Pa=T;Qa=S;Ra=1419240;break}}while(1){Ia=c[Qa>>2]|0;Fa=c[Ra>>2]|0;ra=gHb(Fa,(Fa|0)<0|0?-1:0,Ia,(Ia|0)<0|0?-1:0)|0;Ia=ra>>>15|F<<17;c[Qa>>2]=(c[Pa>>2]|0)-Ia;c[Pa>>2]=Ia+(c[Pa>>2]|0);Ia=Pa-8|0;if(Ia>>>0<B>>>0){Sa=0;break}else{Pa=Ia;Qa=Qa+8|0;Ra=Ra+4|0}}do{c[oa+(Sa<<2)>>2]=c[q+(c[1685288+(Sa<<2)>>2]<<2)>>2];Sa=Sa+1|0;}while((Sa|0)<32);Ia=ma-32|0;if((Ia|0)<0){UGb(ia|0,ja|0,960)|0;Ta=3584}else{Ta=Ia}Ia=na+1|0;if((Ia|0)<36){la=la+(ka<<1)|0;ma=Ta;na=Ia;oa=oa+128|0}else{break}}c[ha>>2]=Ta;fa=fa+1|0;ga=c[w>>2]|0;}while((fa|0)<(ga|0));if((ga|0)<=0){Ua=ga;Va=23;break}fa=t+25856|0;B=t+16448|0;S=t+25920|0;T=t+25664|0;aa=0;ea=ga;while(1){D=c[S>>2]|0;if((D|0)>0){C=0;$=T+(aa*96|0)|0;while(1){E=C+32|0;V=C+64|0;J=C+96|0;L=C+128|0;M=C+160|0;da=C+192|0;N=C+224|0;Z=C+256|0;R=C+288|0;X=C+320|0;H=C+352|0;I=0;do{ca=c[B+(aa*4608|0)+(I*1536|0)+(C<<2)>>2]|0;P=(ca|0)>-1?ca:-ca|0;ca=c[B+(aa*4608|0)+(I*1536|0)+(E<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(V<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(J<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(L<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(M<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(da<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(N<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(Z<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(R<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(X<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(H<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;do{if((ca|0)>1){P=ca>>>0>65535>>>0;_=P?ca>>>16:ca;Y=P?16:0;if((_&65280|0)==0){Wa=Y;Xa=_}else{Wa=Y|8;Xa=_>>>8}_=((21-Wa-(d[1191992+Xa|0]|0)|0)*3|0)-3|0;if((_|0)>-1){Ya=_}else{Za=0;break}while(1){_=Ya+1|0;if((ca|0)>(c[u+26952+(_<<2)>>2]|0)){break}else{Ya=_}}Za=Ya&255}else{Za=62}}while(0);a[$+I|0]=Za;I=I+1|0;}while((I|0)<3);I=a[$]|0;H=$+1|0;X=a[H]|0;R=X&255;Z=$+2|0;N=a[Z]|0;switch((d[R+64-(N&255)+(u+27208)|0]|0)+((d[(I&255)+64-R+(u+27208)|0]|0)*5|0)|0){case 1:case 2:case 21:case 22:{a[Z]=X;_a=3;break};case 5:case 9:case 14:{a[H]=I;_a=1;break};case 6:case 7:case 10:case 11:case 12:{a[Z]=I;a[H]=I;_a=2;break};case 17:case 16:case 15:{a[Z]=X;a[$]=X;_a=2;break};case 8:{if((I&255)>>>0>(N&255)>>>0){a[$]=N;$a=N}else{$a=I}a[Z]=$a;a[H]=$a;_a=2;break};case 3:case 23:{a[H]=N;_a=3;break};case 18:case 13:{a[H]=N;a[$]=N;_a=2;break};default:{_a=0}}a[fa+(aa<<5)+C|0]=_a;N=C+1|0;if((N|0)<(D|0)){C=N;$=$+3|0}else{break}}ab=c[w>>2]|0}else{ab=ea}$=aa+1|0;if(($|0)<(ab|0)){aa=$;ea=ab}else{break}}ea=(ab|0)>0;if(!ea){bb=ab;cb=0;break}aa=c[t+25920>>2]|0;if((aa|0)>0){db=0}else{bb=ab;cb=1;break}while(1){fa=0;do{b[r+(db<<6)+(fa<<1)>>1]=~~(+g[1049712+(fa<<2)>>2]*10.0);fa=fa+1|0;}while((fa|0)<(aa|0));fa=db+1|0;if((fa|0)<(ab|0)){db=fa}else{bb=ab;cb=ea;break}}}else{Ua=y;Va=23}}while(0);if((Va|0)==23){bb=Ua;cb=(Ua|0)>0}UGb(m|0,r|0,bb<<6)|0;Ua=bb<<5;TGb(n|0,0,Ua|0)|0;TGb(s|0,0,Ua|0)|0;Ua=c[t+40>>2]|0;Va=t+44|0;y=(c[Va>>2]|0)+(c[t+48>>2]|0)|0;c[Va>>2]=y;if((y|0)>65535){c[Va>>2]=y-65536;c[t+52>>2]=1;eb=Ua+8|0}else{c[t+52>>2]=0;eb=Ua}Ua=t+25924|0;y=t+25920|0;Va=c[y>>2]|0;ab=(Va|0)>0;if(ab){db=0;_a=32;$a=c[Ua>>2]|0;while(1){Za=d[$a]|0;Ya=(ba(Za,bb)|0)+_a|0;Xa=db+1|0;if((Xa|0)<(Va|0)){db=Xa;_a=Ya;$a=$a+(1<<Za)|0}else{fb=Ya;break}}}else{fb=32}a:do{if(cb){$a=fb;while(1){while(1){if(ab){gb=0;hb=-2147483648;ib=-1;jb=-1}else{kb=$a;break a}while(1){_a=0;db=hb;Ya=ib;Za=jb;while(1){Xa=b[m+(gb<<6)+(_a<<1)>>1]|0;if((Xa|0)>(db|0)){Wa=(a[n+(gb<<5)+_a|0]|0)==2;lb=Wa?Za:_a;mb=Wa?Ya:gb;nb=Wa?db:Xa}else{lb=Za;mb=Ya;nb=db}Xa=_a+1|0;if((Xa|0)<(Va|0)){_a=Xa;db=nb;Ya=mb;Za=lb}else{break}}Za=gb+1|0;if((Za|0)<(bb|0)){gb=Za;hb=nb;ib=mb;jb=lb}else{break}}if((lb|0)<0){kb=$a;break a}Za=c[Ua>>2]|0;if((lb|0)>0){Ya=0;db=Za;while(1){_a=db+(1<<d[db])|0;Xa=Ya+1|0;if((Xa|0)<(lb|0)){Ya=Xa;db=_a}else{ob=_a;break}}}else{ob=Za}pb=n+(mb<<5)+lb|0;if((a[pb]|0)==0){qb=((d[637928+(d[u+25856+(mb<<5)+lb|0]|0)|0]|0)*6|0)+2+(e[u+27528+(d[ob+1|0]<<1)>>1]|0)|0}else{db=d[s+(mb<<5)+lb|0]|0;qb=(e[u+27528+(d[ob+(db+1)|0]<<1)>>1]|0)-(e[u+27528+(d[ob+db|0]<<1)>>1]|0)|0}rb=qb+$a|0;if((rb|0)<=(eb|0)){break}a[pb]=2}db=s+(mb<<5)+lb|0;Ya=(a[db]|0)+1&255;a[db]=Ya;db=Ya&255;b[m+(mb<<6)+(lb<<1)>>1]=(b[r+(mb<<6)+(lb<<1)>>1]|0)-(b[552464+(d[ob+db|0]<<1)>>1]|0);a[pb]=(db|0)==((1<<d[ob])-1|0)?2:1;$a=rb}}else{kb=fb}}while(0);fb=eb-kb|0;if(!((fb|0)>-1)){yDb(0,0,2050368,(kb=i,i=i+24|0,c[kb>>2]=2004752,c[kb+8>>2]=1967320,c[kb+16>>2]=593,kb)|0);i=kb;Cd();return 0}kb=r0a(f,h,1792,0)|0;if((kb|0)<0){sb=kb;i=l;return sb|0}kb=h+28|0;eb=c[kb>>2]|0;rb=(eb|0)<0;ob=rb?0:c[h+24>>2]|0;pb=rb?0:eb;c[t+20>>2]=pb<<3;eb=t+8|0;c[eb>>2]=ob;c[t+16>>2]=ob+pb;pb=t+12|0;c[pb>>2]=ob;rb=t+4|0;lb=t;mb=ob;x=fe(((c[w>>2]|0)==2?0:192)|(c[t+52>>2]|(c[t+36>>2]|(c[t+32>>2]|(1-(c[t+28>>2]|0)<<7|1048400))<<2)<<1)<<9|4|0)|0;a[mb]=x;x=x>>8;a[mb+1|0]=x;x=x>>8;a[mb+2|0]=x;x=x>>8;a[mb+3|0]=x;mb=(c[pb>>2]|0)+4|0;c[pb>>2]=mb;c[lb>>2]=0;c[rb>>2]=32;t=c[y>>2]|0;do{if((t|0)>0){ob=0;r=0;m=c[w>>2]|0;qb=0;n=32;jb=t;ib=mb;while(1){nb=d[(c[Ua>>2]|0)+ob|0]|0;if((m|0)>0){hb=32-nb|0;gb=0;bb=qb;Va=n;ab=m;cb=ib;while(1){$a=d[s+(gb<<5)+r|0]|0;if((Va|0)>(nb|0)){tb=Va-nb|0;ub=$a|bb<<nb;vb=ab;wb=cb}else{db=cb;x=fe($a>>>((nb-Va|0)>>>0)|bb<<Va|0)|0;a[db]=x;x=x>>8;a[db+1|0]=x;x=x>>8;a[db+2|0]=x;x=x>>8;a[db+3|0]=x;db=(c[pb>>2]|0)+4|0;c[pb>>2]=db;tb=hb+Va|0;ub=$a;vb=c[w>>2]|0;wb=db}c[lb>>2]=ub;c[rb>>2]=tb;db=gb+1|0;if((db|0)<(vb|0)){gb=db;bb=ub;Va=tb;ab=vb;cb=wb}else{break}}xb=vb;yb=ub;zb=tb;Ab=c[y>>2]|0;Bb=wb}else{xb=m;yb=qb;zb=n;Ab=jb;Bb=ib}cb=r+1|0;if((cb|0)>=(Ab|0)){break}ob=(1<<nb)+ob|0;r=cb;m=xb;qb=yb;n=zb;jb=Ab;ib=Bb}if((Ab|0)>0){Cb=0;Db=xb;Eb=yb;Fb=zb;Gb=Ab;Hb=Bb}else{Ib=0;Jb=Ab;Kb=yb;Lb=zb;Mb=Bb;break}while(1){if((Db|0)>0){ib=0;jb=Db;n=Eb;qb=Fb;m=Hb;while(1){if((a[s+(ib<<5)+Cb|0]|0)==0){Nb=jb;Ob=n;Pb=qb;Qb=m}else{r=d[u+25856+(ib<<5)+Cb|0]|0;if((qb|0)>2){Rb=qb-2|0;Sb=r|n<<2;Tb=jb;Ub=m}else{ob=m;x=fe(r>>>((2-qb|0)>>>0)|n<<qb|0)|0;a[ob]=x;x=x>>8;a[ob+1|0]=x;x=x>>8;a[ob+2|0]=x;x=x>>8;a[ob+3|0]=x;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;Rb=qb+30|0;Sb=r;Tb=c[w>>2]|0;Ub=ob}c[lb>>2]=Sb;c[rb>>2]=Rb;Nb=Tb;Ob=Sb;Pb=Rb;Qb=Ub}ob=ib+1|0;if((ob|0)<(Nb|0)){ib=ob;jb=Nb;n=Ob;qb=Pb;m=Qb}else{break}}Vb=Nb;Wb=Ob;Xb=Pb;Yb=c[y>>2]|0;Zb=Qb}else{Vb=Db;Wb=Eb;Xb=Fb;Yb=Gb;Zb=Hb}m=Cb+1|0;if((m|0)<(Yb|0)){Cb=m;Db=Vb;Eb=Wb;Fb=Xb;Gb=Yb;Hb=Zb}else{break}}if((Yb|0)>0){_b=0;$b=Vb;ac=Wb;bc=Xb;cc=Yb;dc=Zb}else{Ib=0;Jb=Yb;Kb=Wb;Lb=Xb;Mb=Zb;break}while(1){if(($b|0)>0){m=0;qb=ac;n=bc;jb=dc;while(1){do{if((a[s+(m<<5)+_b|0]|0)==0){ec=qb;fc=n;gc=jb}else{ib=u+25664+(m*96|0)+(_b*3|0)|0;nb=d[u+25856+(m<<5)+_b|0]|0;if((nb|0)==0){ob=d[ib]|0;if((n|0)>6){hc=n-6|0;ic=ob|qb<<6;jc=jb}else{r=jb;x=fe(ob>>>((6-n|0)>>>0)|qb<<n|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;hc=n+26|0;ic=ob;jc=r}c[lb>>2]=ic;c[rb>>2]=hc;r=d[u+25664+(m*96|0)+(_b*3|0)+1|0]|0;if((hc|0)>6){kc=hc-6|0;lc=r|ic<<6;mc=jc}else{ob=jc;x=fe(r>>>((6-hc|0)>>>0)|ic<<hc|0)|0;a[ob]=x;x=x>>8;a[ob+1|0]=x;x=x>>8;a[ob+2|0]=x;x=x>>8;a[ob+3|0]=x;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;kc=hc+26|0;lc=r;mc=ob}c[lb>>2]=lc;c[rb>>2]=kc;ob=d[u+25664+(m*96|0)+(_b*3|0)+2|0]|0;if((kc|0)>6){nc=kc-6|0;oc=ob|lc<<6;pc=mc}else{r=mc;x=fe(ob>>>((6-kc|0)>>>0)|lc<<kc|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;nc=kc+26|0;oc=ob;pc=r}c[lb>>2]=oc;c[rb>>2]=nc;ec=oc;fc=nc;gc=pc;break}else if((nb|0)==3|(nb|0)==1){r=d[ib]|0;if((n|0)>6){qc=n-6|0;rc=r|qb<<6;sc=jb}else{ob=jb;x=fe(r>>>((6-n|0)>>>0)|qb<<n|0)|0;a[ob]=x;x=x>>8;a[ob+1|0]=x;x=x>>8;a[ob+2|0]=x;x=x>>8;a[ob+3|0]=x;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;qc=n+26|0;rc=r;sc=ob}c[lb>>2]=rc;c[rb>>2]=qc;ob=d[u+25664+(m*96|0)+(_b*3|0)+2|0]|0;if((qc|0)>6){tc=qc-6|0;uc=ob|rc<<6;vc=sc}else{r=sc;x=fe(ob>>>((6-qc|0)>>>0)|rc<<qc|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;tc=qc+26|0;uc=ob;vc=r}c[lb>>2]=uc;c[rb>>2]=tc;ec=uc;fc=tc;gc=vc;break}else if((nb|0)==2){nb=d[ib]|0;if((n|0)>6){wc=n-6|0;xc=nb|qb<<6;yc=jb}else{ib=jb;x=fe(nb>>>((6-n|0)>>>0)|qb<<n|0)|0;a[ib]=x;x=x>>8;a[ib+1|0]=x;x=x>>8;a[ib+2|0]=x;x=x>>8;a[ib+3|0]=x;ib=(c[pb>>2]|0)+4|0;c[pb>>2]=ib;wc=n+26|0;xc=nb;yc=ib}c[lb>>2]=xc;c[rb>>2]=wc;ec=xc;fc=wc;gc=yc;break}else{ec=qb;fc=n;gc=jb;break}}}while(0);Za=m+1|0;zc=c[w>>2]|0;if((Za|0)<(zc|0)){m=Za;qb=ec;n=fc;jb=gc}else{break}}Ac=zc;Bc=ec;Cc=fc;Dc=c[y>>2]|0;Ec=gc}else{Ac=$b;Bc=ac;Cc=bc;Dc=cc;Ec=dc}jb=_b+1|0;if((jb|0)<(Dc|0)){_b=jb;$b=Ac;ac=Bc;bc=Cc;cc=Dc;dc=Ec}else{Ib=0;Jb=Dc;Kb=Bc;Lb=Cc;Mb=Ec;break}}}else{Ib=0;Jb=t;Kb=0;Lb=32;Mb=mb}}while(0);while(1){mb=0;t=Jb;Ec=Kb;Cc=Lb;Bc=Mb;while(1){b:do{if((t|0)>0){Dc=mb+1|0;dc=mb+2|0;cc=0;bc=0;ac=c[w>>2]|0;Ac=Ec;$b=Cc;_b=t;gc=Bc;while(1){fc=d[(c[Ua>>2]|0)+cc|0]|0;if((ac|0)>0){ec=0;zc=Ac;yc=$b;wc=gc;while(1){xc=a[s+(ec<<5)+bc|0]|0;do{if(xc<<24>>24==0){Fc=zc;Gc=yc;Hc=wc}else{vc=d[(c[Ua>>2]|0)+((xc&255)+cc)|0]|0;tc=c[1180728+(vc<<2)>>2]|0;uc=d[u+25664+(ec*96|0)+(bc*3|0)+Ib|0]|0;qc=a[u+27336+uc|0]|0;rc=qc<<24>>24;sc=e[u+27400+(uc<<1)>>1]|0;uc=-rc|0;pc=tc-1|0;nc=c[u+16448+(ec*4608|0)+(Ib*1536|0)+(mb<<7)+(bc<<2)>>2]|0;if(qc<<24>>24<0){qc=(ba(((ba(nc<<uc,sc)|0)>>15)+32768|0,tc)|0)>>16;oc=(qc|0)<0?0:qc;qc=(ba(((ba(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(Dc<<7)+(bc<<2)>>2]<<uc,sc)|0)>>15)+32768|0,tc)|0)>>16;kc=(qc|0)<0?0:qc;qc=(ba(((ba(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(dc<<7)+(bc<<2)>>2]<<uc,sc)|0)>>15)+32768|0,tc)|0)>>16;uc=(qc|0)<0?0:qc;Ic=(oc|0)<(tc|0)?oc:pc;Jc=(kc|0)<(tc|0)?kc:pc;Kc=(uc|0)<(tc|0)?uc:pc}else{uc=(ba(((ba(nc>>rc,sc)|0)>>15)+32768|0,tc)|0)>>16;nc=(uc|0)<0?0:uc;uc=(ba(((ba(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(Dc<<7)+(bc<<2)>>2]>>rc,sc)|0)>>15)+32768|0,tc)|0)>>16;kc=(uc|0)<0?0:uc;uc=(ba(((ba(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(dc<<7)+(bc<<2)>>2]>>rc,sc)|0)>>15)+32768|0,tc)|0)>>16;sc=(uc|0)<0?0:uc;Ic=(nc|0)<(tc|0)?nc:pc;Jc=(kc|0)<(tc|0)?kc:pc;Kc=(sc|0)<(tc|0)?sc:pc}pc=c[1180800+(vc<<2)>>2]|0;vc=-pc|0;if((pc|0)<0){sc=(ba((ba(Kc,tc)|0)+Jc|0,tc)|0)+Ic|0;if((yc|0)>(vc|0)){Lc=pc+yc|0;Mc=sc|zc<<vc;Nc=wc}else{tc=wc;x=fe(sc>>>((vc-yc|0)>>>0)|zc<<yc|0)|0;a[tc]=x;x=x>>8;a[tc+1|0]=x;x=x>>8;a[tc+2|0]=x;x=x>>8;a[tc+3|0]=x;tc=(c[pb>>2]|0)+4|0;c[pb>>2]=tc;Lc=yc+32+pc|0;Mc=sc;Nc=tc}c[lb>>2]=Mc;c[rb>>2]=Lc;Fc=Mc;Gc=Lc;Hc=Nc;break}if((yc|0)>(pc|0)){Oc=yc;Pc=zc<<pc|Ic;Qc=wc}else{tc=wc;x=fe(Ic>>>((pc-yc|0)>>>0)|zc<<yc|0)|0;a[tc]=x;x=x>>8;a[tc+1|0]=x;x=x>>8;a[tc+2|0]=x;x=x>>8;a[tc+3|0]=x;tc=(c[pb>>2]|0)+4|0;c[pb>>2]=tc;Oc=yc+32|0;Pc=Ic;Qc=tc}tc=Oc-pc|0;c[lb>>2]=Pc;c[rb>>2]=tc;if((tc|0)>(pc|0)){Rc=tc-pc|0;Sc=Pc<<pc|Jc;Tc=Qc}else{sc=Qc;x=fe(Jc>>>((pc-tc|0)>>>0)|Pc<<tc|0)|0;a[sc]=x;x=x>>8;a[sc+1|0]=x;x=x>>8;a[sc+2|0]=x;x=x>>8;a[sc+3|0]=x;sc=(c[pb>>2]|0)+4|0;c[pb>>2]=sc;Rc=32-pc+tc|0;Sc=Jc;Tc=sc}c[lb>>2]=Sc;c[rb>>2]=Rc;if((Rc|0)>(pc|0)){Uc=Rc-pc|0;Vc=Sc<<pc|Kc;Wc=Tc}else{sc=Tc;x=fe(Kc>>>((pc-Rc|0)>>>0)|Sc<<Rc|0)|0;a[sc]=x;x=x>>8;a[sc+1|0]=x;x=x>>8;a[sc+2|0]=x;x=x>>8;a[sc+3|0]=x;sc=(c[pb>>2]|0)+4|0;c[pb>>2]=sc;Uc=32-pc+Rc|0;Vc=Kc;Wc=sc}c[lb>>2]=Vc;c[rb>>2]=Uc;Fc=Vc;Gc=Uc;Hc=Wc}}while(0);xc=ec+1|0;Xc=c[w>>2]|0;if((xc|0)<(Xc|0)){ec=xc;zc=Fc;yc=Gc;wc=Hc}else{break}}Yc=Xc;Zc=Fc;_c=Gc;$c=c[y>>2]|0;ad=Hc}else{Yc=ac;Zc=Ac;_c=$b;$c=_b;ad=gc}wc=bc+1|0;if((wc|0)>=($c|0)){bd=$c;cd=Zc;dd=_c;ed=ad;break b}cc=(1<<fc)+cc|0;bc=wc;ac=Yc;Ac=Zc;$b=_c;_b=$c;gc=ad}}else{bd=t;cd=Ec;dd=Cc;ed=Bc}}while(0);gc=mb+3|0;if((gc|0)<12){mb=gc;t=bd;Ec=cd;Cc=dd;Bc=ed}else{break}}Bc=Ib+1|0;if((Bc|0)<3){Ib=Bc;Jb=bd;Kb=cd;Lb=dd;Mb=ed}else{break}}if((fb|0)>0){Mb=0;Lb=cd;Kb=dd;bd=ed;while(1){if((Kb|0)>1){fd=Kb-1|0;gd=Lb<<1;hd=bd}else{Jb=bd;x=fe(Lb<<Kb|0)|0;a[Jb]=x;x=x>>8;a[Jb+1|0]=x;x=x>>8;a[Jb+2|0]=x;x=x>>8;a[Jb+3|0]=x;Jb=(c[pb>>2]|0)+4|0;c[pb>>2]=Jb;fd=Kb+31|0;gd=0;hd=Jb}c[lb>>2]=gd;c[rb>>2]=fd;Jb=Mb+1|0;if((Jb|0)<(fb|0)){Mb=Jb;Lb=gd;Kb=fd;bd=hd}else{id=fd;jd=gd;kd=hd;break}}}else{id=dd;jd=cd;kd=ed}c:do{if((id|0)<32){ed=jd<<id;c[lb>>2]=ed;cd=ed>>>24&255;ed=kd;while(1){c[pb>>2]=ed+1;a[ed]=cd;dd=c[lb>>2]|0;c[lb>>2]=dd<<8;hd=(c[rb>>2]|0)+8|0;c[rb>>2]=hd;if((hd|0)>=32){break c}cd=dd>>>16&255;ed=c[pb>>2]|0}}}while(0);c[rb>>2]=32;c[lb>>2]=0;lb=j+136|0;j=c[lb>>2]|0;kd=c[lb+4>>2]|0;if((j|0)==0&(kd|0)==(-2147483648|0)){ld=32}else{lb=c[f+116>>2]|0;c[o>>2]=1;c[o+4>>2]=c[f+412>>2];id=KDb(lb,(lb|0)<0|0?-1:0,o,f+104|0)|0;f=ZGb(j,kd,id,F)|0;id=h+8|0;c[id>>2]=f;c[id+4>>2]=F;ld=c[rb>>2]|0}c[kb>>2]=(32-ld+((c[pb>>2]|0)-(c[eb>>2]|0)<<3)|0)/8|0;c[k>>2]=1;sb=0;i=l;return sb|0}function oOa(d){d=d|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0;f=i;h=c[d+60>>2]|0;j=c[d+412>>2]|0;k=c[d+416>>2]|0;if((k-1|0)>>>0>1>>>0){yDb(d,16,1939064,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;m=-22;i=f;return m|0}n=(c[d+72>>2]|0)/1e3|0;o=h+24|0;c[o>>2]=k;c[d+424>>2]=1152;c[d+116>>2]=481;k=h+28|0;c[k>>2]=0;p=0;while(1){if((p|0)>=3){q=0;break}r=e[1743632+(p<<1)>>1]|0;if((r|0)==(j|0)){q=0;break}if((r>>>1|0)==(j|0)){s=7;break}else{p=p+1|0}}if((s|0)==7){c[k>>2]=1;q=1}if((p|0)==3){yDb(d,16,1914784,(l=i,i=i+8|0,c[l>>2]=j,l)|0);i=l;m=-22;i=f;return m|0}c[h+36>>2]=p;p=0;while(1){if((p|0)>=15){break}if((e[1743670+(q*90|0)+(p<<1)>>1]|0|0)==(n|0)){break}else{p=p+1|0}}if((p|0)==15){yDb(d,16,1894240,(l=i,i=i+8|0,c[l>>2]=n,l)|0);i=l;m=-22;i=f;return m|0}c[h+32>>2]=p;t=+(ba(n,1152e3)|0)/(+(j|0)*8.0);c[h+40>>2]=~~t<<3;c[h+44>>2]=0;c[h+48>>2]=~~((t- +P(t))*65536.0);p=Nmb(n,c[o>>2]|0,j,q)|0;c[h+25920>>2]=c[1180704+(p<<2)>>2];c[h+25924>>2]=c[1181904+(p<<2)>>2];if((c[o>>2]|0)>0){p=h+16440|0;q=0;do{c[p+(q<<2)>>2]=0;q=q+1|0;}while((q|0)<(c[o>>2]|0))}o=h+25928|0;q=0;while(1){p=(c[1180872+(q<<2)>>2]|0)+2>>2;j=p&65535;b[o+(q<<1)>>1]=j;if((q&63|0)==0){u=j}else{u=-p&65535}if((q|0)==0){q=q+1|0;continue}else{b[o+(512-q<<1)>>1]=u;p=q+1|0;if((p|0)<257){q=p;continue}else{break}}}q=h+26952|0;u=h+27336|0;o=0;while(1){p=3-o|0;j=~~(+Wc(+(+(p|0)/3.0))*1048576.0);c[q+(o<<2)>>2]=(j|0)<1?1:j;g[u+(o<<2)>>2]=+Wc(+(+(-p|0)/3.0))*9.5367431640625e-7;p=o+1|0;if((p|0)<64){o=p}else{v=0;break}}do{o=v-64|0;do{if((o|0)<-2){w=0}else{if((o|0)<0){w=1;break}if((o|0)==0){w=2;break}w=(o|0)<3?3:4}}while(0);a[h+(v+27208)|0]=w;v=v+1|0;}while((v|0)<128);v=h+27592|0;h=0;while(1){w=c[1180800+(h<<2)>>2]|0;if((w|0)<0){x=-w|0}else{x=w*3|0}b[v+(h<<1)>>1]=x*12|0;w=h+1|0;if((w|0)<17){h=w}else{m=0;break}}i=f;return m|0}function pOa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0.0,Jc=0.0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0;l=i;i=i+776|0;m=l|0;n=l+128|0;o=l+192|0;p=l+200|0;q=l+456|0;r=l+584|0;s=l+712|0;t=c[f+60>>2]|0;u=t;v=c[j>>2]|0;w=t+24|0;y=c[w>>2]|0;do{if((y|0)>0){z=t+25928|0;A=p+64|0;B=q|0;C=q+116|0;D=q+124|0;E=q+108|0;G=q+100|0;H=q+92|0;I=q+84|0;J=q+76|0;K=q+68|0;L=q+60|0;M=q+52|0;N=q+44|0;O=q+36|0;P=q+28|0;Q=q+20|0;R=q+12|0;S=q+4|0;T=q+120|0;U=q+104|0;V=q+88|0;W=q+72|0;X=q+56|0;Y=q+40|0;Z=q+24|0;_=q+8|0;$=q+112|0;aa=q+16|0;ca=q+80|0;da=q+48|0;ea=q+32|0;fa=0;ga=y;do{ha=u+16440+(fa<<2)|0;ia=u+56+(fa<<13)+7232|0;ja=u+56+(fa<<13)|0;ka=ga<<5;la=v+(fa<<1)|0;ma=c[ha>>2]|0;na=0;oa=u+16448+(fa*4608|0)|0;while(1){pa=ma+31|0;qa=la;ra=0;while(1){b[u+56+(fa<<13)+(pa-ra<<1)>>1]=b[qa>>1]|0;sa=ra+1|0;if((sa|0)<32){qa=qa+(ga<<1)|0;ra=sa}else{break}}ra=u+56+(fa<<13)+(ma<<1)|0;qa=z;pa=0;while(1){sa=ba(b[qa>>1]|0,b[ra>>1]|0)|0;ta=(ba(b[qa+128>>1]|0,b[ra+128>>1]|0)|0)+sa|0;sa=ta+(ba(b[qa+256>>1]|0,b[ra+256>>1]|0)|0)|0;ta=sa+(ba(b[qa+384>>1]|0,b[ra+384>>1]|0)|0)|0;sa=ta+(ba(b[qa+512>>1]|0,b[ra+512>>1]|0)|0)|0;ta=sa+(ba(b[qa+640>>1]|0,b[ra+640>>1]|0)|0)|0;sa=ta+(ba(b[qa+768>>1]|0,b[ra+768>>1]|0)|0)|0;c[p+(pa<<2)>>2]=sa+(ba(b[qa+896>>1]|0,b[ra+896>>1]|0)|0);sa=pa+1|0;if((sa|0)<64){ra=ra+2|0;qa=qa+2|0;pa=sa}else{break}}c[B>>2]=c[A>>2]>>14;pa=1;while(1){c[q+(pa<<2)>>2]=(c[p+(16-pa<<2)>>2]|0)+(c[p+(pa+16<<2)>>2]|0)>>14;qa=pa+1|0;if((qa|0)<17){pa=qa}else{ua=17;break}}do{c[q+(ua<<2)>>2]=(c[p+(ua+16<<2)>>2]|0)-(c[p+(80-ua<<2)>>2]|0)>>14;ua=ua+1|0;}while((ua|0)<32);pa=c[C>>2]|0;qa=(c[D>>2]|0)+pa|0;ra=c[E>>2]|0;sa=c[G>>2]|0;ta=sa+ra|0;va=c[H>>2]|0;c[G>>2]=va+sa;sa=c[I>>2]|0;wa=sa+va|0;va=c[J>>2]|0;xa=va+sa|0;sa=c[K>>2]|0;ya=sa+va|0;va=c[L>>2]|0;c[K>>2]=va+sa;sa=c[M>>2]|0;za=sa+va|0;va=c[N>>2]|0;Aa=va+sa|0;sa=c[O>>2]|0;Ba=sa+va|0;va=c[P>>2]|0;c[O>>2]=va+sa;sa=c[Q>>2]|0;Ca=sa+va|0;va=c[R>>2]|0;Da=va+sa|0;c[Q>>2]=Da;sa=(c[S>>2]|0)+va|0;va=c[U>>2]|0;Ea=(c[T>>2]|0)+va|0;Fa=c[V>>2]|0;c[U>>2]=Fa+va;va=c[W>>2]|0;Ga=va+Fa|0;Fa=ya+wa|0;Ha=c[X>>2]|0;c[W>>2]=Ha+va;va=c[Y>>2]|0;Ia=va+Ha|0;Ha=Ba+za|0;Ja=c[Z>>2]|0;c[Y>>2]=Ja+va;va=(c[_>>2]|0)+Ja|0;Ja=sa+Ca|0;c[P>>2]=Ja;Ka=c[ca>>2]|0;La=(c[$>>2]|0)+Ka|0;c[T>>2]=Ea+Ga;Ea=c[da>>2]|0;c[ca>>2]=Ea+Ka;c[I>>2]=Aa+xa;c[H>>2]=Ha+Fa;Ka=Ea+(c[aa>>2]|0)|0;c[X>>2]=va+Ia;c[R>>2]=-sa;c[Z>>2]=-va;c[N>>2]=-(Ba+Ca|0);c[da>>2]=-Ka;c[M>>2]=-(Aa+Da|0);c[L>>2]=-(Ha+Ja|0);c[J>>2]=-(za+ya|0);c[V>>2]=-(Ga+Ia|0);c[E>>2]=-(wa+ta|0);c[$>>2]=-La;c[C>>2]=-(ra+pa+xa|0);c[D>>2]=-(qa+ta+Fa|0);Fa=B;while(1){ta=Fa+64|0;qa=c[ta>>2]|0;xa=gHb(qa,(qa|0)<0|0?-1:0,23170,0)|0;qa=xa>>>15|F<<17;xa=c[Fa>>2]|0;pa=xa-qa|0;ra=qa+xa|0;xa=Fa+96|0;qa=Fa+32|0;La=c[qa>>2]|0;wa=-((c[xa>>2]|0)+La|0)|0;Ia=gHb(wa,(wa|0)<0|0?-1:0,23170,0)|0;wa=Ia>>>15|F<<17;Ia=La-wa|0;Ga=gHb(Ia,(Ia|0)<0|0?-1:0,17733,0)|0;Ia=Ga>>>15|F<<17;Ga=wa+La|0;La=gHb(Ga,(Ga|0)<0|0?-1:0,42813,0)|0;Ga=La>>>15|F<<17;c[Fa>>2]=Ia+ra;c[qa>>2]=pa-Ga;c[ta>>2]=Ga+pa;c[xa>>2]=ra-Ia;Ia=Fa+4|0;if((Ia|0)==(ea|0)){Ma=B;break}else{Fa=Ia}}while(1){Fa=Ma+112|0;Ia=c[Fa>>2]|0;ra=gHb(Ia,(Ia|0)<0|0?-1:0,16704,0)|0;Ia=ra>>>15|F<<17;ra=c[Ma>>2]|0;c[Fa>>2]=ra-Ia;c[Ma>>2]=Ia+ra;ra=Ma+16|0;Ia=c[ra>>2]|0;Fa=gHb(Ia,(Ia|0)<0|0?-1:0,83981,0)|0;Ia=Fa>>>15|F<<17;Fa=Ma+96|0;xa=c[Fa>>2]|0;c[ra>>2]=xa-Ia;c[Fa>>2]=Ia+xa;xa=Ma+80|0;Ia=c[xa>>2]|0;Fa=gHb(Ia,(Ia|0)<0|0?-1:0,29490,0)|0;Ia=Fa>>>15|F<<17;Fa=Ma+32|0;ra=c[Fa>>2]|0;c[xa>>2]=ra-Ia;c[Fa>>2]=Ia+ra;ra=Ma+48|0;Ia=c[ra>>2]|0;Fa=gHb(Ia,(Ia|0)<0|0?-1:0,19704,0)|0;Ia=Fa>>>15|F<<17;Fa=Ma+64|0;xa=c[Fa>>2]|0;c[ra>>2]=xa-Ia;c[Fa>>2]=Ia+xa;xa=Ma+4|0;if((xa|0)==(aa|0)){Na=1419088;Oa=0;break}else{Ma=xa}}while(1){xa=Oa<<2;Ia=q+(30-xa<<2)|0;Fa=c[Ia>>2]|0;ra=c[Na>>2]|0;pa=gHb(ra,(ra|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=pa>>>15|F<<17;pa=q+(xa<<2)|0;c[Ia>>2]=(c[pa>>2]|0)-Fa;c[pa>>2]=Fa+(c[pa>>2]|0);pa=q+((xa|2)<<2)|0;Fa=c[pa>>2]|0;Ia=Na+4|0;ra=c[Ia>>2]|0;Ga=gHb(ra,(ra|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=Ga>>>15|F<<17;Ga=q+(28-xa<<2)|0;c[pa>>2]=(c[Ga>>2]|0)-Fa;c[Ga>>2]=Fa+(c[Ga>>2]|0);Ga=q+(31-xa<<2)|0;Fa=c[Ga>>2]|0;pa=c[Na>>2]|0;ra=gHb(pa,(pa|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=ra>>>15|F<<17;ra=q+((xa|1)<<2)|0;c[Ga>>2]=(c[ra>>2]|0)-Fa;c[ra>>2]=Fa+(c[ra>>2]|0);ra=q+((xa|3)<<2)|0;Fa=c[ra>>2]|0;Ga=c[Ia>>2]|0;Ia=gHb(Ga,(Ga|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=Ia>>>15|F<<17;Ia=q+(29-xa<<2)|0;c[ra>>2]=(c[Ia>>2]|0)-Fa;c[Ia>>2]=Fa+(c[Ia>>2]|0);Ia=Oa+1|0;if((Ia|0)<4){Na=Na+8|0;Oa=Ia}else{Pa=T;Qa=S;Ra=1419120;break}}while(1){Ia=c[Qa>>2]|0;Fa=c[Ra>>2]|0;ra=gHb(Fa,(Fa|0)<0|0?-1:0,Ia,(Ia|0)<0|0?-1:0)|0;Ia=ra>>>15|F<<17;c[Qa>>2]=(c[Pa>>2]|0)-Ia;c[Pa>>2]=Ia+(c[Pa>>2]|0);Ia=Pa-8|0;if(Ia>>>0<B>>>0){Sa=0;break}else{Pa=Ia;Qa=Qa+8|0;Ra=Ra+4|0}}do{c[oa+(Sa<<2)>>2]=c[q+(c[1685160+(Sa<<2)>>2]<<2)>>2];Sa=Sa+1|0;}while((Sa|0)<32);Ia=ma-32|0;if((Ia|0)<0){UGb(ia|0,ja|0,960)|0;Ta=3584}else{Ta=Ia}Ia=na+1|0;if((Ia|0)<36){la=la+(ka<<1)|0;ma=Ta;na=Ia;oa=oa+128|0}else{break}}c[ha>>2]=Ta;fa=fa+1|0;ga=c[w>>2]|0;}while((fa|0)<(ga|0));if((ga|0)<=0){Ua=ga;Va=23;break}fa=t+25856|0;B=t+16448|0;S=t+25920|0;T=t+25664|0;aa=0;ea=ga;while(1){D=c[S>>2]|0;if((D|0)>0){C=0;$=T+(aa*96|0)|0;while(1){E=C+32|0;V=C+64|0;J=C+96|0;L=C+128|0;M=C+160|0;da=C+192|0;N=C+224|0;Z=C+256|0;R=C+288|0;X=C+320|0;H=C+352|0;I=0;do{ca=c[B+(aa*4608|0)+(I*1536|0)+(C<<2)>>2]|0;P=(ca|0)>-1?ca:-ca|0;ca=c[B+(aa*4608|0)+(I*1536|0)+(E<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(V<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(J<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(L<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(M<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(da<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(N<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(Z<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(R<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(X<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ca|0)?_:ca;ca=c[B+(aa*4608|0)+(I*1536|0)+(H<<2)>>2]|0;_=(ca|0)>-1?ca:-ca|0;ca=(_|0)>(P|0)?_:P;do{if((ca|0)>1){P=ca>>>0>65535>>>0;_=P?ca>>>16:ca;Y=P?16:0;if((_&65280|0)==0){Wa=Y;Xa=_}else{Wa=Y|8;Xa=_>>>8}_=((21-Wa-(d[1191992+Xa|0]|0)|0)*3|0)-3|0;if((_|0)>-1){Ya=_}else{Za=0;break}while(1){_=Ya+1|0;if((ca|0)>(c[u+26952+(_<<2)>>2]|0)){break}else{Ya=_}}Za=Ya&255}else{Za=62}}while(0);a[$+I|0]=Za;I=I+1|0;}while((I|0)<3);I=a[$]|0;H=$+1|0;X=a[H]|0;R=X&255;Z=$+2|0;N=a[Z]|0;switch((d[R+64-(N&255)+(u+27208)|0]|0)+((d[(I&255)+64-R+(u+27208)|0]|0)*5|0)|0){case 8:{if((I&255)>>>0>(N&255)>>>0){a[$]=N;_a=N}else{_a=I}a[Z]=_a;a[H]=_a;$a=2;break};case 1:case 2:case 21:case 22:{a[Z]=X;$a=3;break};case 3:case 23:{a[H]=N;$a=3;break};case 5:case 9:case 14:{a[H]=I;$a=1;break};case 18:case 13:{a[H]=N;a[$]=N;$a=2;break};case 17:case 16:case 15:{a[Z]=X;a[$]=X;$a=2;break};case 6:case 7:case 10:case 11:case 12:{a[Z]=I;a[H]=I;$a=2;break};default:{$a=0}}a[fa+(aa<<5)+C|0]=$a;I=C+1|0;if((I|0)<(D|0)){C=I;$=$+3|0}else{break}}ab=c[w>>2]|0}else{ab=ea}$=aa+1|0;if(($|0)<(ab|0)){aa=$;ea=ab}else{break}}ea=(ab|0)>0;if(!ea){bb=ab;cb=0;break}aa=c[t+25920>>2]|0;if((aa|0)>0){db=0}else{bb=ab;cb=1;break}while(1){fa=0;do{b[r+(db<<6)+(fa<<1)>>1]=~~(+g[1049584+(fa<<2)>>2]*10.0);fa=fa+1|0;}while((fa|0)<(aa|0));fa=db+1|0;if((fa|0)<(ab|0)){db=fa}else{bb=ab;cb=ea;break}}}else{Ua=y;Va=23}}while(0);if((Va|0)==23){bb=Ua;cb=(Ua|0)>0}UGb(m|0,r|0,bb<<6)|0;Ua=bb<<5;TGb(n|0,0,Ua|0)|0;TGb(s|0,0,Ua|0)|0;Ua=c[t+40>>2]|0;Va=t+44|0;y=(c[Va>>2]|0)+(c[t+48>>2]|0)|0;c[Va>>2]=y;if((y|0)>65535){c[Va>>2]=y-65536;c[t+52>>2]=1;eb=Ua+8|0}else{c[t+52>>2]=0;eb=Ua}Ua=t+25924|0;y=t+25920|0;Va=c[y>>2]|0;ab=(Va|0)>0;if(ab){db=0;$a=32;_a=c[Ua>>2]|0;while(1){Za=d[_a]|0;Ya=(ba(Za,bb)|0)+$a|0;Xa=db+1|0;if((Xa|0)<(Va|0)){db=Xa;$a=Ya;_a=_a+(1<<Za)|0}else{fb=Ya;break}}}else{fb=32}a:do{if(cb){_a=fb;while(1){while(1){if(ab){gb=0;hb=-2147483648;ib=-1;jb=-1}else{kb=_a;break a}while(1){$a=0;db=hb;Ya=ib;Za=jb;while(1){Xa=b[m+(gb<<6)+($a<<1)>>1]|0;if((Xa|0)>(db|0)){Wa=(a[n+(gb<<5)+$a|0]|0)==2;lb=Wa?Za:$a;mb=Wa?Ya:gb;nb=Wa?db:Xa}else{lb=Za;mb=Ya;nb=db}Xa=$a+1|0;if((Xa|0)<(Va|0)){$a=Xa;db=nb;Ya=mb;Za=lb}else{break}}Za=gb+1|0;if((Za|0)<(bb|0)){gb=Za;hb=nb;ib=mb;jb=lb}else{break}}if((lb|0)<0){kb=_a;break a}Za=c[Ua>>2]|0;if((lb|0)>0){Ya=0;db=Za;while(1){$a=db+(1<<d[db])|0;Xa=Ya+1|0;if((Xa|0)<(lb|0)){Ya=Xa;db=$a}else{ob=$a;break}}}else{ob=Za}pb=n+(mb<<5)+lb|0;if((a[pb]|0)==0){qb=((d[637920+(d[u+25856+(mb<<5)+lb|0]|0)|0]|0)*6|0)+2+(e[u+27592+(d[ob+1|0]<<1)>>1]|0)|0}else{db=d[s+(mb<<5)+lb|0]|0;qb=(e[u+27592+(d[ob+(db+1)|0]<<1)>>1]|0)-(e[u+27592+(d[ob+db|0]<<1)>>1]|0)|0}rb=qb+_a|0;if((rb|0)<=(eb|0)){break}a[pb]=2}db=s+(mb<<5)+lb|0;Ya=(a[db]|0)+1&255;a[db]=Ya;db=Ya&255;b[m+(mb<<6)+(lb<<1)>>1]=(b[r+(mb<<6)+(lb<<1)>>1]|0)-(b[552424+(d[ob+db|0]<<1)>>1]|0);a[pb]=(db|0)==((1<<d[ob])-1|0)?2:1;_a=rb}}else{kb=fb}}while(0);fb=eb-kb|0;if(!((fb|0)>-1)){yDb(0,0,2050328,(kb=i,i=i+24|0,c[kb>>2]=2004736,c[kb+8>>2]=1967280,c[kb+16>>2]=593,kb)|0);i=kb;Cd();return 0}kb=r0a(f,h,1792,0)|0;if((kb|0)<0){sb=kb;i=l;return sb|0}kb=h+28|0;eb=c[kb>>2]|0;rb=(eb|0)<0;ob=rb?0:c[h+24>>2]|0;pb=rb?0:eb;c[t+20>>2]=pb<<3;eb=t+8|0;c[eb>>2]=ob;c[t+16>>2]=ob+pb;pb=t+12|0;c[pb>>2]=ob;rb=t+4|0;lb=t;mb=ob;x=fe(((c[w>>2]|0)==2?0:192)|(c[t+52>>2]|(c[t+36>>2]|(c[t+32>>2]|(1-(c[t+28>>2]|0)<<7|1048400))<<2)<<1)<<9|4|0)|0;a[mb]=x;x=x>>8;a[mb+1|0]=x;x=x>>8;a[mb+2|0]=x;x=x>>8;a[mb+3|0]=x;mb=(c[pb>>2]|0)+4|0;c[pb>>2]=mb;c[lb>>2]=0;c[rb>>2]=32;t=c[y>>2]|0;do{if((t|0)>0){ob=0;r=0;m=c[w>>2]|0;qb=0;n=32;jb=t;ib=mb;while(1){nb=d[(c[Ua>>2]|0)+ob|0]|0;if((m|0)>0){hb=32-nb|0;gb=0;bb=qb;Va=n;ab=m;cb=ib;while(1){_a=d[s+(gb<<5)+r|0]|0;if((Va|0)>(nb|0)){tb=Va-nb|0;ub=_a|bb<<nb;vb=ab;wb=cb}else{db=cb;x=fe(_a>>>((nb-Va|0)>>>0)|bb<<Va|0)|0;a[db]=x;x=x>>8;a[db+1|0]=x;x=x>>8;a[db+2|0]=x;x=x>>8;a[db+3|0]=x;db=(c[pb>>2]|0)+4|0;c[pb>>2]=db;tb=hb+Va|0;ub=_a;vb=c[w>>2]|0;wb=db}c[lb>>2]=ub;c[rb>>2]=tb;db=gb+1|0;if((db|0)<(vb|0)){gb=db;bb=ub;Va=tb;ab=vb;cb=wb}else{break}}xb=vb;yb=ub;zb=tb;Ab=c[y>>2]|0;Bb=wb}else{xb=m;yb=qb;zb=n;Ab=jb;Bb=ib}cb=r+1|0;if((cb|0)>=(Ab|0)){break}ob=(1<<nb)+ob|0;r=cb;m=xb;qb=yb;n=zb;jb=Ab;ib=Bb}if((Ab|0)>0){Cb=0;Db=xb;Eb=yb;Fb=zb;Gb=Ab;Hb=Bb}else{Ib=0;Jb=Ab;Kb=yb;Lb=zb;Mb=Bb;break}while(1){if((Db|0)>0){ib=0;jb=Db;n=Eb;qb=Fb;m=Hb;while(1){if((a[s+(ib<<5)+Cb|0]|0)==0){Nb=jb;Ob=n;Pb=qb;Qb=m}else{r=d[u+25856+(ib<<5)+Cb|0]|0;if((qb|0)>2){Rb=qb-2|0;Sb=r|n<<2;Tb=jb;Ub=m}else{ob=m;x=fe(r>>>((2-qb|0)>>>0)|n<<qb|0)|0;a[ob]=x;x=x>>8;a[ob+1|0]=x;x=x>>8;a[ob+2|0]=x;x=x>>8;a[ob+3|0]=x;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;Rb=qb+30|0;Sb=r;Tb=c[w>>2]|0;Ub=ob}c[lb>>2]=Sb;c[rb>>2]=Rb;Nb=Tb;Ob=Sb;Pb=Rb;Qb=Ub}ob=ib+1|0;if((ob|0)<(Nb|0)){ib=ob;jb=Nb;n=Ob;qb=Pb;m=Qb}else{break}}Vb=Nb;Wb=Ob;Xb=Pb;Yb=c[y>>2]|0;Zb=Qb}else{Vb=Db;Wb=Eb;Xb=Fb;Yb=Gb;Zb=Hb}m=Cb+1|0;if((m|0)<(Yb|0)){Cb=m;Db=Vb;Eb=Wb;Fb=Xb;Gb=Yb;Hb=Zb}else{break}}if((Yb|0)>0){_b=0;$b=Vb;ac=Wb;bc=Xb;cc=Yb;dc=Zb}else{Ib=0;Jb=Yb;Kb=Wb;Lb=Xb;Mb=Zb;break}while(1){if(($b|0)>0){m=0;qb=ac;n=bc;jb=dc;while(1){do{if((a[s+(m<<5)+_b|0]|0)==0){ec=qb;fc=n;gc=jb}else{ib=u+25664+(m*96|0)+(_b*3|0)|0;nb=d[u+25856+(m<<5)+_b|0]|0;if((nb|0)==3|(nb|0)==1){ob=d[ib]|0;if((n|0)>6){hc=n-6|0;ic=ob|qb<<6;jc=jb}else{r=jb;x=fe(ob>>>((6-n|0)>>>0)|qb<<n|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;hc=n+26|0;ic=ob;jc=r}c[lb>>2]=ic;c[rb>>2]=hc;r=d[u+25664+(m*96|0)+(_b*3|0)+2|0]|0;if((hc|0)>6){kc=hc-6|0;lc=r|ic<<6;mc=jc}else{ob=jc;x=fe(r>>>((6-hc|0)>>>0)|ic<<hc|0)|0;a[ob]=x;x=x>>8;a[ob+1|0]=x;x=x>>8;a[ob+2|0]=x;x=x>>8;a[ob+3|0]=x;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;kc=hc+26|0;lc=r;mc=ob}c[lb>>2]=lc;c[rb>>2]=kc;ec=lc;fc=kc;gc=mc;break}else if((nb|0)==2){ob=d[ib]|0;if((n|0)>6){nc=n-6|0;oc=ob|qb<<6;pc=jb}else{r=jb;x=fe(ob>>>((6-n|0)>>>0)|qb<<n|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;nc=n+26|0;oc=ob;pc=r}c[lb>>2]=oc;c[rb>>2]=nc;ec=oc;fc=nc;gc=pc;break}else if((nb|0)==0){nb=d[ib]|0;if((n|0)>6){qc=n-6|0;rc=nb|qb<<6;sc=jb}else{ib=jb;x=fe(nb>>>((6-n|0)>>>0)|qb<<n|0)|0;a[ib]=x;x=x>>8;a[ib+1|0]=x;x=x>>8;a[ib+2|0]=x;x=x>>8;a[ib+3|0]=x;ib=(c[pb>>2]|0)+4|0;c[pb>>2]=ib;qc=n+26|0;rc=nb;sc=ib}c[lb>>2]=rc;c[rb>>2]=qc;ib=d[u+25664+(m*96|0)+(_b*3|0)+1|0]|0;if((qc|0)>6){tc=qc-6|0;uc=ib|rc<<6;vc=sc}else{nb=sc;x=fe(ib>>>((6-qc|0)>>>0)|rc<<qc|0)|0;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=(c[pb>>2]|0)+4|0;c[pb>>2]=nb;tc=qc+26|0;uc=ib;vc=nb}c[lb>>2]=uc;c[rb>>2]=tc;nb=d[u+25664+(m*96|0)+(_b*3|0)+2|0]|0;if((tc|0)>6){wc=tc-6|0;xc=nb|uc<<6;yc=vc}else{ib=vc;x=fe(nb>>>((6-tc|0)>>>0)|uc<<tc|0)|0;a[ib]=x;x=x>>8;a[ib+1|0]=x;x=x>>8;a[ib+2|0]=x;x=x>>8;a[ib+3|0]=x;ib=(c[pb>>2]|0)+4|0;c[pb>>2]=ib;wc=tc+26|0;xc=nb;yc=ib}c[lb>>2]=xc;c[rb>>2]=wc;ec=xc;fc=wc;gc=yc;break}else{ec=qb;fc=n;gc=jb;break}}}while(0);Za=m+1|0;zc=c[w>>2]|0;if((Za|0)<(zc|0)){m=Za;qb=ec;n=fc;jb=gc}else{break}}Ac=zc;Bc=ec;Cc=fc;Dc=c[y>>2]|0;Ec=gc}else{Ac=$b;Bc=ac;Cc=bc;Dc=cc;Ec=dc}jb=_b+1|0;if((jb|0)<(Dc|0)){_b=jb;$b=Ac;ac=Bc;bc=Cc;cc=Dc;dc=Ec}else{Ib=0;Jb=Dc;Kb=Bc;Lb=Cc;Mb=Ec;break}}}else{Ib=0;Jb=t;Kb=0;Lb=32;Mb=mb}}while(0);while(1){mb=0;t=Jb;Ec=Kb;Cc=Lb;Bc=Mb;while(1){b:do{if((t|0)>0){Dc=mb+1|0;dc=mb+2|0;cc=0;bc=0;ac=c[w>>2]|0;Ac=Ec;$b=Cc;_b=t;gc=Bc;while(1){fc=d[(c[Ua>>2]|0)+cc|0]|0;if((ac|0)>0){ec=0;zc=Ac;yc=$b;wc=gc;while(1){xc=a[s+(ec<<5)+bc|0]|0;do{if(xc<<24>>24==0){Fc=zc;Gc=yc;Hc=wc}else{tc=d[(c[Ua>>2]|0)+((xc&255)+cc)|0]|0;uc=c[1180728+(tc<<2)>>2]|0;Ic=+g[u+27336+(d[u+25664+(ec*96|0)+(bc*3|0)+Ib|0]<<2)>>2];Jc=+(uc|0);vc=uc-1|0;qc=~~(Jc*(Ic*+(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(mb<<7)+(bc<<2)>>2]|0)+1.0)*.5);rc=(qc|0)<(uc|0)?qc:vc;qc=~~(Jc*(Ic*+(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(Dc<<7)+(bc<<2)>>2]|0)+1.0)*.5);sc=(qc|0)<(uc|0)?qc:vc;qc=~~(Jc*(Ic*+(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(dc<<7)+(bc<<2)>>2]|0)+1.0)*.5);pc=(qc|0)<(uc|0)?qc:vc;vc=c[1180800+(tc<<2)>>2]|0;tc=-vc|0;if((vc|0)<0){qc=(ba((ba(pc,uc)|0)+sc|0,uc)|0)+rc|0;if((yc|0)>(tc|0)){Kc=vc+yc|0;Lc=qc|zc<<tc;Mc=wc}else{uc=wc;x=fe(qc>>>((tc-yc|0)>>>0)|zc<<yc|0)|0;a[uc]=x;x=x>>8;a[uc+1|0]=x;x=x>>8;a[uc+2|0]=x;x=x>>8;a[uc+3|0]=x;uc=(c[pb>>2]|0)+4|0;c[pb>>2]=uc;Kc=yc+32+vc|0;Lc=qc;Mc=uc}c[lb>>2]=Lc;c[rb>>2]=Kc;Fc=Lc;Gc=Kc;Hc=Mc;break}if((yc|0)>(vc|0)){Nc=yc;Oc=rc|zc<<vc;Pc=wc}else{uc=wc;x=fe(rc>>>((vc-yc|0)>>>0)|zc<<yc|0)|0;a[uc]=x;x=x>>8;a[uc+1|0]=x;x=x>>8;a[uc+2|0]=x;x=x>>8;a[uc+3|0]=x;uc=(c[pb>>2]|0)+4|0;c[pb>>2]=uc;Nc=yc+32|0;Oc=rc;Pc=uc}uc=Nc-vc|0;c[lb>>2]=Oc;c[rb>>2]=uc;if((uc|0)>(vc|0)){Qc=uc-vc|0;Rc=Oc<<vc|sc;Sc=Pc}else{rc=Pc;x=fe(sc>>>((vc-uc|0)>>>0)|Oc<<uc|0)|0;a[rc]=x;x=x>>8;a[rc+1|0]=x;x=x>>8;a[rc+2|0]=x;x=x>>8;a[rc+3|0]=x;rc=(c[pb>>2]|0)+4|0;c[pb>>2]=rc;Qc=32-vc+uc|0;Rc=sc;Sc=rc}c[lb>>2]=Rc;c[rb>>2]=Qc;if((Qc|0)>(vc|0)){Tc=Qc-vc|0;Uc=Rc<<vc|pc;Vc=Sc}else{rc=Sc;x=fe(pc>>>((vc-Qc|0)>>>0)|Rc<<Qc|0)|0;a[rc]=x;x=x>>8;a[rc+1|0]=x;x=x>>8;a[rc+2|0]=x;x=x>>8;a[rc+3|0]=x;rc=(c[pb>>2]|0)+4|0;c[pb>>2]=rc;Tc=32-vc+Qc|0;Uc=pc;Vc=rc}c[lb>>2]=Uc;c[rb>>2]=Tc;Fc=Uc;Gc=Tc;Hc=Vc}}while(0);xc=ec+1|0;Wc=c[w>>2]|0;if((xc|0)<(Wc|0)){ec=xc;zc=Fc;yc=Gc;wc=Hc}else{break}}Xc=Wc;Yc=Fc;Zc=Gc;_c=c[y>>2]|0;$c=Hc}else{Xc=ac;Yc=Ac;Zc=$b;_c=_b;$c=gc}wc=bc+1|0;if((wc|0)>=(_c|0)){ad=_c;bd=Yc;cd=Zc;dd=$c;break b}cc=(1<<fc)+cc|0;bc=wc;ac=Xc;Ac=Yc;$b=Zc;_b=_c;gc=$c}}else{ad=t;bd=Ec;cd=Cc;dd=Bc}}while(0);gc=mb+3|0;if((gc|0)<12){mb=gc;t=ad;Ec=bd;Cc=cd;Bc=dd}else{break}}Bc=Ib+1|0;if((Bc|0)<3){Ib=Bc;Jb=ad;Kb=bd;Lb=cd;Mb=dd}else{break}}if((fb|0)>0){Mb=0;Lb=bd;Kb=cd;ad=dd;while(1){if((Kb|0)>1){ed=Kb-1|0;fd=Lb<<1;gd=ad}else{Jb=ad;x=fe(Lb<<Kb|0)|0;a[Jb]=x;x=x>>8;a[Jb+1|0]=x;x=x>>8;a[Jb+2|0]=x;x=x>>8;a[Jb+3|0]=x;Jb=(c[pb>>2]|0)+4|0;c[pb>>2]=Jb;ed=Kb+31|0;fd=0;gd=Jb}c[lb>>2]=fd;c[rb>>2]=ed;Jb=Mb+1|0;if((Jb|0)<(fb|0)){Mb=Jb;Lb=fd;Kb=ed;ad=gd}else{hd=ed;id=fd;jd=gd;break}}}else{hd=cd;id=bd;jd=dd}c:do{if((hd|0)<32){dd=id<<hd;c[lb>>2]=dd;bd=dd>>>24&255;dd=jd;while(1){c[pb>>2]=dd+1;a[dd]=bd;cd=c[lb>>2]|0;c[lb>>2]=cd<<8;gd=(c[rb>>2]|0)+8|0;c[rb>>2]=gd;if((gd|0)>=32){break c}bd=cd>>>16&255;dd=c[pb>>2]|0}}}while(0);c[rb>>2]=32;c[lb>>2]=0;lb=j+136|0;j=c[lb>>2]|0;jd=c[lb+4>>2]|0;if((j|0)==0&(jd|0)==(-2147483648|0)){kd=32}else{lb=c[f+116>>2]|0;c[o>>2]=1;c[o+4>>2]=c[f+412>>2];hd=KDb(lb,(lb|0)<0|0?-1:0,o,f+104|0)|0;f=ZGb(j,jd,hd,F)|0;hd=h+8|0;c[hd>>2]=f;c[hd+4>>2]=F;kd=c[rb>>2]|0}c[kb>>2]=(32-kd+((c[pb>>2]|0)-(c[eb>>2]|0)<<3)|0)/8|0;c[k>>2]=1;sb=0;i=l;return sb|0}function qOa(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+4|0;Z3(a+10056|0,c[b>>2]|0);pea(a+11300|0,8);BFa(a+11332|0,c[(c[b>>2]|0)+88>>2]|0);T3a(a+11540|0,c[(c[b>>2]|0)+796>>2]|0);c[a+14368>>2]=620;c[a+14372>>2]=116;c[a+14352>>2]=148;c[a+14356>>2]=478;b=a+14360|0;c[b>>2]=48;if((c[a+60>>2]&8388608|0)!=0){c[b>>2]=710}c[a+14364>>2]=668;b=a+11184|0;d=a+232|0;if((c[a+14200>>2]|0)==0){x2(b,d,1075976);x2(b,a+364|0,1075976);e=a+496|0;x2(b,e,1264944);f=a+628|0;x2(b,f,1264880);return 0}else{x2(b,d,1264880);x2(b,a+364|0,1264880);e=a+496|0;x2(b,e,1264944);f=a+628|0;x2(b,f,1264880);return 0}return 0}function rOa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=g<<1;if((c[d+228>>2]|0)==0){b[e>>1]=ba(b[e>>1]|0,c[((f|0)<4?d+168|0:d+172|0)>>2]|0)|0;i=g-1|1}else{i=0}do{if((c[d+176>>2]|0)==0){g=a[(c[d+180+(f<<2)>>2]|0)+(d+300)|0]|0;if(!(g<<24>>24==0)){j=g&255;break}return}else{j=63}}while(0);d=-i|0;f=1;do{g=e+(f<<1)|0;k=b[g>>1]|0;if(!(k<<16>>16==0)){l=ba(h,k<<16>>16)|0;b[g>>1]=l+(k<<16>>16<0?d:i)}f=f+1|0;}while((f|0)<=(j|0));return}function sOa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=g-1|1;i=g<<1;g=d[(c[a+180+(f<<2)>>2]|0)+(a+300)|0]|0;a=-h|0;f=0;do{j=e+(f<<1)|0;k=b[j>>1]|0;if(!(k<<16>>16==0)){l=ba(i,k<<16>>16)|0;b[j>>1]=l+(k<<16>>16<0?a:h)}f=f+1|0;}while((f|0)<=(g|0));return}function tOa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=c[a+180+(g<<2)>>2]|0;b[f>>1]=ba(b[f>>1]|0,c[((g|0)<4?a+168|0:a+172|0)>>2]|0)|0;if((i|0)<1){return}g=-h|0;j=1;do{k=d[a+368+j|0]|0;l=f+(k<<1)|0;m=b[l>>1]|0;n=m<<16>>16;if(!(m<<16>>16==0)){if(m<<16>>16<0){o=-(((ba(ba(n,g)|0,e[a+12560+(k<<1)>>1]|0)|0)>>>3)+65535|1)&65535}else{m=ba(n,h)|0;o=(((ba(m,e[a+12560+(k<<1)>>1]|0)|0)>>>3)+65535|1)&65535}b[l>>1]=o}j=j+1|0;}while((j|0)<=(i|0));return}function uOa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[a+180+(g<<2)>>2]|0;if((i|0)<0){return}else{j=0}do{g=d[a+368+j|0]|0;k=f+(g<<1)|0;l=b[k>>1]|0;m=l<<16>>16;if(!(l<<16>>16==0)){if(l<<16>>16<0){l=ba(-m<<1|1,h)|0;n=-(((ba(l,e[a+12816+(g<<1)>>1]|0)|0)>>>4)+65535|1)&65535}else{l=ba(m<<1|1,h)|0;n=(((ba(l,e[a+12816+(g<<1)>>1]|0)|0)>>>4)+65535|1)&65535}b[k>>1]=n}j=j+1|0;}while((j|0)<=(i|0));return}function vOa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[a+14200>>2]|0)==0){i=c[a+180+(g<<2)>>2]|0}else{i=63}b[f>>1]=ba(b[f>>1]|0,c[((g|0)<4?a+168|0:a+172|0)>>2]|0)|0;if((i|0)<1){return}g=-h|0;j=1;do{k=d[a+368+j|0]|0;l=f+(k<<1)|0;m=b[l>>1]|0;n=m<<16>>16;if(!(m<<16>>16==0)){if(m<<16>>16<0){o=-((ba(ba(n,g)|0,e[a+12560+(k<<1)>>1]|0)|0)>>>3)&65535}else{m=ba(n,h)|0;o=(ba(m,e[a+12560+(k<<1)>>1]|0)|0)>>>3&65535}b[l>>1]=o}j=j+1|0;}while((j|0)<=(i|0));return}function wOa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((c[a+14200>>2]|0)==0){i=c[a+180+(g<<2)>>2]|0}else{i=63}j=(ba(b[f>>1]|0,c[((g|0)<4?a+168|0:a+172|0)>>2]|0)|0)&65535;b[f>>1]=j;g=(j<<16>>16)-1|0;if((i|0)<1){k=g;l=k&1;m=f+126|0;n=b[m>>1]|0;o=n&65535;p=o^l;q=p&65535;b[m>>1]=q;return}j=-h|0;r=g;g=1;while(1){s=d[a+368+g|0]|0;t=f+(s<<1)|0;u=b[t>>1]|0;v=u<<16>>16;if(u<<16>>16==0){w=r}else{if(u<<16>>16<0){x=-((ba(ba(v,j)|0,e[a+12560+(s<<1)>>1]|0)|0)>>3)|0}else{u=ba(v,h)|0;x=(ba(u,e[a+12560+(s<<1)>>1]|0)|0)>>3}b[t>>1]=x;w=x+r|0}t=g+1|0;if((t|0)>(i|0)){k=w;break}else{r=w;g=t}}l=k&1;m=f+126|0;n=b[m>>1]|0;o=n&65535;p=o^l;q=p&65535;b[m>>1]=q;return}function xOa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;do{if((c[a+14200>>2]|0)==0){i=c[a+180+(g<<2)>>2]|0;if((i|0)<0){j=-1}else{k=i;break}l=j&1;m=f+126|0;n=b[m>>1]|0;o=n&65535;p=o^l;q=p&65535;b[m>>1]=q;return}else{k=63}}while(0);g=-1;i=0;while(1){r=d[a+368+i|0]|0;s=f+(r<<1)|0;t=b[s>>1]|0;u=t<<16>>16;if(t<<16>>16==0){v=g}else{if(t<<16>>16<0){t=ba(-u<<1|1,h)|0;w=-((ba(t,e[a+12816+(r<<1)>>1]|0)|0)>>4)|0}else{t=ba(u<<1|1,h)|0;w=(ba(t,e[a+12816+(r<<1)>>1]|0)|0)>>4}b[s>>1]=w;v=w+g|0}s=i+1|0;if((s|0)>(k|0)){j=v;break}else{g=v;i=s}}l=j&1;m=f+126|0;n=b[m>>1]|0;o=n&65535;p=o^l;q=p&65535;b[m>>1]=q;return}function yOa(a){a=a|0;c[a+1584>>2]=0;c[a+1580>>2]=0;XAb(a+1564|0);XAb(a+1572|0);XAb(a+1588|0);XAb(a+1540|0);XAb(a+1508|0);XAb(a+1532|0);XAb(a+1516|0);XAb(a+1548|0);XAb(a+1520|0);XAb(a+1552|0);return}function zOa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=b+1508|0;do{if((c[f>>2]|0)!=0){g=b+1580|0;h=b+1584|0;if((c[g>>2]|0)==(c[a+116>>2]|0)){if((c[h>>2]|0)==(c[a+120>>2]|0)){break}}c[h>>2]=0;c[g>>2]=0;XAb(b+1564|0);XAb(b+1572|0);XAb(b+1588|0);XAb(b+1540|0);XAb(f);XAb(b+1532|0);XAb(b+1516|0);XAb(b+1548|0);XAb(b+1520|0);XAb(b+1552|0)}}while(0);a:do{if((d|0)==0){g=b+360|0;if((c[g>>2]|0)!=0){yDb(0,0,2248440,(j=i,i=i+24|0,c[j>>2]=2107856,c[j+8>>2]=2184888,c[j+16>>2]=599,j)|0);i=j;Cd();return 0}h=a+4|0;k=R$a(c[(c[h>>2]|0)+12>>2]|0)|0;l=b|0;m=b+1496|0;c[m>>2]=l;n=c[a+48>>2]|0;if((n|0)==152|(n|0)==153|(n|0)==168){n=c[h>>2]|0;c[b+68>>2]=c[n+120>>2];c[b+72>>2]=c[n+124>>2];c[b+80>>2]=c[n+140>>2];o=Y$a(n,l,0)|0}else{l=c[h>>2]|0;if((k|0)!=0){c[b+68>>2]=(c[l+120>>2]|0)+32;c[b+72>>2]=(c[l+124>>2]|0)+32}o=W0a(l,m,(c[b+2192>>2]|0)!=0|0)|0}do{if((o|0)>=0){if((c[g>>2]|0)==0){break}if((k|0)==0){p=c[h>>2]|0}else{m=b|0;l=c[m>>2]|0;if((l|0)!=0){n=a+14220|0;q=a+14216|0;r=b+32|0;s=0;t=m;m=l;do{if((s|0)==0){u=0;v=c[r>>2]<<4}else{l=ba(16>>>((c[n>>2]|0)>>>0),c[b+32+(s<<2)>>2]|0)|0;u=c[q>>2]|0;v=l}c[t>>2]=m+((16>>>(u>>>0))+v);s=s+1|0;t=b+(s<<2)|0;m=c[t>>2]|0;}while((m|0)!=0)}m=c[h>>2]|0;c[b+68>>2]=c[m+120>>2];c[b+72>>2]=c[m+124>>2];p=m}m=c[p+712>>2]|0;do{if((m|0)!=0){t=c[m+36>>2]|0;if((t|0)==0){break}s=VAb(t)|0;c[b+1596>>2]=s;if((s|0)!=0){c[b+1600>>2]=c[s+4>>2];break}yDb(c[h>>2]|0,16,2009392,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;w=-1;i=e;return w|0}}while(0);m=a+148|0;s=c[m>>2]|0;do{if((s|0)==0){x=c[b+36>>2]|0}else{if((s|0)==(c[b+32>>2]|0)){t=c[a+152>>2]|0;if((t|0)==(c[b+36>>2]|0)){x=t;break}}yDb(c[h>>2]|0,16,1999048,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;AOa(a,b);w=-1;i=e;return w|0}}while(0);if((x|0)!=(c[b+40>>2]|0)){yDb(c[h>>2]|0,16,1994864,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;AOa(a,b);w=-1;i=e;return w|0}s=b+32|0;do{if((c[a+9944>>2]|0)==0){if((EOa(a,c[s>>2]|0)|0)>=0){break}yDb(c[h>>2]|0,16,1991592,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;AOa(a,b);w=-1;i=e;return w|0}}while(0);c[m>>2]=c[s>>2];c[a+152>>2]=c[b+36>>2];break a}}while(0);k=c[b>>2]|0;yDb(c[h>>2]|0,16,2013584,(j=i,i=i+16|0,c[j>>2]=o,c[j+8>>2]=k,j)|0);i=j;w=-1;i=e;return w|0}else{if((c[b>>2]|0)==0){yDb(0,0,2248440,(j=i,i=i+24|0,c[j>>2]=2319976,c[j+8>>2]=2184888,c[j+16>>2]=596,j)|0);i=j;Cd();return 0}else{c[b+2196>>2]=1;break}}}while(0);b:do{if((c[f>>2]|0)==0){o=a+124|0;x=c[o>>2]|0;p=a+120|0;v=c[p>>2]|0;u=(ba(v+1|0,x)|0)+1|0;d=ba(v,x)|0;x=ba(v<<3,c[a+128>>2]|0)|0;v=b+1540|0;c[v>>2]=VAb(d+2|0)|0;c[f>>2]=VAb(u+(c[o>>2]|0)|0)|0;k=VAb((c[o>>2]|0)+u<<2)|0;c[b+1532>>2]=k;if((c[v>>2]|0)==0){y=81;break}if((c[f>>2]|0)==0|(k|0)==0){y=81;break}k=a+56|0;if((c[k>>2]|0)!=0){v=d<<1;u=b+1564|0;c[u>>2]=VAb(v)|0;o=b+1572|0;c[o>>2]=VAb(v)|0;v=VAb(d)|0;c[b+1588>>2]=v;if((c[u>>2]|0)==0){y=81;break}if((c[o>>2]|0)==0|(v|0)==0){y=81;break}}do{if((c[a+28>>2]|0)==2){y=53}else{if((c[k>>2]|0)!=0){y=53;break}if((c[(c[a+4>>2]|0)+692>>2]|0)!=0){y=53}}}while(0);c:do{if((y|0)==53){k=x+16|0;h=d<<2;if((k|0)==0){break}else{z=0}while(1){if((z|0)>=2){break c}v=b+1516+(z<<2)|0;c[v>>2]=VAb(k)|0;o=VAb(h)|0;c[b+1548+(z<<2)>>2]=o;if((c[v>>2]|0)==0|(o|0)==0){y=81;break b}else{z=z+1|0}}}}while(0);c[b+1580>>2]=c[a+116>>2];c[b+1584>>2]=c[p>>2]}else{d=b+1564|0;if((c[d>>2]|0)!=0){if((_Ab(d)|0)<0){y=81;break}}d=b+1572|0;if((c[d>>2]|0)!=0){if((_Ab(d)|0)<0){y=81;break}}d=b+1588|0;if((c[d>>2]|0)!=0){if((_Ab(d)|0)<0){y=81;break}}d=b+1540|0;if((c[d>>2]|0)!=0){if((_Ab(d)|0)<0){y=81;break}}if((c[f>>2]|0)!=0){if((_Ab(f)|0)<0){y=81;break}}d=b+1532|0;if((c[d>>2]|0)!=0){if((_Ab(d)|0)<0){y=81;break}}d=b+1516|0;if((c[d>>2]|0)!=0){if((_Ab(d)|0)<0){y=81;break}}d=b+1548|0;if((c[d>>2]|0)!=0){if((_Ab(d)|0)<0){y=81;break}}d=b+1520|0;if((c[d>>2]|0)!=0){if((_Ab(d)|0)<0){y=81;break}}d=b+1552|0;if((c[d>>2]|0)==0){break}if((_Ab(d)|0)<0){y=81}}}while(0);if((y|0)==81){yDb(c[a+4>>2]|0,16,2050296,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;AOa(a,b);c[b+1584>>2]=0;c[b+1580>>2]=0;XAb(b+1564|0);XAb(b+1572|0);XAb(b+1588|0);XAb(b+1540|0);XAb(f);XAb(b+1532|0);XAb(b+1516|0);XAb(b+1548|0);XAb(b+1520|0);XAb(b+1552|0);w=-12;i=e;return w|0}if((c[a+56>>2]|0)!=0){c[b+1568>>2]=c[(c[b+1564>>2]|0)+4>>2];c[b+1576>>2]=c[(c[b+1572>>2]|0)+4>>2];c[b+1592>>2]=c[(c[b+1588>>2]|0)+4>>2]}c[b+1544>>2]=c[(c[b+1540>>2]|0)+4>>2];j=c[a+124>>2]<<1|1;c[b+1512>>2]=(c[(c[f>>2]|0)+4>>2]|0)+j;c[b+1536>>2]=(c[(c[b+1532>>2]|0)+4>>2]|0)+(j<<2);j=c[b+1516>>2]|0;if((j|0)==0){w=0;i=e;return w|0}c[b+1524>>2]=(c[j+4>>2]|0)+16;c[b+1556>>2]=c[(c[b+1548>>2]|0)+4>>2];c[b+1528>>2]=(c[(c[b+1520>>2]|0)+4>>2]|0)+16;c[b+1560>>2]=c[(c[b+1552>>2]|0)+4>>2];w=0;i=e;return w|0}function AOa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=b|0;e=b+1496|0;c[e>>2]=d;f=c[a+48>>2]|0;if((f|0)==152|(f|0)==153|(f|0)==168){KCb(d)}else{U0a(c[a+4>>2]|0,e)}e=b+1596|0;XAb(e);if((c[b+2188>>2]|0)==0){g=e;TGb(g|0,0,628)|0;return}c[b+1584>>2]=0;c[b+1580>>2]=0;XAb(b+1564|0);XAb(b+1572|0);XAb(b+1588|0);XAb(b+1540|0);XAb(b+1508|0);XAb(b+1532|0);XAb(b+1516|0);XAb(b+1548|0);XAb(b+1520|0);XAb(b+1552|0);g=e;TGb(g|0,0,628)|0;return}function BOa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;if((c[b+360>>2]|0)!=0){yDb(0,0,2248440,(f=i,i=i+24|0,c[f>>2]=2004672,c[f+8>>2]=2184888,c[f+16>>2]=714,f)|0);i=f;Cd();return 0}if((c[d+360>>2]|0)==0){yDb(0,0,2248440,(f=i,i=i+24|0,c[f>>2]=1967256,c[f+8>>2]=2184888,c[f+16>>2]=715,f)|0);i=f;Cd();return 0}f=d+1496|0;c[f>>2]=d;g=b+1496|0;c[g>>2]=b;h=T0a(g,f)|0;do{if((h|0)<0){j=h}else{f=COa(b,d)|0;if((f|0)<0){j=f;break}if((c[d+1600>>2]|0)!=0){g=WAb(c[d+1596>>2]|0)|0;c[b+1596>>2]=g;if((g|0)==0){j=f;break}c[b+1600>>2]=c[g+4>>2]}c[b+2164>>2]=c[d+2164>>2];g=d+2168|0;f=c[g+4>>2]|0;k=b+2168|0;c[k>>2]=c[g>>2];c[k+4>>2]=f;f=d+2176|0;k=c[f+4>>2]|0;g=b+2176|0;c[g>>2]=c[f>>2];c[g+4>>2]=k;c[b+2184>>2]=c[d+2184>>2];c[b+2188>>2]=c[d+2188>>2];c[b+2192>>2]=c[d+2192>>2];c[b+2196>>2]=c[d+2196>>2];l=0;i=e;return l|0}}while(0);AOa(a,b);l=j;i=e;return l|0}function COa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b+1564|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1564|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;XAb(f);XAb(a+1572|0);XAb(a+1588|0);XAb(a+1540|0);XAb(a+1508|0);XAb(a+1532|0);XAb(a+1516|0);XAb(a+1548|0);XAb(a+1520|0);XAb(a+1552|0);h=-12;return h|0}}while(0);d=b+1572|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1572|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;XAb(a+1564|0);XAb(f);XAb(a+1588|0);XAb(a+1540|0);XAb(a+1508|0);XAb(a+1532|0);XAb(a+1516|0);XAb(a+1548|0);XAb(a+1520|0);XAb(a+1552|0);h=-12;return h|0}}while(0);d=b+1588|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1588|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;XAb(a+1564|0);XAb(a+1572|0);XAb(f);XAb(a+1540|0);XAb(a+1508|0);XAb(a+1532|0);XAb(a+1516|0);XAb(a+1548|0);XAb(a+1520|0);XAb(a+1552|0);h=-12;return h|0}}while(0);d=b+1540|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1540|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;XAb(a+1564|0);XAb(a+1572|0);XAb(a+1588|0);XAb(f);XAb(a+1508|0);XAb(a+1532|0);XAb(a+1516|0);XAb(a+1548|0);XAb(a+1520|0);XAb(a+1552|0);h=-12;return h|0}}while(0);d=b+1508|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1508|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;XAb(a+1564|0);XAb(a+1572|0);XAb(a+1588|0);XAb(a+1540|0);XAb(f);XAb(a+1532|0);XAb(a+1516|0);XAb(a+1548|0);XAb(a+1520|0);XAb(a+1552|0);h=-12;return h|0}}while(0);d=b+1532|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1532|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;XAb(a+1564|0);XAb(a+1572|0);XAb(a+1588|0);XAb(a+1540|0);XAb(a+1508|0);XAb(f);XAb(a+1516|0);XAb(a+1548|0);XAb(a+1520|0);XAb(a+1552|0);h=-12;return h|0}}while(0);d=b+1516|0;e=c[d>>2]|0;do{if((e|0)==0){i=37}else{f=a+1516|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){i=37;break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){i=37;break}j=f;k=a+1520|0}}while(0);a:do{if((i|0)==37){d=b+1548|0;e=c[d>>2]|0;do{if((e|0)==0){i=43}else{f=a+1548|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){i=43;break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){i=43;break}l=f;m=a+1552|0}}while(0);b:do{if((i|0)==43){d=b+1520|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1520|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}j=a+1516|0;k=f;break a}}while(0);d=b+1552|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1552|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}XAb(f);g=WAb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}l=a+1548|0;m=f;break b}}while(0);c[a+1568>>2]=c[b+1568>>2];c[a+1576>>2]=c[b+1576>>2];c[a+1592>>2]=c[b+1592>>2];c[a+1544>>2]=c[b+1544>>2];c[a+1512>>2]=c[b+1512>>2];c[a+1536>>2]=c[b+1536>>2];c[a+1524>>2]=c[b+1524>>2];c[a+1556>>2]=c[b+1556>>2];c[a+1528>>2]=c[b+1528>>2];c[a+1560>>2]=c[b+1560>>2];c[a+1580>>2]=c[b+1580>>2];c[a+1584>>2]=c[b+1584>>2];h=0;return h|0}}while(0);c[a+1584>>2]=0;c[a+1580>>2]=0;XAb(a+1564|0);XAb(a+1572|0);XAb(a+1588|0);XAb(a+1540|0);XAb(a+1508|0);XAb(a+1532|0);XAb(a+1516|0);XAb(l);XAb(a+1520|0);XAb(m);h=-12;return h|0}}while(0);c[a+1584>>2]=0;c[a+1580>>2]=0;XAb(a+1564|0);XAb(a+1572|0);XAb(a+1588|0);XAb(a+1540|0);XAb(a+1508|0);XAb(a+1532|0);XAb(j);XAb(a+1548|0);XAb(k);XAb(a+1552|0);h=-12;return h|0}function DOa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=i;i=i+24|0;e=a+9944|0;f=c[e>>2]|0;g=a+12192|0;h=c[g>>2]|0;j=a+12208|0;k=c[j>>2]|0;l=a+9948|0;m=c[l>>2]|0;n=a+9956|0;o=c[n>>2]|0;p=a+9952|0;q=c[p>>2]|0;r=a+12216|0;s=c[r>>2]|0;t=a+12220|0;u=c[t>>2]|0;v=a+14344|0;w=c[v>>2]|0;x=a+14340|0;y=c[x>>2]|0;z=a+808|0;A=c[z>>2]|0;B=a+812|0;C=c[B>>2]|0;D=a+12224|0;E=c[D>>2]|0;F=a+784|0;G=d|0;c[G>>2]=c[F>>2];c[G+4>>2]=c[F+4>>2];c[G+8>>2]=c[F+8>>2];c[G+12>>2]=c[F+12>>2];c[G+16>>2]=c[F+16>>2];c[G+20>>2]=c[F+20>>2];H=a+13184|0;I=c[H>>2]|0;J=a+13188|0;K=c[J>>2]|0;L=a+13192|0;M=c[L>>2]|0;N=a+9908|0;O=c[N>>2]|0;P=a+9912|0;Q=c[P>>2]|0;R=a+9916|0;S=c[R>>2]|0;T=a+9920|0;U=c[T>>2]|0;UGb(a|0,b|0,14672)|0;c[e>>2]=f;c[g>>2]=h;c[j>>2]=k;c[l>>2]=m;c[n>>2]=o;c[p>>2]=q;c[r>>2]=s;c[t>>2]=u;c[v>>2]=w;c[x>>2]=y;c[z>>2]=A;c[B>>2]=C;c[D>>2]=E;c[F>>2]=c[G>>2];c[F+4>>2]=c[G+4>>2];c[F+8>>2]=c[G+8>>2];c[F+12>>2]=c[G+12>>2];c[F+16>>2]=c[G+16>>2];c[F+20>>2]=c[G+20>>2];c[H>>2]=I;c[J>>2]=K;c[L>>2]=M;c[N>>2]=O;c[P>>2]=Q;c[R>>2]=S;c[T>>2]=U;c[a+14292>>2]=y;c[a+14296>>2]=y+128;c[a+14300>>2]=y+256;c[a+14304>>2]=y+384;U=y+512|0;T=a+14308|0;c[T>>2]=U;S=y+640|0;R=a+14312|0;c[R>>2]=S;c[a+14316>>2]=y+768;c[a+14320>>2]=y+896;c[a+14324>>2]=y+1024;c[a+14328>>2]=y+1152;c[a+14332>>2]=y+1280;c[a+14336>>2]=y+1408;y=a+4|0;if((c[(c[y>>2]|0)+52>>2]|0)==844251990){c[T>>2]=S;c[R>>2]=U}if((f|0)!=0){V=0;i=d;return V|0}f=EOa(a,c[a+148>>2]|0)|0;if((f|0)>=0){V=0;i=d;return V|0}yDb(c[y>>2]|0,16,1914736,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;V=f;i=d;return V|0}function EOa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=(((b|0)>-1?b:-b|0)<<2)+380&-128;b=e*24|0;f=cEb(b)|0;g=a+9944|0;c[g>>2]=f;do{if((f|0)!=0|(b|0)==0){h=e<<5;j=cEb(h)|0;c[a+12192>>2]=j;if(!((j|0)!=0|(h|0)==0)){yDb(c[a+4>>2]|0,16,2257120,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;break}c[a+12208>>2]=j;c[a+9948>>2]=j;c[a+9956>>2]=j;c[a+9952>>2]=j+16;l=0;i=d;return l|0}else{yDb(c[a+4>>2]|0,16,2257120,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k}}while(0);$Db(g);l=-12;i=d;return l|0}function FOa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;if((c[a+56>>2]|0)==0){d=1}else{e=c[(c[a+4>>2]|0)+404>>2]|0;d=(e|0)==0?1:e}do{if((c[a+48>>2]|0)==2){if((c[a+14152>>2]|0)!=0){f=6;break}e=(((c[a+12>>2]|0)+31|0)/32|0)<<1;c[a+120>>2]=e;g=e}else{f=6}}while(0);if((f|0)==6){e=((c[a+12>>2]|0)+15|0)/16|0;c[a+120>>2]=e;g=e}e=a+4|0;h=c[e>>2]|0;if((c[h+140>>2]|0)==-1){yDb(h,16,2288760,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=b;return k|0}if((d|0)>32){f=11}else{if((d|0)<=(g|0)|(g|0)==0){l=d}else{f=11}}if((f|0)==11){if((g|0)==0){m=32}else{m=(g|0)<32?g:32}yDb(h,24,2272456,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=m,j)|0);i=j;l=m}m=c[a+8>>2]|0;d=c[a+12>>2]|0;do{if((m|d|0)!=0){if((hDb(m,d,0,c[e>>2]|0)|0)==0){break}else{k=-1}i=b;return k|0}}while(0);qOa(a)|0;d=c[e>>2]|0;c[a+60>>2]=c[d+88>>2];c[a+64>>2]=c[d+92>>2];_Ga(c[d+140>>2]|0,a+14216|0,a+14220|0);c[a+88>>2]=S0a(c[(c[e>>2]|0)+52>>2]|0)|0;c[a+92>>2]=S0a(c[(c[e>>2]|0)+56>>2]|0)|0;d=cEb(80064)|0;m=d;h=a+156|0;c[h>>2]=m;a:do{if((d|0)==0){yDb(c[e>>2]|0,16,2257120,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}else{g=0;f=m;while(1){KCb(f+(g*2224|0)|0);n=g+1|0;if((n|0)>=36){break}g=n;f=c[h>>2]|0}f=a+952|0;g=a+7624|0;TGb(g|0,0,2224)|0;TGb(f|0,0,4448)|0;KCb(a+3176|0);KCb(f|0);KCb(g|0);if((JOa(a)|0)!=0){break}c[a+13760>>2]=-1;c[a+96>>2]=1;c[a+816>>2]=a;do{if((l|0)>1){g=a;f=1;do{n=WDb(14672)|0;c[a+816+(f<<2)>>2]=n;UGb(n|0,g|0,14672)|0;f=f+1|0;}while((f|0)<(l|0));if((l|0)<=0){break}f=a+120|0;g=(l|0)/2|0;n=0;do{o=a+816+(n<<2)|0;if((KOa(c[o>>2]|0)|0)<0){break a}p=((ba(c[f>>2]|0,n)|0)+g|0)/(l|0)|0;q=c[o>>2]|0;c[q+808>>2]=p;n=n+1|0;c[q+812>>2]=((ba(c[f>>2]|0,n)|0)+g|0)/(l|0)|0;}while((n|0)<(l|0))}else{if((KOa(a)|0)<0){break a}c[a+808>>2]=0;c[a+812>>2]=c[a+120>>2]}}while(0);c[a+944>>2]=l;k=0;i=b;return k|0}}while(0);LOa(a);k=-1;i=b;return k|0}function GOa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+944|0;do{if((c[b>>2]|0)>1){d=0;do{MOa(c[a+816+(d<<2)>>2]|0);d=d+1|0;e=c[b>>2]|0;}while((d|0)<(e|0));if((e|0)>1){f=1}else{break}do{$Db(a+816+(f<<2)|0);f=f+1|0;}while((f|0)<(c[b>>2]|0))}else{MOa(a)}}while(0);NOa(a);f=c[a+156>>2]|0;if((f|0)!=0){e=0;do{c[f+(e*2224|0)+2188>>2]=1;e=e+1|0;}while((e|0)<36)}c[a+9856>>2]=0;c[a+9852>>2]=0;c[a+9848>>2]=0;do{if((c[a+48>>2]|0)==2){if((c[a+14152>>2]|0)!=0){g=11;break}e=c[a+12>>2]|0;c[a+120>>2]=((e+31|0)/32|0)<<1;h=e}else{g=11}}while(0);if((g|0)==11){g=c[a+12>>2]|0;c[a+120>>2]=(g+15|0)/16|0;h=g}g=a+8|0;e=c[g>>2]|0;do{if((e|h|0)!=0){if((hDb(e,h,0,c[a+4>>2]|0)|0)==0){break}else{i=-1094995529}return i|0}}while(0);h=JOa(a)|0;a:do{if((h|0)==0){c[a+816>>2]=a;if((c[g>>2]|0)==0){i=0;return i|0}if((c[a+12>>2]|0)==0){i=0;return i|0}e=c[b>>2]|0;do{if((e|0)>1){f=a;d=1;do{j=WDb(14672)|0;c[a+816+(d<<2)>>2]=j;UGb(j|0,f|0,14672)|0;d=d+1|0;}while((d|0)<(e|0));if((e|0)<=0){break}d=a+120|0;f=(e|0)/2|0;j=0;do{k=a+816+(j<<2)|0;if((KOa(c[k>>2]|0)|0)<0){l=0;break a}m=((ba(c[d>>2]|0,j)|0)+f|0)/(e|0)|0;n=c[k>>2]|0;c[n+808>>2]=m;j=j+1|0;c[n+812>>2]=((ba(c[d>>2]|0,j)|0)+f|0)/(e|0)|0;}while((j|0)<(e|0))}else{j=KOa(a)|0;if((j|0)<0){l=j;break a}c[a+808>>2]=0;c[a+812>>2]=c[a+120>>2]}}while(0);c[b>>2]=e;i=0;return i|0}else{l=h}}while(0);LOa(a);i=l;return i|0}function HOa(a){a=a|0;c[a+9892>>2]=1179688;c[a+9888>>2]=1179688;c[a+9896>>2]=1234152;c[a+14224>>2]=1;c[a+14152>>2]=1;c[a+14172>>2]=3;c[a+104>>2]=0;c[a+108>>2]=0;c[a+11556>>2]=1;c[a+11560>>2]=1;c[a+944>>2]=1;return}function IOa(a){a=a|0;c[a+9892>>2]=1179688;c[a+9888>>2]=1179688;c[a+9896>>2]=1234152;c[a+14224>>2]=1;c[a+14152>>2]=1;c[a+14172>>2]=3;c[a+104>>2]=0;c[a+108>>2]=0;c[a+11556>>2]=1;c[a+11560>>2]=1;c[a+944>>2]=1;return}function JOa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=i;e=((c[a+8>>2]|0)+15|0)/16|0;f=a+116|0;c[f>>2]=e;g=e+1|0;h=a+124|0;c[h>>2]=g;j=e<<1|1;k=a+128|0;c[k>>2]=j;c[a+132>>2]=e<<2|1;l=a+120|0;m=c[l>>2]|0;n=ba(g,m)|0;o=(ba(m+2|0,g)|0)+1|0;c[a+136>>2]=e<<4;c[a+140>>2]=m<<4;p=ba(m,e)|0;e=a+144|0;c[e>>2]=p;c[a+12532>>2]=j;c[a+12528>>2]=j;c[a+12524>>2]=j;c[a+12520>>2]=j;c[a+12540>>2]=g;c[a+12536>>2]=g;q=ba(m<<1|1,j)|0;r=ba(g,m+1|0)|0;s=q+(r<<1)|0;if((m&1|0)==0){t=s}else{t=(g+j<<1)+s|0}s=cEb((p<<2)+4|0)|0;p=s;j=a+12556|0;c[j>>2]=p;do{if((s|0)==0){if((c[e>>2]&1073741823|0)==1073741823){break}yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}while(0);s=c[l>>2]|0;g=c[f>>2]|0;if((s|0)>0){m=0;w=g;while(1){if((w|0)>0){x=0;y=w;while(1){c[p+((ba(y,m)|0)+x<<2)>>2]=(ba(c[h>>2]|0,m)|0)+x;z=x+1|0;A=c[f>>2]|0;if((z|0)<(A|0)){x=z;y=A}else{B=A;break}}}else{B=w}y=m+1|0;if((y|0)<(s|0)){m=y;w=B}else{C=B;break}}}else{C=g}c[p+((ba(C,s)|0)<<2)>>2]=(ba(c[h>>2]|0,s-1|0)|0)+C;C=a+56|0;do{if((c[C>>2]|0)!=0){s=o<<2;p=cEb(s)|0;g=a+11564|0;c[g>>2]=p;B=(s|0)==0;if(!((p|0)!=0|B)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=cEb(s)|0;w=a+11568|0;c[w>>2]=p;if(!((p|0)!=0|B)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=cEb(s)|0;m=a+11572|0;c[m>>2]=p;if(!((p|0)!=0|B)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=cEb(s)|0;y=a+11576|0;c[y>>2]=p;if(!((p|0)!=0|B)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=cEb(s)|0;x=a+11580|0;c[x>>2]=p;if(!((p|0)!=0|B)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=cEb(s)|0;s=p;c[a+11584>>2]=s;if(!((p|0)!=0|B)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}B=(c[h>>2]|0)+1|0;c[a+11636>>2]=(c[g>>2]|0)+(B<<2);c[a+11640>>2]=(c[w>>2]|0)+(B<<2);c[a+11644>>2]=(c[m>>2]|0)+(B<<2);c[a+11648>>2]=(c[y>>2]|0)+(B<<2);c[a+11652>>2]=(c[x>>2]|0)+(B<<2);c[a+11656>>2]=s+(B<<2);B=n<<1;s=cEb(B)|0;c[a+12492>>2]=s;if(!((s|0)!=0|(B|0)==0)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}B=n<<2;s=cEb(B)|0;c[a+9976>>2]=s;x=(B|0)==0;if(!((s|0)!=0|x)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}s=WDb(B)|0;c[a+14412>>2]=s;if(!((s|0)!=0|x)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}s=WDb(B)|0;c[a+14416>>2]=s;if((s|0)!=0|x){break}yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}while(0);if((c[a+48>>2]|0)==13){D=33}else{if((c[a+60>>2]&536870912|0)!=0){D=33}}a:do{if((D|0)==33){x=o<<2;s=(x|0)==0;B=n<<1;y=(B|0)==0;m=0;while(1){if((m|0)>=2){break a}if(s){w=cEb(0)|0;c[a+11604+(m<<4)>>2]=w;c[a+11676+(m<<4)>>2]=w+((c[h>>2]|0)+1<<2);w=cEb(0)|0;c[a+11604+(m<<4)+4>>2]=w;c[a+11676+(m<<4)+4>>2]=w+((c[h>>2]|0)+1<<2);w=cEb(B)|0;c[a+11716+(m<<3)>>2]=w;if(!((w|0)!=0|y)){D=41;break}w=cEb(0)|0;c[a+11588+(m<<3)>>2]=w;c[a+11660+(m<<3)>>2]=w+((c[h>>2]|0)+1<<2);w=cEb(0)|0;c[a+11604+(m<<4)+8>>2]=w;c[a+11676+(m<<4)+8>>2]=w+((c[h>>2]|0)+1<<2);w=cEb(0)|0;c[a+11604+(m<<4)+12>>2]=w;c[a+11676+(m<<4)+12>>2]=w+((c[h>>2]|0)+1<<2);w=cEb(B)|0;c[a+11716+(m<<3)+4>>2]=w;if(!((w|0)!=0|y)){D=41;break}w=cEb(0)|0;c[a+11588+(m<<3)+4>>2]=w;c[a+11660+(m<<3)+4>>2]=w+((c[h>>2]|0)+1<<2)}else{w=cEb(x)|0;g=w;c[a+11604+(m<<4)>>2]=g;if((w|0)==0){D=38;break}c[a+11676+(m<<4)>>2]=g+((c[h>>2]|0)+1<<2);g=cEb(x)|0;w=g;c[a+11604+(m<<4)+4>>2]=w;if((g|0)==0){D=38;break}c[a+11676+(m<<4)+4>>2]=w+((c[h>>2]|0)+1<<2);w=cEb(B)|0;c[a+11716+(m<<3)>>2]=w;if(!((w|0)!=0|y)){D=41;break}w=cEb(x)|0;g=w;c[a+11588+(m<<3)>>2]=g;if((w|0)==0){D=43;break}c[a+11660+(m<<3)>>2]=g+((c[h>>2]|0)+1<<2);g=cEb(x)|0;w=g;c[a+11604+(m<<4)+8>>2]=w;if((g|0)==0){D=38;break}c[a+11676+(m<<4)+8>>2]=w+((c[h>>2]|0)+1<<2);w=cEb(x)|0;g=w;c[a+11604+(m<<4)+12>>2]=g;if((w|0)==0){D=38;break}c[a+11676+(m<<4)+12>>2]=g+((c[h>>2]|0)+1<<2);g=cEb(B)|0;c[a+11716+(m<<3)+4>>2]=g;if(!((g|0)!=0|y)){D=41;break}g=cEb(x)|0;w=g;c[a+11588+(m<<3)+4>>2]=w;if((g|0)==0){D=43;break}c[a+11660+(m<<3)+4>>2]=w+((c[h>>2]|0)+1<<2)}w=cEb(B)|0;c[a+11708+(m<<2)>>2]=w;if((w|0)!=0|y){m=m+1|0}else{D=45;break}}if((D|0)==38){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}else if((D|0)==41){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}else if((D|0)==43){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}else if((D|0)==45){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}}while(0);do{if((c[a+28>>2]|0)==2){o=cEb((ba(c[l>>2]<<1&2,c[k>>2]|0)|0)+q|0)|0;c[a+9900>>2]=o;do{if((o|0)==0){m=c[k>>2]|0;if((q|0)==(ba(c[l>>2]<<1&2,-m|0)|0)){E=m;break}yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}else{E=c[k>>2]|0}}while(0);c[a+9904>>2]=o+(E+1);m=cEb(n)|0;c[a+9936>>2]=m;y=(n|0)==0;if(!((m|0)!=0|y)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}m=cEb(n)|0;c[a+9940>>2]=m;if((m|0)!=0|y){break}yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}while(0);do{if((c[a+32>>2]|0)==0){if((c[a+40>>2]|0)!=0){D=58;break}if((c[C>>2]|0)==0){D=58}}else{D=58}}while(0);do{if((D|0)==58){C=t<<1;E=cEb(C)|0;y=E;c[a+9872>>2]=y;if((E|0)!=0|(C|0)==0){c[a+9876>>2]=y+((c[k>>2]|0)+1<<1);C=q+1+(c[h>>2]|0)|0;c[a+9880>>2]=y+(C<<1);c[a+9884>>2]=y+(C+r<<1);if((t|0)>0){F=0}else{break}do{b[y+(F<<1)>>1]=1024;F=F+1|0;}while((F|0)<(t|0))}else{yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}}while(0);t=cEb(n)|0;F=a+9932|0;c[F>>2]=t;if(!((t|0)!=0|(n|0)==0)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}TGb(t|0,1,n|0)|0;t=n+2|0;n=cEb(t)|0;r=a+9928|0;c[r>>2]=n;if(!((n|0)!=0|(t|0)==0)){yDb(c[a+4>>2]|0,16,2257120,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}u=c[l>>2]|0;l=c[h>>2]|0;h=ba(l,u)|0;c[a+14424>>2]=c[a+4>>2];c[a+14428>>2]=a+10056;c[a+14432>>2]=c[j>>2];c[a+14436>>2]=c[e>>2];c[a+14440>>2]=c[f>>2];c[a+14444>>2]=u;c[a+14448>>2]=l;c[a+14452>>2]=c[k>>2];k=a+14468|0;c[k>>2]=WDb(h)|0;l=cEb(h)|0;h=a+14464|0;c[h>>2]=l;if((c[k>>2]|0)==0|(l|0)==0){$Db(k);$Db(h);v=-12;i=d;return v|0}else{c[a+14484>>2]=c[r>>2];c[a+14488>>2]=c[F>>2];c[a+14472>>2]=c[a+9876>>2];c[a+14476>>2]=c[a+9880>>2];c[a+14480>>2]=c[a+9884>>2];c[a+14584>>2]=110;c[a+14588>>2]=a;v=0;i=d;return v|0}return 0}function KOa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=a+128|0;e=c[d>>2]|0;f=c[a+120>>2]|0;g=ba(f<<1|1,e)|0;h=a+124|0;j=c[h>>2]|0;k=ba(j,f+1|0)|0;l=g+(k<<1)|0;if((f&1|0)==0){m=l}else{m=(j+e<<1)+l|0}c[a+12208>>2]=0;c[a+12192>>2]=0;TGb(a+9944|0,0,16)|0;do{if((c[a+56>>2]|0)!=0){l=cEb(256)|0;c[a+12216>>2]=l;if((l|0)==0){yDb(c[a+4>>2]|0,16,2257120,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}l=cEb(256)|0;c[a+12220>>2]=l;e=a+4|0;j=c[e>>2]|0;if((l|0)==0){yDb(j,16,2257120,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}if((c[j+312>>2]|0)==0){break}j=cEb(512)|0;c[a+13184>>2]=j;if((j|0)!=0){break}yDb(c[e>>2]|0,16,2257120,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}}while(0);e=cEb(3072)|0;c[a+14344>>2]=e;if((e|0)==0){yDb(c[a+4>>2]|0,16,2257120,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}j=e;c[a+14340>>2]=j;c[a+14292>>2]=j;c[a+14296>>2]=e+128;c[a+14300>>2]=e+256;c[a+14304>>2]=e+384;j=e+512|0;l=a+14308|0;c[l>>2]=j;f=e+640|0;p=a+14312|0;c[p>>2]=f;c[a+14316>>2]=e+768;c[a+14320>>2]=e+896;c[a+14324>>2]=e+1024;c[a+14328>>2]=e+1152;c[a+14332>>2]=e+1280;c[a+14336>>2]=e+1408;e=a+4|0;if((c[(c[e>>2]|0)+52>>2]|0)==844251990){c[l>>2]=f;c[p>>2]=j}if((c[a+28>>2]|0)!=2){o=0;i=b;return o|0}j=m<<5;m=cEb(j)|0;p=m;c[a+9908>>2]=p;if((m|0)!=0|(j|0)==0){c[a+9912>>2]=p+((c[d>>2]|0)+1<<5);d=g+1+(c[h>>2]|0)|0;c[a+9916>>2]=p+(d<<5);c[a+9920>>2]=p+(d+k<<5);o=0;i=b;return o|0}else{yDb(c[e>>2]|0,16,2257120,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}return 0}function LOa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+944|0;if((c[b>>2]|0)>1){d=0;do{MOa(c[a+816+(d<<2)>>2]|0);d=d+1|0;e=c[b>>2]|0;}while((d|0)<(e|0));if((e|0)>1){e=1;do{$Db(a+816+(e<<2)|0);e=e+1|0;}while((e|0)<(c[b>>2]|0))}c[b>>2]=1}else{MOa(a)}$Db(a+13744|0);c[a+13756>>2]=0;$Db(a+14016|0);c[a+14024>>2]=0;b=a+156|0;e=c[b>>2]|0;a:do{if((e|0)!=0){d=0;f=e;while(1){c[f+(d*2224|0)+1584>>2]=0;c[f+(d*2224|0)+1580>>2]=0;XAb(f+(d*2224|0)+1564|0);XAb(f+(d*2224|0)+1572|0);XAb(f+(d*2224|0)+1588|0);XAb(f+(d*2224|0)+1540|0);XAb(f+(d*2224|0)+1508|0);XAb(f+(d*2224|0)+1532|0);XAb(f+(d*2224|0)+1516|0);XAb(f+(d*2224|0)+1548|0);XAb(f+(d*2224|0)+1520|0);XAb(f+(d*2224|0)+1552|0);AOa(a,(c[b>>2]|0)+(d*2224|0)|0);g=d+1|0;if((g|0)>=36){break a}d=g;f=c[b>>2]|0}}}while(0);$Db(b);c[a+2536>>2]=0;c[a+2532>>2]=0;XAb(a+2516|0);XAb(a+2524|0);XAb(a+2540|0);XAb(a+2492|0);XAb(a+2460|0);XAb(a+2484|0);XAb(a+2468|0);XAb(a+2500|0);XAb(a+2472|0);XAb(a+2504|0);AOa(a,a+952|0);c[a+9208>>2]=0;c[a+9204>>2]=0;XAb(a+9188|0);XAb(a+9196|0);XAb(a+9212|0);XAb(a+9164|0);XAb(a+9132|0);XAb(a+9156|0);XAb(a+9140|0);XAb(a+9172|0);XAb(a+9144|0);XAb(a+9176|0);AOa(a,a+7624|0);c[a+4760>>2]=0;c[a+4756>>2]=0;XAb(a+4740|0);XAb(a+4748|0);XAb(a+4764|0);XAb(a+4716|0);XAb(a+4684|0);XAb(a+4708|0);XAb(a+4692|0);XAb(a+4724|0);XAb(a+4696|0);XAb(a+4728|0);AOa(a,a+3176|0);NOa(a);c[a+96>>2]=0;c[a+9856>>2]=0;c[a+9852>>2]=0;c[a+9848>>2]=0;c[a+152>>2]=0;c[a+148>>2]=0;return}function MOa(a){a=a|0;if((a|0)==0){return}$Db(a+9944|0);$Db(a+12192|0);c[a+9952>>2]=0;c[a+9956>>2]=0;c[a+9948>>2]=0;c[a+12208>>2]=0;$Db(a+13184|0);$Db(a+12216|0);$Db(a+12220|0);$Db(a+14344|0);$Db(a+9908|0);c[a+14340>>2]=0;return}function NOa(a){a=a|0;$Db(a+12492|0);$Db(a+11564|0);$Db(a+11568|0);$Db(a+11572|0);$Db(a+11576|0);$Db(a+11580|0);$Db(a+11584|0);TGb(a+11636|0,0,24)|0;$Db(a+11604|0);c[a+11676>>2]=0;$Db(a+11608|0);c[a+11680>>2]=0;$Db(a+11716|0);$Db(a+11588|0);c[a+11660>>2]=0;$Db(a+11612|0);c[a+11684>>2]=0;$Db(a+11616|0);c[a+11688>>2]=0;$Db(a+11720|0);$Db(a+11592|0);c[a+11664>>2]=0;$Db(a+11708|0);$Db(a+11620|0);c[a+11692>>2]=0;$Db(a+11624|0);c[a+11696>>2]=0;$Db(a+11724|0);$Db(a+11596|0);c[a+11668>>2]=0;$Db(a+11628|0);c[a+11700>>2]=0;$Db(a+11632|0);c[a+11704>>2]=0;$Db(a+11728|0);$Db(a+11600|0);c[a+11672>>2]=0;$Db(a+11712|0);$Db(a+9872|0);$Db(a+9900|0);$Db(a+9932|0);$Db(a+9936|0);$Db(a+9940|0);$Db(a+9928|0);$Db(a+14464|0);$Db(a+14468|0);$Db(a+12556|0);$Db(a+9976|0);$Db(a+14412|0);$Db(a+14416|0);c[a+152>>2]=0;c[a+148>>2]=0;return}function OOa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+216|0;g=f|0;h=f+72|0;j=f+144|0;k=(e|0)!=0;do{if(k){if((c[b+28>>2]|0)==0){break}i=f;return}}while(0);l=b+4|0;m=g|0;n=h|0;o=j|0;p=b|0;q=b+12|0;r=b+16|0;s=0;do{if((s|0)==0){t=l;u=0}else{t=p;u=c[l>>2]|0}v=c[t>>2]|0;TGb(m|0,0,65)|0;TGb(n|0,0,65)|0;w=c[p>>2]|0;TGb(o|0,w&255|0,65)|0;if((u|0)<(v|0)){x=c[q>>2]|0;y=c[r>>2]|0;z=u;do{A=a[x+z|0]|0;B=A<<24>>24;C=a[y+z|0]|0;D=j+B|0;if((d[D]|0)==(w|0)){a[D]=z}D=g+B|0;if(C<<24>>24>(a[D]|0)){a[D]=C}D=h+(C<<24>>24)|0;if(A<<24>>24>(a[D]|0)){a[D]=A}z=z+1|0;}while((z|0)<(v|0))}if(k){v=e+(s*195|0)|0;c[b+28+(s<<2)>>2]=v;UGb(v|0,m|0,65)|0;v=e+(s*195|0)+65|0;c[b+36+(s<<2)>>2]=v;UGb(v|0,n|0,65)|0;v=e+(s*195|0)+130|0;c[b+20+(s<<2)>>2]=v;E=v}else{v=WDb(65)|0;c[b+28+(s<<2)>>2]=v;UGb(v|0,m|0,65)|0;v=WDb(65)|0;c[b+36+(s<<2)>>2]=v;UGb(v|0,n|0,65)|0;v=WDb(65)|0;c[b+20+(s<<2)>>2]=v;E=v}UGb(E|0,o|0,65)|0;s=s+1|0;}while((s|0)<2);i=f;return}function POa(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=d+52|0;f=d+48|0;g=d|0;h=d+12|0;i=d+16|0;j=d+4|0;k=0;l=c[e>>2]|0;while(1){m=(k|0)==0;n=m?1:k<<1;o=m?0:k+65535|1;if((l|0)>0){m=d+64+(k<<2)|0;p=0;while(1){q=c[f>>2]|0;r=b[q+(p<<2)>>1]|0;s=r<<16>>16;t=b[q+(p<<2)+2>>1]|0;do{if(t<<16>>16==0){u=66;v=64}else{if(t<<16>>16<0){u=0;v=r;break}if((s|0)==(c[g>>2]|0)){u=66;v=0;break}q=(ba(a[(c[i>>2]|0)+s|0]|0,n)|0)+o|0;u=(a[(c[h>>2]|0)+s|0]|0)+((s|0)<(c[j>>2]|0)?1:-63)&255;v=q&65535}}while(0);a[(c[m>>2]|0)+(p<<2)+2|0]=t;s=c[m>>2]|0;b[s+(p<<2)>>1]=v;a[s+(p<<2)+3|0]=u;s=p+1|0;r=c[e>>2]|0;if((s|0)<(r|0)){p=s}else{w=r;break}}}else{w=l}p=k+1|0;if((p|0)<32){k=p;l=w}else{break}}return}function QOa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=a+156|0;f=c[e>>2]|0;g=a+9848|0;a:do{if((b|0)==0){h=c[g>>2]|0;j=0;do{do{if((h|0)!=(f+(j*2224|0)|0)){if((c[f+(j*2224|0)+360>>2]|0)==0){k=j;break a}if((c[f+(j*2224|0)+2188>>2]|0)==0){break}if((c[f+(j*2224|0)+2192>>2]&4|0)==0){k=j;break a}}}while(0);j=j+1|0;}while((j|0)<36);l=a+4|0;m=c[l>>2]|0;n=m;yDb(n,8,2021456,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;Cd();return 0}else{j=0;do{if((c[f+(j*2224|0)+360>>2]|0)==0){if((f+(j*2224|0)|0)!=(c[g>>2]|0)){k=j;break a}}j=j+1|0;}while((j|0)<36);l=a+4|0;m=c[l>>2]|0;n=m;yDb(n,8,2021456,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;Cd();return 0}}while(0);if(!(k>>>0<36>>>0)){i=d;return k|0}o=f+(k*2224|0)+2188|0;if((c[o>>2]|0)==0){i=d;return k|0}c[o>>2]=0;c[f+(k*2224|0)+1584>>2]=0;c[f+(k*2224|0)+1580>>2]=0;XAb(f+(k*2224|0)+1564|0);XAb(f+(k*2224|0)+1572|0);XAb(f+(k*2224|0)+1588|0);XAb(f+(k*2224|0)+1540|0);XAb(f+(k*2224|0)+1508|0);XAb(f+(k*2224|0)+1532|0);XAb(f+(k*2224|0)+1516|0);XAb(f+(k*2224|0)+1548|0);XAb(f+(k*2224|0)+1520|0);XAb(f+(k*2224|0)+1552|0);AOa(a,(c[e>>2]|0)+(k*2224|0)|0);i=d;return k|0}function ROa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[a+9924>>2]=0;if((_0a(b)|0)==0){yDb(b,16,2242760,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1;i=d;return h|0}j=a+9992|0;k=a+9848|0;do{if((c[j>>2]|0)!=3){l=c[k>>2]|0;if((l|0)==0){break}if((l|0)==(c[a+9852>>2]|0)){break}if((c[l+360>>2]|0)==0){break}AOa(a,l)}}while(0);l=a+156|0;m=a+9852|0;n=b+816|0;o=b;p=0;do{q=c[l>>2]|0;r=q+(p*2224|0)|0;do{if((r|0)!=(c[k>>2]|0)){if((r|0)==(c[m>>2]|0)){break}if((c[q+(p*2224|0)+2192>>2]|0)==0){break}if((c[q+(p*2224|0)+2188>>2]|0)!=0){break}if((c[n>>2]&1|0)==0){yDb(o,16,2230336,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;s=c[l>>2]|0}else{s=q}AOa(a,s+(p*2224|0)|0)}}while(0);p=p+1|0;}while((p|0)<36);p=a+7624|0;AOa(a,p);s=0;do{n=c[l>>2]|0;if((c[n+(s*2224|0)+2192>>2]|0)==0){AOa(a,n+(s*2224|0)|0)}s=s+1|0;}while((s|0)<36);s=a+9856|0;n=c[s>>2]|0;if((n|0)==0){t=23}else{if((c[n+360>>2]|0)==0){u=n}else{t=23}}do{if((t|0)==23){n=QOa(a,0)|0;if((n|0)>=0){u=(c[l>>2]|0)+(n*2224|0)|0;break}yDb(c[a+4>>2]|0,16,2218320,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=n;i=d;return h|0}}while(0);n=u+2192|0;c[n>>2]=0;q=a+10008|0;do{if((c[q>>2]|0)==0){if((c[j>>2]|0)==3){break}c[n>>2]=3}}while(0);n=a+104|0;r=c[n>>2]|0;c[n>>2]=r+1;c[u+160>>2]=r;if((zOa(a,u,0)|0)<0){h=-1;i=d;return h|0}c[s>>2]=u;r=u+300|0;c[r>>2]=c[a+14184>>2];n=a+48|0;do{if(((c[n>>2]|0)-1|0)>>>0<2>>>0){v=c[a+14172>>2]|0;if((v|0)==3){break}c[r>>2]=((v|0)==1|0)==(c[a+14240>>2]|0)}}while(0);if((c[a+14224>>2]|0)==0){w=(c[a+14152>>2]|0)==0|0}else{w=0}c[u+296>>2]=w;w=a+14172|0;c[u+2164>>2]=(c[w>>2]|0)!=3;r=c[j>>2]|0;c[u+88>>2]=r;c[u+84>>2]=(r|0)==1;r=BOa(a,p,u)|0;if((r|0)<0){h=r;i=d;return h|0}r=c[j>>2]|0;do{if((r|0)==3){x=c[k>>2]|0}else{u=c[m>>2]|0;c[k>>2]=u;if((c[q>>2]|0)!=0){x=u;break}c[m>>2]=c[s>>2];x=u}}while(0);if((x|0)==0){t=42}else{if((c[x+360>>2]|0)==0){t=42}}do{if((t|0)==42){if((r|0)==1){if((c[w>>2]|0)==3){break}}x=a+4|0;eFb(c[(c[x>>2]|0)+140>>2]|0,e,f)|0;s=c[j>>2]|0;do{if((s|0)==3){q=c[m>>2]|0;if((q|0)==0){t=49;break}if((c[q+360>>2]|0)==0){if((s|0)==1){t=50;break}else{t=49;break}}else{yDb(o,48,2209e3,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;break}}else if((s|0)==1){t=50}else{t=49}}while(0);do{if((t|0)==49){yDb(o,16,2200392,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}else if((t|0)==50){if((c[w>>2]|0)==3){break}yDb(o,48,2191896,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}}while(0);s=QOa(a,0)|0;if((s|0)<0){yDb(c[x>>2]|0,16,2218320,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=s;i=d;return h|0}q=c[l>>2]|0;u=q+(s*2224|0)|0;c[k>>2]=u;c[q+(s*2224|0)+2192>>2]=3;c[q+(s*2224|0)+84>>2]=0;c[q+(s*2224|0)+88>>2]=2;if((zOa(a,u,0)|0)<0){c[k>>2]=0;h=-1;i=d;return h|0}do{if((c[b+712>>2]|0)==0){u=b+124|0;s=c[u>>2]|0;do{if((s|0)>0){q=b+120|0;p=0;do{v=c[k>>2]|0;y=(c[v>>2]|0)+(ba(c[v+32>>2]|0,p)|0)|0;TGb(y|0,-128|0,c[q>>2]|0)|0;p=p+1|0;z=c[u>>2]|0;}while((p|0)<(z|0));if((z|0)<=0){A=z;break}p=b+120|0;q=0;while(1){y=c[k>>2]|0;v=(c[y+4>>2]|0)+(ba(c[y+36>>2]|0,q)|0)|0;TGb(v|0,-128|0,-(-(c[p>>2]|0)>>c[e>>2])|0)|0;v=c[k>>2]|0;y=(c[v+8>>2]|0)+(ba(c[v+40>>2]|0,q)|0)|0;TGb(y|0,-128|0,-(-(c[p>>2]|0)>>c[e>>2])|0)|0;y=q+1|0;v=c[u>>2]|0;if((y|0)<(-(-v>>c[f>>2])|0)){q=y}else{A=v;break}}}else{A=s}}while(0);s=c[n>>2]|0;if(!((s|0)==22|(s|0)==5)){break}if((A|0)<=0){break}s=b+120|0;q=0;do{p=c[k>>2]|0;v=(c[p>>2]|0)+(ba(c[p+32>>2]|0,q)|0)|0;TGb(v|0,16,c[s>>2]|0)|0;q=q+1|0;}while((q|0)<(c[u>>2]|0))}}while(0);Y0a((c[k>>2]|0)+1496|0,2147483647,0);Y0a((c[k>>2]|0)+1496|0,2147483647,1)}}while(0);A=c[m>>2]|0;if((A|0)==0){t=70}else{if((c[A+360>>2]|0)==0){t=70}}do{if((t|0)==70){if((c[j>>2]|0)!=3){break}A=QOa(a,0)|0;if((A|0)<0){yDb(c[a+4>>2]|0,16,2218320,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=A;i=d;return h|0}f=c[l>>2]|0;e=f+(A*2224|0)|0;c[m>>2]=e;c[f+(A*2224|0)+2192>>2]=3;c[f+(A*2224|0)+84>>2]=0;c[f+(A*2224|0)+88>>2]=2;if((zOa(a,e,0)|0)>=0){Y0a((c[m>>2]|0)+1496|0,2147483647,0);Y0a((c[m>>2]|0)+1496|0,2147483647,1);break}c[m>>2]=0;h=-1;i=d;return h|0}}while(0);do{if((c[k>>2]|0)!=0){l=a+952|0;AOa(a,l);t=c[k>>2]|0;if((c[t+360>>2]|0)==0){break}e=BOa(a,l,t)|0;if((e|0)<0){h=e}else{break}i=d;return h|0}}while(0);do{if((c[m>>2]|0)!=0){e=a+3176|0;AOa(a,e);t=c[m>>2]|0;if((c[t+360>>2]|0)==0){break}l=BOa(a,e,t)|0;if((l|0)<0){h=l}else{break}i=d;return h|0}}while(0);do{if((c[j>>2]|0)!=1){m=c[k>>2]|0;if((m|0)==0){yDb(0,0,2248440,(g=i,i=i+24|0,c[g>>2]=2175392,c[g+8>>2]=2184888,c[g+16>>2]=1840,g)|0);i=g;Cd();return 0}if((c[m+360>>2]|0)!=0){break}yDb(0,0,2248440,(g=i,i=i+24|0,c[g>>2]=2175392,c[g+8>>2]=2184888,c[g+16>>2]=1840,g)|0);i=g;Cd();return 0}}while(0);g=c[w>>2]|0;if((g|0)!=3){w=(g|0)==2;g=c[a+7656>>2]|0;if(w){k=a+7624|0;c[k>>2]=(c[k>>2]|0)+g}c[a+7656>>2]=g<<1;g=a+984|0;c[g>>2]=c[g>>2]<<1;g=a+3208|0;c[g>>2]=c[g>>2]<<1;g=c[a+7660>>2]|0;if(w){k=a+7628|0;c[k>>2]=(c[k>>2]|0)+g}c[a+7660>>2]=g<<1;g=a+988|0;c[g>>2]=c[g>>2]<<1;g=a+3212|0;c[g>>2]=c[g>>2]<<1;g=c[a+7664>>2]|0;if(w){k=a+7632|0;c[k>>2]=(c[k>>2]|0)+g}c[a+7664>>2]=g<<1;g=a+992|0;c[g>>2]=c[g>>2]<<1;g=a+3216|0;c[g>>2]=c[g>>2]<<1;g=c[a+7668>>2]|0;if(w){w=a+7636|0;c[w>>2]=(c[w>>2]|0)+g}c[a+7668>>2]=g<<1;g=a+996|0;c[g>>2]=c[g>>2]<<1;g=a+3220|0;c[g>>2]=c[g>>2]<<1}c[a+13740>>2]=c[b+696>>2];do{if((c[a+14004>>2]|0)==0){if((c[n>>2]|0)==2){break}if(((c[a+28>>2]|0)-1|0)>>>0<2>>>0){c[a+14384>>2]=c[a+14368>>2];c[a+14388>>2]=c[a+14372>>2];h=0;i=d;return h|0}else{c[a+14384>>2]=c[a+14352>>2];c[a+14388>>2]=c[a+14356>>2];h=0;i=d;return h|0}}}while(0);c[a+14384>>2]=c[a+14360>>2];c[a+14388>>2]=c[a+14364>>2];h=0;i=d;return h|0}function SOa(a){a=a|0;if((c[a+9816>>2]|0)==0){return}Y0a((c[a+9856>>2]|0)+1496|0,2147483647,0);return}function TOa(d,e,f,g,h,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;n=i;i=i+16|0;o=n|0;p=n+8|0;if((c[d+712>>2]|0)!=0|(e|0)==0){i=n;return}q=e+1536|0;if((c[q>>2]|0)==0){i=n;return}r=d+12|0;if((c[(c[r>>2]|0)+16>>2]&128|0)!=0){i=n;return}s=d+688|0;t=c[s>>2]|0;if((t&152|0)==0){u=t}else{t=d;v=(mGb(c[f+88>>2]|0)|0)<<24>>24;yDb(t,48,2165096,(w=i,i=i+8|0,c[w>>2]=v,w)|0);i=w;if((k|0)>0){v=(j|0)>0;x=e+1512|0;y=0;do{if(v){z=ba(y,l)|0;A=0;do{B=c[s>>2]|0;if((B&128|0)==0){C=B}else{B=a[g+(A+z)|0]|0;yDb(t,48,2158392,(w=i,i=i+8|0,c[w>>2]=(B&255)>>>0>9>>>0?9:B&255,w)|0);i=w;C=c[s>>2]|0}if((C&16|0)==0){D=C}else{yDb(t,48,2151392,(w=i,i=i+8|0,c[w>>2]=a[(c[x>>2]|0)+(A+z)|0]|0,w)|0);i=w;D=c[s>>2]|0}do{if((D&8|0)!=0){B=c[(c[q>>2]|0)+(A+z<<2)>>2]|0;do{if((B&4|0)==0){if(!((B&7|0)==0|(B&512|0)==0)){yDb(t,48,2138744,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&1|0)!=0){yDb(t,48,2132472,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&2|0)!=0){yDb(t,48,2126072,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}E=(B&256|0)!=0;G=(B&2048|0)==0;if(!(G|E^1)){yDb(t,48,2120256,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if(E){yDb(t,48,2114168,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}E=(B&1024|0)!=0;if(!(G|E^1)){yDb(t,48,2099856,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if(E){yDb(t,48,2093352,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if(!G){yDb(t,48,2088016,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&49152|0)==0){yDb(t,48,2083440,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&12288|0)==0){yDb(t,48,2077824,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}else{yDb(t,48,2072984,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}}else{yDb(t,48,2144360,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}}while(0);do{if((B&64|0)==0){if((B&16|0)!=0){yDb(t,48,2064016,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&32|0)!=0){yDb(t,48,2060152,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&15|0)==0){yDb(t,48,2044576,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}else{yDb(t,48,2055360,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}}else{yDb(t,48,2068360,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}}while(0);if((B&128|0)==0){yDb(t,48,2055360,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}else{yDb(t,48,2039512,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}}}while(0);A=A+1|0;}while((A|0)<(j|0))}yDb(t,48,2036232,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=y+1|0;}while((y|0)<(k|0))}u=c[s>>2]|0}do{if((u&24576|0)==0){if((c[d+692>>2]|0)!=0){break}i=n;return}}while(0);u=m+1|0;m=c[d+120>>2]|0;y=c[d+124>>2]|0;w=c[d+48>>2]|0;t=(w|0)==28;D=(w|0)==24;w=t|D?2:1;x=(j<<w)+((c[(c[r>>2]|0)+12>>2]|0)!=28)|0;c[h>>2]=0;_Ga(c[d+140>>2]|0,o,p);SCb(f)|0;c[f+216>>2]=0;o=f|0;h=c[o>>2]|0;r=16>>>((c[p>>2]|0)>>>0);if((k|0)<=0){i=n;return}p=(j|0)>0;C=d+692|0;d=e+1524|0;v=(r|0)>0;A=(t|D)^1;D=w-2|0;t=1<<D;z=w-1|0;G=x<<D;E=x+1<<D;D=f+32|0;H=f+4|0;I=f+36|0;J=f+8|0;K=f+40|0;L=e+1512|0;M=f+88|0;f=0;do{if(p){N=ba(f,l)|0;O=f<<4;P=f<<1;Q=O|8;R=ba(f,r)|0;S=ba(f,x)|0;T=O|4;U=0;do{V=U+N|0;a:do{if((c[C>>2]|0)!=0){if((c[d>>2]|0)==0){break}W=U<<4;X=W|8;Y=U+S|0;Z=Y<<w;_=W|4;$=Y<<1;Y=U<<1;aa=0;while(1){do{if((aa|0)==1){if((c[C>>2]&2|0)==0){ca=76;break}if((c[M>>2]|0)==3){da=0;ca=68}}else if((aa|0)==0){if((c[C>>2]&1|0)==0){ca=76;break}if((c[M>>2]|0)==2){da=0;ca=68}}else if((aa|0)==2){if((c[C>>2]&4|0)==0){break a}if((c[M>>2]|0)==3){da=1;ca=68}}else{da=0;ca=68}}while(0);if((ca|0)==76){ca=0;aa=aa+1|0;continue}do{if((ca|0)==68){ca=0;ea=c[(c[q>>2]|0)+(V<<2)>>2]|0;if((ea&12288<<(da<<1)|0)==0){break}if((ea&64|0)!=0){fa=e+1524+(da<<2)|0;ga=ba(P,x)|0;ha=ga+Y<<z;ia=c[fa>>2]|0;UOa(h,_,T,(b[ia+(ha<<2)>>1]>>u)+_|0,(b[ia+(ha<<2)+2>>1]>>u)+T|0,m,y,c[D>>2]|0);ha=W|12;ia=Y|1;ja=ga+ia<<z;ga=c[fa>>2]|0;UOa(h,ha,T,(b[ga+(ja<<2)>>1]>>u)+ha|0,(b[ga+(ja<<2)+2>>1]>>u)+T|0,m,y,c[D>>2]|0);ja=O|12;ga=ba(P|1,x)|0;ka=ga+Y<<z;la=c[fa>>2]|0;UOa(h,_,ja,(b[la+(ka<<2)>>1]>>u)+_|0,(b[la+(ka<<2)+2>>1]>>u)+ja|0,m,y,c[D>>2]|0);ka=ga+ia<<z;ia=c[fa>>2]|0;UOa(h,ha,ja,(b[ia+(ka<<2)>>1]>>u)+ha|0,(b[ia+(ka<<2)+2>>1]>>u)+ja|0,m,y,c[D>>2]|0);break}if((ea&16|0)!=0){ja=e+1524+(da<<2)|0;ka=(ba(P,x)|0)+Y<<z;ia=c[ja>>2]|0;UOa(h,X,T,(b[ia+(ka<<2)>>1]>>u)+X|0,(b[ia+(ka<<2)+2>>1]>>u<<(ea>>>7&1))+T|0,m,y,c[D>>2]|0);ka=O|12;ia=(ba(P|1,x)|0)+Y<<z;ha=c[ja>>2]|0;UOa(h,X,ka,(b[ha+(ia<<2)>>1]>>u)+X|0,(b[ha+(ia<<2)+2>>1]>>u<<((c[(c[q>>2]|0)+(V<<2)>>2]|0)>>>7&1))+ka|0,m,y,c[D>>2]|0);break}ka=e+1524+(da<<2)|0;if((ea&32|0)==0){ia=c[ka>>2]|0;UOa(h,X,Q,(b[ia+(Z<<2)>>1]>>u)+X|0,(b[ia+(Z<<2)+2>>1]>>u)+Q|0,m,y,c[D>>2]|0);break}else{ia=$<<z;ha=c[ka>>2]|0;UOa(h,_,Q,(b[ha+(ia<<2)>>1]>>u)+_|0,(b[ha+(ia<<2)+2>>1]>>u<<(ea>>>7&1))+Q|0,m,y,c[D>>2]|0);ea=W|12;ia=($|1)<<z;ha=c[ka>>2]|0;UOa(h,ea,Q,(b[ha+(ia<<2)>>1]>>u)+ea|0,(b[ha+(ia<<2)+2>>1]>>u<<((c[(c[q>>2]|0)+(V<<2)>>2]|0)>>>7&1))+Q|0,m,y,c[D>>2]|0);break}}}while(0);aa=aa+1|0;if((aa|0)>=3){break}}}}while(0);aa=c[s>>2]|0;do{if((aa&8192|0)!=0){$=(a[(c[L>>2]|0)+V|0]<<7|0)/31|0;W=gHb($,($|0)<0|0?-1:0,16843009,16843009)|0;$=F;if(!v){break}_=c[H>>2]|0;Z=U<<3;X=c[I>>2]|0;Y=c[J>>2]|0;B=c[K>>2]|0;ia=0;do{ha=ia+R|0;ea=_+((ba(X,ha)|0)+Z)|0;c[ea>>2]=W;c[ea+4>>2]=$;ea=Y+((ba(B,ha)|0)+Z)|0;c[ea>>2]=W;c[ea+4>>2]=$;ia=ia+1|0;}while((ia|0)<(r|0))}}while(0);do{if((aa&16384|0)!=0){if((c[d>>2]|0)==0){break}ia=c[(c[q>>2]|0)+(V<<2)>>2]|0;do{if((ia&4|0)==0){if(!(((ia&7|0)==0|(ia&512|0)==0)&(ia&2|0)==0)){ma=-1751672937;na=-1751672937;oa=-1448498775;pa=-1448498775;break}if((ia&1|0)!=0){ma=-1347440721;na=-1347440721;oa=-2139062144;pa=-2139062144;break}$=(ia&2304|0)==2304;if((ia&256|0)!=0){ma=$?-2139062144:-1734829928;na=$?-2139062144:-1734829928;oa=$?-2139062144:1448498774;pa=$?-2139062144:1448498774;break}$=(ia&1024|0)!=0;W=(ia&3072|0)==3072;if((ia&3072|0)!=0){ma=$?W?-2004318072:2004318071:-2139062144;na=$?W?-2004318072:2004318071:-2139062144;oa=$?1347440720:-2139062144;pa=$?1347440720:-2139062144;break}if((ia&49152|0)==0){ma=1448498774;na=1448498774;oa=1734829927;pa=1734829927;break}$=(ia&12288|0)==0;ma=$?-2139062144:1448498774;na=$?-2139062144:1448498774;oa=$?-1330597712:-1751672937;pa=$?-1330597712:-1751672937}else{ma=-1448498775;na=-1448498775;oa=1751672936;pa=1751672936}}while(0);if(v){$=c[H>>2]|0;W=U<<3;Z=c[I>>2]|0;B=c[J>>2]|0;Y=c[K>>2]|0;X=0;do{_=X+R|0;ea=$+((ba(Z,_)|0)+W)|0;c[ea>>2]=pa;c[ea+4>>2]=oa;ea=B+((ba(Y,_)|0)+W)|0;c[ea>>2]=na;c[ea+4>>2]=ma;X=X+1|0;}while((X|0)<(r|0))}X=(ia&64|0)==0;if((ia&80|0)!=0){W=c[o>>2]|0;Y=U<<4;B=ba(c[D>>2]|0,Q)|0;Z=W+(B+Y)|0;$=c[Z+4>>2]^-2139062144;c[Z>>2]=c[Z>>2]^-2139062144;c[Z+4>>2]=$;$=W+(B+(Y|8))|0;Y=c[$+4>>2]^-2139062144;c[$>>2]=c[$>>2]^-2139062144;c[$+4>>2]=Y}if((ia&96|0)!=0){Y=U<<4|8;$=0;do{B=(ba(c[D>>2]|0,$+O|0)|0)+Y|0;W=(c[o>>2]|0)+B|0;a[W]=a[W]^-128;$=$+1|0;}while(($|0)<16)}if(X|A){break}$=U<<4;Y=U<<1;ia=0;do{W=ia&1;B=W<<3|$;Z=ia>>1;ea=(Z<<3)+O|0;_=(ba(Z+P|0,x)|0)+(W|Y)<<z;W=c[d>>2]|0;Z=W+(_<<2)|0;ha=c[Z>>2]|0;ka=W+(_+t<<2)|0;ja=W+(_+G<<2)|0;if((ha|0)==(c[ka>>2]|0)){if((c[ja>>2]|0)==(c[W+(_+E<<2)>>2]|0)){qa=ha}else{ca=103}}else{ca=103}if((ca|0)==103){ca=0;ha=B|4;fa=(ba(c[D>>2]|0,ea)|0)+ha|0;ga=(c[o>>2]|0)+fa|0;a[ga]=a[ga]^-128;ga=(ba(c[D>>2]|0,ea|1)|0)+ha|0;fa=(c[o>>2]|0)+ga|0;a[fa]=a[fa]^-128;fa=(ba(c[D>>2]|0,ea|2)|0)+ha|0;ga=(c[o>>2]|0)+fa|0;a[ga]=a[ga]^-128;ga=(ba(c[D>>2]|0,ea|3)|0)+ha|0;fa=(c[o>>2]|0)+ga|0;a[fa]=a[fa]^-128;fa=(ba(c[D>>2]|0,ea|4)|0)+ha|0;ga=(c[o>>2]|0)+fa|0;a[ga]=a[ga]^-128;ga=(ba(c[D>>2]|0,ea|5)|0)+ha|0;fa=(c[o>>2]|0)+ga|0;a[fa]=a[fa]^-128;fa=(ba(c[D>>2]|0,ea|6)|0)+ha|0;ga=(c[o>>2]|0)+fa|0;a[ga]=a[ga]^-128;ga=(ba(c[D>>2]|0,ea|7)|0)+ha|0;ha=(c[o>>2]|0)+ga|0;a[ha]=a[ha]^-128;qa=c[Z>>2]|0}if((qa|0)==(c[ja>>2]|0)){if((c[ka>>2]|0)!=(c[W+(_+E<<2)>>2]|0)){ca=106}}else{ca=106}if((ca|0)==106){ca=0;_=(c[o>>2]|0)+((ba(c[D>>2]|0,ea|4)|0)+B)|0;B=c[_+4>>2]^-2139062144;c[_>>2]=c[_>>2]^-2139062144;c[_+4>>2]=B}ia=ia+1|0;}while((ia|0)<4)}}while(0);a[g+V|0]=0;U=U+1|0;}while((U|0)<(j|0))}f=f+1|0;}while((f|0)<(k|0));i=n;return}function UOa(a,b,e,f,g,h,i,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=h+100|0;if((b|0)<-100){l=-100}else{l=(k|0)<(b|0)?k:b}b=i+100|0;if((e|0)<-100){m=-100}else{m=(b|0)<(e|0)?b:e}if((f|0)<-100){n=-100}else{n=(k|0)<(f|0)?k:f}if((g|0)<-100){o=-100}else{o=(b|0)<(g|0)?b:g}g=n-l|0;b=o-m|0;if(((ba(b,b)|0)+(ba(g,g)|0)|0)<=9){gPa(a,l,m,n,o,h,i,j);return}f=b+g|0;k=b-g|0;g=(ba(f,f)|0)+(ba(k,k)|0)|0;b=g<<8;if(b>>>0<255>>>0){p=(d[1135648+(b|1)|0]|0)-1>>4}else{do{if(b>>>0<4096>>>0){q=(d[1135648+(g<<4&268435440)|0]|0)>>>2}else{if(b>>>0<16384>>>0){q=(d[1135648+(g<<2&67108860)|0]|0)>>>1;break}if(b>>>0<65536>>>0){q=d[1135648+(g&16777215)|0]|0;break}else{e=g>>>8;r=(e&65280|0)==0;s=((d[1191992+(r?e&65535:g>>>16&255)|0]|0)+(r?0:8)|0)>>>1;r=b>>>((s+2|0)>>>0);e=d[1135648+(r>>>((s+8|0)>>>0))|0]|0;gHb(r,0,c[1199552+(e<<2)>>2]|0,0)|0;q=F+(e<<s)|0;break}}}while(0);p=q-((ba(q,q)|0)>>>0>b>>>0)|0}b=f*48|0;f=p>>1;q=-f|0;g=(((b|0)>0?f:q)+b|0)/(p|0)|0;b=k*48|0;k=(((b|0)>0?f:q)+b|0)/(p|0)|0;gPa(a,l,m,g+l|0,k+m|0,h,i,j);gPa(a,l,m,l-k|0,g+m|0,h,i,j);gPa(a,l,m,n,o,h,i,j);return}function VOa(a,b,d){a=a|0;b=b|0;d=d|0;TOa(c[a+4>>2]|0,b,d,c[a+9928>>2]|0,a+13944|0,c[a+116>>2]|0,c[a+120>>2]|0,c[a+124>>2]|0,c[a+13924>>2]|0);return}function WOa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=WAb(c[d+1508>>2]|0)|0;d=a+124|0;a=c[d>>2]|0;h=a<<1|1;if((g|0)==0){j=-12;i=f;return j|0}k=g+8|0;l=c[k>>2]|0;if((l|0)<((ba(((c[b+72>>2]|0)+15|0)/16|0,a)|0)+h|0)){yDb(0,0,2248440,(a=i,i=i+24|0,c[a>>2]=2032600,c[a+8>>2]=2184888,c[a+16>>2]=2272,a)|0);i=a;Cd();return 0}c[k>>2]=l-h;l=g+4|0;c[l>>2]=(c[l>>2]|0)+h;j=GCb(b,g,c[d>>2]|0,e)|0;i=f;return j|0}function XOa(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[d+128>>2]|0;f=c[d+12496>>2]|0;g=f+1|0;h=g+e|0;i=c[d+9876>>2]|0;b[i+(h<<1)>>1]=1024;j=f+e|0;b[i+(j<<1)>>1]=1024;b[i+(g<<1)>>1]=1024;b[i+(f<<1)>>1]=1024;i=d+9912|0;TGb((c[i>>2]|0)+(f<<5)|0,0,64)|0;TGb((c[i>>2]|0)+(j<<5)|0,0,64)|0;if((c[d+14092>>2]|0)>2){i=d+9904|0;a[(c[i>>2]|0)+h|0]=0;a[(c[i>>2]|0)+j|0]=0;a[(c[i>>2]|0)+g|0]=0;a[(c[i>>2]|0)+f|0]=0}f=(ba(c[d+12480>>2]|0,c[d+124>>2]|0)|0)+(c[d+12476>>2]|0)|0;b[(c[d+9884>>2]|0)+(f<<1)>>1]=1024;b[(c[d+9880>>2]|0)+(f<<1)>>1]=1024;TGb((c[d+9916>>2]|0)+(f<<5)|0,0,32)|0;TGb((c[d+9920>>2]|0)+(f<<5)|0,0,32)|0;a[(c[d+9932>>2]|0)+f|0]=0;return}function YOa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;g=i;h=e+4|0;j=c[h>>2]|0;k=(c[j+800>>2]|0)!=0;l=c[e+12480>>2]|0;m=ba(c[e+124>>2]|0,l)|0;n=c[e+12476>>2]|0;o=m+n|0;m=(c[j+688>>2]&64|0)==0;if((c[e+28>>2]|0)==0){if(!k){if(!m){yDb(j,48,2028424,(p=i,i=i+16|0,c[p>>2]=n,c[p+8>>2]=l,p)|0);i=p;q=0;r=c[h>>2]|0;do{yDb(r,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+(d[e+11184+q|0]<<1)>>1]|0,p)|0);i=p;q=q+1|0;r=c[h>>2]|0}while((q|0)<64);yDb(r,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;r=0;q=c[h>>2]|0;do{yDb(q,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+128+(d[e+11184+r|0]<<1)>>1]|0,p)|0);i=p;r=r+1|0;q=c[h>>2]|0}while((r|0)<64);yDb(q,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=0;r=c[h>>2]|0;do{yDb(r,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+256+(d[e+11184+q|0]<<1)>>1]|0,p)|0);i=p;q=q+1|0;r=c[h>>2]|0}while((q|0)<64);yDb(r,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;r=0;q=c[h>>2]|0;do{yDb(q,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+384+(d[e+11184+r|0]<<1)>>1]|0,p)|0);i=p;r=r+1|0;q=c[h>>2]|0}while((r|0)<64);yDb(q,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=0;r=c[h>>2]|0;do{yDb(r,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+512+(d[e+11184+q|0]<<1)>>1]|0,p)|0);i=p;q=q+1|0;r=c[h>>2]|0}while((q|0)<64);yDb(r,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;r=0;q=c[h>>2]|0;do{yDb(q,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+640+(d[e+11184+r|0]<<1)>>1]|0,p)|0);i=p;r=r+1|0;q=c[h>>2]|0}while((r|0)<64);yDb(q,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}q=e+9960|0;a[(c[e+9136>>2]|0)+o|0]=c[q>>2];r=e+12488|0;if((c[r>>2]|0)==0){s=128<<c[e+14176>>2];c[e+9868>>2]=s;c[e+9864>>2]=s;c[e+9860>>2]=s}do{if((c[e+60>>2]&32768|0)==0){s=c[h>>2]|0;if((c[s+584>>2]|0)!=0){break}if((c[s+588>>2]|0)!=0){break}if((c[e+56>>2]|0)==0){break}if((c[e+20>>2]|0)==0){if((c[e+9992>>2]|0)!=3){break}}if((c[s+296>>2]|0)==2){break}i=g;return}}while(0);s=c[e+7656>>2]|0;t=c[e+7660>>2]|0;u=e+9992|0;v=c[e+56>>2]|0;do{if((c[u>>2]|0)==3){if((v|0)==0){w=(c[(c[h>>2]|0)+148>>2]|0)!=0;x=e+56|0;y=130;break}else{z=e+56|0;y=134;break}}else{A=e+56|0;if((v|0)==0){w=1;x=A;y=130}else{z=A;y=134}}}while(0);a:do{if((y|0)==130){v=(c[e+9928>>2]|0)+o|0;A=e+9924|0;do{if((c[A>>2]|0)==0){if((c[e+9816>>2]|0)==0){a[v]=1;B=e+14236|0;C=c[B>>2]|0;D=s<<C;E=(C|0)==0?s<<3:s;if(w){F=x;G=B;H=D;I=E;y=136;break a}else{J=B;K=D;L=E;break}}else{a[v]=0;E=e+14236|0;D=c[E>>2]|0;B=s<<D;C=(D|0)==0?s<<3:s;if(w){F=x;G=E;H=B;I=C;y=136;break a}else{J=E;K=B;L=C;break}}}else{c[A>>2]=0;a[v]=1;C=e+14236|0;B=c[C>>2]|0;E=s<<B;D=(B|0)==0?s<<3:s;if(w){F=x;G=C;H=E;I=D;y=136;break a}else{J=C;K=E;L=D}}}while(0);v=c[e+9956>>2]|0;M=v;N=v+(s<<4)|0;O=v+(s<<5)|0;P=x;Q=0;R=J;S=K;T=L}else if((y|0)==134){v=e+14236|0;A=c[v>>2]|0;F=z;G=v;H=s<<A;I=(A|0)==0?s<<3:s;y=136}}while(0);if((y|0)==136){M=c[e+12544>>2]|0;N=c[e+12548>>2]|0;O=c[e+12552>>2]|0;P=F;Q=1;R=G;S=H;T=I}I=(c[P>>2]|0)!=0;b:do{if((c[r>>2]|0)==0){do{if(!I){H=c[e+12452>>2]|0;do{if((c[e+12472>>2]|0)==0){y=142}else{if((c[u>>2]|0)==3){y=142;break}U=e+11460|0}}while(0);if((y|0)==142){U=e+11332|0}G=e+11736|0;F=c[G>>2]|0;if((F&1|0)==0){V=H;W=U;X=F}else{APa(e,M,N,O,0,e+952|0,U,H);V=c[e+12456>>2]|0;W=e+11396|0;X=c[G>>2]|0}if((X&2|0)==0){break}APa(e,M,N,O,1,e+3176|0,W,V)}}while(0);G=c[(c[h>>2]|0)+852>>2]|0;do{if((G|0)>7){F=c[u>>2]|0;if((F|0)==3){break b}if((G|0)<=31){break}if((F|0)!=1|(G|0)>47){break b}}}while(0);c:do{if((c[P>>2]|0)==0){do{if((c[e+14092>>2]|0)==0){G=c[e+48>>2]|0;if((G|0)==1|(G|0)==2){break}else if((G|0)!=13){break c}if((c[e+14004>>2]|0)!=0){break c}}}while(0);if((c[e+180>>2]|0)>-1){Xe[c[e+11180>>2]&4095](M,S,f|0)}if((c[e+184>>2]|0)>-1){Xe[c[e+11180>>2]&4095](M+8|0,S,f+128|0)}if((c[e+188>>2]|0)>-1){Xe[c[e+11180>>2]&4095](M+T|0,S,f+256|0)}if((c[e+192>>2]|0)>-1){Xe[c[e+11180>>2]&4095](M+(T+8)|0,S,f+384|0)}if((c[e+14220>>2]|0)!=0){if((c[e+196>>2]|0)>-1){Xe[c[e+11180>>2]&4095](N,t,f+512|0)}if(!((c[e+200>>2]|0)>-1)){break b}Xe[c[e+11180>>2]&4095](O,t,f+640|0);break b}H=c[R>>2]|0;G=t<<H;F=(H|0)==0?t<<3:t;if((c[e+196>>2]|0)>-1){Xe[c[e+11180>>2]&4095](N,G,f+512|0)}if((c[e+200>>2]|0)>-1){Xe[c[e+11180>>2]&4095](O,G,f+640|0)}if((c[e+204>>2]|0)>-1){Xe[c[e+11180>>2]&4095](N+F|0,G,f+768|0)}if((c[e+208>>2]|0)>-1){Xe[c[e+11180>>2]&4095](O+F|0,G,f+896|0)}if((c[e+14216>>2]|0)!=0){break b}if((c[e+212>>2]|0)>-1){Xe[c[e+11180>>2]&4095](N+8|0,G,f+1024|0)}if((c[e+216>>2]|0)>-1){Xe[c[e+11180>>2]&4095](O+8|0,G,f+1152|0)}H=F+8|0;if((c[e+220>>2]|0)>-1){Xe[c[e+11180>>2]&4095](N+H|0,G,f+1280|0)}if(!((c[e+224>>2]|0)>-1)){break b}Xe[c[e+11180>>2]&4095](O+H|0,G,f+1408|0);break b}}while(0);G=f|0;if((c[e+180>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,G,0,c[q>>2]|0);Xe[c[e+11180>>2]&4095](M,S,G)}G=f+128|0;if((c[e+184>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,G,1,c[q>>2]|0);Xe[c[e+11180>>2]&4095](M+8|0,S,G)}G=f+256|0;if((c[e+188>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,G,2,c[q>>2]|0);Xe[c[e+11180>>2]&4095](M+T|0,S,G)}G=f+384|0;if((c[e+192>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,G,3,c[q>>2]|0);Xe[c[e+11180>>2]&4095](M+(T+8)|0,S,G)}if((c[e+14220>>2]|0)!=0){G=f+512|0;H=e+9964|0;if((c[e+196>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,G,4,c[H>>2]|0);Xe[c[e+11180>>2]&4095](N,t,G)}G=f+640|0;if(!((c[e+200>>2]|0)>-1)){break}cf[c[e+14388>>2]&1023](e,G,5,c[H>>2]|0);Xe[c[e+11180>>2]&4095](O,t,G);break}G=S>>1;H=T>>1;F=f+512|0;z=e+9964|0;if((c[e+196>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,F,4,c[z>>2]|0);Xe[c[e+11180>>2]&4095](N,G,F)}F=f+640|0;if((c[e+200>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,F,5,c[z>>2]|0);Xe[c[e+11180>>2]&4095](O,G,F)}F=f+768|0;if((c[e+204>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,F,6,c[z>>2]|0);Xe[c[e+11180>>2]&4095](N+H|0,G,F)}F=f+896|0;if(!((c[e+208>>2]|0)>-1)){break}cf[c[e+14388>>2]&1023](e,F,7,c[z>>2]|0);Xe[c[e+11180>>2]&4095](O+H|0,G,F)}else{do{if(!I){if(!(((c[e+48>>2]|0)-1|0)>>>0<2>>>0)){break}F=e+11176|0;Xe[c[F>>2]&4095](M,S,f|0);Xe[c[F>>2]&4095](M+8|0,S,f+128|0);Xe[c[F>>2]&4095](M+T|0,S,f+256|0);Xe[c[F>>2]&4095](M+(T+8)|0,S,f+384|0);if((c[e+14220>>2]|0)!=0){Xe[c[F>>2]&4095](N,t,f+512|0);Xe[c[F>>2]&4095](O,t,f+640|0);break b}G=c[R>>2]|0;H=t<<G;z=(G|0)==0?t<<3:t;Xe[c[F>>2]&4095](N,H,f+512|0);Xe[c[F>>2]&4095](O,H,f+640|0);Xe[c[F>>2]&4095](N+z|0,H,f+768|0);Xe[c[F>>2]&4095](O+z|0,H,f+896|0);if((c[e+14216>>2]|0)!=0){break b}Xe[c[F>>2]&4095](N+8|0,H,f+1024|0);Xe[c[F>>2]&4095](O+8|0,H,f+1152|0);G=z+8|0;Xe[c[F>>2]&4095](N+G|0,H,f+1280|0);Xe[c[F>>2]&4095](O+G|0,H,f+1408|0);break b}}while(0);H=f|0;G=e+14384|0;cf[c[G>>2]&1023](e,H,0,c[q>>2]|0);F=e+11176|0;Xe[c[F>>2]&4095](M,S,H);H=f+128|0;cf[c[G>>2]&1023](e,H,1,c[q>>2]|0);Xe[c[F>>2]&4095](M+8|0,S,H);H=f+256|0;cf[c[G>>2]&1023](e,H,2,c[q>>2]|0);Xe[c[F>>2]&4095](M+T|0,S,H);H=f+384|0;cf[c[G>>2]&1023](e,H,3,c[q>>2]|0);Xe[c[F>>2]&4095](M+(T+8)|0,S,H);if((c[e+14220>>2]|0)==0){H=T>>1;z=S>>1;L=f+512|0;K=e+9964|0;cf[c[G>>2]&1023](e,L,4,c[K>>2]|0);Xe[c[F>>2]&4095](N,z,L);L=f+640|0;cf[c[G>>2]&1023](e,L,5,c[K>>2]|0);Xe[c[F>>2]&4095](O,z,L);L=f+768|0;cf[c[G>>2]&1023](e,L,6,c[K>>2]|0);Xe[c[F>>2]&4095](N+H|0,z,L);L=f+896|0;cf[c[G>>2]&1023](e,L,7,c[K>>2]|0);Xe[c[F>>2]&4095](O+H|0,z,L);break}else{L=f+512|0;z=e+9964|0;cf[c[G>>2]&1023](e,L,4,c[z>>2]|0);Xe[c[F>>2]&4095](N,t,L);L=f+640|0;cf[c[G>>2]&1023](e,L,5,c[z>>2]|0);Xe[c[F>>2]&4095](O,t,L);break}}}while(0);if(Q){i=g;return}cf[c[e+11332>>2]&1023](c[e+12544>>2]|0,M,s,16);s=e+14216|0;M=e+14220|0;cf[c[e+11332+(c[s>>2]<<4)>>2]&1023](c[e+12548>>2]|0,N,t,16>>>((c[M>>2]|0)>>>0));cf[c[e+11332+(c[s>>2]<<4)>>2]&1023](c[e+12552>>2]|0,O,t,16>>>((c[M>>2]|0)>>>0));i=g;return}if(!m){yDb(j,48,2028424,(p=i,i=i+16|0,c[p>>2]=n,c[p+8>>2]=l,p)|0);i=p;M=0;t=c[h>>2]|0;do{yDb(t,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+(d[e+11184+M|0]<<1)>>1]|0,p)|0);i=p;M=M+1|0;t=c[h>>2]|0}while((M|0)<64);yDb(t,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=0;M=c[h>>2]|0;do{yDb(M,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+128+(d[e+11184+t|0]<<1)>>1]|0,p)|0);i=p;t=t+1|0;M=c[h>>2]|0}while((t|0)<64);yDb(M,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;M=0;t=c[h>>2]|0;do{yDb(t,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+256+(d[e+11184+M|0]<<1)>>1]|0,p)|0);i=p;M=M+1|0;t=c[h>>2]|0}while((M|0)<64);yDb(t,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=0;M=c[h>>2]|0;do{yDb(M,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+384+(d[e+11184+t|0]<<1)>>1]|0,p)|0);i=p;t=t+1|0;M=c[h>>2]|0}while((t|0)<64);yDb(M,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;M=0;t=c[h>>2]|0;do{yDb(t,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+512+(d[e+11184+M|0]<<1)>>1]|0,p)|0);i=p;M=M+1|0;t=c[h>>2]|0}while((M|0)<64);yDb(t,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=0;M=c[h>>2]|0;do{yDb(M,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+640+(d[e+11184+t|0]<<1)>>1]|0,p)|0);i=p;t=t+1|0;M=c[h>>2]|0}while((t|0)<64);yDb(M,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}M=e+9960|0;a[(c[e+9136>>2]|0)+o|0]=c[M>>2];t=e+12488|0;if((c[t>>2]|0)==0){O=128<<c[e+14176>>2];c[e+9868>>2]=O;c[e+9864>>2]=O;c[e+9860>>2]=O}O=c[h>>2]|0;do{if((c[e+60>>2]&32768|0)==0){if((c[O+584>>2]|0)!=0){break}if((c[O+588>>2]|0)!=0){break}if((c[e+56>>2]|0)==0){break}if((c[e+20>>2]|0)==0){if((c[e+9992>>2]|0)!=3){break}}if((c[O+296>>2]|0)==2){break}i=g;return}}while(0);s=c[e+7656>>2]|0;N=c[e+7660>>2]|0;Q=e+9992|0;S=8>>>((c[O+800>>2]|0)>>>0);O=e+56|0;do{if((c[O>>2]|0)==0){T=(c[e+9928>>2]|0)+o|0;q=e+9924|0;if((c[q>>2]|0)!=0){c[q>>2]=0;a[T]=1;break}if((c[e+9816>>2]|0)==0){a[T]=1;break}else{a[T]=0;break}}}while(0);T=e+14236|0;q=c[T>>2]|0;R=s<<q;if((q|0)==0){Y=ba(S,s)|0}else{Y=s}s=c[e+12544>>2]|0;q=c[e+12548>>2]|0;I=c[e+12552>>2]|0;P=(c[O>>2]|0)!=0;if((c[t>>2]|0)!=0){do{if(!P){if(!(((c[e+48>>2]|0)-1|0)>>>0<2>>>0)){break}t=e+11176|0;Xe[c[t>>2]&4095](s,R,f|0);Xe[c[t>>2]&4095](s+S|0,R,f+128|0);Xe[c[t>>2]&4095](s+Y|0,R,f+256|0);Xe[c[t>>2]&4095](s+(Y+S)|0,R,f+384|0);if((c[e+14220>>2]|0)!=0){Xe[c[t>>2]&4095](q,N,f+512|0);Xe[c[t>>2]&4095](I,N,f+640|0);i=g;return}u=c[T>>2]|0;V=N<<u;if((u|0)==0){Z=ba(S,N)|0}else{Z=N}Xe[c[t>>2]&4095](q,V,f+512|0);Xe[c[t>>2]&4095](I,V,f+640|0);Xe[c[t>>2]&4095](q+Z|0,V,f+768|0);Xe[c[t>>2]&4095](I+Z|0,V,f+896|0);if((c[e+14216>>2]|0)!=0){i=g;return}Xe[c[t>>2]&4095](q+S|0,V,f+1024|0);Xe[c[t>>2]&4095](I+S|0,V,f+1152|0);u=Z+S|0;Xe[c[t>>2]&4095](q+u|0,V,f+1280|0);Xe[c[t>>2]&4095](I+u|0,V,f+1408|0);i=g;return}}while(0);Z=f|0;V=e+14384|0;cf[c[V>>2]&1023](e,Z,0,c[M>>2]|0);u=e+11176|0;Xe[c[u>>2]&4095](s,R,Z);Z=f+128|0;cf[c[V>>2]&1023](e,Z,1,c[M>>2]|0);Xe[c[u>>2]&4095](s+S|0,R,Z);Z=f+256|0;cf[c[V>>2]&1023](e,Z,2,c[M>>2]|0);Xe[c[u>>2]&4095](s+Y|0,R,Z);Z=f+384|0;cf[c[V>>2]&1023](e,Z,3,c[M>>2]|0);Xe[c[u>>2]&4095](s+(Y+S)|0,R,Z);if((c[e+14220>>2]|0)==0){Z=Y>>1;t=R>>1;W=f+512|0;X=e+9964|0;cf[c[V>>2]&1023](e,W,4,c[X>>2]|0);Xe[c[u>>2]&4095](q,t,W);W=f+640|0;cf[c[V>>2]&1023](e,W,5,c[X>>2]|0);Xe[c[u>>2]&4095](I,t,W);W=f+768|0;cf[c[V>>2]&1023](e,W,6,c[X>>2]|0);Xe[c[u>>2]&4095](q+Z|0,t,W);W=f+896|0;cf[c[V>>2]&1023](e,W,7,c[X>>2]|0);Xe[c[u>>2]&4095](I+Z|0,t,W);i=g;return}else{W=f+512|0;t=e+9964|0;cf[c[V>>2]&1023](e,W,4,c[t>>2]|0);Xe[c[u>>2]&4095](q,N,W);W=f+640|0;cf[c[V>>2]&1023](e,W,5,c[t>>2]|0);Xe[c[u>>2]&4095](I,N,W);i=g;return}}do{if(!P){W=e+11300|0;u=e+11736|0;t=c[u>>2]|0;if((t&1|0)==0){_=W;$=t}else{fPa(e,s,q,I,0,e+952|0,W);_=e+11316|0;$=c[u>>2]|0}if(($&2|0)==0){break}fPa(e,s,q,I,1,e+3176|0,_)}}while(0);_=c[(c[h>>2]|0)+852>>2]|0;do{if((_|0)>7){$=c[Q>>2]|0;if(($|0)==3){i=g;return}if((_|0)<=31){break}if(!(($|0)!=1|(_|0)>47)){break}i=g;return}}while(0);d:do{if((c[O>>2]|0)==0){do{if((c[e+14092>>2]|0)==0){_=c[e+48>>2]|0;if((_|0)==1|(_|0)==2){break}else if((_|0)!=13){break d}if((c[e+14004>>2]|0)!=0){break d}}}while(0);if((c[e+180>>2]|0)>-1){Xe[c[e+11180>>2]&4095](s,R,f|0)}if((c[e+184>>2]|0)>-1){Xe[c[e+11180>>2]&4095](s+S|0,R,f+128|0)}if((c[e+188>>2]|0)>-1){Xe[c[e+11180>>2]&4095](s+Y|0,R,f+256|0)}if((c[e+192>>2]|0)>-1){Xe[c[e+11180>>2]&4095](s+(Y+S)|0,R,f+384|0)}if((c[e+14220>>2]|0)!=0){if((c[e+196>>2]|0)>-1){Xe[c[e+11180>>2]&4095](q,N,f+512|0)}if(!((c[e+200>>2]|0)>-1)){i=g;return}Xe[c[e+11180>>2]&4095](I,N,f+640|0);i=g;return}_=c[T>>2]|0;Q=N<<_;if((_|0)==0){aa=ba(S,N)|0}else{aa=N}if((c[e+196>>2]|0)>-1){Xe[c[e+11180>>2]&4095](q,Q,f+512|0)}if((c[e+200>>2]|0)>-1){Xe[c[e+11180>>2]&4095](I,Q,f+640|0)}if((c[e+204>>2]|0)>-1){Xe[c[e+11180>>2]&4095](q+aa|0,Q,f+768|0)}if((c[e+208>>2]|0)>-1){Xe[c[e+11180>>2]&4095](I+aa|0,Q,f+896|0)}if((c[e+14216>>2]|0)!=0){i=g;return}if((c[e+212>>2]|0)>-1){Xe[c[e+11180>>2]&4095](q+S|0,Q,f+1024|0)}if((c[e+216>>2]|0)>-1){Xe[c[e+11180>>2]&4095](I+S|0,Q,f+1152|0)}_=aa+S|0;if((c[e+220>>2]|0)>-1){Xe[c[e+11180>>2]&4095](q+_|0,Q,f+1280|0)}if(!((c[e+224>>2]|0)>-1)){i=g;return}Xe[c[e+11180>>2]&4095](I+_|0,Q,f+1408|0);i=g;return}}while(0);aa=f|0;if((c[e+180>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,aa,0,c[M>>2]|0);Xe[c[e+11180>>2]&4095](s,R,aa)}aa=f+128|0;if((c[e+184>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,aa,1,c[M>>2]|0);Xe[c[e+11180>>2]&4095](s+S|0,R,aa)}aa=f+256|0;if((c[e+188>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,aa,2,c[M>>2]|0);Xe[c[e+11180>>2]&4095](s+Y|0,R,aa)}aa=f+384|0;if((c[e+192>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,aa,3,c[M>>2]|0);Xe[c[e+11180>>2]&4095](s+(Y+S)|0,R,aa)}if((c[e+14220>>2]|0)!=0){aa=f+512|0;S=e+9964|0;if((c[e+196>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,aa,4,c[S>>2]|0);Xe[c[e+11180>>2]&4095](q,N,aa)}aa=f+640|0;if(!((c[e+200>>2]|0)>-1)){i=g;return}cf[c[e+14388>>2]&1023](e,aa,5,c[S>>2]|0);Xe[c[e+11180>>2]&4095](I,N,aa);i=g;return}aa=R>>1;R=Y>>1;Y=f+512|0;N=e+9964|0;if((c[e+196>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,Y,4,c[N>>2]|0);Xe[c[e+11180>>2]&4095](q,aa,Y)}Y=f+640|0;if((c[e+200>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,Y,5,c[N>>2]|0);Xe[c[e+11180>>2]&4095](I,aa,Y)}Y=f+768|0;if((c[e+204>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,Y,6,c[N>>2]|0);Xe[c[e+11180>>2]&4095](q+R|0,aa,Y)}Y=f+896|0;if(!((c[e+208>>2]|0)>-1)){i=g;return}cf[c[e+14388>>2]&1023](e,Y,7,c[N>>2]|0);Xe[c[e+11180>>2]&4095](I+R|0,aa,Y);i=g;return}if(!k){if(!m){yDb(j,48,2028424,(p=i,i=i+16|0,c[p>>2]=n,c[p+8>>2]=l,p)|0);i=p;k=0;Y=c[h>>2]|0;do{yDb(Y,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+(d[e+11184+k|0]<<1)>>1]|0,p)|0);i=p;k=k+1|0;Y=c[h>>2]|0}while((k|0)<64);yDb(Y,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Y=0;k=c[h>>2]|0;do{yDb(k,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+128+(d[e+11184+Y|0]<<1)>>1]|0,p)|0);i=p;Y=Y+1|0;k=c[h>>2]|0}while((Y|0)<64);yDb(k,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=0;Y=c[h>>2]|0;do{yDb(Y,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+256+(d[e+11184+k|0]<<1)>>1]|0,p)|0);i=p;k=k+1|0;Y=c[h>>2]|0}while((k|0)<64);yDb(Y,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Y=0;k=c[h>>2]|0;do{yDb(k,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+384+(d[e+11184+Y|0]<<1)>>1]|0,p)|0);i=p;Y=Y+1|0;k=c[h>>2]|0}while((Y|0)<64);yDb(k,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=0;Y=c[h>>2]|0;do{yDb(Y,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+512+(d[e+11184+k|0]<<1)>>1]|0,p)|0);i=p;k=k+1|0;Y=c[h>>2]|0}while((k|0)<64);yDb(Y,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Y=0;k=c[h>>2]|0;do{yDb(k,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+640+(d[e+11184+Y|0]<<1)>>1]|0,p)|0);i=p;Y=Y+1|0;k=c[h>>2]|0}while((Y|0)<64);yDb(k,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}k=e+9960|0;a[(c[e+9136>>2]|0)+o|0]=c[k>>2];Y=e+12488|0;aa=(c[e+32>>2]|0)==0;e:do{if((c[Y>>2]|0)==0){do{if(aa){if((c[e+228>>2]|0)!=0){break}R=128<<c[e+14176>>2];c[e+9868>>2]=R;c[e+9864>>2]=R;c[e+9860>>2]=R;break e}}while(0);if((a[(c[e+9932>>2]|0)+o|0]|0)==0){break}XOa(e)}else{if(aa){if((c[e+228>>2]|0)==0){break}}a[(c[e+9932>>2]|0)+o|0]=1}}while(0);do{if((c[e+60>>2]&32768|0)==0){aa=c[h>>2]|0;if((c[aa+584>>2]|0)!=0){break}if((c[aa+588>>2]|0)!=0){break}if((c[e+56>>2]|0)==0){break}if((c[e+20>>2]|0)==0){if((c[e+9992>>2]|0)!=3){break}}if((c[aa+296>>2]|0)==2){break}i=g;return}}while(0);aa=c[e+7656>>2]|0;R=c[e+7660>>2]|0;I=e+9992|0;N=c[e+56>>2]|0;do{if((c[I>>2]|0)==3){if((N|0)==0){ca=(c[(c[h>>2]|0)+148>>2]|0)!=0;da=e+56|0;y=372;break}else{ea=e+56|0;y=376;break}}else{q=e+56|0;if((N|0)==0){ca=1;da=q;y=372}else{ea=q;y=376}}}while(0);f:do{if((y|0)==372){N=(c[e+9928>>2]|0)+o|0;q=e+9924|0;do{if((c[q>>2]|0)==0){if((c[e+9816>>2]|0)==0){a[N]=1;S=e+14236|0;s=c[S>>2]|0;M=aa<<s;T=(s|0)==0?aa<<3:aa;if(ca){fa=da;ga=S;ha=M;ia=T;y=378;break f}else{ja=S;ka=M;la=T;break}}else{a[N]=0;T=e+14236|0;M=c[T>>2]|0;S=aa<<M;s=(M|0)==0?aa<<3:aa;if(ca){fa=da;ga=T;ha=S;ia=s;y=378;break f}else{ja=T;ka=S;la=s;break}}}else{c[q>>2]=0;a[N]=1;s=e+14236|0;S=c[s>>2]|0;T=aa<<S;M=(S|0)==0?aa<<3:aa;if(ca){fa=da;ga=s;ha=T;ia=M;y=378;break f}else{ja=s;ka=T;la=M}}}while(0);N=c[e+9956>>2]|0;ma=N;na=N+(aa<<4)|0;oa=N+(aa<<5)|0;pa=da;qa=0;ra=ja;sa=ka;ta=la}else if((y|0)==376){N=e+14236|0;q=c[N>>2]|0;fa=ea;ga=N;ha=aa<<q;ia=(q|0)==0?aa<<3:aa;y=378}}while(0);if((y|0)==378){ma=c[e+12544>>2]|0;na=c[e+12548>>2]|0;oa=c[e+12552>>2]|0;pa=fa;qa=1;ra=ga;sa=ha;ta=ia}ia=(c[pa>>2]|0)!=0;g:do{if((c[Y>>2]|0)==0){do{if(!ia){ha=c[e+12452>>2]|0;do{if((c[e+12472>>2]|0)==0){y=384}else{if((c[I>>2]|0)==3){y=384;break}ua=e+11460|0}}while(0);if((y|0)==384){ua=e+11332|0}ga=e+11736|0;fa=c[ga>>2]|0;if((fa&1|0)==0){va=ha;wa=ua;xa=fa}else{APa(e,ma,na,oa,0,e+952|0,ua,ha);va=c[e+12456>>2]|0;wa=e+11396|0;xa=c[ga>>2]|0}if((xa&2|0)==0){break}APa(e,ma,na,oa,1,e+3176|0,wa,va)}}while(0);ga=c[(c[h>>2]|0)+852>>2]|0;do{if((ga|0)>7){fa=c[I>>2]|0;if((fa|0)==3){break g}if((ga|0)<=31){break}if((fa|0)!=1|(ga|0)>47){break g}}}while(0);h:do{if((c[pa>>2]|0)==0){ga=c[e+48>>2]|0;do{if((c[e+14092>>2]|0)==0){if((ga|0)==1|(ga|0)==2){break}else if((ga|0)!=13){break h}if((c[e+14004>>2]|0)!=0){break h}}else{if((ga|0)!=19){break}Scb(e,f,ma,na,oa);break g}}while(0);if((c[e+180>>2]|0)>-1){Xe[c[e+11180>>2]&4095](ma,sa,f|0)}if((c[e+184>>2]|0)>-1){Xe[c[e+11180>>2]&4095](ma+8|0,sa,f+128|0)}if((c[e+188>>2]|0)>-1){Xe[c[e+11180>>2]&4095](ma+ta|0,sa,f+256|0)}if((c[e+192>>2]|0)>-1){Xe[c[e+11180>>2]&4095](ma+(ta+8)|0,sa,f+384|0)}if((c[e+14220>>2]|0)!=0){if((c[e+196>>2]|0)>-1){Xe[c[e+11180>>2]&4095](na,R,f+512|0)}if(!((c[e+200>>2]|0)>-1)){break g}Xe[c[e+11180>>2]&4095](oa,R,f+640|0);break g}ga=c[ra>>2]|0;ha=R<<ga;fa=(ga|0)==0?R<<3:R;if((c[e+196>>2]|0)>-1){Xe[c[e+11180>>2]&4095](na,ha,f+512|0)}if((c[e+200>>2]|0)>-1){Xe[c[e+11180>>2]&4095](oa,ha,f+640|0)}if((c[e+204>>2]|0)>-1){Xe[c[e+11180>>2]&4095](na+fa|0,ha,f+768|0)}if((c[e+208>>2]|0)>-1){Xe[c[e+11180>>2]&4095](oa+fa|0,ha,f+896|0)}if((c[e+14216>>2]|0)!=0){break g}if((c[e+212>>2]|0)>-1){Xe[c[e+11180>>2]&4095](na+8|0,ha,f+1024|0)}if((c[e+216>>2]|0)>-1){Xe[c[e+11180>>2]&4095](oa+8|0,ha,f+1152|0)}ga=fa+8|0;if((c[e+220>>2]|0)>-1){Xe[c[e+11180>>2]&4095](na+ga|0,ha,f+1280|0)}if(!((c[e+224>>2]|0)>-1)){break g}Xe[c[e+11180>>2]&4095](oa+ga|0,ha,f+1408|0);break g}}while(0);ha=f|0;if((c[e+180>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,ha,0,c[k>>2]|0);Xe[c[e+11180>>2]&4095](ma,sa,ha)}ha=f+128|0;if((c[e+184>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,ha,1,c[k>>2]|0);Xe[c[e+11180>>2]&4095](ma+8|0,sa,ha)}ha=f+256|0;if((c[e+188>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,ha,2,c[k>>2]|0);Xe[c[e+11180>>2]&4095](ma+ta|0,sa,ha)}ha=f+384|0;if((c[e+192>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,ha,3,c[k>>2]|0);Xe[c[e+11180>>2]&4095](ma+(ta+8)|0,sa,ha)}if((c[e+14220>>2]|0)!=0){ha=f+512|0;ga=e+9964|0;if((c[e+196>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,ha,4,c[ga>>2]|0);Xe[c[e+11180>>2]&4095](na,R,ha)}ha=f+640|0;if(!((c[e+200>>2]|0)>-1)){break}cf[c[e+14388>>2]&1023](e,ha,5,c[ga>>2]|0);Xe[c[e+11180>>2]&4095](oa,R,ha);break}ha=sa>>1;ga=ta>>1;fa=f+512|0;ea=e+9964|0;if((c[e+196>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,fa,4,c[ea>>2]|0);Xe[c[e+11180>>2]&4095](na,ha,fa)}fa=f+640|0;if((c[e+200>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,fa,5,c[ea>>2]|0);Xe[c[e+11180>>2]&4095](oa,ha,fa)}fa=f+768|0;if((c[e+204>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,fa,6,c[ea>>2]|0);Xe[c[e+11180>>2]&4095](na+ga|0,ha,fa)}fa=f+896|0;if(!((c[e+208>>2]|0)>-1)){break}cf[c[e+14388>>2]&1023](e,fa,7,c[ea>>2]|0);Xe[c[e+11180>>2]&4095](oa+ga|0,ha,fa)}else{do{if(!ia){if(!(((c[e+48>>2]|0)-1|0)>>>0<2>>>0)){break}fa=e+11176|0;Xe[c[fa>>2]&4095](ma,sa,f|0);Xe[c[fa>>2]&4095](ma+8|0,sa,f+128|0);Xe[c[fa>>2]&4095](ma+ta|0,sa,f+256|0);Xe[c[fa>>2]&4095](ma+(ta+8)|0,sa,f+384|0);if((c[e+14220>>2]|0)!=0){Xe[c[fa>>2]&4095](na,R,f+512|0);Xe[c[fa>>2]&4095](oa,R,f+640|0);break g}ha=c[ra>>2]|0;ga=R<<ha;ea=(ha|0)==0?R<<3:R;Xe[c[fa>>2]&4095](na,ga,f+512|0);Xe[c[fa>>2]&4095](oa,ga,f+640|0);Xe[c[fa>>2]&4095](na+ea|0,ga,f+768|0);Xe[c[fa>>2]&4095](oa+ea|0,ga,f+896|0);if((c[e+14216>>2]|0)!=0){break g}Xe[c[fa>>2]&4095](na+8|0,ga,f+1024|0);Xe[c[fa>>2]&4095](oa+8|0,ga,f+1152|0);ha=ea+8|0;Xe[c[fa>>2]&4095](na+ha|0,ga,f+1280|0);Xe[c[fa>>2]&4095](oa+ha|0,ga,f+1408|0);break g}}while(0);ga=f|0;ha=e+14384|0;cf[c[ha>>2]&1023](e,ga,0,c[k>>2]|0);fa=e+11176|0;Xe[c[fa>>2]&4095](ma,sa,ga);ga=f+128|0;cf[c[ha>>2]&1023](e,ga,1,c[k>>2]|0);Xe[c[fa>>2]&4095](ma+8|0,sa,ga);ga=f+256|0;cf[c[ha>>2]&1023](e,ga,2,c[k>>2]|0);Xe[c[fa>>2]&4095](ma+ta|0,sa,ga);ga=f+384|0;cf[c[ha>>2]&1023](e,ga,3,c[k>>2]|0);Xe[c[fa>>2]&4095](ma+(ta+8)|0,sa,ga);if((c[e+14220>>2]|0)==0){ga=ta>>1;ea=sa>>1;la=f+512|0;ka=e+9964|0;cf[c[ha>>2]&1023](e,la,4,c[ka>>2]|0);Xe[c[fa>>2]&4095](na,ea,la);la=f+640|0;cf[c[ha>>2]&1023](e,la,5,c[ka>>2]|0);Xe[c[fa>>2]&4095](oa,ea,la);la=f+768|0;cf[c[ha>>2]&1023](e,la,6,c[ka>>2]|0);Xe[c[fa>>2]&4095](na+ga|0,ea,la);la=f+896|0;cf[c[ha>>2]&1023](e,la,7,c[ka>>2]|0);Xe[c[fa>>2]&4095](oa+ga|0,ea,la);break}else{la=f+512|0;ea=e+9964|0;cf[c[ha>>2]&1023](e,la,4,c[ea>>2]|0);Xe[c[fa>>2]&4095](na,R,la);la=f+640|0;cf[c[ha>>2]&1023](e,la,5,c[ea>>2]|0);Xe[c[fa>>2]&4095](oa,R,la);break}}}while(0);if(qa){i=g;return}cf[c[e+11332>>2]&1023](c[e+12544>>2]|0,ma,aa,16);aa=e+14216|0;ma=e+14220|0;cf[c[e+11332+(c[aa>>2]<<4)>>2]&1023](c[e+12548>>2]|0,na,R,16>>>((c[ma>>2]|0)>>>0));cf[c[e+11332+(c[aa>>2]<<4)>>2]&1023](c[e+12552>>2]|0,oa,R,16>>>((c[ma>>2]|0)>>>0));i=g;return}if(!m){yDb(j,48,2028424,(p=i,i=i+16|0,c[p>>2]=n,c[p+8>>2]=l,p)|0);i=p;l=0;n=c[h>>2]|0;do{yDb(n,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+(d[e+11184+l|0]<<1)>>1]|0,p)|0);i=p;l=l+1|0;n=c[h>>2]|0}while((l|0)<64);yDb(n,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=0;l=c[h>>2]|0;do{yDb(l,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+128+(d[e+11184+n|0]<<1)>>1]|0,p)|0);i=p;n=n+1|0;l=c[h>>2]|0}while((n|0)<64);yDb(l,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;l=0;n=c[h>>2]|0;do{yDb(n,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+256+(d[e+11184+l|0]<<1)>>1]|0,p)|0);i=p;l=l+1|0;n=c[h>>2]|0}while((l|0)<64);yDb(n,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=0;l=c[h>>2]|0;do{yDb(l,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+384+(d[e+11184+n|0]<<1)>>1]|0,p)|0);i=p;n=n+1|0;l=c[h>>2]|0}while((n|0)<64);yDb(l,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;l=0;n=c[h>>2]|0;do{yDb(n,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+512+(d[e+11184+l|0]<<1)>>1]|0,p)|0);i=p;l=l+1|0;n=c[h>>2]|0}while((l|0)<64);yDb(n,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=0;l=c[h>>2]|0;do{yDb(l,48,2024824,(p=i,i=i+8|0,c[p>>2]=b[f+640+(d[e+11184+n|0]<<1)>>1]|0,p)|0);i=p;n=n+1|0;l=c[h>>2]|0}while((n|0)<64);yDb(l,48,2036232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}p=e+9960|0;a[(c[e+9136>>2]|0)+o|0]=c[p>>2];l=e+12488|0;n=(c[e+32>>2]|0)==0;i:do{if((c[l>>2]|0)==0){do{if(n){if((c[e+228>>2]|0)!=0){break}j=128<<c[e+14176>>2];c[e+9868>>2]=j;c[e+9864>>2]=j;c[e+9860>>2]=j;break i}}while(0);if((a[(c[e+9932>>2]|0)+o|0]|0)==0){break}XOa(e)}else{if(n){if((c[e+228>>2]|0)==0){break}}a[(c[e+9932>>2]|0)+o|0]=1}}while(0);n=c[h>>2]|0;do{if((c[e+60>>2]&32768|0)==0){if((c[n+584>>2]|0)!=0){break}if((c[n+588>>2]|0)!=0){break}if((c[e+56>>2]|0)==0){break}if((c[e+20>>2]|0)==0){if((c[e+9992>>2]|0)!=3){break}}if((c[n+296>>2]|0)==2){break}i=g;return}}while(0);j=c[e+7656>>2]|0;m=c[e+7660>>2]|0;ma=e+9992|0;R=8>>>((c[n+800>>2]|0)>>>0);n=e+56|0;do{if((c[n>>2]|0)==0){oa=(c[e+9928>>2]|0)+o|0;aa=e+9924|0;if((c[aa>>2]|0)!=0){c[aa>>2]=0;a[oa]=1;break}if((c[e+9816>>2]|0)==0){a[oa]=1;break}else{a[oa]=0;break}}}while(0);o=e+14236|0;oa=c[o>>2]|0;aa=j<<oa;if((oa|0)==0){ya=ba(R,j)|0}else{ya=j}j=c[e+12544>>2]|0;oa=c[e+12548>>2]|0;na=c[e+12552>>2]|0;qa=(c[n>>2]|0)!=0;if((c[l>>2]|0)!=0){do{if(!qa){if(!(((c[e+48>>2]|0)-1|0)>>>0<2>>>0)){break}l=e+11176|0;Xe[c[l>>2]&4095](j,aa,f|0);Xe[c[l>>2]&4095](j+R|0,aa,f+128|0);Xe[c[l>>2]&4095](j+ya|0,aa,f+256|0);Xe[c[l>>2]&4095](j+(ya+R)|0,aa,f+384|0);if((c[e+14220>>2]|0)!=0){Xe[c[l>>2]&4095](oa,m,f+512|0);Xe[c[l>>2]&4095](na,m,f+640|0);i=g;return}sa=c[o>>2]|0;ta=m<<sa;if((sa|0)==0){za=ba(R,m)|0}else{za=m}Xe[c[l>>2]&4095](oa,ta,f+512|0);Xe[c[l>>2]&4095](na,ta,f+640|0);Xe[c[l>>2]&4095](oa+za|0,ta,f+768|0);Xe[c[l>>2]&4095](na+za|0,ta,f+896|0);if((c[e+14216>>2]|0)!=0){i=g;return}Xe[c[l>>2]&4095](oa+R|0,ta,f+1024|0);Xe[c[l>>2]&4095](na+R|0,ta,f+1152|0);sa=za+R|0;Xe[c[l>>2]&4095](oa+sa|0,ta,f+1280|0);Xe[c[l>>2]&4095](na+sa|0,ta,f+1408|0);i=g;return}}while(0);za=f|0;ta=e+14384|0;cf[c[ta>>2]&1023](e,za,0,c[p>>2]|0);sa=e+11176|0;Xe[c[sa>>2]&4095](j,aa,za);za=f+128|0;cf[c[ta>>2]&1023](e,za,1,c[p>>2]|0);Xe[c[sa>>2]&4095](j+R|0,aa,za);za=f+256|0;cf[c[ta>>2]&1023](e,za,2,c[p>>2]|0);Xe[c[sa>>2]&4095](j+ya|0,aa,za);za=f+384|0;cf[c[ta>>2]&1023](e,za,3,c[p>>2]|0);Xe[c[sa>>2]&4095](j+(ya+R)|0,aa,za);if((c[e+14220>>2]|0)==0){za=ya>>1;l=aa>>1;k=f+512|0;ra=e+9964|0;cf[c[ta>>2]&1023](e,k,4,c[ra>>2]|0);Xe[c[sa>>2]&4095](oa,l,k);k=f+640|0;cf[c[ta>>2]&1023](e,k,5,c[ra>>2]|0);Xe[c[sa>>2]&4095](na,l,k);k=f+768|0;cf[c[ta>>2]&1023](e,k,6,c[ra>>2]|0);Xe[c[sa>>2]&4095](oa+za|0,l,k);k=f+896|0;cf[c[ta>>2]&1023](e,k,7,c[ra>>2]|0);Xe[c[sa>>2]&4095](na+za|0,l,k);i=g;return}else{k=f+512|0;l=e+9964|0;cf[c[ta>>2]&1023](e,k,4,c[l>>2]|0);Xe[c[sa>>2]&4095](oa,m,k);k=f+640|0;cf[c[ta>>2]&1023](e,k,5,c[l>>2]|0);Xe[c[sa>>2]&4095](na,m,k);i=g;return}}do{if(!qa){k=e+11300|0;sa=e+11736|0;l=c[sa>>2]|0;if((l&1|0)==0){Aa=k;Ba=l}else{fPa(e,j,oa,na,0,e+952|0,k);Aa=e+11316|0;Ba=c[sa>>2]|0}if((Ba&2|0)==0){break}fPa(e,j,oa,na,1,e+3176|0,Aa)}}while(0);Aa=c[(c[h>>2]|0)+852>>2]|0;do{if((Aa|0)>7){h=c[ma>>2]|0;if((h|0)==3){i=g;return}if((Aa|0)<=31){break}if(!((h|0)!=1|(Aa|0)>47)){break}i=g;return}}while(0);j:do{if((c[n>>2]|0)==0){Aa=c[e+48>>2]|0;do{if((c[e+14092>>2]|0)==0){if((Aa|0)==1|(Aa|0)==2){break}else if((Aa|0)!=13){break j}if((c[e+14004>>2]|0)!=0){break j}}else{if((Aa|0)!=19){break}Scb(e,f,j,oa,na);i=g;return}}while(0);if((c[e+180>>2]|0)>-1){Xe[c[e+11180>>2]&4095](j,aa,f|0)}if((c[e+184>>2]|0)>-1){Xe[c[e+11180>>2]&4095](j+R|0,aa,f+128|0)}if((c[e+188>>2]|0)>-1){Xe[c[e+11180>>2]&4095](j+ya|0,aa,f+256|0)}if((c[e+192>>2]|0)>-1){Xe[c[e+11180>>2]&4095](j+(ya+R)|0,aa,f+384|0)}if((c[e+14220>>2]|0)!=0){if((c[e+196>>2]|0)>-1){Xe[c[e+11180>>2]&4095](oa,m,f+512|0)}if(!((c[e+200>>2]|0)>-1)){i=g;return}Xe[c[e+11180>>2]&4095](na,m,f+640|0);i=g;return}Aa=c[o>>2]|0;ma=m<<Aa;if((Aa|0)==0){Ca=ba(R,m)|0}else{Ca=m}if((c[e+196>>2]|0)>-1){Xe[c[e+11180>>2]&4095](oa,ma,f+512|0)}if((c[e+200>>2]|0)>-1){Xe[c[e+11180>>2]&4095](na,ma,f+640|0)}if((c[e+204>>2]|0)>-1){Xe[c[e+11180>>2]&4095](oa+Ca|0,ma,f+768|0)}if((c[e+208>>2]|0)>-1){Xe[c[e+11180>>2]&4095](na+Ca|0,ma,f+896|0)}if((c[e+14216>>2]|0)!=0){i=g;return}if((c[e+212>>2]|0)>-1){Xe[c[e+11180>>2]&4095](oa+R|0,ma,f+1024|0)}if((c[e+216>>2]|0)>-1){Xe[c[e+11180>>2]&4095](na+R|0,ma,f+1152|0)}Aa=Ca+R|0;if((c[e+220>>2]|0)>-1){Xe[c[e+11180>>2]&4095](oa+Aa|0,ma,f+1280|0)}if(!((c[e+224>>2]|0)>-1)){i=g;return}Xe[c[e+11180>>2]&4095](na+Aa|0,ma,f+1408|0);i=g;return}}while(0);Ca=f|0;if((c[e+180>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,Ca,0,c[p>>2]|0);Xe[c[e+11180>>2]&4095](j,aa,Ca)}Ca=f+128|0;if((c[e+184>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,Ca,1,c[p>>2]|0);Xe[c[e+11180>>2]&4095](j+R|0,aa,Ca)}Ca=f+256|0;if((c[e+188>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,Ca,2,c[p>>2]|0);Xe[c[e+11180>>2]&4095](j+ya|0,aa,Ca)}Ca=f+384|0;if((c[e+192>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,Ca,3,c[p>>2]|0);Xe[c[e+11180>>2]&4095](j+(ya+R)|0,aa,Ca)}if((c[e+14220>>2]|0)!=0){Ca=f+512|0;R=e+9964|0;if((c[e+196>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,Ca,4,c[R>>2]|0);Xe[c[e+11180>>2]&4095](oa,m,Ca)}Ca=f+640|0;if(!((c[e+200>>2]|0)>-1)){i=g;return}cf[c[e+14388>>2]&1023](e,Ca,5,c[R>>2]|0);Xe[c[e+11180>>2]&4095](na,m,Ca);i=g;return}Ca=aa>>1;aa=ya>>1;ya=f+512|0;m=e+9964|0;if((c[e+196>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,ya,4,c[m>>2]|0);Xe[c[e+11180>>2]&4095](oa,Ca,ya)}ya=f+640|0;if((c[e+200>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,ya,5,c[m>>2]|0);Xe[c[e+11180>>2]&4095](na,Ca,ya)}ya=f+768|0;if((c[e+204>>2]|0)>-1){cf[c[e+14388>>2]&1023](e,ya,6,c[m>>2]|0);Xe[c[e+11180>>2]&4095](oa+aa|0,Ca,ya)}ya=f+896|0;if(!((c[e+208>>2]|0)>-1)){i=g;return}cf[c[e+14388>>2]&1023](e,ya,7,c[m>>2]|0);Xe[c[e+11180>>2]&4095](na+aa|0,Ca,ya);i=g;return}function ZOa(a,b,e,f,g,h,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=i;i=i+32|0;m=l|0;n=m;o=d[(bFb(c[a+140>>2]|0)|0)+6|0]|0;p=(h|0)!=3;if(p){q=f<<1;r=g<<1}else{q=f;r=g}g=(c[a+124>>2]|0)-q|0;f=(r|0)>(g|0)?g:r;do{if(!((j|0)==0|p^1)){if((c[a+288>>2]&2|0)!=0){break}i=l;return}}while(0);p=c[a+148>>2]|0;if((p|0)==0){i=l;return}j=c[b+88>>2]|0;do{if((j|0)!=3&(k|0)==0){if((c[a+288>>2]&1|0)!=0){s=b;break}if((e|0)!=0){s=e;break}i=l;return}else{s=b}}while(0);b=s|0;do{if((j|0)==3&(h|0)==3){if((c[a+48>>2]|0)==24){t=12;break}TGb(n|0,0,32)|0;u=m|0}else{t=12}}while(0);if((t|0)==12){t=m|0;c[t>>2]=ba(c[s+32>>2]|0,q)|0;n=ba(c[s+36>>2]|0,q>>o)|0;c[m+8>>2]=n;c[m+4>>2]=n;TGb(m+12|0,0,20)|0;u=t}Se[p&511](a,b,u,q,h,f);i=l;return}function _Oa(a,b,d){a=a|0;b=b|0;d=d|0;ZOa(c[a+4>>2]|0,c[a+9856>>2]|0,c[a+9848>>2]|0,b,d,c[a+14172>>2]|0,c[a+14240>>2]|0,c[a+13944>>2]|0);return}function $Oa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[a+7656>>2]|0;d=c[a+7660>>2]|0;e=c[a+4>>2]|0;f=4-(c[e+800>>2]|0)|0;g=c[a+128>>2]|0;h=c[a+12480>>2]|0;i=ba(h,g)|0;j=c[a+12476>>2]|0;k=j+i<<1;c[a+12496>>2]=k-2;c[a+12500>>2]=k-1;k=ba(h<<1|1,g)|0;i=j<<1;c[a+12504>>2]=i-2+k;c[a+12508>>2]=i-1+k;k=c[a+124>>2]|0;i=ba(h+1|0,k)|0;l=c[a+120>>2]|0;c[a+12512>>2]=i-1+(ba(g<<1,l)|0)+j;c[a+12516>>2]=(ba(l<<1,g)|0)-1+(ba(h+2+l|0,k)|0)+j;k=c[a+7624>>2]|0;l=j-1|0;j=l<<f;g=a+12544|0;c[g>>2]=k+j;i=c[a+7628>>2]|0;m=l<<f-(c[a+14216>>2]|0);l=a+12548|0;c[l>>2]=i+m;n=c[a+7632>>2]|0;o=a+12552|0;c[o>>2]=n+m;do{if((c[a+9992>>2]|0)==3){if((c[e+148>>2]|0)==0){break}if((c[a+14172>>2]|0)!=3){break}return}}while(0);if((c[a+14172>>2]|0)==3){c[g>>2]=k+(j+((ba(h,b)|0)<<f));e=ba(h,d)|0;p=e<<f-(c[a+14220>>2]|0);c[l>>2]=i+(m+p);c[o>>2]=n+(m+p);return}else{p=h>>1;c[g>>2]=k+(j+((ba(p,b)|0)<<f));b=ba(p,d)|0;d=b<<f-(c[a+14220>>2]|0);c[l>>2]=i+(m+d);c[o>>2]=n+(m+d);return}}function aPa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+128|0;h=g|0;if((f|0)<1){i=g;return}else{j=0}while(1){k=d[e+j|0]|0;l=a+(k<<1)|0;b[h+(k<<1)>>1]=b[l>>1]|0;b[l>>1]=0;l=j+1|0;if((l|0)>(f|0)){m=0;break}else{j=l}}do{j=d[e+m|0]|0;b[a+((d[c+j|0]|0)<<1)>>1]=b[h+(j<<1)>>1]|0;m=m+1|0;}while((m|0)<=(f|0));i=g;return}function bPa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+60>>2]|0;a=d;if((d|0)==0){return}e=d+156|0;f=c[e>>2]|0;if((f|0)==0){return}else{g=0;h=f}while(1){AOa(a,h+(g*2224|0)|0);f=g+1|0;if((f|0)>=36){break}g=f;h=c[e>>2]|0}c[d+9852>>2]=0;c[d+9848>>2]=0;c[d+9856>>2]=0;AOa(a,d+7624|0);AOa(a,d+952|0);AOa(a,d+3176|0);c[d+12480>>2]=0;c[d+12476>>2]=0;c[d+9988>>2]=0;c[d+13760>>2]=-1;c[d+13764>>2]=0;c[d+13768>>2]=0;c[d+13772>>2]=0;c[d+13748>>2]=0;c[d+13752>>2]=0;c[d+14020>>2]=0;b[d+13872>>1]=0;return}function cPa(a,b){a=a|0;b=b|0;var e=0;if((b|0)<1){e=1}else{e=(b|0)>31?31:b}c[a+9960>>2]=e;b=d[(c[a+9896>>2]|0)+e|0]|0;c[a+9964>>2]=b;c[a+168>>2]=d[(c[a+9888>>2]|0)+e|0]|0;c[a+172>>2]=d[(c[a+9892>>2]|0)+b|0]|0;return}function dPa(a){a=a|0;if((c[a+9992>>2]|0)==3){return}if((c[a+13940>>2]|0)!=0){return}if((c[a+14460>>2]|0)!=0){return}Y0a((c[a+9856>>2]|0)+1496|0,c[a+12480>>2]|0,0);return}function ePa(a){a=a|0;c[a+14556>>2]=c[a+9856>>2];c[a+14560>>2]=c[a+9848>>2];c[a+14564>>2]=c[a+9852>>2];b[a+14568>>1]=b[a+13872>>1]|0;b[a+14570>>1]=b[a+13874>>1]|0;c[a+14572>>2]=c[a+13924>>2];c[a+14576>>2]=c[a+13940>>2];Kkb(a+14424|0);return}function fPa(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0;j=a+4|0;k=c[(c[j>>2]|0)+800>>2]|0;l=8>>>(k>>>0);m=a+12476|0;n=a+12480|0;o=c[n>>2]|0;switch(c[a+11740>>2]|0){case 0:{p=c[a+11744+(g<<5)>>2]|0;q=c[a+11744+(g<<5)+4>>2]|0;r=l<<1;s=k-1|0;t=c[a+14216>>2]|0;u=t+s|0;v=(u|0)>3?3:u;u=(2<<k)-1|0;w=c[a+136>>2]>>k;x=c[a+140>>2]>>k;y=c[a+7656>>2]|0;z=c[a+7660>>2]|0;if((c[a+13924>>2]|0)==0){A=p;B=q}else{A=(p|0)/2|0;B=(q|0)/2|0}q=A&u;p=B&u;C=c[m>>2]|0;D=k+1|0;E=(ba(C,r)|0)+(A>>D)|0;F=(B>>D)+(ba(r,o)|0)|0;G=c[a+28>>2]|0;do{if((G|0)==2){H=B>>1&u|p&1;I=A>>1&u|q&1;J=F>>1;K=E>>1}else if((G|0)==1){L=(A|0)/4|0;M=(B|0)/4|0;H=M<<1&u;I=L<<1&u;J=(M>>k)+(ba(o,l)|0)|0;K=(L>>k)+(ba(C,l)|0)|0}else{if((c[a+14220>>2]|0)!=0){L=(A|0)/2|0;M=(B|0)/2|0;H=M&u;I=L&u;J=(M>>D)+(ba(o,l)|0)|0;K=(L>>D)+(ba(C,l)|0)|0;break}if((t|0)==0){H=p;I=q;J=F;K=E;break}L=(A|0)/2|0;H=p;I=L&u;J=F;K=(L>>D)+(ba(C,l)|0)|0}}while(0);C=(c[h>>2]|0)+(E+(ba(F,y)|0))|0;D=(ba(J,z)|0)+K|0;u=(c[h+4>>2]|0)+D|0;A=(c[h+8>>2]|0)+D|0;D=w-((q|0)!=0)-r|0;if(E>>>0>((D|0)>0?D:0)>>>0|(J|0)<0){N=15}else{D=x-((p|0)!=0)-r|0;if(F>>>0>((D|0)>0?D:0)>>>0){N=15}else{O=C;P=u;Q=A}}if((N|0)==15){D=a+11540|0;t=a+9944|0;Ne[c[D>>2]&127](c[t>>2]|0,C,y,y,17,17,E,F,w,x);F=c[t>>2]|0;t=(c[a+148>>2]|0)*18|0;E=F+t|0;C=w>>1;w=x>>1;Ne[c[D>>2]&127](E,u,z,z,9,9,K,J,C,w);u=F+(t+16)|0;Ne[c[D>>2]&127](u,A,z,z,9,9,K,J,C,w);O=F;P=E;Q=u}Se[c[i+(s<<2)>>2]&511](b,O,y,r,q<<2>>k,p<<2>>k);p=(c[a+14220>>2]|0)==0?r:l;r=I<<2>>k;I=H<<2>>k;if((p|0)==0){return}H=i+(v<<2)|0;Se[c[H>>2]&511](e,P,z,p,r,I);Se[c[H>>2]&511](f,Q,z,p,r,I);return};case 2:{I=a+14172|0;r=l<<1;p=o>>1;z=a+14216|0;Q=a+136|0;H=a+140|0;P=a+7656|0;v=a+7660|0;q=a+13924|0;y=p<<1;O=a+28|0;s=a+14220|0;u=a+11540|0;E=a+9944|0;F=a+148|0;w=a+152|0;C=l+1>>1;J=a+9992|0;K=a+14240|0;A=a+9856|0;D=f;t=0;x=e;B=b;while(1){G=c[a+11808+(g<<3)+(t<<2)>>2]|0;do{if((c[I>>2]|0)==(G+1|0)){R=h}else{if((c[J>>2]|0)==3){R=h;break}if((c[K>>2]|0)!=0){R=h;break}R=c[A>>2]|0}}while(0);L=c[a+11744+(g<<5)+(t<<3)>>2]|0;M=(c[a+11744+(g<<5)+(t<<3)+4>>2]|0)+(ba(t,r)|0)|0;S=c[(c[j>>2]|0)+800>>2]|0;T=S-1|0;U=c[z>>2]|0;V=T+U|0;W=(V|0)>3?3:V;V=8>>>(S>>>0);X=(2<<S)-1|0;Y=c[Q>>2]>>S;Z=c[H>>2]>>S;_=c[P>>2]|0;$=c[v>>2]|0;if((c[q>>2]|0)==0){aa=L;ca=M}else{aa=(L|0)/2|0;ca=(M|0)/2|0}M=aa&X;L=ca&X;da=c[m>>2]|0;ea=V<<1;fa=S+1|0;ga=(ba(da,ea)|0)+(aa>>fa)|0;ha=(ca>>fa)+(ba(y,V)|0)|0;ia=c[O>>2]|0;do{if((ia|0)==2){ja=ca>>1&X|L&1;ka=aa>>1&X|M&1;la=ha>>1;ma=ga>>1}else if((ia|0)==1){na=(aa|0)/4|0;oa=(ca|0)/4|0;ja=oa<<1&X;ka=na<<1&X;la=(oa>>S)+(ba(V,p)|0)|0;ma=(na>>S)+(ba(da,V)|0)|0}else{if((c[s>>2]|0)!=0){na=(aa|0)/2|0;oa=(ca|0)/2|0;ja=oa&X;ka=na&X;la=(oa>>fa)+(ba(V,p)|0)|0;ma=(na>>fa)+(ba(da,V)|0)|0;break}if((U|0)==0){ja=L;ka=M;la=ha;ma=ga;break}na=(aa|0)/2|0;ja=L;ka=na&X;la=ha;ma=(na>>fa)+(ba(da,V)|0)|0}}while(0);V=(c[R>>2]|0)+(ga+(ba(ha,_)|0))|0;da=(ba(la,$)|0)+ma|0;fa=(c[R+4>>2]|0)+da|0;X=(c[R+8>>2]|0)+da|0;da=Y-((M|0)!=0)-ea|0;if(ga>>>0>((da|0)>0?da:0)>>>0|(la|0)<0){N=103}else{da=Z-((L|0)!=0)-l|0;if(ha>>>0>((da|0)>0?da:0)>>>0){N=103}else{pa=V;qa=fa;ra=X}}if((N|0)==103){N=0;Ne[c[u>>2]&127](c[E>>2]|0,V,_,_,17,17,ga,ha,Y,Z);V=c[E>>2]|0;da=(c[F>>2]|0)*18|0;U=V+da|0;ia=Y>>1;na=Z>>1;Ne[c[u>>2]&127](U,fa,$,$,9,9,ma,la,ia,na);fa=V+(da+16)|0;Ne[c[u>>2]&127](fa,X,$,$,9,9,ma,la,ia,na);pa=V;qa=U;ra=fa}if((G|0)==0){sa=pa;ta=qa;ua=ra}else{fa=c[w>>2]|0;sa=pa+(c[F>>2]|0)|0;ta=qa+fa|0;ua=ra+fa|0}Se[c[i+(T<<2)>>2]&511](B,sa,_,l,M<<2>>S,L<<2>>S);fa=c[s>>2]|0;U=(fa|0)==0?l:C;V=ka<<2>>S;na=ja<<2>>S;if((U|0)==0){va=fa}else{fa=i+(W<<2)|0;Se[c[fa>>2]&511](x,ta,$,U,V,na);Se[c[fa>>2]&511](D,ua,$,U,V,na);va=c[s>>2]|0}na=B+(ba(c[F>>2]|0,r)|0)|0;V=ba(r>>va,c[w>>2]|0)|0;U=t+1|0;if((U|0)<2){D=D+V|0;t=U;x=x+V|0;B=na}else{break}}return};case 1:{B=a+148|0;x=c[m>>2]<<1;t=o<<1;D=a+136|0;w=a+140|0;va=a+13924|0;r=a+11540|0;F=a+9944|0;s=l+1|0;ua=0;ta=0;ja=0;ka=k;do{C=ja&1;sa=ja>>1;ra=c[B>>2]|0;qa=b+(ba((ba(ra,sa)|0)+C|0,l)|0)|0;pa=ba(C|x,l)|0;C=ba(sa+t|0,l)|0;sa=c[D>>2]>>k;la=c[w>>2]>>k;ma=a+11744+(g<<5)+(ja<<3)|0;u=c[ma>>2]|0;E=a+11744+(g<<5)+(ja<<3)+4|0;R=c[E>>2]|0;aa=(ka|0)>3?3:ka;p=(2<<ka)-1|0;if((c[va>>2]|0)==0){wa=R;xa=u}else{wa=(R|0)/2|0;xa=(u|0)/2|0}u=xa&p;R=wa&p;p=ka+1|0;ca=(xa>>p)+pa|0;pa=(wa>>p)+C|0;C=(c[h>>2]|0)+((ba(pa,ra)|0)+ca)|0;p=sa-((u|0)!=0)-l|0;if(ca>>>0>((p|0)>0?p:0)>>>0){N=22}else{p=la-((R|0)!=0)-l|0;if(pa>>>0>((p|0)>0?p:0)>>>0){N=22}else{ya=C}}if((N|0)==22){N=0;Ne[c[r>>2]&127](c[F>>2]|0,C,ra,ra,s,s,ca,pa,sa,la);ya=c[F>>2]|0}Se[c[i+(aa<<2)>>2]&511](qa,ya,ra,l,u<<2>>ka,R<<2>>ka);ua=(c[ma>>2]|0)+ua|0;ta=(c[E>>2]|0)+ta|0;ja=ja+1|0;ka=c[(c[j>>2]|0)+800>>2]|0}while((ja|0)<4);ja=(ka|0)>3?3:ka;ya=8>>>(ka>>>0);s=(2<<ka)-1|0;wa=ka+1|0;xa=c[D>>2]>>wa;D=c[w>>2]>>wa;if((c[va>>2]|0)==0){za=ua;Aa=ta}else{za=(ua|0)/2|0;Aa=(ta|0)/2|0}ta=(d[1210168+(za&15)|0]|0)+(za>>3)|0;za=(d[1210168+(Aa&15)|0]|0)+(Aa>>3)|0;Aa=ta&s;ua=za&s;s=(ba(c[m>>2]|0,ya)|0)+(ta>>wa)|0;ta=(ba(c[n>>2]|0,ya)|0)+(za>>wa)|0;wa=a+152|0;za=c[wa>>2]|0;n=(ba(ta,za)|0)+s|0;va=(c[h+4>>2]|0)+n|0;w=xa-((Aa|0)!=0)-ya|0;if(s>>>0>((w|0)>0?w:0)>>>0){N=28}else{w=D-((ua|0)!=0)-ya|0;if(ta>>>0>((w|0)>0?w:0)>>>0){N=28}else{Ba=va;Ca=0;Da=za}}if((N|0)==28){Ne[c[r>>2]&127](c[F>>2]|0,va,za,za,9,9,s,ta,xa,D);Ba=c[F>>2]|0;Ca=1;Da=c[wa>>2]|0}za=Aa<<2>>ka;Aa=ua<<2>>ka;ka=i+(ja<<2)|0;Se[c[ka>>2]&511](e,Ba,Da,ya,za,Aa);Da=(c[h+8>>2]|0)+n|0;if(Ca){Ca=c[wa>>2]|0;Ne[c[r>>2]&127](c[F>>2]|0,Da,Ca,Ca,9,9,s,ta,xa,D);Ea=c[F>>2]|0}else{Ea=Da}Se[c[ka>>2]&511](f,Ea,c[wa>>2]|0,ya,za,Aa);return};case 4:{Aa=a+14172|0;if((c[Aa>>2]|0)!=3){za=l<<1;ya=o>>1;wa=a+14216|0;Ea=a+136|0;ka=a+140|0;Da=a+7656|0;F=a+7660|0;D=a+13924|0;xa=ya<<1;ta=a+28|0;s=a+14220|0;Ca=a+11540|0;r=a+9944|0;n=a+148|0;Ba=a+11316|0;ja=a+14240|0;ua=a+152|0;va=a+9856|0;w=0;t=h;x=i;a:while(1){B=t+4|0;E=t+8|0;ma=w;R=x;while(1){if((ma|0)>=2){break a}Fa=ma+1|0;u=(c[Aa>>2]|0)==(Fa|0);ra=ma<<1;qa=c[a+11744+(g<<5)+(ra<<3)>>2]|0;aa=c[a+11744+(g<<5)+(ra<<3)+4>>2]|0;ra=c[(c[j>>2]|0)+800>>2]|0;la=ra-1|0;sa=c[wa>>2]|0;pa=la+sa|0;ca=(pa|0)>3?3:pa;pa=8>>>(ra>>>0);C=(2<<ra)-1|0;p=c[Ea>>2]>>ra;O=c[ka>>2]>>ra;y=c[Da>>2]|0;q=c[F>>2]|0;if((c[D>>2]|0)==0){Ga=qa;Ha=aa}else{Ga=(qa|0)/2|0;Ha=(aa|0)/2|0}aa=Ga&C;qa=Ha&C;v=c[m>>2]|0;P=pa<<1;H=ra+1|0;Q=(ba(v,P)|0)+(Ga>>H)|0;z=(Ha>>H)+(ba(xa,pa)|0)|0;A=c[ta>>2]|0;do{if((A|0)==2){Ia=Ha>>1&C|qa&1;Ja=Ga>>1&C|aa&1;Ka=z>>1;La=Q>>1}else if((A|0)==1){K=(Ga|0)/4|0;J=(Ha|0)/4|0;Ia=J<<1&C;Ja=K<<1&C;Ka=(J>>ra)+(ba(pa,ya)|0)|0;La=(K>>ra)+(ba(v,pa)|0)|0}else{if((c[s>>2]|0)!=0){K=(Ga|0)/2|0;J=(Ha|0)/2|0;Ia=J&C;Ja=K&C;Ka=(J>>H)+(ba(pa,ya)|0)|0;La=(K>>H)+(ba(v,pa)|0)|0;break}if((sa|0)==0){Ia=qa;Ja=aa;Ka=z;La=Q;break}K=(Ga|0)/2|0;Ia=qa;Ja=K&C;Ka=z;La=(K>>H)+(ba(v,pa)|0)|0}}while(0);pa=(c[t>>2]|0)+(Q+(ba(z,y)|0))|0;v=(ba(Ka,q)|0)+La|0;H=(c[B>>2]|0)+v|0;C=(c[E>>2]|0)+v|0;v=p-((aa|0)!=0)-P|0;if(Q>>>0>((v|0)>0?v:0)>>>0|(Ka|0)<0){N=147}else{v=O-((qa|0)!=0)-za|0;if(z>>>0>((v|0)>0?v:0)>>>0){N=147}else{Ma=pa;Na=H;Oa=C}}if((N|0)==147){N=0;Ne[c[Ca>>2]&127](c[r>>2]|0,pa,y,y,17,17,Q,z,p,O);pa=c[r>>2]|0;v=(c[n>>2]|0)*18|0;sa=pa+v|0;A=p>>1;K=O>>1;Ne[c[Ca>>2]&127](sa,H,q,q,9,9,La,Ka,A,K);H=pa+(v+16)|0;Ne[c[Ca>>2]&127](H,C,q,q,9,9,La,Ka,A,K);Ma=pa;Na=sa;Oa=H}if(u){Pa=Ma;Qa=Na;Ra=Oa}else{H=c[ua>>2]|0;Pa=Ma+(c[n>>2]|0)|0;Qa=Na+H|0;Ra=Oa+H|0}Se[c[R+(la<<2)>>2]&511](b,Pa,y,za,aa<<2>>ra,qa<<2>>ra);H=(c[s>>2]|0)==0?za:l;sa=Ja<<2>>ra;pa=Ia<<2>>ra;if((H|0)!=0){K=R+(ca<<2)|0;Se[c[K>>2]&511](e,Qa,q,H,sa,pa);Se[c[K>>2]&511](f,Ra,q,H,sa,pa)}if((c[ja>>2]|0)==0){break}else{ma=Fa;R=Ba}}w=Fa;t=c[va>>2]|0;x=Ba}return}Ba=a+14216|0;x=a+136|0;va=a+140|0;t=a+7656|0;Fa=a+7660|0;w=a+13924|0;ja=o<<1;Ra=a+28|0;Qa=a+14220|0;Ia=h+4|0;Ja=h+8|0;za=a+11540|0;s=a+9944|0;Pa=a+148|0;Oa=l+1|0;Na=a+152|0;n=a+11316|0;Ma=i;ua=0;while(1){Ka=ua<<1;La=0;do{Ca=La+Ka|0;r=c[a+11744+(g<<5)+(Ca<<3)>>2]|0;Ga=c[a+11744+(g<<5)+(Ca<<3)+4>>2]|0;Ca=c[(c[j>>2]|0)+800>>2]|0;ya=Ca-1|0;Ha=c[Ba>>2]|0;ta=ya+Ha|0;xa=(ta|0)>3?3:ta;ta=8>>>(Ca>>>0);D=(2<<Ca)-1|0;F=c[x>>2]>>Ca;Da=c[va>>2]>>Ca;ka=c[t>>2]<<1;Ea=c[Fa>>2]<<1;if((c[w>>2]|0)==0){Sa=r;Ta=Ga}else{Sa=(r|0)/2|0;Ta=(Ga|0)/2|0}Ga=Ta+(ba((1<<Ca)-1|0,La-(La^ua)|0)|0)|0;r=Sa&D;wa=Ga&D;Aa=c[m>>2]|0;R=ta<<1;ma=Ca+1|0;E=(ba(Aa,R)|0)+(Sa>>ma)|0;B=(Ga>>ma)+((ba(ja,ta)|0)>>1)|0;$=c[Ra>>2]|0;do{if(($|0)==2){Ua=Ga>>1&D|wa&1;Va=Sa>>1&D|r&1;Wa=B>>1;Xa=E>>1}else if(($|0)==1){W=(Sa|0)/4|0;S=(Ga|0)/4|0;Ua=S<<1&D;Va=W<<1&D;Wa=(S>>Ca)+(ba(ta,o)|0)|0;Xa=(W>>Ca)+(ba(Aa,ta)|0)|0}else{if((c[Qa>>2]|0)!=0){W=(Sa|0)/2|0;S=(Ga|0)/2|0;Ua=S&D;Va=W&D;Wa=(S>>ma)+((ba(ta,o)|0)>>1)|0;Xa=(W>>ma)+(ba(Aa,ta)|0)|0;break}if((Ha|0)==0){Ua=wa;Va=r;Wa=B;Xa=E;break}W=(Sa|0)/2|0;Ua=wa;Va=W&D;Wa=B;Xa=(W>>ma)+(ba(Aa,ta)|0)|0}}while(0);ta=(c[h>>2]|0)+((ba(B,ka)|0)+E)|0;Aa=(ba(Wa,Ea)|0)+Xa|0;ma=(c[Ia>>2]|0)+Aa|0;D=(c[Ja>>2]|0)+Aa|0;Aa=F-((r|0)!=0)-R|0;Ha=Da>>1;if(E>>>0>((Aa|0)>0?Aa:0)>>>0|(Wa|0)<0){N=124}else{Aa=Ha-((wa|0)!=0)-l|0;if(B>>>0>((Aa|0)>0?Aa:0)>>>0){N=124}else{Ya=ta;Za=ma;_a=D}}if((N|0)==124){N=0;Aa=ka>>1;Ne[c[za>>2]&127](c[s>>2]|0,ta,Aa,Aa,17,18,E,B<<1,F,Da);Aa=c[s>>2]|0;ta=(c[Pa>>2]|0)*18|0;Ga=Aa+ta|0;$=Ea>>1;q=Wa<<1;ca=F>>1;Ne[c[za>>2]&127](Ga,ma,$,$,9,10,Xa,q,ca,Ha);ma=Aa+(ta+16)|0;Ne[c[za>>2]&127](ma,D,$,$,9,10,Xa,q,ca,Ha);Ya=Aa;Za=Ga;_a=ma}if((La|0)==0){$a=b;ab=e;bb=f}else{ma=c[Na>>2]|0;$a=b+(c[Pa>>2]|0)|0;ab=e+ma|0;bb=f+ma|0}if((La|0)==(ua|0)){cb=Ya;db=Za;eb=_a}else{ma=c[Na>>2]|0;cb=Ya+(c[Pa>>2]|0)|0;db=Za+ma|0;eb=_a+ma|0}Se[c[Ma+(ya<<2)>>2]&511]($a,cb,ka,l,r<<2>>Ca,wa<<2>>Ca);if((c[Qa>>2]|0)==0){fb=l}else{fb=Oa-La>>1}ma=Va<<2>>Ca;Ga=Ua<<2>>Ca;if((fb|0)!=0){Aa=Ma+(xa<<2)|0;Se[c[Aa>>2]&511](ab,db,Ea,fb,ma,Ga);Se[c[Aa>>2]&511](bb,eb,Ea,fb,ma,Ga)}La=La+1|0;}while((La|0)<2);La=ua+1|0;if((La|0)<2){Ma=n;ua=La}else{break}}return};case 3:{ua=c[a+14172>>2]|0;n=c[a+11808+(g<<3)>>2]|0;if((ua|0)!=3){do{if((ua|0)==(n+1|0)){gb=h}else{if((c[a+9992>>2]|0)==3){gb=h;break}if((c[a+14240>>2]|0)!=0){gb=h;break}gb=c[a+9856>>2]|0}}while(0);ua=c[a+11744+(g<<5)>>2]|0;Ma=c[a+11744+(g<<5)+4>>2]|0;fb=l<<1;eb=o>>1;bb=k-1|0;db=c[a+14216>>2]|0;ab=bb+db|0;Ua=(ab|0)>3?3:ab;ab=(2<<k)-1|0;Va=c[a+136>>2]>>k;Oa=c[a+140>>2]>>k;Qa=c[a+7656>>2]|0;cb=c[a+7660>>2]|0;if((c[a+13924>>2]|0)==0){hb=ua;ib=Ma}else{hb=(ua|0)/2|0;ib=(Ma|0)/2|0}Ma=hb&ab;ua=ib&ab;$a=c[m>>2]|0;_a=k+1|0;Za=(ba($a,fb)|0)+(hb>>_a)|0;Pa=(ib>>_a)+(ba(eb<<1,l)|0)|0;Ya=c[a+28>>2]|0;do{if((Ya|0)==2){jb=ib>>1&ab|ua&1;kb=hb>>1&ab|Ma&1;lb=Pa>>1;mb=Za>>1}else if((Ya|0)==1){Na=(hb|0)/4|0;Xa=(ib|0)/4|0;jb=Xa<<1&ab;kb=Na<<1&ab;lb=(Xa>>k)+(ba(l,eb)|0)|0;mb=(Na>>k)+(ba($a,l)|0)|0}else{if((c[a+14220>>2]|0)!=0){Na=(hb|0)/2|0;Xa=(ib|0)/2|0;jb=Xa&ab;kb=Na&ab;lb=(Xa>>_a)+(ba(l,eb)|0)|0;mb=(Na>>_a)+(ba($a,l)|0)|0;break}if((db|0)==0){jb=ua;kb=Ma;lb=Pa;mb=Za;break}Na=(hb|0)/2|0;jb=ua;kb=Na&ab;lb=Pa;mb=(Na>>_a)+(ba($a,l)|0)|0}}while(0);$a=(c[gb>>2]|0)+(Za+(ba(Pa,Qa)|0))|0;_a=(ba(lb,cb)|0)+mb|0;ab=(c[gb+4>>2]|0)+_a|0;hb=(c[gb+8>>2]|0)+_a|0;_a=Va-((Ma|0)!=0)-fb|0;if(Za>>>0>((_a|0)>0?_a:0)>>>0|(lb|0)<0){N=83}else{_a=Oa-((ua|0)!=0)-fb|0;if(Pa>>>0>((_a|0)>0?_a:0)>>>0){N=83}else{nb=$a;ob=ab;pb=hb}}if((N|0)==83){_a=a+11540|0;gb=a+9944|0;Ne[c[_a>>2]&127](c[gb>>2]|0,$a,Qa,Qa,17,17,Za,Pa,Va,Oa);Pa=c[gb>>2]|0;gb=(c[a+148>>2]|0)*18|0;Za=Pa+gb|0;$a=Va>>1;Va=Oa>>1;Ne[c[_a>>2]&127](Za,ab,cb,cb,9,9,mb,lb,$a,Va);ab=Pa+(gb+16)|0;Ne[c[_a>>2]&127](ab,hb,cb,cb,9,9,mb,lb,$a,Va);nb=Pa;ob=Za;pb=ab}if((n|0)==0){qb=nb;rb=ob;sb=pb}else{ab=c[a+152>>2]|0;qb=nb+(c[a+148>>2]|0)|0;rb=ob+ab|0;sb=pb+ab|0}Se[c[i+(bb<<2)>>2]&511](b,qb,Qa,fb,Ma<<2>>k,ua<<2>>k);ua=(c[a+14220>>2]|0)==0?fb:l;fb=kb<<2>>k;kb=jb<<2>>k;if((ua|0)==0){return}jb=i+(Ua<<2)|0;Se[c[jb>>2]&511](e,rb,cb,ua,fb,kb);Se[c[jb>>2]&511](f,sb,cb,ua,fb,kb);return}kb=c[a+11744+(g<<5)>>2]|0;fb=c[a+11744+(g<<5)+4>>2]|0;ua=k-1|0;cb=a+14216|0;sb=c[cb>>2]|0;jb=sb+ua|0;rb=(jb|0)>3?3:jb;jb=(2<<k)-1|0;Ua=a+136|0;Ma=c[Ua>>2]>>k;Qa=a+140|0;qb=c[Qa>>2]>>k;bb=a+7656|0;ab=c[bb>>2]<<1;pb=a+7660|0;ob=c[pb>>2]<<1;nb=a+13924|0;if((c[nb>>2]|0)==0){tb=kb;ub=fb}else{tb=(kb|0)/2|0;ub=(fb|0)/2|0}fb=ub-(ba(n,(1<<k)-1|0)|0)|0;ub=tb&jb;kb=fb&jb;Za=c[m>>2]|0;Pa=l<<1;Va=k+1|0;$a=(ba(Za,Pa)|0)+(tb>>Va)|0;lb=o<<1;mb=(fb>>Va)+((ba(lb,l)|0)>>1)|0;hb=a+28|0;_a=c[hb>>2]|0;do{if((_a|0)==2){vb=fb>>1&jb|kb&1;wb=tb>>1&jb|ub&1;xb=mb>>1;yb=$a>>1}else if((_a|0)==1){gb=(tb|0)/4|0;Oa=(fb|0)/4|0;vb=Oa<<1&jb;wb=gb<<1&jb;xb=(Oa>>k)+(ba(o,l)|0)|0;yb=(gb>>k)+(ba(Za,l)|0)|0}else{if((c[a+14220>>2]|0)!=0){gb=(tb|0)/2|0;Oa=(fb|0)/2|0;vb=Oa&jb;wb=gb&jb;xb=(Oa>>Va)+((ba(o,l)|0)>>1)|0;yb=(gb>>Va)+(ba(Za,l)|0)|0;break}if((sb|0)==0){vb=kb;wb=ub;xb=mb;yb=$a;break}gb=(tb|0)/2|0;vb=kb;wb=gb&jb;xb=mb;yb=(gb>>Va)+(ba(Za,l)|0)|0}}while(0);Za=(c[h>>2]|0)+((ba(mb,ab)|0)+$a)|0;Va=h+4|0;jb=(ba(xb,ob)|0)+yb|0;tb=(c[Va>>2]|0)+jb|0;sb=h+8|0;fb=(c[sb>>2]|0)+jb|0;jb=Ma-((ub|0)!=0)-Pa|0;Pa=qb>>1;if($a>>>0>((jb|0)>0?jb:0)>>>0|(xb|0)<0){N=44}else{jb=Pa-((kb|0)!=0)-l|0;if(mb>>>0>((jb|0)>0?jb:0)>>>0){N=44}else{zb=Za;Ab=tb;Bb=fb}}if((N|0)==44){jb=a+11540|0;_a=a+9944|0;gb=ab>>1;Ne[c[jb>>2]&127](c[_a>>2]|0,Za,gb,gb,17,18,$a,mb<<1,Ma,qb);qb=c[_a>>2]|0;_a=(c[a+148>>2]|0)*18|0;mb=qb+_a|0;$a=ob>>1;gb=xb<<1;xb=Ma>>1;Ne[c[jb>>2]&127](mb,tb,$a,$a,9,10,yb,gb,xb,Pa);tb=qb+(_a+16)|0;Ne[c[jb>>2]&127](tb,fb,$a,$a,9,10,yb,gb,xb,Pa);zb=qb;Ab=mb;Bb=tb}if((n|0)==0){Cb=zb;Db=Ab;Eb=Bb}else{n=c[a+152>>2]|0;Cb=zb+(c[a+148>>2]|0)|0;Db=Ab+n|0;Eb=Bb+n|0}Se[c[i+(ua<<2)>>2]&511](b,Cb,ab,l,ub<<2>>k,kb<<2>>k);kb=a+14220|0;if((c[kb>>2]|0)==0){Fb=l}else{Fb=l+1>>1}ub=wb<<2>>k;wb=vb<<2>>k;if((Fb|0)!=0){k=i+(rb<<2)|0;Se[c[k>>2]&511](e,Db,ob,Fb,ub,wb);Se[c[k>>2]&511](f,Eb,ob,Fb,ub,wb)}wb=c[a+11808+(g<<3)+4>>2]|0;ub=c[a+11744+(g<<5)+8>>2]|0;Fb=c[a+11744+(g<<5)+12>>2]|0;g=c[(c[j>>2]|0)+800>>2]|0;j=g-1|0;ob=c[cb>>2]|0;cb=j+ob|0;Eb=(cb|0)>3?3:cb;cb=8>>>(g>>>0);k=(2<<g)-1|0;Db=c[Ua>>2]>>g;Ua=c[Qa>>2]>>g;Qa=c[bb>>2]<<1;bb=c[pb>>2]<<1;if((c[nb>>2]|0)==0){Gb=ub;Hb=Fb}else{Gb=(ub|0)/2|0;Hb=(Fb|0)/2|0}Fb=Hb+(ba((1<<g)-1|0,1-wb|0)|0)|0;Hb=Gb&k;ub=Fb&k;nb=c[m>>2]|0;m=cb<<1;pb=g+1|0;rb=(ba(nb,m)|0)+(Gb>>pb)|0;vb=(Fb>>pb)+((ba(cb,lb)|0)>>1)|0;lb=c[hb>>2]|0;do{if((lb|0)==2){Ib=Fb>>1&k|ub&1;Jb=Gb>>1&k|Hb&1;Kb=vb>>1;Lb=rb>>1}else if((lb|0)==1){hb=(Gb|0)/4|0;ab=(Fb|0)/4|0;Ib=ab<<1&k;Jb=hb<<1&k;Kb=(ab>>g)+(ba(cb,o)|0)|0;Lb=(hb>>g)+(ba(nb,cb)|0)|0}else{if((c[kb>>2]|0)!=0){hb=(Gb|0)/2|0;ab=(Fb|0)/2|0;Ib=ab&k;Jb=hb&k;Kb=(ab>>pb)+((ba(cb,o)|0)>>1)|0;Lb=(hb>>pb)+(ba(nb,cb)|0)|0;break}if((ob|0)==0){Ib=ub;Jb=Hb;Kb=vb;Lb=rb;break}hb=(Gb|0)/2|0;Ib=ub;Jb=hb&k;Kb=vb;Lb=(hb>>pb)+(ba(nb,cb)|0)|0}}while(0);cb=(c[h>>2]|0)+((ba(vb,Qa)|0)+rb)|0;h=(ba(Kb,bb)|0)+Lb|0;nb=(c[Va>>2]|0)+h|0;Va=(c[sb>>2]|0)+h|0;h=Db-((Hb|0)!=0)-m|0;m=Ua>>1;do{if(rb>>>0>((h|0)>0?h:0)>>>0|(Kb|0)<0){N=63}else{sb=m-((ub|0)!=0)-l|0;if(vb>>>0>((sb|0)>0?sb:0)>>>0){N=63;break}Mb=cb;Nb=nb;Ob=Va;Pb=a+148|0}}while(0);if((N|0)==63){N=a+11540|0;h=a+9944|0;sb=Qa>>1;Ne[c[N>>2]&127](c[h>>2]|0,cb,sb,sb,17,18,rb,vb<<1,Db,Ua);Ua=c[h>>2]|0;h=a+148|0;vb=(c[h>>2]|0)*18|0;rb=Ua+vb|0;sb=bb>>1;cb=Kb<<1;Kb=Db>>1;Ne[c[N>>2]&127](rb,nb,sb,sb,9,10,Lb,cb,Kb,m);nb=Ua+(vb+16)|0;Ne[c[N>>2]&127](nb,Va,sb,sb,9,10,Lb,cb,Kb,m);Mb=Ua;Nb=rb;Ob=nb;Pb=h}h=c[Pb>>2]|0;Pb=c[a+152>>2]|0;if((wb|0)==0){Qb=Mb;Rb=Nb;Sb=Ob}else{Qb=Mb+h|0;Rb=Nb+Pb|0;Sb=Ob+Pb|0}Se[c[i+(j<<2)>>2]&511](b+h|0,Qb,Qa,l,Hb<<2>>g,ub<<2>>g);ub=l>>((c[kb>>2]|0)!=0);kb=Jb<<2>>g;Jb=Ib<<2>>g;if((ub|0)==0){return}g=i+(Eb<<2)|0;Se[c[g>>2]&511](e+Pb|0,Rb,bb,ub,kb,Jb);Se[c[g>>2]&511](f+Pb|0,Sb,bb,ub,kb,Jb);return};default:{return}}}function gPa(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=h-1|0;if((c|0)<0){l=0}else{l=(k|0)<(c|0)?k:c}c=i-1|0;if((e|0)<0){m=0}else{m=(c|0)<(e|0)?c:e}if((f|0)<0){n=0}else{n=(k|0)<(f|0)?k:f}if((g|0)<0){o=0}else{o=(c|0)<(g|0)?c:g}g=b+((ba(m,j)|0)+l)|0;a[g]=(a[g]|0)+100;g=n-l|0;c=o-m|0;if((((g|0)>-1?g:-g|0)|0)>(((c|0)>-1?c:-c|0)|0)){c=(l|0)>(n|0);g=c?o:m;f=c?n:l;k=(ba(g,j)|0)+f|0;e=(c?l:n)-f|0;f=((c?m:o)-g<<16|0)/(e|0)|0;if((e|0)<0){return}else{p=0}do{g=ba(p,f)|0;c=g>>16;i=g&65535;g=p+k|0;h=b+(g+(ba(c,j)|0))|0;a[h]=(d[h]|0)+(((65536-i|0)*100|0)>>>16);if((i|0)!=0){h=b+(g+(ba(c+1|0,j)|0))|0;a[h]=(d[h]|0)+((i*100|0)>>>16)}p=p+1|0;}while((p|0)<=(e|0));return}e=(m|0)>(o|0);p=e?m:o;k=e?o:m;m=e?n:l;o=(ba(k,j)|0)+m|0;f=p-k|0;if((p|0)==(k|0)){q=0}else{q=((e?l:n)-m<<16|0)/(f|0)|0}if((f|0)<0){return}m=o+1|0;n=0;do{l=ba(n,q)|0;e=l&65535;k=(l>>16)+(ba(n,j)|0)|0;l=b+(k+o)|0;a[l]=(d[l]|0)+(((65536-e|0)*100|0)>>>16);if((e|0)!=0){l=b+(m+k)|0;a[l]=(d[l]|0)+((e*100|0)>>>16)}n=n+1|0;}while((n|0)<=(f|0));return}function hPa(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0;l=i;m=a;c[a+11736>>2]=d;c[a+11740>>2]=e;c[a+12488>>2]=j;c[a+9924>>2]=k;k=a+12476|0;c[k>>2]=g;g=a+12480|0;c[g>>2]=h;UGb(a+11744|0,f|0,64)|0;$Oa(m);f=a+4|0;h=8>>>((c[(c[f>>2]|0)+800>>2]|0)>>>0);j=a+12496|0;c[j>>2]=(c[j>>2]|0)+2;j=a+12500|0;c[j>>2]=(c[j>>2]|0)+2;j=a+12504|0;c[j>>2]=(c[j>>2]|0)+2;j=a+12508|0;c[j>>2]=(c[j>>2]|0)+2;j=a+12512|0;c[j>>2]=(c[j>>2]|0)+1;j=a+12516|0;c[j>>2]=(c[j>>2]|0)+1;j=a+12544|0;c[j>>2]=(c[j>>2]|0)+(h<<1);e=a+12548|0;c[e>>2]=(c[e>>2]|0)+h;d=a+12552|0;c[d>>2]=(c[d>>2]|0)+h;h=a+14340|0;me[c[a+10096>>2]&511](c[h>>2]|0);n=c[g>>2]|0;g=ba(c[a+148>>2]|0,n)|0;o=c[k>>2]|0;c[j>>2]=(c[a+7624>>2]|0)+(o+g<<4);g=ba(16>>>((c[a+14220>>2]|0)>>>0),n)|0;n=ba(g,c[a+152>>2]|0)|0;g=(ba(16>>>((c[a+14216>>2]|0)>>>0),o)|0)+n|0;c[e>>2]=(c[a+7628>>2]|0)+g;c[d>>2]=(c[a+7632>>2]|0)+g;if((b|0)==0){p=c[h>>2]|0;YOa(m,p);i=l;return}yDb(c[f>>2]|0,48,2017600,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;p=c[h>>2]|0;YOa(m,p);i=l;return}function iPa(a,f,g,h,j,k,l,m){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;n=i;if((k|0)>(l|0)){i=n;return}o=(m|0)<64;p=j<<8;j=(p|0)>0;q=c[a+1108>>2]|0;r=0;s=k;while(1){a:do{if((q|0)==80|(q|0)==70|(q|0)==226){k=0;do{t=ba(e[h+((d[a+1128+k|0]|0)<<1)>>1]|0,s)|0;u=hHb(2097152,0,t,(t|0)<0|0?-1:0)|0;c[f+(s<<8)+(k<<2)>>2]=u;k=k+1|0;}while((k|0)<64)}else{if((q|0)==8){k=s;u=(s|0)<0|0?-1:0;t=0;while(1){v=d[a+1128+t|0]|0;w=gHb(e[1276888+(t<<1)>>1]|0,0,k,u)|0;x=gHb(w,F,e[h+(v<<1)>>1]|0,0)|0;v=hHb(0,8,x,F)|0;c[f+(s<<8)+(t<<2)>>2]=v;t=t+1|0;if((t|0)>=64){break a}}}if(j){t=0;do{u=ba(e[h+((d[a+1128+t|0]|0)<<1)>>1]|0,s)|0;k=hHb(2097152,0,u,(u|0)<0|0?-1:0)|0;c[f+(s<<8)+(t<<2)>>2]=k;k=65536/(u|0)|0;u=k&65535;v=g+(s<<8)+(t<<1)|0;b[v>>1]=u;x=k&65535;if((x|0)==0|(x|0)==32768){b[v>>1]=32767;y=32767}else{y=u}u=y&65535;b[g+(s<<8)+128+(t<<1)>>1]=((u>>>1)+p|0)/(u|0)|0;t=t+1|0;}while((t|0)<64)}else{t=0;do{u=ba(e[h+((d[a+1128+t|0]|0)<<1)>>1]|0,s)|0;v=hHb(2097152,0,u,(u|0)<0|0?-1:0)|0;c[f+(s<<8)+(t<<2)>>2]=v;v=65536/(u|0)|0;u=v&65535;x=g+(s<<8)+(t<<1)|0;b[x>>1]=u;k=v&65535;if((k|0)==0|(k|0)==32768){b[x>>1]=32767;z=32767}else{z=u}u=z&65535;b[g+(s<<8)+128+(t<<1)>>1]=(p-(u>>>1)|0)/(u|0)|0;t=t+1|0;}while((t|0)<64)}}}while(0);if(o){if((q|0)==8){t=m;u=r;while(1){x=gHb(e[1276888+(t<<1)>>1]|0,0,8191,0)|0;k=F;v=c[f+(s<<8)+(t<<2)>>2]|0;w=gHb(v,(v|0)<0|0?-1:0,x>>>14|k<<18,k>>>14|0<<18)|0;k=F;x=u;while(1){v=aHb(w|0,k|0,x|0)|0;A=F;B=0;if((A|0)>(B|0)|(A|0)==(B|0)&v>>>0>2147483647>>>0){x=x+1|0}else{break}}k=t+1|0;if((k|0)<64){t=k;u=x}else{C=x;break}}}else{u=m;t=r;while(1){k=c[f+(s<<8)+(u<<2)>>2]|0;w=gHb(k,(k|0)<0|0?-1:0,8191,0)|0;k=F;v=t;while(1){B=aHb(w|0,k|0,v|0)|0;A=F;D=0;if((A|0)>(D|0)|(A|0)==(D|0)&B>>>0>2147483647>>>0){v=v+1|0}else{break}}k=u+1|0;if((k|0)<64){u=k;t=v}else{C=v;break}}}}else{C=r}t=s+1|0;if((t|0)>(l|0)){break}else{r=C;s=t}}if((C|0)==0){i=n;return}yDb(0,32,2230272,(s=i,i=i+8|0,c[s>>2]=21-C,s)|0);i=s;i=n;return}function jPa(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=b|0;h=c[g>>2]|0;i=b+4|0;j=c[i>>2]|0;k=(j|0)>1;if((f|0)==0){if(k){l=j-1|0;m=h<<1}else{n=fe(h<<j|0)|0;o=b+12|0;p=c[o>>2]|0;x=n;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;l=j+31|0;m=0}c[g>>2]=m;c[i>>2]=l;return}if(k){q=j-1|0;r=h<<1|1;s=b+12|0}else{k=fe(1>>>((1-j|0)>>>0)|h<<j|0)|0;h=b+12|0;b=c[h>>2]|0;x=k;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;q=j+31|0;r=1;s=h}c[g>>2]=r;c[i>>2]=q;h=0;j=r;r=q;while(1){q=e[f+((d[1075976+h|0]|0)<<1)>>1]|0;if((r|0)>8){t=r-8|0;u=j<<8|q}else{b=fe(q>>>((8-r|0)>>>0)|j<<r|0)|0;k=c[s>>2]|0;x=b;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;t=r+24|0;u=q}c[g>>2]=u;c[i>>2]=t;q=h+1|0;if((q|0)<64){h=q;j=u;r=t}else{break}}return}function kPa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[b+9136>>2]|0;e=b+144|0;if((c[e>>2]|0)<=0){return}f=b+12556|0;g=b+9976|0;h=b+4|0;b=0;do{i=c[(c[f>>2]|0)+(b<<2)>>2]|0;j=(((c[(c[g>>2]|0)+(i<<2)>>2]|0)*139|0)+8192|0)>>>14;k=c[h>>2]|0;l=c[k+500>>2]|0;m=c[k+504>>2]|0;if((j|0)<(l|0)){n=l&255}else{n=((j|0)>(m|0)?m:j)&255}a[d+i|0]=n;b=b+1|0;}while((b|0)<(c[e>>2]|0));return}function lPa(a){a=a|0;var b=0,d=0,e=0;Jca(a+11548|0);b=a+14392|0;d=c[b>>2]|0;if((d|0)==0){c[b>>2]=2;e=2}else{e=d}d=a+14400|0;if((c[d>>2]|0)==0){c[d>>2]=524}c[a+14396>>2]=e;if((c[(c[a+4>>2]|0)+600>>2]|0)==0){return 0}c[b>>2]=50;return 0}function mPa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=c[a+364>>2]|0;me[c[a+11164>>2]&511](e);if((c[a+13184>>2]|0)!=0){ne[c[a+14400>>2]&1023](a,e)}if((c[a+12488>>2]|0)==0){j=a+13076|0;k=a+13168|0;l=0;m=-1}else{if((c[a+228>>2]|0)==0){n=c[((f|0)<4?a+168|0:a+172|0)>>2]<<3}else{n=8}b[e>>1]=((b[e>>1]|0)+(n>>1)|0)/(n|0)|0;j=a+13072|0;k=(f|0)<4?a+13160|0:a+13164|0;l=1;m=0}f=c[k>>2]|0;k=c[j>>2]<<13;j=2097152-k-1|0;n=j<<1;o=63;while(1){p=d[i+o|0]|0;q=e+(p<<1)|0;if(((ba(b[q>>1]|0,c[f+(g<<8)+(p<<2)>>2]|0)|0)+j|0)>>>0>n>>>0){r=o;break}b[q>>1]=0;q=o-1|0;if((q|0)<(l|0)){r=m;break}else{o=q}}if((l|0)>(r|0)){s=0}else{o=0;m=l;while(1){l=d[i+m|0]|0;q=e+(l<<1)|0;p=ba(b[q>>1]|0,c[f+(g<<8)+(l<<2)>>2]|0)|0;if((p+j|0)>>>0>n>>>0){if((p|0)>0){l=p+k>>21;t=l;u=l&65535}else{l=k-p>>21;t=l;u=-l&65535}b[q>>1]=u;v=t|o}else{b[q>>1]=0;v=o}q=m+1|0;if((q|0)>(r|0)){s=v;break}else{o=v;m=q}}}c[h>>2]=(c[a+13084>>2]|0)<(s|0);if((c[a+11248>>2]|0)==1){return r|0}aPa(e,a+11184|0,i,r);return r|0}function nPa(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[a+12488>>2]|0;g=a+13188+(f<<2)|0;c[g>>2]=(c[g>>2]|0)+1;g=a+13184|0;h=a+13196|0;a=0;do{i=d+(a<<1)|0;j=b[i>>1]|0;k=j<<16>>16;if(!(j<<16>>16==0)){l=(c[g>>2]|0)+(f<<8)+(a<<2)|0;m=c[l>>2]|0;if(j<<16>>16>0){c[l>>2]=m+k;j=k-(e[(c[h>>2]|0)+(f<<7)+(a<<1)>>1]|0)|0;n=(j|0)<0?0:j&65535}else{c[l>>2]=m-k;m=(e[(c[h>>2]|0)+(f<<7)+(a<<1)>>1]|0)+k|0;n=(m|0)>0?0:m&65535}b[i>>1]=n}a=a+1|0;}while((a|0)<64);return}function oPa(a,f,g,h,j){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0;k=i;i=i+1824|0;l=k|0;m=k+264|0;n=k+528|0;o=k+792|0;p=k+1056|0;q=k+1568|0;r=c[a+364>>2]|0;s=c[a+13088>>2]|0;t=(c[a+9972>>2]|0)>>>1;u=a+11164|0;me[c[u>>2]&511](f);if((c[a+13184>>2]|0)!=0){ne[c[a+14400>>2]&1023](a,f)}v=h<<4;w=(h<<3)-8|8;x=a+12488|0;if((c[x>>2]|0)==0){y=c[a+13168>>2]|0;z=0;A=w;B=0;C=-1;D=a+13100|0;E=a+13104|0}else{if((c[a+228>>2]|0)==0){F=w;G=c[((g|0)<4?a+168|0:a+172|0)>>2]<<3}else{F=0;G=8}b[f>>1]=((b[f>>1]|0)+(G>>1)|0)/(G|0)|0;G=c[((g|0)<4?a+13160|0:a+13164|0)>>2]|0;if((c[a+14004>>2]|0)==0){if((c[a+28>>2]|0)==0){H=8}else{I=0}}else{H=8}if((H|0)==8){I=1048576}y=G;z=I;A=F;B=1;C=0;D=a+13092|0;E=a+13096|0}F=c[D>>2]|0;D=c[E>>2]|0;E=2097152-z-1|0;I=E<<1;G=63;while(1){if((G|0)<(B|0)){J=C;break}H=d[r+G|0]|0;if(((ba(b[f+(H<<1)>>1]|0,c[y+(h<<8)+(H<<2)>>2]|0)|0)+E|0)>>>0>I>>>0){J=G;break}else{G=G-1|0}}G=(B|0)>(J|0);do{if(G){c[j>>2]=(c[a+13084>>2]|0)>>>31}else{C=B;H=0;while(1){w=d[r+C|0]|0;K=ba(b[f+(w<<1)>>1]|0,c[y+(h<<8)+(w<<2)>>2]|0)|0;if((K+E|0)>>>0>I>>>0){if((K|0)>0){w=K+z>>21;c[p+(C<<2)>>2]=w;c[p+256+(C<<2)>>2]=w-1;L=w}else{w=z-K>>21;c[p+(C<<2)>>2]=-w;c[p+256+(C<<2)>>2]=1-w;L=w}c[q+(C<<2)>>2]=(L|0)>2?2:L;M=L|H}else{c[p+(C<<2)>>2]=K>>31|1;c[q+(C<<2)>>2]=1;M=H}K=C+1|0;if((K|0)>(J|0)){break}else{C=K;H=M}}c[j>>2]=(c[a+13084>>2]|0)<(M|0);if(G){break}c[n+(B<<2)>>2]=0;H=o|0;c[H>>2]=B;C=(c[u>>2]|0)==8;K=(J|0)<28;w=a+28|0;N=ba(t,s)|0;O=B;P=B;Q=0;R=0;S=0;T=1;while(1){U=d[r+O|0]|0;V=b[f+(U<<1)>>1]|0;W=V<<16>>16;X=V<<16>>16>-1?W:-W|0;if(C){Y=(ba(e[1200584+(U<<1)>>1]|0,X)|0)>>12}else{Y=X}X=ba(Y,Y)|0;W=c[q+(O<<2)>>2]|0;if((W|0)>0){V=((c[w>>2]|0)-1|0)>>>0<2>>>0;Z=T-1|0;_=(T|0)>0;$=O+1|0;aa=l+($<<2)|0;ca=m+($<<2)|0;da=0;ea=2013265920;fa=P;ga=Q;ha=R;ia=S;while(1){ja=c[p+(da<<8)+(O<<2)>>2]|0;ka=(ja|0)>-1?ja:-ja|0;if(V){la=(ba(ka,v)|0)+A|0}else{ma=d[a+11184+U|0]|0;if((c[x>>2]|0)==0){na=ba(ka<<1|1,h)|0;oa=(ba(na,e[a+12816+(ma<<1)>>1]|0)|0)>>4}else{na=ba(ka,h)|0;oa=(ba(na,e[a+12560+(ma<<1)>>1]|0)|0)>>3}la=(oa<<3)-8|8}ma=la-Y|0;na=(ba(ma,ma)|0)-X|0;ma=ja+64|0;do{if(ma>>>0<128>>>0){if(_){ka=Z;pa=ea;while(1){qa=c[o+(ka<<2)>>2]|0;ra=O-qa|0;sa=ba(d[F+((ra<<7)+ma)|0]|0,t)|0;ta=(c[n+(qa<<2)>>2]|0)+na+sa|0;if((ta|0)<(pa|0)){c[aa>>2]=ra;c[ca>>2]=ja;ua=ta}else{ua=pa}if((ka|0)>0){ka=ka-1|0;pa=ua}else{va=ua;break}}}else{va=ea}if(!V){wa=ia;xa=ha;ya=ga;za=fa;Aa=va;break}if(!_){wa=ia;xa=ha;ya=ga;za=fa;Aa=va;break}pa=ja&65535;ka=Z;ta=fa;ra=ga;sa=ha;qa=ia;while(1){Ba=c[o+(ka<<2)>>2]|0;Ca=O-Ba|0;Da=ba(d[D+((Ca<<7)+ma)|0]|0,t)|0;Ea=(c[n+(Ba<<2)>>2]|0)+na+Da|0;Da=(Ea|0)<(ra|0);Ba=Da?$:ta;Fa=Da?Ea:ra;Ea=Da?pa:sa;Ga=Da?Ca:qa;if((ka|0)>0){ka=ka-1|0;ta=Ba;ra=Fa;sa=Ea;qa=Ga}else{wa=Ga;xa=Ea;ya=Fa;za=Ba;Aa=va;break}}}else{qa=na+N|0;if(_){sa=Z;ra=ea;while(1){ta=c[o+(sa<<2)>>2]|0;ka=(c[n+(ta<<2)>>2]|0)+qa|0;if((ka|0)<(ra|0)){c[aa>>2]=O-ta;c[ca>>2]=ja;Ha=ka}else{Ha=ra}if((sa|0)>0){sa=sa-1|0;ra=Ha}else{Ia=Ha;break}}}else{Ia=ea}if(!V){wa=ia;xa=ha;ya=ga;za=fa;Aa=Ia;break}if(!_){wa=ia;xa=ha;ya=ga;za=fa;Aa=Ia;break}ra=ja&65535;sa=Z;ka=fa;ta=ga;pa=ha;Ba=ia;while(1){Fa=c[o+(sa<<2)>>2]|0;Ea=(c[n+(Fa<<2)>>2]|0)+qa|0;if((Ea|0)<(ta|0)){Ja=O-Fa|0;Ka=ra;La=Ea;Ma=$}else{Ja=Ba;Ka=pa;La=ta;Ma=ka}if((sa|0)>0){sa=sa-1|0;ka=Ma;ta=La;pa=Ka;Ba=Ja}else{wa=Ja;xa=Ka;ya=La;za=Ma;Aa=Ia;break}}}}while(0);ja=da+1|0;if((ja|0)<(W|0)){da=ja;ea=Aa;fa=za;ga=ya;ha=xa;ia=wa}else{Na=Aa;Oa=za;Pa=ya;Qa=xa;Ra=wa;Sa=$;break}}}else{Na=2013265920;Oa=P;Pa=Q;Qa=R;Ra=S;Sa=O+1|0}c[n+(Sa<<2)>>2]=Na;a:do{if(K){$=T;while(1){if(($|0)==0){Ta=0;break a}ia=$-1|0;if((c[n+(c[o+(ia<<2)>>2]<<2)>>2]|0)>(Na|0)){$=ia}else{Ta=$;break}}}else{$=Na+t|0;ia=T;while(1){if((ia|0)==0){Ta=0;break a}ha=ia-1|0;if((c[n+(c[o+(ha<<2)>>2]<<2)>>2]|0)>($|0)){ia=ha}else{Ta=ia;break}}}}while(0);c[o+(Ta<<2)>>2]=Sa;if((Sa|0)>(J|0)){break}else{O=Sa;P=Oa;Q=Pa;R=Qa;S=Ra;T=Ta+1|0}}do{if(((c[w>>2]|0)-1|0)>>>0<2>>>0){Ua=Ra;Va=Qa;Wa=Pa;Xa=Oa}else{T=c[H>>2]|0;S=J+1|0;if((T|0)>(S|0)){Ua=Ra;Va=Qa;Wa=2013265920;Xa=Oa;break}R=t<<1;Q=T;T=Oa;P=2013265920;O=Qa;K=Ra;while(1){N=(c[n+(Q<<2)>>2]|0)+((Q|0)==0?0:R)|0;if((N|0)<(P|0)){Ya=c[l+(Q<<2)>>2]|0;Za=c[m+(Q<<2)>>2]&65535;_a=N;$a=Q}else{Ya=K;Za=O;_a=P;$a=T}N=Q+1|0;if((N|0)>(S|0)){Ua=Ya;Va=Za;Wa=_a;Xa=$a;break}else{Q=N;T=$a;P=_a;O=Za;K=Ya}}}}while(0);H=a+13112+(g<<2)|0;c[H>>2]=Wa;K=b[f>>1]|0;O=K<<16>>16;P=K<<16>>16>-1?O:-O|0;O=Xa-1|0;TGb(f+(B<<1)|0,0,64-B<<1|0)|0;if((O|0)<(B|0)){ab=O;i=k;return ab|0}if((O|B|0)!=0){b[f+(d[a+368+O|0]<<1)>>1]=Va;K=O-Ua|0;if((K|0)>(B|0)){bb=K}else{ab=O;i=k;return ab|0}while(1){K=bb-1|0;b[f+(d[a+368+K|0]<<1)>>1]=c[m+(bb<<2)>>2];T=K-(c[l+(bb<<2)>>2]|0)|0;if((T|0)>(B|0)){bb=T}else{ab=O;break}}i=k;return ab|0}T=ba(P,P)|0;K=c[q>>2]|0;if((K|0)>0){Q=a+12816|0;if(((c[w>>2]|0)-1|0)>>>0<2>>>0){S=0;R=0;N=T;while(1){C=c[p+(S<<8)>>2]|0;ia=(((((ba((C|0)>-1?C:-C|0,v)|0)+A|0)>>>3)+4|0)>>>3<<6)-P|0;$=ba(ia,ia)|0;ia=C+64|0;if(ia>>>0<128>>>0){cb=d[D+ia|0]|0}else{cb=s}ia=(ba(cb,t)|0)+$|0;$=(ia|0)<(N|0);ha=$?C:R;C=$?ia:N;ia=S+1|0;if((ia|0)<(K|0)){S=ia;R=ha;N=C}else{db=ha;eb=C;break}}}else{N=0;R=0;S=T;while(1){w=c[p+(N<<8)>>2]|0;C=ba(((w|0)>-1?w:-w|0)<<1|1,h)|0;ha=(((((ba(C,e[Q>>1]|0)|0)>>4)+536870911|1)+4|0)>>>3<<6)-P|0;C=ba(ha,ha)|0;ha=w+64|0;if(ha>>>0<128>>>0){fb=d[D+ha|0]|0}else{fb=s}ha=(ba(fb,t)|0)+C|0;C=(ha|0)<(S|0);ia=C?w:R;w=C?ha:S;ha=N+1|0;if((ha|0)<(K|0)){N=ha;R=ia;S=w}else{db=ia;eb=w;break}}}}else{db=0;eb=T}b[f>>1]=db;c[H>>2]=eb-T;ab=(db|0)==0?-1:O;i=k;return ab|0}}while(0);TGb(f+(B<<1)|0,0,64-B<<1|0)|0;ab=J;i=k;return ab|0}function pPa(a){a=a|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;e=i;f=c[a+60>>2]|0;h=f;HOa(h);TGb(8593720,1,32)|0;c[f+12460>>2]=8524096;c[f+11856>>2]=8589640;c[f+100>>2]=0;c[f+112>>2]=0;j=a+48|0;k=c[j>>2]|0;a:do{if((k|0)==8|(k|0)==108){l=c[a+140>>2]|0;switch(l|0){case 12:case 13:case 14:{m=l;n=9;break a;break};case 0:case 4:case 5:{if(!((c[a+680>>2]|0)>-1)){m=l;n=9;break a}break};default:{}}yDb(a,16,2208960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((k|0)==2){l=c[a+140>>2]|0;if((l|0)==0|(l|0)==4){m=l;n=9;break}yDb(a,16,2218280,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else{if((c[a+140>>2]|0)==0){n=12;break}yDb(a,16,2200360,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((n|0)==9){if((m|0)==13|(m|0)==4){c[f+14212>>2]=2;break}else if((m|0)==14|(m|0)==5){c[f+14212>>2]=3;break}else{n=12;break}}}while(0);if((n|0)==12){c[f+14212>>2]=1}m=a+72|0;c[f+24>>2]=c[m>>2];k=a+120|0;l=f+8|0;c[l>>2]=c[k>>2];q=a+124|0;r=f+12|0;c[r>>2]=c[q>>2];s=a+136|0;t=c[s>>2]|0;do{if((t|0)>600){if(!((c[a+680>>2]|0)>-2)){u=t;break}yDb(a,24,2191832,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=600,o)|0);i=o;c[s>>2]=600;u=600}else{u=t}}while(0);t=f+16|0;c[t>>2]=u;s=f+4|0;c[s>>2]=a;v=a+88|0;w=f+60|0;c[w>>2]=c[v>>2];c[f+64>>2]=c[a+92>>2];x=a+156|0;y=c[x>>2]|0;if((y|0)>16){yDb(a,16,2175344,(o=i,i=i+8|0,c[o>>2]=16,o)|0);i=o;c[x>>2]=16;z=16;A=c[t>>2]|0}else{z=y;A=u}u=f+68|0;c[u>>2]=z;z=a+12|0;y=f+48|0;c[y>>2]=c[(c[z>>2]|0)+12>>2];c[f+80>>2]=c[a+680>>2];x=f+13924|0;c[x>>2]=(c[v>>2]|0)>>>4&1;B=f+14004|0;c[B>>2]=c[a+180>>2];C=f+14252|0;c[C>>2]=(c[a+628>>2]|0)!=0;c[f+14176>>2]=c[a+324>>2];D=f+760|0;c[D>>2]=0;c[D+4>>2]=-2147483648;D=f+20|0;if((A|0)<2){c[D>>2]=1;c[t>>2]=12}else{c[D>>2]=0}c[f+11732>>2]=c[a+144>>2];t=(c[v>>2]|0)>>>1&1;A=f+52|0;c[A>>2]=t;E=c[s>>2]|0;do{if(+g[E+192>>2]!=0.0){n=28}else{if(+g[E+208>>2]!=0.0){n=28;break}if(+g[E+196>>2]!=0.0){n=28;break}if(+g[E+200>>2]!=0.0){n=28;break}if(+g[E+204>>2]!=0.0){n=28;break}if(+g[E+336>>2]!=0.0){n=28;break}if((c[f+14404>>2]&4|0)==0){G=0}else{n=28}}}while(0);if((n|0)==28){G=t^1}c[f+9980>>2]=G;G=f+13836|0;c[G>>2]=(c[w>>2]|0)>>>11&1;t=a+540|0;E=c[t>>2]|0;H=a+524|0;I=(c[H>>2]|0)==0;do{if((E|0)==0){if(I){J=0}else{n=48}}else{if(!I){if((c[H>>2]|0)==0){n=48;break}else{J=E;break}}switch(c[j>>2]|0){case 1:case 2:{if((E|0)>15e6){K=((E*112|0|0)/15e6|0)<<14}else{K=1835008}L=K;M=K;n=45;break};case 13:case 15:case 16:case 17:{do{if((E|0)>14999999){N=(((E*440|0)+1989934592|0)/234e5|0)+320|0;c[H>>2]=N;O=N}else{if((E|0)>1999999){N=(((E*240|0)-48e7|0)/13e6|0)+80|0;c[H>>2]=N;O=N;break}if((E|0)>383999){N=(((E*40|0)-1536e4|0)/1616e3|0)+40|0;c[H>>2]=N;O=N;break}else{c[H>>2]=40;O=40;break}}}while(0);N=O<<14;L=N;M=N;n=45;break};default:{P=E}}do{if((n|0)==45){c[H>>2]=M;if((L|0)==0){P=E;break}yDb(a,32,2164968,(o=i,i=i+8|0,c[o>>2]=(L|0)/8192|0,o)|0);i=o;P=c[t>>2]|0}}while(0);if((P|0)==0^(c[H>>2]|0)==0){n=48}else{J=P}}}while(0);do{if((n|0)==48){yDb(a,16,2158320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;P=c[t>>2]|0;if((P|0)==0){J=0;break}if((c[H>>2]|0)==0){p=-1}else{J=P;break}i=e;return p|0}}while(0);P=a+544|0;L=c[P>>2]|0;do{if((L|0)==0){Q=0}else{if((J|0)==(L|0)){R=J}else{yDb(a,32,2151320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;R=c[P>>2]|0}if((R|0)==0){Q=0;break}if((R|0)<=(c[m>>2]|0)){Q=R;break}yDb(a,16,2144328,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);R=c[t>>2]|0;do{if((R|0)!=0){t=c[m>>2]|0;if((R|0)<(t|0)){yDb(a,16,2138712,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else{if((R|0)!=(t|0)|(R|0)==(Q|0)){break}yDb(a,32,2132424,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);Q=c[H>>2]|0;do{if((Q|0)!=0){H=c[m>>2]|0;R=c[a+104>>2]|0;t=gHb(R,(R|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;H=F;R=c[a+108>>2]|0;P=gHb(R,(R|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;R=F;if(!((H|0)>(R|0)|(H|0)==(R|0)&t>>>0>P>>>0)){break}yDb(a,16,2126032,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((c[A>>2]|0)==0){P=c[m>>2]|0;t=c[a+76>>2]|0;if(!(+(P|0)*(+(c[a+104>>2]|0)/+(c[a+108>>2]|0))>+(t|0))){break}yDb(a,16,2120208,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=P,o)|0);i=o;p=-1;i=e;return p|0}}while(0);m=c[s>>2]|0;A=c[m+540>>2]|0;do{if((A|0)!=0){if((c[m+544>>2]|0)!=(A|0)){break}if(!(((c[y>>2]|0)-1|0)>>>0<2>>>0)){break}P=Q-1|0;t=gHb(P,(P|0)<0|0?-1:0,9e4,0)|0;P=F;R=gHb(A,(A|0)<0|0?-1:0,65535,0)|0;H=F;if(!((P|0)>(H|0)|(P|0)==(H|0)&t>>>0>R>>>0)){break}yDb(a,32,2114056,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);do{if((c[w>>2]&4|0)!=0){A=c[y>>2]|0;if((A|0)==13|(A|0)==5|(A|0)==20|(A|0)==22){break}yDb(a,16,2099824,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);A=f+13788|0;do{if((c[A>>2]|0)!=0){if((c[(c[s>>2]|0)+296>>2]|0)==0){break}yDb(a,16,2093304,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((c[x>>2]|0)!=0){if((c[y>>2]|0)==13){break}yDb(a,16,2087984,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);x=c[u>>2]|0;Q=c[y>>2]|0;do{if((x|0)!=0){if(!((Q|0)==13|(Q|0)==1|(Q|0)==2)){yDb(a,16,2083400,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}if((x|0)>=0){break}yDb(a,16,2077752,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((Q|0)==13|(Q|0)==5|(Q|0)==20){x=a+224|0;m=c[x>>2]|0;R=c[a+228>>2]|0;if(!((m|0)>255|(R|0)>255)){S=Q;break}t=a+228|0;yDb(a,24,2072920,(o=i,i=i+16|0,c[o>>2]=m,c[o+8>>2]=R,o)|0);i=o;R=c[x>>2]|0;m=c[t>>2]|0;iFb(x,t,R,(R|0)<0|0?-1:0,m,(m|0)<0|0?-1:0,255,0)|0;S=c[y>>2]|0}else{S=Q}}while(0);b:do{if((S|0)==1){n=98}else if((S|0)==5|(S|0)==20){do{if((c[k>>2]|0)<=2048){if((c[q>>2]|0)>1152){break}if((S|0)==1){n=98;break b}else if(!((S|0)==5|(S|0)==20)){break b}do{if((c[k>>2]&3|0)==0){if((c[q>>2]&3|0)!=0){break}if((S|0)==1){n=98;break b}else{break b}}}while(0);yDb(a,16,2063984,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);yDb(a,16,2068304,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((n|0)==98){if((c[k>>2]|0)<=4095){if((c[q>>2]|0)<=4095){break}}yDb(a,16,2060096,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);Q=(S|0)==2;do{if(Q){if((c[k>>2]|0)<=16383){if((c[q>>2]|0)<=16383){break}}yDb(a,16,2055304,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);c:do{if((S|0)==7){n=110}else if((S|0)==6){do{if((c[k>>2]&15|0)==0){if((c[q>>2]&15|0)!=0){break}if((S|0)==7){n=110;break c}else{break c}}}while(0);yDb(a,16,2044528,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=e;return p|0}}while(0);do{if((n|0)==110){if((c[k>>2]&3|0)==0){if((c[q>>2]&3|0)==0){break}}yDb(a,16,2039464,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=e;return p|0}}while(0);do{if((S-18|0)>>>0<2>>>0){if((c[k>>2]&1|0)==0){break}yDb(a,16,2036200,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);k=c[w>>2]|0;do{if((k&537133056|0)!=0){if((S|0)==13|(S|0)==2){break}yDb(a,16,2032560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((c[B>>2]|0)!=0){if((S|0)==13|(S|0)==2){break}yDb(a,16,2028368,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);q=c[f+14404>>2]|0;do{if((q&8|0)!=0){if((c[a+600>>2]|0)!=0){break}yDb(a,16,2024792,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);m=c[s>>2]|0;do{if((q&4|0)!=0){if((c[m+296>>2]|0)==2){break}yDb(a,16,2021432,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);if((c[m+308>>2]|0)<1e9&(k|0)<0){yDb(a,16,2017504,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}do{if((k&524288|0)==0){T=S}else{if(!Q){yDb(a,16,2013536,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}if((c[u>>2]|0)==0){T=2;break}yDb(a,16,2009352,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((c[f+14192>>2]|0)==1){if((c[a+504>>2]|0)<=12){break}yDb(a,16,1998992,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);Q=m+808|0;S=c[Q>>2]|0;k=(S|0)>1;d:do{if(k){switch(T|0){case 13:case 1:case 2:case 8:case 20:{n=144;break d;break};default:{}}yDb(a,16,1994816,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else{if((S|0)>=1){if((c[m+404>>2]|0)>1|k){n=144;break}else{U=S;break}}yDb(a,16,1991512,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);if((n|0)==144){c[C>>2]=1;U=c[Q>>2]|0}if((U|0)>1&(T|0)==20){c[f+13824>>2]=1}T=a+108|0;U=c[T>>2]|0;do{if((U|0)!=0){Q=a+104|0;S=c[Q>>2]|0;if((S|0)==0){break}if((c[a+320>>2]|0)>4194303){yDb(a,16,1983672,(o=i,i=i+8|0,c[o>>2]=4194303,o)|0);i=o;p=-1;i=e;return p|0}k=a+168|0;do{if((c[k>>2]|0)==0){V=U;W=S}else{if((c[v>>2]&1024|0)==0){V=U;W=S;break}yDb(a,32,1980896,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[k>>2]=0;V=c[T>>2]|0;W=c[Q>>2]|0}}while(0);S=GDb(V,(V|0)<0|0?-1:0,W,(W|0)<0|0?-1:0)|0;m=S;if((m|0)>1){yDb(a,32,1978184,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[T>>2]=(c[T>>2]|0)/(m|0)|0;c[Q>>2]=(c[Q>>2]|0)/(m|0)|0}do{if((c[B>>2]|0)==0){m=c[y>>2]|0;if((m|0)==1|(m|0)==2|(m|0)==8|(m|0)==108){n=159;break}c[f+13072>>2]=0;c[f+13076>>2]=-64;X=0;Y=-64}else{n=159}}while(0);if((n|0)==159){c[f+13072>>2]=96;c[f+13076>>2]=0;X=96;Y=0}Q=a+500|0;m=c[Q>>2]|0;if((m|0)>(c[a+504>>2]|0)|(m|0)<1){yDb(a,16,1975632,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=e;return p|0}m=c[a+280>>2]|0;if((m|0)==999999){Z=X}else{c[f+13072>>2]=m;Z=m}m=c[a+284>>2]|0;S=f+13076|0;if((m|0)==999999){_=Y}else{c[S>>2]=m;_=m}m=a;q=f+13072|0;yDb(m,48,1973568,(o=i,i=i+16|0,c[o>>2]=Z,c[o+8>>2]=_,o)|0);i=o;R=c[s>>2]|0;t=c[R+108>>2]|0;if((c[j>>2]|0)==13&(t|0)>65535){yDb(m,16,1970800,(o=i,i=i+24|0,c[o>>2]=c[R+104>>2],c[o+8>>2]=t,c[o+16>>2]=65535,o)|0);i=o;p=-1;i=e;return p|0}R=t-1|0;t=R>>>0>65535>>>0;x=t?R>>>16:R;R=t?16:0;if((x&65280|0)==0){$=R;aa=x}else{$=R|8;aa=x>>>8}c[f+13844>>2]=$+1+(d[1191992+aa|0]|0);e:do{switch(c[(c[z>>2]|0)+12>>2]|0){case 1:{c[f+28>>2]=0;x=c[w>>2]&524288;c[f+13944>>2]=x>>>19;if((x|0)==0){ba=(c[u>>2]|0)+1|0}else{ba=0}c[a+116>>2]=ba;break};case 19:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;c[f+14092>>2]=5;c[f+14088>>2]=1;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 2:{c[f+28>>2]=0;x=c[w>>2]&524288;c[f+13944>>2]=x>>>19;if((x|0)==0){ca=(c[u>>2]|0)+1|0}else{ca=0}c[a+116>>2]=ca;c[C>>2]=1;break};case 8:case 108:{c[f+28>>2]=3;c[D>>2]=1;if((GLa(h)|0)<0){p=-1;i=e;return p|0}else{c[a+116>>2]=0;c[f+13944>>2]=1;break e}break};case 5:{if((Q0a(1210824,8,c[l>>2]|0,c[r>>2]|0)|0)!=8){c[f+28>>2]=2;c[a+116>>2]=0;c[f+13944>>2]=1;break e}x=c[r>>2]|0;yDb(m,16,1959464,(o=i,i=i+16|0,c[o>>2]=c[l>>2],c[o+8>>2]=x,o)|0);i=o;p=-1;i=e;return p|0};case 7:{c[f+28>>2]=2;c[a+116>>2]=0;c[f+13944>>2]=1;c[f+13832>>2]=1;c[f+228>>2]=1;c[f+40>>2]=1;c[G>>2]=1;c[f+10048>>2]=0;break};case 4:{if((sca(c[l>>2]|0,c[r>>2]|0)|0)>=0){c[f+28>>2]=1;c[a+116>>2]=0;c[f+13944>>2]=1;break e}x=c[r>>2]|0;yDb(m,16,1962168,(o=i,i=i+16|0,c[o>>2]=c[l>>2],c[o+8>>2]=x,o)|0);i=o;p=-1;i=e;return p|0};case 17:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;c[f+14092>>2]=3;c[f+14088>>2]=1;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 18:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;c[f+14092>>2]=4;c[f+14088>>2]=1;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 20:{c[f+28>>2]=2;c[f+40>>2]=1;x=(c[v>>2]|0)>>>24&1;c[f+228>>2]=x;c[f+13832>>2]=x;x=c[v>>2]&2048;c[G>>2]=x>>>11;if((c[A>>2]|x|0)==0){da=(c[f+13816>>2]|0)!=0|0}else{da=1}c[f+10048>>2]=da;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 22:{c[f+28>>2]=2;c[f+44>>2]=2;c[f+10048>>2]=1;c[C>>2]=0;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 6:{c[f+28>>2]=2;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 13:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;x=c[u>>2]|0;R=(x|0)==0;c[f+13944>>2]=R&1;c[a+116>>2]=R?0:x+1|0;break};case 16:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;c[f+14092>>2]=2;c[a+116>>2]=0;c[f+13944>>2]=1;break};default:{p=-1;i=e;return p|0}}}while(0);c[a+176>>2]=(c[f+13944>>2]|0)==0;c[f+56>>2]=1;if((c[v>>2]&537133056|0)==0){ea=(c[f+14200>>2]|0)==0|0}else{ea=0}c[f+14152>>2]=ea;c[f+14224>>2]=ea;if((FOa(h)|0)<0){p=-1;i=e;return p|0}c[(c[s>>2]|0)+804>>2]=f+7624;m=f+14092|0;do{if((c[m>>2]|0)==0){n=203}else{x=cEb(135200)|0;c[f+14108>>2]=x;if((x|0)!=0){n=203;break}yDb(c[s>>2]|0,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);f:do{if((n|0)==203){x=cEb(256)|0;c[(c[s>>2]|0)+668>>2]=x;x=c[s>>2]|0;if((c[x+668>>2]|0)==0){yDb(x,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=cEb(8192)|0;R=f+13160|0;c[R>>2]=x;if((x|0)==0){yDb(c[s>>2]|0,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=cEb(8192)|0;c[f+13164>>2]=x;if((x|0)==0){yDb(c[s>>2]|0,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=cEb(8192)|0;t=f+13168|0;c[t>>2]=x;if((x|0)==0){yDb(c[s>>2]|0,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=cEb(8192)|0;H=f+13172|0;c[H>>2]=x;if((x|0)==0){yDb(c[s>>2]|0,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=cEb(8192)|0;c[f+13176>>2]=x;if((x|0)==0){yDb(c[s>>2]|0,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=cEb(8192)|0;P=f+13180|0;c[P>>2]=x;if((x|0)==0){yDb(c[s>>2]|0,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=cEb(144)|0;c[f+160>>2]=x;if((x|0)==0){yDb(c[s>>2]|0,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=cEb(144)|0;c[f+164>>2]=x;J=c[s>>2]|0;if((x|0)==0){yDb(J,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}do{if((c[J+312>>2]|0)!=0){x=cEb(256)|0;c[f+13196>>2]=x;if((x|0)!=0){break}yDb(c[s>>2]|0,16,1957384,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break f}}while(0);Jca(f+11548|0);J=f+14392|0;x=c[J>>2]|0;if((x|0)==0){c[J>>2]=2;fa=2}else{fa=x}x=f+14400|0;if((c[x>>2]|0)==0){c[x>>2]=524}c[f+14396>>2]=fa;x=c[s>>2]|0;if((c[x+600>>2]|0)!=0){c[J>>2]=50}if((c[f+13832>>2]|0)!=0){c[f+9896>>2]=1211152}c[f+13920>>2]=5;J=f+10056|0;V3(J,f+10540|0,c[x+244>>2]|0);V3(J,f+10564|0,c[(c[s>>2]|0)+596>>2]|0);x=f+28|0;L=c[x>>2]|0;if((L|0)==1){wca(h);ga=c[x>>2]|0}else{ga=L}if((ga|0)==2){Olb(h)}if((c[m>>2]|0)!=0){$Pa(h)}if((c[x>>2]|0)==0){MMa(h)}L=f+12560|0;E=L;M=f+12816|0;O=M;K=0;do{I=d[f+(K+11184)|0]|0;do{if((c[y>>2]|0)==13){if((c[B>>2]|0)==0){n=244;break}b[E+(I<<1)>>1]=b[1177024+(K<<1)>>1]|0;b[O+(I<<1)>>1]=b[1176896+(K<<1)>>1]|0}else{n=244}}while(0);do{if((n|0)==244){n=0;if(((c[x>>2]|0)-1|0)>>>0<2>>>0){N=b[1179048+(K<<1)>>1]|0;b[O+(I<<1)>>1]=N;b[E+(I<<1)>>1]=N;break}else{b[E+(I<<1)>>1]=b[1179176+(K<<1)>>1]|0;b[O+(I<<1)>>1]=b[1179048+(K<<1)>>1]|0;break}}}while(0);N=c[s>>2]|0;ha=c[N+300>>2]|0;if((ha|0)==0){ia=N}else{b[E+(I<<1)>>1]=b[ha+(K<<1)>>1]|0;ia=c[s>>2]|0}ha=c[ia+304>>2]|0;if((ha|0)!=0){b[O+(I<<1)>>1]=b[ha+(K<<1)>>1]|0}K=K+1|0;}while((K|0)<64);if((c[x>>2]|0)!=3){iPa(J,c[R>>2]|0,c[H>>2]|0,L,c[q>>2]|0,c[Q>>2]|0,31,1);iPa(J,c[t>>2]|0,c[P>>2]|0,M,c[S>>2]|0,c[Q>>2]|0,31,0)}if((kUa(h)|0)<0){p=-1;i=e;return p|0}K=c[a+868>>2]|0;if((K|0)!=0){c[f+14592>>2]=K}if((c[k>>2]|0)!=2){p=0;i=e;return p|0}K=f+14596|0;O=a+356|0;E=0;while(1){if((E|0)>=((c[u>>2]|0)+2|0)){p=0;n=263;break}ha=ICb()|0;c[K+(E<<2)>>2]=ha;if((ha|0)==0){p=-12;n=263;break}c[ha+80>>2]=0;c[ha+68>>2]=c[l>>2]>>c[O>>2];c[ha+72>>2]=c[r>>2]>>c[O>>2];N=LCb(ha,32)|0;if((N|0)<0){p=N;n=263;break}else{E=E+1|0}}if((n|0)==263){i=e;return p|0}}}while(0);qPa(a)|0;p=-1313558101;i=e;return p|0}}while(0);yDb(a,16,1988136,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}function qPa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+60>>2]|0;d=b;oUa(d);LOa(d);if((c[b+28>>2]|0)==3){HLa(d)}$Db(a+96|0);JCb(b+14596|0);JCb(b+14600|0);JCb(b+14604|0);JCb(b+14608|0);JCb(b+14612|0);JCb(b+14616|0);JCb(b+14620|0);JCb(b+14624|0);JCb(b+14628|0);JCb(b+14632|0);JCb(b+14636|0);JCb(b+14640|0);JCb(b+14644|0);JCb(b+14648|0);JCb(b+14652|0);JCb(b+14656|0);JCb(b+14660|0);JCb(b+14664|0);a=b+5400|0;yOa(a);AOa(d,a);$Db((c[b+4>>2]|0)+668|0);$Db(b+14108|0);a=b+13164|0;d=a;e=b+13160|0;if((c[d>>2]|0)!=(c[e>>2]|0)){$Db(a)}a=b+13176|0;f=a;g=b+13172|0;if((c[f>>2]|0)==(c[g>>2]|0)){c[d>>2]=0;c[f>>2]=0;$Db(e);h=b+13168|0;$Db(h);$Db(g);i=b+13180|0;$Db(i);j=b+160|0;$Db(j);k=b+164|0;$Db(k);l=b+13196|0;$Db(l);return 0}$Db(a);c[d>>2]=0;c[f>>2]=0;$Db(e);h=b+13168|0;$Db(h);$Db(g);i=b+13180|0;$Db(i);j=b+160|0;$Db(j);k=b+164|0;$Db(k);l=b+13196|0;$Db(l);return 0}function rPa(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0.0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0;m=i;i=i+288|0;n=m|0;o=m+80|0;p=m+88|0;q=m+168|0;r=m+176|0;s=m+256|0;t=m+264|0;u=m+272|0;v=m+280|0;w=c[f+60>>2]|0;y=w;z=w+944|0;A=c[z>>2]|0;B=w+112|0;c[B>>2]=(c[B>>2]|0)+1;C=w+68|0;D=c[C>>2]|0;if((D|0)==0){G=(c[w+13944>>2]|0)==0|0}else{G=D}do{if((k|0)==0){H=0}else{D=k+136|0;I=c[D>>2]|0;J=c[D+4>>2]|0;D=w+100|0;K=c[D>>2]|0;c[D>>2]=K+1;D=w+760|0;L=c[D>>2]|0;M=c[D+4>>2]|0;N=(L|0)!=0|(M|0)!=(-2147483648|0);do{if((I|0)==0&(J|0)==(-2147483648|0)){if(N){O=YGb(L,M,1,0)|0;R=F;c[D>>2]=O;c[D+4>>2]=R;yDb(c[w+4>>2]|0,32,2338112,(T=i,i=i+16|0,c[T>>2]=O,c[T+8>>2]=R,T)|0);i=T;U=R;V=O;break}else{U=(K|0)<0|0?-1:0;V=K;break}}else{do{if(N){if((J|0)>(M|0)|(J|0)==(M|0)&I>>>0>L>>>0){if(!((c[w+13944>>2]|0)==0&(K|0)==1)){break}O=ZGb(I,J,L,M)|0;R=w+768|0;c[R>>2]=O;c[R+4>>2]=F;break}else{yDb(c[w+4>>2]|0,16,2339448,(T=i,i=i+32|0,c[T>>2]=I,c[T+8>>2]=J,c[T+16>>2]=L,c[T+24>>2]=M,T)|0);i=T;W=-1;i=m;return W|0}}}while(0);c[D>>2]=I;c[D+4>>2]=J;U=J;V=I}}while(0);I=w+148|0;J=w+152|0;D=c[J>>2]|0;M=w+8|0;if((c[M>>2]&15|0)==0){L=c[I>>2]|0;if((c[w+12>>2]&15|0)==0){X=(c[k+40>>2]|0)==(D|0)?(c[k+36>>2]|0)==(D|0)?(c[k+32>>2]|0)==(L|0)?(c[k+360>>2]|0)!=0|0:0:0:0;Y=L}else{Z=L;_=17}}else{Z=c[I>>2]|0;_=17}if((_|0)==17){X=0;Y=Z}L=k|0;a:do{if((X|0)==0|(c[L>>2]&7|0)!=0|(Y&7|0)!=0){D=QOa(y,0)|0;if((D|0)<0){W=-1;i=m;return W|0}N=c[w+156>>2]|0;R=N+(D*2224|0)|0;c[N+(D*2224|0)+2192>>2]=3;if((zOa(y,R,0)|0)<0){W=-1;i=m;return W|0}do{if(((c[R>>2]|0)+16|0)==(c[L>>2]|0)){if(((c[N+(D*2224|0)+4>>2]|0)+16|0)!=(c[k+4>>2]|0)){break}if(((c[N+(D*2224|0)+8>>2]|0)+16|0)==(c[k+8>>2]|0)){$=R;break a}}}while(0);O=w+4|0;eFb(c[(c[O>>2]|0)+140>>2]|0,u,v)|0;ca=w+12|0;da=w+48|0;ea=w+11260|0;fa=0;while(1){ha=c[k+32+(fa<<2)>>2]|0;ia=(fa|0)!=0;ja=c[(ia?J:I)>>2]|0;ka=ia?c[u>>2]|0:0;la=ia?c[v>>2]|0:0;ia=c[M>>2]>>ka;ma=c[ca>>2]|0;na=ma>>la;oa=c[k+(fa<<2)>>2]|0;pa=c[N+(D*2224|0)+(fa<<2)>>2]|0;qa=c[O>>2]|0;do{if((c[da>>2]|0)==108){if((c[qa+88>>2]&16384|0)!=0){ra=na;break}ra=((ma+15|0)/16|0)<<4>>la}else{ra=na}}while(0);na=(c[qa+524>>2]|0)==0?pa+16|0:pa;do{if((ha|0)==(ja|0)){UGb(na|0,oa|0,ba(ra,ha)|0)|0}else{if((ra|0)==0){break}else{sa=oa;ta=ra;ua=na}while(1){ma=ta-1|0;UGb(ua|0,sa|0,ia)|0;if((ma|0)==0){break}else{sa=sa+ha|0;ta=ma;ua=ua+ja|0}}}}while(0);if((c[M>>2]&15|0)==0){if((c[ca>>2]&15|0)!=0){_=37}}else{_=37}if((_|0)==37){_=0;Ke[c[ea>>2]&1023](na,ja,ia,ra,16>>>(ka>>>0),16>>>(la>>>0),2)}ha=fa+1|0;if((ha|0)<3){fa=ha}else{$=R;break}}}else{R=QOa(y,1)|0;if((R|0)<0){W=-1;i=m;return W|0}fa=c[w+156>>2]|0;ea=fa+(R*2224|0)|0;c[fa+(R*2224|0)+2192>>2]=3;if((MCb(ea|0,k)|0)<0){W=-1;i=m;return W|0}if((zOa(y,ea,1)|0)<0){W=-1}else{$=ea;break}i=m;return W|0}}while(0);if((NCb($|0,k)|0)<0){W=-1;i=m;return W|0}else{c[$+164>>2]=K;M=$+136|0;c[M>>2]=V;c[M+4>>2]=U;H=$;break}}}while(0);$=w+160|0;U=1;V=c[$>>2]|0;do{c[V+(U-1<<2)>>2]=c[V+(U<<2)>>2];U=U+1|0;V=c[$>>2]|0}while((U|0)<36);c[V+(G<<2)>>2]=H;H=w+164|0;G=1;V=c[H>>2]|0;do{c[V+(G-1<<2)>>2]=c[V+(G<<2)>>2];G=G+1|0;V=c[H>>2]|0}while((G|0)<36);c[V+140>>2]=0;V=c[H>>2]|0;b:do{if((c[V>>2]|0)==0){G=c[c[$>>2]>>2]|0;if((G|0)==0){va=V;break}U=w+4|0;k=c[U>>2]|0;if((c[k+584>>2]|0)==0){if((c[k+588>>2]|0)==0){wa=k}else{_=49}}else{_=49}do{if((_|0)==49){if((c[B>>2]|0)>=(c[w+16>>2]|0)){wa=k;break}ra=c[w+9852>>2]|0;if((ra|0)==0){wa=k;break}ua=w+120|0;ta=w+116|0;sa=G+2196|0;v=w+10568|0;u=0;Y=0;X=0;Z=0;M=c[ua>>2]|0;I=k;while(1){J=c[G+32+(Z<<2)>>2]|0;L=(Z|0)!=0?1:2;if((ba(L,M)|0)>0){ea=G+(Z<<2)|0;R=ra+(Z<<2)|0;fa=u;ca=Y;da=X;O=0;D=c[ta>>2]|0;N=M;ha=I;while(1){if((ba(D,L)|0)>0){oa=ba(O,J)|0;pa=fa;qa=ca;ma=da;xa=0;while(1){ya=xa+oa<<3;za=Pe[c[v>>2]&255](w,(c[ea>>2]|0)+(((c[sa>>2]|0)!=0?0:16)+ya)|0,(c[R>>2]|0)+ya|0,J,8)|0;Aa=c[U>>2]|0;ya=c[Aa+592>>2]|0;switch(((ya|0)>-1?ya:-ya|0)|0){case 0:{Ba=(ma|0)>(za|0)?ma:za;Ca=pa;Da=qa;break};case 2:{ya=za;Ea=(za|0)<0|0?-1:0;Fa=YGb(gHb(ya,Ea,ya,Ea)|0,F,qa,pa)|0;Ba=ma;Ca=F;Da=Fa;break};case 3:{Fa=za;Ea=(za|0)<0|0?-1:0;ya=gHb(gHb(Fa,Ea,Fa,Ea)|0,F,Fa,Ea)|0;Ea=F;Fa=-1;Ga=(Ea|0)>(Fa|0)|(Ea|0)==(Fa|0)&ya>>>0>-1>>>0;Fa=ZGb(0,0,ya,Ea)|0;Ha=YGb(Ga?ya:Fa,Ga?Ea:F,qa,pa)|0;Ba=ma;Ca=F;Da=Ha;break};case 1:{Ba=((za|0)>-1?za:-za|0)+ma|0;Ca=pa;Da=qa;break};case 4:{Ha=za;Ea=(za|0)<0|0?-1:0;za=gHb(Ha,Ea,Ha,Ea)|0;Ea=F;Ha=YGb(gHb(za,Ea,za,Ea)|0,F,qa,pa)|0;Ba=ma;Ca=F;Da=Ha;break};default:{Ba=ma;Ca=pa;Da=qa}}Ha=xa+1|0;Ia=c[ta>>2]|0;if((Ha|0)<(ba(Ia,L)|0)){pa=Ca;qa=Da;ma=Ba;xa=Ha}else{break}}Ja=Ca;Ka=Da;La=Ba;Ma=Ia;Na=c[ua>>2]|0;Oa=Aa}else{Ja=fa;Ka=ca;La=da;Ma=D;Na=N;Oa=ha}xa=O+1|0;if((xa|0)<(ba(Na,L)|0)){fa=Ja;ca=Ka;da=La;O=xa;D=Ma;N=Na;ha=Oa}else{Pa=Ja;Qa=Ka;Ra=La;Sa=Na;Ta=Oa;break}}}else{Pa=u;Qa=Y;Ra=X;Sa=M;Ta=I}ha=Z+1|0;if((ha|0)<3){u=Pa;Y=Qa;X=Ra;Z=ha;M=Sa;I=Ta}else{break}}I=(Ra|0)==0;M=I?Qa:Ra;Z=I?Pa:(Ra|0)<0|0?-1:0;I=c[Ta+592>>2]|0;if((I|0)<0){Ua=+S(+((+(M>>>0)+ +(Z|0)*4294967296.0)/+(ba(c[ta>>2]|0,Sa)|0)),+(-1.0/+(I|0)));Va=(E=+Ua,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);Wa=~~+Ua>>>0}else{Va=Z;Wa=M}M=c[Ta+584>>2]|0;Z=(M|0)<0|0?-1:0;if(!((Va|0)<(Z|0)|(Va|0)==(Z|0)&Wa>>>0<M>>>0)){M=c[Ta+588>>2]|0;Z=gHb(c[w+9968>>2]|0,0,M,(M|0)<0|0?-1:0)|0;M=F;I=M>>8|((M|0)<0|0?-1:0)<<24;if(!((Va|0)<(I|0)|(Va|0)==(I|0)&Wa>>>0<(Z>>>8|M<<24)>>>0)){wa=Ta;break}}KCb(c[c[$>>2]>>2]|0);pUa(y,0)|0;va=c[H>>2]|0;break b}}while(0);G=w+9852|0;do{if((c[G>>2]|0)!=0){if((c[w+20>>2]|0)!=0){break}k=w+60|0;c:do{if((c[k>>2]&1024|0)!=0){K=(c[C>>2]|0)+1|0;if((K|0)<=0){break}M=c[$>>2]|0;Z=c[(c[M>>2]|0)+164>>2]|0;I=c[w+13232>>2]|0;X=w+13236|0;Y=0;while(1){Xa=Y+Z|0;if((Xa|0)>=(I|0)){break c}u=c[M+(Y<<2)>>2]|0;if((u|0)==0){break}c[u+88>>2]=c[(c[X>>2]|0)+(Xa*80|0)+40>>2];Y=Y+1|0;if((Y|0)>=(K|0)){break c}}c[(c[X>>2]|0)+((Xa-1|0)*80|0)+40>>2]=2}}while(0);ta=c[wa+168>>2]|0;d:do{if((ta|0)==0){K=c[C>>2]|0;while(1){if((K|0)==0){Ya=0;_=142;break d}if((c[(c[$>>2]|0)+(K<<2)>>2]|0)==0){K=K-1|0}else{Za=K;_=143;break}}}else if((ta|0)==2){K=t;X=p0a(c[wa+48>>2]|0)|0;Y=ARa(0)|0;c[t>>2]=Y;M=c[U>>2]|0;I=c[M+356>>2]|0;if(!(I>>>0<4>>>0)){yDb(0,0,1948704,(T=i,i=i+24|0,c[T>>2]=2340744,c[T+8>>2]=1944616,c[T+16>>2]=1205,T)|0);i=T;Cd();return 0}Z=c[w+10032>>2]|0;u=c[w+10036>>2]|0;ua=(u|0)==0?Z:u;u=((ba(ua,ua)|0)+64|0)>>>7;c[Y+120>>2]=c[w+8>>2]>>I;c[Y+124>>2]=c[w+12>>2]>>I;sa=Y+88|0;c[sa>>2]=33026;c[sa>>2]=c[M+88>>2]&16|33026;c[Y+296>>2]=c[M+296>>2];c[Y+232>>2]=c[M+232>>2];c[Y+240>>2]=c[M+240>>2];c[Y+236>>2]=c[M+236>>2];c[Y+140>>2]=0;sa=M+104|0;M=Y+104|0;v=c[sa+4>>2]|0;c[M>>2]=c[sa>>2];c[M+4>>2]=v;c[Y+156>>2]=c[C>>2];if((m0a(Y,X,0)|0)<0){Ya=-1;_=142;break}X=c[C>>2]|0;if((X+2|0)>0){Y=y+11264+(I<<2)|0;I=0;v=X;while(1){M=(I|0)!=0;if(M){_a=(c[$>>2]|0)+(I-1<<2)|0}else{_a=G}sa=c[_a>>2]|0;do{if((sa|0)==0){$a=v}else{if(M){if((c[(c[$>>2]|0)+(I-1<<2)>>2]|0)==0){$a=v;break}}ra=c[sa>>2]|0;ha=c[sa+4>>2]|0;N=c[sa+8>>2]|0;D=c[sa+36>>2]|0;O=c[sa+40>>2]|0;if((c[sa+2196>>2]|0)!=0|M^1){ab=ra;bb=ha;cb=N}else{ab=ra+16|0;bb=ha+16|0;cb=N+16|0}N=y+14596+(I<<2)|0;ha=c[N>>2]|0;ra=c[t>>2]|0;Se[c[Y>>2]&511](c[ha>>2]|0,c[ha+32>>2]|0,ab,c[sa+32>>2]|0,c[ra+120>>2]|0,c[ra+124>>2]|0);ra=c[N>>2]|0;ha=c[t>>2]|0;Se[c[Y>>2]&511](c[ra+4>>2]|0,c[ra+36>>2]|0,bb,D,c[ha+120>>2]>>1,c[ha+124>>2]>>1);ha=c[N>>2]|0;N=c[t>>2]|0;Se[c[Y>>2]&511](c[ha+8>>2]|0,c[ha+40>>2]|0,cb,O,c[N+120>>2]>>1,c[N+124>>2]>>1);$a=c[C>>2]|0}}while(0);sa=I+1|0;if((sa|0)<($a+2|0)){I=sa;v=$a}else{db=$a;break}}}else{db=X}e:do{if((db+1|0)>0){v=w+14596|0;I=r;Y=r+28|0;sa=n;M=n+28|0;N=p;O=p+28|0;if((c[c[$>>2]>>2]|0)==0){eb=-1;break}ha=0;D=2147483647;ra=-1;da=-1;ca=c[t>>2]|0;while(1){TGb(ca+720|0,0,24)|0;fa=c[v>>2]|0;c[fa+88>>2]=1;c[fa+168>>2]=118;TGb(I|0,0,80)|0;vZ(r);L=v0a(ca,r,fa,s)|0;if((L|0)<0){fb=L}else{L=c[Y>>2]|0;BZ(r);fb=L}L=c[C>>2]|0;if((L+1|0)>0){fa=ha+1|0;J=0;R=0;ea=0;la=L;while(1){ka=((J|0)%(fa|0)|0|0)==(ha|0)|(J|0)==(la|0);ia=J+1|0;ja=c[y+14596+(ia<<2)>>2]|0;c[ja+88>>2]=ka?2:3;c[ja+168>>2]=ka?Z:ua;ka=c[t>>2]|0;TGb(N|0,0,80)|0;vZ(p);na=v0a(ka,p,ja,q)|0;if((na|0)<0){gb=na}else{na=c[O>>2]|0;BZ(p);gb=na}na=(ba(gb,u)|0)>>4;ja=YGb(na,(na|0)<0|0?-1:0,ea,R)|0;na=F;ka=c[C>>2]|0;if((ia|0)<(ka+1|0)){J=ia;R=na;ea=ja;la=ka}else{hb=gb;ib=na;jb=ja;kb=ka;break}}}else{hb=fb;ib=0;jb=0;kb=L}la=c[t>>2]|0;if((hb|0)==0){lb=ib;mb=jb;nb=kb;ob=la}else{ea=ib;R=jb;J=la;do{TGb(sa|0,0,80)|0;vZ(n);la=v0a(J,n,0,o)|0;if((la|0)<0){pb=la}else{la=c[M>>2]|0;BZ(n);pb=la}la=(ba(pb,u)|0)>>4;R=YGb(la,(la|0)<0|0?-1:0,R,ea)|0;ea=F;J=c[t>>2]|0}while((pb|0)!=0);lb=ea;mb=R;nb=c[C>>2]|0;ob=J}L=ob+720|0;la=ob+728|0;fa=c[la>>2]|0;ka=c[la+4>>2]|0;la=ob+736|0;ja=c[la>>2]|0;na=c[la+4>>2]|0;la=YGb(c[L>>2]|0,c[L+4>>2]|0,mb,lb)|0;L=YGb(la,F,fa,ka)|0;ka=YGb(L,F,ja,na)|0;na=F;ja=(na|0)<(D|0)|(na|0)==(D|0)&ka>>>0<ra>>>0;L=ja?ha:da;fa=ha+1|0;if((fa|0)>=(nb+1|0)){eb=L;break e}if((c[(c[$>>2]|0)+(fa<<2)>>2]|0)==0){eb=L;break}else{ha=fa;D=ja?na:D;ra=ja?ka:ra;da=L;ca=ob}}}else{eb=-1}}while(0);E0a(c[t>>2]|0)|0;$Db(K);Za=eb;_=143}else if((ta|0)==1){u=c[C>>2]|0;if((u|0)>0){ua=w+148|0;Z=w+8|0;X=w+12|0;ca=w+10108|0;da=w+10100|0;ra=1;D=c[$>>2]|0;ha=u;while(1){M=c[D+(ra<<2)>>2]|0;do{if((M|0)==0){qb=D;rb=ha}else{if((c[M+2184>>2]|0)!=0){qb=D;rb=ha;break}sa=c[M>>2]|0;O=c[c[D+(ra-1<<2)>>2]>>2]|0;N=c[ua>>2]|0;Y=c[Z>>2]&-16;I=c[X>>2]&-16;if((I|0)>0){v=(Y|0)>0;L=0;ka=0;while(1){if(v){ja=ba(ka,N)|0;na=L;fa=0;while(1){la=fa+ja|0;ia=sa+la|0;xa=Pe[c[ca>>2]&255](0,ia,O+la|0,N,16)|0;ma=(Oe[c[da>>2]&1023](ia,N)|0)+128>>8;ia=0;qa=0;while(1){pa=(ba(ia,N)|0)+la|0;oa=0;sb=qa;do{Ha=(d[sa+(pa+oa)|0]|0)-ma|0;sb=((Ha|0)>-1?Ha:-Ha|0)+sb|0;oa=oa+1|0;}while((oa|0)<16);oa=ia+1|0;if((oa|0)<16){ia=oa;qa=sb}else{break}}qa=((sb+500|0)<(xa|0))+na|0;ia=fa+16|0;if((ia|0)<(Y|0)){na=qa;fa=ia}else{tb=qa;break}}}else{tb=L}fa=ka+16|0;if((fa|0)<(I|0)){L=tb;ka=fa}else{break}}ka=c[$>>2]|0;ub=tb;vb=ka;wb=c[ka+(ra<<2)>>2]|0}else{ub=0;vb=D;wb=M}c[wb+2184>>2]=ub+1;qb=vb;rb=c[C>>2]|0}}while(0);M=ra+1|0;if((M|0)<(rb+1|0)){ra=M;D=qb;ha=rb}else{xb=rb;break}}}else{xb=u}ha=xb+1|0;D=w+144|0;ra=0;while(1){if((ra|0)>=(ha|0)){break}da=c[(c[$>>2]|0)+(ra<<2)>>2]|0;if((da|0)==0){break}if(((c[da+2184>>2]|0)-1|0)>((c[D>>2]|0)/(c[(c[U>>2]|0)+380>>2]|0)|0|0)){break}else{ra=ra+1|0}}D=ra-1|0;ha=(D|0)<0?0:D;D=ha+1|0;if((D|0)<=0){Za=ha;_=143;break}u=c[$>>2]|0;da=0;while(1){c[(c[u+(da<<2)>>2]|0)+2184>>2]=0;ca=da+1|0;if((ca|0)<(D|0)){da=ca}else{Za=ha;_=143;break}}}else{yDb(wa,16,2343304,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;Ya=0;_=142}}while(0);f:do{if((_|0)==142){yb=Ya;zb=c[$>>2]|0}else if((_|0)==143){ta=c[$>>2]|0;if((Za|0)>0){Ab=Za}else{yb=Za;zb=ta;break}while(1){ha=Ab;while(1){Bb=ha-1|0;da=c[(c[ta+(Bb<<2)>>2]|0)+88>>2]|0;if(!((da|0)==3|(da|0)==0)){break}if((Bb|0)>0){ha=Bb}else{yb=Ab;zb=ta;break f}}if((Bb|0)>0){Ab=Bb}else{yb=Bb;zb=ta;break}}}}while(0);do{if((c[(c[zb+(yb<<2)>>2]|0)+88>>2]|0)==3){if((yb|0)!=(c[C>>2]|0)){break}yDb(c[U>>2]|0,16,2341872,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T}}while(0);ta=c[B>>2]|0;ha=c[w+16>>2]|0;do{if((ta+yb|0)<(ha|0)){Cb=yb}else{if((c[w+14404>>2]&2|0)!=0&(ha|0)>(ta|0)){Cb=ha+~ta|0;break}else{da=(c[k>>2]|0)<0?0:yb;c[(c[(c[$>>2]|0)+(da<<2)>>2]|0)+88>>2]=1;Cb=da;break}}}while(0);ta=c[$>>2]|0;if((c[k>>2]|0)>-1|(Cb|0)==0){Db=Cb}else{Db=(((c[(c[ta+(Cb<<2)>>2]|0)+88>>2]|0)==1)<<31>>31)+Cb|0}c[c[H>>2]>>2]=c[ta+(Db<<2)>>2];ta=c[H>>2]|0;ha=c[ta>>2]|0;da=ha+88|0;if((c[da>>2]|0)!=1){c[da>>2]=2}da=w+104|0;D=c[da>>2]|0;c[da>>2]=D+1;c[ha+160>>2]=D;if((Db|0)>0){Eb=0;Fb=ta}else{va=ta;break b}while(1){ta=Eb+1|0;c[Fb+(ta<<2)>>2]=c[(c[$>>2]|0)+(Eb<<2)>>2];D=c[H>>2]|0;ha=c[D+(ta<<2)>>2]|0;c[ha+88>>2]=3;u=c[da>>2]|0;c[da>>2]=u+1;c[ha+160>>2]=u;if((ta|0)<(Db|0)){Eb=ta;Fb=D}else{va=D;break b}}}}while(0);c[c[H>>2]>>2]=c[c[$>>2]>>2];U=c[H>>2]|0;G=c[U>>2]|0;c[G+88>>2]=1;da=w+104|0;k=c[da>>2]|0;c[da>>2]=k+1;c[G+160>>2]=k;va=U}else{va=V}}while(0);V=c[va>>2]|0;do{if((V|0)==0){AOa(y,w+5400|0)}else{c[V+2192>>2]=(c[V+88>>2]|0)!=3?3:0;va=w+5400|0;$=va;AOa(y,$);Fb=BOa(y,$,c[c[H>>2]>>2]|0)|0;if((Fb|0)!=0){if((Fb|0)<0){W=-1}else{break}i=m;return W|0}Fb=c[c[H>>2]>>2]|0;do{if((c[Fb+2196>>2]|0)==0){if((c[(c[w+4>>2]|0)+524>>2]|0)!=0){_=165;break}c[w+9856>>2]=Fb;$=va;c[$>>2]=(c[$>>2]|0)+16;$=w+5404|0;c[$>>2]=(c[$>>2]|0)+16;$=w+5408|0;c[$>>2]=(c[$>>2]|0)+16;$=w+5412|0;c[$>>2]=(c[$>>2]|0)+16}else{_=165}}while(0);do{if((_|0)==165){va=QOa(y,0)|0;if((va|0)<0){W=-1;i=m;return W|0}Fb=c[w+156>>2]|0;$=Fb+(va*2224|0)|0;c[Fb+(va*2224|0)+2192>>2]=c[(c[c[H>>2]>>2]|0)+2192>>2];if((zOa(y,$,0)|0)<0){W=-1;i=m;return W|0}if((NCb($|0,c[c[H>>2]>>2]|0)|0)<0){W=-1;i=m;return W|0}else{KCb(c[c[H>>2]>>2]|0);c[(c[c[H>>2]>>2]|0)+2196>>2]=0;c[w+9856>>2]=$;break}}}while(0);$=w+7624|0;AOa(y,$);if((BOa(y,$,c[w+9856>>2]|0)|0)<0){W=-1;i=m;return W|0}else{c[w+108>>2]=c[w+5564>>2];break}}}while(0);do{if((c[w+5400>>2]|0)==0){c[w+13216>>2]=0}else{H=w+116|0;V=w+120|0;$=(ba((c[H>>2]|0)*3100|0,c[V>>2]|0)|0)+1e4|0;va=r0a(f,j,$,($|0)<0|0?-1:0)|0;if((va|0)<0){W=va;i=m;return W|0}va=w+13792|0;if((c[va>>2]|0)!=0){c[w+13804>>2]=GZ(j,3,ba((c[H>>2]|0)*12|0,c[V>>2]|0)|0)|0;c[w+13808>>2]=0;c[w+13800>>2]=0;c[w+13796>>2]=0}H=(A|0)>0;if(H){$=w+816|0;Fb=j+24|0;Eb=j+28|0;Db=0;do{Cb=c[$+(Db<<2)>>2]|0;yb=c[Cb+808>>2]|0;C=c[Cb+812>>2]|0;zb=c[V>>2]|0;Bb=c[Fb>>2]|0;Ab=c[Eb>>2]|0;Za=Ab;Ya=(Ab|0)<0|0?-1:0;Ab=gHb(Za,Ya,yb,(yb|0)<0|0?-1:0)|0;yb=zb;wa=(zb|0)<0|0?-1:0;zb=eHb(Ab,F,yb,wa)|0;Ab=zb;zb=gHb(Za,Ya,C,(C|0)<0|0?-1:0)|0;C=eHb(zb,F,yb,wa)|0;wa=C-Ab|0;C=(wa|0)<0;yb=C?0:Bb+Ab|0;Ab=C?0:wa;c[Cb+804>>2]=Ab<<3;c[Cb+792>>2]=yb;c[Cb+800>>2]=yb+Ab;c[Cb+796>>2]=yb;c[Cb+788>>2]=32;c[Cb+784>>2]=0;Db=Db+1|0;}while((Db|0)<(A|0))}Db=c[w+5488>>2]|0;Eb=w+9992|0;c[Eb>>2]=Db;do{if((Db|0)==3){Gb=3}else{Fb=c[w+9848>>2]|0;if((Fb|0)==0){Gb=Db;break}if((Fb|0)==(c[w+9852>>2]|0)){Gb=Db;break}if((c[Fb+360>>2]|0)==0){Gb=Db;break}AOa(y,Fb);Gb=c[Eb>>2]|0}}while(0);Db=w+9856|0;Fb=c[Db>>2]|0;c[Fb+88>>2]=Gb;c[Fb+84>>2]=(Gb|0)==1;Fb=w+7624|0;$=Fb;AOa(y,$);Cb=BOa(y,$,c[Db>>2]|0)|0;if((Cb|0)<0){W=Cb;i=m;return W|0}do{if((c[Eb>>2]|0)==3){Hb=c[w+9848>>2]|0}else{Cb=w+9852|0;$=c[Cb>>2]|0;c[w+9848>>2]=$;if((c[w+10008>>2]|0)!=0){Hb=$;break}c[Cb>>2]=c[Db>>2];Hb=$}}while(0);do{if((Hb|0)!=0){$=w+952|0;AOa(y,$);Cb=c[w+9848>>2]|0;if((c[Cb+360>>2]|0)==0){break}yb=BOa(y,$,Cb)|0;if((yb|0)<0){W=yb}else{break}i=m;return W|0}}while(0);yb=w+9852|0;do{if((c[yb>>2]|0)!=0){Cb=w+3176|0;AOa(y,Cb);$=c[yb>>2]|0;if((c[$+360>>2]|0)==0){break}Ab=BOa(y,Cb,$)|0;if((Ab|0)<0){W=Ab}else{break}i=m;return W|0}}while(0);yb=c[w+14172>>2]|0;if((yb|0)!=3){Ab=(yb|0)==2;yb=w+7656|0;$=c[yb>>2]|0;if(Ab){Cb=Fb;c[Cb>>2]=(c[Cb>>2]|0)+$}c[yb>>2]=$<<1;$=w+984|0;c[$>>2]=c[$>>2]<<1;$=w+3208|0;c[$>>2]=c[$>>2]<<1;$=w+7660|0;yb=c[$>>2]|0;if(Ab){Cb=w+7628|0;c[Cb>>2]=(c[Cb>>2]|0)+yb}c[$>>2]=yb<<1;yb=w+988|0;c[yb>>2]=c[yb>>2]<<1;yb=w+3212|0;c[yb>>2]=c[yb>>2]<<1;yb=w+7664|0;$=c[yb>>2]|0;if(Ab){Cb=w+7632|0;c[Cb>>2]=(c[Cb>>2]|0)+$}c[yb>>2]=$<<1;$=w+992|0;c[$>>2]=c[$>>2]<<1;$=w+3216|0;c[$>>2]=c[$>>2]<<1;$=w+7668|0;yb=c[$>>2]|0;if(Ab){Ab=w+7636|0;c[Ab>>2]=(c[Ab>>2]|0)+yb}c[$>>2]=yb<<1;yb=w+996|0;c[yb>>2]=c[yb>>2]<<1;yb=w+3220|0;c[yb>>2]=c[yb>>2]<<1}do{if((c[w+14004>>2]|0)==0){if((c[w+48>>2]|0)==2){_=203;break}if(((c[w+28>>2]|0)-1|0)>>>0<2>>>0){c[w+14384>>2]=c[w+14368>>2];c[w+14388>>2]=c[w+14372>>2];break}else{c[w+14384>>2]=c[w+14352>>2];c[w+14388>>2]=c[w+14356>>2];break}}else{_=203}}while(0);if((_|0)==203){c[w+14384>>2]=c[w+14360>>2];c[w+14388>>2]=c[w+14364>>2]}yb=w+13184|0;$=c[yb>>2]|0;Ab=w+4|0;if(($|0)==0){Ib=w+13188|0;Jb=w+13192|0}else{Cb=w+13196|0;wa=w+13188|0;C=c[wa>>2]|0;if((C|0)>65536){Bb=0;do{zb=$+(Bb<<2)|0;c[zb>>2]=c[zb>>2]>>1;Bb=Bb+1|0;}while((Bb|0)<64);Bb=c[wa>>2]>>1;c[wa>>2]=Bb;Kb=Bb}else{Kb=C}Bb=(c[Ab>>2]|0)+312|0;zb=c[Bb>>2]|0;Ya=ba(zb,Kb)|0;Za=c[Cb>>2]|0;xb=0;do{rb=c[$+(xb<<2)>>2]|0;b[Za+(xb<<1)>>1]=(((rb|0)/2|0)+Ya|0)/(rb+1|0)|0;xb=xb+1|0;}while((xb|0)<64);xb=w+13192|0;Ya=c[xb>>2]|0;if((Ya|0)>65536){Cb=0;do{C=$+256+(Cb<<2)|0;c[C>>2]=c[C>>2]>>1;Cb=Cb+1|0;}while((Cb|0)<64);Cb=c[xb>>2]>>1;c[xb>>2]=Cb;Lb=c[Bb>>2]|0;Mb=Cb}else{Lb=zb;Mb=Ya}Cb=ba(Lb,Mb)|0;C=0;while(1){rb=c[$+256+(C<<2)>>2]|0;b[Za+128+(C<<1)>>1]=(((rb|0)/2|0)+Cb|0)/(rb+1|0)|0;rb=C+1|0;if((rb|0)<64){C=rb}else{Ib=wa;Jb=xb;break}}}xb=w+108|0;wa=w+12424|0;C=wa;Cb=w+12432|0;Za=w+48|0;$=w+13856|0;Ya=w+13872|0;zb=w+13864|0;Bb=w+13874|0;rb=w+12440|0;qb=w+14088|0;vb=w+12472|0;ub=w+60|0;wb=w+10036|0;tb=w+9968|0;sb=w+9960|0;eb=w+9972|0;t=w+10004|0;ob=w+13164|0;nb=ob;lb=w+13160|0;mb=w+13176|0;pb=mb;n=w+13172|0;o=w+12488|0;jb=w+124|0;ib=w+12492|0;kb=w+52|0;hb=w+816|0;fb=w+9800|0;gb=w+9792|0;p=w+14092|0;q=w+13816|0;r=w+11640|0;s=w+11648|0;db=w+11556|0;$a=w+11644|0;cb=w+11652|0;bb=w+11560|0;ab=w+11716|0;_a=w+11676|0;Xa=w+11680|0;Ta=w+11720|0;Wa=w+11684|0;Va=w+11688|0;Sa=w+11724|0;Ra=w+11692|0;Pa=w+11696|0;Qa=w+11728|0;Oa=w+11700|0;Na=w+11704|0;La=w+11636|0;Ka=w+11708|0;Ja=w+11660|0;Ma=w+11664|0;Aa=w+11712|0;Ia=w+11668|0;Ba=w+11672|0;Da=w+13084|0;Ca=w+28|0;U=w+14176|0;k=w+9892|0;G=w+9888|0;da=w+12560|0;D=w+12688|0;ta=w+10056|0;u=w+13072|0;ha=w+7708|0;ra=w+7712|0;ca=w+12480|0;X=w+12476|0;Z=w+784|0;ua=Z;K=w+788|0;M=w+792|0;ka=w+796|0;L=w+13700|0;I=w+364|0;Y=w+13668|0;sa=w+14140|0;N=w+14180|0;O=w+14224|0;v=w+13940|0;J=w+13664|0;R=w+13672|0;ea=w+13676|0;fa=w+13680|0;na=w+13684|0;ja=w+13688|0;qa=w+13692|0;ia=w+13696|0;ma=w+14456|0;la=w+14008|0;oa=w+7848|0;pa=oa;Ha=w+7856|0;Ea=w+7864|0;za=Z;Z=f+636|0;Ga=f+632|0;Fa=f+660|0;ya=f+640|0;Nb=f+644|0;Ob=f+648|0;Pb=w+144|0;Qb=f+652|0;Rb=f+656|0;Sb=w+10048|0;Tb=w+1e4|0;Ub=f+524|0;Vb=w+13240|0;Wb=f+556|0;Xb=w+13224|0;Yb=w+9980|0;Zb=w+9924|0;_b=w+13848|0;$b=w+13852|0;ac=hb;bc=w+9976|0;cc=w+9816|0;dc=w+20|0;ec=w+11260|0;fc=Fb;gc=w+7656|0;hc=w+136|0;ic=w+140|0;jc=w+7628|0;kc=w+7660|0;lc=w+7632|0;mc=w+7664|0;nc=w+32|0;g:while(1){oc=c[xb>>2]|0;pc=c[z>>2]|0;TGb(wa|0,0,16)|0;qc=c[Za>>2]|0;do{if((qc-1|0)>>>0<2>>>0){_=229}else{if((c[nc>>2]|0)==0){break}if((c[p>>2]|0)==0){_=229}}}while(0);do{if((_|0)==229){_=0;rc=(c[Db>>2]|0)+136|0;sc=c[(c[Ab>>2]|0)+104>>2]|0;tc=gHb(sc,(sc|0)<0|0?-1:0,c[rc>>2]|0,c[rc+4>>2]|0)|0;rc=F;c[$>>2]=tc;c[$+4>>2]=rc;if((c[Eb>>2]|0)==3){sc=e[Ya>>1]|0;uc=ZGb(tc,rc,c[zb>>2]|0,c[zb+4>>2]|0)|0;vc=YGb(uc,F,sc,0)|0;b[Bb>>1]=vc;break}else{vc=ZGb(tc,rc,c[zb>>2]|0,c[zb+4>>2]|0)|0;b[Ya>>1]=vc;c[zb>>2]=tc;c[zb+4>>2]=rc;break}}}while(0);if((qc|0)==13){uNa(y)}c[rb>>2]=0;rc=c[Eb>>2]|0;do{if((rc|0)==1){if((c[p>>2]|0)>2){c[vb>>2]=1;break}else{c[vb>>2]=0;break}}else if((rc|0)!=3){if((c[qb>>2]|0)==0){tc=c[Za>>2]|0;if(!((tc|0)==20|(tc|0)==13)){break}}c[vb>>2]=c[vb>>2]^1}}while(0);qc=c[ub>>2]|0;do{if((qc&1024|0)==0){if((qc&2|0)!=0){break}if((rc|0)==3){wc=wb}else{wc=y+10024+(c[t>>2]<<2)|0}tc=c[wc>>2]|0;c[tb>>2]=tc;vc=((tc*139|0)+8192|0)>>>14;c[sb>>2]=vc;sc=c[Ab>>2]|0;uc=c[sc+500>>2]|0;xc=c[sc+504>>2]|0;if((vc|0)<(uc|0)){yc=uc}else{yc=(vc|0)>(xc|0)?xc:vc}c[sb>>2]=yc;c[eb>>2]=((ba(tc,tc)|0)+64|0)>>>7}else{if((sPa(y,1)|0)<0){W=-1;_=420;break g}qUa(y)}}while(0);rc=c[Za>>2]|0;if(!((rc|0)==108|(rc|0)==8)){if((c[nb>>2]|0)!=(c[lb>>2]|0)){$Db(ob)}rc=c[pb>>2]|0;if((rc|0)==(c[n>>2]|0)){zc=rc}else{$Db(mb);zc=c[n>>2]|0}c[nb>>2]=c[lb>>2];c[pb>>2]=zc}c[o>>2]=0;rc=1;while(1){if((rc|0)>=(pc|0)){break}if((DOa(c[y+816+(rc<<2)>>2]|0,y)|0)<0){W=-1;_=420;break g}else{rc=rc+1|0}}if((lmb(y)|0)<0){W=-1;_=420;break}rc=c[Eb>>2]|0;do{if((rc|0)==1){qc=ba(c[V>>2]|0,c[jb>>2]|0)|0;if((qc|0)>0){tc=c[ib>>2]|0;vc=0;do{b[tc+(vc<<1)>>1]=1;vc=vc+1|0;}while((vc|0)<(qc|0))}if((c[kb>>2]|0)!=0){break}qc=c[Ab>>2]|0;oe[c[qc+824>>2]&63](qc,734,hb,0,pc,4)|0}else{qc=c[Ab>>2]|0;vc=qc+348|0;c[tb>>2]=((ba(c[vc>>2]|0,c[tb>>2]|0)|0)+128|0)>>>8;tc=c[vc>>2]|0;vc=gHb(tc,(tc|0)<0|0?-1:0,c[eb>>2]|0,0)|0;tc=YGb(vc,F,128,0)|0;c[eb>>2]=tc>>>8|F<<24;do{if((rc|0)==3){Ac=qc}else{tc=c[qc+256>>2]|0;if((tc|0)==0){Ac=qc;break}if(!((c[t>>2]|0)==1|(tc|0)==2)){Ac=qc;break}oe[c[qc+824>>2]&63](qc,260,hb,0,pc,4)|0;Ac=c[Ab>>2]|0}}while(0);oe[c[Ac+824>>2]&63](Ac,688,hb,0,pc,4)|0}}while(0);rc=(pc|0)>1;if(rc){qc=1;do{tc=c[y+816+(qc<<2)>>2]|0;vc=tc+12440|0;c[rb>>2]=(c[rb>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=tc+12424|0;xc=YGb(c[C>>2]|0,c[C+4>>2]|0,c[vc>>2]|0,c[vc+4>>2]|0)|0;c[C>>2]=xc;c[C+4>>2]=F;c[vc>>2]=0;c[vc+4>>2]=0;vc=tc+12432|0;tc=YGb(c[Cb>>2]|0,c[Cb+4>>2]|0,c[vc>>2]|0,c[vc+4>>2]|0)|0;c[Cb>>2]=tc;c[Cb+4>>2]=F;c[vc>>2]=0;c[vc+4>>2]=0;qc=qc+1|0;}while((qc|0)<(pc|0))}qc=c[C>>2]|0;vc=c[C+4>>2]|0;tc=c[Db>>2]|0;xc=tc+2176|0;c[xc>>2]=qc;c[xc+4>>2]=vc;c[fb>>2]=qc;c[fb+4>>2]=vc;vc=c[Cb>>2]|0;qc=c[Cb+4>>2]|0;xc=tc+2168|0;c[xc>>2]=vc;c[xc+4>>2]=qc;c[gb>>2]=vc;c[gb+4>>2]=qc;do{if((c[rb>>2]|0)>(c[(c[Ab>>2]|0)+308>>2]|0)){if((c[Eb>>2]|0)!=2){break}c[Eb>>2]=1;qc=ba(c[V>>2]|0,c[jb>>2]|0)|0;if((qc|0)>0){vc=c[ib>>2]|0;xc=0;do{b[vc+(xc<<1)>>1]=1;xc=xc+1|0;}while((xc|0)<(qc|0))}if((c[p>>2]|0)<=2){break}c[vb>>2]=1}}while(0);do{if((c[q>>2]|0)==0){qc=c[Eb>>2]|0;if((qc|0)==2|(qc|0)==4){c[db>>2]=Amb(y,c[La>>2]|0,2)|0;if((c[ub>>2]&536870912|0)!=0){xc=Amb(y,c[Ja>>2]|0,256)|0;vc=Amb(y,c[Ba>>2]|0,256)|0;tc=c[db>>2]|0;uc=(tc|0)>(xc|0)?tc:xc;c[db>>2]=(uc|0)>(vc|0)?uc:vc}Bmb(y);Cmb(y,0,0,c[La>>2]|0,c[db>>2]|0,2,0);if((c[ub>>2]&536870912|0)!=0){Cmb(y,c[Ka>>2]|0,0,c[Ja>>2]|0,c[db>>2]|0,256,0);Cmb(y,c[Ka>>2]|0,1,c[Ma>>2]|0,c[db>>2]|0,256,0);Cmb(y,c[Aa>>2]|0,0,c[Ia>>2]|0,c[db>>2]|0,256,0);Cmb(y,c[Aa>>2]|0,1,c[Ba>>2]|0,c[db>>2]|0,256,0)}Bc=c[Eb>>2]|0}else{Bc=qc}if((Bc|0)!=3){break}qc=Amb(y,c[r>>2]|0,32)|0;vc=Amb(y,c[s>>2]|0,128)|0;c[db>>2]=(qc|0)>(vc|0)?qc:vc;vc=Amb(y,c[$a>>2]|0,64)|0;qc=Amb(y,c[cb>>2]|0,128)|0;c[bb>>2]=(vc|0)>(qc|0)?vc:qc;Cmb(y,0,0,c[r>>2]|0,c[db>>2]|0,32,1);Cmb(y,0,0,c[$a>>2]|0,c[bb>>2]|0,64,1);Cmb(y,0,0,c[s>>2]|0,c[db>>2]|0,128,1);Cmb(y,0,0,c[cb>>2]|0,c[bb>>2]|0,128,1);if((c[ub>>2]&536870912|0)==0){break}Cmb(y,c[ab>>2]|0,0,c[_a>>2]|0,c[db>>2]|0,2560,1);Cmb(y,c[ab>>2]|0,1,c[Xa>>2]|0,c[db>>2]|0,2560,1);Cmb(y,c[Ta>>2]|0,0,c[Wa>>2]|0,c[db>>2]|0,2560,1);Cmb(y,c[Ta>>2]|0,1,c[Va>>2]|0,c[db>>2]|0,2560,1);Cmb(y,c[Sa>>2]|0,0,c[Ra>>2]|0,c[bb>>2]|0,3072,1);Cmb(y,c[Sa>>2]|0,1,c[Pa>>2]|0,c[bb>>2]|0,3072,1);Cmb(y,c[Qa>>2]|0,0,c[Oa>>2]|0,c[bb>>2]|0,3072,1);Cmb(y,c[Qa>>2]|0,1,c[Na>>2]|0,c[bb>>2]|0,3072,1)}}while(0);if((sPa(y,0)|0)<0){W=-1;_=420;break}qc=c[sb>>2]|0;do{if((qc|0)<3){if((c[Da>>2]|0)>=129){Cc=qc;break}if((c[Eb>>2]|0)!=1){Cc=qc;break}if((c[ub>>2]&2|0)!=0){Cc=qc;break}c[sb>>2]=3;Cc=3}else{Cc=qc}}while(0);if((c[Ca>>2]|0)==3){qc=c[Ab>>2]|0;vc=c[qc+300>>2]|0;uc=(vc|0)==0?1179176:vc;vc=c[qc+952>>2]|0;qc=(vc|0)==0?uc:vc;vc=1;xc=Cc;while(1){tc=d[y+11184+vc|0]|0;sc=(ba(e[qc+(vc<<1)>>1]|0,xc)|0)>>3;if(sc>>>0>255>>>0){Dc=-sc>>31&255}else{Dc=sc&255}b[y+12688+(tc<<1)>>1]=Dc&255;sc=(ba(e[uc+(vc<<1)>>1]|0,c[sb>>2]|0)|0)>>3;if(sc>>>0>255>>>0){Ec=-sc>>31&255}else{Ec=sc&255}b[y+12560+(tc<<1)>>1]=Ec&255;tc=vc+1|0;if((tc|0)>=64){break}vc=tc;xc=c[sb>>2]|0}xc=c[1178424+(c[U>>2]<<2)>>2]|0;c[k>>2]=xc;c[G>>2]=xc;vc=d[xc+8|0]|0;b[da>>1]=vc;b[D>>1]=vc;iPa(ta,c[lb>>2]|0,c[n>>2]|0,da,c[u>>2]|0,8,8,1);iPa(ta,c[nb>>2]|0,c[pb>>2]|0,D,c[u>>2]|0,8,8,1);c[sb>>2]=8}if((c[Za>>2]|0)==108){vc=1;do{xc=d[(d[1075976+vc|0]|0)+(y+11184)|0]|0;b[y+12560+(xc<<1)>>1]=d[433840+vc|0]|0;b[y+12688+(xc<<1)>>1]=d[433904+vc|0]|0;vc=vc+1|0;}while((vc|0)<64);c[G>>2]=1342896;c[k>>2]=1342928;b[da>>1]=13;b[D>>1]=14;iPa(ta,c[lb>>2]|0,c[n>>2]|0,da,c[u>>2]|0,8,8,1);iPa(ta,c[nb>>2]|0,c[pb>>2]|0,D,c[u>>2]|0,8,8,1);c[sb>>2]=8}vc=(c[Eb>>2]|0)==1|0;c[ha>>2]=vc;xc=c[Db>>2]|0;c[xc+84>>2]=vc;vc=c[Eb>>2]|0;c[ra>>2]=vc;c[xc+88>>2]=vc;if((c[ha>>2]|0)!=0){c[B>>2]=0}c[ca>>2]=0;c[X>>2]=0;c[L>>2]=32-(c[K>>2]|0)+((c[ka>>2]|0)-(c[M>>2]|0)<<3);vc=c[Ca>>2]|0;do{if((vc|0)==3){JLa(c[Ab>>2]|0,ua,I,da,D)}else if((vc|0)==2){xc=c[Za>>2]|0;if((xc|0)==19){ddb(y,oc)|0;break}if((c[p>>2]|0)!=0){aQa(y,oc);break}if((c[nc>>2]|0)!=0){vNa(y,oc);break}if((xc|0)==6){eVa(y,oc);break}else if((xc|0)==7){fVa(y,oc);break}else if((xc|0)==22){fba(y,oc);break}else{Hlb(y,oc);break}}else if((vc|0)==0){KMa(y,oc)}else if((vc|0)==1){tca(y,oc)}else{_=326;break g}}while(0);c[Y>>2]=32-(c[K>>2]|0)-(c[L>>2]|0)+((c[ka>>2]|0)-(c[M>>2]|0)<<3);if(rc){oc=1;do{vc=c[y+816+(oc<<2)>>2]|0;c[vc+9992>>2]=c[Eb>>2];UGb(vc+7624|0,Fb|0,2224)|0;c[vc+11556>>2]=c[db>>2];c[vc+11560>>2]=c[bb>>2];c[vc+9960>>2]=c[sb>>2];c[vc+9968>>2]=c[tb>>2];c[vc+9972>>2]=c[eb>>2];c[vc+112>>2]=c[B>>2];c[vc+14140>>2]=c[sa>>2];c[vc+14180>>2]=c[N>>2];c[vc+14224>>2]=c[O>>2];c[vc+13940>>2]=c[v>>2];oc=oc+1|0;}while((oc|0)<(pc|0));oc=c[Ab>>2]|0;oe[c[oc+824>>2]&63](oc,544,hb,0,pc,4)|0;oc=1;do{rc=c[y+816+(oc<<2)>>2]|0;vc=rc+13188|0;c[Ib>>2]=(c[Ib>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+13192|0;c[Jb>>2]=(c[Jb>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+13664|0;c[J>>2]=(c[J>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+13672|0;c[R>>2]=(c[R>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+13676|0;c[ea>>2]=(c[ea>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+13680|0;c[fa>>2]=(c[fa>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+13684|0;c[na>>2]=(c[na>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+13688|0;c[ja>>2]=(c[ja>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+13692|0;c[qa>>2]=(c[qa>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+13696|0;c[ia>>2]=(c[ia>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+14456|0;c[ma>>2]=(c[ma>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+14008|0;c[la>>2]=(c[la>>2]|0)+(c[vc>>2]|0);c[vc>>2]=0;vc=rc+7848|0;xc=YGb(c[pa>>2]|0,c[pa+4>>2]|0,c[vc>>2]|0,c[vc+4>>2]|0)|0;c[pa>>2]=xc;c[pa+4>>2]=F;c[vc>>2]=0;c[vc+4>>2]=0;vc=rc+7856|0;xc=YGb(c[Ha>>2]|0,c[Ha+4>>2]|0,c[vc>>2]|0,c[vc+4>>2]|0)|0;c[Ha>>2]=xc;c[Ha+4>>2]=F;c[vc>>2]=0;c[vc+4>>2]=0;vc=rc+7864|0;xc=YGb(c[Ea>>2]|0,c[Ea+4>>2]|0,c[vc>>2]|0,c[vc+4>>2]|0)|0;c[Ea>>2]=xc;c[Ea+4>>2]=F;c[vc>>2]=0;c[vc+4>>2]=0;if((c[(c[Ab>>2]|0)+312>>2]|0)!=0){vc=c[rc+13184>>2]|0;xc=c[yb>>2]|0;uc=0;do{qc=vc+(uc<<2)|0;tc=xc+(uc<<2)|0;c[tc>>2]=(c[tc>>2]|0)+(c[qc>>2]|0);c[qc>>2]=0;qc=vc+256+(uc<<2)|0;tc=xc+256+(uc<<2)|0;c[tc>>2]=(c[tc>>2]|0)+(c[qc>>2]|0);c[qc>>2]=0;uc=uc+1|0;}while((uc|0)<64)}uc=c[rc+792>>2]|0;M_(ua,uc,32-(c[rc+788>>2]|0)+((c[rc+796>>2]|0)-uc<<3)|0);uc=c[K>>2]|0;if((uc|0)<32){xc=c[za>>2]<<uc;c[za>>2]=xc;uc=xc>>>24&255;while(1){xc=c[ka>>2]|0;c[ka>>2]=xc+1;a[xc]=uc;xc=c[za>>2]|0;c[za>>2]=xc<<8;vc=(c[K>>2]|0)+8|0;c[K>>2]=vc;if((vc|0)<32){uc=xc>>>16&255}else{break}}}c[K>>2]=32;c[za>>2]=0;oc=oc+1|0;}while((oc|0)<(pc|0))}else{oc=c[Ab>>2]|0;oe[c[oc+824>>2]&63](oc,544,hb,0,pc,4)|0}c[Z>>2]=c[Y>>2];c[Ga>>2]=c[J>>2];c[Fa>>2]=c[ia>>2];c[ya>>2]=c[R>>2];c[Nb>>2]=c[ea>>2];c[Ob>>2]=c[fa>>2];c[Qb>>2]=(c[Pb>>2]|0)-(c[fa>>2]|0)-(c[qa>>2]|0);c[Rb>>2]=c[qa>>2];do{if((c[Sb>>2]|0)!=0){if((c[cc>>2]|0)==0){break}if((c[dc>>2]|0)!=0){break}oc=bFb(c[(c[Ab>>2]|0)+140>>2]|0)|0;uc=d[oc+5|0]|0;rc=d[oc+6|0]|0;Ke[c[ec>>2]&1023](c[fc>>2]|0,c[gc>>2]|0,c[hc>>2]|0,c[ic>>2]|0,16,16,3);oc=16>>>(uc>>>0);xc=16>>>(rc>>>0);Ke[c[ec>>2]&1023](c[jc>>2]|0,c[kc>>2]|0,c[hc>>2]>>uc,c[ic>>2]>>rc,oc,xc,3);Ke[c[ec>>2]&1023](c[lc>>2]|0,c[mc>>2]|0,c[hc>>2]>>uc,c[ic>>2]>>rc,oc,xc,3)}}while(0);pc=c[Eb>>2]|0;c[Tb>>2]=pc;c[y+10024+(pc<<2)>>2]=c[(c[Db>>2]|0)+168>>2];pc=c[Eb>>2]|0;if((pc|0)!=3){c[t>>2]=pc}c[(c[Ab>>2]|0)+804>>2]=c[Db>>2];if((c[Ca>>2]|0)==3){MLa(ua,c[Y>>2]|0)}if((c[Ub>>2]|0)==0){_=362;break}if((32-(c[K>>2]|0)+((c[ka>>2]|0)-(c[M>>2]|0)<<3)|0)<=(~~(+h[Vb>>3]*+g[Wb>>2])|0)){_=362;break}pc=c[tb>>2]|0;if(!(pc>>>0<(c[(c[Ab>>2]|0)+580>>2]|0)>>>0)){_=362;break}xc=pc+1|0;oc=c[sb>>2]|0;rc=((ba(oc+1|0,pc)|0)>>>0)/(oc>>>0)|0;c[Xb>>2]=xc>>>0>rc>>>0?xc:rc;h:do{if((c[Yb>>2]|0)!=0){if((ba(c[jb>>2]|0,c[V>>2]|0)|0)<=0){break}rc=c[bc>>2]|0;xc=0;pc=oc;while(1){uc=rc+(xc<<2)|0;vc=c[uc>>2]|0;qc=vc+1|0;tc=(ba(pc+1|0,vc)|0)/(pc|0)|0;c[uc>>2]=(qc|0)>(tc|0)?qc:tc;tc=xc+1|0;if((tc|0)>=(ba(c[jb>>2]|0,c[V>>2]|0)|0)){break h}xc=tc;pc=c[sb>>2]|0}}}while(0);c[Zb>>2]=0;oc=c[Eb>>2]|0;if((oc|0)==2){if((c[qb>>2]|0)==0){pc=c[Za>>2]|0;if((pc|0)==20|(pc|0)==13){_=357}}else{_=357}if((_|0)==357){_=0;c[vb>>2]=c[vb>>2]^1}if((oc|0)!=3){_=359}}else if((oc|0)!=3){_=359}if((_|0)==359){_=0;c[$b>>2]=c[_b>>2];oc=ZGb(c[$>>2]|0,c[$+4>>2]|0,e[Ya>>1]|0,0)|0;c[zb>>2]=oc;c[zb+4>>2]=F}if(H){Fc=0}else{continue}while(1){oc=c[ac+(Fc<<2)>>2]|0;pc=oc+792|0;xc=c[pc>>2]|0;rc=oc+800|0;tc=(c[rc>>2]|0)-xc|0;qc=(tc|0)<0;uc=qc?0:xc;xc=qc?0:tc;c[oc+804>>2]=xc<<3;c[pc>>2]=uc;c[rc>>2]=uc+xc;c[oc+796>>2]=uc;c[oc+788>>2]=32;c[oc+784>>2]=0;oc=Fc+1|0;if((oc|0)<(A|0)){Fc=oc}else{continue g}}}if((_|0)==326){yDb(0,0,1948704,(T=i,i=i+24|0,c[T>>2]=2355832,c[T+8>>2]=1944616,c[T+16>>2]=3600,T)|0);i=T;Cd();return 0}else if((_|0)==362){if((c[ub>>2]&512|0)!=0){jUa(y)}ac=oa;H=c[ac>>2]|0;zb=c[ac+4>>2]|0;ac=c[Db>>2]|0;Ya=ac+224|0;c[Ya>>2]=H;c[Ya+4>>2]=zb;Ya=f+720|0;$=YGb(c[Ya>>2]|0,c[Ya+4>>2]|0,H,zb)|0;c[Ya>>2]=$;c[Ya+4>>2]=F;Ya=w+7856|0;$=c[Ya>>2]|0;zb=c[Ya+4>>2]|0;Ya=ac+232|0;c[Ya>>2]=$;c[Ya+4>>2]=zb;Ya=f+728|0;H=YGb(c[Ya>>2]|0,c[Ya+4>>2]|0,$,zb)|0;c[Ya>>2]=H;c[Ya+4>>2]=F;Ya=w+7864|0;H=c[Ya>>2]|0;zb=c[Ya+4>>2]|0;Ya=ac+240|0;c[Ya>>2]=H;c[Ya+4>>2]=zb;Ya=f+736|0;$=YGb(c[Ya>>2]|0,c[Ya+4>>2]|0,H,zb)|0;c[Ya>>2]=$;c[Ya+4>>2]=F;Ya=w+7872|0;$=c[Ya>>2]|0;zb=c[Ya+4>>2]|0;Ya=ac+248|0;c[Ya>>2]=$;c[Ya+4>>2]=zb;Ya=f+744|0;ac=YGb(c[Ya>>2]|0,c[Ya+4>>2]|0,$,zb)|0;c[Ya>>2]=ac;c[Ya+4>>2]=F;Ya=c[K>>2]|0;i:do{if((Ya|0)<32){ac=c[za>>2]<<Ya;c[za>>2]=ac;zb=ac>>>24&255;while(1){ac=c[ka>>2]|0;c[ka>>2]=ac+1;a[ac]=zb;ac=c[za>>2]|0;c[za>>2]=ac<<8;$=(c[K>>2]|0)+8|0;c[K>>2]=$;if(($|0)>=32){break i}zb=ac>>>16&255}}}while(0);c[K>>2]=32;c[za>>2]=0;Ya=(c[ka>>2]|0)-(c[M>>2]|0)<<3;Db=w+13216|0;c[Db>>2]=Ya;oa=pUa(y,Ya)|0;c[w+13220>>2]=oa<<3;if((oa|0)!=0){Ya=c[M>>2]|0;ub=c[K>>2]|0;zb=c[ka>>2]|0;if(((c[w+800>>2]|0)-Ya-(32-ub+(zb-Ya<<3)>>3)|0)<(oa+50|0)){yDb(c[Ab>>2]|0,16,1954992,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;W=-1;i=m;return W|0}Ya=c[Za>>2]|0;do{if((Ya|0)==1|(Ya|0)==2){ac=oa;$=c[za>>2]|0;H=ub;_b=zb;while(1){$b=ac-1|0;if((H|0)>8){Gc=H-8|0;Hc=$<<8;Ic=_b}else{vb=_b;x=fe($<<H|0)|0;a[vb]=x;x=x>>8;a[vb+1|0]=x;x=x>>8;a[vb+2|0]=x;x=x>>8;a[vb+3|0]=x;vb=(c[ka>>2]|0)+4|0;c[ka>>2]=vb;Gc=H+24|0;Hc=0;Ic=vb}c[za>>2]=Hc;c[K>>2]=Gc;if(($b|0)==0){Jc=Gc;break}else{ac=$b;$=Hc;H=Gc;_b=Ic}}}else if((Ya|0)==13){_b=c[za>>2]|0;if((ub|0)>16){Kc=ub-16|0;Lc=_b<<16;Mc=zb}else{H=zb;x=fe(_b<<ub|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=(c[ka>>2]|0)+4|0;c[ka>>2]=H;Kc=ub+16|0;Lc=0;Mc=H}c[za>>2]=Lc;c[K>>2]=Kc;if((Kc|0)>16){Nc=Kc-16|0;Oc=Mc}else{H=Mc;x=fe(451>>>((16-Kc|0)>>>0)|Lc<<Kc|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=(c[ka>>2]|0)+4|0;c[ka>>2]=H;Nc=Kc+16|0;Oc=H}c[za>>2]=451;c[K>>2]=Nc;H=oa-4|0;if((H|0)==0){Jc=Nc;break}else{Pc=H;Qc=451;Rc=Nc;Sc=Oc}while(1){H=Pc-1|0;if((Rc|0)>8){Tc=Rc-8|0;Uc=Qc<<8|255;Vc=Sc}else{_b=Sc;x=fe(255>>>((8-Rc|0)>>>0)|Qc<<Rc|0)|0;a[_b]=x;x=x>>8;a[_b+1|0]=x;x=x>>8;a[_b+2|0]=x;x=x>>8;a[_b+3|0]=x;_b=(c[ka>>2]|0)+4|0;c[ka>>2]=_b;Tc=Rc+24|0;Uc=255;Vc=_b}c[za>>2]=Uc;c[K>>2]=Tc;if((H|0)==0){Jc=Tc;break}else{Pc=H;Qc=Uc;Rc=Tc;Sc=Vc}}}else{yDb(c[Ab>>2]|0,16,1952784,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;Jc=c[K>>2]|0}}while(0);j:do{if((Jc|0)<32){oa=c[za>>2]<<Jc;c[za>>2]=oa;ub=oa>>>24&255;while(1){oa=c[ka>>2]|0;c[ka>>2]=oa+1;a[oa]=ub;oa=c[za>>2]|0;c[za>>2]=oa<<8;zb=(c[K>>2]|0)+8|0;c[K>>2]=zb;if((zb|0)>=32){break j}ub=oa>>>16&255}}}while(0);c[K>>2]=32;c[za>>2]=0;c[Db>>2]=(c[ka>>2]|0)-(c[M>>2]|0)<<3}ub=c[Ab>>2]|0;oa=c[ub+540>>2]|0;do{if((oa|0)!=0){if((c[ub+544>>2]|0)!=(oa|0)){break}if((c[Ca>>2]|0)!=0){break}zb=(c[Ub>>2]|0)-1|0;Ya=gHb(zb,(zb|0)<0|0?-1:0,9e4,0)|0;zb=F;Za=gHb(oa,(oa|0)<0|0?-1:0,65535,0)|0;H=F;if((zb|0)>(H|0)|(zb|0)==(H|0)&Ya>>>0>Za>>>0){break}Za=w+14148|0;Ya=(c[Db>>2]|0)+8-((c[Za>>2]|0)-(c[M>>2]|0)<<3)|0;Ua=+h[Vb>>3]+ +(Ya|0)- +(oa|0)*(+(c[ub+104>>2]|0)/+(c[ub+108>>2]|0));if(Ua<0.0){yDb(ub,16,1950544,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;Wc=c[(c[Ab>>2]|0)+540>>2]|0}else{Wc=oa}H=~~(Ua*9.0e4/+(Wc|0));zb=gHb(Ya,(Ya|0)<0|0?-1:0,9e4,0)|0;Ya=Wc;_b=(Wc|0)<0|0?-1:0;$=YGb(zb,F,-1,-1)|0;zb=YGb($,F,Ya,_b)|0;$=eHb(zb,F,Ya,_b)|0;_b=$;$=(H|0)>(_b|0)?H:_b;if(($|0)<65535){_b=c[Za>>2]|0;a[_b]=a[_b]&-8;_b=c[Za>>2]|0;a[_b]=d[_b]|0|$>>>13;a[(c[Za>>2]|0)+1|0]=$>>>5;_b=(c[Za>>2]|0)+2|0;a[_b]=a[_b]&7;_b=(c[Za>>2]|0)+2|0;a[_b]=d[_b]|0|$<<3;_b=$*300|0;$=f+880|0;c[$>>2]=_b;c[$+4>>2]=(_b|0)<0|0?-1:0;break}else{yDb(0,0,1948704,(T=i,i=i+24|0,c[T>>2]=1946648,c[T+8>>2]=1944616,c[T+16>>2]=1779,T)|0);i=T;Cd();return 0}}}while(0);oa=c[Db>>2]|0;Ab=w+13208|0;ub=YGb(c[Ab>>2]|0,c[Ab+4>>2]|0,oa,(oa|0)<0|0?-1:0)|0;c[Ab>>2]=ub;c[Ab+4>>2]=F;c[f+664>>2]=oa;oa=w+7760|0;Ab=c[oa>>2]|0;ub=c[oa+4>>2]|0;oa=j+8|0;c[oa>>2]=Ab;c[oa+4>>2]=ub;do{if((c[w+13944>>2]|0)==0){if((c[Eb>>2]|0)==3){_=409;break}if((c[w+7784>>2]|0)==0){oa=w+768|0;Vb=ZGb(Ab,ub,c[oa>>2]|0,c[oa+4>>2]|0)|0;oa=j+16|0;c[oa>>2]=Vb;c[oa+4>>2]=F;Xc=w+776|0}else{oa=w+776|0;Vb=c[oa+4>>2]|0;M=j+16|0;c[M>>2]=c[oa>>2];c[M+4>>2]=Vb;Xc=oa}c[Xc>>2]=Ab;c[Xc+4>>2]=ub}else{_=409}}while(0);if((_|0)==409){Eb=j+16|0;c[Eb>>2]=Ab;c[Eb+4>>2]=ub}if((c[ha>>2]|0)!=0){Eb=j+36|0;c[Eb>>2]=c[Eb>>2]|1}if((c[va>>2]|0)==0){break}MZ(j,3,c[w+13808>>2]|0)|0;break}else if((_|0)==420){i=m;return W|0}}}while(0);_=w+156|0;Xc=0;do{f=c[_>>2]|0;if((c[f+(Xc*2224|0)+2192>>2]|0)==0){AOa(y,f+(Xc*2224|0)|0)}Xc=Xc+1|0;}while((Xc|0)<36);Xc=c[w+13216>>2]|0;c[j+28>>2]=(Xc|0)/8|0;c[l>>2]=(Xc+7|0)>>>0>14>>>0;W=0;i=m;return W|0}function sPa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+13224|0;f=c[e>>2]|0;do{if((f|0)==0){if((c[b+52>>2]|0)!=0){break}g=~~+rUa(b,d);h=b+7792|0;c[h>>2]=g;c[(c[b+9856>>2]|0)+168>>2]=g;if((c[h>>2]|0)<0){i=-1}else{break}return i|0}else{c[b+7792>>2]=f;c[(c[b+9856>>2]|0)+168>>2]=f;if((d|0)!=0){break}c[e>>2]=0}}while(0);if((c[b+9980>>2]|0)==0){e=c[b+7792>>2]|0;c[b+9968>>2]=e;j=e}else{e=c[b+48>>2]|0;do{if((e|0)==5|(e|0)==20|(e|0)==22){Klb(b)}else if((e|0)==13){oNa(b)}else{d=c[b+9136>>2]|0;f=b+144|0;if((c[f>>2]|0)<=0){break}h=b+12556|0;g=b+9976|0;k=b+4|0;l=0;do{m=c[(c[h>>2]|0)+(l<<2)>>2]|0;n=(((c[(c[g>>2]|0)+(m<<2)>>2]|0)*139|0)+8192|0)>>>14;o=c[k>>2]|0;p=c[o+500>>2]|0;q=c[o+504>>2]|0;if((n|0)<(p|0)){r=p&255}else{r=((n|0)>(q|0)?q:n)&255}a[d+m|0]=r;l=l+1|0;}while((l|0)<(c[f>>2]|0))}}while(0);r=c[c[b+9976>>2]>>2]|0;c[b+9968>>2]=r;j=r}r=((j*139|0)+8192|0)>>>14;e=b+9960|0;c[e>>2]=r;f=c[b+4>>2]|0;l=c[f+500>>2]|0;d=c[f+504>>2]|0;if((r|0)<(l|0)){s=l}else{s=(r|0)>(d|0)?d:r}c[e>>2]=s;c[b+9972>>2]=((ba(j,j)|0)+64|0)>>>7;i=0;return i|0}function tPa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[b>>2]|0;b=a;d=a+12256|0;c[d>>2]=1;c[a+12260>>2]=c[(c[a+4>>2]|0)+264>>2];e=a+14084|0;c[e>>2]=1;f=a+12480|0;g=(c[a+812>>2]|0)-1|0;c[f>>2]=g;h=a+808|0;i=c[h>>2]|0;if((g|0)<(i|0)){c[d>>2]=0;return 0}j=a+116|0;k=a+12476|0;a=g;g=i;while(1){i=c[j>>2]|0;l=i-1|0;c[k>>2]=l;if((i|0)>0){i=l;l=a;do{wmb(b,i,l)|0;m=c[k>>2]|0;i=m-1|0;c[k>>2]=i;l=c[f>>2]|0}while((m|0)>0);n=l;o=c[h>>2]|0}else{n=a;o=g}c[e>>2]=0;i=n-1|0;c[f>>2]=i;if((i|0)<(o|0)){break}else{a=i;g=o}}c[d>>2]=0;return 0}function uPa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[b>>2]|0;b=a;Y3()|0;c[a+12260>>2]=c[(c[a+4>>2]|0)+248>>2];d=a+14084|0;c[d>>2]=1;e=c[a+808>>2]|0;f=a+12480|0;c[f>>2]=e;g=a+812|0;if((e|0)>=(c[g>>2]|0)){return 0}e=a+12476|0;h=a+116|0;i=a+12496|0;j=a+12500|0;k=a+12504|0;l=a+12508|0;m=a+9992|0;do{c[e>>2]=0;$Oa(b);c[e>>2]=0;if((c[h>>2]|0)>0){a=0;do{c[i>>2]=(c[i>>2]|0)+2;c[j>>2]=(c[j>>2]|0)+2;c[k>>2]=(c[k>>2]|0)+2;c[l>>2]=(c[l>>2]|0)+2;n=c[f>>2]|0;if((c[m>>2]|0)==3){xmb(b,a,n)}else{smb(b,a,n)}a=(c[e>>2]|0)+1|0;c[e>>2]=a;}while((a|0)<(c[h>>2]|0))}c[d>>2]=0;a=(c[f>>2]|0)+1|0;c[f>>2]=a;}while((a|0)<(c[g>>2]|0));return 0}function vPa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[e>>2]|0;Y3()|0;e=c[d+808>>2]|0;f=d+812|0;g=c[f>>2]|0;if((e|0)>=(g|0)){return 0}h=d+116|0;i=d+5400|0;j=d+148|0;k=d+10100|0;l=d+10104|0;m=d+124|0;n=d+9192|0;o=d+9216|0;p=d+12432|0;d=e;e=c[h>>2]|0;q=g;while(1){if((e|0)>0){g=0;do{r=c[j>>2]|0;s=(c[i>>2]|0)+((ba(r,d)|0)+g<<4)|0;t=Oe[c[k>>2]&1023](s,r)|0;r=(628-((ba(t,t)|0)>>>8)+(Oe[c[l>>2]&1023](s,c[j>>2]|0)|0)|0)>>>8;s=(ba(c[m>>2]|0,d)|0)+g|0;b[(c[n>>2]|0)+(s<<1)>>1]=r;a[(c[o>>2]|0)+s|0]=(t+128|0)>>>8;t=YGb(c[p>>2]|0,c[p+4>>2]|0,r,0)|0;c[p>>2]=t;c[p+4>>2]=F;g=g+1|0;u=c[h>>2]|0;}while((g|0)<(u|0));v=u;w=c[f>>2]|0}else{v=e;w=q}g=d+1|0;if((g|0)<(w|0)){d=g;e=v;q=w}else{break}}return 0}function wPa(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Oe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Ye=0,Ze=0,$e=0,af=0,bf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0.0,Jg=0.0,Kg=0.0,Lg=0.0,Mg=0.0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0,$i=0,aj=0,bj=0,cj=0,dj=0,ej=0,fj=0,gj=0,hj=0,ij=0,jj=0,kj=0,lj=0,mj=0,nj=0,oj=0,pj=0,qj=0,rj=0,sj=0,tj=0,uj=0,vj=0,wj=0,xj=0,yj=0,zj=0,Aj=0,Bj=0,Cj=0,Dj=0,Ej=0,Fj=0,Gj=0,Hj=0,Ij=0,Jj=0,Kj=0,Lj=0,Mj=0,Nj=0,Oj=0,Pj=0,Qj=0,Rj=0,Sj=0,Tj=0,Uj=0,Vj=0,Wj=0,Xj=0,Yj=0,Zj=0,_j=0,$j=0,ak=0,bk=0,ck=0,dk=0,ek=0,fk=0,gk=0,hk=0,ik=0,jk=0,kk=0,lk=0,mk=0,nk=0,ok=0,pk=0,qk=0,rk=0,sk=0,tk=0,uk=0,vk=0,wk=0,xk=0,yk=0,zk=0,Ak=0,Bk=0,Ck=0,Dk=0,Ek=0,Fk=0,Gk=0,Hk=0,Ik=0,Jk=0,Kk=0,Lk=0,Mk=0,Nk=0,Ok=0,Pk=0,Qk=0,Rk=0,Sk=0,Tk=0,Uk=0,Vk=0,Wk=0,Xk=0,Yk=0,Zk=0,_k=0,$k=0,al=0,bl=0,cl=0,dl=0,el=0,fl=0,gl=0,hl=0,il=0,jl=0,kl=0,ll=0,ml=0,nl=0,ol=0,pl=0,ql=0,rl=0,sl=0,tl=0,ul=0,vl=0,wl=0,xl=0,yl=0,zl=0,Al=0,Bl=0,Cl=0,Dl=0;f=i;i=i+51400|0;h=f|0;j=f+8|0;k=f+16|0;l=f+24|0;m=f+32|0;n=f+160|0;o=f+288|0;p=f+552|0;q=f+2088|0;r=f+3624|0;s=f+3672|0;t=f+3680|0;u=f+18352|0;v=f+33024|0;w=f+39024|0;y=f+45024|0;z=f+51024|0;A=f+51072|0;B=f+51120|0;C=f+51168|0;D=f+51176|0;E=f+51184|0;G=f+51208|0;H=c[g>>2]|0;g=H+14220|0;I=c[g>>2]|0;Y3()|0;J=v|0;c[z+20>>2]=24e3;c[z+8>>2]=J;c[z+16>>2]=v+3e3;c[z+12>>2]=J;c[z+4>>2]=32;c[z>>2]=0;J=w|0;c[A+20>>2]=24e3;c[A+8>>2]=J;c[A+16>>2]=w+3e3;c[A+12>>2]=J;c[A+4>>2]=32;c[A>>2]=0;J=y|0;c[B+20>>2]=24e3;c[B+8>>2]=J;c[B+16>>2]=y+3e3;c[B+12>>2]=J;c[B+4>>2]=32;c[B>>2]=0;J=v+3e3|0;c[z+44>>2]=24e3;c[z+32>>2]=J;c[z+40>>2]=v+6e3;c[z+36>>2]=J;c[z+28>>2]=32;c[z+24>>2]=0;J=w+3e3|0;c[A+44>>2]=24e3;c[A+32>>2]=J;c[A+40>>2]=w+6e3;c[A+36>>2]=J;c[A+28>>2]=32;c[A+24>>2]=0;J=y+3e3|0;c[B+44>>2]=24e3;c[B+32>>2]=J;c[B+40>>2]=y+6e3;c[B+36>>2]=J;c[B+28>>2]=32;c[B+24>>2]=0;J=H;K=16>>>(I>>>0);I=H+788|0;L=H+792|0;M=H+796|0;N=H+13700|0;c[N>>2]=32-(c[I>>2]|0)+((c[M>>2]|0)-(c[L>>2]|0)<<3);O=H+13664|0;c[O>>2]=0;P=H+13696|0;Q=H+13672|0;R=Q;S=H+13676|0;U=H+13680|0;V=H+13684|0;W=H+13688|0;X=H+13692|0;Y=H+9860|0;Z=H+7848|0;TGb(Q|0,0,28)|0;Q=128<<c[H+14176>>2];c[Y>>2]=Q;_=Z;c[_>>2]=0;c[_+4>>2]=0;c[H+9864>>2]=Q;_=H+7856|0;c[_>>2]=0;c[_+4>>2]=0;c[H+9868>>2]=Q;Q=H+7864|0;c[Q>>2]=0;c[Q+4>>2]=0;Q=H+784|0;_=H+48|0;$=c[_>>2]|0;do{if(($|0)==108){c[Y>>2]=78;c[H+9864>>2]=73;c[H+9868>>2]=73;aa=H+12484|0;c[aa>>2]=0;ca=H+11824|0;TGb(ca|0,0,32)|0;da=H+14144|0;c[da>>2]=0;ea=aa;fa=ca;ga=da}else{da=H+12484|0;c[da>>2]=0;ca=H+11824|0;TGb(ca|0,0,32)|0;aa=H+14144|0;c[aa>>2]=0;if(($|0)==5|($|0)==20|($|0)==22){c[H+13784>>2]=Cca(J)|0;ea=da;fa=ca;ga=aa;break}else if(($|0)!=13){ea=da;fa=ca;ga=aa;break}if((c[H+13940>>2]|0)==0){ea=da;fa=ca;ga=aa;break}yNa(J);ea=da;fa=ca;ga=aa}}while(0);$=H+13704|0;c[$>>2]=0;aa=H+13708|0;c[aa>>2]=0;ca=H+14084|0;c[ca>>2]=1;da=H+14280|0;c[da>>2]=c[L>>2];ha=H+808|0;ia=c[ha>>2]|0;ja=H+812|0;a:do{if((ia|0)<(c[ja>>2]|0)){ka=H+12476|0;la=H+12480|0;ma=H+9960|0;na=H+116|0;oa=H+124|0;pa=H+12492|0;qa=H+800|0;ra=H+13936|0;sa=H+4|0;ta=H+12496|0;ua=ta;va=H+12500|0;wa=H+12504|0;xa=H+12508|0;ya=H+12512|0;za=H+12516|0;Aa=H+12544|0;Ba=H+12548|0;Ca=H+12552|0;Da=H+14252|0;Ea=H+9924|0;Fa=H+9984|0;Ga=H+13792|0;Ha=H+14404|0;Ia=H+11740|0;Ja=H+14212|0;Ka=q;La=H+148|0;Ma=H+152|0;Na=H+10044|0;Oa=r|0;Pa=r+4|0;Qa=r+8|0;Ra=r+12|0;Sa=r+16|0;Ta=r+20|0;Ua=r+24|0;Va=r+28|0;Wa=r+32|0;Xa=r+36|0;Ya=r+40|0;Za=r+44|0;_a=H+9980|0;$a=H+5400|0;ab=H+5404|0;bb=H+5408|0;cb=H+8|0;db=H+9944|0;eb=H+14216|0;fb=H+12|0;gb=H+11540|0;hb=H+12488|0;ib=H+12472|0;jb=H+11332|0;kb=H+10680|0;lb=H+11736|0;mb=H+60|0;nb=H+10060|0;ob=H+14340|0;pb=H+9200|0;qb=H+10112|0;rb=H+14236|0;sb=H+10540|0;tb=H+3176|0;ub=H+952|0;vb=H+11396|0;wb=H+10808|0;xb=H+9992|0;yb=H+11460|0;zb=H+10936|0;Ab=H+14408|0;Bb=H+14392|0;Cb=H+13084|0;Db=H+13080|0;Eb=H+72|0;Fb=H+76|0;Gb=H+14200|0;Hb=H+200|0;Ib=H+196|0;Jb=H+172|0;Kb=H+204|0;Lb=H+208|0;Mb=H+212|0;Nb=H+216|0;Ob=H+220|0;Pb=H+224|0;Qb=H+180|0;Rb=Qb;Sb=H+13112|0;Tb=H+184|0;Ub=H+13116|0;Vb=H+188|0;Wb=H+13120|0;Xb=H+192|0;Yb=H+13124|0;Zb=H+13128|0;_b=H+13132|0;$b=H+13136|0;ac=H+13140|0;bc=H+13144|0;cc=H+13148|0;dc=H+13152|0;ec=H+13156|0;fc=n|0;gc=H+364|0;hc=H+13100|0;ic=H+13104|0;jc=H+9972|0;kc=m|0;lc=H+11256|0;mc=H+11252|0;nc=o|0;oc=H+11164|0;pc=H+228|0;qc=H+168|0;rc=H+13092|0;sc=H+13096|0;tc=p|0;uc=p+128|0;vc=p+256|0;wc=p+384|0;xc=p+512|0;yc=p+640|0;zc=p+768|0;Ac=p+896|0;Bc=H+10056|0;Cc=H+10556|0;Dc=H+9976|0;Ec=H+9968|0;Fc=H+9856|0;Hc=H+28|0;Ic=H+11744|0;Jc=Ic;Kc=H+11748|0;Lc=H+11636|0;Mc=H+11708|0;Nc=H+11808|0;Oc=H+11660|0;Pc=H+9148|0;Qc=H+11656|0;Rc=H+11648|0;Sc=H+11652|0;Tc=H+11776|0;Uc=Tc;Vc=H+11780|0;Wc=H+11644|0;Xc=H+11640|0;Yc=H+11716|0;Zc=H+11676|0;_c=Zc;$c=H+11724|0;ad=H+11816|0;bd=H+11692|0;cd=Zc;Zc=Ic;dd=H+13836|0;ed=H+10132|0;fd=Z;gd=H+7856|0;hd=H+7864|0;id=H+10136|0;jd=u+11824|0;kd=u+12484|0;ld=Y;md=u+9860|0;nd=H+9864|0;od=u+9864|0;pd=H+9868|0;qd=u+9868|0;rd=u+13664|0;sd=u+13672|0;td=u+13676|0;ud=u+13680|0;vd=u+13684|0;wd=u+13688|0;xd=u+13692|0;yd=u+13696|0;zd=u+13700|0;Ad=u+9924|0;Bd=u+9960|0;Cd=u+9984|0;Dd=H+14100|0;Ed=u+14100|0;Fd=u+784|0;Gd=Fd;Hd=t+13936|0;Id=H+13940|0;Jd=t+13940|0;Kd=t+12488|0;Ld=t+11744|0;Md=t+11736|0;Nd=t+11740|0;Od=z|0;Pd=A|0;Qd=B|0;Rd=t+9960|0;Sd=H+9136|0;Td=t+11824|0;Ud=t+12484|0;Vd=t+9860|0;Wd=t+9864|0;Xd=t+9868|0;Yd=t+13664|0;Zd=t+13672|0;_d=t+13676|0;$d=t+13680|0;ae=t+13684|0;be=t+13688|0;ce=t+13692|0;de=t+13696|0;ee=t+9924|0;fe=t+784|0;ge=t+14340|0;he=t+180|0;ie=t+184|0;je=t+188|0;ke=t+192|0;le=t+196|0;ne=t+200|0;oe=t+204|0;pe=t+208|0;qe=t+14236|0;re=t+14100|0;se=Q;te=jb;ue=H+9948|0;ve=H+11348|0;we=H+13980|0;xe=H+13984|0;ye=H+13988|0;ze=H+13992|0;Ae=we;Be=u+13980|0;Ce=Be;De=H+13956|0;Ee=H+13960|0;Fe=H+13964|0;Ge=H+13968|0;He=De;Ie=u+13956|0;Je=Ie;Ke=t+13980|0;Le=t+13956|0;Me=t+11744|0;Oe=t+11748|0;Qe=t+11776|0;Re=t+11780|0;Se=H+9876|0;Te=H+9912|0;Ue=H+32|0;Ve=H+9932|0;We=H+13796|0;Ye=H+13800|0;Ze=H+13808|0;$e=H+13804|0;af=H+13784|0;bf=H+14592|0;df=H+108|0;ef=H+13824|0;ff=H+13996|0;gf=H+13972|0;hf=ia;b:while(1){c[ka>>2]=0;c[la>>2]=hf;cPa(J,c[ma>>2]|0);$Oa(J);if((c[na>>2]|0)>0){jf=(hf|0)>0;kf=0;do{lf=(ba(c[oa>>2]|0,hf)|0)+kf|0;mf=b[(c[pa>>2]|0)+(lf<<1)>>1]|0;c[C>>2]=2147483647;nf=c[L>>2]|0;if(((c[qa>>2]|0)-nf-(32-(c[I>>2]|0)+((c[M>>2]|0)-nf<<3)>>3)|0)<3e3){of=12;break b}if((c[ra>>2]|0)!=0){nf=c[ye>>2]|0;if(((c[ff>>2]|0)-nf-(32-(c[xe>>2]|0)+((c[ze>>2]|0)-nf<<3)>>3)|0)<3e3){of=16;break b}nf=c[Fe>>2]|0;if(((c[gf>>2]|0)-nf-(32-(c[Ee>>2]|0)+((c[Ge>>2]|0)-nf<<3)>>3)|0)<3e3){of=16;break b}}c[ka>>2]=kf;c[la>>2]=hf;nf=8>>>((c[(c[sa>>2]|0)+800>>2]|0)>>>0);c[ua>>2]=(c[ua>>2]|0)+2;c[va>>2]=(c[va>>2]|0)+2;c[wa>>2]=(c[wa>>2]|0)+2;c[xa>>2]=(c[xa>>2]|0)+2;c[ya>>2]=(c[ya>>2]|0)+1;c[za>>2]=(c[za>>2]|0)+1;c[Aa>>2]=(c[Aa>>2]|0)+(nf<<1);c[Ba>>2]=(c[Ba>>2]|0)+nf;c[Ca>>2]=(c[Ca>>2]|0)+nf;if((c[_>>2]|0)==4){uca(J);nf=c[la>>2]|0;pf=ba(c[oa>>2]|0,nf)|0;qf=c[ka>>2]|0;rf=pf+qf|0;sf=rf;tf=b[(c[pa>>2]|0)+(rf<<1)>>1]|0;uf=qf;vf=nf}else{sf=lf;tf=mf;uf=kf;vf=hf}mf=tf&65535;c:do{if((c[Da>>2]|0)==0){wf=uf}else{lf=c[(c[sa>>2]|0)+628>>2]|0;do{if((lf|0)==0){xf=0}else{nf=c[L>>2]|0;if((nf-(c[da>>2]|0)+(39-(c[I>>2]|0)+((c[M>>2]|0)-nf<<3)>>3)|0)<(lf|0)){xf=0;break}xf=(kf+hf|0)>0|0}}while(0);lf=(c[ha>>2]|0)==(hf|0);nf=(kf|0)==0;qf=lf&jf&nf?1:xf;d:do{switch(c[_>>2]|0){case 5:case 20:{if((c[ef>>2]|0)!=0){yf=qf;zf=uf;break d}if((uf|0)!=0){wf=uf;break c}if(((vf|0)%(c[af>>2]|0)|0|0)==0){yf=qf;zf=0}else{wf=0;break c}break};case 2:{if((uf|0)!=0){Af=qf;Bf=uf;of=29;break d}Af=(vf|0)==0?qf:1;Bf=0;of=29;break};case 1:{Af=qf;Bf=uf;of=29;break};case 8:{if((uf|0)!=0){yf=qf;zf=uf;break d}yf=(vf|0)==0?qf:1;zf=0;break};default:{yf=qf;zf=uf}}}while(0);if((of|0)==29){of=0;yf=(c[ea>>2]|0)==0?Af:0;zf=Bf}if((yf|0)==0){wf=zf;break}do{if(!(lf&nf)){xPa(J);if((c[_>>2]|0)!=13){break}if((c[Id>>2]|0)==0){break}yNa(J)}}while(0);nf=c[da>>2]|0;lf=c[M>>2]|0;qf=lf-nf|0;rf=c[bf>>2]|0;do{if((rf|0)==0){Cf=qf}else{if(((c[aa>>2]|0)+(c[$>>2]|0)|0)<=0){Cf=qf;break}if(((((32-(c[I>>2]|0)+(lf-(c[L>>2]|0)<<3)|0)/8|0)+16+(c[df>>2]|0)+(c[ka>>2]|0)+(c[la>>2]|0)|0)%(100/(rf|0)|0|0)|0|0)!=0){Cf=qf;break}c[M>>2]=nf;Cf=0}}while(0);qf=c[sa>>2]|0;rf=c[qf+624>>2]|0;if((rf|0)!=0){lf=(ba(hf-(c[aa>>2]|0)|0,c[na>>2]|0)|0)+kf|0;cf[rf&1023](qf,nf,Cf,lf-(c[$>>2]|0)|0)}lf=c[Ga>>2]|0;if((lf|0)!=0){qf=(c[M>>2]|0)-(c[L>>2]|0)<<3;rf=32-(c[I>>2]|0)|0;if((rf-(c[We>>2]<<3)+qf|0)>=(lf<<3|0)){c[Ze>>2]=(c[Ze>>2]|0)+12;c[We>>2]=c[Ye>>2]}c[We>>2]=(qf+rf|0)/8|0}switch(c[_>>2]|0){case 13:{ANa(J);TMa(J);break};case 1:case 2:{JMa(J);wMa(J);break};case 5:case 20:{Jlb(J,hf);break};default:{}}if((c[mb>>2]&512|0)!=0){rf=((c[M>>2]|0)-(c[L>>2]|0)<<3)+(32-(c[I>>2]|0))|0;c[P>>2]=(c[P>>2]|0)-(c[N>>2]|0)+rf;c[N>>2]=rf}c[da>>2]=(c[da>>2]|0)+Cf;c[ca>>2]=1;c[$>>2]=kf;c[aa>>2]=hf;wf=c[ka>>2]|0}}while(0);do{if((c[$>>2]|0)==(wf|0)){if(((c[aa>>2]|0)+1|0)!=(c[la>>2]|0)){break}c[ca>>2]=0}}while(0);c[Ea>>2]=0;c[Fa>>2]=0;rf=c[Ga>>2]|0;if((rf|0)!=0){qf=(c[M>>2]|0)-(c[L>>2]|0)<<3;lf=32-(c[I>>2]|0)|0;pf=c[Ze>>2]|0;if((lf-(c[We>>2]<<3)+qf|0)<(rf<<3|0)){Df=pf}else{rf=pf+12|0;c[Ze>>2]=rf;c[We>>2]=c[Ye>>2];Df=rf}rf=qf+lf|0;c[Ye>>2]=(rf|0)/8|0;if((Df|0)==0){c[Ze>>2]=12;Ef=12}else{Ef=Df}lf=c[$e>>2]|0;qf=c[la>>2]|0;pf=c[af>>2]|0;Ff=(ba((qf|0)%(pf|0)|0,c[na>>2]|0)|0)+wf|0;Bca(J,0,0,h,j)|0;Gf=lf+(Ef-12)|0;x=rf;a[Gf]=x;x=x>>8;a[Gf+1|0]=x;x=x>>8;a[Gf+2|0]=x;x=x>>8;a[Gf+3|0]=x;a[lf+(Ef-8)|0]=c[ma>>2];a[lf+(Ef-7)|0]=(qf|0)/(pf|0)|0;pf=lf+(Ef-6)|0;x=Ff&65535;a[pf]=x;x=x>>8;a[pf+1|0]=x;a[lf+(Ef-4)|0]=c[h>>2];a[lf+(Ef-3)|0]=c[j>>2];a[lf+(Ef-2)|0]=0;a[lf+(Ef-1)|0]=0}do{if((mf+65535&mf|0)==0){if((c[Ha>>2]&4|0)!=0){of=65;break}c[Ia>>2]=0;switch(mf|0){case 1:{c[lb>>2]=0;c[hb>>2]=1;c[Jc>>2]=0;c[Kc>>2]=0;Hf=0;If=0;break};case 2:{c[lb>>2]=1;c[hb>>2]=0;lf=c[Lc>>2]|0;pf=b[lf+(sf<<2)>>1]|0;c[Jc>>2]=pf;Ff=b[lf+(sf<<2)+2>>1]|0;c[Kc>>2]=Ff;Hf=Ff;If=pf;break};case 256:{c[lb>>2]=1;c[Ia>>2]=3;c[hb>>2]=0;pf=d[(c[Mc>>2]|0)+sf|0]|0;c[Nc>>2]=pf;Ff=Oc+(pf<<2)|0;c[Ic>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11712>>2]|0)+sf|0]|0;c[H+11812>>2]=Ff;pf=Oc+8+(Ff<<2)|0;c[H+11752>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;Hf=0;If=0;break};case 4:{c[lb>>2]=1;c[Ia>>2]=1;c[hb>>2]=0;pf=c[ta>>2]|0;Ff=c[Pc>>2]|0;c[Ic>>2]=b[Ff+(pf<<2)>>1]|0;c[H+11748>>2]=b[Ff+(pf<<2)+2>>1]|0;pf=c[H+12500>>2]|0;c[H+11752>>2]=b[Ff+(pf<<2)>>1]|0;c[H+11756>>2]=b[Ff+(pf<<2)+2>>1]|0;pf=c[H+12504>>2]|0;c[H+11760>>2]=b[Ff+(pf<<2)>>1]|0;c[H+11764>>2]=b[Ff+(pf<<2)+2>>1]|0;pf=c[H+12508>>2]|0;c[H+11768>>2]=b[Ff+(pf<<2)>>1]|0;c[H+11772>>2]=b[Ff+(pf<<2)+2>>1]|0;Hf=0;If=0;break};case 16:{c[lb>>2]=7;c[hb>>2]=0;pf=c[Qc>>2]|0;Ff=b[pf+(sf<<2)>>1]|0;lf=b[pf+(sf<<2)+2>>1]|0;VMa(J,Ff,lf)|0;Hf=lf;If=Ff;break};case 4096:{c[lb>>2]=7;c[hb>>2]=0;VMa(J,0,0)|0;Hf=0;If=0;break};case 128:{c[lb>>2]=3;c[hb>>2]=0;Ff=c[Rc>>2]|0;c[Jc>>2]=b[Ff+(sf<<2)>>1]|0;c[Kc>>2]=b[Ff+(sf<<2)+2>>1]|0;Ff=c[Sc>>2]|0;c[Uc>>2]=b[Ff+(sf<<2)>>1]|0;c[Vc>>2]=b[Ff+(sf<<2)+2>>1]|0;Hf=0;If=0;break};case 64:{c[lb>>2]=2;c[hb>>2]=0;Ff=c[Wc>>2]|0;lf=b[Ff+(sf<<2)>>1]|0;c[Uc>>2]=lf;pf=b[Ff+(sf<<2)+2>>1]|0;c[Vc>>2]=pf;Hf=pf;If=lf;break};case 32:{c[lb>>2]=1;c[hb>>2]=0;lf=c[Xc>>2]|0;pf=b[lf+(sf<<2)>>1]|0;c[Jc>>2]=pf;Ff=b[lf+(sf<<2)+2>>1]|0;c[Kc>>2]=Ff;Hf=Ff;If=pf;break};case 512:{c[lb>>2]=1;c[Ia>>2]=3;c[hb>>2]=0;pf=d[(c[Yc>>2]|0)+sf|0]|0;c[Nc>>2]=pf;Ff=_c+(pf<<2)|0;c[Ic>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11720>>2]|0)+sf|0]|0;c[H+11812>>2]=Ff;pf=_c+8+(Ff<<2)|0;c[H+11752>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;Hf=0;If=0;break};case 1024:{c[lb>>2]=2;c[Ia>>2]=3;c[hb>>2]=0;pf=d[(c[$c>>2]|0)+sf|0]|0;c[ad>>2]=pf;Ff=bd+(pf<<2)|0;c[Tc>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11780>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11728>>2]|0)+sf|0]|0;c[H+11820>>2]=Ff;pf=bd+8+(Ff<<2)|0;c[H+11784>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11788>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;Hf=0;If=0;break};case 2048:{c[lb>>2]=3;c[Ia>>2]=3;c[hb>>2]=0;pf=d[(c[Yc>>2]|0)+sf|0]|0;c[Nc>>2]=pf;Ff=cd+(pf<<2)|0;c[Ic>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11720>>2]|0)+sf|0]|0;c[H+11812>>2]=Ff;pf=cd+8+(Ff<<2)|0;c[H+11752>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;pf=d[(c[H+11724>>2]|0)+sf|0]|0;c[H+11816>>2]=pf;Ff=cd+16+(pf<<2)|0;c[H+11776>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11780>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11728>>2]|0)+sf|0]|0;c[H+11820>>2]=Ff;pf=cd+24+(Ff<<2)|0;c[H+11784>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11788>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;Hf=0;If=0;break};default:{yDb(c[sa>>2]|0,16,2346232,(Jf=i,i=i+1|0,i=i+7&-8,c[Jf>>2]=0,Jf)|0);i=Jf;Hf=0;If=0}}pf=c[Ja>>2]|0;e:do{if((pf|0)==1){Ff=c[ka>>2]|0;lf=c[la>>2]|0;qf=c[La>>2]|0;Gf=c[Ma>>2]|0;rf=c[Na>>2]|0;c[Oa>>2]=rf;c[Pa>>2]=rf;c[Qa>>2]=rf;c[Ra>>2]=rf;c[Sa>>2]=rf;c[Ta>>2]=rf;Kf=qf<<3;qf=Gf<<3;do{if((c[_a>>2]|0)==0){if((c[Ha>>2]&4|0)==0){break}cPa(J,(c[Fa>>2]|0)+(c[ma>>2]|0)|0)}else{Gf=c[ma>>2]|0;Lf=(ba(c[oa>>2]|0,lf)|0)+Ff|0;Mf=c[(c[Dc>>2]|0)+(Lf<<2)>>2]|0;c[Ec>>2]=Mf;Nf=((Mf*139|0)+8192|0)>>>14;c[ma>>2]=Nf;Of=c[sa>>2]|0;Pf=c[Of+500>>2]|0;Qf=c[Of+504>>2]|0;if((Nf|0)<(Pf|0)){Rf=Pf}else{Rf=(Nf|0)>(Qf|0)?Qf:Nf}c[ma>>2]=Rf;c[jc>>2]=((ba(Mf,Mf)|0)+64|0)>>>7;do{if((c[Ha>>2]&4|0)==0){Mf=a[(c[(c[Fc>>2]|0)+1512>>2]|0)+Lf|0]|0;c[ma>>2]=Mf;Nf=Mf-Gf|0;c[Fa>>2]=Nf;if((c[Hc>>2]|0)!=2){Sf=Nf;break}if((Nf|0)<-2){Tf=-2}else{Tf=(Nf|0)>2?2:Nf}c[Fa>>2]=Tf;if((c[_>>2]|0)!=13){Sf=Tf;break}if((c[hb>>2]|0)!=0){Sf=Tf;break}do{if((c[xb>>2]|0)==3){if((Tf&1|0)==0){if((c[lb>>2]&4|0)==0){Uf=Tf;break}}c[Fa>>2]=0;Uf=0}else{Uf=Tf}}while(0);if((c[Ia>>2]|0)!=1){Sf=Uf;break}c[Fa>>2]=0;Sf=0}else{Sf=c[Fa>>2]|0}}while(0);cPa(J,Sf+Gf|0)}}while(0);Lf=c[La>>2]|0;Nf=c[Ma>>2]|0;Mf=lf<<4;Qf=Ff<<4;Pf=(c[$a>>2]|0)+((ba(Lf,Mf)|0)+Qf)|0;Of=lf<<3;Vf=Ff<<3;Wf=(ba(Nf,Of)|0)+Vf|0;Xf=(c[ab>>2]|0)+Wf|0;Yf=(c[bb>>2]|0)+Wf|0;Wf=c[cb>>2]|0;if((Qf+16|0)>(Wf|0)){of=178}else{if((Mf+16|0)>(c[fb>>2]|0)){of=178}else{Zf=Pf;_f=Xf;$f=Yf}}do{if((of|0)==178){of=0;if((c[_>>2]|0)==108){Zf=Pf;_f=Xf;$f=Yf;break}ag=c[db>>2]|0;bg=ag+32|0;cg=c[eb>>2]|0;dg=cg+Wf>>cg;cg=c[fb>>2]|0;eg=c[g>>2]|0;fg=eg+cg>>eg;Ne[c[gb>>2]&127](bg,Pf,Lf,Lf,16,16,Qf,Mf,Wf,cg);cg=Lf*18|0;eg=ag+(cg+32)|0;Ne[c[gb>>2]&127](eg,Xf,Nf,Nf,8,8,Vf,Of,dg,fg);gg=ag+(cg+48)|0;Ne[c[gb>>2]&127](gg,Yf,Nf,Nf,8,8,Vf,Of,dg,fg);Zf=bg;_f=eg;$f=gg}}while(0);do{if((c[hb>>2]|0)==0){Of=c[Aa>>2]|0;Vf=c[Ba>>2]|0;Yf=c[Ca>>2]|0;if((c[ib>>2]|0)==0){hg=kb;ig=jb}else{Xf=(c[xb>>2]|0)==3;hg=Xf?kb:zb;ig=Xf?jb:yb}Xf=hg;Wf=ig;Mf=c[lb>>2]|0;if((Mf&1|0)==0){jg=Xf;kg=Wf;lg=Mf}else{APa(J,Of,Vf,Yf,0,ub,Wf,Xf);jg=wb;kg=vb;lg=c[lb>>2]|0}if((lg&2|0)!=0){APa(J,Of,Vf,Yf,1,tb,kg,jg)}do{if((c[mb>>2]&262144|0)==0){mg=Kf;ng=qf;og=Lf;pg=Nf}else{c[rb>>2]=0;Xf=Pe[c[sb>>2]&255](H,Of,Zf,Lf,8)|0;Wf=Lf<<3;Mf=(Pe[c[sb>>2]&255](H,Of+Wf|0,Zf+Wf|0,Lf,8)|0)+Xf|0;Xf=Mf+((c[(c[sa>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((Xf|0)<=0){mg=Kf;ng=qf;og=Lf;pg=Nf;break}Mf=Lf<<1;Wf=Pe[c[sb>>2]&255](H,Of,Zf,Mf,8)|0;if((Xf|0)<=((Pe[c[sb>>2]&255](H,Of+Lf|0,Zf+Lf|0,Mf,8)|0)+Wf|0)){mg=Kf;ng=qf;og=Lf;pg=Nf;break}c[rb>>2]=1;mg=Lf;ng=Nf;og=Mf;pg=Nf<<((c[Ja>>2]|0)==2)}}while(0);cf[c[nb>>2]&1023](c[ob>>2]|0,Zf,Of,og);Gf=Zf+8|0;Mf=Of+8|0;cf[c[nb>>2]&1023]((c[ob>>2]|0)+128|0,Gf,Mf,og);Wf=Zf+mg|0;Xf=Of+mg|0;cf[c[nb>>2]&1023]((c[ob>>2]|0)+256|0,Wf,Xf,og);Qf=mg+8|0;Pf=Zf+Qf|0;gg=Of+Qf|0;cf[c[nb>>2]&1023]((c[ob>>2]|0)+384|0,Pf,gg,og);do{if((c[mb>>2]&8192|0)==0){cf[c[nb>>2]&1023]((c[ob>>2]|0)+512|0,_f,Vf,pg);cf[c[nb>>2]&1023]((c[ob>>2]|0)+640|0,$f,Yf,pg);if((c[g>>2]|0)!=0){break}cf[c[nb>>2]&1023]((c[ob>>2]|0)+768|0,_f+ng|0,Vf+ng|0,pg);cf[c[nb>>2]&1023]((c[ob>>2]|0)+896|0,$f+ng|0,Yf+ng|0,pg)}else{c[Sa>>2]=1;c[Ta>>2]=1}}while(0);Qf=(ba(c[oa>>2]|0,lf)|0)+Ff|0;eg=c[ma>>2]|0;if((e[(c[pb>>2]|0)+(Qf<<1)>>1]|0)>=(ba(eg<<1,eg)|0)){qg=mg;rg=ng;sg=og;tg=pg;ug=rf;vg=rf;wg=rf;break}eg=Pe[c[qb>>2]&255](0,Zf,Of,og,8)|0;if((eg|0)<((c[ma>>2]|0)*20|0|0)){c[Oa>>2]=1;xg=1}else{xg=rf}eg=Pe[c[qb>>2]&255](0,Gf,Mf,og,8)|0;if((eg|0)<((c[ma>>2]|0)*20|0|0)){c[Pa>>2]=1;yg=1}else{yg=rf}eg=Pe[c[qb>>2]&255](0,Wf,Xf,og,8)|0;if((eg|0)<((c[ma>>2]|0)*20|0|0)){c[Qa>>2]=1;zg=1}else{zg=rf}eg=Pe[c[qb>>2]&255](0,Pf,gg,og,8)|0;if((eg|0)<((c[ma>>2]|0)*20|0|0)){c[Ra>>2]=1}eg=Pe[c[qb>>2]&255](0,_f,Vf,pg,8)|0;if((eg|0)<((c[ma>>2]|0)*20|0|0)){c[Sa>>2]=1}eg=Pe[c[qb>>2]&255](0,$f,Yf,pg,8)|0;if((eg|0)<((c[ma>>2]|0)*20|0|0)){c[Ta>>2]=1}if((c[g>>2]|0)!=0){qg=mg;rg=ng;sg=og;tg=pg;ug=xg;vg=yg;wg=zg;break}eg=Pe[c[qb>>2]&255](0,_f+ng|0,Vf+ng|0,pg,8)|0;if((eg|0)<((c[ma>>2]|0)*20|0|0)){c[Ua>>2]=1}eg=Pe[c[qb>>2]&255](0,$f+ng|0,Yf+ng|0,pg,8)|0;if((eg|0)>=((c[ma>>2]|0)*20|0|0)){qg=mg;rg=ng;sg=og;tg=pg;ug=xg;vg=yg;wg=zg;break}c[Va>>2]=1;qg=mg;rg=ng;sg=og;tg=pg;ug=xg;vg=yg;wg=zg}else{do{if((c[mb>>2]&262144|0)==0){Ag=Kf;Bg=qf;Cg=Lf;Dg=Nf}else{c[rb>>2]=0;eg=Pe[c[Cc>>2]&255](H,Zf,0,Lf,8)|0;Qf=eg-400+(Pe[c[Cc>>2]&255](H,Zf+(Lf<<3)|0,0,Lf,8)|0)|0;if((Qf|0)<=0){Ag=Kf;Bg=qf;Cg=Lf;Dg=Nf;break}eg=Lf<<1;bg=Pe[c[Cc>>2]&255](H,Zf,0,eg,8)|0;if((Qf|0)<=((Pe[c[Cc>>2]&255](H,Zf+Lf|0,0,eg,8)|0)+bg|0)){Ag=Kf;Bg=qf;Cg=Lf;Dg=Nf;break}c[rb>>2]=1;Ag=Lf;Bg=Nf;Cg=eg;Dg=Nf<<(((c[Ja>>2]|0)-2|0)>>>0<2>>>0)}}while(0);Xe[c[Bc>>2]&4095](c[ob>>2]|0,Zf,Cg);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+128|0,Zf+8|0,Cg);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+256|0,Zf+Ag|0,Cg);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+384|0,Zf+(Ag+8)|0,Cg);if((c[mb>>2]&8192|0)!=0){c[Sa>>2]=1;c[Ta>>2]=1;qg=Ag;rg=Bg;sg=Cg;tg=Dg;ug=rf;vg=rf;wg=rf;break}Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+512|0,_f,Dg);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+640|0,$f,Dg);if((c[g>>2]|0)!=0){qg=Ag;rg=Bg;sg=Cg;tg=Dg;ug=rf;vg=rf;wg=rf;break}Yf=c[Bc>>2]|0;Vf=(c[ob>>2]|0)+768|0;if((c[eb>>2]|0)==0){Xe[Yf&4095](Vf,_f+8|0,Dg);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,$f+8|0,Dg);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1024|0,_f+Bg|0,Dg);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1152|0,$f+Bg|0,Dg);gg=Bg+8|0;Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1280|0,_f+gg|0,Dg);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1408|0,$f+gg|0,Dg);qg=Ag;rg=Bg;sg=Cg;tg=Dg;ug=rf;vg=rf;wg=rf;break}else{Xe[Yf&4095](Vf,_f+Bg|0,Dg);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,$f+Bg|0,Dg);qg=Ag;rg=Bg;sg=Cg;tg=Dg;ug=rf;vg=rf;wg=rf;break}}}while(0);if((c[Ab>>2]|0)==0){Eg=0}else{if((ug|0)==0){zPa(tc,Zf,sg)}if((vg|0)==0){zPa(uc,Zf+8|0,sg);Fg=c[Qa>>2]|0}else{Fg=wg}if((Fg|0)==0){zPa(vc,Zf+qg|0,sg)}if((c[Ra>>2]|0)==0){zPa(wc,Zf+(qg+8)|0,sg)}if((c[Sa>>2]|0)==0){zPa(xc,_f,tg)}if((c[Ta>>2]|0)==0){zPa(yc,$f,tg)}do{if((c[g>>2]|0)==0){if((c[Ua>>2]|0)==0){zPa(zc,_f+rg|0,tg)}if((c[Va>>2]|0)!=0){break}zPa(Ac,$f+rg|0,tg)}}while(0);UGb(Ka|0,c[ob>>2]|0,768)|0;Eg=0}do{do{if((c[r+(Eg<<2)>>2]|0)==0){rf=Pe[c[Bb>>2]&255](J,(c[ob>>2]|0)+(Eg<<7)|0,Eg,c[ma>>2]|0,s)|0;c[J+180+(Eg<<2)>>2]=rf;if((c[s>>2]|0)==0){break}Nf=c[ob>>2]|0;Lf=c[Cb>>2]|0;qf=c[Db>>2]|0;Kf=(c[hb>>2]|0)!=0|0;if((Kf|0)>(rf|0)){break}Ff=Lf&65535;lf=qf&65535;Vf=0;Yf=Kf;while(1){Kf=Nf+(Eg<<7)+(d[J+368+Yf|0]<<1)|0;gg=b[Kf>>1]|0;Pf=gg<<16>>16;if((Pf|0)>(Lf|0)){Gg=Ff;Hg=Vf+1|0}else{Xf=(Pf|0)<(qf|0);Gg=Xf?lf:gg;Hg=(Xf&1)+Vf|0}b[Kf>>1]=Gg;Kf=Yf+1|0;if((Kf|0)>(rf|0)){break}else{Vf=Hg;Yf=Kf}}if((Hg|0)==0){break}Yf=c[sa>>2]|0;if((c[Yf+296>>2]|0)!=0){break}yDb(Yf,32,2344760,(Jf=i,i=i+24|0,c[Jf>>2]=Hg,c[Jf+8>>2]=qf,c[Jf+16>>2]=Lf,Jf)|0);i=Jf}else{c[J+180+(Eg<<2)>>2]=-1}}while(0);Eg=Eg+1|0;}while((Eg|0)<6);if((c[Ab>>2]|0)!=0){Yf=0;do{if((c[r+(Yf<<2)>>2]|0)==0){Vf=c[ob>>2]|0;rf=Vf+(Yf<<7)|0;lf=p+(Yf<<7)|0;Ff=c[ma>>2]|0;Nf=c[gc>>2]|0;if((b[4432924]|0)==0){Kf=0;do{Xf=Kf<<3;Ig=(Kf|0)==0?11585.237502960395:16384.0;Jg=Ig*.7071067811865476;Kg=+(Kf|0)*.39269908169872414;gg=0;do{Pf=gg+Xf+(J+11184)|0;Wf=(gg|0)==0;Lg=+(gg|0)*.39269908169872414;Mf=0;do{Mg=+T(Lg*(+(Mf|0)+.5));if(Wf){Gf=0;do{Of=d[Pf]|0;b[8865848+(Of<<7)+((Gf<<3)+Mf<<1)>>1]=Gc(+(Mg*Jg*+T(Kg*(+(Gf|0)+.5))))|0;Gf=Gf+1|0;}while((Gf|0)<8)}else{Gf=0;do{Of=d[Pf]|0;b[8865848+(Of<<7)+((Gf<<3)+Mf<<1)>>1]=Gc(+(Mg*Ig*+T(Kg*(+(Gf|0)+.5))))|0;Gf=Gf+1|0;}while((Gf|0)<8)}Mf=Mf+1|0;}while((Mf|0)<8);gg=gg+1|0;}while((gg|0)<8);Kf=Kf+1|0;}while((Kf|0)<8)}Kf=Ff<<1;gg=Ff-1|1;if((c[hb>>2]|0)==0){Ng=gg;Og=0;Pg=32;Qg=hc;Rg=ic;Sg=1}else{do{if((c[pc>>2]|0)==0){if((Yf|0)<4){Tg=gg;Ug=c[qc>>2]|0;break}else{Tg=gg;Ug=c[Jb>>2]|0;break}}else{Tg=0;Ug=1}}while(0);gg=Ug<<3;Ng=Tg;Og=1;Pg=(ba(b[rf>>1]|0,gg)|0)+32|0;Qg=rc;Rg=sc;Sg=gg}gg=c[Qg>>2]|0;Ff=c[Rg>>2]|0;Xf=J+180+(Yf<<2)|0;Lf=c[Xf>>2]|0;qf=0;while(1){b[m+(qf<<1)>>1]=Pg-(b[q+(Yf<<7)+(qf<<1)>>1]<<6);Mf=qf+1|0;if((Mf|0)<64){qf=Mf}else{Vg=0;Wg=0;break}}do{qf=p+(Yf<<7)+(Wg<<1)|0;Mf=b[qf>>1]|0;Pf=Mf<<16>>16;Wf=(Mf<<16>>16>-1?Pf:-Pf|0)+144|0;Pf=((((Wf|0)/2|0)+6912|0)/(Wf|0)|0)+15|0;b[qf>>1]=Pf;Vg=(ba(Pf,Pf)|0)+Vg|0;Wg=Wg+1|0;}while((Wg|0)<64);Pf=gHb(c[jc>>2]|0,0,Vg,(Vg|0)<0|0?-1:0)|0;qf=Pf>>>19|F<<13;Pf=-Ng|0;if((Og|0)<=(Lf|0)){Wf=0;Mf=0;Gf=Og;while(1){Of=d[J+368+Gf|0]|0;eg=b[Vf+(Yf<<7)+(Of<<1)>>1]|0;if(eg<<16>>16==0){Xg=Mf;Yg=Wf+1|0}else{bg=ba(eg<<16>>16,Kf)|0;c[o+(Mf<<2)>>2]=Wf;Xe[c[lc>>2]&4095](kc,8865848+(Of<<7)|0,bg+(eg<<16>>16<0?Pf:Ng)|0);Xg=Mf+1|0;Yg=0}eg=Gf+1|0;if((eg|0)>(Lf|0)){break}else{Wf=Yg;Mf=Xg;Gf=eg}}}Gf=(Og|0)==0;Mf=-Sg|0;Wf=Lf;while(1){eg=_e[c[mc>>2]&1023](kc,lf,8865848,0)|0;if((Wf|0)>2){Zg=0;of=283}else{if((c[Ab>>2]|0)>2){Zg=0;of=283}else{_g=0}}if((of|0)==283){while(1){of=0;bg=b[p+(Yf<<7)+(Zg<<1)>>1]|0;b[n+(Zg<<1)>>1]=(ba(ba(bg,bg)|0,b[m+(Zg<<1)>>1]|0)|0)+131072>>18;bg=Zg+1|0;if((bg|0)<64){Zg=bg;of=283}else{break}}me[c[oc>>2]&511](fc);_g=1}do{if(Gf){$g=eg;ah=0;bh=0}else{bg=b[rf>>1]|0;if((ba(bg-1|0,Sg)|0)>>>0>2047>>>0){ch=eg;dh=0;eh=0}else{Of=_e[c[mc>>2]&1023](kc,lf,8865848,Mf)|0;Qf=(Of|0)<(eg|0);ch=Qf?Of:eg;dh=Qf<<31>>31;eh=Qf?Mf:0}if((ba(bg+1|0,Sg)|0)>>>0>2047>>>0){$g=ch;ah=dh;bh=eh;break}bg=_e[c[mc>>2]&1023](kc,lf,8865848,Sg)|0;Qf=(bg|0)<(ch|0);$g=Qf?bg:ch;ah=Qf?1:dh;bh=Qf?Sg:eh}}while(0);eg=Wf+1|0;Qf=c[nc>>2]|0;bg=bh;Of=ah;fg=0;dg=$g;cg=0;ag=1;fh=Og;gh=0;hh=0;while(1){ih=d[J+368+fh|0]|0;jh=b[Vf+(Yf<<7)+(ih<<1)>>1]|0;kh=jh<<16>>16;lh=c[Ab>>2]|0;if((lh|0)<3&(fh|0)>(eg|0)){mh=bg;nh=Of;oh=fg;break}ph=jh<<16>>16!=0;if(ph){qh=ba(kh,Kf)|0;rh=qh+(jh<<16>>16<0?Pf:Ng)|0;sh=ag+1|0;th=c[o+(ag<<2)>>2]|0}else{rh=0;sh=ag;th=Qf-1|0}qh=jh<<16>>16>-1?kh:-kh|0;uh=(fh|0)<(Wf|0);vh=fh+1|0;wh=th+vh|0;xh=J+368+wh|0;yh=(wh|0)<(Wf|0);wh=(th+cg<<7)+128|0;zh=th<<7;Ah=cg<<7;Bh=Ah|65;Ch=gg+Bh|0;Dh=Ff+Bh|0;Bh=(gh|0)==0;Eh=(hh<<7)+gh|0;Fh=Ff+Eh|0;Gh=gg+Eh|0;Eh=8865848+(ih<<7)|0;ih=(jh+62&65535)>>>0<125>>>0;jh=Ah|64;Ah=kh+jh|0;Hh=gg+Ah|0;Ih=Ff+Ah|0;Ah=Nf+fh|0;Jh=bg;Kh=Of;Lh=fg;Mh=dg;Nh=-1;Oh=lh;while(1){lh=Nh+kh|0;if((Oh|0)<2){if((((lh|0)>-1?lh:-lh|0)|0)>(qh|0)){Ph=Mh;Qh=Lh;Rh=Kh;Sh=Jh}else{of=297}}else{of=297}f:do{if((of|0)==297){of=0;do{if((lh|0)==0){if(!uh){Th=d[Dh]|0;if(Bh){Uh=0;Vh=-Th|0;break}Uh=0;Vh=(d[Fh]|0)-Th-(d[Gh]|0)|0;break}Th=(b[Vf+(Yf<<7)+(d[xh]<<1)>>1]|0)+64|0;Wh=Th>>>0>127>>>0?0:Th;Th=Wh+wh|0;if(yh){Uh=0;Vh=(d[gg+Th|0]|0)-(d[gg+(Wh+zh)|0]|0)-(d[Ch]|0)|0;break}else{Uh=0;Vh=(d[Ff+Th|0]|0)-(d[Ff+(Wh+zh)|0]|0)-(d[Ch]|0)|0;break}}else{Wh=ba(lh,Kf)|0;Th=((lh|0)<0?Pf:Ng)+Wh|0;if((Th+2047|0)>>>0>4094>>>0){Ph=Mh;Qh=Lh;Rh=Kh;Sh=Jh;break f}if(ph){if(!ih){Uh=Th;Vh=0;break}Wh=lh+jh|0;if(uh){Uh=Th;Vh=(d[gg+Wh|0]|0)-(d[Hh]|0)|0;break}else{Uh=Th;Vh=(d[Ff+Wh|0]|0)-(d[Ih]|0)|0;break}}do{if(_g){Wh=b[n+(d[Ah]<<1)>>1]|0;if(Wh<<16>>16==0){break}if((Wh<<16>>16^lh|0)>-1){Ph=Mh;Qh=Lh;Rh=Kh;Sh=Jh;break f}}}while(0);if(!uh){Wh=d[Dh]|0;if(Bh){Uh=Th;Vh=Wh;break}Uh=Th;Vh=(d[Gh]|0)+Wh-(d[Fh]|0)|0;break}Wh=(b[Vf+(Yf<<7)+(d[xh]<<1)>>1]|0)+64|0;Xh=Wh>>>0>127>>>0?0:Wh;Wh=d[Ch]|0;Yh=Xh+zh|0;if(yh){Uh=Th;Vh=(d[gg+Yh|0]|0)+Wh-(d[gg+(Xh+wh)|0]|0)|0;break}else{Uh=Th;Vh=(d[Ff+Yh|0]|0)+Wh-(d[Ff+(Xh+wh)|0]|0)|0;break}}}while(0);Xh=ba(Vh,qf)|0;Wh=Uh-rh|0;Yh=(_e[c[mc>>2]&1023](kc,lf,Eh,Wh)|0)+Xh|0;Xh=(Yh|0)<(Mh|0);Ph=Xh?Yh:Mh;Qh=Xh?fh:Lh;Rh=Xh?Nh:Kh;Sh=Xh?Wh:Jh}}while(0);if((Nh|0)>=0){break}Jh=Sh;Kh=Rh;Lh=Qh;Mh=Ph;Nh=Nh+2|0;Oh=c[Ab>>2]|0}if(ph){Oh=kh+64|0;Zh=cg;_h=Oh>>>0>127>>>0?0:Oh;$h=0}else{Zh=hh;_h=gh;$h=cg+1|0}if((vh|0)<64){Qf=th;bg=Sh;Of=Rh;fg=Qh;dg=Ph;cg=$h;ag=sh;fh=vh;gh=_h;hh=Zh}else{mh=Sh;nh=Rh;oh=Qh;break}}if((nh|0)==0){break}hh=d[J+368+oh|0]|0;gh=Vf+(Yf<<7)+(hh<<1)|0;b[gh>>1]=(e[gh>>1]|0)+nh;g:do{if((oh|0)>(Wf|0)){ai=oh}else{gh=Wf;while(1){if((gh|0)<(Og|0)){ai=gh;break g}if((b[Vf+(Yf<<7)+(d[J+368+gh|0]<<1)>>1]|0)==0){gh=gh-1|0}else{ai=gh;break}}}}while(0);if((Og|0)<=(ai|0)){gh=0;vh=0;kh=Og;while(1){if((b[Vf+(Yf<<7)+(d[J+368+kh|0]<<1)>>1]|0)==0){bi=vh;ci=gh+1|0}else{c[o+(vh<<2)>>2]=gh;bi=vh+1|0;ci=0}ph=kh+1|0;if((ph|0)>(ai|0)){break}else{gh=ci;vh=bi;kh=ph}}}Xe[c[lc>>2]&4095](kc,8865848+(hh<<7)|0,mh);Wf=ai}c[Xf>>2]=Wf}Yf=Yf+1|0;}while((Yf|0)<6)}Yf=c[Eb>>2]|0;h:do{if((Yf|0)!=0){if((c[hb>>2]|0)==0){di=0;ei=Yf}else{break}while(1){Vf=c[ob>>2]|0;lf=Vf+(di<<7)|0;qf=J+180+(di<<2)|0;Ff=c[qf>>2]|0;gg=ei>>>31;Pf=gg^1;Kf=(ei|0)<0?-ei|0:ei;i:do{if((Ff|0)>(gg<<31>>31|0)){if((Ff|0)<0){fi=0}else{Nf=(gg|0)!=1;Mf=0;rf=0;Gf=0;while(1){Lf=b[Vf+(di<<7)+(d[J+368+Mf|0]<<1)>>1]|0;kh=Lf<<16>>16;vh=Lf<<16>>16>-1?kh:-kh|0;do{if((vh|0)==1){if(Nf&(Mf|0)==0){gi=Gf;hi=rf;break}gi=(a[1405072+rf|0]|0)+Gf|0;hi=0}else{if((vh|0)>1){break i}gi=Gf;hi=rf+1|0}}while(0);vh=Mf+1|0;if((vh|0)>(Ff|0)){fi=gi;break}else{Mf=vh;rf=hi;Gf=gi}}}if((fi|0)>=(Kf|0)){break}if((Pf|0)<=(Ff|0)){Gf=Pf;do{b[Vf+(di<<7)+(d[J+368+Gf|0]<<1)>>1]=0;Gf=Gf+1|0;}while((Gf|0)<=(Ff|0))}if((b[lf>>1]|0)==0){c[qf>>2]=-1;break}else{c[qf>>2]=0;break}}}while(0);qf=di+1|0;if((qf|0)>=4){break h}di=qf;ei=c[Eb>>2]|0}}}while(0);Yf=c[Fb>>2]|0;j:do{if((Yf|0)!=0){if((c[hb>>2]|0)==0){ii=4;ji=Yf}else{break}while(1){Wf=c[ob>>2]|0;Xf=Wf+(ii<<7)|0;qf=J+180+(ii<<2)|0;lf=c[qf>>2]|0;Ff=ji>>>31;Vf=Ff^1;Pf=(ji|0)<0?-ji|0:ji;k:do{if((lf|0)>(Ff<<31>>31|0)){if((lf|0)<0){ki=0}else{Kf=(Ff|0)!=1;gg=0;hh=0;Gf=0;while(1){rf=b[Wf+(ii<<7)+(d[J+368+gg|0]<<1)>>1]|0;Mf=rf<<16>>16;Nf=rf<<16>>16>-1?Mf:-Mf|0;do{if((Nf|0)==1){if(Kf&(gg|0)==0){li=Gf;mi=hh;break}li=(a[1405072+hh|0]|0)+Gf|0;mi=0}else{if((Nf|0)>1){break k}li=Gf;mi=hh+1|0}}while(0);Nf=gg+1|0;if((Nf|0)>(lf|0)){ki=li;break}else{gg=Nf;hh=mi;Gf=li}}}if((ki|0)>=(Pf|0)){break}if((Vf|0)<=(lf|0)){Gf=Vf;do{b[Wf+(ii<<7)+(d[J+368+Gf|0]<<1)>>1]=0;Gf=Gf+1|0;}while((Gf|0)<=(lf|0))}if((b[Xf>>1]|0)==0){c[qf>>2]=-1;break}else{c[qf>>2]=0;break}}}while(0);qf=ii+1|0;if((qf|0)>=6){break j}ii=qf;ji=c[Fb>>2]|0}}}while(0);do{if((c[Ha>>2]&8|0)!=0){if((c[Rb>>2]|0)==-1){c[Sb>>2]=8388607}if((c[Tb>>2]|0)==-1){c[Ub>>2]=8388607}if((c[Vb>>2]|0)==-1){c[Wb>>2]=8388607}if((c[Xb>>2]|0)==-1){c[Yb>>2]=8388607}if((c[Ib>>2]|0)==-1){c[Zb>>2]=8388607}if(!((c[Hb>>2]|0)==-1)){break}c[_b>>2]=8388607}}while(0);do{if((c[mb>>2]&8192|0)!=0){if((c[hb>>2]|0)==0){break}c[Hb>>2]=0;c[Ib>>2]=0;Yf=c[Jb>>2]|0;qf=((((Yf|0)/2|0)+1024|0)/(Yf|0)|0)&65535;Yf=c[ob>>2]|0;b[Yf+640>>1]=qf;b[Yf+512>>1]=qf;if((c[g>>2]|0)!=0){break}c[Kb>>2]=0;b[Yf+768>>1]=qf;c[Lb>>2]=0;b[Yf+896>>1]=qf;c[Mb>>2]=0;b[Yf+1024>>1]=qf;c[Nb>>2]=0;b[Yf+1152>>1]=qf;c[Ob>>2]=0;b[Yf+1280>>1]=qf;c[Pb>>2]=0;b[Yf+1408>>1]=qf}}while(0);do{if((c[Gb>>2]|0)!=0){if((c[Bb>>2]|0)==2){break}if((c[Rb>>2]|0)>0){qf=63;while(1){if((qf|0)<=0){break}if((b[(c[ob>>2]|0)+(d[J+368+qf|0]<<1)>>1]|0)==0){qf=qf-1|0}else{break}}c[Rb>>2]=qf}if((c[Tb>>2]|0)>0){Yf=63;while(1){if((Yf|0)<=0){break}if((b[(c[ob>>2]|0)+128+(d[J+368+Yf|0]<<1)>>1]|0)==0){Yf=Yf-1|0}else{break}}c[Tb>>2]=Yf}if((c[Vb>>2]|0)>0){qf=63;while(1){if((qf|0)<=0){break}if((b[(c[ob>>2]|0)+256+(d[J+368+qf|0]<<1)>>1]|0)==0){qf=qf-1|0}else{break}}c[Vb>>2]=qf}if((c[Xb>>2]|0)>0){Yf=63;while(1){if((Yf|0)<=0){break}if((b[(c[ob>>2]|0)+384+(d[J+368+Yf|0]<<1)>>1]|0)==0){Yf=Yf-1|0}else{break}}c[Xb>>2]=Yf}if((c[Ib>>2]|0)>0){qf=63;while(1){if((qf|0)<=0){break}if((b[(c[ob>>2]|0)+512+(d[J+368+qf|0]<<1)>>1]|0)==0){qf=qf-1|0}else{break}}c[Ib>>2]=qf}if((c[Hb>>2]|0)>0){ni=63}else{break}while(1){if((ni|0)<=0){break}if((b[(c[ob>>2]|0)+640+(d[J+368+ni|0]<<1)>>1]|0)==0){ni=ni-1|0}else{break}}c[Hb>>2]=ni}}while(0);switch(c[_>>2]|0){case 1:case 2:{LMa(J,c[ob>>2]|0,If,Hf);break e;break};case 13:{pNa(J,c[ob>>2]|0,If,Hf);break e;break};case 16:case 17:case 18:{eQa(J,c[ob>>2]|0,If,Hf);break e;break};case 19:{edb(J,c[ob>>2]|0,If,Hf);break e;break};case 4:{vca(J,c[ob>>2]|0,If,Hf);break e;break};case 5:case 20:case 22:case 6:case 7:{Llb(J,c[ob>>2]|0,If,Hf);break e;break};case 8:case 108:{OLa(J,c[ob>>2]|0);break e;break};default:{break e}}}else if((pf|0)==2){qf=c[ka>>2]|0;Yf=c[la>>2]|0;Xf=c[La>>2]|0;lf=c[Ma>>2]|0;Wf=c[Na>>2]|0;c[Oa>>2]=Wf;c[Pa>>2]=Wf;c[Qa>>2]=Wf;c[Ra>>2]=Wf;c[Sa>>2]=Wf;c[Ta>>2]=Wf;c[Ua>>2]=Wf;c[Va>>2]=Wf;Vf=Xf<<3;Xf=lf<<3;do{if((c[_a>>2]|0)==0){if((c[Ha>>2]&4|0)==0){break}cPa(J,(c[Fa>>2]|0)+(c[ma>>2]|0)|0)}else{lf=c[ma>>2]|0;Pf=(ba(c[oa>>2]|0,Yf)|0)+qf|0;Ff=c[(c[Dc>>2]|0)+(Pf<<2)>>2]|0;c[Ec>>2]=Ff;Gf=((Ff*139|0)+8192|0)>>>14;c[ma>>2]=Gf;hh=c[sa>>2]|0;gg=c[hh+500>>2]|0;Kf=c[hh+504>>2]|0;if((Gf|0)<(gg|0)){oi=gg}else{oi=(Gf|0)>(Kf|0)?Kf:Gf}c[ma>>2]=oi;c[jc>>2]=((ba(Ff,Ff)|0)+64|0)>>>7;do{if((c[Ha>>2]&4|0)==0){Ff=a[(c[(c[Fc>>2]|0)+1512>>2]|0)+Pf|0]|0;c[ma>>2]=Ff;Gf=Ff-lf|0;c[Fa>>2]=Gf;if((c[Hc>>2]|0)!=2){pi=Gf;break}if((Gf|0)<-2){qi=-2}else{qi=(Gf|0)>2?2:Gf}c[Fa>>2]=qi;if((c[_>>2]|0)!=13){pi=qi;break}if((c[hb>>2]|0)!=0){pi=qi;break}do{if((c[xb>>2]|0)==3){if((qi&1|0)==0){if((c[lb>>2]&4|0)==0){ri=qi;break}}c[Fa>>2]=0;ri=0}else{ri=qi}}while(0);if((c[Ia>>2]|0)!=1){pi=ri;break}c[Fa>>2]=0;pi=0}else{pi=c[Fa>>2]|0}}while(0);cPa(J,pi+lf|0)}}while(0);Pf=c[La>>2]|0;Gf=c[Ma>>2]|0;Ff=Yf<<4;Kf=qf<<4;gg=(c[$a>>2]|0)+((ba(Pf,Ff)|0)+Kf)|0;hh=qf<<3;Nf=(ba(Gf,Ff)|0)+hh|0;Mf=(c[ab>>2]|0)+Nf|0;rf=(c[bb>>2]|0)+Nf|0;Nf=c[cb>>2]|0;if((Kf+16|0)>(Nf|0)){of=421}else{if((Ff+16|0)>(c[fb>>2]|0)){of=421}else{si=gg;ti=Mf;ui=rf}}do{if((of|0)==421){of=0;if((c[_>>2]|0)==108){si=gg;ti=Mf;ui=rf;break}vh=c[db>>2]|0;kh=vh+32|0;Lf=c[eb>>2]|0;gh=Lf+Nf>>Lf;Lf=c[fb>>2]|0;ph=c[g>>2]|0;fh=ph+Lf>>ph;Ne[c[gb>>2]&127](kh,gg,Pf,Pf,16,16,Kf,Ff,Nf,Lf);Lf=Pf*18|0;ph=vh+(Lf+32)|0;Ne[c[gb>>2]&127](ph,Mf,Gf,Gf,8,16,hh,Ff,gh,fh);ag=vh+(Lf+48)|0;Ne[c[gb>>2]&127](ag,rf,Gf,Gf,8,16,hh,Ff,gh,fh);si=kh;ti=ph;ui=ag}}while(0);do{if((c[hb>>2]|0)==0){Ff=c[Aa>>2]|0;hh=c[Ba>>2]|0;rf=c[Ca>>2]|0;if((c[ib>>2]|0)==0){vi=kb;wi=jb}else{Mf=(c[xb>>2]|0)==3;vi=Mf?kb:zb;wi=Mf?jb:yb}Mf=vi;Nf=wi;Kf=c[lb>>2]|0;if((Kf&1|0)==0){xi=Mf;yi=Nf;zi=Kf}else{APa(J,Ff,hh,rf,0,ub,Nf,Mf);xi=wb;yi=vb;zi=c[lb>>2]|0}if((zi&2|0)!=0){APa(J,Ff,hh,rf,1,tb,yi,xi)}do{if((c[mb>>2]&262144|0)==0){Ai=Vf;Bi=Xf;Ci=Pf;Di=Gf}else{c[rb>>2]=0;Mf=Pe[c[sb>>2]&255](H,Ff,si,Pf,8)|0;Nf=Pf<<3;Kf=(Pe[c[sb>>2]&255](H,Ff+Nf|0,si+Nf|0,Pf,8)|0)+Mf|0;Mf=Kf+((c[(c[sa>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((Mf|0)<=0){Ai=Vf;Bi=Xf;Ci=Pf;Di=Gf;break}Kf=Pf<<1;Nf=Pe[c[sb>>2]&255](H,Ff,si,Kf,8)|0;if((Mf|0)<=((Pe[c[sb>>2]&255](H,Ff+Pf|0,si+Pf|0,Kf,8)|0)+Nf|0)){Ai=Vf;Bi=Xf;Ci=Pf;Di=Gf;break}c[rb>>2]=1;Ai=Pf;Bi=Gf;Ci=Kf;Di=Gf<<((c[Ja>>2]|0)==2)}}while(0);cf[c[nb>>2]&1023](c[ob>>2]|0,si,Ff,Ci);lf=si+8|0;Kf=Ff+8|0;cf[c[nb>>2]&1023]((c[ob>>2]|0)+128|0,lf,Kf,Ci);Nf=si+Ai|0;Mf=Ff+Ai|0;cf[c[nb>>2]&1023]((c[ob>>2]|0)+256|0,Nf,Mf,Ci);gg=Ai+8|0;ag=si+gg|0;ph=Ff+gg|0;cf[c[nb>>2]&1023]((c[ob>>2]|0)+384|0,ag,ph,Ci);do{if((c[mb>>2]&8192|0)==0){cf[c[nb>>2]&1023]((c[ob>>2]|0)+512|0,ti,hh,Di);cf[c[nb>>2]&1023]((c[ob>>2]|0)+640|0,ui,rf,Di);if((c[g>>2]|0)!=0){break}cf[c[nb>>2]&1023]((c[ob>>2]|0)+768|0,ti+Bi|0,hh+Bi|0,Di);cf[c[nb>>2]&1023]((c[ob>>2]|0)+896|0,ui+Bi|0,rf+Bi|0,Di)}else{c[Sa>>2]=1;c[Ta>>2]=1}}while(0);gg=(ba(c[oa>>2]|0,Yf)|0)+qf|0;kh=c[ma>>2]|0;if((e[(c[pb>>2]|0)+(gg<<1)>>1]|0)>=(ba(kh<<1,kh)|0)){Ei=Ai;Fi=Bi;Gi=Ci;Hi=Di;Ii=Wf;Ji=Wf;Ki=Wf;break}kh=Pe[c[qb>>2]&255](0,si,Ff,Ci,8)|0;if((kh|0)<((c[ma>>2]|0)*20|0|0)){c[Oa>>2]=1;Li=1}else{Li=Wf}kh=Pe[c[qb>>2]&255](0,lf,Kf,Ci,8)|0;if((kh|0)<((c[ma>>2]|0)*20|0|0)){c[Pa>>2]=1;Mi=1}else{Mi=Wf}kh=Pe[c[qb>>2]&255](0,Nf,Mf,Ci,8)|0;if((kh|0)<((c[ma>>2]|0)*20|0|0)){c[Qa>>2]=1;Ni=1}else{Ni=Wf}kh=Pe[c[qb>>2]&255](0,ag,ph,Ci,8)|0;if((kh|0)<((c[ma>>2]|0)*20|0|0)){c[Ra>>2]=1}kh=Pe[c[qb>>2]&255](0,ti,hh,Di,8)|0;if((kh|0)<((c[ma>>2]|0)*20|0|0)){c[Sa>>2]=1}kh=Pe[c[qb>>2]&255](0,ui,rf,Di,8)|0;if((kh|0)<((c[ma>>2]|0)*20|0|0)){c[Ta>>2]=1}if((c[g>>2]|0)!=0){Ei=Ai;Fi=Bi;Gi=Ci;Hi=Di;Ii=Li;Ji=Mi;Ki=Ni;break}kh=Pe[c[qb>>2]&255](0,ti+Bi|0,hh+Bi|0,Di,8)|0;if((kh|0)<((c[ma>>2]|0)*20|0|0)){c[Ua>>2]=1}kh=Pe[c[qb>>2]&255](0,ui+Bi|0,rf+Bi|0,Di,8)|0;if((kh|0)>=((c[ma>>2]|0)*20|0|0)){Ei=Ai;Fi=Bi;Gi=Ci;Hi=Di;Ii=Li;Ji=Mi;Ki=Ni;break}c[Va>>2]=1;Ei=Ai;Fi=Bi;Gi=Ci;Hi=Di;Ii=Li;Ji=Mi;Ki=Ni}else{do{if((c[mb>>2]&262144|0)==0){Oi=Vf;Pi=Xf;Qi=Pf;Ri=Gf}else{c[rb>>2]=0;kh=Pe[c[Cc>>2]&255](H,si,0,Pf,8)|0;gg=kh-400+(Pe[c[Cc>>2]&255](H,si+(Pf<<3)|0,0,Pf,8)|0)|0;if((gg|0)<=0){Oi=Vf;Pi=Xf;Qi=Pf;Ri=Gf;break}kh=Pf<<1;fh=Pe[c[Cc>>2]&255](H,si,0,kh,8)|0;if((gg|0)<=((Pe[c[Cc>>2]&255](H,si+Pf|0,0,kh,8)|0)+fh|0)){Oi=Vf;Pi=Xf;Qi=Pf;Ri=Gf;break}c[rb>>2]=1;Oi=Pf;Pi=Gf;Qi=kh;Ri=Gf<<(((c[Ja>>2]|0)-2|0)>>>0<2>>>0)}}while(0);Xe[c[Bc>>2]&4095](c[ob>>2]|0,si,Qi);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+128|0,si+8|0,Qi);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+256|0,si+Oi|0,Qi);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+384|0,si+(Oi+8)|0,Qi);if((c[mb>>2]&8192|0)!=0){c[Sa>>2]=1;c[Ta>>2]=1;Ei=Oi;Fi=Pi;Gi=Qi;Hi=Ri;Ii=Wf;Ji=Wf;Ki=Wf;break}Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+512|0,ti,Ri);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+640|0,ui,Ri);if((c[g>>2]|0)!=0){Ei=Oi;Fi=Pi;Gi=Qi;Hi=Ri;Ii=Wf;Ji=Wf;Ki=Wf;break}rf=c[Bc>>2]|0;hh=(c[ob>>2]|0)+768|0;if((c[eb>>2]|0)==0){Xe[rf&4095](hh,ti+8|0,Ri);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,ui+8|0,Ri);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1024|0,ti+Pi|0,Ri);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1152|0,ui+Pi|0,Ri);ph=Pi+8|0;Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1280|0,ti+ph|0,Ri);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1408|0,ui+ph|0,Ri);Ei=Oi;Fi=Pi;Gi=Qi;Hi=Ri;Ii=Wf;Ji=Wf;Ki=Wf;break}else{Xe[rf&4095](hh,ti+Pi|0,Ri);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,ui+Pi|0,Ri);Ei=Oi;Fi=Pi;Gi=Qi;Hi=Ri;Ii=Wf;Ji=Wf;Ki=Wf;break}}}while(0);if((c[Ab>>2]|0)==0){Si=0}else{if((Ii|0)==0){zPa(tc,si,Gi)}if((Ji|0)==0){zPa(uc,si+8|0,Gi);Ti=c[Qa>>2]|0}else{Ti=Ki}if((Ti|0)==0){zPa(vc,si+Ei|0,Gi)}if((c[Ra>>2]|0)==0){zPa(wc,si+(Ei+8)|0,Gi)}if((c[Sa>>2]|0)==0){zPa(xc,ti,Hi)}if((c[Ta>>2]|0)==0){zPa(yc,ui,Hi)}do{if((c[g>>2]|0)==0){if((c[Ua>>2]|0)==0){zPa(zc,ti+Fi|0,Hi)}if((c[Va>>2]|0)!=0){break}zPa(Ac,ui+Fi|0,Hi)}}while(0);UGb(Ka|0,c[ob>>2]|0,1024)|0;Si=0}do{do{if((c[r+(Si<<2)>>2]|0)==0){Wf=Pe[c[Bb>>2]&255](J,(c[ob>>2]|0)+(Si<<7)|0,Si,c[ma>>2]|0,l)|0;c[J+180+(Si<<2)>>2]=Wf;if((c[l>>2]|0)==0){break}Gf=c[ob>>2]|0;Pf=c[Cb>>2]|0;Xf=c[Db>>2]|0;Vf=(c[hb>>2]|0)!=0|0;if((Vf|0)>(Wf|0)){break}qf=Pf&65535;Yf=Xf&65535;hh=0;rf=Vf;while(1){Vf=Gf+(Si<<7)+(d[J+368+rf|0]<<1)|0;ph=b[Vf>>1]|0;ag=ph<<16>>16;if((ag|0)>(Pf|0)){Ui=qf;Vi=hh+1|0}else{Mf=(ag|0)<(Xf|0);Ui=Mf?Yf:ph;Vi=(Mf&1)+hh|0}b[Vf>>1]=Ui;Vf=rf+1|0;if((Vf|0)>(Wf|0)){break}else{hh=Vi;rf=Vf}}if((Vi|0)==0){break}rf=c[sa>>2]|0;if((c[rf+296>>2]|0)!=0){break}yDb(rf,32,2344760,(Jf=i,i=i+24|0,c[Jf>>2]=Vi,c[Jf+8>>2]=Xf,c[Jf+16>>2]=Pf,Jf)|0);i=Jf}else{c[J+180+(Si<<2)>>2]=-1}}while(0);Si=Si+1|0;}while((Si|0)<8);if((c[Ab>>2]|0)!=0){rf=0;do{if((c[r+(rf<<2)>>2]|0)==0){hh=c[ob>>2]|0;Wf=hh+(rf<<7)|0;Yf=p+(rf<<7)|0;qf=c[ma>>2]|0;Gf=c[gc>>2]|0;if((b[4432924]|0)==0){Vf=0;do{Mf=Vf<<3;Kg=(Vf|0)==0?11585.237502960395:16384.0;Ig=Kg*.7071067811865476;Jg=+(Vf|0)*.39269908169872414;ph=0;do{ag=ph+Mf+(J+11184)|0;Nf=(ph|0)==0;Lg=+(ph|0)*.39269908169872414;Kf=0;do{Mg=+T(Lg*(+(Kf|0)+.5));if(Nf){lf=0;do{Ff=d[ag]|0;b[8865848+(Ff<<7)+((lf<<3)+Kf<<1)>>1]=Gc(+(Mg*Ig*+T(Jg*(+(lf|0)+.5))))|0;lf=lf+1|0;}while((lf|0)<8)}else{lf=0;do{Ff=d[ag]|0;b[8865848+(Ff<<7)+((lf<<3)+Kf<<1)>>1]=Gc(+(Mg*Kg*+T(Jg*(+(lf|0)+.5))))|0;lf=lf+1|0;}while((lf|0)<8)}Kf=Kf+1|0;}while((Kf|0)<8);ph=ph+1|0;}while((ph|0)<8);Vf=Vf+1|0;}while((Vf|0)<8)}Vf=qf<<1;ph=qf-1|1;if((c[hb>>2]|0)==0){Wi=ph;Xi=0;Yi=32;Zi=hc;_i=ic;$i=1}else{do{if((c[pc>>2]|0)==0){if((rf|0)<4){aj=ph;bj=c[qc>>2]|0;break}else{aj=ph;bj=c[Jb>>2]|0;break}}else{aj=0;bj=1}}while(0);ph=bj<<3;Wi=aj;Xi=1;Yi=(ba(b[Wf>>1]|0,ph)|0)+32|0;Zi=rc;_i=sc;$i=ph}ph=c[Zi>>2]|0;qf=c[_i>>2]|0;Mf=J+180+(rf<<2)|0;Pf=c[Mf>>2]|0;Xf=0;while(1){b[m+(Xf<<1)>>1]=Yi-(b[q+(rf<<7)+(Xf<<1)>>1]<<6);Kf=Xf+1|0;if((Kf|0)<64){Xf=Kf}else{cj=0;dj=0;break}}do{Xf=p+(rf<<7)+(dj<<1)|0;Kf=b[Xf>>1]|0;ag=Kf<<16>>16;Nf=(Kf<<16>>16>-1?ag:-ag|0)+144|0;ag=((((Nf|0)/2|0)+6912|0)/(Nf|0)|0)+15|0;b[Xf>>1]=ag;cj=(ba(ag,ag)|0)+cj|0;dj=dj+1|0;}while((dj|0)<64);ag=gHb(c[jc>>2]|0,0,cj,(cj|0)<0|0?-1:0)|0;Xf=ag>>>19|F<<13;ag=-Wi|0;if((Xi|0)<=(Pf|0)){Nf=0;Kf=0;lf=Xi;while(1){Ff=d[J+368+lf|0]|0;kh=b[hh+(rf<<7)+(Ff<<1)>>1]|0;if(kh<<16>>16==0){ej=Kf;fj=Nf+1|0}else{fh=ba(kh<<16>>16,Vf)|0;c[o+(Kf<<2)>>2]=Nf;Xe[c[lc>>2]&4095](kc,8865848+(Ff<<7)|0,fh+(kh<<16>>16<0?ag:Wi)|0);ej=Kf+1|0;fj=0}kh=lf+1|0;if((kh|0)>(Pf|0)){break}else{Nf=fj;Kf=ej;lf=kh}}}lf=(Xi|0)==0;Kf=-$i|0;Nf=Pf;while(1){kh=_e[c[mc>>2]&1023](kc,Yf,8865848,0)|0;if((Nf|0)>2){gj=0;of=526}else{if((c[Ab>>2]|0)>2){gj=0;of=526}else{hj=0}}if((of|0)==526){while(1){of=0;fh=b[p+(rf<<7)+(gj<<1)>>1]|0;b[n+(gj<<1)>>1]=(ba(ba(fh,fh)|0,b[m+(gj<<1)>>1]|0)|0)+131072>>18;fh=gj+1|0;if((fh|0)<64){gj=fh;of=526}else{break}}me[c[oc>>2]&511](fc);hj=1}do{if(lf){ij=kh;jj=0;kj=0}else{fh=b[Wf>>1]|0;if((ba(fh-1|0,$i)|0)>>>0>2047>>>0){lj=kh;mj=0;nj=0}else{Ff=_e[c[mc>>2]&1023](kc,Yf,8865848,Kf)|0;gg=(Ff|0)<(kh|0);lj=gg?Ff:kh;mj=gg<<31>>31;nj=gg?Kf:0}if((ba(fh+1|0,$i)|0)>>>0>2047>>>0){ij=lj;jj=mj;kj=nj;break}fh=_e[c[mc>>2]&1023](kc,Yf,8865848,$i)|0;gg=(fh|0)<(lj|0);ij=gg?fh:lj;jj=gg?1:mj;kj=gg?$i:nj}}while(0);kh=Nf+1|0;gg=c[nc>>2]|0;fh=kj;Ff=jj;gh=0;Lf=ij;vh=0;cg=1;dg=Xi;fg=0;Of=0;while(1){bg=d[J+368+dg|0]|0;Qf=b[hh+(rf<<7)+(bg<<1)>>1]|0;eg=Qf<<16>>16;Oh=c[Ab>>2]|0;if((Oh|0)<3&(dg|0)>(kh|0)){oj=fh;pj=Ff;qj=gh;break}Nh=Qf<<16>>16!=0;if(Nh){Mh=ba(eg,Vf)|0;rj=Mh+(Qf<<16>>16<0?ag:Wi)|0;sj=cg+1|0;tj=c[o+(cg<<2)>>2]|0}else{rj=0;sj=cg;tj=gg-1|0}Mh=Qf<<16>>16>-1?eg:-eg|0;Lh=(dg|0)<(Nf|0);Kh=dg+1|0;Jh=tj+Kh|0;Eh=J+368+Jh|0;wh=(Jh|0)<(Nf|0);Jh=(tj+vh<<7)+128|0;yh=tj<<7;zh=vh<<7;Ch=zh|65;xh=ph+Ch|0;Fh=qf+Ch|0;Ch=(fg|0)==0;Gh=(Of<<7)+fg|0;Bh=qf+Gh|0;Dh=ph+Gh|0;Gh=8865848+(bg<<7)|0;bg=(Qf+62&65535)>>>0<125>>>0;Qf=zh|64;zh=eg+Qf|0;uh=ph+zh|0;Ah=qf+zh|0;zh=Gf+dg|0;Ih=fh;Hh=Ff;jh=gh;ih=Lf;qh=-1;lh=Oh;while(1){Oh=qh+eg|0;if((lh|0)<2){if((((Oh|0)>-1?Oh:-Oh|0)|0)>(Mh|0)){uj=ih;vj=jh;wj=Hh;xj=Ih}else{of=540}}else{of=540}l:do{if((of|0)==540){of=0;do{if((Oh|0)==0){if(!Lh){Wh=d[Fh]|0;if(Ch){yj=0;zj=-Wh|0;break}yj=0;zj=(d[Bh]|0)-Wh-(d[Dh]|0)|0;break}Wh=(b[hh+(rf<<7)+(d[Eh]<<1)>>1]|0)+64|0;Xh=Wh>>>0>127>>>0?0:Wh;Wh=Xh+Jh|0;if(wh){yj=0;zj=(d[ph+Wh|0]|0)-(d[ph+(Xh+yh)|0]|0)-(d[xh]|0)|0;break}else{yj=0;zj=(d[qf+Wh|0]|0)-(d[qf+(Xh+yh)|0]|0)-(d[xh]|0)|0;break}}else{Xh=ba(Oh,Vf)|0;Wh=((Oh|0)<0?ag:Wi)+Xh|0;if((Wh+2047|0)>>>0>4094>>>0){uj=ih;vj=jh;wj=Hh;xj=Ih;break l}if(Nh){if(!bg){yj=Wh;zj=0;break}Xh=Oh+Qf|0;if(Lh){yj=Wh;zj=(d[ph+Xh|0]|0)-(d[uh]|0)|0;break}else{yj=Wh;zj=(d[qf+Xh|0]|0)-(d[Ah]|0)|0;break}}do{if(hj){Xh=b[n+(d[zh]<<1)>>1]|0;if(Xh<<16>>16==0){break}if((Xh<<16>>16^Oh|0)>-1){uj=ih;vj=jh;wj=Hh;xj=Ih;break l}}}while(0);if(!Lh){Th=d[Fh]|0;if(Ch){yj=Wh;zj=Th;break}yj=Wh;zj=(d[Dh]|0)+Th-(d[Bh]|0)|0;break}Th=(b[hh+(rf<<7)+(d[Eh]<<1)>>1]|0)+64|0;Xh=Th>>>0>127>>>0?0:Th;Th=d[xh]|0;Yh=Xh+yh|0;if(wh){yj=Wh;zj=(d[ph+Yh|0]|0)+Th-(d[ph+(Xh+Jh)|0]|0)|0;break}else{yj=Wh;zj=(d[qf+Yh|0]|0)+Th-(d[qf+(Xh+Jh)|0]|0)|0;break}}}while(0);Xh=ba(zj,Xf)|0;Th=yj-rj|0;Yh=(_e[c[mc>>2]&1023](kc,Yf,Gh,Th)|0)+Xh|0;Xh=(Yh|0)<(ih|0);uj=Xh?Yh:ih;vj=Xh?dg:jh;wj=Xh?qh:Hh;xj=Xh?Th:Ih}}while(0);if((qh|0)>=0){break}Ih=xj;Hh=wj;jh=vj;ih=uj;qh=qh+2|0;lh=c[Ab>>2]|0}if(Nh){lh=eg+64|0;Aj=vh;Bj=lh>>>0>127>>>0?0:lh;Cj=0}else{Aj=Of;Bj=fg;Cj=vh+1|0}if((Kh|0)<64){gg=tj;fh=xj;Ff=wj;gh=vj;Lf=uj;vh=Cj;cg=sj;dg=Kh;fg=Bj;Of=Aj}else{oj=xj;pj=wj;qj=vj;break}}if((pj|0)==0){break}Of=d[J+368+qj|0]|0;fg=hh+(rf<<7)+(Of<<1)|0;b[fg>>1]=(e[fg>>1]|0)+pj;m:do{if((qj|0)>(Nf|0)){Dj=qj}else{fg=Nf;while(1){if((fg|0)<(Xi|0)){Dj=fg;break m}if((b[hh+(rf<<7)+(d[J+368+fg|0]<<1)>>1]|0)==0){fg=fg-1|0}else{Dj=fg;break}}}}while(0);if((Xi|0)<=(Dj|0)){fg=0;Kh=0;eg=Xi;while(1){if((b[hh+(rf<<7)+(d[J+368+eg|0]<<1)>>1]|0)==0){Ej=Kh;Fj=fg+1|0}else{c[o+(Kh<<2)>>2]=fg;Ej=Kh+1|0;Fj=0}Nh=eg+1|0;if((Nh|0)>(Dj|0)){break}else{fg=Fj;Kh=Ej;eg=Nh}}}Xe[c[lc>>2]&4095](kc,8865848+(Of<<7)|0,oj);Nf=Dj}c[Mf>>2]=Nf}rf=rf+1|0;}while((rf|0)<8)}rf=c[Eb>>2]|0;n:do{if((rf|0)!=0){if((c[hb>>2]|0)==0){Gj=0;Hj=rf}else{break}while(1){hh=c[ob>>2]|0;Yf=hh+(Gj<<7)|0;Xf=J+180+(Gj<<2)|0;qf=c[Xf>>2]|0;ph=Hj>>>31;ag=ph^1;Vf=(Hj|0)<0?-Hj|0:Hj;o:do{if((qf|0)>(ph<<31>>31|0)){if((qf|0)<0){Ij=0}else{Gf=(ph|0)!=1;Kf=0;Wf=0;lf=0;while(1){Pf=b[hh+(Gj<<7)+(d[J+368+Kf|0]<<1)>>1]|0;eg=Pf<<16>>16;Kh=Pf<<16>>16>-1?eg:-eg|0;do{if((Kh|0)==1){if(Gf&(Kf|0)==0){Jj=lf;Kj=Wf;break}Jj=(a[1405072+Wf|0]|0)+lf|0;Kj=0}else{if((Kh|0)>1){break o}Jj=lf;Kj=Wf+1|0}}while(0);Kh=Kf+1|0;if((Kh|0)>(qf|0)){Ij=Jj;break}else{Kf=Kh;Wf=Kj;lf=Jj}}}if((Ij|0)>=(Vf|0)){break}if((ag|0)<=(qf|0)){lf=ag;do{b[hh+(Gj<<7)+(d[J+368+lf|0]<<1)>>1]=0;lf=lf+1|0;}while((lf|0)<=(qf|0))}if((b[Yf>>1]|0)==0){c[Xf>>2]=-1;break}else{c[Xf>>2]=0;break}}}while(0);Xf=Gj+1|0;if((Xf|0)>=4){break n}Gj=Xf;Hj=c[Eb>>2]|0}}}while(0);rf=c[Fb>>2]|0;p:do{if((rf|0)!=0){if((c[hb>>2]|0)==0){Lj=4;Mj=rf}else{break}while(1){Nf=c[ob>>2]|0;Mf=Nf+(Lj<<7)|0;Xf=J+180+(Lj<<2)|0;Yf=c[Xf>>2]|0;qf=Mj>>>31;hh=qf^1;ag=(Mj|0)<0?-Mj|0:Mj;q:do{if((Yf|0)>(qf<<31>>31|0)){if((Yf|0)<0){Nj=0}else{Vf=(qf|0)!=1;ph=0;Of=0;lf=0;while(1){Wf=b[Nf+(Lj<<7)+(d[J+368+ph|0]<<1)>>1]|0;Kf=Wf<<16>>16;Gf=Wf<<16>>16>-1?Kf:-Kf|0;do{if((Gf|0)==1){if(Vf&(ph|0)==0){Oj=lf;Pj=Of;break}Oj=(a[1405072+Of|0]|0)+lf|0;Pj=0}else{if((Gf|0)>1){break q}Oj=lf;Pj=Of+1|0}}while(0);Gf=ph+1|0;if((Gf|0)>(Yf|0)){Nj=Oj;break}else{ph=Gf;Of=Pj;lf=Oj}}}if((Nj|0)>=(ag|0)){break}if((hh|0)<=(Yf|0)){lf=hh;do{b[Nf+(Lj<<7)+(d[J+368+lf|0]<<1)>>1]=0;lf=lf+1|0;}while((lf|0)<=(Yf|0))}if((b[Mf>>1]|0)==0){c[Xf>>2]=-1;break}else{c[Xf>>2]=0;break}}}while(0);Xf=Lj+1|0;if((Xf|0)>=8){break p}Lj=Xf;Mj=c[Fb>>2]|0}}}while(0);do{if((c[Ha>>2]&8|0)!=0){if((c[Rb>>2]|0)==-1){c[Sb>>2]=8388607}if((c[Tb>>2]|0)==-1){c[Ub>>2]=8388607}if((c[Vb>>2]|0)==-1){c[Wb>>2]=8388607}if((c[Xb>>2]|0)==-1){c[Yb>>2]=8388607}if((c[Ib>>2]|0)==-1){c[Zb>>2]=8388607}if((c[Hb>>2]|0)==-1){c[_b>>2]=8388607}if((c[Kb>>2]|0)==-1){c[$b>>2]=8388607}if(!((c[Lb>>2]|0)==-1)){break}c[ac>>2]=8388607}}while(0);do{if((c[mb>>2]&8192|0)!=0){if((c[hb>>2]|0)==0){break}c[Hb>>2]=0;c[Ib>>2]=0;rf=c[Jb>>2]|0;Xf=((((rf|0)/2|0)+1024|0)/(rf|0)|0)&65535;rf=c[ob>>2]|0;b[rf+640>>1]=Xf;b[rf+512>>1]=Xf;if((c[g>>2]|0)!=0){break}c[Kb>>2]=0;b[rf+768>>1]=Xf;c[Lb>>2]=0;b[rf+896>>1]=Xf;c[Mb>>2]=0;b[rf+1024>>1]=Xf;c[Nb>>2]=0;b[rf+1152>>1]=Xf;c[Ob>>2]=0;b[rf+1280>>1]=Xf;c[Pb>>2]=0;b[rf+1408>>1]=Xf}}while(0);do{if((c[Gb>>2]|0)!=0){if((c[Bb>>2]|0)==2){break}else{Qj=0}do{Xf=J+180+(Qj<<2)|0;if((c[Xf>>2]|0)>0){rf=63;while(1){if((rf|0)<=0){break}if((b[(c[ob>>2]|0)+(Qj<<7)+(d[J+368+rf|0]<<1)>>1]|0)==0){rf=rf-1|0}else{break}}c[Xf>>2]=rf}Qj=Qj+1|0;}while((Qj|0)<8)}}while(0);switch(c[_>>2]|0){case 1:case 2:{LMa(J,c[ob>>2]|0,If,Hf);break e;break};case 13:{pNa(J,c[ob>>2]|0,If,Hf);break e;break};case 16:case 17:case 18:{eQa(J,c[ob>>2]|0,If,Hf);break e;break};case 19:{edb(J,c[ob>>2]|0,If,Hf);break e;break};case 4:{vca(J,c[ob>>2]|0,If,Hf);break e;break};case 5:case 20:case 22:case 6:case 7:{Llb(J,c[ob>>2]|0,If,Hf);break e;break};case 8:case 108:{OLa(J,c[ob>>2]|0);break e;break};default:{break e}}}else{Mf=c[ka>>2]|0;Yf=c[la>>2]|0;Nf=c[La>>2]|0;hh=c[Ma>>2]|0;ag=c[Na>>2]|0;c[Oa>>2]=ag;c[Pa>>2]=ag;c[Qa>>2]=ag;c[Ra>>2]=ag;c[Sa>>2]=ag;c[Ta>>2]=ag;c[Ua>>2]=ag;c[Va>>2]=ag;c[Wa>>2]=ag;c[Xa>>2]=ag;c[Ya>>2]=ag;c[Za>>2]=ag;qf=Nf<<3;Nf=hh<<3;do{if((c[_a>>2]|0)==0){if((c[Ha>>2]&4|0)==0){break}cPa(J,(c[Fa>>2]|0)+(c[ma>>2]|0)|0)}else{hh=c[ma>>2]|0;lf=(ba(c[oa>>2]|0,Yf)|0)+Mf|0;Of=c[(c[Dc>>2]|0)+(lf<<2)>>2]|0;c[Ec>>2]=Of;ph=((Of*139|0)+8192|0)>>>14;c[ma>>2]=ph;Vf=c[sa>>2]|0;Gf=c[Vf+500>>2]|0;Kf=c[Vf+504>>2]|0;if((ph|0)<(Gf|0)){Rj=Gf}else{Rj=(ph|0)>(Kf|0)?Kf:ph}c[ma>>2]=Rj;c[jc>>2]=((ba(Of,Of)|0)+64|0)>>>7;do{if((c[Ha>>2]&4|0)==0){Of=a[(c[(c[Fc>>2]|0)+1512>>2]|0)+lf|0]|0;c[ma>>2]=Of;ph=Of-hh|0;c[Fa>>2]=ph;if((c[Hc>>2]|0)!=2){Sj=ph;break}if((ph|0)<-2){Tj=-2}else{Tj=(ph|0)>2?2:ph}c[Fa>>2]=Tj;if((c[_>>2]|0)!=13){Sj=Tj;break}if((c[hb>>2]|0)!=0){Sj=Tj;break}do{if((c[xb>>2]|0)==3){if((Tj&1|0)==0){if((c[lb>>2]&4|0)==0){Uj=Tj;break}}c[Fa>>2]=0;Uj=0}else{Uj=Tj}}while(0);if((c[Ia>>2]|0)!=1){Sj=Uj;break}c[Fa>>2]=0;Sj=0}else{Sj=c[Fa>>2]|0}}while(0);cPa(J,Sj+hh|0)}}while(0);lf=c[La>>2]|0;rf=c[Ma>>2]|0;Xf=Yf<<4;ph=Mf<<4;Of=(c[$a>>2]|0)+((ba(lf,Xf)|0)+ph)|0;Kf=(ba(rf,Xf)|0)+ph|0;Gf=(c[ab>>2]|0)+Kf|0;Vf=(c[bb>>2]|0)+Kf|0;Kf=c[cb>>2]|0;if((ph+16|0)>(Kf|0)){of=664}else{if((Xf+16|0)>(c[fb>>2]|0)){of=664}else{Vj=Of;Wj=Gf;Xj=Vf}}do{if((of|0)==664){of=0;if((c[_>>2]|0)==108){Vj=Of;Wj=Gf;Xj=Vf;break}Wf=c[db>>2]|0;Kh=Wf+32|0;eg=c[eb>>2]|0;Pf=eg+Kf>>eg;eg=c[fb>>2]|0;fg=c[g>>2]|0;Nh=fg+eg>>fg;Ne[c[gb>>2]&127](Kh,Of,lf,lf,16,16,ph,Xf,Kf,eg);eg=lf*18|0;fg=Wf+(eg+32)|0;Ne[c[gb>>2]&127](fg,Gf,rf,rf,16,16,ph,Xf,Pf,Nh);dg=Wf+(eg+48)|0;Ne[c[gb>>2]&127](dg,Vf,rf,rf,16,16,ph,Xf,Pf,Nh);Vj=Kh;Wj=fg;Xj=dg}}while(0);do{if((c[hb>>2]|0)==0){Xf=c[Aa>>2]|0;ph=c[Ba>>2]|0;Vf=c[Ca>>2]|0;if((c[ib>>2]|0)==0){Yj=kb;Zj=jb}else{Gf=(c[xb>>2]|0)==3;Yj=Gf?kb:zb;Zj=Gf?jb:yb}Gf=Yj;Kf=Zj;Of=c[lb>>2]|0;if((Of&1|0)==0){_j=Gf;$j=Kf;ak=Of}else{APa(J,Xf,ph,Vf,0,ub,Kf,Gf);_j=wb;$j=vb;ak=c[lb>>2]|0}if((ak&2|0)!=0){APa(J,Xf,ph,Vf,1,tb,$j,_j)}do{if((c[mb>>2]&262144|0)==0){bk=qf;ck=Nf;dk=lf;ek=rf}else{c[rb>>2]=0;Gf=Pe[c[sb>>2]&255](H,Xf,Vj,lf,8)|0;Kf=lf<<3;Of=(Pe[c[sb>>2]&255](H,Xf+Kf|0,Vj+Kf|0,lf,8)|0)+Gf|0;Gf=Of+((c[(c[sa>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((Gf|0)<=0){bk=qf;ck=Nf;dk=lf;ek=rf;break}Of=lf<<1;Kf=Pe[c[sb>>2]&255](H,Xf,Vj,Of,8)|0;if((Gf|0)<=((Pe[c[sb>>2]&255](H,Xf+lf|0,Vj+lf|0,Of,8)|0)+Kf|0)){bk=qf;ck=Nf;dk=lf;ek=rf;break}c[rb>>2]=1;bk=lf;ck=rf;dk=Of;ek=rf<<((c[Ja>>2]|0)==2)}}while(0);cf[c[nb>>2]&1023](c[ob>>2]|0,Vj,Xf,dk);hh=Vj+8|0;Of=Xf+8|0;cf[c[nb>>2]&1023]((c[ob>>2]|0)+128|0,hh,Of,dk);Kf=Vj+bk|0;Gf=Xf+bk|0;cf[c[nb>>2]&1023]((c[ob>>2]|0)+256|0,Kf,Gf,dk);dg=bk+8|0;fg=Vj+dg|0;Kh=Xf+dg|0;cf[c[nb>>2]&1023]((c[ob>>2]|0)+384|0,fg,Kh,dk);do{if((c[mb>>2]&8192|0)==0){cf[c[nb>>2]&1023]((c[ob>>2]|0)+512|0,Wj,ph,ek);cf[c[nb>>2]&1023]((c[ob>>2]|0)+640|0,Xj,Vf,ek);if((c[g>>2]|0)!=0){break}cf[c[nb>>2]&1023]((c[ob>>2]|0)+768|0,Wj+ck|0,ph+ck|0,ek);cf[c[nb>>2]&1023]((c[ob>>2]|0)+896|0,Xj+ck|0,Vf+ck|0,ek)}else{c[Sa>>2]=1;c[Ta>>2]=1}}while(0);dg=(ba(c[oa>>2]|0,Yf)|0)+Mf|0;Nh=c[ma>>2]|0;if((e[(c[pb>>2]|0)+(dg<<1)>>1]|0)>=(ba(Nh<<1,Nh)|0)){fk=bk;gk=ck;hk=dk;ik=ek;jk=ag;kk=ag;lk=ag;break}Nh=Pe[c[qb>>2]&255](0,Vj,Xf,dk,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Oa>>2]=1;mk=1}else{mk=ag}Nh=Pe[c[qb>>2]&255](0,hh,Of,dk,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Pa>>2]=1;nk=1}else{nk=ag}Nh=Pe[c[qb>>2]&255](0,Kf,Gf,dk,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Qa>>2]=1;ok=1}else{ok=ag}Nh=Pe[c[qb>>2]&255](0,fg,Kh,dk,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Ra>>2]=1}Nh=Pe[c[qb>>2]&255](0,Wj,ph,ek,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Sa>>2]=1}Nh=Pe[c[qb>>2]&255](0,Xj,Vf,ek,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Ta>>2]=1}if((c[g>>2]|0)!=0){fk=bk;gk=ck;hk=dk;ik=ek;jk=mk;kk=nk;lk=ok;break}Nh=Pe[c[qb>>2]&255](0,Wj+ck|0,ph+ck|0,ek,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Ua>>2]=1}Nh=Pe[c[qb>>2]&255](0,Xj+ck|0,Vf+ck|0,ek,8)|0;if((Nh|0)>=((c[ma>>2]|0)*20|0|0)){fk=bk;gk=ck;hk=dk;ik=ek;jk=mk;kk=nk;lk=ok;break}c[Va>>2]=1;fk=bk;gk=ck;hk=dk;ik=ek;jk=mk;kk=nk;lk=ok}else{do{if((c[mb>>2]&262144|0)==0){pk=qf;qk=Nf;rk=lf;sk=rf}else{c[rb>>2]=0;Nh=Pe[c[Cc>>2]&255](H,Vj,0,lf,8)|0;dg=Nh-400+(Pe[c[Cc>>2]&255](H,Vj+(lf<<3)|0,0,lf,8)|0)|0;if((dg|0)<=0){pk=qf;qk=Nf;rk=lf;sk=rf;break}Nh=lf<<1;Pf=Pe[c[Cc>>2]&255](H,Vj,0,Nh,8)|0;if((dg|0)<=((Pe[c[Cc>>2]&255](H,Vj+lf|0,0,Nh,8)|0)+Pf|0)){pk=qf;qk=Nf;rk=lf;sk=rf;break}c[rb>>2]=1;pk=lf;qk=rf;rk=Nh;sk=rf<<(((c[Ja>>2]|0)-2|0)>>>0<2>>>0)}}while(0);Xe[c[Bc>>2]&4095](c[ob>>2]|0,Vj,rk);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+128|0,Vj+8|0,rk);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+256|0,Vj+pk|0,rk);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+384|0,Vj+(pk+8)|0,rk);if((c[mb>>2]&8192|0)!=0){c[Sa>>2]=1;c[Ta>>2]=1;fk=pk;gk=qk;hk=rk;ik=sk;jk=ag;kk=ag;lk=ag;break}Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+512|0,Wj,sk);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+640|0,Xj,sk);if((c[g>>2]|0)!=0){fk=pk;gk=qk;hk=rk;ik=sk;jk=ag;kk=ag;lk=ag;break}Vf=c[Bc>>2]|0;ph=(c[ob>>2]|0)+768|0;if((c[eb>>2]|0)==0){Xe[Vf&4095](ph,Wj+8|0,sk);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,Xj+8|0,sk);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1024|0,Wj+qk|0,sk);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1152|0,Xj+qk|0,sk);Kh=qk+8|0;Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1280|0,Wj+Kh|0,sk);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+1408|0,Xj+Kh|0,sk);fk=pk;gk=qk;hk=rk;ik=sk;jk=ag;kk=ag;lk=ag;break}else{Xe[Vf&4095](ph,Wj+qk|0,sk);Xe[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,Xj+qk|0,sk);fk=pk;gk=qk;hk=rk;ik=sk;jk=ag;kk=ag;lk=ag;break}}}while(0);if((c[Ab>>2]|0)==0){tk=0}else{if((jk|0)==0){zPa(tc,Vj,hk)}if((kk|0)==0){zPa(uc,Vj+8|0,hk);uk=c[Qa>>2]|0}else{uk=lk}if((uk|0)==0){zPa(vc,Vj+fk|0,hk)}if((c[Ra>>2]|0)==0){zPa(wc,Vj+(fk+8)|0,hk)}if((c[Sa>>2]|0)==0){zPa(xc,Wj,ik)}if((c[Ta>>2]|0)==0){zPa(yc,Xj,ik)}do{if((c[g>>2]|0)==0){if((c[Ua>>2]|0)==0){zPa(zc,Wj+gk|0,ik)}if((c[Va>>2]|0)!=0){break}zPa(Ac,Xj+gk|0,ik)}}while(0);UGb(Ka|0,c[ob>>2]|0,1536)|0;tk=0}do{do{if((c[r+(tk<<2)>>2]|0)==0){ag=Pe[c[Bb>>2]&255](J,(c[ob>>2]|0)+(tk<<7)|0,tk,c[ma>>2]|0,k)|0;c[J+180+(tk<<2)>>2]=ag;if((c[k>>2]|0)==0){break}rf=c[ob>>2]|0;lf=c[Cb>>2]|0;Nf=c[Db>>2]|0;qf=(c[hb>>2]|0)!=0|0;if((qf|0)>(ag|0)){break}Mf=lf&65535;Yf=Nf&65535;ph=0;Vf=qf;while(1){qf=rf+(tk<<7)+(d[J+368+Vf|0]<<1)|0;Kh=b[qf>>1]|0;fg=Kh<<16>>16;if((fg|0)>(lf|0)){vk=Mf;wk=ph+1|0}else{Gf=(fg|0)<(Nf|0);vk=Gf?Yf:Kh;wk=(Gf&1)+ph|0}b[qf>>1]=vk;qf=Vf+1|0;if((qf|0)>(ag|0)){break}else{ph=wk;Vf=qf}}if((wk|0)==0){break}Vf=c[sa>>2]|0;if((c[Vf+296>>2]|0)!=0){break}yDb(Vf,32,2344760,(Jf=i,i=i+24|0,c[Jf>>2]=wk,c[Jf+8>>2]=Nf,c[Jf+16>>2]=lf,Jf)|0);i=Jf}else{c[J+180+(tk<<2)>>2]=-1}}while(0);tk=tk+1|0;}while((tk|0)<12);if((c[Ab>>2]|0)!=0){Vf=0;do{if((c[r+(Vf<<2)>>2]|0)==0){ph=c[ob>>2]|0;ag=ph+(Vf<<7)|0;Yf=p+(Vf<<7)|0;Mf=c[ma>>2]|0;rf=c[gc>>2]|0;if((b[4432924]|0)==0){qf=0;do{Gf=qf<<3;Jg=(qf|0)==0?11585.237502960395:16384.0;Kg=Jg*.7071067811865476;Ig=+(qf|0)*.39269908169872414;Kh=0;do{fg=Kh+Gf+(J+11184)|0;Kf=(Kh|0)==0;Lg=+(Kh|0)*.39269908169872414;Of=0;do{Mg=+T(Lg*(+(Of|0)+.5));if(Kf){hh=0;do{Xf=d[fg]|0;b[8865848+(Xf<<7)+((hh<<3)+Of<<1)>>1]=Gc(+(Mg*Kg*+T(Ig*(+(hh|0)+.5))))|0;hh=hh+1|0;}while((hh|0)<8)}else{hh=0;do{Xf=d[fg]|0;b[8865848+(Xf<<7)+((hh<<3)+Of<<1)>>1]=Gc(+(Mg*Jg*+T(Ig*(+(hh|0)+.5))))|0;hh=hh+1|0;}while((hh|0)<8)}Of=Of+1|0;}while((Of|0)<8);Kh=Kh+1|0;}while((Kh|0)<8);qf=qf+1|0;}while((qf|0)<8)}qf=Mf<<1;Kh=Mf-1|1;if((c[hb>>2]|0)==0){xk=Kh;yk=0;zk=32;Ak=hc;Bk=ic;Ck=1}else{do{if((c[pc>>2]|0)==0){if((Vf|0)<4){Dk=Kh;Ek=c[qc>>2]|0;break}else{Dk=Kh;Ek=c[Jb>>2]|0;break}}else{Dk=0;Ek=1}}while(0);Kh=Ek<<3;xk=Dk;yk=1;zk=(ba(b[ag>>1]|0,Kh)|0)+32|0;Ak=rc;Bk=sc;Ck=Kh}Kh=c[Ak>>2]|0;Mf=c[Bk>>2]|0;Gf=J+180+(Vf<<2)|0;lf=c[Gf>>2]|0;Nf=0;while(1){b[m+(Nf<<1)>>1]=zk-(b[q+(Vf<<7)+(Nf<<1)>>1]<<6);Of=Nf+1|0;if((Of|0)<64){Nf=Of}else{Fk=0;Gk=0;break}}do{Nf=p+(Vf<<7)+(Gk<<1)|0;Of=b[Nf>>1]|0;fg=Of<<16>>16;Kf=(Of<<16>>16>-1?fg:-fg|0)+144|0;fg=((((Kf|0)/2|0)+6912|0)/(Kf|0)|0)+15|0;b[Nf>>1]=fg;Fk=(ba(fg,fg)|0)+Fk|0;Gk=Gk+1|0;}while((Gk|0)<64);fg=gHb(c[jc>>2]|0,0,Fk,(Fk|0)<0|0?-1:0)|0;Nf=fg>>>19|F<<13;fg=-xk|0;if((yk|0)<=(lf|0)){Kf=0;Of=0;hh=yk;while(1){Xf=d[J+368+hh|0]|0;Nh=b[ph+(Vf<<7)+(Xf<<1)>>1]|0;if(Nh<<16>>16==0){Hk=Of;Ik=Kf+1|0}else{Pf=ba(Nh<<16>>16,qf)|0;c[o+(Of<<2)>>2]=Kf;Xe[c[lc>>2]&4095](kc,8865848+(Xf<<7)|0,Pf+(Nh<<16>>16<0?fg:xk)|0);Hk=Of+1|0;Ik=0}Nh=hh+1|0;if((Nh|0)>(lf|0)){break}else{Kf=Ik;Of=Hk;hh=Nh}}}hh=(yk|0)==0;Of=-Ck|0;Kf=lf;while(1){Nh=_e[c[mc>>2]&1023](kc,Yf,8865848,0)|0;if((Kf|0)>2){Jk=0;of=769}else{if((c[Ab>>2]|0)>2){Jk=0;of=769}else{Kk=0}}if((of|0)==769){while(1){of=0;Pf=b[p+(Vf<<7)+(Jk<<1)>>1]|0;b[n+(Jk<<1)>>1]=(ba(ba(Pf,Pf)|0,b[m+(Jk<<1)>>1]|0)|0)+131072>>18;Pf=Jk+1|0;if((Pf|0)<64){Jk=Pf;of=769}else{break}}me[c[oc>>2]&511](fc);Kk=1}do{if(hh){Lk=Nh;Mk=0;Nk=0}else{Pf=b[ag>>1]|0;if((ba(Pf-1|0,Ck)|0)>>>0>2047>>>0){Ok=Nh;Pk=0;Qk=0}else{Xf=_e[c[mc>>2]&1023](kc,Yf,8865848,Of)|0;dg=(Xf|0)<(Nh|0);Ok=dg?Xf:Nh;Pk=dg<<31>>31;Qk=dg?Of:0}if((ba(Pf+1|0,Ck)|0)>>>0>2047>>>0){Lk=Ok;Mk=Pk;Nk=Qk;break}Pf=_e[c[mc>>2]&1023](kc,Yf,8865848,Ck)|0;dg=(Pf|0)<(Ok|0);Lk=dg?Pf:Ok;Mk=dg?1:Pk;Nk=dg?Ck:Qk}}while(0);Nh=Kf+1|0;dg=c[nc>>2]|0;Pf=Nk;Xf=Mk;eg=0;Wf=Lk;cg=0;vh=1;Lf=yk;gh=0;Ff=0;while(1){fh=d[J+368+Lf|0]|0;gg=b[ph+(Vf<<7)+(fh<<1)>>1]|0;kh=gg<<16>>16;lh=c[Ab>>2]|0;if((lh|0)<3&(Lf|0)>(Nh|0)){Rk=Pf;Sk=Xf;Tk=eg;break}qh=gg<<16>>16!=0;if(qh){ih=ba(kh,qf)|0;Uk=ih+(gg<<16>>16<0?fg:xk)|0;Vk=vh+1|0;Wk=c[o+(vh<<2)>>2]|0}else{Uk=0;Vk=vh;Wk=dg-1|0}ih=gg<<16>>16>-1?kh:-kh|0;jh=(Lf|0)<(Kf|0);Hh=Lf+1|0;Ih=Wk+Hh|0;Gh=J+368+Ih|0;Jh=(Ih|0)<(Kf|0);Ih=(Wk+cg<<7)+128|0;wh=Wk<<7;yh=cg<<7;xh=yh|65;Eh=Kh+xh|0;Bh=Mf+xh|0;xh=(gh|0)==0;Dh=(Ff<<7)+gh|0;Ch=Mf+Dh|0;Fh=Kh+Dh|0;Dh=8865848+(fh<<7)|0;fh=(gg+62&65535)>>>0<125>>>0;gg=yh|64;yh=kh+gg|0;Lh=Kh+yh|0;zh=Mf+yh|0;yh=rf+Lf|0;Ah=Pf;uh=Xf;Qf=eg;bg=Wf;Mh=-1;Oh=lh;while(1){lh=Mh+kh|0;if((Oh|0)<2){if((((lh|0)>-1?lh:-lh|0)|0)>(ih|0)){Xk=bg;Yk=Qf;Zk=uh;_k=Ah}else{of=783}}else{of=783}r:do{if((of|0)==783){of=0;do{if((lh|0)==0){if(!jh){Th=d[Bh]|0;if(xh){$k=0;al=-Th|0;break}$k=0;al=(d[Ch]|0)-Th-(d[Fh]|0)|0;break}Th=(b[ph+(Vf<<7)+(d[Gh]<<1)>>1]|0)+64|0;Xh=Th>>>0>127>>>0?0:Th;Th=Xh+Ih|0;if(Jh){$k=0;al=(d[Kh+Th|0]|0)-(d[Kh+(Xh+wh)|0]|0)-(d[Eh]|0)|0;break}else{$k=0;al=(d[Mf+Th|0]|0)-(d[Mf+(Xh+wh)|0]|0)-(d[Eh]|0)|0;break}}else{Xh=ba(lh,qf)|0;Th=((lh|0)<0?fg:xk)+Xh|0;if((Th+2047|0)>>>0>4094>>>0){Xk=bg;Yk=Qf;Zk=uh;_k=Ah;break r}if(qh){if(!fh){$k=Th;al=0;break}Xh=lh+gg|0;if(jh){$k=Th;al=(d[Kh+Xh|0]|0)-(d[Lh]|0)|0;break}else{$k=Th;al=(d[Mf+Xh|0]|0)-(d[zh]|0)|0;break}}do{if(Kk){Xh=b[n+(d[yh]<<1)>>1]|0;if(Xh<<16>>16==0){break}if((Xh<<16>>16^lh|0)>-1){Xk=bg;Yk=Qf;Zk=uh;_k=Ah;break r}}}while(0);if(!jh){Wh=d[Bh]|0;if(xh){$k=Th;al=Wh;break}$k=Th;al=(d[Fh]|0)+Wh-(d[Ch]|0)|0;break}Wh=(b[ph+(Vf<<7)+(d[Gh]<<1)>>1]|0)+64|0;Xh=Wh>>>0>127>>>0?0:Wh;Wh=d[Eh]|0;Yh=Xh+wh|0;if(Jh){$k=Th;al=(d[Kh+Yh|0]|0)+Wh-(d[Kh+(Xh+Ih)|0]|0)|0;break}else{$k=Th;al=(d[Mf+Yh|0]|0)+Wh-(d[Mf+(Xh+Ih)|0]|0)|0;break}}}while(0);Xh=ba(al,Nf)|0;Wh=$k-Uk|0;Yh=(_e[c[mc>>2]&1023](kc,Yf,Dh,Wh)|0)+Xh|0;Xh=(Yh|0)<(bg|0);Xk=Xh?Yh:bg;Yk=Xh?Lf:Qf;Zk=Xh?Mh:uh;_k=Xh?Wh:Ah}}while(0);if((Mh|0)>=0){break}Ah=_k;uh=Zk;Qf=Yk;bg=Xk;Mh=Mh+2|0;Oh=c[Ab>>2]|0}if(qh){Oh=kh+64|0;bl=cg;cl=Oh>>>0>127>>>0?0:Oh;dl=0}else{bl=Ff;cl=gh;dl=cg+1|0}if((Hh|0)<64){dg=Wk;Pf=_k;Xf=Zk;eg=Yk;Wf=Xk;cg=dl;vh=Vk;Lf=Hh;gh=cl;Ff=bl}else{Rk=_k;Sk=Zk;Tk=Yk;break}}if((Sk|0)==0){break}Ff=d[J+368+Tk|0]|0;gh=ph+(Vf<<7)+(Ff<<1)|0;b[gh>>1]=(e[gh>>1]|0)+Sk;s:do{if((Tk|0)>(Kf|0)){el=Tk}else{gh=Kf;while(1){if((gh|0)<(yk|0)){el=gh;break s}if((b[ph+(Vf<<7)+(d[J+368+gh|0]<<1)>>1]|0)==0){gh=gh-1|0}else{el=gh;break}}}}while(0);if((yk|0)<=(el|0)){gh=0;Hh=0;kh=yk;while(1){if((b[ph+(Vf<<7)+(d[J+368+kh|0]<<1)>>1]|0)==0){fl=Hh;gl=gh+1|0}else{c[o+(Hh<<2)>>2]=gh;fl=Hh+1|0;gl=0}qh=kh+1|0;if((qh|0)>(el|0)){break}else{gh=gl;Hh=fl;kh=qh}}}Xe[c[lc>>2]&4095](kc,8865848+(Ff<<7)|0,Rk);Kf=el}c[Gf>>2]=Kf}Vf=Vf+1|0;}while((Vf|0)<12)}Vf=c[Eb>>2]|0;t:do{if((Vf|0)!=0){if((c[hb>>2]|0)==0){hl=0;il=Vf}else{break}while(1){ph=c[ob>>2]|0;Yf=ph+(hl<<7)|0;Nf=J+180+(hl<<2)|0;Mf=c[Nf>>2]|0;Kh=il>>>31;fg=Kh^1;qf=(il|0)<0?-il|0:il;u:do{if((Mf|0)>(Kh<<31>>31|0)){if((Mf|0)<0){jl=0}else{rf=(Kh|0)!=1;Of=0;ag=0;hh=0;while(1){lf=b[ph+(hl<<7)+(d[J+368+Of|0]<<1)>>1]|0;kh=lf<<16>>16;Hh=lf<<16>>16>-1?kh:-kh|0;do{if((Hh|0)==1){if(rf&(Of|0)==0){kl=hh;ll=ag;break}kl=(a[1405072+ag|0]|0)+hh|0;ll=0}else{if((Hh|0)>1){break u}kl=hh;ll=ag+1|0}}while(0);Hh=Of+1|0;if((Hh|0)>(Mf|0)){jl=kl;break}else{Of=Hh;ag=ll;hh=kl}}}if((jl|0)>=(qf|0)){break}if((fg|0)<=(Mf|0)){hh=fg;do{b[ph+(hl<<7)+(d[J+368+hh|0]<<1)>>1]=0;hh=hh+1|0;}while((hh|0)<=(Mf|0))}if((b[Yf>>1]|0)==0){c[Nf>>2]=-1;break}else{c[Nf>>2]=0;break}}}while(0);Nf=hl+1|0;if((Nf|0)>=4){break t}hl=Nf;il=c[Eb>>2]|0}}}while(0);Vf=c[Fb>>2]|0;v:do{if((Vf|0)!=0){if((c[hb>>2]|0)==0){ml=4;nl=Vf}else{break}while(1){Kf=c[ob>>2]|0;Gf=Kf+(ml<<7)|0;Nf=J+180+(ml<<2)|0;Yf=c[Nf>>2]|0;Mf=nl>>>31;ph=Mf^1;fg=(nl|0)<0?-nl|0:nl;w:do{if((Yf|0)>(Mf<<31>>31|0)){if((Yf|0)<0){ol=0}else{qf=(Mf|0)!=1;Kh=0;Ff=0;hh=0;while(1){ag=b[Kf+(ml<<7)+(d[J+368+Kh|0]<<1)>>1]|0;Of=ag<<16>>16;rf=ag<<16>>16>-1?Of:-Of|0;do{if((rf|0)==1){if(qf&(Kh|0)==0){pl=hh;ql=Ff;break}pl=(a[1405072+Ff|0]|0)+hh|0;ql=0}else{if((rf|0)>1){break w}pl=hh;ql=Ff+1|0}}while(0);rf=Kh+1|0;if((rf|0)>(Yf|0)){ol=pl;break}else{Kh=rf;Ff=ql;hh=pl}}}if((ol|0)>=(fg|0)){break}if((ph|0)<=(Yf|0)){hh=ph;do{b[Kf+(ml<<7)+(d[J+368+hh|0]<<1)>>1]=0;hh=hh+1|0;}while((hh|0)<=(Yf|0))}if((b[Gf>>1]|0)==0){c[Nf>>2]=-1;break}else{c[Nf>>2]=0;break}}}while(0);Nf=ml+1|0;if((Nf|0)>=12){break v}ml=Nf;nl=c[Fb>>2]|0}}}while(0);do{if((c[Ha>>2]&8|0)!=0){if((c[Rb>>2]|0)==-1){c[Sb>>2]=8388607}if((c[Tb>>2]|0)==-1){c[Ub>>2]=8388607}if((c[Vb>>2]|0)==-1){c[Wb>>2]=8388607}if((c[Xb>>2]|0)==-1){c[Yb>>2]=8388607}if((c[Ib>>2]|0)==-1){c[Zb>>2]=8388607}if((c[Hb>>2]|0)==-1){c[_b>>2]=8388607}if((c[Kb>>2]|0)==-1){c[$b>>2]=8388607}if((c[Lb>>2]|0)==-1){c[ac>>2]=8388607}if((c[Mb>>2]|0)==-1){c[bc>>2]=8388607}if((c[Nb>>2]|0)==-1){c[cc>>2]=8388607}if((c[Ob>>2]|0)==-1){c[dc>>2]=8388607}if(!((c[Pb>>2]|0)==-1)){break}c[ec>>2]=8388607}}while(0);do{if((c[mb>>2]&8192|0)!=0){if((c[hb>>2]|0)==0){break}c[Hb>>2]=0;c[Ib>>2]=0;Vf=c[Jb>>2]|0;Nf=((((Vf|0)/2|0)+1024|0)/(Vf|0)|0)&65535;Vf=c[ob>>2]|0;b[Vf+640>>1]=Nf;b[Vf+512>>1]=Nf;if((c[g>>2]|0)!=0){break}c[Kb>>2]=0;b[Vf+768>>1]=Nf;c[Lb>>2]=0;b[Vf+896>>1]=Nf;c[Mb>>2]=0;b[Vf+1024>>1]=Nf;c[Nb>>2]=0;b[Vf+1152>>1]=Nf;c[Ob>>2]=0;b[Vf+1280>>1]=Nf;c[Pb>>2]=0;b[Vf+1408>>1]=Nf}}while(0);do{if((c[Gb>>2]|0)!=0){if((c[Bb>>2]|0)==2){break}else{rl=0}do{Nf=J+180+(rl<<2)|0;if((c[Nf>>2]|0)>0){Vf=63;while(1){if((Vf|0)<=0){break}if((b[(c[ob>>2]|0)+(rl<<7)+(d[J+368+Vf|0]<<1)>>1]|0)==0){Vf=Vf-1|0}else{break}}c[Nf>>2]=Vf}rl=rl+1|0;}while((rl|0)<12)}}while(0);switch(c[_>>2]|0){case 1:case 2:{LMa(J,c[ob>>2]|0,If,Hf);break e;break};case 13:{pNa(J,c[ob>>2]|0,If,Hf);break e;break};case 16:case 17:case 18:{eQa(J,c[ob>>2]|0,If,Hf);break e;break};case 19:{edb(J,c[ob>>2]|0,If,Hf);break e;break};case 4:{vca(J,c[ob>>2]|0,If,Hf);break e;break};case 5:case 20:case 22:case 6:case 7:{Llb(J,c[ob>>2]|0,If,Hf);break e;break};case 8:case 108:{OLa(J,c[ob>>2]|0);break e;break};default:{break e}}}}while(0);c[ga>>2]=c[lb>>2];do{if((c[Hc>>2]|0)==2){if((c[xb>>2]|0)==3){break}xca(J)}}while(0);YOa(J,c[ob>>2]|0)}else{of=65}}while(0);do{if((of|0)==65){of=0;c[D>>2]=0;UGb(jd|0,fa|0,32)|0;c[kd>>2]=c[ea>>2];c[md>>2]=c[ld>>2];c[od>>2]=c[nd>>2];c[qd>>2]=c[pd>>2];c[rd>>2]=c[O>>2];c[sd>>2]=c[R>>2];c[td>>2]=c[S>>2];c[ud>>2]=c[U>>2];c[vd>>2]=c[V>>2];c[wd>>2]=c[W>>2];c[xd>>2]=c[X>>2];c[yd>>2]=c[P>>2];c[zd>>2]=0;c[Ad>>2]=0;c[Bd>>2]=c[ma>>2];c[Cd>>2]=c[Fa>>2];c[Ed>>2]=c[Dd>>2];c[Gd>>2]=c[Q>>2];c[Gd+4>>2]=c[Q+4>>2];c[Gd+8>>2]=c[Q+8>>2];c[Gd+12>>2]=c[Q+12>>2];c[Gd+16>>2]=c[Q+16>>2];c[Gd+20>>2]=c[Q+20>>2];c[Hd>>2]=c[ra>>2];c[Jd>>2]=c[Id>>2];if((c[ra>>2]|0)!=0){c[Ce>>2]=c[we>>2];c[Ce+4>>2]=c[we+4>>2];c[Ce+8>>2]=c[we+8>>2];c[Ce+12>>2]=c[we+12>>2];c[Ce+16>>2]=c[we+16>>2];c[Ce+20>>2]=c[we+20>>2];c[Je>>2]=c[De>>2];c[Je+4>>2]=c[De+4>>2];c[Je+8>>2]=c[De+8>>2];c[Je+12>>2]=c[De+12>>2];c[Je+16>>2]=c[De+16>>2];c[Je+20>>2]=c[De+20>>2]}if((mf&2|0)!=0){c[lb>>2]=1;c[Ia>>2]=0;c[hb>>2]=0;pf=c[Lc>>2]|0;nf=b[pf+(sf<<2)>>1]|0;c[Jc>>2]=nf;Gf=b[pf+(sf<<2)+2>>1]|0;c[Kc>>2]=Gf;yPa(J,u,t,Od,Pd,Qd,C,D,nf,Gf)}if((mf&256|0)!=0){c[lb>>2]=1;c[Ia>>2]=3;c[hb>>2]=0;Gf=d[(c[Mc>>2]|0)+sf|0]|0;c[Nc>>2]=Gf;nf=Oc+(Gf<<2)|0;c[Ic>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11712>>2]|0)+sf|0]|0;c[H+11812>>2]=nf;Gf=Oc+8+(nf<<2)|0;c[H+11752>>2]=b[(c[Gf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[Gf>>2]|0)+(sf<<2)+2>>1]|0;yPa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((mf&8|0)!=0){c[lb>>2]=1;c[Ia>>2]=0;c[hb>>2]=0;c[Jc>>2]=0;c[Kc>>2]=0;yPa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((mf&4|0)!=0){c[lb>>2]=1;c[Ia>>2]=1;c[hb>>2]=0;Gf=c[ta>>2]|0;nf=c[Pc>>2]|0;c[Ic>>2]=b[nf+(Gf<<2)>>1]|0;c[H+11748>>2]=b[nf+(Gf<<2)+2>>1]|0;Gf=c[H+12500>>2]|0;c[H+11752>>2]=b[nf+(Gf<<2)>>1]|0;c[H+11756>>2]=b[nf+(Gf<<2)+2>>1]|0;Gf=c[H+12504>>2]|0;c[H+11760>>2]=b[nf+(Gf<<2)>>1]|0;c[H+11764>>2]=b[nf+(Gf<<2)+2>>1]|0;Gf=c[H+12508>>2]|0;c[H+11768>>2]=b[nf+(Gf<<2)>>1]|0;c[H+11772>>2]=b[nf+(Gf<<2)+2>>1]|0;yPa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((mf&32|0)!=0){c[lb>>2]=1;c[Ia>>2]=0;c[hb>>2]=0;Gf=c[Xc>>2]|0;nf=b[Gf+(sf<<2)>>1]|0;c[Jc>>2]=nf;pf=b[Gf+(sf<<2)+2>>1]|0;c[Kc>>2]=pf;yPa(J,u,t,Od,Pd,Qd,C,D,nf,pf)}if((mf&64|0)!=0){c[lb>>2]=2;c[Ia>>2]=0;c[hb>>2]=0;pf=c[Wc>>2]|0;nf=b[pf+(sf<<2)>>1]|0;c[Uc>>2]=nf;Gf=b[pf+(sf<<2)+2>>1]|0;c[Vc>>2]=Gf;yPa(J,u,t,Od,Pd,Qd,C,D,nf,Gf)}if((mf&128|0)!=0){c[lb>>2]=3;c[Ia>>2]=0;c[hb>>2]=0;Gf=c[Rc>>2]|0;c[Jc>>2]=b[Gf+(sf<<2)>>1]|0;c[Kc>>2]=b[Gf+(sf<<2)+2>>1]|0;Gf=c[Sc>>2]|0;c[Uc>>2]=b[Gf+(sf<<2)>>1]|0;c[Vc>>2]=b[Gf+(sf<<2)+2>>1]|0;yPa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((mf&512|0)!=0){c[lb>>2]=1;c[Ia>>2]=3;c[hb>>2]=0;Gf=d[(c[Yc>>2]|0)+sf|0]|0;c[Nc>>2]=Gf;nf=_c+(Gf<<2)|0;c[Ic>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11720>>2]|0)+sf|0]|0;c[H+11812>>2]=nf;Gf=_c+8+(nf<<2)|0;c[H+11752>>2]=b[(c[Gf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[Gf>>2]|0)+(sf<<2)+2>>1]|0;yPa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((mf&1024|0)!=0){c[lb>>2]=2;c[Ia>>2]=3;c[hb>>2]=0;Gf=d[(c[$c>>2]|0)+sf|0]|0;c[ad>>2]=Gf;nf=bd+(Gf<<2)|0;c[Tc>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11780>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11728>>2]|0)+sf|0]|0;c[H+11820>>2]=nf;Gf=bd+8+(nf<<2)|0;c[H+11784>>2]=b[(c[Gf>>2]|0)+(sf<<2)>>1]|0;c[H+11788>>2]=b[(c[Gf>>2]|0)+(sf<<2)+2>>1]|0;yPa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((mf&2048|0)!=0){c[lb>>2]=3;c[Ia>>2]=3;c[hb>>2]=0;Gf=d[(c[Yc>>2]|0)+sf|0]|0;c[Nc>>2]=Gf;nf=cd+(Gf<<2)|0;c[Ic>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11720>>2]|0)+sf|0]|0;c[H+11812>>2]=nf;Gf=cd+8+(nf<<2)|0;c[H+11752>>2]=b[(c[Gf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[Gf>>2]|0)+(sf<<2)+2>>1]|0;Gf=d[(c[H+11724>>2]|0)+sf|0]|0;c[H+11816>>2]=Gf;nf=cd+16+(Gf<<2)|0;c[H+11776>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11780>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11728>>2]|0)+sf|0]|0;c[H+11820>>2]=nf;Gf=cd+24+(nf<<2)|0;c[H+11784>>2]=b[(c[Gf>>2]|0)+(sf<<2)>>1]|0;c[H+11788>>2]=b[(c[Gf>>2]|0)+(sf<<2)+2>>1]|0;yPa(J,u,t,Od,Pd,Qd,C,D,0,0)}do{if((mf&1|0)!=0){c[lb>>2]=0;c[Ia>>2]=0;c[hb>>2]=1;c[Jc>>2]=0;c[Kc>>2]=0;yPa(J,u,t,Od,Pd,Qd,C,D,0,0);if((c[Ue>>2]|0)==0){if((c[pc>>2]|0)==0){break}}if((c[Kd>>2]|0)==0){XOa(J);break}else{Gf=(ba(c[oa>>2]|0,hf)|0)+kf|0;a[(c[Ve>>2]|0)+Gf|0]=1;break}}}while(0);do{if((c[Ha>>2]&4|0)!=0){if((c[C>>2]|0)==2147483647){break}if((c[Nd>>2]|0)!=0){break}Gf=c[Bd>>2]|0;nf=c[Md>>2]|0;pf=nf>>>1&1;if((c[hb>>2]|0)==0){sl=0}else{sl=(c[Se>>2]|0)!=0}c[lb>>2]=nf;c[Ia>>2]=0;c[hb>>2]=c[Kd>>2];c[Jc>>2]=c[Me>>2];c[Kc>>2]=c[Oe>>2];c[Uc>>2]=c[Qe>>2];c[Vc>>2]=c[Re>>2];nf=Zc+(pf<<5)|0;Yf=Zc+(pf<<5)+4|0;pf=sl^1;Kf=(c[xb>>2]|0)==3?2:0;do{ph=c[1342880+(Kf<<2)>>2]|0;fg=ph+Gf|0;Mf=c[sa>>2]|0;do{if((fg|0)>=(c[Mf+500>>2]|0)){if((fg|0)>(c[Mf+504>>2]|0)){break}c[Cd>>2]=ph;if(sl){hh=c[ta>>2]|0;Ff=c[Se>>2]|0;c[E>>2]=b[Ff+(hh<<1)>>1]|0;Kh=c[Te>>2]|0;UGb(G|0,Kh+(hh<<5)|0,32)|0;hh=c[H+12500>>2]|0;c[E+4>>2]=b[Ff+(hh<<1)>>1]|0;UGb(G+32|0,Kh+(hh<<5)|0,32)|0;hh=c[H+12504>>2]|0;c[E+8>>2]=b[Ff+(hh<<1)>>1]|0;UGb(G+64|0,Kh+(hh<<5)|0,32)|0;hh=c[H+12508>>2]|0;c[E+12>>2]=b[Ff+(hh<<1)>>1]|0;UGb(G+96|0,Kh+(hh<<5)|0,32)|0;hh=c[H+12512>>2]|0;c[E+16>>2]=b[Ff+(hh<<1)>>1]|0;UGb(G+128|0,Kh+(hh<<5)|0,32)|0;hh=c[H+12516>>2]|0;c[E+20>>2]=b[Ff+(hh<<1)>>1]|0;UGb(G+160|0,Kh+(hh<<5)|0,32)|0}yPa(J,u,t,Od,Pd,Qd,C,D,c[nf>>2]|0,c[Yf>>2]|0);if((c[Rd>>2]|0)==(fg|0)|pf){break}hh=c[ta>>2]|0;b[(c[Se>>2]|0)+(hh<<1)>>1]=c[E>>2];UGb((c[Te>>2]|0)+(hh<<5)|0,G|0,32)|0;hh=c[H+12500>>2]|0;b[(c[Se>>2]|0)+(hh<<1)>>1]=c[E+4>>2];UGb((c[Te>>2]|0)+(hh<<5)|0,G+32|0,32)|0;hh=c[H+12504>>2]|0;b[(c[Se>>2]|0)+(hh<<1)>>1]=c[E+8>>2];UGb((c[Te>>2]|0)+(hh<<5)|0,G+64|0,32)|0;hh=c[H+12508>>2]|0;b[(c[Se>>2]|0)+(hh<<1)>>1]=c[E+12>>2];UGb((c[Te>>2]|0)+(hh<<5)|0,G+96|0,32)|0;hh=c[H+12512>>2]|0;b[(c[Se>>2]|0)+(hh<<1)>>1]=c[E+16>>2];UGb((c[Te>>2]|0)+(hh<<5)|0,G+128|0,32)|0;hh=c[H+12516>>2]|0;b[(c[Se>>2]|0)+(hh<<1)>>1]=c[E+20>>2];UGb((c[Te>>2]|0)+(hh<<5)|0,G+160|0,32)|0}}while(0);Kf=Kf+1|0;}while((Kf|0)<4)}}while(0);if((mf&16|0)!=0){Kf=c[Qc>>2]|0;pf=b[Kf+(sf<<2)>>1]|0;Yf=b[Kf+(sf<<2)+2>>1]|0;c[Cd>>2]=0;c[lb>>2]=7;c[hb>>2]=0;VMa(J,pf,Yf)|0;yPa(J,u,t,Od,Pd,Qd,C,D,pf,Yf)}if((mf&4096|0)!=0){c[Cd>>2]=0;c[lb>>2]=7;c[hb>>2]=0;VMa(J,0,0)|0;yPa(J,u,t,Od,Pd,Qd,C,D,0,0)}do{if((c[Kd>>2]|0)==0){if((c[Ha>>2]&1|0)==0){break}if((c[H+200>>2]|(c[H+196>>2]|(c[H+192>>2]|(c[H+188>>2]|(c[H+184>>2]|c[Qb>>2]))))|0)==0){break}UGb(Ic|0,Ld|0,64)|0;Yf=c[Md>>2]|0;do{if((Yf&4|0)==0){if((Yf&2|0)==0){tl=c[Kc>>2]|0;ul=c[Jc>>2]|0;vl=Yf;break}else{tl=c[Vc>>2]|0;ul=c[Uc>>2]|0;vl=Yf;break}}else{VMa(J,0,0)|0;tl=0;ul=0;vl=c[Md>>2]|0}}while(0);c[lb>>2]=vl;c[Ia>>2]=c[Nd>>2];c[hb>>2]=0;c[Cd>>2]=0;c[Na>>2]=1;yPa(J,u,t,Od,Pd,Qd,C,D,ul,tl);c[Na>>2]=0}}while(0);a[(c[Sd>>2]|0)+sf|0]=c[Rd>>2];UGb(Ic|0,Ld|0,64)|0;UGb(fa|0,Td|0,32)|0;c[ea>>2]=c[Ud>>2];c[ld>>2]=c[Vd>>2];c[nd>>2]=c[Wd>>2];c[pd>>2]=c[Xd>>2];c[O>>2]=c[Yd>>2];c[R>>2]=c[Zd>>2];c[S>>2]=c[_d>>2];c[U>>2]=c[$d>>2];c[V>>2]=c[ae>>2];c[W>>2]=c[be>>2];c[X>>2]=c[ce>>2];c[P>>2]=c[de>>2];c[hb>>2]=c[Kd>>2];c[Ea>>2]=c[ee>>2];c[Ia>>2]=c[Nd>>2];c[lb>>2]=c[Md>>2];c[Q>>2]=c[fe>>2];c[Q+4>>2]=c[fe+4>>2];c[Q+8>>2]=c[fe+8>>2];c[Q+12>>2]=c[fe+12>>2];c[Q+16>>2]=c[fe+16>>2];c[Q+20>>2]=c[fe+20>>2];if((c[Hd>>2]|0)!=0){c[we>>2]=c[Ke>>2];c[we+4>>2]=c[Ke+4>>2];c[we+8>>2]=c[Ke+8>>2];c[we+12>>2]=c[Ke+12>>2];c[we+16>>2]=c[Ke+16>>2];c[we+20>>2]=c[Ke+20>>2];c[De>>2]=c[Le>>2];c[De+4>>2]=c[Le+4>>2];c[De+8>>2]=c[Le+8>>2];c[De+12>>2]=c[Le+12>>2];c[De+16>>2]=c[Le+16>>2];c[De+20>>2]=c[Le+20>>2]}c[ob>>2]=c[ge>>2];c[Rb>>2]=c[he>>2];c[Tb>>2]=c[ie>>2];c[Vb>>2]=c[je>>2];c[Xb>>2]=c[ke>>2];c[Ib>>2]=c[le>>2];c[Hb>>2]=c[ne>>2];c[Kb>>2]=c[oe>>2];c[Lb>>2]=c[pe>>2];c[rb>>2]=c[qe>>2];c[ma>>2]=c[Rd>>2];c[Dd>>2]=c[re>>2];Yf=c[I>>2]|0;pf=c[M>>2]|0;Kf=32-Yf+(pf-(c[L>>2]|0)<<3)|0;x:do{if((Yf|0)<32){nf=c[se>>2]<<Yf;c[se>>2]=nf;Gf=nf>>>24&255;nf=pf;while(1){c[M>>2]=nf+1;a[nf]=Gf;fg=c[se>>2]|0;c[se>>2]=fg<<8;ph=(c[I>>2]|0)+8|0;c[I>>2]=ph;if((ph|0)>=32){break x}Gf=fg>>>16&255;nf=c[M>>2]|0}}}while(0);c[I>>2]=32;c[se>>2]=0;pf=c[D>>2]|0;Yf=pf^1;M_(Fd,v+(Yf*3e3|0)|0,Kf);c[Q>>2]=c[Gd>>2];c[Q+4>>2]=c[Gd+4>>2];c[Q+8>>2]=c[Gd+8>>2];c[Q+12>>2]=c[Gd+12>>2];c[Q+16>>2]=c[Gd+16>>2];c[Q+20>>2]=c[Gd+20>>2];if((c[ra>>2]|0)!=0){nf=c[xe>>2]|0;Gf=c[ze>>2]|0;fg=32-nf+(Gf-(c[ye>>2]|0)<<3)|0;y:do{if((nf|0)<32){ph=c[Ae>>2]<<nf;c[Ae>>2]=ph;Mf=ph>>>24&255;ph=Gf;while(1){c[ze>>2]=ph+1;a[ph]=Mf;hh=c[Ae>>2]|0;c[Ae>>2]=hh<<8;Kh=(c[xe>>2]|0)+8|0;c[xe>>2]=Kh;if((Kh|0)>=32){break y}Mf=hh>>>16&255;ph=c[ze>>2]|0}}}while(0);c[xe>>2]=32;c[Ae>>2]=0;M_(Be,w+(Yf*3e3|0)|0,fg);c[we>>2]=c[Ce>>2];c[we+4>>2]=c[Ce+4>>2];c[we+8>>2]=c[Ce+8>>2];c[we+12>>2]=c[Ce+12>>2];c[we+16>>2]=c[Ce+16>>2];c[we+20>>2]=c[Ce+20>>2];Gf=c[Ee>>2]|0;nf=c[Ge>>2]|0;Kf=32-Gf+(nf-(c[Fe>>2]|0)<<3)|0;z:do{if((Gf|0)<32){ph=c[He>>2]<<Gf;c[He>>2]=ph;Mf=ph>>>24&255;ph=nf;while(1){c[Ge>>2]=ph+1;a[ph]=Mf;hh=c[He>>2]|0;c[He>>2]=hh<<8;Kh=(c[Ee>>2]|0)+8|0;c[Ee>>2]=Kh;if((Kh|0)>=32){break z}Mf=hh>>>16&255;ph=c[Ge>>2]|0}}}while(0);c[Ee>>2]=32;c[He>>2]=0;M_(Ie,y+(Yf*3e3|0)|0,Kf);c[De>>2]=c[Je>>2];c[De+4>>2]=c[Je+4>>2];c[De+8>>2]=c[Je+8>>2];c[De+12>>2]=c[Je+12>>2];c[De+16>>2]=c[Je+16>>2];c[De+20>>2]=c[Je+20>>2]}c[N>>2]=32-(c[I>>2]|0)+((c[M>>2]|0)-(c[L>>2]|0)<<3);do{if((c[Hc>>2]|0)==2){if((c[xb>>2]|0)==3){break}xca(J)}}while(0);if((pf|0)==0){cf[c[te>>2]&1023](c[Aa>>2]|0,c[ue>>2]|0,c[La>>2]|0,16);cf[c[ve>>2]&1023](c[Ba>>2]|0,(c[ue>>2]|0)+(c[La>>2]<<4)|0,c[Ma>>2]|0,8);cf[c[ve>>2]&1023](c[Ca>>2]|0,(c[ue>>2]|0)+(c[La>>2]<<4|8)|0,c[Ma>>2]|0,8)}if((c[(c[sa>>2]|0)+296>>2]|0)!=1){break}YOa(J,c[ob>>2]|0)}}while(0);if((c[hb>>2]|0)!=0){mf=c[Lc>>2]|0;b[mf+(sf<<2)>>1]=0;b[mf+(sf<<2)+2>>1]=0}if((c[mb>>2]&32768|0)!=0){mf=c[ka>>2]<<4;Kf=c[cb>>2]|0;Yf=(mf+16|0)>(Kf|0)?Kf-mf|0:16;Kf=c[la>>2]<<4;nf=c[fb>>2]|0;Gf=(Kf+16|0)>(nf|0)?nf-Kf|0:16;nf=c[$a>>2]|0;fg=c[La>>2]|0;ph=(ba(Kf,fg)|0)+mf|0;mf=nf+ph|0;Kf=c[Aa>>2]|0;do{if((Yf|0)==16&(Gf|0)==16){wl=Pe[c[ed>>2]&255](0,mf,Kf,fg,16)|0}else{if((Yf|0)==8&(Gf|0)==8){wl=Pe[c[id>>2]&255](0,mf,Kf,fg,8)|0;break}if((Gf|0)<=0){wl=0;break}Mf=(Yf|0)>0;hh=0;Kh=0;while(1){if(Mf){Ff=ba(Kh,fg)|0;qf=hh;rf=0;while(1){Of=rf+Ff|0;ag=(c[5398952+((d[nf+(Of+ph)|0]|256)-(d[Kf+Of|0]|0)<<2)>>2]|0)+qf|0;Of=rf+1|0;if((Of|0)<(Yf|0)){qf=ag;rf=Of}else{xl=ag;break}}}else{xl=hh}rf=Kh+1|0;if((rf|0)<(Gf|0)){hh=xl;Kh=rf}else{wl=xl;break}}}}while(0);Kf=YGb(c[fd>>2]|0,c[fd+4>>2]|0,wl,(wl|0)<0|0?-1:0)|0;c[fd>>2]=Kf;c[fd+4>>2]=F;Kf=c[ab>>2]|0;ph=c[Ma>>2]|0;nf=(ba(ba(c[la>>2]|0,K)|0,ph)|0)+(c[ka>>2]<<3)|0;fg=Kf+nf|0;mf=c[Ba>>2]|0;Kh=Yf>>1;hh=Gf>>c[g>>2];Mf=(Kh|0)==16;do{if(Mf&(hh|0)==16){yl=Pe[c[ed>>2]&255](0,fg,mf,ph,16)|0}else{if((Kh|0)==8&(hh|0)==8){yl=Pe[c[id>>2]&255](0,fg,mf,ph,8)|0;break}if((hh|0)<=0){yl=0;break}pf=(Kh|0)>0;rf=0;qf=0;while(1){if(pf){Ff=ba(qf,ph)|0;ag=rf;Of=0;while(1){Hh=Of+Ff|0;kh=(c[5398952+((d[Kf+(Hh+nf)|0]|256)-(d[mf+Hh|0]|0)<<2)>>2]|0)+ag|0;Hh=Of+1|0;if((Hh|0)<(Kh|0)){ag=kh;Of=Hh}else{zl=kh;break}}}else{zl=rf}Of=qf+1|0;if((Of|0)<(hh|0)){rf=zl;qf=Of}else{yl=zl;break}}}}while(0);hh=YGb(c[gd>>2]|0,c[gd+4>>2]|0,yl,(yl|0)<0|0?-1:0)|0;c[gd>>2]=hh;c[gd+4>>2]=F;hh=c[bb>>2]|0;mf=c[Ma>>2]|0;nf=(ba(ba(c[la>>2]|0,K)|0,mf)|0)+(c[ka>>2]<<3)|0;Kf=hh+nf|0;ph=c[Ca>>2]|0;fg=Gf>>c[g>>2];do{if(Mf&(fg|0)==16){Al=Pe[c[ed>>2]&255](0,Kf,ph,mf,16)|0}else{if((Kh|0)==8&(fg|0)==8){Al=Pe[c[id>>2]&255](0,Kf,ph,mf,8)|0;break}if((fg|0)<=0){Al=0;break}Yf=(Kh|0)>0;qf=0;rf=0;while(1){if(Yf){pf=ba(rf,mf)|0;Of=qf;ag=0;while(1){Ff=ag+pf|0;kh=(c[5398952+((d[hh+(Ff+nf)|0]|256)-(d[ph+Ff|0]|0)<<2)>>2]|0)+Of|0;Ff=ag+1|0;if((Ff|0)<(Kh|0)){Of=kh;ag=Ff}else{Bl=kh;break}}}else{Bl=qf}ag=rf+1|0;if((ag|0)<(fg|0)){qf=Bl;rf=ag}else{Al=Bl;break}}}}while(0);fg=YGb(c[hd>>2]|0,c[hd+4>>2]|0,Al,(Al|0)<0|0?-1:0)|0;c[hd>>2]=fg;c[hd+4>>2]=F}do{if((c[dd>>2]|0)!=0){if((c[Hc>>2]|0)!=2){break}zca(J)}}while(0);kf=kf+1|0;}while((kf|0)<(c[na>>2]|0))}kf=hf+1|0;if((kf|0)<(c[ja>>2]|0)){hf=kf}else{Cl=kf;break a}}if((of|0)==12){yDb(c[sa>>2]|0,16,2354552,(Jf=i,i=i+1|0,i=i+7&-8,c[Jf>>2]=0,Jf)|0);i=Jf;Dl=-1;i=f;return Dl|0}else if((of|0)==16){yDb(c[sa>>2]|0,16,2348120,(Jf=i,i=i+1|0,i=i+7&-8,c[Jf>>2]=0,Jf)|0);i=Jf;Dl=-1;i=f;return Dl|0}}else{Cl=ia}}while(0);ia=c[H+14092>>2]|0;do{if((ia|0)!=0&(ia|0)<4){if((c[H+9992>>2]|0)!=1){break}bQa(J)}}while(0);xPa(J);J=c[H+4>>2]|0;ia=c[J+624>>2]|0;if((ia|0)==0){Dl=0;i=f;return Dl|0}Jf=ba(Cl-(c[aa>>2]|0)|0,c[H+116>>2]|0)|0;H=c[da>>2]|0;cf[ia&1023](J,H,(c[M>>2]|0)-H|0,Jf-(c[$>>2]|0)|0);Dl=0;i=f;return Dl|0}function xPa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;do{if((c[b+48>>2]|0)==13){if((c[b+13940>>2]|0)!=0){zNa(b)}tNa(b+784|0)}else{if((c[b+28>>2]|0)!=3){break}LLa(b)}}while(0);d=b+784|0;K_(d);e=b+788|0;f=c[e>>2]|0;g=d|0;if((f|0)<32){d=c[g>>2]<<f;c[g>>2]=d;f=b+796|0;h=d>>>24&255;while(1){d=c[f>>2]|0;c[f>>2]=d+1;a[d]=h;d=c[g>>2]|0;c[g>>2]=d<<8;i=(c[e>>2]|0)+8|0;c[e>>2]=i;if((i|0)<32){h=d>>>16&255}else{break}}}c[e>>2]=32;c[g>>2]=0;if((c[b+60>>2]&512|0)==0){return}if((c[b+13940>>2]|0)!=0){return}g=(c[b+796>>2]|0)-(c[b+792>>2]|0)<<3;e=b+13700|0;h=c[e>>2]|0;c[e>>2]=g;e=b+13696|0;c[e>>2]=(c[e>>2]|0)-h+g;return}function yPa(f,g,h,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0.0,db=0.0,eb=0.0,fb=0,gb=0.0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Oe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Ye=0,Ze=0,$e=0,af=0,bf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0;q=i;i=i+3680|0;r=q|0;s=q+8|0;t=q+16|0;u=q+144|0;v=q+272|0;w=q+536|0;x=q+2072|0;y=q+3608|0;z=q+3656|0;A=q+3664|0;B=f+11824|0;UGb(B|0,g+11824|0,32)|0;C=f+12484|0;c[C>>2]=c[g+12484>>2];D=f+9860|0;c[D>>2]=c[g+9860>>2];E=f+9864|0;c[E>>2]=c[g+9864>>2];G=f+9868|0;c[G>>2]=c[g+9868>>2];H=f+13664|0;c[H>>2]=c[g+13664>>2];I=f+13672|0;c[I>>2]=c[g+13672>>2];J=f+13676|0;c[J>>2]=c[g+13676>>2];K=f+13680|0;c[K>>2]=c[g+13680>>2];L=f+13684|0;c[L>>2]=c[g+13684>>2];M=f+13688|0;c[M>>2]=c[g+13688>>2];N=f+13692|0;c[N>>2]=c[g+13692>>2];O=f+13696|0;c[O>>2]=c[g+13696>>2];c[f+13700>>2]=0;P=f+9924|0;c[P>>2]=0;Q=c[g+9960>>2]|0;R=f+9960|0;c[R>>2]=Q;S=c[g+9984>>2]|0;U=f+9984|0;c[U>>2]=S;V=f+14100|0;c[V>>2]=c[g+14100>>2];g=c[n>>2]|0;W=f+14340|0;c[W>>2]=(c[f+14344>>2]|0)+(g*1536|0);X=f+784|0;Y=j+(g*24|0)|0;c[X>>2]=c[Y>>2];c[X+4>>2]=c[Y+4>>2];c[X+8>>2]=c[Y+8>>2];c[X+12>>2]=c[Y+12>>2];c[X+16>>2]=c[Y+16>>2];c[X+20>>2]=c[Y+20>>2];Y=f+13936|0;if((c[Y>>2]|0)!=0){g=f+13980|0;j=k+((c[n>>2]|0)*24|0)|0;c[g>>2]=c[j>>2];c[g+4>>2]=c[j+4>>2];c[g+8>>2]=c[j+8>>2];c[g+12>>2]=c[j+12>>2];c[g+16>>2]=c[j+16>>2];c[g+20>>2]=c[j+20>>2];j=f+13956|0;g=l+((c[n>>2]|0)*24|0)|0;c[j>>2]=c[g>>2];c[j+4>>2]=c[g+4>>2];c[j+8>>2]=c[g+8>>2];c[j+12>>2]=c[g+12>>2];c[j+16>>2]=c[g+16>>2];c[j+20>>2]=c[g+20>>2]}if((c[n>>2]|0)!=0){g=A;j=f+12544|0;l=j;c[g>>2]=c[l>>2];c[g+4>>2]=c[l+4>>2];c[g+8>>2]=c[l+8>>2];l=c[f+9948>>2]|0;c[j>>2]=l;j=c[f+148>>2]<<4;c[f+12548>>2]=l+j;c[f+12552>>2]=l+(j|8)}j=f+14212|0;l=c[j>>2]|0;a:do{if((l|0)==1){g=x;k=c[f+12476>>2]|0;Z=c[f+12480>>2]|0;_=f+148|0;$=c[_>>2]|0;aa=f+152|0;ca=c[aa>>2]|0;da=c[f+10044>>2]|0;ea=y|0;c[ea>>2]=da;fa=y+4|0;c[fa>>2]=da;ga=y+8|0;c[ga>>2]=da;ha=y+12|0;c[ha>>2]=da;ia=y+16|0;c[ia>>2]=da;ja=y+20|0;c[ja>>2]=da;da=$<<3;$=ca<<3;do{if((c[f+9980>>2]|0)==0){if((c[f+14404>>2]&4|0)==0){break}cPa(f,S+Q|0)}else{ca=(ba(c[f+124>>2]|0,Z)|0)+k|0;ka=c[(c[f+9976>>2]|0)+(ca<<2)>>2]|0;c[f+9968>>2]=ka;la=((ka*139|0)+8192|0)>>>14;c[R>>2]=la;ma=c[f+4>>2]|0;na=c[ma+500>>2]|0;oa=c[ma+504>>2]|0;if((la|0)<(na|0)){pa=na}else{pa=(la|0)>(oa|0)?oa:la}c[R>>2]=pa;c[f+9972>>2]=((ba(ka,ka)|0)+64|0)>>>7;do{if((c[f+14404>>2]&4|0)==0){ka=a[(c[(c[f+9856>>2]|0)+1512>>2]|0)+ca|0]|0;c[R>>2]=ka;la=ka-Q|0;c[U>>2]=la;if((c[f+28>>2]|0)!=2){qa=la;break}if((la|0)<-2){ra=-2}else{ra=(la|0)>2?2:la}c[U>>2]=ra;if((c[f+48>>2]|0)!=13){qa=ra;break}if((c[f+12488>>2]|0)!=0){qa=ra;break}do{if((c[f+9992>>2]|0)==3){if((ra&1|0)==0){if((c[f+11736>>2]&4|0)==0){sa=ra;break}}c[U>>2]=0;sa=0}else{sa=ra}}while(0);if((c[f+11740>>2]|0)!=1){qa=sa;break}c[U>>2]=0;qa=0}else{qa=S}}while(0);cPa(f,qa+Q|0)}}while(0);ca=c[_>>2]|0;la=c[aa>>2]|0;ka=Z<<4;oa=k<<4;na=(c[f+5400>>2]|0)+((ba(ca,ka)|0)+oa)|0;ma=Z<<3;ta=k<<3;ua=(ba(la,ma)|0)+ta|0;va=(c[f+5404>>2]|0)+ua|0;wa=(c[f+5408>>2]|0)+ua|0;ua=c[f+8>>2]|0;if((oa+16|0)>(ua|0)){xa=26}else{if((ka+16|0)>(c[f+12>>2]|0)){xa=26}else{ya=na;za=va;Aa=wa}}do{if((xa|0)==26){if((c[f+48>>2]|0)==108){ya=na;za=va;Aa=wa;break}Ba=c[f+9944>>2]|0;Ca=Ba+32|0;Da=c[f+14216>>2]|0;Ea=Da+ua>>Da;Da=c[f+12>>2]|0;Fa=c[f+14220>>2]|0;Ga=Fa+Da>>Fa;Fa=f+11540|0;Ne[c[Fa>>2]&127](Ca,na,ca,ca,16,16,oa,ka,ua,Da);Da=ca*18|0;Ha=Ba+(Da+32)|0;Ne[c[Fa>>2]&127](Ha,va,la,la,8,8,ta,ma,Ea,Ga);Ia=Ba+(Da+48)|0;Ne[c[Fa>>2]&127](Ia,wa,la,la,8,8,ta,ma,Ea,Ga);ya=Ca;za=Ha;Aa=Ia}}while(0);ma=f+12488|0;do{if((c[ma>>2]|0)==0){ta=c[f+12544>>2]|0;wa=c[f+12548>>2]|0;va=c[f+12552>>2]|0;do{if((c[f+12472>>2]|0)==0){xa=41}else{if((c[f+9992>>2]|0)==3){xa=41;break}Ja=f+10936|0;Ka=f+11460|0}}while(0);if((xa|0)==41){Ja=f+10680|0;Ka=f+11332|0}ua=f+11736|0;ka=c[ua>>2]|0;if((ka&1|0)==0){La=Ja;Ma=Ka;Na=ka}else{APa(f,ta,wa,va,0,f+952|0,Ka,Ja);La=f+10808|0;Ma=f+11396|0;Na=c[ua>>2]|0}if((Na&2|0)!=0){APa(f,ta,wa,va,1,f+3176|0,Ma,La)}ua=f+60|0;do{if((c[ua>>2]&262144|0)==0){Oa=da;Pa=$;Qa=ca;Ra=la}else{ka=f+14236|0;c[ka>>2]=0;oa=f+10540|0;na=f;aa=Pe[c[oa>>2]&255](na,ta,ya,ca,8)|0;_=ca<<3;Ia=(Pe[c[oa>>2]&255](na,ta+_|0,ya+_|0,ca,8)|0)+aa|0;aa=Ia+((c[(c[f+4>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((aa|0)<=0){Oa=da;Pa=$;Qa=ca;Ra=la;break}Ia=ca<<1;_=Pe[c[oa>>2]&255](na,ta,ya,Ia,8)|0;if((aa|0)<=((Pe[c[oa>>2]&255](na,ta+ca|0,ya+ca|0,Ia,8)|0)+_|0)){Oa=da;Pa=$;Qa=ca;Ra=la;break}c[ka>>2]=1;Oa=ca;Pa=la;Qa=Ia;Ra=la<<((c[j>>2]|0)==2)}}while(0);Ia=f+10060|0;cf[c[Ia>>2]&1023](c[W>>2]|0,ya,ta,Qa);ka=ya+8|0;_=ta+8|0;cf[c[Ia>>2]&1023]((c[W>>2]|0)+128|0,ka,_,Qa);na=ya+Oa|0;oa=ta+Oa|0;cf[c[Ia>>2]&1023]((c[W>>2]|0)+256|0,na,oa,Qa);aa=Oa+8|0;Ha=ya+aa|0;Ca=ta+aa|0;cf[c[Ia>>2]&1023]((c[W>>2]|0)+384|0,Ha,Ca,Qa);do{if((c[ua>>2]&8192|0)==0){cf[c[Ia>>2]&1023]((c[W>>2]|0)+512|0,za,wa,Ra);cf[c[Ia>>2]&1023]((c[W>>2]|0)+640|0,Aa,va,Ra);if((c[f+14220>>2]|0)!=0){break}cf[c[Ia>>2]&1023]((c[W>>2]|0)+768|0,za+Pa|0,wa+Pa|0,Ra);cf[c[Ia>>2]&1023]((c[W>>2]|0)+896|0,Aa+Pa|0,va+Pa|0,Ra)}else{c[ia>>2]=1;c[ja>>2]=1}}while(0);Ia=(ba(c[f+124>>2]|0,Z)|0)+k|0;ua=c[R>>2]|0;if((e[(c[f+9200>>2]|0)+(Ia<<1)>>1]|0)>=(ba(ua<<1,ua)|0)){Sa=Oa;Ta=Pa;Ua=Qa;Va=Ra;break}ua=f+10112|0;Ia=Pe[c[ua>>2]&255](0,ya,ta,Qa,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ea>>2]=1}Ia=Pe[c[ua>>2]&255](0,ka,_,Qa,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[fa>>2]=1}Ia=Pe[c[ua>>2]&255](0,na,oa,Qa,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ga>>2]=1}Ia=Pe[c[ua>>2]&255](0,Ha,Ca,Qa,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ha>>2]=1}Ia=Pe[c[ua>>2]&255](0,za,wa,Ra,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ia>>2]=1}Ia=Pe[c[ua>>2]&255](0,Aa,va,Ra,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ja>>2]=1}if((c[f+14220>>2]|0)!=0){Sa=Oa;Ta=Pa;Ua=Qa;Va=Ra;break}Ia=Pe[c[ua>>2]&255](0,za+Pa|0,wa+Pa|0,Ra,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[y+24>>2]=1}Ia=Pe[c[ua>>2]&255](0,Aa+Pa|0,va+Pa|0,Ra,8)|0;if((Ia|0)>=((c[R>>2]|0)*20|0|0)){Sa=Oa;Ta=Pa;Ua=Qa;Va=Ra;break}c[y+28>>2]=1;Sa=Oa;Ta=Pa;Ua=Qa;Va=Ra}else{Ia=f+60|0;do{if((c[Ia>>2]&262144|0)==0){Wa=da;Xa=$;Ya=ca;Za=la}else{ua=f+14236|0;c[ua>>2]=0;aa=f+10556|0;Ga=f;Ea=Pe[c[aa>>2]&255](Ga,ya,0,ca,8)|0;Fa=Ea-400+(Pe[c[aa>>2]&255](Ga,ya+(ca<<3)|0,0,ca,8)|0)|0;if((Fa|0)<=0){Wa=da;Xa=$;Ya=ca;Za=la;break}Ea=ca<<1;Da=Pe[c[aa>>2]&255](Ga,ya,0,Ea,8)|0;if((Fa|0)<=((Pe[c[aa>>2]&255](Ga,ya+ca|0,0,Ea,8)|0)+Da|0)){Wa=da;Xa=$;Ya=ca;Za=la;break}c[ua>>2]=1;Wa=ca;Xa=la;Ya=Ea;Za=la<<(((c[j>>2]|0)-2|0)>>>0<2>>>0)}}while(0);va=f+10056|0;Xe[c[va>>2]&4095](c[W>>2]|0,ya,Ya);Xe[c[va>>2]&4095]((c[W>>2]|0)+128|0,ya+8|0,Ya);Xe[c[va>>2]&4095]((c[W>>2]|0)+256|0,ya+Wa|0,Ya);Xe[c[va>>2]&4095]((c[W>>2]|0)+384|0,ya+(Wa+8)|0,Ya);if((c[Ia>>2]&8192|0)!=0){c[ia>>2]=1;c[ja>>2]=1;Sa=Wa;Ta=Xa;Ua=Ya;Va=Za;break}Xe[c[va>>2]&4095]((c[W>>2]|0)+512|0,za,Za);Xe[c[va>>2]&4095]((c[W>>2]|0)+640|0,Aa,Za);if((c[f+14220>>2]|0)!=0){Sa=Wa;Ta=Xa;Ua=Ya;Va=Za;break}wa=c[va>>2]|0;Ca=(c[W>>2]|0)+768|0;if((c[f+14216>>2]|0)==0){Xe[wa&4095](Ca,za+8|0,Za);Xe[c[va>>2]&4095]((c[W>>2]|0)+896|0,Aa+8|0,Za);Xe[c[va>>2]&4095]((c[W>>2]|0)+1024|0,za+Xa|0,Za);Xe[c[va>>2]&4095]((c[W>>2]|0)+1152|0,Aa+Xa|0,Za);Ha=Xa+8|0;Xe[c[va>>2]&4095]((c[W>>2]|0)+1280|0,za+Ha|0,Za);Xe[c[va>>2]&4095]((c[W>>2]|0)+1408|0,Aa+Ha|0,Za);Sa=Wa;Ta=Xa;Ua=Ya;Va=Za;break}else{Xe[wa&4095](Ca,za+Xa|0,Za);Xe[c[va>>2]&4095]((c[W>>2]|0)+896|0,Aa+Xa|0,Za);Sa=Wa;Ta=Xa;Ua=Ya;Va=Za;break}}}while(0);la=f+14408|0;if((c[la>>2]|0)!=0){if((c[ea>>2]|0)==0){zPa(w|0,ya,Ua)}if((c[fa>>2]|0)==0){zPa(w+128|0,ya+8|0,Ua)}if((c[ga>>2]|0)==0){zPa(w+256|0,ya+Sa|0,Ua)}if((c[ha>>2]|0)==0){zPa(w+384|0,ya+(Sa+8)|0,Ua)}if((c[ia>>2]|0)==0){zPa(w+512|0,za,Va)}if((c[ja>>2]|0)==0){zPa(w+640|0,Aa,Va)}do{if((c[f+14220>>2]|0)==0){if((c[y+24>>2]|0)==0){zPa(w+768|0,za+Ta|0,Va)}if((c[y+28>>2]|0)!=0){break}zPa(w+896|0,Aa+Ta|0,Va)}}while(0);UGb(g|0,c[W>>2]|0,768)|0}ja=f+14392|0;ia=f+13084|0;ha=f+13080|0;ga=f+4|0;fa=0;do{do{if((c[y+(fa<<2)>>2]|0)==0){ea=Pe[c[ja>>2]&255](f,(c[W>>2]|0)+(fa<<7)|0,fa,c[R>>2]|0,z)|0;c[f+180+(fa<<2)>>2]=ea;if((c[z>>2]|0)==0){break}ca=c[W>>2]|0;$=c[ia>>2]|0;da=c[ha>>2]|0;k=(c[ma>>2]|0)!=0|0;if((k|0)>(ea|0)){break}Z=$&65535;va=da&65535;Ca=0;wa=k;while(1){k=ca+(fa<<7)+(d[f+368+wa|0]<<1)|0;Ha=b[k>>1]|0;oa=Ha<<16>>16;if((oa|0)>($|0)){_a=Z;$a=Ca+1|0}else{na=(oa|0)<(da|0);_a=na?va:Ha;$a=(na&1)+Ca|0}b[k>>1]=_a;k=wa+1|0;if((k|0)>(ea|0)){break}else{Ca=$a;wa=k}}if(($a|0)==0){break}wa=c[ga>>2]|0;if((c[wa+296>>2]|0)!=0){break}yDb(wa,32,2344760,(ab=i,i=i+24|0,c[ab>>2]=$a,c[ab+8>>2]=da,c[ab+16>>2]=$,ab)|0);i=ab}else{c[f+180+(fa<<2)>>2]=-1}}while(0);fa=fa+1|0;}while((fa|0)<6);if((c[la>>2]|0)!=0){fa=u|0;ga=f+364|0;ha=f+13100|0;ia=f+13104|0;g=f+9972|0;Ia=t|0;wa=f+11256|0;Ca=f+11252|0;ea=v|0;va=f+11164|0;Z=f+228|0;ca=f+168|0;k=f+172|0;na=f+13092|0;Ha=f+13096|0;oa=0;do{if((c[y+(oa<<2)>>2]|0)==0){_=c[W>>2]|0;ka=_+(oa<<7)|0;ta=w+(oa<<7)|0;Ea=c[R>>2]|0;ua=c[ga>>2]|0;if((b[4432924]|0)==0){Da=0;do{Ga=Da<<3;bb=(Da|0)==0?11585.237502960395:16384.0;cb=bb*.7071067811865476;db=+(Da|0)*.39269908169872414;aa=0;do{Fa=aa+Ga+(f+11184)|0;Ba=(aa|0)==0;eb=+(aa|0)*.39269908169872414;fb=0;do{gb=+T(eb*(+(fb|0)+.5));if(Ba){hb=0;do{ib=d[Fa]|0;b[8865848+(ib<<7)+((hb<<3)+fb<<1)>>1]=Gc(+(gb*cb*+T(db*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}else{hb=0;do{ib=d[Fa]|0;b[8865848+(ib<<7)+((hb<<3)+fb<<1)>>1]=Gc(+(gb*bb*+T(db*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}fb=fb+1|0;}while((fb|0)<8);aa=aa+1|0;}while((aa|0)<8);Da=Da+1|0;}while((Da|0)<8)}Da=Ea<<1;aa=Ea-1|1;if((c[ma>>2]|0)==0){jb=aa;kb=0;lb=32;mb=ha;nb=ia;ob=1}else{do{if((c[Z>>2]|0)==0){if((oa|0)<4){pb=aa;qb=c[ca>>2]|0;break}else{pb=aa;qb=c[k>>2]|0;break}}else{pb=0;qb=1}}while(0);aa=qb<<3;jb=pb;kb=1;lb=(ba(b[ka>>1]|0,aa)|0)+32|0;mb=na;nb=Ha;ob=aa}aa=c[mb>>2]|0;Ea=c[nb>>2]|0;Ga=f+180+(oa<<2)|0;$=c[Ga>>2]|0;da=0;while(1){b[t+(da<<1)>>1]=lb-(b[x+(oa<<7)+(da<<1)>>1]<<6);fb=da+1|0;if((fb|0)<64){da=fb}else{rb=0;sb=0;break}}do{da=w+(oa<<7)+(sb<<1)|0;fb=b[da>>1]|0;Fa=fb<<16>>16;Ba=(fb<<16>>16>-1?Fa:-Fa|0)+144|0;Fa=((((Ba|0)/2|0)+6912|0)/(Ba|0)|0)+15|0;b[da>>1]=Fa;rb=(ba(Fa,Fa)|0)+rb|0;sb=sb+1|0;}while((sb|0)<64);Fa=gHb(c[g>>2]|0,0,rb,(rb|0)<0|0?-1:0)|0;da=Fa>>>19|F<<13;Fa=-jb|0;if((kb|0)<=($|0)){Ba=0;fb=0;hb=kb;while(1){ib=d[f+368+hb|0]|0;tb=b[_+(oa<<7)+(ib<<1)>>1]|0;if(tb<<16>>16==0){ub=fb;vb=Ba+1|0}else{wb=ba(tb<<16>>16,Da)|0;c[v+(fb<<2)>>2]=Ba;Xe[c[wa>>2]&4095](Ia,8865848+(ib<<7)|0,wb+(tb<<16>>16<0?Fa:jb)|0);ub=fb+1|0;vb=0}tb=hb+1|0;if((tb|0)>($|0)){break}else{Ba=vb;fb=ub;hb=tb}}}hb=(kb|0)==0;fb=-ob|0;Ba=$;while(1){tb=_e[c[Ca>>2]&1023](Ia,ta,8865848,0)|0;if((Ba|0)>2){xb=0;xa=135}else{if((c[la>>2]|0)>2){xb=0;xa=135}else{yb=0}}if((xa|0)==135){while(1){xa=0;wb=b[w+(oa<<7)+(xb<<1)>>1]|0;b[u+(xb<<1)>>1]=(ba(ba(wb,wb)|0,b[t+(xb<<1)>>1]|0)|0)+131072>>18;wb=xb+1|0;if((wb|0)<64){xb=wb;xa=135}else{break}}me[c[va>>2]&511](fa);yb=1}do{if(hb){zb=tb;Ab=0;Bb=0}else{wb=b[ka>>1]|0;if((ba(wb-1|0,ob)|0)>>>0>2047>>>0){Cb=tb;Db=0;Eb=0}else{ib=_e[c[Ca>>2]&1023](Ia,ta,8865848,fb)|0;Fb=(ib|0)<(tb|0);Cb=Fb?ib:tb;Db=Fb<<31>>31;Eb=Fb?fb:0}if((ba(wb+1|0,ob)|0)>>>0>2047>>>0){zb=Cb;Ab=Db;Bb=Eb;break}wb=_e[c[Ca>>2]&1023](Ia,ta,8865848,ob)|0;Fb=(wb|0)<(Cb|0);zb=Fb?wb:Cb;Ab=Fb?1:Db;Bb=Fb?ob:Eb}}while(0);tb=Ba+1|0;Fb=c[ea>>2]|0;wb=Bb;ib=Ab;Gb=0;Hb=zb;Ib=0;Jb=1;Kb=kb;Lb=0;Mb=0;while(1){Nb=d[f+368+Kb|0]|0;Ob=b[_+(oa<<7)+(Nb<<1)>>1]|0;Pb=Ob<<16>>16;Qb=c[la>>2]|0;if((Qb|0)<3&(Kb|0)>(tb|0)){Rb=wb;Sb=ib;Tb=Gb;break}Ub=Ob<<16>>16!=0;if(Ub){Vb=ba(Pb,Da)|0;Wb=Vb+(Ob<<16>>16<0?Fa:jb)|0;Xb=Jb+1|0;Yb=c[v+(Jb<<2)>>2]|0}else{Wb=0;Xb=Jb;Yb=Fb-1|0}Vb=Ob<<16>>16>-1?Pb:-Pb|0;Zb=(Kb|0)<(Ba|0);_b=Kb+1|0;$b=Yb+_b|0;ac=f+368+$b|0;bc=($b|0)<(Ba|0);$b=(Yb+Ib<<7)+128|0;cc=Yb<<7;dc=Ib<<7;ec=dc|65;fc=aa+ec|0;gc=Ea+ec|0;ec=(Lb|0)==0;hc=(Mb<<7)+Lb|0;ic=Ea+hc|0;jc=aa+hc|0;hc=8865848+(Nb<<7)|0;Nb=(Ob+62&65535)>>>0<125>>>0;Ob=dc|64;dc=Pb+Ob|0;kc=aa+dc|0;lc=Ea+dc|0;dc=ua+Kb|0;mc=wb;nc=ib;oc=Gb;pc=Hb;qc=-1;rc=Qb;while(1){Qb=qc+Pb|0;if((rc|0)<2){if((((Qb|0)>-1?Qb:-Qb|0)|0)>(Vb|0)){sc=pc;tc=oc;uc=nc;vc=mc}else{xa=149}}else{xa=149}b:do{if((xa|0)==149){xa=0;do{if((Qb|0)==0){if(!Zb){wc=d[gc]|0;if(ec){xc=0;yc=-wc|0;break}xc=0;yc=(d[ic]|0)-wc-(d[jc]|0)|0;break}wc=(b[_+(oa<<7)+(d[ac]<<1)>>1]|0)+64|0;zc=wc>>>0>127>>>0?0:wc;wc=zc+$b|0;if(bc){xc=0;yc=(d[aa+wc|0]|0)-(d[aa+(zc+cc)|0]|0)-(d[fc]|0)|0;break}else{xc=0;yc=(d[Ea+wc|0]|0)-(d[Ea+(zc+cc)|0]|0)-(d[fc]|0)|0;break}}else{zc=ba(Qb,Da)|0;wc=((Qb|0)<0?Fa:jb)+zc|0;if((wc+2047|0)>>>0>4094>>>0){sc=pc;tc=oc;uc=nc;vc=mc;break b}if(Ub){if(!Nb){xc=wc;yc=0;break}zc=Qb+Ob|0;if(Zb){xc=wc;yc=(d[aa+zc|0]|0)-(d[kc]|0)|0;break}else{xc=wc;yc=(d[Ea+zc|0]|0)-(d[lc]|0)|0;break}}do{if(yb){zc=b[u+(d[dc]<<1)>>1]|0;if(zc<<16>>16==0){break}if((zc<<16>>16^Qb|0)>-1){sc=pc;tc=oc;uc=nc;vc=mc;break b}}}while(0);if(!Zb){zc=d[gc]|0;if(ec){xc=wc;yc=zc;break}xc=wc;yc=(d[jc]|0)+zc-(d[ic]|0)|0;break}zc=(b[_+(oa<<7)+(d[ac]<<1)>>1]|0)+64|0;Ac=zc>>>0>127>>>0?0:zc;zc=d[fc]|0;Bc=Ac+cc|0;if(bc){xc=wc;yc=(d[aa+Bc|0]|0)+zc-(d[aa+(Ac+$b)|0]|0)|0;break}else{xc=wc;yc=(d[Ea+Bc|0]|0)+zc-(d[Ea+(Ac+$b)|0]|0)|0;break}}}while(0);Ac=ba(yc,da)|0;zc=xc-Wb|0;Bc=(_e[c[Ca>>2]&1023](Ia,ta,hc,zc)|0)+Ac|0;Ac=(Bc|0)<(pc|0);sc=Ac?Bc:pc;tc=Ac?Kb:oc;uc=Ac?qc:nc;vc=Ac?zc:mc}}while(0);if((qc|0)>=0){break}mc=vc;nc=uc;oc=tc;pc=sc;qc=qc+2|0;rc=c[la>>2]|0}if(Ub){rc=Pb+64|0;Cc=Ib;Dc=rc>>>0>127>>>0?0:rc;Ec=0}else{Cc=Mb;Dc=Lb;Ec=Ib+1|0}if((_b|0)<64){Fb=Yb;wb=vc;ib=uc;Gb=tc;Hb=sc;Ib=Ec;Jb=Xb;Kb=_b;Lb=Dc;Mb=Cc}else{Rb=vc;Sb=uc;Tb=tc;break}}if((Sb|0)==0){break}Mb=d[f+368+Tb|0]|0;Lb=_+(oa<<7)+(Mb<<1)|0;b[Lb>>1]=(e[Lb>>1]|0)+Sb;c:do{if((Tb|0)>(Ba|0)){Fc=Tb}else{Lb=Ba;while(1){if((Lb|0)<(kb|0)){Fc=Lb;break c}if((b[_+(oa<<7)+(d[f+368+Lb|0]<<1)>>1]|0)==0){Lb=Lb-1|0}else{Fc=Lb;break}}}}while(0);if((kb|0)<=(Fc|0)){Lb=0;_b=0;Pb=kb;while(1){if((b[_+(oa<<7)+(d[f+368+Pb|0]<<1)>>1]|0)==0){Hc=_b;Ic=Lb+1|0}else{c[v+(_b<<2)>>2]=Lb;Hc=_b+1|0;Ic=0}Ub=Pb+1|0;if((Ub|0)>(Fc|0)){break}else{Lb=Ic;_b=Hc;Pb=Ub}}}Xe[c[wa>>2]&4095](Ia,8865848+(Mb<<7)|0,Rb);Ba=Fc}c[Ga>>2]=Ba}oa=oa+1|0;}while((oa|0)<6)}oa=f+72|0;Ia=c[oa>>2]|0;d:do{if((Ia|0)!=0){if((c[ma>>2]|0)==0){Jc=0;Kc=Ia}else{break}while(1){wa=c[W>>2]|0;la=wa+(Jc<<7)|0;Ca=f+180+(Jc<<2)|0;ea=c[Ca>>2]|0;fa=Kc>>>31;va=fa^1;g=(Kc|0)<0?-Kc|0:Kc;e:do{if((ea|0)>(fa<<31>>31|0)){if((ea|0)<0){Lc=0}else{Ha=(fa|0)!=1;na=0;k=0;ca=0;while(1){Z=b[wa+(Jc<<7)+(d[f+368+na|0]<<1)>>1]|0;ia=Z<<16>>16;ha=Z<<16>>16>-1?ia:-ia|0;do{if((ha|0)==1){if(Ha&(na|0)==0){Mc=ca;Nc=k;break}Mc=(a[1405072+k|0]|0)+ca|0;Nc=0}else{if((ha|0)>1){break e}Mc=ca;Nc=k+1|0}}while(0);ha=na+1|0;if((ha|0)>(ea|0)){Lc=Mc;break}else{na=ha;k=Nc;ca=Mc}}}if((Lc|0)>=(g|0)){break}if((va|0)<=(ea|0)){ca=va;do{b[wa+(Jc<<7)+(d[f+368+ca|0]<<1)>>1]=0;ca=ca+1|0;}while((ca|0)<=(ea|0))}if((b[la>>1]|0)==0){c[Ca>>2]=-1;break}else{c[Ca>>2]=0;break}}}while(0);Ca=Jc+1|0;if((Ca|0)>=4){break d}Jc=Ca;Kc=c[oa>>2]|0}}}while(0);oa=f+76|0;Ia=c[oa>>2]|0;f:do{if((Ia|0)!=0){if((c[ma>>2]|0)==0){Oc=4;Pc=Ia}else{break}while(1){Ba=c[W>>2]|0;Ga=Ba+(Oc<<7)|0;Ca=f+180+(Oc<<2)|0;la=c[Ca>>2]|0;ea=Pc>>>31;wa=ea^1;va=(Pc|0)<0?-Pc|0:Pc;g:do{if((la|0)>(ea<<31>>31|0)){if((la|0)<0){Qc=0}else{g=(ea|0)!=1;fa=0;Mb=0;ca=0;while(1){k=b[Ba+(Oc<<7)+(d[f+368+fa|0]<<1)>>1]|0;na=k<<16>>16;Ha=k<<16>>16>-1?na:-na|0;do{if((Ha|0)==1){if(g&(fa|0)==0){Rc=ca;Sc=Mb;break}Rc=(a[1405072+Mb|0]|0)+ca|0;Sc=0}else{if((Ha|0)>1){break g}Rc=ca;Sc=Mb+1|0}}while(0);Ha=fa+1|0;if((Ha|0)>(la|0)){Qc=Rc;break}else{fa=Ha;Mb=Sc;ca=Rc}}}if((Qc|0)>=(va|0)){break}if((wa|0)<=(la|0)){ca=wa;do{b[Ba+(Oc<<7)+(d[f+368+ca|0]<<1)>>1]=0;ca=ca+1|0;}while((ca|0)<=(la|0))}if((b[Ga>>1]|0)==0){c[Ca>>2]=-1;break}else{c[Ca>>2]=0;break}}}while(0);Ca=Oc+1|0;if((Ca|0)>=6){break f}Oc=Ca;Pc=c[oa>>2]|0}}}while(0);do{if((c[f+14404>>2]&8|0)!=0){if((c[f+180>>2]|0)==-1){c[f+13112>>2]=8388607}if((c[f+184>>2]|0)==-1){c[f+13116>>2]=8388607}if((c[f+188>>2]|0)==-1){c[f+13120>>2]=8388607}if((c[f+192>>2]|0)==-1){c[f+13124>>2]=8388607}if((c[f+196>>2]|0)==-1){c[f+13128>>2]=8388607}if(!((c[f+200>>2]|0)==-1)){break}c[f+13132>>2]=8388607}}while(0);do{if((c[f+60>>2]&8192|0)!=0){if((c[ma>>2]|0)==0){break}c[f+200>>2]=0;c[f+196>>2]=0;oa=c[f+172>>2]|0;Ia=((((oa|0)/2|0)+1024|0)/(oa|0)|0)&65535;oa=c[W>>2]|0;b[oa+640>>1]=Ia;b[oa+512>>1]=Ia;if((c[f+14220>>2]|0)!=0){break}c[f+204>>2]=0;b[oa+768>>1]=Ia;c[f+208>>2]=0;b[oa+896>>1]=Ia;c[f+212>>2]=0;b[oa+1024>>1]=Ia;c[f+216>>2]=0;b[oa+1152>>1]=Ia;c[f+220>>2]=0;b[oa+1280>>1]=Ia;c[f+224>>2]=0;b[oa+1408>>1]=Ia}}while(0);do{if((c[f+14200>>2]|0)!=0){if((c[ja>>2]|0)==2){break}ma=f+180|0;if((c[ma>>2]|0)>0){Ia=63;while(1){if((Ia|0)<=0){break}if((b[(c[W>>2]|0)+(d[f+368+Ia|0]<<1)>>1]|0)==0){Ia=Ia-1|0}else{break}}c[ma>>2]=Ia}oa=f+184|0;if((c[oa>>2]|0)>0){Ca=63;while(1){if((Ca|0)<=0){break}if((b[(c[W>>2]|0)+128+(d[f+368+Ca|0]<<1)>>1]|0)==0){Ca=Ca-1|0}else{break}}c[oa>>2]=Ca}Ia=f+188|0;if((c[Ia>>2]|0)>0){ma=63;while(1){if((ma|0)<=0){break}if((b[(c[W>>2]|0)+256+(d[f+368+ma|0]<<1)>>1]|0)==0){ma=ma-1|0}else{break}}c[Ia>>2]=ma}Ca=f+192|0;if((c[Ca>>2]|0)>0){oa=63;while(1){if((oa|0)<=0){break}if((b[(c[W>>2]|0)+384+(d[f+368+oa|0]<<1)>>1]|0)==0){oa=oa-1|0}else{break}}c[Ca>>2]=oa}ma=f+196|0;if((c[ma>>2]|0)>0){Ia=63;while(1){if((Ia|0)<=0){break}if((b[(c[W>>2]|0)+512+(d[f+368+Ia|0]<<1)>>1]|0)==0){Ia=Ia-1|0}else{break}}c[ma>>2]=Ia}oa=f+200|0;if((c[oa>>2]|0)>0){Tc=63}else{break}while(1){if((Tc|0)<=0){break}if((b[(c[W>>2]|0)+640+(d[f+368+Tc|0]<<1)>>1]|0)==0){Tc=Tc-1|0}else{break}}c[oa>>2]=Tc}}while(0);switch(c[f+48>>2]|0){case 1:case 2:{LMa(f,c[W>>2]|0,o,p);break a;break};case 13:{pNa(f,c[W>>2]|0,o,p);break a;break};case 16:case 17:case 18:{eQa(f,c[W>>2]|0,o,p);break a;break};case 19:{edb(f,c[W>>2]|0,o,p);break a;break};case 4:{vca(f,c[W>>2]|0,o,p);break a;break};case 5:case 20:case 22:case 6:case 7:{Llb(f,c[W>>2]|0,o,p);break a;break};case 8:case 108:{OLa(f,c[W>>2]|0);break a;break};default:{break a}}}else if((l|0)==2){ja=x;Ia=c[f+12476>>2]|0;ma=c[f+12480>>2]|0;Ca=f+148|0;Ga=c[Ca>>2]|0;la=f+152|0;Ba=c[la>>2]|0;wa=c[f+10044>>2]|0;va=y|0;c[va>>2]=wa;ea=y+4|0;c[ea>>2]=wa;ca=y+8|0;c[ca>>2]=wa;Mb=y+12|0;c[Mb>>2]=wa;fa=y+16|0;c[fa>>2]=wa;g=y+20|0;c[g>>2]=wa;Ha=y+24|0;c[Ha>>2]=wa;na=y+28|0;c[na>>2]=wa;wa=Ga<<3;Ga=Ba<<3;do{if((c[f+9980>>2]|0)==0){if((c[f+14404>>2]&4|0)==0){break}cPa(f,S+Q|0)}else{Ba=(ba(c[f+124>>2]|0,ma)|0)+Ia|0;k=c[(c[f+9976>>2]|0)+(Ba<<2)>>2]|0;c[f+9968>>2]=k;ha=((k*139|0)+8192|0)>>>14;c[R>>2]=ha;ia=c[f+4>>2]|0;Z=c[ia+500>>2]|0;ga=c[ia+504>>2]|0;if((ha|0)<(Z|0)){Uc=Z}else{Uc=(ha|0)>(ga|0)?ga:ha}c[R>>2]=Uc;c[f+9972>>2]=((ba(k,k)|0)+64|0)>>>7;do{if((c[f+14404>>2]&4|0)==0){k=a[(c[(c[f+9856>>2]|0)+1512>>2]|0)+Ba|0]|0;c[R>>2]=k;ha=k-Q|0;c[U>>2]=ha;if((c[f+28>>2]|0)!=2){Vc=ha;break}if((ha|0)<-2){Wc=-2}else{Wc=(ha|0)>2?2:ha}c[U>>2]=Wc;if((c[f+48>>2]|0)!=13){Vc=Wc;break}if((c[f+12488>>2]|0)!=0){Vc=Wc;break}do{if((c[f+9992>>2]|0)==3){if((Wc&1|0)==0){if((c[f+11736>>2]&4|0)==0){Xc=Wc;break}}c[U>>2]=0;Xc=0}else{Xc=Wc}}while(0);if((c[f+11740>>2]|0)!=1){Vc=Xc;break}c[U>>2]=0;Vc=0}else{Vc=S}}while(0);cPa(f,Vc+Q|0)}}while(0);Ba=c[Ca>>2]|0;oa=c[la>>2]|0;ha=ma<<4;k=Ia<<4;ga=(c[f+5400>>2]|0)+((ba(Ba,ha)|0)+k)|0;Z=Ia<<3;ia=(ba(oa,ha)|0)+Z|0;_=(c[f+5404>>2]|0)+ia|0;ta=(c[f+5408>>2]|0)+ia|0;ia=c[f+8>>2]|0;if((k+16|0)>(ia|0)){xa=272}else{if((ha+16|0)>(c[f+12>>2]|0)){xa=272}else{Yc=ga;Zc=_;_c=ta}}do{if((xa|0)==272){if((c[f+48>>2]|0)==108){Yc=ga;Zc=_;_c=ta;break}da=c[f+9944>>2]|0;Ea=da+32|0;aa=c[f+14216>>2]|0;Fa=aa+ia>>aa;aa=c[f+12>>2]|0;Da=c[f+14220>>2]|0;ua=Da+aa>>Da;Da=f+11540|0;Ne[c[Da>>2]&127](Ea,ga,Ba,Ba,16,16,k,ha,ia,aa);aa=Ba*18|0;fb=da+(aa+32)|0;Ne[c[Da>>2]&127](fb,_,oa,oa,8,16,Z,ha,Fa,ua);ka=da+(aa+48)|0;Ne[c[Da>>2]&127](ka,ta,oa,oa,8,16,Z,ha,Fa,ua);Yc=Ea;Zc=fb;_c=ka}}while(0);ha=f+12488|0;do{if((c[ha>>2]|0)==0){Z=c[f+12544>>2]|0;ta=c[f+12548>>2]|0;_=c[f+12552>>2]|0;do{if((c[f+12472>>2]|0)==0){xa=287}else{if((c[f+9992>>2]|0)==3){xa=287;break}$c=f+10936|0;ad=f+11460|0}}while(0);if((xa|0)==287){$c=f+10680|0;ad=f+11332|0}ia=f+11736|0;k=c[ia>>2]|0;if((k&1|0)==0){bd=$c;cd=ad;dd=k}else{APa(f,Z,ta,_,0,f+952|0,ad,$c);bd=f+10808|0;cd=f+11396|0;dd=c[ia>>2]|0}if((dd&2|0)!=0){APa(f,Z,ta,_,1,f+3176|0,cd,bd)}ia=f+60|0;do{if((c[ia>>2]&262144|0)==0){ed=wa;fd=Ga;gd=Ba;hd=oa}else{k=f+14236|0;c[k>>2]=0;ga=f+10540|0;la=f;Ca=Pe[c[ga>>2]&255](la,Z,Yc,Ba,8)|0;ka=Ba<<3;fb=(Pe[c[ga>>2]&255](la,Z+ka|0,Yc+ka|0,Ba,8)|0)+Ca|0;Ca=fb+((c[(c[f+4>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((Ca|0)<=0){ed=wa;fd=Ga;gd=Ba;hd=oa;break}fb=Ba<<1;ka=Pe[c[ga>>2]&255](la,Z,Yc,fb,8)|0;if((Ca|0)<=((Pe[c[ga>>2]&255](la,Z+Ba|0,Yc+Ba|0,fb,8)|0)+ka|0)){ed=wa;fd=Ga;gd=Ba;hd=oa;break}c[k>>2]=1;ed=Ba;fd=oa;gd=fb;hd=oa<<((c[j>>2]|0)==2)}}while(0);fb=f+10060|0;cf[c[fb>>2]&1023](c[W>>2]|0,Yc,Z,gd);k=Yc+8|0;ka=Z+8|0;cf[c[fb>>2]&1023]((c[W>>2]|0)+128|0,k,ka,gd);la=Yc+ed|0;ga=Z+ed|0;cf[c[fb>>2]&1023]((c[W>>2]|0)+256|0,la,ga,gd);Ca=ed+8|0;Ea=Yc+Ca|0;ua=Z+Ca|0;cf[c[fb>>2]&1023]((c[W>>2]|0)+384|0,Ea,ua,gd);do{if((c[ia>>2]&8192|0)==0){cf[c[fb>>2]&1023]((c[W>>2]|0)+512|0,Zc,ta,hd);cf[c[fb>>2]&1023]((c[W>>2]|0)+640|0,_c,_,hd);if((c[f+14220>>2]|0)!=0){break}cf[c[fb>>2]&1023]((c[W>>2]|0)+768|0,Zc+fd|0,ta+fd|0,hd);cf[c[fb>>2]&1023]((c[W>>2]|0)+896|0,_c+fd|0,_+fd|0,hd)}else{c[fa>>2]=1;c[g>>2]=1}}while(0);fb=(ba(c[f+124>>2]|0,ma)|0)+Ia|0;ia=c[R>>2]|0;if((e[(c[f+9200>>2]|0)+(fb<<1)>>1]|0)>=(ba(ia<<1,ia)|0)){id=ed;jd=fd;kd=gd;ld=hd;break}ia=f+10112|0;fb=Pe[c[ia>>2]&255](0,Yc,Z,gd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[va>>2]=1}fb=Pe[c[ia>>2]&255](0,k,ka,gd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[ea>>2]=1}fb=Pe[c[ia>>2]&255](0,la,ga,gd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[ca>>2]=1}fb=Pe[c[ia>>2]&255](0,Ea,ua,gd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[Mb>>2]=1}fb=Pe[c[ia>>2]&255](0,Zc,ta,hd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[fa>>2]=1}fb=Pe[c[ia>>2]&255](0,_c,_,hd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[g>>2]=1}if((c[f+14220>>2]|0)!=0){id=ed;jd=fd;kd=gd;ld=hd;break}fb=Pe[c[ia>>2]&255](0,Zc+fd|0,ta+fd|0,hd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[Ha>>2]=1}fb=Pe[c[ia>>2]&255](0,_c+fd|0,_+fd|0,hd,8)|0;if((fb|0)>=((c[R>>2]|0)*20|0|0)){id=ed;jd=fd;kd=gd;ld=hd;break}c[na>>2]=1;id=ed;jd=fd;kd=gd;ld=hd}else{fb=f+60|0;do{if((c[fb>>2]&262144|0)==0){md=wa;nd=Ga;od=Ba;pd=oa}else{ia=f+14236|0;c[ia>>2]=0;Ca=f+10556|0;Fa=f;Da=Pe[c[Ca>>2]&255](Fa,Yc,0,Ba,8)|0;aa=Da-400+(Pe[c[Ca>>2]&255](Fa,Yc+(Ba<<3)|0,0,Ba,8)|0)|0;if((aa|0)<=0){md=wa;nd=Ga;od=Ba;pd=oa;break}Da=Ba<<1;da=Pe[c[Ca>>2]&255](Fa,Yc,0,Da,8)|0;if((aa|0)<=((Pe[c[Ca>>2]&255](Fa,Yc+Ba|0,0,Da,8)|0)+da|0)){md=wa;nd=Ga;od=Ba;pd=oa;break}c[ia>>2]=1;md=Ba;nd=oa;od=Da;pd=oa<<(((c[j>>2]|0)-2|0)>>>0<2>>>0)}}while(0);_=f+10056|0;Xe[c[_>>2]&4095](c[W>>2]|0,Yc,od);Xe[c[_>>2]&4095]((c[W>>2]|0)+128|0,Yc+8|0,od);Xe[c[_>>2]&4095]((c[W>>2]|0)+256|0,Yc+md|0,od);Xe[c[_>>2]&4095]((c[W>>2]|0)+384|0,Yc+(md+8)|0,od);if((c[fb>>2]&8192|0)!=0){c[fa>>2]=1;c[g>>2]=1;id=md;jd=nd;kd=od;ld=pd;break}Xe[c[_>>2]&4095]((c[W>>2]|0)+512|0,Zc,pd);Xe[c[_>>2]&4095]((c[W>>2]|0)+640|0,_c,pd);if((c[f+14220>>2]|0)!=0){id=md;jd=nd;kd=od;ld=pd;break}ta=c[_>>2]|0;ua=(c[W>>2]|0)+768|0;if((c[f+14216>>2]|0)==0){Xe[ta&4095](ua,Zc+8|0,pd);Xe[c[_>>2]&4095]((c[W>>2]|0)+896|0,_c+8|0,pd);Xe[c[_>>2]&4095]((c[W>>2]|0)+1024|0,Zc+nd|0,pd);Xe[c[_>>2]&4095]((c[W>>2]|0)+1152|0,_c+nd|0,pd);Ea=nd+8|0;Xe[c[_>>2]&4095]((c[W>>2]|0)+1280|0,Zc+Ea|0,pd);Xe[c[_>>2]&4095]((c[W>>2]|0)+1408|0,_c+Ea|0,pd);id=md;jd=nd;kd=od;ld=pd;break}else{Xe[ta&4095](ua,Zc+nd|0,pd);Xe[c[_>>2]&4095]((c[W>>2]|0)+896|0,_c+nd|0,pd);id=md;jd=nd;kd=od;ld=pd;break}}}while(0);oa=f+14408|0;if((c[oa>>2]|0)!=0){if((c[va>>2]|0)==0){zPa(w|0,Yc,kd)}if((c[ea>>2]|0)==0){zPa(w+128|0,Yc+8|0,kd)}if((c[ca>>2]|0)==0){zPa(w+256|0,Yc+id|0,kd)}if((c[Mb>>2]|0)==0){zPa(w+384|0,Yc+(id+8)|0,kd)}if((c[fa>>2]|0)==0){zPa(w+512|0,Zc,ld)}if((c[g>>2]|0)==0){zPa(w+640|0,_c,ld)}do{if((c[f+14220>>2]|0)==0){if((c[Ha>>2]|0)==0){zPa(w+768|0,Zc+jd|0,ld)}if((c[na>>2]|0)!=0){break}zPa(w+896|0,_c+jd|0,ld)}}while(0);UGb(ja|0,c[W>>2]|0,1024)|0}na=f+14392|0;Ha=f+13084|0;g=f+13080|0;fa=f+4|0;Mb=0;do{do{if((c[y+(Mb<<2)>>2]|0)==0){ca=Pe[c[na>>2]&255](f,(c[W>>2]|0)+(Mb<<7)|0,Mb,c[R>>2]|0,s)|0;c[f+180+(Mb<<2)>>2]=ca;if((c[s>>2]|0)==0){break}ea=c[W>>2]|0;va=c[Ha>>2]|0;Ba=c[g>>2]|0;Ga=(c[ha>>2]|0)!=0|0;if((Ga|0)>(ca|0)){break}wa=va&65535;Ia=Ba&65535;ma=0;_=Ga;while(1){Ga=ea+(Mb<<7)+(d[f+368+_|0]<<1)|0;ua=b[Ga>>1]|0;ta=ua<<16>>16;if((ta|0)>(va|0)){qd=wa;rd=ma+1|0}else{Ea=(ta|0)<(Ba|0);qd=Ea?Ia:ua;rd=(Ea&1)+ma|0}b[Ga>>1]=qd;Ga=_+1|0;if((Ga|0)>(ca|0)){break}else{ma=rd;_=Ga}}if((rd|0)==0){break}_=c[fa>>2]|0;if((c[_+296>>2]|0)!=0){break}yDb(_,32,2344760,(ab=i,i=i+24|0,c[ab>>2]=rd,c[ab+8>>2]=Ba,c[ab+16>>2]=va,ab)|0);i=ab}else{c[f+180+(Mb<<2)>>2]=-1}}while(0);Mb=Mb+1|0;}while((Mb|0)<8);if((c[oa>>2]|0)!=0){Mb=u|0;fa=f+364|0;g=f+13100|0;Ha=f+13104|0;ja=f+9972|0;fb=t|0;_=f+11256|0;ma=f+11252|0;ca=v|0;Ia=f+11164|0;wa=f+228|0;ea=f+168|0;Ga=f+172|0;Ea=f+13092|0;ua=f+13096|0;ta=0;do{if((c[y+(ta<<2)>>2]|0)==0){ga=c[W>>2]|0;la=ga+(ta<<7)|0;ka=w+(ta<<7)|0;k=c[R>>2]|0;Z=c[fa>>2]|0;if((b[4432924]|0)==0){Da=0;do{ia=Da<<3;db=(Da|0)==0?11585.237502960395:16384.0;bb=db*.7071067811865476;cb=+(Da|0)*.39269908169872414;da=0;do{Fa=da+ia+(f+11184)|0;Ca=(da|0)==0;eb=+(da|0)*.39269908169872414;aa=0;do{gb=+T(eb*(+(aa|0)+.5));if(Ca){hb=0;do{$=d[Fa]|0;b[8865848+($<<7)+((hb<<3)+aa<<1)>>1]=Gc(+(gb*bb*+T(cb*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}else{hb=0;do{$=d[Fa]|0;b[8865848+($<<7)+((hb<<3)+aa<<1)>>1]=Gc(+(gb*db*+T(cb*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}aa=aa+1|0;}while((aa|0)<8);da=da+1|0;}while((da|0)<8);Da=Da+1|0;}while((Da|0)<8)}Da=k<<1;da=k-1|1;if((c[ha>>2]|0)==0){sd=da;td=0;ud=32;vd=g;wd=Ha;xd=1}else{do{if((c[wa>>2]|0)==0){if((ta|0)<4){yd=da;zd=c[ea>>2]|0;break}else{yd=da;zd=c[Ga>>2]|0;break}}else{yd=0;zd=1}}while(0);da=zd<<3;sd=yd;td=1;ud=(ba(b[la>>1]|0,da)|0)+32|0;vd=Ea;wd=ua;xd=da}da=c[vd>>2]|0;k=c[wd>>2]|0;ia=f+180+(ta<<2)|0;va=c[ia>>2]|0;Ba=0;while(1){b[t+(Ba<<1)>>1]=ud-(b[x+(ta<<7)+(Ba<<1)>>1]<<6);aa=Ba+1|0;if((aa|0)<64){Ba=aa}else{Ad=0;Bd=0;break}}do{Ba=w+(ta<<7)+(Bd<<1)|0;aa=b[Ba>>1]|0;Fa=aa<<16>>16;Ca=(aa<<16>>16>-1?Fa:-Fa|0)+144|0;Fa=((((Ca|0)/2|0)+6912|0)/(Ca|0)|0)+15|0;b[Ba>>1]=Fa;Ad=(ba(Fa,Fa)|0)+Ad|0;Bd=Bd+1|0;}while((Bd|0)<64);Fa=gHb(c[ja>>2]|0,0,Ad,(Ad|0)<0|0?-1:0)|0;Ba=Fa>>>19|F<<13;Fa=-sd|0;if((td|0)<=(va|0)){Ca=0;aa=0;hb=td;while(1){$=d[f+368+hb|0]|0;Pb=b[ga+(ta<<7)+($<<1)>>1]|0;if(Pb<<16>>16==0){Cd=aa;Dd=Ca+1|0}else{_b=ba(Pb<<16>>16,Da)|0;c[v+(aa<<2)>>2]=Ca;Xe[c[_>>2]&4095](fb,8865848+($<<7)|0,_b+(Pb<<16>>16<0?Fa:sd)|0);Cd=aa+1|0;Dd=0}Pb=hb+1|0;if((Pb|0)>(va|0)){break}else{Ca=Dd;aa=Cd;hb=Pb}}}hb=(td|0)==0;aa=-xd|0;Ca=va;while(1){Pb=_e[c[ma>>2]&1023](fb,ka,8865848,0)|0;if((Ca|0)>2){Ed=0;xa=381}else{if((c[oa>>2]|0)>2){Ed=0;xa=381}else{Fd=0}}if((xa|0)==381){while(1){xa=0;_b=b[w+(ta<<7)+(Ed<<1)>>1]|0;b[u+(Ed<<1)>>1]=(ba(ba(_b,_b)|0,b[t+(Ed<<1)>>1]|0)|0)+131072>>18;_b=Ed+1|0;if((_b|0)<64){Ed=_b;xa=381}else{break}}me[c[Ia>>2]&511](Mb);Fd=1}do{if(hb){Gd=Pb;Hd=0;Id=0}else{_b=b[la>>1]|0;if((ba(_b-1|0,xd)|0)>>>0>2047>>>0){Jd=Pb;Kd=0;Ld=0}else{$=_e[c[ma>>2]&1023](fb,ka,8865848,aa)|0;Lb=($|0)<(Pb|0);Jd=Lb?$:Pb;Kd=Lb<<31>>31;Ld=Lb?aa:0}if((ba(_b+1|0,xd)|0)>>>0>2047>>>0){Gd=Jd;Hd=Kd;Id=Ld;break}_b=_e[c[ma>>2]&1023](fb,ka,8865848,xd)|0;Lb=(_b|0)<(Jd|0);Gd=Lb?_b:Jd;Hd=Lb?1:Kd;Id=Lb?xd:Ld}}while(0);Pb=Ca+1|0;Lb=c[ca>>2]|0;_b=Id;$=Hd;Ub=0;Kb=Gd;Jb=0;Ib=1;Hb=td;Gb=0;ib=0;while(1){wb=d[f+368+Hb|0]|0;Fb=b[ga+(ta<<7)+(wb<<1)>>1]|0;tb=Fb<<16>>16;rc=c[oa>>2]|0;if((rc|0)<3&(Hb|0)>(Pb|0)){Md=_b;Nd=$;Od=Ub;break}qc=Fb<<16>>16!=0;if(qc){pc=ba(tb,Da)|0;Pd=pc+(Fb<<16>>16<0?Fa:sd)|0;Qd=Ib+1|0;Rd=c[v+(Ib<<2)>>2]|0}else{Pd=0;Qd=Ib;Rd=Lb-1|0}pc=Fb<<16>>16>-1?tb:-tb|0;oc=(Hb|0)<(Ca|0);nc=Hb+1|0;mc=Rd+nc|0;hc=f+368+mc|0;$b=(mc|0)<(Ca|0);mc=(Rd+Jb<<7)+128|0;bc=Rd<<7;cc=Jb<<7;fc=cc|65;ac=da+fc|0;ic=k+fc|0;fc=(Gb|0)==0;jc=(ib<<7)+Gb|0;ec=k+jc|0;gc=da+jc|0;jc=8865848+(wb<<7)|0;wb=(Fb+62&65535)>>>0<125>>>0;Fb=cc|64;cc=tb+Fb|0;Zb=da+cc|0;dc=k+cc|0;cc=Z+Hb|0;lc=_b;kc=$;Ob=Ub;Nb=Kb;Vb=-1;Qb=rc;while(1){rc=Vb+tb|0;if((Qb|0)<2){if((((rc|0)>-1?rc:-rc|0)|0)>(pc|0)){Sd=Nb;Td=Ob;Ud=kc;Vd=lc}else{xa=395}}else{xa=395}h:do{if((xa|0)==395){xa=0;do{if((rc|0)==0){if(!oc){zc=d[ic]|0;if(fc){Wd=0;Xd=-zc|0;break}Wd=0;Xd=(d[ec]|0)-zc-(d[gc]|0)|0;break}zc=(b[ga+(ta<<7)+(d[hc]<<1)>>1]|0)+64|0;Ac=zc>>>0>127>>>0?0:zc;zc=Ac+mc|0;if($b){Wd=0;Xd=(d[da+zc|0]|0)-(d[da+(Ac+bc)|0]|0)-(d[ac]|0)|0;break}else{Wd=0;Xd=(d[k+zc|0]|0)-(d[k+(Ac+bc)|0]|0)-(d[ac]|0)|0;break}}else{Ac=ba(rc,Da)|0;zc=((rc|0)<0?Fa:sd)+Ac|0;if((zc+2047|0)>>>0>4094>>>0){Sd=Nb;Td=Ob;Ud=kc;Vd=lc;break h}if(qc){if(!wb){Wd=zc;Xd=0;break}Ac=rc+Fb|0;if(oc){Wd=zc;Xd=(d[da+Ac|0]|0)-(d[Zb]|0)|0;break}else{Wd=zc;Xd=(d[k+Ac|0]|0)-(d[dc]|0)|0;break}}do{if(Fd){Ac=b[u+(d[cc]<<1)>>1]|0;if(Ac<<16>>16==0){break}if((Ac<<16>>16^rc|0)>-1){Sd=Nb;Td=Ob;Ud=kc;Vd=lc;break h}}}while(0);if(!oc){wc=d[ic]|0;if(fc){Wd=zc;Xd=wc;break}Wd=zc;Xd=(d[gc]|0)+wc-(d[ec]|0)|0;break}wc=(b[ga+(ta<<7)+(d[hc]<<1)>>1]|0)+64|0;Ac=wc>>>0>127>>>0?0:wc;wc=d[ac]|0;Bc=Ac+bc|0;if($b){Wd=zc;Xd=(d[da+Bc|0]|0)+wc-(d[da+(Ac+mc)|0]|0)|0;break}else{Wd=zc;Xd=(d[k+Bc|0]|0)+wc-(d[k+(Ac+mc)|0]|0)|0;break}}}while(0);Ac=ba(Xd,Ba)|0;wc=Wd-Pd|0;Bc=(_e[c[ma>>2]&1023](fb,ka,jc,wc)|0)+Ac|0;Ac=(Bc|0)<(Nb|0);Sd=Ac?Bc:Nb;Td=Ac?Hb:Ob;Ud=Ac?Vb:kc;Vd=Ac?wc:lc}}while(0);if((Vb|0)>=0){break}lc=Vd;kc=Ud;Ob=Td;Nb=Sd;Vb=Vb+2|0;Qb=c[oa>>2]|0}if(qc){Qb=tb+64|0;Yd=Jb;Zd=Qb>>>0>127>>>0?0:Qb;_d=0}else{Yd=ib;Zd=Gb;_d=Jb+1|0}if((nc|0)<64){Lb=Rd;_b=Vd;$=Ud;Ub=Td;Kb=Sd;Jb=_d;Ib=Qd;Hb=nc;Gb=Zd;ib=Yd}else{Md=Vd;Nd=Ud;Od=Td;break}}if((Nd|0)==0){break}ib=d[f+368+Od|0]|0;Gb=ga+(ta<<7)+(ib<<1)|0;b[Gb>>1]=(e[Gb>>1]|0)+Nd;i:do{if((Od|0)>(Ca|0)){$d=Od}else{Gb=Ca;while(1){if((Gb|0)<(td|0)){$d=Gb;break i}if((b[ga+(ta<<7)+(d[f+368+Gb|0]<<1)>>1]|0)==0){Gb=Gb-1|0}else{$d=Gb;break}}}}while(0);if((td|0)<=($d|0)){Gb=0;nc=0;tb=td;while(1){if((b[ga+(ta<<7)+(d[f+368+tb|0]<<1)>>1]|0)==0){ae=nc;be=Gb+1|0}else{c[v+(nc<<2)>>2]=Gb;ae=nc+1|0;be=0}qc=tb+1|0;if((qc|0)>($d|0)){break}else{Gb=be;nc=ae;tb=qc}}}Xe[c[_>>2]&4095](fb,8865848+(ib<<7)|0,Md);Ca=$d}c[ia>>2]=Ca}ta=ta+1|0;}while((ta|0)<8)}ta=f+72|0;fb=c[ta>>2]|0;j:do{if((fb|0)!=0){if((c[ha>>2]|0)==0){ce=0;de=fb}else{break}while(1){_=c[W>>2]|0;oa=_+(ce<<7)|0;ma=f+180+(ce<<2)|0;ca=c[ma>>2]|0;Mb=de>>>31;Ia=Mb^1;ja=(de|0)<0?-de|0:de;k:do{if((ca|0)>(Mb<<31>>31|0)){if((ca|0)<0){ee=0}else{ua=(Mb|0)!=1;Ea=0;Ga=0;ea=0;while(1){wa=b[_+(ce<<7)+(d[f+368+Ea|0]<<1)>>1]|0;Ha=wa<<16>>16;g=wa<<16>>16>-1?Ha:-Ha|0;do{if((g|0)==1){if(ua&(Ea|0)==0){fe=ea;ge=Ga;break}fe=(a[1405072+Ga|0]|0)+ea|0;ge=0}else{if((g|0)>1){break k}fe=ea;ge=Ga+1|0}}while(0);g=Ea+1|0;if((g|0)>(ca|0)){ee=fe;break}else{Ea=g;Ga=ge;ea=fe}}}if((ee|0)>=(ja|0)){break}if((Ia|0)<=(ca|0)){ea=Ia;do{b[_+(ce<<7)+(d[f+368+ea|0]<<1)>>1]=0;ea=ea+1|0;}while((ea|0)<=(ca|0))}if((b[oa>>1]|0)==0){c[ma>>2]=-1;break}else{c[ma>>2]=0;break}}}while(0);ma=ce+1|0;if((ma|0)>=4){break j}ce=ma;de=c[ta>>2]|0}}}while(0);ta=f+76|0;fb=c[ta>>2]|0;l:do{if((fb|0)!=0){if((c[ha>>2]|0)==0){he=4;ie=fb}else{break}while(1){Ca=c[W>>2]|0;ia=Ca+(he<<7)|0;ma=f+180+(he<<2)|0;oa=c[ma>>2]|0;ca=ie>>>31;_=ca^1;Ia=(ie|0)<0?-ie|0:ie;m:do{if((oa|0)>(ca<<31>>31|0)){if((oa|0)<0){je=0}else{ja=(ca|0)!=1;Mb=0;ib=0;ea=0;while(1){Ga=b[Ca+(he<<7)+(d[f+368+Mb|0]<<1)>>1]|0;Ea=Ga<<16>>16;ua=Ga<<16>>16>-1?Ea:-Ea|0;do{if((ua|0)==1){if(ja&(Mb|0)==0){ke=ea;le=ib;break}ke=(a[1405072+ib|0]|0)+ea|0;le=0}else{if((ua|0)>1){break m}ke=ea;le=ib+1|0}}while(0);ua=Mb+1|0;if((ua|0)>(oa|0)){je=ke;break}else{Mb=ua;ib=le;ea=ke}}}if((je|0)>=(Ia|0)){break}if((_|0)<=(oa|0)){ea=_;do{b[Ca+(he<<7)+(d[f+368+ea|0]<<1)>>1]=0;ea=ea+1|0;}while((ea|0)<=(oa|0))}if((b[ia>>1]|0)==0){c[ma>>2]=-1;break}else{c[ma>>2]=0;break}}}while(0);ma=he+1|0;if((ma|0)>=8){break l}he=ma;ie=c[ta>>2]|0}}}while(0);do{if((c[f+14404>>2]&8|0)!=0){if((c[f+180>>2]|0)==-1){c[f+13112>>2]=8388607}if((c[f+184>>2]|0)==-1){c[f+13116>>2]=8388607}if((c[f+188>>2]|0)==-1){c[f+13120>>2]=8388607}if((c[f+192>>2]|0)==-1){c[f+13124>>2]=8388607}if((c[f+196>>2]|0)==-1){c[f+13128>>2]=8388607}if((c[f+200>>2]|0)==-1){c[f+13132>>2]=8388607}if((c[f+204>>2]|0)==-1){c[f+13136>>2]=8388607}if(!((c[f+208>>2]|0)==-1)){break}c[f+13140>>2]=8388607}}while(0);do{if((c[f+60>>2]&8192|0)!=0){if((c[ha>>2]|0)==0){break}c[f+200>>2]=0;c[f+196>>2]=0;ta=c[f+172>>2]|0;fb=((((ta|0)/2|0)+1024|0)/(ta|0)|0)&65535;ta=c[W>>2]|0;b[ta+640>>1]=fb;b[ta+512>>1]=fb;if((c[f+14220>>2]|0)!=0){break}c[f+204>>2]=0;b[ta+768>>1]=fb;c[f+208>>2]=0;b[ta+896>>1]=fb;c[f+212>>2]=0;b[ta+1024>>1]=fb;c[f+216>>2]=0;b[ta+1152>>1]=fb;c[f+220>>2]=0;b[ta+1280>>1]=fb;c[f+224>>2]=0;b[ta+1408>>1]=fb}}while(0);do{if((c[f+14200>>2]|0)!=0){if((c[na>>2]|0)==2){break}else{ne=0}do{ha=f+180+(ne<<2)|0;if((c[ha>>2]|0)>0){fb=63;while(1){if((fb|0)<=0){break}if((b[(c[W>>2]|0)+(ne<<7)+(d[f+368+fb|0]<<1)>>1]|0)==0){fb=fb-1|0}else{break}}c[ha>>2]=fb}ne=ne+1|0;}while((ne|0)<8)}}while(0);switch(c[f+48>>2]|0){case 1:case 2:{LMa(f,c[W>>2]|0,o,p);break a;break};case 13:{pNa(f,c[W>>2]|0,o,p);break a;break};case 16:case 17:case 18:{eQa(f,c[W>>2]|0,o,p);break a;break};case 19:{edb(f,c[W>>2]|0,o,p);break a;break};case 4:{vca(f,c[W>>2]|0,o,p);break a;break};case 5:case 20:case 22:case 6:case 7:{Llb(f,c[W>>2]|0,o,p);break a;break};case 8:case 108:{OLa(f,c[W>>2]|0);break a;break};default:{break a}}}else{na=x;ta=c[f+12476>>2]|0;ma=c[f+12480>>2]|0;ia=f+148|0;oa=c[ia>>2]|0;Ca=f+152|0;_=c[Ca>>2]|0;Ia=c[f+10044>>2]|0;ca=y|0;c[ca>>2]=Ia;ea=y+4|0;c[ea>>2]=Ia;ib=y+8|0;c[ib>>2]=Ia;Mb=y+12|0;c[Mb>>2]=Ia;ja=y+16|0;c[ja>>2]=Ia;ua=y+20|0;c[ua>>2]=Ia;Ea=y+24|0;c[Ea>>2]=Ia;Ga=y+28|0;c[Ga>>2]=Ia;c[y+32>>2]=Ia;c[y+36>>2]=Ia;c[y+40>>2]=Ia;c[y+44>>2]=Ia;Ia=oa<<3;oa=_<<3;do{if((c[f+9980>>2]|0)==0){if((c[f+14404>>2]&4|0)==0){break}cPa(f,S+Q|0)}else{_=(ba(c[f+124>>2]|0,ma)|0)+ta|0;g=c[(c[f+9976>>2]|0)+(_<<2)>>2]|0;c[f+9968>>2]=g;Ha=((g*139|0)+8192|0)>>>14;c[R>>2]=Ha;wa=c[f+4>>2]|0;fa=c[wa+500>>2]|0;ga=c[wa+504>>2]|0;if((Ha|0)<(fa|0)){oe=fa}else{oe=(Ha|0)>(ga|0)?ga:Ha}c[R>>2]=oe;c[f+9972>>2]=((ba(g,g)|0)+64|0)>>>7;do{if((c[f+14404>>2]&4|0)==0){g=a[(c[(c[f+9856>>2]|0)+1512>>2]|0)+_|0]|0;c[R>>2]=g;Ha=g-Q|0;c[U>>2]=Ha;if((c[f+28>>2]|0)!=2){pe=Ha;break}if((Ha|0)<-2){qe=-2}else{qe=(Ha|0)>2?2:Ha}c[U>>2]=qe;if((c[f+48>>2]|0)!=13){pe=qe;break}if((c[f+12488>>2]|0)!=0){pe=qe;break}do{if((c[f+9992>>2]|0)==3){if((qe&1|0)==0){if((c[f+11736>>2]&4|0)==0){re=qe;break}}c[U>>2]=0;re=0}else{re=qe}}while(0);if((c[f+11740>>2]|0)!=1){pe=re;break}c[U>>2]=0;pe=0}else{pe=S}}while(0);cPa(f,pe+Q|0)}}while(0);_=c[ia>>2]|0;fb=c[Ca>>2]|0;ha=ma<<4;Ha=ta<<4;g=(c[f+5400>>2]|0)+((ba(_,ha)|0)+Ha)|0;ga=(ba(fb,ha)|0)+Ha|0;fa=(c[f+5404>>2]|0)+ga|0;wa=(c[f+5408>>2]|0)+ga|0;ga=c[f+8>>2]|0;if((Ha+16|0)>(ga|0)){xa=518}else{if((ha+16|0)>(c[f+12>>2]|0)){xa=518}else{se=g;te=fa;ue=wa}}do{if((xa|0)==518){if((c[f+48>>2]|0)==108){se=g;te=fa;ue=wa;break}ka=c[f+9944>>2]|0;Ba=ka+32|0;k=c[f+14216>>2]|0;da=k+ga>>k;k=c[f+12>>2]|0;Fa=c[f+14220>>2]|0;Da=Fa+k>>Fa;Fa=f+11540|0;Ne[c[Fa>>2]&127](Ba,g,_,_,16,16,Ha,ha,ga,k);k=_*18|0;Z=ka+(k+32)|0;Ne[c[Fa>>2]&127](Z,fa,fb,fb,16,16,Ha,ha,da,Da);aa=ka+(k+48)|0;Ne[c[Fa>>2]&127](aa,wa,fb,fb,16,16,Ha,ha,da,Da);se=Ba;te=Z;ue=aa}}while(0);ha=f+12488|0;do{if((c[ha>>2]|0)==0){Ha=c[f+12544>>2]|0;wa=c[f+12548>>2]|0;fa=c[f+12552>>2]|0;do{if((c[f+12472>>2]|0)==0){xa=533}else{if((c[f+9992>>2]|0)==3){xa=533;break}ve=f+10936|0;we=f+11460|0}}while(0);if((xa|0)==533){ve=f+10680|0;we=f+11332|0}ga=f+11736|0;g=c[ga>>2]|0;if((g&1|0)==0){xe=ve;ye=we;ze=g}else{APa(f,Ha,wa,fa,0,f+952|0,we,ve);xe=f+10808|0;ye=f+11396|0;ze=c[ga>>2]|0}if((ze&2|0)!=0){APa(f,Ha,wa,fa,1,f+3176|0,ye,xe)}ga=f+60|0;do{if((c[ga>>2]&262144|0)==0){Ae=Ia;Be=oa;Ce=_;De=fb}else{g=f+14236|0;c[g>>2]=0;Ca=f+10540|0;ia=f;aa=Pe[c[Ca>>2]&255](ia,Ha,se,_,8)|0;Z=_<<3;Ba=(Pe[c[Ca>>2]&255](ia,Ha+Z|0,se+Z|0,_,8)|0)+aa|0;aa=Ba+((c[(c[f+4>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((aa|0)<=0){Ae=Ia;Be=oa;Ce=_;De=fb;break}Ba=_<<1;Z=Pe[c[Ca>>2]&255](ia,Ha,se,Ba,8)|0;if((aa|0)<=((Pe[c[Ca>>2]&255](ia,Ha+_|0,se+_|0,Ba,8)|0)+Z|0)){Ae=Ia;Be=oa;Ce=_;De=fb;break}c[g>>2]=1;Ae=_;Be=fb;Ce=Ba;De=fb<<((c[j>>2]|0)==2)}}while(0);Ba=f+10060|0;cf[c[Ba>>2]&1023](c[W>>2]|0,se,Ha,Ce);g=se+8|0;Z=Ha+8|0;cf[c[Ba>>2]&1023]((c[W>>2]|0)+128|0,g,Z,Ce);ia=se+Ae|0;Ca=Ha+Ae|0;cf[c[Ba>>2]&1023]((c[W>>2]|0)+256|0,ia,Ca,Ce);aa=Ae+8|0;Da=se+aa|0;da=Ha+aa|0;cf[c[Ba>>2]&1023]((c[W>>2]|0)+384|0,Da,da,Ce);do{if((c[ga>>2]&8192|0)==0){cf[c[Ba>>2]&1023]((c[W>>2]|0)+512|0,te,wa,De);cf[c[Ba>>2]&1023]((c[W>>2]|0)+640|0,ue,fa,De);if((c[f+14220>>2]|0)!=0){break}cf[c[Ba>>2]&1023]((c[W>>2]|0)+768|0,te+Be|0,wa+Be|0,De);cf[c[Ba>>2]&1023]((c[W>>2]|0)+896|0,ue+Be|0,fa+Be|0,De)}else{c[ja>>2]=1;c[ua>>2]=1}}while(0);Ba=(ba(c[f+124>>2]|0,ma)|0)+ta|0;ga=c[R>>2]|0;if((e[(c[f+9200>>2]|0)+(Ba<<1)>>1]|0)>=(ba(ga<<1,ga)|0)){Ee=Ae;Fe=Be;Ge=Ce;He=De;break}ga=f+10112|0;Ba=Pe[c[ga>>2]&255](0,se,Ha,Ce,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ca>>2]=1}Ba=Pe[c[ga>>2]&255](0,g,Z,Ce,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ea>>2]=1}Ba=Pe[c[ga>>2]&255](0,ia,Ca,Ce,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ib>>2]=1}Ba=Pe[c[ga>>2]&255](0,Da,da,Ce,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[Mb>>2]=1}Ba=Pe[c[ga>>2]&255](0,te,wa,De,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ja>>2]=1}Ba=Pe[c[ga>>2]&255](0,ue,fa,De,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ua>>2]=1}if((c[f+14220>>2]|0)!=0){Ee=Ae;Fe=Be;Ge=Ce;He=De;break}Ba=Pe[c[ga>>2]&255](0,te+Be|0,wa+Be|0,De,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[Ea>>2]=1}Ba=Pe[c[ga>>2]&255](0,ue+Be|0,fa+Be|0,De,8)|0;if((Ba|0)>=((c[R>>2]|0)*20|0|0)){Ee=Ae;Fe=Be;Ge=Ce;He=De;break}c[Ga>>2]=1;Ee=Ae;Fe=Be;Ge=Ce;He=De}else{Ba=f+60|0;do{if((c[Ba>>2]&262144|0)==0){Ie=Ia;Je=oa;Ke=_;Le=fb}else{ga=f+14236|0;c[ga>>2]=0;aa=f+10556|0;Fa=f;k=Pe[c[aa>>2]&255](Fa,se,0,_,8)|0;ka=k-400+(Pe[c[aa>>2]&255](Fa,se+(_<<3)|0,0,_,8)|0)|0;if((ka|0)<=0){Ie=Ia;Je=oa;Ke=_;Le=fb;break}k=_<<1;la=Pe[c[aa>>2]&255](Fa,se,0,k,8)|0;if((ka|0)<=((Pe[c[aa>>2]&255](Fa,se+_|0,0,k,8)|0)+la|0)){Ie=Ia;Je=oa;Ke=_;Le=fb;break}c[ga>>2]=1;Ie=_;Je=fb;Ke=k;Le=fb<<(((c[j>>2]|0)-2|0)>>>0<2>>>0)}}while(0);fa=f+10056|0;Xe[c[fa>>2]&4095](c[W>>2]|0,se,Ke);Xe[c[fa>>2]&4095]((c[W>>2]|0)+128|0,se+8|0,Ke);Xe[c[fa>>2]&4095]((c[W>>2]|0)+256|0,se+Ie|0,Ke);Xe[c[fa>>2]&4095]((c[W>>2]|0)+384|0,se+(Ie+8)|0,Ke);if((c[Ba>>2]&8192|0)!=0){c[ja>>2]=1;c[ua>>2]=1;Ee=Ie;Fe=Je;Ge=Ke;He=Le;break}Xe[c[fa>>2]&4095]((c[W>>2]|0)+512|0,te,Le);Xe[c[fa>>2]&4095]((c[W>>2]|0)+640|0,ue,Le);if((c[f+14220>>2]|0)!=0){Ee=Ie;Fe=Je;Ge=Ke;He=Le;break}wa=c[fa>>2]|0;da=(c[W>>2]|0)+768|0;if((c[f+14216>>2]|0)==0){Xe[wa&4095](da,te+8|0,Le);Xe[c[fa>>2]&4095]((c[W>>2]|0)+896|0,ue+8|0,Le);Xe[c[fa>>2]&4095]((c[W>>2]|0)+1024|0,te+Je|0,Le);Xe[c[fa>>2]&4095]((c[W>>2]|0)+1152|0,ue+Je|0,Le);Da=Je+8|0;Xe[c[fa>>2]&4095]((c[W>>2]|0)+1280|0,te+Da|0,Le);Xe[c[fa>>2]&4095]((c[W>>2]|0)+1408|0,ue+Da|0,Le);Ee=Ie;Fe=Je;Ge=Ke;He=Le;break}else{Xe[wa&4095](da,te+Je|0,Le);Xe[c[fa>>2]&4095]((c[W>>2]|0)+896|0,ue+Je|0,Le);Ee=Ie;Fe=Je;Ge=Ke;He=Le;break}}}while(0);fb=f+14408|0;if((c[fb>>2]|0)!=0){if((c[ca>>2]|0)==0){zPa(w|0,se,Ge)}if((c[ea>>2]|0)==0){zPa(w+128|0,se+8|0,Ge)}if((c[ib>>2]|0)==0){zPa(w+256|0,se+Ee|0,Ge)}if((c[Mb>>2]|0)==0){zPa(w+384|0,se+(Ee+8)|0,Ge)}if((c[ja>>2]|0)==0){zPa(w+512|0,te,He)}if((c[ua>>2]|0)==0){zPa(w+640|0,ue,He)}do{if((c[f+14220>>2]|0)==0){if((c[Ea>>2]|0)==0){zPa(w+768|0,te+Fe|0,He)}if((c[Ga>>2]|0)!=0){break}zPa(w+896|0,ue+Fe|0,He)}}while(0);UGb(na|0,c[W>>2]|0,1536)|0}Ga=f+14392|0;Ea=f+13084|0;ua=f+13080|0;ja=f+4|0;Mb=0;do{do{if((c[y+(Mb<<2)>>2]|0)==0){ib=Pe[c[Ga>>2]&255](f,(c[W>>2]|0)+(Mb<<7)|0,Mb,c[R>>2]|0,r)|0;c[f+180+(Mb<<2)>>2]=ib;if((c[r>>2]|0)==0){break}ea=c[W>>2]|0;ca=c[Ea>>2]|0;_=c[ua>>2]|0;oa=(c[ha>>2]|0)!=0|0;if((oa|0)>(ib|0)){break}Ia=ca&65535;ta=_&65535;ma=0;fa=oa;while(1){oa=ea+(Mb<<7)+(d[f+368+fa|0]<<1)|0;da=b[oa>>1]|0;wa=da<<16>>16;if((wa|0)>(ca|0)){Me=Ia;Oe=ma+1|0}else{Da=(wa|0)<(_|0);Me=Da?ta:da;Oe=(Da&1)+ma|0}b[oa>>1]=Me;oa=fa+1|0;if((oa|0)>(ib|0)){break}else{ma=Oe;fa=oa}}if((Oe|0)==0){break}fa=c[ja>>2]|0;if((c[fa+296>>2]|0)!=0){break}yDb(fa,32,2344760,(ab=i,i=i+24|0,c[ab>>2]=Oe,c[ab+8>>2]=_,c[ab+16>>2]=ca,ab)|0);i=ab}else{c[f+180+(Mb<<2)>>2]=-1}}while(0);Mb=Mb+1|0;}while((Mb|0)<12);if((c[fb>>2]|0)!=0){Mb=u|0;ja=f+364|0;ua=f+13100|0;Ea=f+13104|0;na=f+9972|0;Ba=t|0;fa=f+11256|0;ma=f+11252|0;ib=v|0;ta=f+11164|0;Ia=f+228|0;ea=f+168|0;oa=f+172|0;Da=f+13092|0;da=f+13096|0;wa=0;do{if((c[y+(wa<<2)>>2]|0)==0){Ca=c[W>>2]|0;ia=Ca+(wa<<7)|0;Z=w+(wa<<7)|0;g=c[R>>2]|0;Ha=c[ja>>2]|0;if((b[4432924]|0)==0){k=0;do{ga=k<<3;cb=(k|0)==0?11585.237502960395:16384.0;db=cb*.7071067811865476;bb=+(k|0)*.39269908169872414;la=0;do{Fa=la+ga+(f+11184)|0;aa=(la|0)==0;eb=+(la|0)*.39269908169872414;ka=0;do{gb=+T(eb*(+(ka|0)+.5));if(aa){hb=0;do{va=d[Fa]|0;b[8865848+(va<<7)+((hb<<3)+ka<<1)>>1]=Gc(+(gb*db*+T(bb*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}else{hb=0;do{va=d[Fa]|0;b[8865848+(va<<7)+((hb<<3)+ka<<1)>>1]=Gc(+(gb*cb*+T(bb*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}ka=ka+1|0;}while((ka|0)<8);la=la+1|0;}while((la|0)<8);k=k+1|0;}while((k|0)<8)}k=g<<1;la=g-1|1;if((c[ha>>2]|0)==0){Qe=la;Re=0;Se=32;Te=ua;Ue=Ea;Ve=1}else{do{if((c[Ia>>2]|0)==0){if((wa|0)<4){We=la;Ye=c[ea>>2]|0;break}else{We=la;Ye=c[oa>>2]|0;break}}else{We=0;Ye=1}}while(0);la=Ye<<3;Qe=We;Re=1;Se=(ba(b[ia>>1]|0,la)|0)+32|0;Te=Da;Ue=da;Ve=la}la=c[Te>>2]|0;g=c[Ue>>2]|0;ga=f+180+(wa<<2)|0;ca=c[ga>>2]|0;_=0;while(1){b[t+(_<<1)>>1]=Se-(b[x+(wa<<7)+(_<<1)>>1]<<6);ka=_+1|0;if((ka|0)<64){_=ka}else{Ze=0;$e=0;break}}do{_=w+(wa<<7)+($e<<1)|0;ka=b[_>>1]|0;Fa=ka<<16>>16;aa=(ka<<16>>16>-1?Fa:-Fa|0)+144|0;Fa=((((aa|0)/2|0)+6912|0)/(aa|0)|0)+15|0;b[_>>1]=Fa;Ze=(ba(Fa,Fa)|0)+Ze|0;$e=$e+1|0;}while(($e|0)<64);Fa=gHb(c[na>>2]|0,0,Ze,(Ze|0)<0|0?-1:0)|0;_=Fa>>>19|F<<13;Fa=-Qe|0;if((Re|0)<=(ca|0)){aa=0;ka=0;hb=Re;while(1){va=d[f+368+hb|0]|0;tb=b[Ca+(wa<<7)+(va<<1)>>1]|0;if(tb<<16>>16==0){af=ka;bf=aa+1|0}else{nc=ba(tb<<16>>16,k)|0;c[v+(ka<<2)>>2]=aa;Xe[c[fa>>2]&4095](Ba,8865848+(va<<7)|0,nc+(tb<<16>>16<0?Fa:Qe)|0);af=ka+1|0;bf=0}tb=hb+1|0;if((tb|0)>(ca|0)){break}else{aa=bf;ka=af;hb=tb}}}hb=(Re|0)==0;ka=-Ve|0;aa=ca;while(1){tb=_e[c[ma>>2]&1023](Ba,Z,8865848,0)|0;if((aa|0)>2){df=0;xa=627}else{if((c[fb>>2]|0)>2){df=0;xa=627}else{ef=0}}if((xa|0)==627){while(1){xa=0;nc=b[w+(wa<<7)+(df<<1)>>1]|0;b[u+(df<<1)>>1]=(ba(ba(nc,nc)|0,b[t+(df<<1)>>1]|0)|0)+131072>>18;nc=df+1|0;if((nc|0)<64){df=nc;xa=627}else{break}}me[c[ta>>2]&511](Mb);ef=1}do{if(hb){ff=tb;gf=0;hf=0}else{nc=b[ia>>1]|0;if((ba(nc-1|0,Ve)|0)>>>0>2047>>>0){jf=tb;kf=0;lf=0}else{va=_e[c[ma>>2]&1023](Ba,Z,8865848,ka)|0;Gb=(va|0)<(tb|0);jf=Gb?va:tb;kf=Gb<<31>>31;lf=Gb?ka:0}if((ba(nc+1|0,Ve)|0)>>>0>2047>>>0){ff=jf;gf=kf;hf=lf;break}nc=_e[c[ma>>2]&1023](Ba,Z,8865848,Ve)|0;Gb=(nc|0)<(jf|0);ff=Gb?nc:jf;gf=Gb?1:kf;hf=Gb?Ve:lf}}while(0);tb=aa+1|0;Gb=c[ib>>2]|0;nc=hf;va=gf;qc=0;Hb=ff;Ib=0;Jb=1;Kb=Re;Ub=0;$=0;while(1){_b=d[f+368+Kb|0]|0;Lb=b[Ca+(wa<<7)+(_b<<1)>>1]|0;Pb=Lb<<16>>16;Qb=c[fb>>2]|0;if((Qb|0)<3&(Kb|0)>(tb|0)){mf=nc;nf=va;of=qc;break}Vb=Lb<<16>>16!=0;if(Vb){Nb=ba(Pb,k)|0;pf=Nb+(Lb<<16>>16<0?Fa:Qe)|0;qf=Jb+1|0;rf=c[v+(Jb<<2)>>2]|0}else{pf=0;qf=Jb;rf=Gb-1|0}Nb=Lb<<16>>16>-1?Pb:-Pb|0;Ob=(Kb|0)<(aa|0);kc=Kb+1|0;lc=rf+kc|0;jc=f+368+lc|0;mc=(lc|0)<(aa|0);lc=(rf+Ib<<7)+128|0;$b=rf<<7;bc=Ib<<7;ac=bc|65;hc=la+ac|0;ec=g+ac|0;ac=(Ub|0)==0;gc=($<<7)+Ub|0;fc=g+gc|0;ic=la+gc|0;gc=8865848+(_b<<7)|0;_b=(Lb+62&65535)>>>0<125>>>0;Lb=bc|64;bc=Pb+Lb|0;oc=la+bc|0;cc=g+bc|0;bc=Ha+Kb|0;dc=nc;Zb=va;Fb=qc;wb=Hb;pc=-1;rc=Qb;while(1){Qb=pc+Pb|0;if((rc|0)<2){if((((Qb|0)>-1?Qb:-Qb|0)|0)>(Nb|0)){sf=wb;tf=Fb;uf=Zb;vf=dc}else{xa=641}}else{xa=641}n:do{if((xa|0)==641){xa=0;do{if((Qb|0)==0){if(!Ob){wc=d[ec]|0;if(ac){wf=0;xf=-wc|0;break}wf=0;xf=(d[fc]|0)-wc-(d[ic]|0)|0;break}wc=(b[Ca+(wa<<7)+(d[jc]<<1)>>1]|0)+64|0;Ac=wc>>>0>127>>>0?0:wc;wc=Ac+lc|0;if(mc){wf=0;xf=(d[la+wc|0]|0)-(d[la+(Ac+$b)|0]|0)-(d[hc]|0)|0;break}else{wf=0;xf=(d[g+wc|0]|0)-(d[g+(Ac+$b)|0]|0)-(d[hc]|0)|0;break}}else{Ac=ba(Qb,k)|0;wc=((Qb|0)<0?Fa:Qe)+Ac|0;if((wc+2047|0)>>>0>4094>>>0){sf=wb;tf=Fb;uf=Zb;vf=dc;break n}if(Vb){if(!_b){wf=wc;xf=0;break}Ac=Qb+Lb|0;if(Ob){wf=wc;xf=(d[la+Ac|0]|0)-(d[oc]|0)|0;break}else{wf=wc;xf=(d[g+Ac|0]|0)-(d[cc]|0)|0;break}}do{if(ef){Ac=b[u+(d[bc]<<1)>>1]|0;if(Ac<<16>>16==0){break}if((Ac<<16>>16^Qb|0)>-1){sf=wb;tf=Fb;uf=Zb;vf=dc;break n}}}while(0);if(!Ob){zc=d[ec]|0;if(ac){wf=wc;xf=zc;break}wf=wc;xf=(d[ic]|0)+zc-(d[fc]|0)|0;break}zc=(b[Ca+(wa<<7)+(d[jc]<<1)>>1]|0)+64|0;Ac=zc>>>0>127>>>0?0:zc;zc=d[hc]|0;Bc=Ac+$b|0;if(mc){wf=wc;xf=(d[la+Bc|0]|0)+zc-(d[la+(Ac+lc)|0]|0)|0;break}else{wf=wc;xf=(d[g+Bc|0]|0)+zc-(d[g+(Ac+lc)|0]|0)|0;break}}}while(0);Ac=ba(xf,_)|0;zc=wf-pf|0;Bc=(_e[c[ma>>2]&1023](Ba,Z,gc,zc)|0)+Ac|0;Ac=(Bc|0)<(wb|0);sf=Ac?Bc:wb;tf=Ac?Kb:Fb;uf=Ac?pc:Zb;vf=Ac?zc:dc}}while(0);if((pc|0)>=0){break}dc=vf;Zb=uf;Fb=tf;wb=sf;pc=pc+2|0;rc=c[fb>>2]|0}if(Vb){rc=Pb+64|0;yf=Ib;zf=rc>>>0>127>>>0?0:rc;Af=0}else{yf=$;zf=Ub;Af=Ib+1|0}if((kc|0)<64){Gb=rf;nc=vf;va=uf;qc=tf;Hb=sf;Ib=Af;Jb=qf;Kb=kc;Ub=zf;$=yf}else{mf=vf;nf=uf;of=tf;break}}if((nf|0)==0){break}$=d[f+368+of|0]|0;Ub=Ca+(wa<<7)+($<<1)|0;b[Ub>>1]=(e[Ub>>1]|0)+nf;o:do{if((of|0)>(aa|0)){Bf=of}else{Ub=aa;while(1){if((Ub|0)<(Re|0)){Bf=Ub;break o}if((b[Ca+(wa<<7)+(d[f+368+Ub|0]<<1)>>1]|0)==0){Ub=Ub-1|0}else{Bf=Ub;break}}}}while(0);if((Re|0)<=(Bf|0)){Ub=0;kc=0;Pb=Re;while(1){if((b[Ca+(wa<<7)+(d[f+368+Pb|0]<<1)>>1]|0)==0){Cf=kc;Df=Ub+1|0}else{c[v+(kc<<2)>>2]=Ub;Cf=kc+1|0;Df=0}Vb=Pb+1|0;if((Vb|0)>(Bf|0)){break}else{Ub=Df;kc=Cf;Pb=Vb}}}Xe[c[fa>>2]&4095](Ba,8865848+($<<7)|0,mf);aa=Bf}c[ga>>2]=aa}wa=wa+1|0;}while((wa|0)<12)}wa=f+72|0;Ba=c[wa>>2]|0;p:do{if((Ba|0)!=0){if((c[ha>>2]|0)==0){Ef=0;Ff=Ba}else{break}while(1){fa=c[W>>2]|0;fb=fa+(Ef<<7)|0;ma=f+180+(Ef<<2)|0;ib=c[ma>>2]|0;Mb=Ff>>>31;ta=Mb^1;na=(Ff|0)<0?-Ff|0:Ff;q:do{if((ib|0)>(Mb<<31>>31|0)){if((ib|0)<0){Gf=0}else{da=(Mb|0)!=1;Da=0;oa=0;ea=0;while(1){Ia=b[fa+(Ef<<7)+(d[f+368+Da|0]<<1)>>1]|0;Ea=Ia<<16>>16;ua=Ia<<16>>16>-1?Ea:-Ea|0;do{if((ua|0)==1){if(da&(Da|0)==0){Hf=ea;If=oa;break}Hf=(a[1405072+oa|0]|0)+ea|0;If=0}else{if((ua|0)>1){break q}Hf=ea;If=oa+1|0}}while(0);ua=Da+1|0;if((ua|0)>(ib|0)){Gf=Hf;break}else{Da=ua;oa=If;ea=Hf}}}if((Gf|0)>=(na|0)){break}if((ta|0)<=(ib|0)){ea=ta;do{b[fa+(Ef<<7)+(d[f+368+ea|0]<<1)>>1]=0;ea=ea+1|0;}while((ea|0)<=(ib|0))}if((b[fb>>1]|0)==0){c[ma>>2]=-1;break}else{c[ma>>2]=0;break}}}while(0);ma=Ef+1|0;if((ma|0)>=4){break p}Ef=ma;Ff=c[wa>>2]|0}}}while(0);wa=f+76|0;Ba=c[wa>>2]|0;r:do{if((Ba|0)!=0){if((c[ha>>2]|0)==0){Jf=4;Kf=Ba}else{break}while(1){aa=c[W>>2]|0;ga=aa+(Jf<<7)|0;ma=f+180+(Jf<<2)|0;fb=c[ma>>2]|0;ib=Kf>>>31;fa=ib^1;ta=(Kf|0)<0?-Kf|0:Kf;s:do{if((fb|0)>(ib<<31>>31|0)){if((fb|0)<0){Lf=0}else{na=(ib|0)!=1;Mb=0;$=0;ea=0;while(1){oa=b[aa+(Jf<<7)+(d[f+368+Mb|0]<<1)>>1]|0;Da=oa<<16>>16;da=oa<<16>>16>-1?Da:-Da|0;do{if((da|0)==1){if(na&(Mb|0)==0){Mf=ea;Nf=$;break}Mf=(a[1405072+$|0]|0)+ea|0;Nf=0}else{if((da|0)>1){break s}Mf=ea;Nf=$+1|0}}while(0);da=Mb+1|0;if((da|0)>(fb|0)){Lf=Mf;break}else{Mb=da;$=Nf;ea=Mf}}}if((Lf|0)>=(ta|0)){break}if((fa|0)<=(fb|0)){ea=fa;do{b[aa+(Jf<<7)+(d[f+368+ea|0]<<1)>>1]=0;ea=ea+1|0;}while((ea|0)<=(fb|0))}if((b[ga>>1]|0)==0){c[ma>>2]=-1;break}else{c[ma>>2]=0;break}}}while(0);ma=Jf+1|0;if((ma|0)>=12){break r}Jf=ma;Kf=c[wa>>2]|0}}}while(0);do{if((c[f+14404>>2]&8|0)!=0){if((c[f+180>>2]|0)==-1){c[f+13112>>2]=8388607}if((c[f+184>>2]|0)==-1){c[f+13116>>2]=8388607}if((c[f+188>>2]|0)==-1){c[f+13120>>2]=8388607}if((c[f+192>>2]|0)==-1){c[f+13124>>2]=8388607}if((c[f+196>>2]|0)==-1){c[f+13128>>2]=8388607}if((c[f+200>>2]|0)==-1){c[f+13132>>2]=8388607}if((c[f+204>>2]|0)==-1){c[f+13136>>2]=8388607}if((c[f+208>>2]|0)==-1){c[f+13140>>2]=8388607}if((c[f+212>>2]|0)==-1){c[f+13144>>2]=8388607}if((c[f+216>>2]|0)==-1){c[f+13148>>2]=8388607}if((c[f+220>>2]|0)==-1){c[f+13152>>2]=8388607}if(!((c[f+224>>2]|0)==-1)){break}c[f+13156>>2]=8388607}}while(0);do{if((c[f+60>>2]&8192|0)!=0){if((c[ha>>2]|0)==0){break}c[f+200>>2]=0;c[f+196>>2]=0;wa=c[f+172>>2]|0;Ba=((((wa|0)/2|0)+1024|0)/(wa|0)|0)&65535;wa=c[W>>2]|0;b[wa+640>>1]=Ba;b[wa+512>>1]=Ba;if((c[f+14220>>2]|0)!=0){break}c[f+204>>2]=0;b[wa+768>>1]=Ba;c[f+208>>2]=0;b[wa+896>>1]=Ba;c[f+212>>2]=0;b[wa+1024>>1]=Ba;c[f+216>>2]=0;b[wa+1152>>1]=Ba;c[f+220>>2]=0;b[wa+1280>>1]=Ba;c[f+224>>2]=0;b[wa+1408>>1]=Ba}}while(0);do{if((c[f+14200>>2]|0)!=0){if((c[Ga>>2]|0)==2){break}else{Of=0}do{ha=f+180+(Of<<2)|0;if((c[ha>>2]|0)>0){Ba=63;while(1){if((Ba|0)<=0){break}if((b[(c[W>>2]|0)+(Of<<7)+(d[f+368+Ba|0]<<1)>>1]|0)==0){Ba=Ba-1|0}else{break}}c[ha>>2]=Ba}Of=Of+1|0;}while((Of|0)<12)}}while(0);switch(c[f+48>>2]|0){case 1:case 2:{LMa(f,c[W>>2]|0,o,p);break a;break};case 13:{pNa(f,c[W>>2]|0,o,p);break a;break};case 16:case 17:case 18:{eQa(f,c[W>>2]|0,o,p);break a;break};case 19:{edb(f,c[W>>2]|0,o,p);break a;break};case 4:{vca(f,c[W>>2]|0,o,p);break a;break};case 5:case 20:case 22:case 6:case 7:{Llb(f,c[W>>2]|0,o,p);break a;break};case 8:case 108:{OLa(f,c[W>>2]|0);break a;break};default:{break a}}}}while(0);p=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-(c[f+788>>2]|0))|0;if((c[Y>>2]|0)==0){Pf=p}else{Pf=p+64-(c[f+13984>>2]|0)-(c[f+13960>>2]|0)+((c[f+13968>>2]|0)-(c[f+13964>>2]|0)+((c[f+13992>>2]|0)-(c[f+13988>>2]|0))<<3)|0}p=f+4|0;if((c[(c[p>>2]|0)+296>>2]|0)==2){YOa(f,c[W>>2]|0);o=ba(c[f+9972>>2]|0,Pf)|0;Of=f+12476|0;Kf=c[Of>>2]|0;Jf=Kf<<4;Lf=c[f+8>>2]|0;Mf=(Jf+16|0)>(Lf|0)?Lf-Jf|0:16;Lf=f+12480|0;Nf=c[Lf>>2]|0;Ff=Nf<<4;Ef=c[f+12>>2]|0;Gf=(Ff+16|0)>(Ef|0)?Ef-Ff|0:16;do{if((Mf|0)==16&(Gf|0)==16){if((c[(c[p>>2]|0)+240>>2]|0)==10){Ef=f;Hf=c[f+148>>2]|0;If=(c[f+5400>>2]|0)+((ba(Hf,Ff)|0)+Jf)|0;Bf=Pe[c[f+10324>>2]&255](Ef,If,c[f+12544>>2]|0,Hf,16)|0;Hf=f+10328|0;If=f+152|0;mf=c[If>>2]|0;Cf=(c[f+5404>>2]|0)+((ba(mf,c[Lf>>2]|0)|0)+(c[Of>>2]|0)<<3)|0;Df=(Pe[c[Hf>>2]&255](Ef,Cf,c[f+12548>>2]|0,mf,8)|0)+Bf|0;Bf=c[If>>2]|0;If=(c[f+5408>>2]|0)+((ba(Bf,c[Lf>>2]|0)|0)+(c[Of>>2]|0)<<3)|0;Qf=Df+(Pe[c[Hf>>2]&255](Ef,If,c[f+12552>>2]|0,Bf,8)|0)|0;break}else{Bf=c[f+148>>2]|0;If=(c[f+5400>>2]|0)+((ba(Bf,Ff)|0)+Jf)|0;Ef=Pe[c[f+10132>>2]&255](0,If,c[f+12544>>2]|0,Bf,16)|0;Bf=f+10136|0;If=f+152|0;Hf=c[If>>2]|0;Df=(c[f+5404>>2]|0)+((ba(Hf,c[Lf>>2]|0)|0)+(c[Of>>2]|0)<<3)|0;mf=(Pe[c[Bf>>2]&255](0,Df,c[f+12548>>2]|0,Hf,8)|0)+Ef|0;Ef=c[If>>2]|0;If=(c[f+5408>>2]|0)+((ba(Ef,c[Lf>>2]|0)|0)+(c[Of>>2]|0)<<3)|0;Qf=mf+(Pe[c[Bf>>2]&255](0,If,c[f+12552>>2]|0,Ef,8)|0)|0;break}}else{Ef=c[f+5400>>2]|0;If=c[f+148>>2]|0;Bf=(ba(If,Ff)|0)+Jf|0;mf=c[f+12544>>2]|0;do{if((Mf|0)==8&(Gf|0)==8){Hf=Pe[c[f+10136>>2]&255](0,Ef+Bf|0,mf,If,8)|0;Rf=Hf;Sf=c[Of>>2]|0;Tf=c[Lf>>2]|0}else{if((Gf|0)<=0){Rf=0;Sf=Kf;Tf=Nf;break}Hf=(Mf|0)>0;Df=0;Cf=0;while(1){if(Hf){v=ba(Cf,If)|0;Re=Df;of=0;while(1){nf=of+v|0;tf=(c[5398952+((d[Ef+(nf+Bf)|0]|256)-(d[mf+nf|0]|0)<<2)>>2]|0)+Re|0;nf=of+1|0;if((nf|0)<(Mf|0)){Re=tf;of=nf}else{Uf=tf;break}}}else{Uf=Df}of=Cf+1|0;if((of|0)<(Gf|0)){Df=Uf;Cf=of}else{Rf=Uf;Sf=Kf;Tf=Nf;break}}}}while(0);mf=c[f+5404>>2]|0;Bf=f+152|0;Ef=c[Bf>>2]|0;If=(ba(Tf<<3,Ef)|0)+(Sf<<3)|0;Cf=mf+If|0;Df=c[f+12548>>2]|0;Hf=Mf>>1;of=Gf>>1;Re=(Hf|0)==16&(of|0)==16;do{if(Re){Vf=Pe[c[f+10132>>2]&255](0,Cf,Df,Ef,16)|0}else{if((Hf|0)==8&(of|0)==8){Vf=Pe[c[f+10136>>2]&255](0,Cf,Df,Ef,8)|0;break}if((of|0)<=0){Vf=0;break}v=(Hf|0)>0;Ba=0;ha=0;while(1){if(v){tf=ba(ha,Ef)|0;nf=Ba;uf=0;while(1){vf=uf+tf|0;yf=(c[5398952+((d[mf+(vf+If)|0]|256)-(d[Df+vf|0]|0)<<2)>>2]|0)+nf|0;vf=uf+1|0;if((vf|0)<(Hf|0)){nf=yf;uf=vf}else{Wf=yf;break}}}else{Wf=Ba}uf=ha+1|0;if((uf|0)<(of|0)){Ba=Wf;ha=uf}else{Vf=Wf;break}}}}while(0);Df=Vf+Rf|0;If=c[f+5408>>2]|0;mf=c[Bf>>2]|0;Ef=(ba(c[Lf>>2]<<3,mf)|0)+(c[Of>>2]<<3)|0;Cf=If+Ef|0;ha=c[f+12552>>2]|0;do{if(Re){Xf=Pe[c[f+10132>>2]&255](0,Cf,ha,mf,16)|0}else{if((Hf|0)==8&(of|0)==8){Xf=Pe[c[f+10136>>2]&255](0,Cf,ha,mf,8)|0;break}if((of|0)<=0){Xf=0;break}Ba=(Hf|0)>0;v=0;uf=0;while(1){if(Ba){nf=ba(uf,mf)|0;tf=v;yf=0;while(1){vf=yf+nf|0;zf=(c[5398952+((d[If+(vf+Ef)|0]|256)-(d[ha+vf|0]|0)<<2)>>2]|0)+tf|0;vf=yf+1|0;if((vf|0)<(Hf|0)){tf=zf;yf=vf}else{Yf=zf;break}}}else{Yf=v}yf=uf+1|0;if((yf|0)<(of|0)){v=Yf;uf=yf}else{Xf=Yf;break}}}}while(0);Qf=Df+Xf|0}}while(0);Zf=(Qf<<7)+o|0}else{Zf=Pf}if((c[n>>2]|0)!=0){Pf=f+12544|0;o=A;c[Pf>>2]=c[o>>2];c[Pf+4>>2]=c[o+4>>2];c[Pf+8>>2]=c[o+8>>2]}if((Zf|0)>=(c[m>>2]|0)){i=q;return}c[m>>2]=Zf;c[n>>2]=c[n>>2]^1;UGb(h+11744|0,f+11744|0,64)|0;UGb(h+11824|0,B|0,32)|0;c[h+12484>>2]=c[C>>2];c[h+9860>>2]=c[D>>2];c[h+9864>>2]=c[E>>2];c[h+9868>>2]=c[G>>2];c[h+13664>>2]=c[H>>2];c[h+13672>>2]=c[I>>2];c[h+13676>>2]=c[J>>2];c[h+13680>>2]=c[K>>2];c[h+13684>>2]=c[L>>2];c[h+13688>>2]=c[M>>2];c[h+13692>>2]=c[N>>2];c[h+13696>>2]=c[O>>2];c[h+12488>>2]=c[f+12488>>2];c[h+9924>>2]=c[P>>2];c[h+11740>>2]=c[f+11740>>2];c[h+11736>>2]=c[f+11736>>2];P=h+784|0;c[P>>2]=c[X>>2];c[P+4>>2]=c[X+4>>2];c[P+8>>2]=c[X+8>>2];c[P+12>>2]=c[X+12>>2];c[P+16>>2]=c[X+16>>2];c[P+20>>2]=c[X+20>>2];if((c[Y>>2]|0)!=0){Y=h+13980|0;X=f+13980|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=c[X+4>>2];c[Y+8>>2]=c[X+8>>2];c[Y+12>>2]=c[X+12>>2];c[Y+16>>2]=c[X+16>>2];c[Y+20>>2]=c[X+20>>2];X=h+13956|0;Y=f+13956|0;c[X>>2]=c[Y>>2];c[X+4>>2]=c[Y+4>>2];c[X+8>>2]=c[Y+8>>2];c[X+12>>2]=c[Y+12>>2];c[X+16>>2]=c[Y+16>>2];c[X+20>>2]=c[Y+20>>2]}c[h+14340>>2]=c[W>>2];c[h+180>>2]=c[f+180>>2];c[h+184>>2]=c[f+184>>2];c[h+188>>2]=c[f+188>>2];c[h+192>>2]=c[f+192>>2];c[h+196>>2]=c[f+196>>2];c[h+200>>2]=c[f+200>>2];c[h+204>>2]=c[f+204>>2];c[h+208>>2]=c[f+208>>2];c[h+14236>>2]=c[f+14236>>2];c[h+9960>>2]=c[R>>2];c[h+14100>>2]=c[V>>2];i=q;return}function zPa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;g=0;do{h=g-1|0;i=(h|0)>0?h:0;h=g+2|0;j=(h|0)<8?h:8;h=(i|0)<(j|0);k=g<<3;l=0;m=-3;n=-1;while(1){o=(m|0)>-9;p=(n|0)>0?n:0;do{if(h){q=l-1|0;r=(q|0)>0?q:0;q=l+2|0;s=(q|0)<8?q:8;if((r|0)>=(s|0)){t=0;u=0;v=0;break}q=(o?~m:8)-p|0;w=i;x=0;y=0;z=0;while(1){A=ba(w,f)|0;B=r;C=x;D=y;do{E=d[e+(B+A)|0]|0;C=E+C|0;D=(ba(E,E)|0)+D|0;B=B+1|0;}while((B|0)<(s|0));B=q+z|0;A=w+1|0;if((A|0)<(j|0)){w=A;x=C;y=D;z=B}else{t=C;u=D;v=B;break}}}else{t=0;u=0;v=0}}while(0);p=(ba(v,u)|0)-(ba(t,t)|0)|0;if(p>>>0<255>>>0){G=(d[p+1135649|0]|0)-1>>4}else{do{if(p>>>0<4096>>>0){H=(d[1135648+(p>>>4)|0]|0)>>>2}else{if(p>>>0<16384>>>0){H=(d[1135648+(p>>>6)|0]|0)>>>1;break}if(p>>>0<65536>>>0){H=d[1135648+(p>>>8)|0]|0;break}else{o=p>>>16;z=(o&65280|0)==0;y=((d[1191992+(z?o:p>>>24)|0]|0)+(z?0:8)|0)>>>1;z=p>>>((y+2|0)>>>0);o=d[1135648+(z>>>((y+8|0)>>>0))|0]|0;gHb(z,0,c[1199552+(o<<2)>>2]|0,0)|0;H=F+(o<<y)|0;break}}}while(0);G=H-((ba(H,H)|0)>>>0>p>>>0)|0}b[a+(l+k<<1)>>1]=((G*36|0)>>>0)/(v>>>0)|0;y=l+1|0;if((y|0)<8){l=y;m=m-1|0;n=n+1|0}else{break}}g=g+1|0;}while((g|0)<8);return}function APa(e,f,g,h,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;n=i;i=i+112|0;o=n|0;p=n+24|0;q=n+88|0;r=(c[e+28>>2]|0)==0;s=e+12480|0;t=c[s>>2]|0;u=e+13924|0;v=(c[u>>2]|0)!=0?2:1;w=e+11744+(j<<5)|0;x=e+12476|0;y=c[x>>2]|0;z=(y<<4|8)+(c[w>>2]>>v)|0;A=e+11744+(j<<5)+4|0;B=(c[A>>2]>>v)+(t<<4)|0;v=e+148|0;C=c[v>>2]|0;D=z+64+(ba(B+(y<<2&12)|0,C)|0)|0;y=e+11544|0;Xe[c[y>>2]&4095]((c[k>>2]|0)+D|0,C,4);C=e+152|0;D=(z>>1)+64+(ba((c[x>>2]&7)+(B>>1)|0,c[C>>2]|0)|0)|0;B=k+4|0;z=c[B>>2]|0;E=k+8|0;Xe[c[y>>2]&4095](z+D|0,(c[E>>2]|0)-z|0,2);if(r){r=c[e+11740>>2]|0;if((r|0)==2){z=e+14172|0;D=e+9856|0;y=t>>1;F=e+14220|0;G=e+9992|0;H=e+14240|0;I=c[e+11808+(j<<3)>>2]|0;do{if((c[z>>2]|0)==(I+1|0)){J=40}else{if((c[G>>2]|0)==3){J=40;break}if((c[H>>2]|0)==0){J=41}else{J=40}}}while(0);if((J|0)==40){if((c[k>>2]|0)==0){J=41}else{K=k}}if((J|0)==41){K=c[D>>2]|0}CPa(e,f,g,h,I,K,l,c[w>>2]|0,c[A>>2]|0,8,y);K=f+(c[v>>2]<<4)|0;I=ba(16>>>((c[F>>2]|0)>>>0),c[C>>2]|0)|0;F=g+I|0;L=h+I|0;I=c[e+11808+(j<<3)+4>>2]|0;do{if((c[z>>2]|0)==(I+1|0)){J=54}else{if((c[G>>2]|0)==3){J=54;break}if((c[H>>2]|0)==0){J=55}else{J=54}}}while(0);if((J|0)==54){if((c[k>>2]|0)==0){J=55}else{M=k}}if((J|0)==55){M=c[D>>2]|0}CPa(e,K,F,L,I,M,l,c[e+11744+(j<<5)+8>>2]|0,(c[e+11744+(j<<5)+12>>2]|0)+16|0,8,y);i=n;return}else if((r|0)==0){if((c[e+13916>>2]|0)==0){CPa(e,f,g,h,0,k,l,c[w>>2]|0,c[A>>2]|0,16,t);i=n;return}if((c[e+13880>>2]|0)!=1){y=c[e+13932>>2]|0;M=c[v>>2]|0;I=c[C>>2]|0;L=c[k>>2]|0;F=e+13900|0;K=c[F>>2]|0;D=c[x>>2]|0;H=ba(D,K)|0;G=e+13904|0;z=c[G>>2]|0;N=c[s>>2]|0;O=((ba(N,z)|0)+H<<4)+(c[e+13884>>2]|0)|0;H=e+13908|0;P=c[H>>2]|0;Q=ba(P,D)|0;D=e+13912|0;R=c[D>>2]|0;S=((ba(R,N)|0)+Q<<4)+(c[e+13888>>2]|0)|0;Q=e+10088|0;N=y+1|0;T=1<<(y<<1|1);y=e+12472|0;U=e+136|0;V=e+140|0;Ie[c[Q>>2]&3](f,L,M,16,O,S,K,z,P,R,N,T-(c[y>>2]|0)|0,c[U>>2]|0,c[V>>2]|0);R=c[F>>2]|0;P=c[H>>2]|0;Ie[c[Q>>2]&3](f+8|0,L,M,16,(R<<3)+O|0,(P<<3)+S|0,R,c[G>>2]|0,P,c[D>>2]|0,N,T-(c[y>>2]|0)|0,c[U>>2]|0,c[V>>2]|0);P=c[F>>2]|0;R=c[x>>2]|0;S=ba(R,P)|0;O=c[G>>2]|0;M=c[s>>2]|0;L=((ba(M,O)|0)+S<<3)+(c[e+13892>>2]|0)|0;S=c[H>>2]|0;z=ba(S,R)|0;R=c[D>>2]|0;K=((ba(R,M)|0)+z<<3)+(c[e+13896>>2]|0)|0;Ie[c[Q>>2]&3](g,c[B>>2]|0,I,8,L,K,P,O,S,R,N,T-(c[y>>2]|0)|0,c[U>>2]>>1,c[V>>2]>>1);Ie[c[Q>>2]&3](h,c[E>>2]|0,I,8,L,K,c[F>>2]|0,c[G>>2]|0,c[H>>2]|0,c[D>>2]|0,N,T-(c[y>>2]|0)|0,c[U>>2]>>1,c[V>>2]>>1);i=n;return}V=c[e+13884>>2]|0;U=c[e+13888>>2]|0;y=e+13932|0;T=c[y>>2]|0;N=T+1|0;D=(V>>N)+(c[x>>2]<<4)|0;H=(c[s>>2]<<4)+(U>>N)|0;N=3-T|0;T=e+8|0;G=c[T>>2]|0;if((D|0)<-16){W=-16}else{W=(D|0)>(G|0)?G:D}D=(W|0)==(G|0)?0:V<<N;V=e+12|0;G=c[V>>2]|0;if((H|0)<-16){X=-16}else{X=(H|0)>(G|0)?G:H}H=(X|0)==(G|0)?0:U<<N;N=c[v>>2]|0;U=c[C>>2]|0;G=(c[k>>2]|0)+((ba(N,X)|0)+W)|0;F=e+136|0;K=c[F>>2]|0;L=K-17|0;I=e+140|0;Q=c[I>>2]|0;if(W>>>0<((L|0)>0?L:0)>>>0){L=Q-17|0;if(X>>>0<((L|0)>0?L:0)>>>0){Y=G}else{J=12}}else{J=12}if((J|0)==12){L=e+9944|0;Ne[c[e+11540>>2]&127](c[L>>2]|0,G,N,N,17,17,W,X,K,Q);Y=c[L>>2]|0}do{if(((H|D)&7|0)==0){L=H>>>2&2|D>>>3&1;if((c[e+12472>>2]|0)==0){cf[c[e+11332+(L<<2)>>2]&1023](f,Y,N,16);break}else{cf[c[e+11460+(L<<2)>>2]&1023](f,Y,N,16);break}}else{L=e+10084|0;Q=D&15;K=H&15;X=e+12472|0;Ke[c[L>>2]&1023](f,Y,N,16,Q,K,128-(c[X>>2]|0)|0);Ke[c[L>>2]&1023](f+8|0,Y+8|0,N,16,Q,K,128-(c[X>>2]|0)|0)}}while(0);N=c[e+13892>>2]|0;Y=c[e+13896>>2]|0;H=c[y>>2]|0;y=H+1|0;D=(N>>y)+(c[x>>2]<<3)|0;X=(c[s>>2]<<3)+(Y>>y)|0;y=3-H|0;H=N<<y;N=Y<<y;y=c[T>>2]>>1;if((D|0)<-8){Z=-8}else{Z=(D|0)>(y|0)?y:D}D=(Z|0)==(y|0);y=c[V>>2]>>1;if((X|0)<-8){_=-8}else{_=(X|0)>(y|0)?y:X}X=(_|0)==(y|0);y=(ba(_,U)|0)+Z|0;V=(c[B>>2]|0)+y|0;T=c[F>>2]>>1;Y=T-9|0;K=c[I>>2]>>1;if(Z>>>0<((Y|0)>0?Y:0)>>>0){Y=K-9|0;if(_>>>0<((Y|0)>0?Y:0)>>>0){$=V;aa=0}else{J=24}}else{J=24}if((J|0)==24){Y=e+9944|0;Ne[c[e+11540>>2]&127](c[Y>>2]|0,V,U,U,9,9,Z,_,T,K);$=c[Y>>2]|0;aa=1}Y=e+10084|0;K=D?0:H&15;H=X?0:N&15;N=e+12472|0;Ke[c[Y>>2]&1023](g,$,U,8,K,H,128-(c[N>>2]|0)|0);$=(c[E>>2]|0)+y|0;if(aa){aa=e+9944|0;Ne[c[e+11540>>2]&127](c[aa>>2]|0,$,U,U,9,9,Z,_,c[F>>2]>>1,c[I>>2]>>1);ca=c[aa>>2]|0}else{ca=$}Ke[c[Y>>2]&1023](h,ca,U,8,K,H,128-(c[N>>2]|0)|0);i=n;return}else if((r|0)==3){N=c[e+14172>>2]|0;H=c[e+11808+(j<<3)>>2]|0;if((N|0)==3){DPa(e,f,g,h,0,H,k,l,c[w>>2]|0,c[A>>2]|0,t);DPa(e,f,g,h,1,c[e+11808+(j<<3)+4>>2]|0,k,l,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,t);i=n;return}do{if((N|0)==(H+1|0)){J=35}else{if((c[e+9992>>2]|0)==3){J=35;break}if((c[e+14240>>2]|0)==0){J=36}else{J=35}}}while(0);if((J|0)==35){if((c[k>>2]|0)==0){J=36}else{da=k}}if((J|0)==36){da=c[e+9856>>2]|0}CPa(e,f,g,h,H,da,l,c[w>>2]|0,c[A>>2]|0,16,t>>1);i=n;return}else if((r|0)==4){r=e+14172|0;if((c[r>>2]|0)==3){da=e+11396|0;DPa(e,f,g,h,0,0,k,l,c[w>>2]|0,c[A>>2]|0,t);DPa(e,f,g,h,1,1,k,l,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,t);DPa(e,f,g,h,0,1,k,da,c[e+11744+(j<<5)+16>>2]|0,c[e+11744+(j<<5)+20>>2]|0,t);DPa(e,f,g,h,1,0,k,da,c[e+11744+(j<<5)+24>>2]|0,c[e+11744+(j<<5)+28>>2]|0,t);i=n;return}da=e+9856|0;if((c[k>>2]|0)==0){ea=c[da>>2]|0}else{ea=k}H=t>>1;N=e+11396|0;K=e+14240|0;U=0;ca=l;Y=ea;a:while(1){ea=U;$=ca;while(1){if((ea|0)>=2){break a}fa=ea+1|0;aa=ea<<1;CPa(e,f,g,h,(c[r>>2]|0)!=(fa|0)|0,Y,$,c[e+11744+(j<<5)+(aa<<3)>>2]|0,c[e+11744+(j<<5)+(aa<<3)+4>>2]|0,16,H);if((c[K>>2]|0)==0){break}else{ea=fa;$=N}}U=fa;ca=N;Y=c[da>>2]|0}i=n;return}else{i=n;return}}do{if((c[e+13788>>2]|0)!=0){if((c[e+9992>>2]|0)==3){break}da=c[x>>2]|0;Y=c[s>>2]|0;N=c[e+124>>2]|0;ca=(ba(N,Y)|0)+da|0;fa=c[e+128>>2]|0;U=(ba(Y<<1,fa)|0)+(da<<1)|0;K=c[e+9148>>2]|0;H=c[K+(U<<2)>>2]|0;r=p+16|0;c[p+20>>2]=H;$=c[K+((U|1)<<2)>>2]|0;c[p+24>>2]=$;ea=U+fa|0;aa=K+(ea<<2)|0;I=c[aa>>2]|0;F=p+32|0;c[p+36>>2]=I;_=K+(ea+1<<2)|0;ea=c[_>>2]|0;c[p+40>>2]=ea;c[p+52>>2]=c[aa>>2];c[p+56>>2]=c[_>>2];do{if((Y|0)==0){J=61}else{if((c[(c[e+9160>>2]|0)+(ca-N<<2)>>2]&7|0)!=0){J=61;break}_=U-fa|0;c[p+4>>2]=c[K+(_<<2)>>2];c[p+8>>2]=c[K+(_+1<<2)>>2]}}while(0);if((J|0)==61){c[p+4>>2]=H;c[p+8>>2]=$}do{if((da|0)==0){J=65}else{if((c[(c[e+9160>>2]|0)+(ca-1<<2)>>2]&7|0)!=0){J=65;break}N=U-1|0;c[r>>2]=c[K+(N<<2)>>2];c[F>>2]=c[K+(N+fa<<2)>>2]}}while(0);if((J|0)==65){c[r>>2]=H;c[F>>2]=I}do{if((da+1|0)<(c[e+116>>2]|0)){if((c[(c[e+9160>>2]|0)+(ca+1<<2)>>2]&7|0)!=0){J=69;break}N=U+2|0;c[p+28>>2]=c[K+(N<<2)>>2];c[p+44>>2]=c[K+(N+fa<<2)>>2]}else{J=69}}while(0);if((J|0)==69){c[p+28>>2]=$;c[p+44>>2]=ea}fa=q|0;K=q+2|0;U=q+4|0;ca=q+6|0;I=q+8|0;F=q+10|0;H=q+12|0;r=q+14|0;N=q+16|0;_=q+18|0;aa=da<<4;Z=Y<<4;y=e+9952|0;X=e+8|0;D=e+12|0;T=e+136|0;V=e+140|0;Q=e+11540|0;L=e+9944|0;W=o|0;G=o+4|0;R=o+8|0;S=o+12|0;O=o+16|0;P=0;z=0;M=0;do{ga=P&1;ha=ga+1|0;ia=P>>1;ja=ia+1|0;ka=b[p+(ja<<4)+(ha<<2)>>1]|0;b[fa>>1]=ka;la=b[p+(ja<<4)+(ha<<2)+2>>1]|0;b[K>>1]=la;b[U>>1]=b[p+(ia<<4)+(ha<<2)>>1]|0;b[ca>>1]=b[p+(ia<<4)+(ha<<2)+2>>1]|0;b[I>>1]=b[p+(ja<<4)+(ga<<2)>>1]|0;b[F>>1]=b[p+(ja<<4)+(ga<<2)+2>>1]|0;ma=ga|2;b[H>>1]=b[p+(ja<<4)+(ma<<2)>>1]|0;b[r>>1]=b[p+(ja<<4)+(ma<<2)+2>>1]|0;ma=ia+2|0;b[N>>1]=b[p+(ma<<4)+(ha<<2)>>1]|0;b[_>>1]=b[p+(ma<<4)+(ha<<2)+2>>1]|0;ha=ga<<3;ga=ia<<3;ia=c[v>>2]|0;ma=c[k>>2]|0;ja=ha|aa;na=ga+Z|0;oa=0;do{do{if((oa|0)==0){pa=ka;J=77}else{qa=b[q+(oa<<2)>>1]|0;if(!(qa<<16>>16==ka<<16>>16)){pa=qa;J=77;break}if(!((b[q+(oa<<2)+2>>1]|0)==la<<16>>16)){pa=ka;J=77;break}c[o+(oa<<2)>>2]=c[W>>2]}}while(0);if((J|0)==77){J=0;qa=c[v>>2]|0;ra=(c[y>>2]|0)+((ba(oa>>>1<<3,qa)|0)+(oa<<3&8))|0;c[o+(oa<<2)>>2]=ra;sa=pa<<16>>16;ta=b[q+(oa<<2)+2>>1]|0;ua=(sa>>1)+ja|0;va=na+(ta>>1)|0;wa=c[X>>2]|0;if((ua|0)<-16){xa=-16}else{xa=(ua|0)>(wa|0)?wa:ua}ua=sa&1;sa=(xa|0)==(wa|0)?0:ua;wa=c[D>>2]|0;if((va|0)<-16){ya=-16}else{ya=(va|0)>(wa|0)?wa:va}if((ya|0)==(wa|0)){za=sa}else{za=sa|ta<<1&2}sa=ma+((ba(ya,qa)|0)+xa)|0;wa=c[T>>2]|0;va=wa-ua-8|0;ua=c[V>>2]|0;if(xa>>>0>((va|0)>0?va:0)>>>0){J=85}else{va=ua-(ta&1)-8|0;if(ya>>>0>((va|0)>0?va:0)>>>0){J=85}else{Aa=sa;Ba=qa}}if((J|0)==85){J=0;Ne[c[Q>>2]&127](c[L>>2]|0,sa,qa,qa,9,9,xa,ya,wa,ua);Aa=c[L>>2]|0;Ba=c[v>>2]|0}cf[c[l+16+(za<<2)>>2]&1023](ra,Aa,Ba,8)}oa=oa+1|0;}while((oa|0)<5);oa=(ba(ia,ga)|0)+ha|0;ma=c[v>>2]|0;na=c[G>>2]|0;ja=c[R>>2]|0;ka=c[W>>2]|0;la=c[S>>2]|0;ra=c[O>>2]|0;a[f+oa|0]=((d[ka]<<2)+4+((d[ja]|0)+(d[na]|0)<<1)|0)>>>3;a[f+(oa|1)|0]=((d[ja+1|0]|0)+4+(d[na+1|0]<<1)+((d[ka+1|0]|0)*5|0)|0)>>>3;a[f+(oa|2)|0]=((d[ja+2|0]|0)+4+(d[na+2|0]<<1)+((d[ka+2|0]|0)*5|0)|0)>>>3;a[f+(oa|3)|0]=((d[ja+3|0]|0)+4+(d[na+3|0]<<1)+((d[ka+3|0]|0)*5|0)|0)>>>3;ua=ma+2|0;a[f+(ua+oa)|0]=((d[ja+ua|0]|0)+4+(d[na+ua|0]<<1)+((d[ka+ua|0]|0)*5|0)|0)>>>3;ua=ma+3|0;a[f+(ua+oa)|0]=((d[ja+ua|0]|0)+4+(d[na+ua|0]<<1)+((d[ka+ua|0]|0)*5|0)|0)>>>3;a[f+(oa|4)|0]=((d[na+4|0]<<1)+4+((d[ka+4|0]|0)*5|0)+(d[la+4|0]|0)|0)>>>3;a[f+(oa|5)|0]=((d[na+5|0]<<1)+4+((d[ka+5|0]|0)*5|0)+(d[la+5|0]|0)|0)>>>3;ua=ma+4|0;a[f+(ua+oa)|0]=((d[na+ua|0]<<1)+4+((d[ka+ua|0]|0)*5|0)+(d[la+ua|0]|0)|0)>>>3;ua=ma+5|0;a[f+(ua+oa)|0]=((d[na+ua|0]<<1)+4+((d[ka+ua|0]|0)*5|0)+(d[la+ua|0]|0)|0)>>>3;a[f+(oa|6)|0]=((d[na+6|0]<<1)+4+((d[ka+6|0]|0)*5|0)+(d[la+6|0]|0)|0)>>>3;a[f+(oa|7)|0]=((d[ka+7|0]<<2)+4+((d[la+7|0]|0)+(d[na+7|0]|0)<<1)|0)>>>3;a[f+(ma+oa)|0]=((d[na+ma|0]|0)+4+(d[ja+ma|0]<<1)+((d[ka+ma|0]|0)*5|0)|0)>>>3;ua=ma+1|0;a[f+(ua+oa)|0]=((d[na+ua|0]|0)+4+(d[ja+ua|0]<<1)+((d[ka+ua|0]|0)*5|0)|0)>>>3;ua=ma+6|0;a[f+(ua+oa)|0]=((d[na+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[la+ua|0]<<1)|0)>>>3;ua=ma+7|0;a[f+(ua+oa)|0]=((d[na+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[la+ua|0]<<1)|0)>>>3;ua=ma<<1;a[f+(ua+oa)|0]=((d[na+ua|0]|0)+4+(d[ja+ua|0]<<1)+((d[ka+ua|0]|0)*5|0)|0)>>>3;wa=ua|1;a[f+(wa+oa)|0]=((d[na+wa|0]|0)+4+(d[ja+wa|0]<<1)+((d[ka+wa|0]|0)*5|0)|0)>>>3;qa=ua+ma|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+(d[ja+qa|0]<<1)+((d[ka+qa|0]|0)*5|0)|0)>>>3;qa=wa+ma|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+(d[ja+qa|0]<<1)+((d[ka+qa|0]|0)*5|0)|0)>>>3;qa=ua+2|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+(d[ja+qa|0]|0)+((d[ka+qa|0]|0)*6|0)|0)>>>3;wa=ua+3|0;a[f+(wa+oa)|0]=((d[na+wa|0]|0)+4+(d[ja+wa|0]|0)+((d[ka+wa|0]|0)*6|0)|0)>>>3;sa=qa+ma|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+(d[ja+sa|0]|0)+((d[ka+sa|0]|0)*6|0)|0)>>>3;sa=wa+ma|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+(d[ja+sa|0]|0)+((d[ka+sa|0]|0)*6|0)|0)>>>3;sa=ua+4|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+((d[ka+sa|0]|0)*6|0)+(d[la+sa|0]|0)|0)>>>3;wa=ua+5|0;a[f+(wa+oa)|0]=((d[na+wa|0]|0)+4+((d[ka+wa|0]|0)*6|0)+(d[la+wa|0]|0)|0)>>>3;qa=sa+ma|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[la+qa|0]|0)|0)>>>3;qa=wa+ma|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[la+qa|0]|0)|0)>>>3;qa=ua+6|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+((d[ka+qa|0]|0)*5|0)+(d[la+qa|0]<<1)|0)>>>3;wa=ua+7|0;a[f+(wa+oa)|0]=((d[na+wa|0]|0)+4+((d[ka+wa|0]|0)*5|0)+(d[la+wa|0]<<1)|0)>>>3;sa=qa+ma|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+((d[ka+sa|0]|0)*5|0)+(d[la+sa|0]<<1)|0)>>>3;sa=wa+ma|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+((d[ka+sa|0]|0)*5|0)+(d[la+sa|0]<<1)|0)>>>3;sa=ma<<2;a[f+(sa+oa)|0]=((d[ja+sa|0]<<1)+4+((d[ka+sa|0]|0)*5|0)+(d[ra+sa|0]|0)|0)>>>3;na=sa|1;a[f+(na+oa)|0]=((d[ja+na|0]<<1)+4+((d[ka+na|0]|0)*5|0)+(d[ra+na|0]|0)|0)>>>3;wa=sa+ma|0;a[f+(wa+oa)|0]=((d[ja+wa|0]<<1)+4+((d[ka+wa|0]|0)*5|0)+(d[ra+wa|0]|0)|0)>>>3;wa=na+ma|0;a[f+(wa+oa)|0]=((d[ja+wa|0]<<1)+4+((d[ka+wa|0]|0)*5|0)+(d[ra+wa|0]|0)|0)>>>3;wa=sa|2;a[f+(wa+oa)|0]=((d[ja+wa|0]|0)+4+((d[ka+wa|0]|0)*6|0)+(d[ra+wa|0]|0)|0)>>>3;na=sa|3;a[f+(na+oa)|0]=((d[ja+na|0]|0)+4+((d[ka+na|0]|0)*6|0)+(d[ra+na|0]|0)|0)>>>3;qa=wa+ma|0;a[f+(qa+oa)|0]=((d[ja+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[ra+qa|0]|0)|0)>>>3;qa=na+ma|0;a[f+(qa+oa)|0]=((d[ja+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[ra+qa|0]|0)|0)>>>3;qa=sa+4|0;a[f+(qa+oa)|0]=((d[la+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[ra+qa|0]|0)|0)>>>3;na=sa+5|0;a[f+(na+oa)|0]=((d[la+na|0]|0)+4+((d[ka+na|0]|0)*6|0)+(d[ra+na|0]|0)|0)>>>3;wa=qa+ma|0;a[f+(wa+oa)|0]=((d[la+wa|0]|0)+4+((d[ka+wa|0]|0)*6|0)+(d[ra+wa|0]|0)|0)>>>3;wa=na+ma|0;a[f+(wa+oa)|0]=((d[la+wa|0]|0)+4+((d[ka+wa|0]|0)*6|0)+(d[ra+wa|0]|0)|0)>>>3;wa=sa+6|0;a[f+(wa+oa)|0]=(((d[ka+wa|0]|0)*5|0)+4+(d[la+wa|0]<<1)+(d[ra+wa|0]|0)|0)>>>3;na=sa+7|0;a[f+(na+oa)|0]=(((d[ka+na|0]|0)*5|0)+4+(d[la+na|0]<<1)+(d[ra+na|0]|0)|0)>>>3;qa=wa+ma|0;a[f+(qa+oa)|0]=(((d[ka+qa|0]|0)*5|0)+4+(d[la+qa|0]<<1)+(d[ra+qa|0]|0)|0)>>>3;qa=na+ma|0;a[f+(qa+oa)|0]=(((d[ka+qa|0]|0)*5|0)+4+(d[la+qa|0]<<1)+(d[ra+qa|0]|0)|0)>>>3;qa=sa+ua|0;a[f+(qa+oa)|0]=((d[ja+qa|0]<<1)+4+((d[ka+qa|0]|0)*5|0)+(d[ra+qa|0]|0)|0)>>>3;ua=qa|1;a[f+(ua+oa)|0]=((d[ja+ua|0]<<1)+4+((d[ka+ua|0]|0)*5|0)+(d[ra+ua|0]|0)|0)>>>3;ua=qa+2|0;a[f+(ua+oa)|0]=((d[ja+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[ra+ua|0]<<1)|0)>>>3;sa=qa+3|0;a[f+(sa+oa)|0]=((d[ja+sa|0]|0)+4+((d[ka+sa|0]|0)*5|0)+(d[ra+sa|0]<<1)|0)>>>3;na=ua+ma|0;a[f+(na+oa)|0]=((d[ja+na|0]|0)+4+((d[ka+na|0]|0)*5|0)+(d[ra+na|0]<<1)|0)>>>3;na=sa+ma|0;a[f+(na+oa)|0]=((d[ja+na|0]|0)+4+((d[ka+na|0]|0)*5|0)+(d[ra+na|0]<<1)|0)>>>3;na=qa+4|0;a[f+(na+oa)|0]=((d[la+na|0]|0)+4+((d[ka+na|0]|0)*5|0)+(d[ra+na|0]<<1)|0)>>>3;sa=qa+5|0;a[f+(sa+oa)|0]=((d[la+sa|0]|0)+4+((d[ka+sa|0]|0)*5|0)+(d[ra+sa|0]<<1)|0)>>>3;ua=na+ma|0;a[f+(ua+oa)|0]=((d[la+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[ra+ua|0]<<1)|0)>>>3;ua=sa+ma|0;a[f+(ua+oa)|0]=((d[la+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[ra+ua|0]<<1)|0)>>>3;ua=qa+6|0;a[f+(ua+oa)|0]=(((d[ka+ua|0]|0)*5|0)+4+(d[la+ua|0]<<1)+(d[ra+ua|0]|0)|0)>>>3;ua=qa+7|0;a[f+(ua+oa)|0]=(((d[ka+ua|0]|0)*5|0)+4+(d[la+ua|0]<<1)+(d[ra+ua|0]|0)|0)>>>3;ua=qa+ma|0;a[f+(ua+oa)|0]=((d[ka+ua|0]<<2)+4+((d[ra+ua|0]|0)+(d[ja+ua|0]|0)<<1)|0)>>>3;ma=ua+1|0;a[f+(ma+oa)|0]=((d[ja+ma|0]|0)+4+((d[ka+ma|0]|0)*5|0)+(d[ra+ma|0]<<1)|0)>>>3;ma=ua+6|0;a[f+(ma+oa)|0]=((d[la+ma|0]|0)+4+((d[ka+ma|0]|0)*5|0)+(d[ra+ma|0]<<1)|0)>>>3;ma=ua+7|0;a[f+(ma+oa)|0]=((d[ka+ma|0]<<2)+4+((d[ra+ma|0]|0)+(d[la+ma|0]|0)<<1)|0)>>>3;M=(b[fa>>1]|0)+M|0;z=(b[K>>1]|0)+z|0;P=P+1|0;}while((P|0)<4);EPa(e,g,h,k,l+16|0,M,z);i=n;return}}while(0);switch(c[e+11740>>2]|0){case 2:{Ba=e+14172|0;Aa=e+9856|0;za=t>>1;ya=e+14220|0;xa=e+9992|0;q=e+14240|0;pa=c[e+11808+(j<<3)>>2]|0;do{if((c[Ba>>2]|0)==(pa+1|0)){J=157}else{if((c[xa>>2]|0)==3){J=157;break}if((c[q>>2]|0)==0){J=158}else{J=157}}}while(0);if((J|0)==157){if((c[k>>2]|0)==0){J=158}else{Ca=k}}if((J|0)==158){Ca=c[Aa>>2]|0}CPa(e,f,g,h,pa,Ca,l,c[w>>2]|0,c[A>>2]|0,8,za);Ca=f+(c[v>>2]<<4)|0;pa=ba(16>>>((c[ya>>2]|0)>>>0),c[C>>2]|0)|0;ya=g+pa|0;o=h+pa|0;pa=c[e+11808+(j<<3)+4>>2]|0;do{if((c[Ba>>2]|0)==(pa+1|0)){J=171}else{if((c[xa>>2]|0)==3){J=171;break}if((c[q>>2]|0)==0){J=172}else{J=171}}}while(0);if((J|0)==171){if((c[k>>2]|0)==0){J=172}else{Da=k}}if((J|0)==172){Da=c[Aa>>2]|0}CPa(e,Ca,ya,o,pa,Da,l,c[e+11744+(j<<5)+8>>2]|0,(c[e+11744+(j<<5)+12>>2]|0)+16|0,8,za);i=n;return};case 0:{if((c[e+13916>>2]|0)==0){if((c[u>>2]|0)!=0){BPa(e,f,g,h,0,0,0,k,l,m,c[w>>2]|0,c[A>>2]|0,16);i=n;return}do{if((c[e+14116>>2]|0)!=0){if((c[e+48>>2]|0)!=19){break}Ucb(e,f,g,h,k,l,c[w>>2]|0,c[A>>2]|0,16);i=n;return}}while(0);CPa(e,f,g,h,0,k,l,c[w>>2]|0,c[A>>2]|0,16,t);i=n;return}if((c[e+13880>>2]|0)!=1){za=c[e+13932>>2]|0;Da=c[v>>2]|0;pa=c[C>>2]|0;o=c[k>>2]|0;ya=e+13900|0;Ca=c[ya>>2]|0;Aa=c[x>>2]|0;q=ba(Aa,Ca)|0;xa=e+13904|0;Ba=c[xa>>2]|0;p=c[s>>2]|0;P=((ba(p,Ba)|0)+q<<4)+(c[e+13884>>2]|0)|0;q=e+13908|0;K=c[q>>2]|0;fa=ba(K,Aa)|0;Aa=e+13912|0;O=c[Aa>>2]|0;S=((ba(O,p)|0)+fa<<4)+(c[e+13888>>2]|0)|0;fa=e+10088|0;p=za+1|0;W=1<<(za<<1|1);za=e+12472|0;R=e+136|0;G=e+140|0;Ie[c[fa>>2]&3](f,o,Da,16,P,S,Ca,Ba,K,O,p,W-(c[za>>2]|0)|0,c[R>>2]|0,c[G>>2]|0);O=c[ya>>2]|0;K=c[q>>2]|0;Ie[c[fa>>2]&3](f+8|0,o,Da,16,(O<<3)+P|0,(K<<3)+S|0,O,c[xa>>2]|0,K,c[Aa>>2]|0,p,W-(c[za>>2]|0)|0,c[R>>2]|0,c[G>>2]|0);K=c[ya>>2]|0;O=c[x>>2]|0;S=ba(O,K)|0;P=c[xa>>2]|0;Da=c[s>>2]|0;o=((ba(Da,P)|0)+S<<3)+(c[e+13892>>2]|0)|0;S=c[q>>2]|0;Ba=ba(S,O)|0;O=c[Aa>>2]|0;Ca=((ba(O,Da)|0)+Ba<<3)+(c[e+13896>>2]|0)|0;Ie[c[fa>>2]&3](g,c[B>>2]|0,pa,8,o,Ca,K,P,S,O,p,W-(c[za>>2]|0)|0,c[R>>2]>>1,c[G>>2]>>1);Ie[c[fa>>2]&3](h,c[E>>2]|0,pa,8,o,Ca,c[ya>>2]|0,c[xa>>2]|0,c[q>>2]|0,c[Aa>>2]|0,p,W-(c[za>>2]|0)|0,c[R>>2]>>1,c[G>>2]>>1);i=n;return}G=c[e+13884>>2]|0;R=c[e+13888>>2]|0;za=e+13932|0;W=c[za>>2]|0;p=W+1|0;Aa=(G>>p)+(c[x>>2]<<4)|0;q=(c[s>>2]<<4)+(R>>p)|0;p=3-W|0;W=e+8|0;xa=c[W>>2]|0;if((Aa|0)<-16){Ea=-16}else{Ea=(Aa|0)>(xa|0)?xa:Aa}Aa=(Ea|0)==(xa|0)?0:G<<p;G=e+12|0;xa=c[G>>2]|0;if((q|0)<-16){Fa=-16}else{Fa=(q|0)>(xa|0)?xa:q}q=(Fa|0)==(xa|0)?0:R<<p;p=c[v>>2]|0;R=c[C>>2]|0;C=(c[k>>2]|0)+((ba(p,Fa)|0)+Ea)|0;xa=e+136|0;ya=c[xa>>2]|0;Ca=ya-17|0;o=e+140|0;pa=c[o>>2]|0;if(Ea>>>0<((Ca|0)>0?Ca:0)>>>0){Ca=pa-17|0;if(Fa>>>0<((Ca|0)>0?Ca:0)>>>0){Ga=C}else{J=100}}else{J=100}if((J|0)==100){Ca=e+9944|0;Ne[c[e+11540>>2]&127](c[Ca>>2]|0,C,p,p,17,17,Ea,Fa,ya,pa);Ga=c[Ca>>2]|0}do{if(((q|Aa)&7|0)==0){Ca=q>>>2&2|Aa>>>3&1;if((c[e+12472>>2]|0)==0){cf[c[e+11332+(Ca<<2)>>2]&1023](f,Ga,p,16);break}else{cf[c[e+11460+(Ca<<2)>>2]&1023](f,Ga,p,16);break}}else{Ca=e+10084|0;pa=Aa&15;ya=q&15;Fa=e+12472|0;Ke[c[Ca>>2]&1023](f,Ga,p,16,pa,ya,128-(c[Fa>>2]|0)|0);Ke[c[Ca>>2]&1023](f+8|0,Ga+8|0,p,16,pa,ya,128-(c[Fa>>2]|0)|0)}}while(0);p=c[e+13892>>2]|0;Ga=c[e+13896>>2]|0;q=c[za>>2]|0;za=q+1|0;Aa=(p>>za)+(c[x>>2]<<3)|0;Fa=(c[s>>2]<<3)+(Ga>>za)|0;za=3-q|0;q=p<<za;p=Ga<<za;za=c[W>>2]>>1;if((Aa|0)<-8){Ha=-8}else{Ha=(Aa|0)>(za|0)?za:Aa}Aa=(Ha|0)==(za|0);za=c[G>>2]>>1;if((Fa|0)<-8){Ia=-8}else{Ia=(Fa|0)>(za|0)?za:Fa}Fa=(Ia|0)==(za|0);za=(ba(Ia,R)|0)+Ha|0;G=(c[B>>2]|0)+za|0;B=c[xa>>2]>>1;W=B-9|0;Ga=c[o>>2]>>1;if(Ha>>>0<((W|0)>0?W:0)>>>0){W=Ga-9|0;if(Ia>>>0<((W|0)>0?W:0)>>>0){Ja=G;Ka=0}else{J=112}}else{J=112}if((J|0)==112){W=e+9944|0;Ne[c[e+11540>>2]&127](c[W>>2]|0,G,R,R,9,9,Ha,Ia,B,Ga);Ja=c[W>>2]|0;Ka=1}W=e+10084|0;Ga=Aa?0:q&15;q=Fa?0:p&15;p=e+12472|0;Ke[c[W>>2]&1023](g,Ja,R,8,Ga,q,128-(c[p>>2]|0)|0);Ja=(c[E>>2]|0)+za|0;if(Ka){Ka=e+9944|0;Ne[c[e+11540>>2]&127](c[Ka>>2]|0,Ja,R,R,9,9,Ha,Ia,c[xa>>2]>>1,c[o>>2]>>1);La=c[Ka>>2]|0}else{La=Ja}Ke[c[W>>2]&1023](h,La,R,8,Ga,q,128-(c[p>>2]|0)|0);i=n;return};case 1:{p=c[x>>2]<<4;x=c[s>>2]<<4;s=e+8|0;q=e+12|0;Ga=e+136|0;if((c[u>>2]|0)==0){R=e+140|0;La=e+11540|0;W=e+9944|0;Ja=0;Ka=0;o=0;while(1){xa=Ja<<3&8;Ia=Ja>>1<<3;Ha=c[v>>2]|0;za=f+((ba(Ia,Ha)|0)+xa)|0;E=e+11744+(j<<5)+(Ja<<3)|0;Fa=c[E>>2]|0;Aa=e+11744+(j<<5)+(Ja<<3)+4|0;B=c[Aa>>2]|0;G=(Fa>>1)+(xa|p)|0;xa=Ia+x+(B>>1)|0;Ia=c[s>>2]|0;if((G|0)<-16){Ma=-16}else{Ma=(G|0)>(Ia|0)?Ia:G}G=Fa&1;Fa=(Ma|0)==(Ia|0)?0:G;Ia=c[q>>2]|0;if((xa|0)<-16){Na=-16}else{Na=(xa|0)>(Ia|0)?Ia:xa}if((Na|0)==(Ia|0)){Oa=Fa}else{Oa=Fa|B<<1&2}Fa=(c[k>>2]|0)+((ba(Na,Ha)|0)+Ma)|0;Ia=c[Ga>>2]|0;xa=Ia-G-8|0;G=c[R>>2]|0;if(Ma>>>0>((xa|0)>0?xa:0)>>>0){J=142}else{xa=G-(B&1)-8|0;if(Na>>>0>((xa|0)>0?xa:0)>>>0){J=142}else{Pa=Fa;Qa=Ha}}if((J|0)==142){J=0;Ne[c[La>>2]&127](c[W>>2]|0,Fa,Ha,Ha,9,9,Ma,Na,Ia,G);Pa=c[W>>2]|0;Qa=c[v>>2]|0}cf[c[l+16+(Oa<<2)>>2]&1023](za,Pa,Qa,8);za=(c[E>>2]|0)+o|0;E=(c[Aa>>2]|0)+Ka|0;Aa=Ja+1|0;if((Aa|0)<4){Ja=Aa;Ka=E;o=za}else{Ra=za;Sa=E;break}}}else{o=e+11540|0;Ka=e+9944|0;Ja=e+140|0;Qa=0;Pa=0;Oa=0;while(1){W=e+11744+(j<<5)+(Qa<<3)|0;Na=c[W>>2]|0;Ma=e+11744+(j<<5)+(Qa<<3)+4|0;La=c[Ma>>2]|0;R=La&3;E=Na&3;za=Qa<<3&8;Aa=(za|p)+(Na>>2)|0;Na=Qa>>1<<3;G=Na+x+(La>>2)|0;La=c[s>>2]|0;if((Aa|0)<-16){Ta=-16}else{Ta=(Aa|0)>(La|0)?La:Aa}Aa=c[q>>2]|0;if((G|0)<-16){Ua=-16}else{Ua=(G|0)>(Aa|0)?Aa:G}G=((Ua|0)==(Aa|0)?0:R<<2)|((Ta|0)==(La|0)?0:E);La=c[v>>2]|0;Aa=(c[k>>2]|0)+((ba(La,Ua)|0)+Ta)|0;Ia=c[Ga>>2]|0;Ha=Ia-E-8|0;E=c[Ja>>2]|0;if(Ta>>>0>((Ha|0)>0?Ha:0)>>>0){J=132}else{Ha=E-R-8|0;if(Ua>>>0>((Ha|0)>0?Ha:0)>>>0){J=132}else{Va=Aa;Wa=La}}if((J|0)==132){J=0;Ne[c[o>>2]&127](c[Ka>>2]|0,Aa,La,La,9,9,Ta,Ua,Ia,E);Va=c[Ka>>2]|0;Wa=c[v>>2]|0}E=f+((ba(Wa,Na)|0)+za)|0;Xe[c[m+64+(G<<2)>>2]&4095](E,Va,Wa);E=((c[W>>2]|0)/2|0)+Oa|0;W=((c[Ma>>2]|0)/2|0)+Pa|0;Ma=Qa+1|0;if((Ma|0)<4){Qa=Ma;Pa=W;Oa=E}else{Ra=E;Sa=W;break}}}EPa(e,g,h,k,l+16|0,Ra,Sa);i=n;return};case 3:{Sa=c[e+14172>>2]|0;if((Sa|0)==3){Ra=c[e+11808+(j<<3)>>2]|0;Oa=c[w>>2]|0;Pa=c[A>>2]|0;if((c[u>>2]|0)==0){DPa(e,f,g,h,0,Ra,k,l,Oa,Pa,t);DPa(e,f,g,h,1,c[e+11808+(j<<3)+4>>2]|0,k,l,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,t);i=n;return}else{BPa(e,f,g,h,1,0,Ra,k,l,m,Oa,Pa,8);BPa(e,f,g,h,1,1,c[e+11808+(j<<3)+4>>2]|0,k,l,m,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,8);i=n;return}}m=c[e+11808+(j<<3)>>2]|0;do{if((Sa|0)==(m+1|0)){J=152}else{if((c[e+9992>>2]|0)==3){J=152;break}if((c[e+14240>>2]|0)==0){J=153}else{J=152}}}while(0);if((J|0)==152){if((c[k>>2]|0)==0){J=153}else{Xa=k}}if((J|0)==153){Xa=c[e+9856>>2]|0}CPa(e,f,g,h,m,Xa,l,c[w>>2]|0,c[A>>2]|0,16,t>>1);i=n;return};case 4:{Xa=e+14172|0;if((c[Xa>>2]|0)==3){m=e+11396|0;DPa(e,f,g,h,0,0,k,l,c[w>>2]|0,c[A>>2]|0,t);DPa(e,f,g,h,1,1,k,l,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,t);DPa(e,f,g,h,0,1,k,m,c[e+11744+(j<<5)+16>>2]|0,c[e+11744+(j<<5)+20>>2]|0,t);DPa(e,f,g,h,1,0,k,m,c[e+11744+(j<<5)+24>>2]|0,c[e+11744+(j<<5)+28>>2]|0,t);i=n;return}m=e+9856|0;if((c[k>>2]|0)==0){Ya=c[m>>2]|0}else{Ya=k}k=t>>1;t=e+11396|0;A=e+14240|0;w=0;J=l;l=Ya;b:while(1){Ya=w;Sa=J;while(1){if((Ya|0)>=2){break b}Za=Ya+1|0;Pa=Ya<<1;CPa(e,f,g,h,(c[Xa>>2]|0)!=(Za|0)|0,l,Sa,c[e+11744+(j<<5)+(Pa<<3)>>2]|0,c[e+11744+(j<<5)+(Pa<<3)+4>>2]|0,16,k);if((c[A>>2]|0)==0){break}else{Ya=Za;Sa=t}}w=Za;J=t;l=c[m>>2]|0}i=n;return};default:{i=n;return}}}function BPa(a,b,d,e,f,g,h,i,j,k,l,m,n){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;o=m&3;p=l&3;q=o<<2|p;r=c[a+12476>>2]|0;s=(r<<4)+(l>>2)|0;t=c[a+12480>>2]|0;u=(ba(t,16>>>(f>>>0))|0)+(m>>2)|0;v=a+140|0;w=c[v>>2]|0;x=w>>f;y=a+148|0;z=c[y>>2]|0;A=z<<f;B=a+152|0;C=c[B>>2]<<f;D=(f|0)!=0;do{if(D){E=(l|0)/2|0;F=m>>1}else{G=c[a+84>>2]|0;if((G&256|0)!=0){E=(c[555600+((l&7)<<2)>>2]|0)+(l>>1)|0;F=(c[555600+((m&7)<<2)>>2]|0)+(m>>1)|0;break}if((G&64|0)==0){E=(l|0)/2|0;F=(m|0)/2|0;break}else{E=l>>1|l&1;F=m>>1|m&1;break}}}while(0);m=(E>>>1|E)&1|(F<<1|F)&2;l=(r<<3)+(E>>2)|0;E=(ba(t,8>>>(f>>>0))|0)+(F>>2)|0;F=(c[i>>2]|0)+((ba(A,u)|0)+s)|0;t=(ba(E,C)|0)+l|0;r=(c[i+4>>2]|0)+t|0;G=(c[i+8>>2]|0)+t|0;t=a+136|0;i=c[t>>2]|0;H=i-p-16|0;if(s>>>0>((H|0)>0?H:0)>>>0){I=10}else{H=x-o-n|0;if(u>>>0>((H|0)>0?H:0)>>>0){I=10}else{J=F;K=r;L=G}}if((I|0)==10){I=a+11540|0;H=a+9944|0;Ne[c[I>>2]&127](c[H>>2]|0,F,z,z,17,f+17|0,s,u<<f,i,w);w=c[H>>2]|0;H=(c[y>>2]|0)*18|0;i=w+H|0;u=c[B>>2]|0;s=f+9|0;z=E<<f;Ne[c[I>>2]&127](i,r,u,u,9,s,l,z,c[t>>2]>>1,c[v>>2]>>1);u=w+(H+16)|0;H=c[B>>2]|0;Ne[c[I>>2]&127](u,G,H,H,9,s,l,z,c[t>>2]>>1,c[v>>2]>>1);J=w;K=i;L=u}if(!D){Xe[c[k+(q<<2)>>2]&4095](b,J,A);M=d;N=e;O=K;P=L;Q=j+16+(m<<2)|0;R=c[Q>>2]|0;S=n>>1;cf[R&1023](N,P,C,S);T=c[Q>>2]|0;cf[T&1023](M,O,C,S);return}if((g|0)==0){U=b;V=d;W=e}else{g=c[B>>2]|0;U=b+(c[y>>2]|0)|0;V=d+g|0;W=e+g|0}if((h|0)==0){X=J;Y=K;Z=L}else{h=c[B>>2]|0;X=J+(c[y>>2]|0)|0;Y=K+h|0;Z=L+h|0}h=k+64+(q<<2)|0;Xe[c[h>>2]&4095](U,X,A);Xe[c[h>>2]&4095](U+8|0,X+8|0,A);M=V;N=W;O=Y;P=Z;Q=j+16+(m<<2)|0;R=c[Q>>2]|0;S=n>>1;cf[R&1023](N,P,C,S);T=c[Q>>2]|0;cf[T&1023](M,O,C,S);return}function CPa(a,b,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;n=i;o=a+28|0;p=c[o>>2]|0;q=a+140|0;r=c[q>>2]|0;s=c[a+7656>>2]|0;t=c[a+7660>>2]|0;u=k&1;v=u<<1;w=j&1;x=v|w;y=c[a+12476>>2]|0;z=(y<<4)+(j>>1)|0;A=(m<<4)+(k>>1)|0;do{if((p|0)==2){B=A>>1;C=z>>1;D=j>>>1&1|k&2|x}else if((p|0)==0){E=a+14220|0;do{if((c[E>>2]|0)==0){if((c[a+14216>>2]|0)==0){F=A;G=z;H=x;break}I=(j|0)/2|0;F=A;G=(I>>1)+(y<<3)|0;H=I&1|v}else{I=(j|0)/2|0;J=(k|0)/2|0;F=(J>>1)+(m<<3)|0;G=(I>>1)+(y<<3)|0;H=J<<1&2|I&1}}while(0);I=c[g>>2]|0;J=z+(ba(s,A)|0)|0;K=c[g+4>>2]|0;L=(ba(F,t)|0)+G|0;M=c[g+8>>2]|0;N=(c[a+136>>2]|0)-w-16|0;do{if(!(z>>>0>((N|0)>0?N:0)>>>0)){O=r-u-l|0;if(A>>>0>((O|0)>0?O:0)>>>0){break}if((f|0)==0){P=J;Q=L}else{P=(c[a+148>>2]|0)+J|0;Q=(c[a+152>>2]|0)+L|0}cf[c[h+(x<<2)>>2]&1023](b,I+P|0,s,l);O=a+14216|0;cf[c[h+(c[O>>2]<<4)+(H<<2)>>2]&1023](d,K+Q|0,t,l>>c[E>>2]);cf[c[h+(c[O>>2]<<4)+(H<<2)>>2]&1023](e,M+Q|0,t,l>>c[E>>2]);i=n;return}}while(0);yDb(c[a+4>>2]|0,48,2246240,(R=i,i=i+16|0,c[R>>2]=z,c[R+8>>2]=A,R)|0);i=R;i=n;return}else if((p|0)==1){B=((k|0)/4|0)+(m<<3)|0;C=((j|0)/4|0)+(y<<3)|0;D=0}else{if((c[a+14220>>2]|0)!=0){E=(j|0)/2|0;M=(k|0)/2|0;B=(M>>1)+(m<<3)|0;C=(E>>1)+(y<<3)|0;D=M<<1&2|E&1;break}if((c[a+14216>>2]|0)==0){B=A;C=z;D=x;break}E=(j|0)/2|0;B=A;C=(E>>1)+(y<<3)|0;D=E&1|v}}while(0);v=(c[g>>2]|0)+(z+(ba(s,A)|0))|0;y=(ba(B,t)|0)+C|0;j=(c[g+4>>2]|0)+y|0;m=(c[g+8>>2]|0)+y|0;y=a+136|0;g=c[y>>2]|0;k=g-w-16|0;if(z>>>0>((k|0)>0?k:0)>>>0){S=20}else{k=r-u-l|0;if(A>>>0>((k|0)>0?k:0)>>>0){S=20}else{T=v;U=j;V=m}}do{if((S|0)==20){if(!(((c[a+48>>2]|0)-1|0)>>>0<2>>>0)){k=a+11540|0;u=a+9944|0;w=a+148|0;p=c[w>>2]|0;Ne[c[k>>2]&127](c[u>>2]|0,v,p,p,17,17,z,A,g,r);p=c[u>>2]|0;u=(c[w>>2]|0)*18|0;w=p+u|0;Q=a+152|0;H=c[Q>>2]|0;Ne[c[k>>2]&127](w,j,H,H,9,9,C,B,c[y>>2]>>1,c[q>>2]>>1);H=p+(u+16)|0;u=c[Q>>2]|0;Ne[c[k>>2]&127](H,m,u,u,9,9,C,B,c[y>>2]>>1,c[q>>2]>>1);T=p;U=w;V=H;break}yDb(c[a+4>>2]|0,48,2246240,(R=i,i=i+16|0,c[R>>2]=z,c[R+8>>2]=A,R)|0);i=R;i=n;return}}while(0);if((f|0)==0){W=T;X=U;Y=V}else{f=c[a+152>>2]|0;W=T+(c[a+148>>2]|0)|0;X=U+f|0;Y=V+f|0}cf[c[h+(x<<2)>>2]&1023](b,W,s,l);s=a+14216|0;W=a+14220|0;cf[c[h+(c[s>>2]<<4)+(D<<2)>>2]&1023](d,X,t,l>>c[W>>2]);cf[c[h+(c[s>>2]<<4)+(D<<2)>>2]&1023](e,Y,t,l>>c[W>>2]);if((c[o>>2]|0)!=1){i=n;return}elb(a);i=n;return}function DPa(a,b,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;n=i;o=a+28|0;p=c[o>>2]|0;q=a+140|0;r=c[q>>2]|0;s=r>>1;t=c[a+7656>>2]<<1;u=c[a+7660>>2]<<1;v=l&1;w=v<<1;x=k&1;y=w|x;z=c[a+12476>>2]|0;A=k>>1;B=(z<<4)+A|0;C=m<<3;D=l>>1;E=C+D|0;do{if((p|0)==2){if((c[a+84>>2]&2048|0)==0){F=E>>1;G=B>>1;H=k>>>1&1|l&2|y;break}else{F=(m<<2)+(l>>2)|0;G=(z<<3)+(k>>2)|0;H=D<<1&2|(A|k)&1;break}}else if((p|0)==0){I=a+14220|0;do{if((c[I>>2]|0)==0){if((c[a+14216>>2]|0)==0){J=E;K=B;L=y;break}M=(k|0)/2|0;J=E;K=(M>>1)+(z<<3)|0;L=M&1|w}else{M=(k|0)/2|0;N=(l|0)/2|0;J=(N>>1)+(m<<2)|0;K=(M>>1)+(z<<3)|0;L=N<<1&2|M&1}}while(0);M=c[h>>2]|0;N=B+(ba(t,E)|0)|0;O=c[h+4>>2]|0;P=(ba(J,u)|0)+K|0;Q=c[h+8>>2]|0;R=(c[a+136>>2]|0)-x-16|0;do{if(!(B>>>0>((R|0)>0?R:0)>>>0)){S=s-v-8|0;if(E>>>0>((S|0)>0?S:0)>>>0){break}if((f|0)==0){T=b;U=d;V=e}else{S=c[a+152>>2]|0;T=b+(c[a+148>>2]|0)|0;U=d+S|0;V=e+S|0}if((g|0)==0){W=N;X=P}else{W=(c[a+148>>2]|0)+N|0;X=(c[a+152>>2]|0)+P|0}cf[c[j+(y<<2)>>2]&1023](T,M+W|0,t,8);S=a+14216|0;cf[c[j+(c[S>>2]<<4)+(L<<2)>>2]&1023](U,O+X|0,u,8>>>((c[I>>2]|0)>>>0));cf[c[j+(c[S>>2]<<4)+(L<<2)>>2]&1023](V,Q+X|0,u,8>>>((c[I>>2]|0)>>>0));i=n;return}}while(0);yDb(c[a+4>>2]|0,48,2246240,(Y=i,i=i+16|0,c[Y>>2]=B,c[Y+8>>2]=E,Y)|0);i=Y;i=n;return}else if((p|0)==1){F=((l|0)/4|0)+C|0;G=((k|0)/4|0)+(z<<3)|0;H=0}else{if((c[a+14220>>2]|0)!=0){I=(k|0)/2|0;Q=(l|0)/2|0;F=(Q>>1)+(m<<2)|0;G=(I>>1)+(z<<3)|0;H=Q<<1&2|I&1;break}if((c[a+14216>>2]|0)==0){F=E;G=B;H=y;break}I=(k|0)/2|0;F=E;G=(I>>1)+(z<<3)|0;H=I&1|w}}while(0);w=(c[h>>2]|0)+(B+(ba(t,E)|0))|0;z=(ba(F,u)|0)+G|0;k=(c[h+4>>2]|0)+z|0;m=(c[h+8>>2]|0)+z|0;z=a+136|0;h=c[z>>2]|0;l=h-x-16|0;if(B>>>0>((l|0)>0?l:0)>>>0){Z=24}else{l=s-v-8|0;if(E>>>0>((l|0)>0?l:0)>>>0){Z=24}else{_=w;$=k;aa=m}}do{if((Z|0)==24){if(!(((c[a+48>>2]|0)-1|0)>>>0<2>>>0)){l=a+11540|0;v=a+9944|0;s=a+148|0;x=c[s>>2]|0;Ne[c[l>>2]&127](c[v>>2]|0,w,x,x,17,18,B,E<<1,h,r);x=c[v>>2]|0;v=(c[s>>2]|0)*18|0;s=x+v|0;C=a+152|0;p=c[C>>2]|0;X=F<<1;Ne[c[l>>2]&127](s,k,p,p,9,10,G,X,c[z>>2]>>1,c[q>>2]>>1);p=x+(v+16)|0;v=c[C>>2]|0;Ne[c[l>>2]&127](p,m,v,v,9,10,G,X,c[z>>2]>>1,c[q>>2]>>1);_=x;$=s;aa=p;break}yDb(c[a+4>>2]|0,48,2246240,(Y=i,i=i+16|0,c[Y>>2]=B,c[Y+8>>2]=E,Y)|0);i=Y;i=n;return}}while(0);if((f|0)==0){ca=b;da=d;ea=e}else{f=c[a+152>>2]|0;ca=b+(c[a+148>>2]|0)|0;da=d+f|0;ea=e+f|0}if((g|0)==0){fa=_;ga=$;ha=aa}else{g=c[a+152>>2]|0;fa=_+(c[a+148>>2]|0)|0;ga=$+g|0;ha=aa+g|0}cf[c[j+(y<<2)>>2]&1023](ca,fa,t,8);t=a+14216|0;fa=a+14220|0;cf[c[j+(c[t>>2]<<4)+(H<<2)>>2]&1023](da,ga,u,8>>>((c[fa>>2]|0)>>>0));cf[c[j+(c[t>>2]<<4)+(H<<2)>>2]&1023](ea,ha,u,8>>>((c[fa>>2]|0)>>>0));if((c[o>>2]|0)!=1){i=n;return}elb(a);i=n;return}function EPa(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=(d[1210152+(h&15)|0]|0)+(h>>3)|0;h=(d[1210152+(i&15)|0]|0)+(i>>3)|0;i=(c[a+12476>>2]<<3)+(j>>1)|0;k=(c[a+12480>>2]<<3)+(h>>1)|0;l=c[a+8>>2]>>1;if((i|0)<-8){m=-8}else{m=(i|0)>(l|0)?l:i}i=(m|0)==(l|0)?0:j&1;j=c[a+12>>2]>>1;if((k|0)<-8){n=-8}else{n=(k|0)>(j|0)?j:k}k=(n|0)==(j|0)?0:h<<1&2;h=k|i;j=a+152|0;l=c[j>>2]|0;o=(ba(l,n)|0)+m|0;p=(c[f+4>>2]|0)+o|0;q=a+136|0;r=c[q>>2]>>1;s=r-i-8|0;i=c[a+140>>2]|0;if(m>>>0>((s|0)>0?s:0)>>>0){t=7}else{s=(i>>1)-(k>>>1)-8|0;if(n>>>0>((s|0)>0?s:0)>>>0){t=7}else{u=p;v=0;w=l}}if((t|0)==7){t=a+9944|0;Ne[c[a+11540>>2]&127](c[t>>2]|0,p,l,l,9,9,m,n,r,i>>1);u=c[t>>2]|0;v=1;w=c[j>>2]|0}t=g+(h<<2)|0;cf[c[t>>2]&1023](b,u,w,8);w=(c[f+8>>2]|0)+o|0;if(!v){x=w;y=c[t>>2]|0;z=c[j>>2]|0;cf[y&1023](e,x,z,8);return}v=a+9944|0;o=c[j>>2]|0;Ne[c[a+11540>>2]&127](c[v>>2]|0,w,o,o,9,9,m,n,c[q>>2]>>1,c[a+140>>2]>>1);x=c[v>>2]|0;y=c[t>>2]|0;z=c[j>>2]|0;cf[y&1023](e,x,z,8);return}function FPa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+1040|0;h=g|0;j=g+1024|0;k=g+1032|0;l=d;m=c[f+24>>2]|0;n=f+8|0;o=c[n>>2]|0;p=c[n+4>>2]|0;n=b+104|0;c[j>>2]=1;c[j+4>>2]=100;b=KDb(o,p,n,j)|0;j=b;b=c[f+48>>2]|0;if((b|0)==-1){q=-1}else{c[k>>2]=1;c[k+4>>2]=100;p=KDb(b,(b|0)<0|0?-1:0,n,k)|0;q=p}IAb(h,0,-1);p=f+28|0;do{if((m|0)!=0){if((c[p>>2]|0)<=0){break}f=a[m]|0;if(f<<24>>24==0){break}k=f<<24>>24==32?m+1|0:m;f=a[k]|0;a:do{if(!(f<<24>>24==0)){n=k;b=f;do{b:do{if(b<<24>>24==0){r=n;s=0;t=0}else{o=n;u=0;v=b;while(1){if((Ib(2184808,v<<24>>24|0,4)|0)==0){r=o;s=u;t=v;break b}if((v<<24>>24|0)==47){KAb(h,2107736,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}else if((v<<24>>24|0)==92){KAb(h,2050256,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}else if((v<<24>>24|0)==95){KAb(h,2004608,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}x=o+1|0;y=a[x]|0;if(y<<24>>24==0){r=x;s=1;t=0;break}else{o=x;u=1;v=y}}}}while(0);v=r;u=t;while(1){if((u<<24>>24|0)==124){break}else if((u<<24>>24|0)==0){break a}else if(!((u<<24>>24|0)==10|(u<<24>>24|0)==13)){MAb(h,u,1)}o=v+1|0;v=o;u=a[o]|0}if((s|0)!=0){KAb(h,1967232,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}KAb(h,1938944,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;n=v+1|0;b=a[n]|0;}while(!(b<<24>>24==0))}}while(0);KAb(h,1914648,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if((c[h+4>>2]|0)>>>0<(c[h+8>>2]|0)>>>0){shb(l,c[h>>2]|0,j,q,0)|0;break}QAb(h,0)|0;z=-12;i=g;return z|0}}while(0);c[e>>2]=(c[d+12>>2]|0)!=0;QAb(h,0)|0;z=c[p>>2]|0;i=g;return z|0}function GPa(){var c=0,d=0,e=0,f=0,g=0;c=0;do{d=b[1410104+(c*6|0)>>1]|0;e=c<<1;f=e|1;b[6482536+(f<<1)>>1]=d;b[6482536+(e<<1)>>1]=d;d=a[1410107+(c*6|0)|0]<<1;g=a[1410108+(c*6|0)|0]|0;a[6482824+e|0]=d+g;a[6482824+f|0]=(d|1)-g;g=a[1410106+(c*6|0)|0]<<1;a[6482728+e|0]=g;a[6482728+f|0]=g|1;c=c+1|0;}while((c|0)<47);return}function HPa(b){b=b|0;var c=0;c=b+20|0;TGb(c|0,0,18)|0;a[b+37|0]=92;a[b+38|0]=6;a[c]=8;return}function IPa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;HPa(b);f=b|0;c[f>>2]=e;g=d[e]<<16^16711680;h=b+12|0;c[h>>2]=g;i=e+1|0;do{if((a[e]|0)==-1){if((d[i]|0)>>>0>143>>>0){j=g|1;c[h>>2]=j;k=j;break}else{c[f>>2]=i;j=(g|65026)-(d[i]<<9)|0;c[h>>2]=j;k=j;break}}else{c[f>>2]=i;j=(g|65281)-(d[i]<<8)|0;c[h>>2]=j;k=j}}while(0);c[h>>2]=k<<7;c[b+8>>2]=32768;return}function JPa(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0;g=b+8|0;h=(c[g>>2]|0)-(e[6482536+((d[f]|0)<<1)>>1]|0)|0;c[g>>2]=h;g=b+12|0;i=c[g>>2]|0;if(!(i>>>16>>>0<h>>>0)){c[g>>2]=i-(h<<16);j=KPa(b,f,1)|0;return j|0}if((h&32768|0)==0){j=KPa(b,f,0)|0;return j|0}else{j=a[f]&1;return j|0}return 0}function KPa(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=b+8|0;i=a[f]|0;j=e[6482536+((i&255)<<1)>>1]|0;k=(g|0)!=0;if(((c[h>>2]|0)>>>0<j>>>0|0)==(k&1^1|0)){if(k){c[h>>2]=j;l=a[f]|0}else{l=i}g=l&255;m=g&1^1;n=6482824+g|0}else{if(k){c[h>>2]=j;o=a[f]|0}else{o=i}i=o&255;m=i&1;n=6482728+i|0}a[f]=a[n]|0;n=b+12|0;f=b|0;b=c[n>>2]|0;do{do{if((b&255|0)==0){c[n>>2]=b-256;i=c[f>>2]|0;o=i+1|0;if(!((a[i]|0)==-1)){c[f>>2]=o;i=b+65025-(d[o]<<8)|0;c[n>>2]=i;p=i;break}if((d[o]|0)>>>0>143>>>0){i=b-255|0;c[n>>2]=i;p=i;break}else{c[f>>2]=o;i=b+64770-(d[o]<<9)|0;c[n>>2]=i;p=i;break}}else{p=b}}while(0);i=c[h>>2]<<1;c[h>>2]=i;b=p<<1;c[n>>2]=b;}while((i&32768|0)==0);return m|0}function LPa(b,d){b=b|0;d=d|0;var e=0;HPa(b);c[b+8>>2]=32768;c[b+12>>2]=0;e=d-1|0;c[b>>2]=e;c[b+4>>2]=d;c[b+16>>2]=(a[e]|0)==-1|12;return}function MPa(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=e[6482536+((d[f]|0)<<1)>>1]|0;i=b+8|0;j=(c[i>>2]|0)-h|0;c[i>>2]=j;if((a[f]&1|0)!=(g|0)){if(j>>>0<h>>>0){g=b+12|0;c[g>>2]=(c[g>>2]|0)+h;k=g}else{c[i>>2]=h;k=b+12|0}a[f]=a[6482824+(d[f]|0)|0]|0;g=b+16|0;l=b|0;m=c[i>>2]|0;n=c[k>>2]|0;o=c[g>>2]|0;while(1){c[i>>2]=m<<1;p=n<<1;c[k>>2]=p;q=o-1|0;c[g>>2]=q;a:do{if((q|0)==0){r=c[l>>2]|0;s=a[r]|0;do{if(s<<24>>24==-1){t=r;u=n>>>19&255}else{v=r;w=s;x=p;while(1){if((x&134217728|0)==0){y=26;break}a[v]=w+1;z=c[k>>2]&134217727;c[k>>2]=z;A=c[l>>2]|0;B=a[A]|0;if(B<<24>>24==-1){y=22;break}else{v=A;w=B;x=z}}if((y|0)==22){y=0;t=A;u=z>>>20&255;break}else if((y|0)==26){y=0;w=v+1|0;c[l>>2]=w;a[w]=x>>>19;w=c[k>>2]&524287;c[k>>2]=w;c[g>>2]=8;C=w;D=8;break a}}}while(0);s=t+1|0;c[l>>2]=s;a[s]=u;s=c[k>>2]&1048575;c[k>>2]=s;c[g>>2]=7;C=s;D=7}else{C=p;D=q}}while(0);q=c[i>>2]|0;if((q&32768|0)==0){m=q;n=C;o=D}else{break}}return}if((j&32768|0)!=0){D=b+12|0;c[D>>2]=(c[D>>2]|0)+h;return}if(j>>>0<h>>>0){c[i>>2]=h;E=b+12|0}else{j=b+12|0;c[j>>2]=(c[j>>2]|0)+h;E=j}a[f]=a[6482728+(d[f]|0)|0]|0;f=b+16|0;j=b|0;b=c[i>>2]|0;h=c[E>>2]|0;D=c[f>>2]|0;while(1){c[i>>2]=b<<1;o=h<<1;c[E>>2]=o;C=D-1|0;c[f>>2]=C;b:do{if((C|0)==0){n=c[j>>2]|0;m=a[n]|0;do{if(m<<24>>24==-1){F=n;G=h>>>19&255}else{g=n;k=m;u=o;while(1){if((u&134217728|0)==0){y=13;break}a[g]=k+1;H=c[E>>2]&134217727;c[E>>2]=H;I=c[j>>2]|0;l=a[I]|0;if(l<<24>>24==-1){y=9;break}else{g=I;k=l;u=H}}if((y|0)==9){y=0;F=I;G=H>>>20&255;break}else if((y|0)==13){y=0;k=g+1|0;c[j>>2]=k;a[k]=u>>>19;k=c[E>>2]&524287;c[E>>2]=k;c[f>>2]=8;J=k;K=8;break b}}}while(0);m=F+1|0;c[j>>2]=m;a[m]=G;m=c[E>>2]&1048575;c[E>>2]=m;c[f>>2]=7;J=m;K=7}else{J=o;K=C}}while(0);C=c[i>>2]|0;if((C&32768|0)==0){b=C;h=J;D=K}else{break}}return}function NPa(a){a=a|0;return(c[a>>2]|0)-(c[a+4>>2]|0)|0}function OPa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=b+12|0;e=c[d>>2]|0;f=e|65535;g=b+16|0;h=(f>>>0<((c[b+8>>2]|0)+e|0)>>>0?f:f-32768|0)<<c[g>>2];c[d>>2]=h;f=b|0;e=c[f>>2]|0;i=a[e]|0;do{if(i<<24>>24==-1){j=e;k=h>>>20&255;l=3}else{m=e;n=i;o=h;while(1){if((o&134217728|0)==0){l=6;break}a[m]=n+1;p=c[d>>2]&134217727;c[d>>2]=p;q=c[f>>2]|0;r=a[q]|0;if(r<<24>>24==-1){l=2;break}else{m=q;n=r;o=p}}if((l|0)==2){j=q;k=p>>>20&255;l=3;break}else if((l|0)==6){n=m+1|0;c[f>>2]=n;a[n]=o>>>19;s=8;t=c[d>>2]&524287;break}}}while(0);if((l|0)==3){p=j+1|0;c[f>>2]=p;a[p]=k;s=7;t=c[d>>2]&1048575}c[g>>2]=s;k=t<<s;c[d>>2]=k;s=c[f>>2]|0;t=a[s]|0;do{if(t<<24>>24==-1){u=s;v=k>>>20&255;l=9}else{p=s;j=t;q=k;while(1){if((q&134217728|0)==0){l=12;break}a[p]=j+1;w=c[d>>2]&134217727;c[d>>2]=w;x=c[f>>2]|0;h=a[x]|0;if(h<<24>>24==-1){l=8;break}else{p=x;j=h;q=w}}if((l|0)==8){u=x;v=w>>>20&255;l=9;break}else if((l|0)==12){j=p+1|0;c[f>>2]=j;a[j]=q>>>19;y=8;z=c[d>>2]&524287;break}}}while(0);if((l|0)==9){l=u+1|0;c[f>>2]=l;a[l]=v;y=7;z=c[d>>2]&1048575}c[d>>2]=z;c[g>>2]=y;y=c[f>>2]|0;if((a[y]|0)==-1){A=y;B=b+4|0;C=c[B>>2]|0;D=A;E=C;F=D-E|0;return F|0}g=y+1|0;c[f>>2]=g;A=g;B=b+4|0;C=c[B>>2]|0;D=A;E=C;F=D-E|0;return F|0}function PPa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+24|0;g=f|0;h=(d|0)==0?0:520;c[g>>2]=d;c[g+12>>2]=h;c[g+16>>2]=h+8;c[g+4>>2]=d+(h>>>3);c[g+8>>2]=0;h=a+60|0;QPa(c[h>>2]|0,b,g,e);QPa(c[h>>2]|0,b+320|0,g,e);i=f;return 0}function QPa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;i=a+240|0;j=a+660|0;k=c[j>>2]|0;l=a+596|0;m=g+8|0;n=c[m>>2]|0;o=g+16|0;p=c[o>>2]|0;q=c[g>>2]|0;g=q+(n>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((n&7)>>>0);g=n+6|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)>>2]=((r<<10&64512)*13107|0)-429473792>>15<<1;r=c[m>>2]|0;p=c[o>>2]|0;g=q+(r>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0);g=r+6|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+4>>2]=((n<<10&64512)*13107|0)-429473792>>15<<1;n=c[m>>2]|0;p=c[o>>2]|0;g=q+(n>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((n&7)>>>0);g=n+5|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+8>>2]=((r<<10&31744)*13107|0)-268414976>>15<<1;r=c[m>>2]|0;p=c[o>>2]|0;g=q+(r>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0);g=r+5|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+12>>2]=((n<<10&31744)*13107|0)-147620864>>15<<1;n=c[m>>2]|0;p=c[o>>2]|0;g=q+(n>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((n&7)>>>0);g=n+4|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+16>>2]=((r<<10&15360)*19223|0)-161072356>>15<<1;r=c[m>>2]|0;p=c[o>>2]|0;g=q+(r>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0);g=r+4|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+20>>2]=((n<<10&15360)*17476|0)-80513024>>15<<1;n=c[m>>2]|0;p=c[o>>2]|0;g=q+(n>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((n&7)>>>0);g=n+3|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+24>>2]=((r<<10&7168)*31454|0)-107367572>>15<<1;r=c[m>>2]|0;p=c[o>>2]|0;g=q+(r>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0);g=r+3|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+28>>2]=((n<<10&7168)*29708|0)-53695680>>15<<1;n=c[o>>2]|0;o=i;k=0;l=c[m>>2]|0;while(1){p=q+(l>>>3)|0;g=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((l&7)>>>0)&127;p=l+7|0;r=n>>>0>p>>>0?p:n;c[m>>2]=r;p=q+(r>>>3)|0;s=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((r&7)>>>0)&3;p=r+2|0;r=n>>>0>p>>>0?p:n;c[m>>2]=r;p=q+(r>>>3)|0;t=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((r&7)>>>0)&3;p=r+2|0;r=n>>>0>p>>>0?p:n;c[m>>2]=r;if(g>>>0<40>>>0){u=40}else{u=g>>>0>120>>>0?120:g}g=e[1212384+(s<<1)>>1]|0;s=0;do{b[o+(s<<1)>>1]=((ba(b[o+(s-u<<1)>>1]|0,g)|0)+16384|0)>>>15;s=s+1|0;}while((s|0)<40);s=c[1213600+(h<<4)+(k<<2)>>2]|0;g=q+(r>>>3)|0;p=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0)&63;g=r+6|0;v=n>>>0>g>>>0?g:n;c[m>>2]=v;g=0;w=v;do{v=s+(g<<2)|0;x=c[v>>2]|0;y=q+(w>>>3)|0;z=32-x|0;A=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((w&7)>>>0)<<z>>>(z>>>0);z=x+w|0;w=n>>>0>z>>>0?z:n;c[m>>2]=w;z=o+((g*3|0)+t<<1)|0;b[z>>1]=(b[z>>1]|0)+(b[1212392+(p<<4)+(c[548144+(c[v>>2]<<5)+(A<<2)>>2]<<1)>>1]|0);g=g+1|0;}while((g|0)<13);g=k+1|0;if((g|0)<4){o=o+80|0;k=g;l=w}else{break}}l=a;UGb(a|0,a+320|0,240)|0;k=c[j>>2]|0;o=k^1;m=l+596+(o<<5)|0;n=c[m>>2]|0;q=l+596+(k<<5)|0;h=RPa((n>>2)+(n>>1)+(c[q>>2]>>2)|0)|0;n=l+596+(o<<5)+4|0;u=c[n>>2]|0;g=l+596+(k<<5)+4|0;p=RPa((u>>2)+(u>>1)+(c[g>>2]>>2)|0)|0;u=l+596+(o<<5)+8|0;t=c[u>>2]|0;s=l+596+(k<<5)+8|0;r=RPa((t>>2)+(t>>1)+(c[s>>2]>>2)|0)|0;t=l+596+(o<<5)+12|0;A=c[t>>2]|0;v=l+596+(k<<5)+12|0;z=RPa((A>>2)+(A>>1)+(c[v>>2]>>2)|0)|0;A=l+596+(o<<5)+16|0;x=c[A>>2]|0;y=l+596+(k<<5)+16|0;B=RPa((x>>2)+(x>>1)+(c[y>>2]>>2)|0)|0;x=l+596+(o<<5)+20|0;C=c[x>>2]|0;D=l+596+(k<<5)+20|0;E=RPa((C>>2)+(C>>1)+(c[D>>2]>>2)|0)|0;C=l+596+(o<<5)+24|0;F=c[C>>2]|0;G=l+596+(k<<5)+24|0;H=RPa((F>>2)+(F>>1)+(c[G>>2]>>2)|0)|0;F=l+596+(o<<5)+28|0;I=c[F>>2]|0;J=l+596+(k<<5)+28|0;k=RPa((I>>2)+(I>>1)+(c[J>>2]>>2)|0)|0;I=a+560|0;l=a+588|0;K=a+584|0;L=a+580|0;M=a+576|0;N=a+572|0;O=a+568|0;P=a+564|0;Q=0;R=c[l>>2]|0;S=c[K>>2]|0;T=c[L>>2]|0;U=c[M>>2]|0;V=c[N>>2]|0;W=c[O>>2]|0;X=c[P>>2]|0;Y=c[I>>2]|0;while(1){Z=(b[i+(Q<<1)>>1]|0)-((ba(R,k)|0)+16384>>15)|0;_=Z-((ba(S,H)|0)+16384>>15)|0;$=((ba(_,H)|0)+16384>>15)+S|0;aa=_-((ba(T,E)|0)+16384>>15)|0;ca=((ba(aa,E)|0)+16384>>15)+T|0;_=aa-((ba(U,B)|0)+16384>>15)|0;da=((ba(_,B)|0)+16384>>15)+U|0;aa=_-((ba(V,z)|0)+16384>>15)|0;ea=((ba(aa,z)|0)+16384>>15)+V|0;_=aa-((ba(W,r)|0)+16384>>15)|0;fa=((ba(_,r)|0)+16384>>15)+W|0;aa=_-((ba(X,p)|0)+16384>>15)|0;ga=((ba(aa,p)|0)+16384>>15)+X|0;ha=aa-((ba(Y,h)|0)+16384>>15)|0;ia=((ba(ha,h)|0)+16384>>15)+Y|0;b[f+(Q<<1)>>1]=ha;aa=Q+1|0;if((aa|0)<13){Q=aa;R=$;S=ca;T=da;U=ea;V=fa;W=ga;X=ia;Y=ha}else{break}}Y=a+592|0;X=((ba(Z,k)|0)+16384>>15)+R|0;c[l>>2]=$;c[Y>>2]=X;c[K>>2]=ca;c[L>>2]=da;c[M>>2]=ea;c[N>>2]=fa;c[O>>2]=ga;c[P>>2]=ia;c[I>>2]=ha;X=RPa((c[q>>2]>>1)+(c[m>>2]>>1)|0)|0;R=RPa((c[g>>2]>>1)+(c[n>>2]>>1)|0)|0;k=RPa((c[s>>2]>>1)+(c[u>>2]>>1)|0)|0;Z=RPa((c[v>>2]>>1)+(c[t>>2]>>1)|0)|0;W=RPa((c[y>>2]>>1)+(c[A>>2]>>1)|0)|0;V=RPa((c[D>>2]>>1)+(c[x>>2]>>1)|0)|0;U=RPa((c[G>>2]>>1)+(c[C>>2]>>1)|0)|0;T=RPa((c[J>>2]>>1)+(c[F>>2]>>1)|0)|0;S=13;Q=$;$=ca;ca=da;da=ea;ea=fa;fa=ga;ga=ia;ia=ha;while(1){ja=(b[i+(S<<1)>>1]|0)-((ba(Q,T)|0)+16384>>15)|0;ha=ja-((ba($,U)|0)+16384>>15)|0;ka=((ba(ha,U)|0)+16384>>15)+$|0;h=ha-((ba(ca,V)|0)+16384>>15)|0;la=((ba(h,V)|0)+16384>>15)+ca|0;ha=h-((ba(da,W)|0)+16384>>15)|0;ma=((ba(ha,W)|0)+16384>>15)+da|0;h=ha-((ba(ea,Z)|0)+16384>>15)|0;na=((ba(h,Z)|0)+16384>>15)+ea|0;ha=h-((ba(fa,k)|0)+16384>>15)|0;oa=((ba(ha,k)|0)+16384>>15)+fa|0;h=ha-((ba(ga,R)|0)+16384>>15)|0;pa=((ba(h,R)|0)+16384>>15)+ga|0;qa=h-((ba(ia,X)|0)+16384>>15)|0;ra=((ba(qa,X)|0)+16384>>15)+ia|0;b[f+(S<<1)>>1]=qa;h=S+1|0;if((h|0)<27){S=h;Q=ka;$=la;ca=ma;da=na;ea=oa;fa=pa;ga=ra;ia=qa}else{break}}ia=((ba(ja,T)|0)+16384>>15)+Q|0;c[l>>2]=ka;c[Y>>2]=ia;c[K>>2]=la;c[L>>2]=ma;c[M>>2]=na;c[N>>2]=oa;c[O>>2]=pa;c[P>>2]=ra;c[I>>2]=qa;ia=c[q>>2]|0;Q=RPa((ia>>1)+(c[m>>2]>>2)+(ia>>2)|0)|0;ia=c[g>>2]|0;m=RPa((ia>>1)+(c[n>>2]>>2)+(ia>>2)|0)|0;ia=c[s>>2]|0;n=RPa((ia>>1)+(c[u>>2]>>2)+(ia>>2)|0)|0;ia=c[v>>2]|0;u=RPa((ia>>1)+(c[t>>2]>>2)+(ia>>2)|0)|0;ia=c[y>>2]|0;t=RPa((ia>>1)+(c[A>>2]>>2)+(ia>>2)|0)|0;ia=c[D>>2]|0;A=RPa((ia>>1)+(c[x>>2]>>2)+(ia>>2)|0)|0;ia=c[G>>2]|0;x=RPa((ia>>1)+(c[C>>2]>>2)+(ia>>2)|0)|0;ia=c[J>>2]|0;C=RPa((ia>>1)+(c[F>>2]>>2)+(ia>>2)|0)|0;ia=27;F=ka;ka=la;la=ma;ma=na;na=oa;oa=pa;pa=ra;ra=qa;while(1){sa=(b[i+(ia<<1)>>1]|0)-((ba(F,C)|0)+16384>>15)|0;qa=sa-((ba(ka,x)|0)+16384>>15)|0;ta=((ba(qa,x)|0)+16384>>15)+ka|0;T=qa-((ba(la,A)|0)+16384>>15)|0;ua=((ba(T,A)|0)+16384>>15)+la|0;qa=T-((ba(ma,t)|0)+16384>>15)|0;va=((ba(qa,t)|0)+16384>>15)+ma|0;T=qa-((ba(na,u)|0)+16384>>15)|0;wa=((ba(T,u)|0)+16384>>15)+na|0;qa=T-((ba(oa,n)|0)+16384>>15)|0;xa=((ba(qa,n)|0)+16384>>15)+oa|0;T=qa-((ba(pa,m)|0)+16384>>15)|0;ya=((ba(T,m)|0)+16384>>15)+pa|0;za=T-((ba(ra,Q)|0)+16384>>15)|0;Aa=((ba(za,Q)|0)+16384>>15)+ra|0;b[f+(ia<<1)>>1]=za;T=ia+1|0;if((T|0)<40){ia=T;F=ta;ka=ua;la=va;ma=wa;na=xa;oa=ya;pa=Aa;ra=za}else{break}}ra=((ba(sa,C)|0)+16384>>15)+F|0;c[l>>2]=ta;c[Y>>2]=ra;c[K>>2]=ua;c[L>>2]=va;c[M>>2]=wa;c[N>>2]=xa;c[O>>2]=ya;c[P>>2]=Aa;c[I>>2]=za;ra=RPa(c[q>>2]|0)|0;q=RPa(c[g>>2]|0)|0;g=RPa(c[s>>2]|0)|0;s=RPa(c[v>>2]|0)|0;v=RPa(c[y>>2]|0)|0;y=RPa(c[D>>2]|0)|0;D=RPa(c[G>>2]|0)|0;G=RPa(c[J>>2]|0)|0;J=40;F=ta;ta=ua;ua=va;va=wa;wa=xa;xa=ya;ya=Aa;Aa=za;while(1){Ba=(b[i+(J<<1)>>1]|0)-((ba(F,G)|0)+16384>>15)|0;za=Ba-((ba(ta,D)|0)+16384>>15)|0;Ca=((ba(za,D)|0)+16384>>15)+ta|0;C=za-((ba(ua,y)|0)+16384>>15)|0;Da=((ba(C,y)|0)+16384>>15)+ua|0;za=C-((ba(va,v)|0)+16384>>15)|0;Ea=((ba(za,v)|0)+16384>>15)+va|0;C=za-((ba(wa,s)|0)+16384>>15)|0;Fa=((ba(C,s)|0)+16384>>15)+wa|0;za=C-((ba(xa,g)|0)+16384>>15)|0;Ga=((ba(za,g)|0)+16384>>15)+xa|0;C=za-((ba(ya,q)|0)+16384>>15)|0;Ha=((ba(C,q)|0)+16384>>15)+ya|0;Ia=C-((ba(Aa,ra)|0)+16384>>15)|0;Ja=((ba(Ia,ra)|0)+16384>>15)+Aa|0;b[f+(J<<1)>>1]=Ia;C=J+1|0;if((C|0)<160){J=C;F=Ca;ta=Da;ua=Ea;va=Fa;wa=Ga;xa=Ha;ya=Ja;Aa=Ia}else{break}}Aa=((ba(Ba,G)|0)+16384>>15)+F|0;c[l>>2]=Ca;c[Y>>2]=Aa;c[K>>2]=Da;c[L>>2]=Ea;c[M>>2]=Fa;c[N>>2]=Ga;c[O>>2]=Ha;c[P>>2]=Ja;c[I>>2]=Ia;c[j>>2]=o;o=a+664|0;a=c[o>>2]|0;j=0;do{Ia=f+(j<<1)|0;I=((a*28180|0)+16384>>15)+(b[Ia>>1]|0)|0;if((I+32768|0)>>>0>65535>>>0){Ka=(I>>31^32767)&65535}else{Ka=I&65535}a=Ka<<16>>16;I=a<<1;if((I+32768|0)>>>0>65535>>>0){La=(a>>30^32767)&65535}else{La=I&65535}b[Ia>>1]=La&-8;j=j+1|0;}while((j|0)<160);c[o>>2]=a;return}function RPa(a){a=a|0;var b=0,c=0;b=(a|0)>-1?a:-a|0;do{if((b|0)<11059){c=b<<1}else{if((b|0)<20070){c=b+11059|0;break}else{c=(b>>2)+26112|0;break}}}while(0);return((a|0)<0?-c|0:c)|0}function SPa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=hDb(c[a+120>>2]|0,c[a+124>>2]|0,0,a)|0;if((d|0)<0){e=d;return e|0}if((Fca(a)|0)<0){e=-1;return e|0}Omb(b);if((c[1620606]|0)==0){OOa(1146840,5396608);OOa(1147032,5396998);OOa(1147224,5397388);OOa(1147416,5397778);OOa(1147608,5398168);OOa(1147800,5398558);c[286722]=5871088;c[286724]=642;a=c[286712]|0;N_(1146884,9,(c[286710]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[286726]|0)==0){a=0;do{c[1146904+(a<<2)>>2]=6400248+(a*2568|0);a=a+1|0;}while((a|0)<32);POa(1146840)}c[286770]=5807008;c[286772]=1104;a=c[286760]|0;N_(1147076,9,(c[286758]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[286774]|0)==0){a=0;do{c[1147096+(a<<2)>>2]=6258936+(a*4416|0);a=a+1|0;}while((a|0)<32);POa(1147032)}c[286818]=5766736;c[286820]=554;a=c[286808]|0;N_(1147268,9,(c[286806]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[286822]|0)==0){a=0;do{c[1147288+(a<<2)>>2]=6188024+(a*2216|0);a=a+1|0;}while((a|0)<32);POa(1147224)}c[286866]=5762976;c[286868]=940;a=c[286856]|0;N_(1147460,9,(c[286854]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[286870]|0)==0){a=0;do{c[1147480+(a<<2)>>2]=6067704+(a*3760|0);a=a+1|0;}while((a|0)<32);POa(1147416)}c[286914]=5759128;c[286916]=962;a=c[286904]|0;N_(1147652,9,(c[286902]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[286918]|0)==0){a=0;do{c[1147672+(a<<2)>>2]=5944568+(a*3848|0);a=a+1|0;}while((a|0)<32);POa(1147608)}c[286962]=5868872;c[286964]=554;a=c[286952]|0;N_(1147844,9,(c[286950]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[286966]|0)==0){a=0;do{c[1147864+(a<<2)>>2]=5873656+(a*2216|0);a=a+1|0;}while((a|0)<32);POa(1147800)}c[293131]=5854016;c[293133]=3714;N_(1172520,9,(c[293124]|0)+1|0,c[293126]|0,1,1,c[293125]|0,2,2,0,0,0,4)|0;c[293142]=5843240;c[293144]=2694;N_(1172564,9,(c[293135]|0)+1|0,c[293137]|0,1,1,c[293136]|0,2,2,0,0,0,4)|0;c[1620615]=5838608;c[1620617]=1158;N_(6482456,9,120,1128116,8,4,1128112,8,4,0,0,0,4)|0;c[1620625]=5834136;c[1620627]=1118;N_(6482496,9,120,1129076,8,4,1129072,8,4,0,0,0,4)|0;c[1620620]=5828232;c[1620622]=1476;N_(6482476,9,120,1126196,8,4,1126192,8,4,0,0,0,4)|0;c[1620630]=5823368;c[1620632]=1216;N_(6482516,9,120,1127156,8,4,1127152,8,4,0,0,0,4)|0;c[646567]=5817480;c[646569]=1472;N_(2586264,9,512,5388420,8,4,5388416,8,4,0,0,0,4)|0;c[646573]=5811456;c[646575]=1506;N_(2586288,9,512,5392516,8,4,5392512,8,4,0,0,0,4)|0;c[646561]=5811424;c[646563]=8;N_(2586240,3,4,1107633,2,1,1107632,2,1,0,0,0,4)|0;c[646555]=5806496;c[646557]=128;N_(2586216,7,8,1107617,2,1,1107616,2,1,0,0,0,4)|0;c[646549]=5804344;c[646551]=538;N_(2586192,9,33,1172137,2,1,1172136,2,1,0,0,0,4)|0;c[1719047]=5797800;c[1719049]=1636;a=c[270048]|0;N_(6876184,9,128,a+4|0,8,4,a,8,4,0,0,0,4)|0;c[1719052]=5787208;c[1719054]=2648;a=c[270049]|0;N_(6876204,9,128,a+4|0,8,4,a,8,4,0,0,0,4)|0;c[1719057]=5781080;c[1719059]=1532;a=c[270050]|0;N_(6876224,9,128,a+4|0,8,4,a,8,4,0,0,0,4)|0;c[1719062]=5771128;c[1719064]=2488;a=c[270051]|0;N_(6876244,9,128,a+4|0,8,4,a,8,4,0,0,0,4)|0;c[1620609]=5768984;c[1620611]=536;N_(6482432,9,64,1174082,4,2,1174080,4,2,0,0,0,4)|0;c[1850529]=5768952;c[1850531]=8;N_(7402112,3,4,1126081,2,1,1126080,2,1,0,0,0,4)|0;c[1620606]=1}switch(c[b+14092>>2]|0){case 1:case 2:{c[b+14348>>2]=534;break};case 3:case 4:{c[b+14348>>2]=820;break};case 5:{c[b+14348>>2]=204;break};default:{}}c[b+14080>>2]=c[b+120>>2];e=0;return e|0}function TPa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=a+12476|0;k=c[j>>2]|0;l=a+12480|0;m=c[l>>2]|0;n=(ba(c[a+124>>2]|0,m)|0)+k|0;o=(c[a+9160>>2]|0)+(n<<2)|0;n=(c[a+9992>>2]|0)==2;do{if(n){do{if((c[a+14076>>2]|0)!=0){p=a+14128|0;q=c[p>>2]|0;r=d[(c[a+14120>>2]|0)+(q>>>3)|0]|0;c[p>>2]=((q|0)<(c[a+14136>>2]|0))+q;if((r&128>>>((q&7)>>>0)|0)==0){break}c[a+12488>>2]=0;TGb(a+180|0,-1|0,24)|0;c[a+11736>>2]=1;c[a+11740>>2]=0;c[a+11744>>2]=0;c[a+11748>>2]=0;c[a+9924>>2]=1;c[o>>2]=14344;s=0;i=f;return s|0}}while(0);q=c[a+14092>>2]|0;r=a+14120|0;if((q|0)==2){p=c[646555]|0;t=a+14128|0;u=c[t>>2]|0;v=c[a+14136>>2]|0;w=c[r>>2]|0;x=w+(u>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(u&7)>>>25;x=b[p+(y<<2)>>1]|0;z=(b[p+(y<<2)+2>>1]|0)+u|0;u=v>>>0>z>>>0?z:v;c[t>>2]=u;A=x;B=u;C=v;D=w}else{w=c[1850737]|0;v=a+14128|0;u=c[v>>2]|0;x=c[a+14136>>2]|0;t=c[r>>2]|0;r=t+(u>>>3)|0;z=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(u&7)>>>25;r=b[w+(z<<2)>>1]|0;y=b[w+(z<<2)+2>>1]|0;z=y<<16>>16;if(y<<16>>16<0){y=u+7|0;p=x>>>0>y>>>0?y:x;y=t+(p>>>3)|0;E=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(p&7)>>>((z+32|0)>>>0))+r|0;F=b[w+(E<<2)+2>>1]|0;G=b[w+(E<<2)>>1]|0;H=p}else{F=z;G=r;H=u}u=F+H|0;r=x>>>0>u>>>0?u:x;c[v>>2]=r;A=G;B=r;C=x;D=t}if(A>>>0>7>>>0){yDb(c[a+4>>2]|0,16,1998928,(I=i,i=i+24|0,c[I>>2]=A,c[I+8>>2]=k,c[I+16>>2]=m,I)|0);i=I;s=-1;i=f;return s|0}t=A>>2;c[a+12488>>2]=t;x=A&3;if((t|0)!=0){J=q;K=D;L=C;M=B;N=x;O=24;break}t=c[1888269]|0;r=D+(B>>>3)|0;v=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(B&7)>>>26;r=b[t+(v<<2)>>1]|0;u=(b[t+(v<<2)+2>>1]|0)+B|0;c[a+14128>>2]=C>>>0>u>>>0?u:C;if(r<<16>>16<0){yDb(c[a+4>>2]|0,16,1994784,(I=i,i=i+24|0,c[I>>2]=x,c[I+8>>2]=k,c[I+16>>2]=m,I)|0);i=I;s=-1;i=f;return s|0}u=r<<16>>16<<2|x;if((q|0)==1){O=22}else{if((A&3|0)==3){P=u}else{O=22}}if((O|0)==22){P=u^60}Bca(a,0,0,g,h)|0;c[g>>2]=ZPa(a,c[g>>2]|0)|0;u=ZPa(a,c[h>>2]|0)|0;c[h>>2]=u;c[a+11736>>2]=1;c[a+11740>>2]=0;c[a+11744>>2]=c[g>>2];c[a+11748>>2]=u;Q=P;R=12296}else{c[a+12488>>2]=1;u=c[a+14092>>2]|0;q=a+14120|0;if((u|0)==2){x=c[646561]|0;r=a+14128|0;v=c[r>>2]|0;t=c[a+14136>>2]|0;z=c[q>>2]|0;p=z+(v>>>3)|0;E=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(v&7)>>>29;p=b[x+(E<<2)>>1]|0;w=(b[x+(E<<2)+2>>1]|0)+v|0;v=t>>>0>w>>>0?w:t;c[r>>2]=v;S=p;T=v;U=t;V=z}else{z=c[1850731]|0;t=a+14128|0;v=c[t>>2]|0;p=c[a+14136>>2]|0;r=c[q>>2]|0;q=r+(v>>>3)|0;w=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(v&7)>>>26;q=b[z+(w<<2)>>1]|0;E=(b[z+(w<<2)+2>>1]|0)+v|0;v=p>>>0>E>>>0?E:p;c[t>>2]=v;S=q;T=v;U=p;V=r}r=S<<16>>16;if(!((S&65535)>>>0>3>>>0)){J=u;K=V;L=U;M=T;N=r;O=24;break}yDb(c[a+4>>2]|0,16,1998928,(I=i,i=i+24|0,c[I>>2]=r,c[I+8>>2]=k,c[I+16>>2]=m,I)|0);i=I;s=-1;i=f;return s|0}}while(0);do{if((O|0)==24){if((J|0)==2){m=a+14128|0;k=d[K+(M>>>3)|0]<<(M&7)>>>7;T=((M|0)<(L|0))+M|0;c[m>>2]=T;c[a+176>>2]=k&1;k=c[1888269]|0;U=K+(T>>>3)|0;V=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(T&7)>>>26;U=b[k+(V<<2)>>1]|0;S=(b[k+(V<<2)+2>>1]|0)+T|0;c[m>>2]=L>>>0>S>>>0?S:L;Q=U<<2|N;R=1;break}c[a+176>>2]=0;U=c[1888269]|0;S=K+(M>>>3)|0;m=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(M&7)>>>26;S=b[U+(m<<2)>>1]|0;T=(b[U+(m<<2)+2>>1]|0)+M|0;c[a+14128>>2]=L>>>0>T>>>0?T:L;T=S<<2|N;if(!n){Q=T;R=1;break}Q=T^60;R=1}}while(0);c[o>>2]=R;me[c[a+10096>>2]&511](c[a+14340>>2]|0);R=0;while(1){if((R|0)>=6){s=0;O=32;break}if((XPa(a,e+(R<<7)|0,R,Q>>>((5-R|0)>>>0)&1,0)|0)<0){break}else{R=R+1|0}}if((O|0)==32){i=f;return s|0}O=c[l>>2]|0;yDb(c[a+4>>2]|0,16,2009304,(I=i,i=i+24|0,c[I>>2]=c[j>>2],c[I+8>>2]=O,c[I+16>>2]=R,I)|0);i=I;s=-1;i=f;return s|0}function UPa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=e+12476|0;m=e+12480|0;n=(ba(c[e+124>>2]|0,c[m>>2]|0)|0)+(c[l>>2]|0)|0;o=(c[e+9160>>2]|0)+(n<<2)|0;do{if((c[e+9992>>2]|0)==2){n=e+14128|0;p=c[n>>2]|0;do{if((c[e+14076>>2]|0)==0){q=p;r=c[e+14136>>2]|0;s=c[e+14120>>2]|0}else{t=c[e+14120>>2]|0;u=d[t+(p>>>3)|0]|0;v=c[e+14136>>2]|0;w=((p|0)<(v|0))+p|0;c[n>>2]=w;if((u&128>>>((p&7)>>>0)|0)==0){q=w;r=v;s=t;break}c[e+12488>>2]=0;TGb(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11744>>2]=0;c[e+11748>>2]=0;c[e+9924>>2]=1;c[o>>2]=14344;x=0;i=g;return x|0}}while(0);p=c[1719062]|0;n=e+14128|0;t=s+(q>>>3)|0;v=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(q&7)>>>23;t=b[p+(v<<2)>>1]|0;w=b[p+(v<<2)+2>>1]|0;v=w<<16>>16;do{if(w<<16>>16<0){u=q+9|0;y=r>>>0>u>>>0?u:r;u=s+(y>>>3)|0;z=((fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(y&7)>>>((v+32|0)>>>0))+t|0;u=b[p+(z<<2)>>1]|0;A=b[p+(z<<2)+2>>1]|0;z=A<<16>>16;if(!(A<<16>>16<0)){B=z;C=u;D=y;break}A=y-v|0;y=r>>>0>A>>>0?A:r;A=s+(y>>>3)|0;E=((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7)>>>((z+32|0)>>>0))+u|0;B=b[p+(E<<2)+2>>1]|0;C=b[p+(E<<2)>>1]|0;D=y}else{B=v;C=t;D=q}}while(0);t=B+D|0;c[n>>2]=r>>>0>t>>>0?t:r;if((C|0)<0){x=-1;i=g;return x|0}else{t=C>>>6&1^1;c[e+12488>>2]=t;F=C&63;G=t;break}}else{t=e+12488|0;c[t>>2]=1;v=c[1620609]|0;p=e+14128|0;w=c[p>>2]|0;y=c[e+14136>>2]|0;E=c[e+14120>>2]|0;u=E+(w>>>3)|0;z=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(w&7)>>>23;u=b[v+(z<<2)>>1]|0;A=b[v+(z<<2)+2>>1]|0;z=A<<16>>16;if(A<<16>>16<0){A=w+9|0;H=y>>>0>A>>>0?A:y;A=E+(H>>>3)|0;E=((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(H&7)>>>((z+32|0)>>>0))+u|0;I=b[v+(E<<2)+2>>1]|0;J=b[v+(E<<2)>>1]|0;K=H}else{I=z;J=u;K=w}w=I+K|0;c[p>>2]=y>>>0>w>>>0?w:y;if((J|0)<0){x=-1;i=g;return x|0}else{y=(Pmb(e,0,h)|0)^J>>>5&1;a[c[h>>2]|0]=y;w=(Pmb(e,1,h)|0)^J>>>4&1;a[c[h>>2]|0]=w;p=(Pmb(e,2,h)|0)^J>>>3&1;a[c[h>>2]|0]=p;u=(Pmb(e,3,h)|0)^J>>>2&1;a[c[h>>2]|0]=u;F=J&1|(J&2|(u<<2|(p<<3|(w<<4|y<<5))));G=c[t>>2]|0;break}}}while(0);do{if((G|0)==0){if(!((c[e+14096>>2]|0)==0|(F|0)==0)){J=e+14128|0;h=c[J>>2]|0;K=c[e+14120>>2]|0;I=d[K+(h>>>3)|0]|0;C=c[e+14136>>2]|0;r=((h|0)<(C|0))+h|0;c[J>>2]=r;if((I&128>>>((h&7)>>>0)|0)==0){L=0}else{h=d[K+(r>>>3)|0]<<(r&7)>>>7;c[J>>2]=((r|0)<(C|0))+r;L=(h&1)+1|0}c[e+14064>>2]=L;c[e+14068>>2]=L}Bca(e,0,0,j,k)|0;if((YPa(e,j,k)|0)<0){x=-1;i=g;return x|0}else{c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11744>>2]=c[j>>2];c[e+11748>>2]=c[k>>2];c[o>>2]=12296;break}}else{h=e+14128|0;r=c[h>>2]|0;C=c[e+14120>>2]|0;J=d[C+(r>>>3)|0]<<(r&7)>>>7;K=e+14136|0;c[h>>2]=((r|0)<(c[K>>2]|0))+r;c[e+176>>2]=J&1;c[o>>2]=1;if((c[e+14112>>2]|0)!=0){J=c[1850529]|0;r=c[h>>2]|0;I=c[K>>2]|0;D=C+(r>>>3)|0;B=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(r&7)>>>29;D=b[J+(B<<2)>>1]|0;q=(b[J+(B<<2)+2>>1]|0)+r|0;c[h>>2]=I>>>0>q>>>0?q:I;c[e+13820>>2]=D}if((c[e+14096>>2]|0)==0|(F|0)==0){break}D=c[h>>2]|0;I=d[C+(D>>>3)|0]|0;q=c[K>>2]|0;K=((D|0)<(q|0))+D|0;c[h>>2]=K;if((I&128>>>((D&7)>>>0)|0)==0){M=0}else{D=d[C+(K>>>3)|0]<<(K&7)>>>7;c[h>>2]=((K|0)<(q|0))+K;M=(D&1)+1|0}c[e+14064>>2]=M;c[e+14068>>2]=M}}while(0);me[c[e+10096>>2]&511](c[e+14340>>2]|0);M=0;while(1){if((M|0)>=6){x=0;N=31;break}if((XPa(e,f+(M<<7)|0,M,F>>>((5-M|0)>>>0)&1,0)|0)<0){break}else{M=M+1|0}}if((N|0)==31){i=g;return x|0}N=c[m>>2]|0;yDb(c[e+4>>2]|0,16,2009304,(e=i,i=i+24|0,c[e>>2]=c[l>>2],c[e+8>>2]=N,c[e+16>>2]=M,e)|0);i=e;x=-1;i=g;return x|0}function VPa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;b=i;e=c[a+14092>>2]|0;f=(e|0)==1;g=a+14128|0;h=c[g>>2]|0;j=c[a+14136>>2]|0;k=c[a+14120>>2]|0;do{if(f){l=k+(h>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)&-65536;l=h+16|0;n=j>>>0>l>>>0?l:j;c[g>>2]=n;l=k+(n>>>3)|0;o=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(n&7)>>>16;l=n+16|0;n=j>>>0>l>>>0?l:j;c[g>>2]=n;if((o|m|0)==256){m=n+5|0;n=j>>>0>m>>>0?m:j;c[g>>2]=n;p=n;break}yDb(c[a+4>>2]|0,16,2245704,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1;i=b;return r|0}else{p=h}}while(0);h=a+14128|0;g=a+14136|0;n=a+14120|0;m=k+(p>>>3)|0;o=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>30;m=p+2|0;p=j>>>0>m>>>0?m:j;c[h>>2]=p;m=o+1|0;c[a+9992>>2]=m;if(!((o|0)==0|(m|0)==2)){yDb(c[a+4>>2]|0,16,2132392,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1;i=b;return r|0}m=k+(p>>>3)|0;l=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>27;m=p+5|0;p=j>>>0>m>>>0?m:j;c[h>>2]=p;m=a+9960|0;c[m>>2]=l;c[a+9964>>2]=l;if((l|0)==0){yDb(c[a+4>>2]|0,16,2126008,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1;i=b;return r|0}do{if((o|0)==0){s=k+(p>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(p&7);s=t>>>27;u=p+5|0;v=j>>>0>u>>>0?u:j;c[h>>2]=v;a:do{if(f){do{if((s|0)!=0){if((s|0)>(c[a+120>>2]|0)){break}c[a+14080>>2]=s;break a}}while(0);yDb(c[a+4>>2]|0,16,2120168,(q=i,i=i+8|0,c[q>>2]=s,q)|0);i=q;r=-1;i=b;return r|0}else{if(!(t>>>0<3087007744>>>0)){c[a+14080>>2]=(c[a+120>>2]|0)/(s-22|0)|0;break}yDb(c[a+4>>2]|0,16,2114016,(q=i,i=i+8|0,c[q>>2]=s,q)|0);i=q;r=-1;i=b;return r|0}}while(0);if((e|0)==4){WPa(a,4)|0;do{if((c[a+24>>2]|0)>51200){s=c[h>>2]|0;t=(d[(c[n>>2]|0)+(s>>>3)|0]|0)<<(s&7)>>>7;c[h>>2]=((s|0)<(c[g>>2]|0))+s;s=t&1;c[a+14096>>2]=s;if((s|0)==0){w=29;break}x=c[h>>2]|0;y=c[n>>2]|0;z=c[g>>2]|0}else{c[a+14096>>2]=0;w=29}}while(0);if((w|0)==29){s=c[h>>2]|0;t=c[n>>2]|0;u=d[t+(s>>>3)|0]|0;A=c[g>>2]|0;B=((s|0)<(A|0))+s|0;c[h>>2]=B;if((u&128>>>((s&7)>>>0)|0)==0){C=0;D=B}else{s=(d[t+(B>>>3)|0]|0)<<(B&7)>>>7;u=((B|0)<(A|0))+B|0;c[h>>2]=u;C=(s&1)+1|0;D=u}c[a+14068>>2]=C;u=d[t+(D>>>3)|0]|0;s=((D|0)<(A|0))+D|0;c[h>>2]=s;if((u&128>>>((D&7)>>>0)|0)==0){E=0;F=s}else{u=(d[t+(s>>>3)|0]|0)<<(s&7)>>>7;B=((s|0)<(A|0))+s|0;c[h>>2]=B;E=(u&1)+1|0;F=B}c[a+14064>>2]=E;x=F;y=t;z=A}A=(d[y+(x>>>3)|0]|0)<<(x&7)>>>7;c[h>>2]=((x|0)<(z|0))+x;c[a+14072>>2]=A&1;c[a+14112>>2]=0}else if((e|0)==1|(e|0)==2){c[a+14068>>2]=2;c[a+14064>>2]=2;c[a+14072>>2]=0}else if((e|0)==3){A=d[k+(v>>>3)|0]|0;t=((v|0)<(j|0))+v|0;c[h>>2]=t;if((A&128>>>((v&7)>>>0)|0)==0){G=0;H=t}else{A=(d[k+(t>>>3)|0]|0)<<(t&7)>>>7;B=((t|0)<(j|0))+t|0;c[h>>2]=B;G=(A&1)+1|0;H=B}c[a+14068>>2]=G;B=d[k+(H>>>3)|0]|0;A=((H|0)<(j|0))+H|0;c[h>>2]=A;if((B&128>>>((H&7)>>>0)|0)==0){I=0;J=A}else{B=(d[k+(A>>>3)|0]|0)<<(A&7)>>>7;t=((A|0)<(j|0))+A|0;c[h>>2]=t;I=(B&1)+1|0;J=t}c[a+14064>>2]=I;t=(d[k+(J>>>3)|0]|0)<<(J&7)>>>7;c[h>>2]=((J|0)<(j|0))+J;c[a+14072>>2]=t&1}c[a+12472>>2]=1;t=c[a+4>>2]|0;if((c[t+688>>2]&1|0)==0){break}B=c[a+14068>>2]|0;A=c[a+14064>>2]|0;u=c[a+14072>>2]|0;s=c[a+14096>>2]|0;K=c[a+14080>>2]|0;yDb(t,48,2099736,(q=i,i=i+48|0,c[q>>2]=c[m>>2],c[q+8>>2]=B,c[q+16>>2]=A,c[q+24>>2]=u,c[q+32>>2]=s,c[q+40>>2]=K,q)|0);i=q}else{if((e|0)==1){c[a+14076>>2]=1;w=40}else if((e|0)==2){K=(d[k+(p>>>3)|0]|0)<<(p&7)>>>7;c[h>>2]=((p|0)<(j|0))+p;c[a+14076>>2]=K&1;w=40}else if((e|0)==3){K=(d[k+(p>>>3)|0]|0)<<(p&7)>>>7;s=((p|0)<(j|0))+p|0;c[h>>2]=s;c[a+14076>>2]=K&1;K=d[k+(s>>>3)|0]|0;u=((s|0)<(j|0))+s|0;c[h>>2]=u;if((K&128>>>((s&7)>>>0)|0)==0){L=0;M=u}else{s=(d[k+(u>>>3)|0]|0)<<(u&7)>>>7;K=((u|0)<(j|0))+u|0;c[h>>2]=K;L=(s&1)+1|0;M=K}c[a+14064>>2]=L;c[a+14068>>2]=L;K=(d[k+(M>>>3)|0]|0)<<(M&7)>>>7;s=((M|0)<(j|0))+M|0;c[h>>2]=s;c[a+14072>>2]=K&1;K=(d[k+(s>>>3)|0]|0)<<(s&7)>>>7;c[h>>2]=((s|0)<(j|0))+s;c[a+14060>>2]=K&1}else if((e|0)==4){K=(d[k+(p>>>3)|0]|0)<<(p&7)>>>7;s=((p|0)<(j|0))+p|0;c[h>>2]=s;c[a+14076>>2]=K&1;K=c[a+24>>2]|0;if((K|0)>51200){u=(d[k+(s>>>3)|0]|0)<<(s&7)>>>7;A=((s|0)<(j|0))+s|0;c[h>>2]=A;B=u&1;c[a+14096>>2]=B;if((B|0)==0){N=A;w=47}else{O=A}}else{c[a+14096>>2]=0;N=s;w=47}if((w|0)==47){s=d[k+(N>>>3)|0]|0;A=((N|0)<(j|0))+N|0;c[h>>2]=A;if((s&128>>>((N&7)>>>0)|0)==0){P=0;Q=A}else{s=(d[k+(A>>>3)|0]|0)<<(A&7)>>>7;B=((A|0)<(j|0))+A|0;c[h>>2]=B;P=(s&1)+1|0;Q=B}c[a+14064>>2]=P;c[a+14068>>2]=P;O=Q}B=(d[k+(O>>>3)|0]|0)<<(O&7)>>>7;s=((O|0)<(j|0))+O|0;c[h>>2]=s;c[a+14072>>2]=B&1;B=(d[k+(s>>>3)|0]|0)<<(s&7)>>>7;c[h>>2]=((s|0)<(j|0))+s;c[a+14060>>2]=B&1;if((ba(c[a+12>>2]|0,c[a+8>>2]|0)|0)<76800){R=(K|0)<131073|0}else{R=0}c[a+14112>>2]=R}if((w|0)==40){c[a+14064>>2]=2;c[a+14068>>2]=2;c[a+14072>>2]=0;c[a+14060>>2]=0}K=c[a+4>>2]|0;if((c[K+688>>2]&1|0)!=0){B=c[a+14064>>2]|0;s=c[a+14068>>2]|0;A=c[a+14072>>2]|0;u=c[a+14060>>2]|0;t=c[a+14096>>2]|0;yDb(K,48,2093224,(q=i,i=i+56|0,c[q>>2]=c[a+14076>>2],c[q+8>>2]=B,c[q+16>>2]=s,c[q+24>>2]=A,c[q+32>>2]=u,c[q+40>>2]=t,c[q+48>>2]=l,q)|0);i=q}t=a+12472|0;if((c[a+14088>>2]|0)==0){c[t>>2]=0;break}else{c[t>>2]=c[t>>2]^1;break}}}while(0);c[a+14100>>2]=0;c[a+14104>>2]=0;r=0;i=b;return r|0}function WPa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=a+14128|0;g=c[f>>2]|0;h=(b<<3)-g|0;b=c[a+14092>>2]|0;j=(b|0)>2;k=j?17:16;l=(h|0)<(k|8|0);if((h|0)>=(k|0)&l){k=c[a+14136>>2]|0;m=g+5|0;g=k>>>0>m>>>0?m:k;c[f>>2]=g;m=c[a+14120>>2]|0;n=m+(g>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(g&7)>>>21;n=g+11|0;g=k>>>0>n>>>0?n:k;c[f>>2]=g;c[a+24>>2]=o<<10;if(j){j=(d[m+(g>>>3)|0]|0)<<(g&7)>>>7;c[f>>2]=((g|0)<(k|0))+g;c[a+14088>>2]=j&1;i=e;return 0}else{c[a+14088>>2]=0;i=e;return 0}}if(!l){yDb(c[a+4>>2]|0,16,2083312,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;i=e;return 0}c[a+14088>>2]=0;if((b|0)==2){i=e;return 0}yDb(c[a+4>>2]|0,16,2087952,(p=i,i=i+8|0,c[p>>2]=h,p)|0);i=p;i=e;return 0}function XPa(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=e+12488|0;do{if((c[n>>2]|0)==0){o=e+9960|0;p=c[o>>2]|0;q=(c[e+14064>>2]|0)+3|0;if((h|0)!=0){r=c[e+14092>>2]|0;s=(j|0)==0?e+236|0:j;t=-1;u=(r|0)!=2;v=1146840+(q*192|0)|0;w=p-1|1;x=p<<1;y=1146904+(q*192|0)+(p<<2)|0;z=r;A=o;B=52;break}c[e+180+(g<<2)>>2]=-1;C=0;i=k;return C|0}else{o=e+14092|0;r=c[o>>2]|0;p=(g|0)<4;q=e+14120|0;do{if((r|0)<3){if(p){D=c[646567]|0;E=e+14128|0;F=c[E>>2]|0;G=c[e+14136>>2]|0;H=c[q>>2]|0;I=H+(F>>>3)|0;J=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(F&7)>>>23;I=b[D+(J<<2)>>1]|0;K=b[D+(J<<2)+2>>1]|0;J=K<<16>>16;do{if(K<<16>>16<0){L=F+9|0;M=G>>>0>L>>>0?L:G;L=H+(M>>>3)|0;N=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>((J+32|0)>>>0))+I|0;L=b[D+(N<<2)>>1]|0;O=b[D+(N<<2)+2>>1]|0;N=O<<16>>16;if(!(O<<16>>16<0)){P=N;Q=L;R=M;break}O=M-J|0;M=G>>>0>O>>>0?O:G;O=H+(M>>>3)|0;S=((fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(M&7)>>>((N+32|0)>>>0))+L|0;P=b[D+(S<<2)+2>>1]|0;Q=b[D+(S<<2)>>1]|0;R=M}else{P=J;Q=I;R=F}}while(0);F=P+R|0;c[E>>2]=G>>>0>F>>>0?F:G;T=Q}else{F=c[646573]|0;I=e+14128|0;J=c[I>>2]|0;D=c[e+14136>>2]|0;H=c[q>>2]|0;K=H+(J>>>3)|0;M=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(J&7)>>>23;K=b[F+(M<<2)>>1]|0;S=b[F+(M<<2)+2>>1]|0;M=S<<16>>16;do{if(S<<16>>16<0){L=J+9|0;N=D>>>0>L>>>0?L:D;L=H+(N>>>3)|0;O=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(N&7)>>>((M+32|0)>>>0))+K|0;L=b[F+(O<<2)>>1]|0;U=b[F+(O<<2)+2>>1]|0;O=U<<16>>16;if(!(U<<16>>16<0)){V=O;W=L;X=N;break}U=N-M|0;N=D>>>0>U>>>0?U:D;U=H+(N>>>3)|0;Y=((fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(N&7)>>>((O+32|0)>>>0))+L|0;V=b[F+(Y<<2)+2>>1]|0;W=b[F+(Y<<2)>>1]|0;X=N}else{V=M;W=K;X=J}}while(0);J=V+X|0;c[I>>2]=D>>>0>J>>>0?J:D;T=W}if((T|0)<0){J=e+4|0;yDb(c[J>>2]|0,16,2013520,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;c[m>>2]=0;_=-1;$=J;B=36;break}else{aa=T-256|0;B=29;break}}else{J=c[e+14072>>2]|0;if(p){K=c[6482460+(J*20|0)>>2]|0;M=e+14128|0;F=c[M>>2]|0;H=c[e+14136>>2]|0;S=c[q>>2]|0;G=S+(F>>>3)|0;E=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(F&7)>>>23;G=b[K+(E<<2)>>1]|0;N=b[K+(E<<2)+2>>1]|0;E=N<<16>>16;do{if(N<<16>>16<0){Y=F+9|0;L=H>>>0>Y>>>0?Y:H;Y=S+(L>>>3)|0;O=((fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(L&7)>>>((E+32|0)>>>0))+G|0;Y=b[K+(O<<2)>>1]|0;U=b[K+(O<<2)+2>>1]|0;O=U<<16>>16;if(!(U<<16>>16<0)){ca=O;da=Y;ea=L;break}U=L-E|0;L=H>>>0>U>>>0?U:H;U=S+(L>>>3)|0;fa=((fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(L&7)>>>((O+32|0)>>>0))+Y|0;ca=b[K+(fa<<2)+2>>1]|0;da=b[K+(fa<<2)>>1]|0;ea=L}else{ca=E;da=G;ea=F}}while(0);F=ca+ea|0;G=H>>>0>F>>>0?F:H;c[M>>2]=G;ga=da;ha=G;ia=S;ja=H}else{G=c[6482500+(J*20|0)>>2]|0;F=e+14128|0;E=c[F>>2]|0;K=c[e+14136>>2]|0;N=c[q>>2]|0;D=N+(E>>>3)|0;I=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7)>>>23;D=b[G+(I<<2)>>1]|0;L=b[G+(I<<2)+2>>1]|0;I=L<<16>>16;do{if(L<<16>>16<0){fa=E+9|0;Y=K>>>0>fa>>>0?fa:K;fa=N+(Y>>>3)|0;O=((fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Y&7)>>>((I+32|0)>>>0))+D|0;fa=b[G+(O<<2)>>1]|0;U=b[G+(O<<2)+2>>1]|0;O=U<<16>>16;if(!(U<<16>>16<0)){ka=O;la=fa;ma=Y;break}U=Y-I|0;Y=K>>>0>U>>>0?U:K;U=N+(Y>>>3)|0;na=((fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(Y&7)>>>((O+32|0)>>>0))+fa|0;ka=b[G+(na<<2)+2>>1]|0;la=b[G+(na<<2)>>1]|0;ma=Y}else{ka=I;la=D;ma=E}}while(0);E=ka+ma|0;D=K>>>0>E>>>0?E:K;c[F>>2]=D;ga=la;ha=D;ia=N;ja=K}if((ga|0)<0){D=e+4|0;yDb(c[D>>2]|0,16,2013520,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;c[m>>2]=0;_=-1;$=D;B=36;break}if((ga|0)==119){D=e+14128|0;E=ia+(ha>>>3)|0;I=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(ha&7)>>>24;E=ha+8|0;G=ja>>>0>E>>>0?E:ja;c[D>>2]=G;E=d[ia+(G>>>3)|0]|0;c[D>>2]=((G|0)<(ja|0))+G;aa=(E&128>>>((G&7)>>>0)|0)==0?I:-I|0;B=29;break}else if((ga|0)==0){aa=0;B=29;break}else{I=d[ia+(ha>>>3)|0]|0;c[e+14128>>2]=((ha|0)<(ja|0))+ha;aa=(I&128>>>((ha&7)>>>0)|0)==0?ga:-ga|0;B=29;break}}}while(0);do{if((B|0)==29){do{if((r|0)==1){q=e+9860+((p?0:g-3|0)<<2)|0;I=(c[q>>2]|0)+aa|0;c[q>>2]=I;oa=I}else{I=(Qmb(e,g,l,m)|0)+aa|0;if(p){q=(ba(c[e+168>>2]|0,I)|0)&65535;b[c[l>>2]>>1]=q;oa=I;break}else{q=(ba(c[e+172>>2]|0,I)|0)&65535;b[c[l>>2]>>1]=q;oa=I;break}}}while(0);if((oa|0)>=0){pa=oa;break}_=oa;$=e+4|0;B=36}}while(0);if((B|0)==36){r=c[e+9960>>2]|0;yDb(c[$>>2]|0,16,2077712,(Z=i,i=i+16|0,c[Z>>2]=g,c[Z+8>>2]=r,Z)|0);i=Z;pa=(c[e+14112>>2]|0)==0?_:0}do{if(p){r=1146840+((c[e+14064>>2]|0)*192|0)|0;if((pa|0)<=(c[e+168>>2]<<8|0)){qa=r;break}yDb(c[e+4>>2]|0,16,2072888,(Z=i,i=i+8|0,c[Z>>2]=c[e+9960>>2],Z)|0);i=Z;if((c[e+14112>>2]|0)==0){C=-1}else{qa=r;break}i=k;return C|0}else{r=1146840+(((c[e+14068>>2]|0)+3|0)*192|0)|0;if((pa|0)<=(c[e+172>>2]<<8|0)){qa=r;break}yDb(c[e+4>>2]|0,16,2068272,(Z=i,i=i+8|0,c[Z>>2]=c[e+9960>>2],Z)|0);i=Z;if((c[e+14112>>2]|0)==0){C=-1}else{qa=r;break}i=k;return C|0}}while(0);b[f>>1]=pa;p=c[o>>2]|0;r=(p|0)>3;if((h|0)==0){ra=0;break}do{if((c[e+176>>2]|0)==0){sa=e+368|0}else{if((c[m>>2]|0)==0){sa=e+632|0;break}else{sa=e+500|0;break}}}while(0);s=sa;t=0;u=r;v=qa;w=0;x=1;y=qa+64|0;z=p;A=e+9960|0;B=52}}while(0);if((B|0)==52){qa=u&1;u=c[y>>2]|0;y=e+14128|0;sa=c[y>>2]|0;h=c[e+14136>>2]|0;pa=-w|0;_=e+14100|0;$=e+14104|0;oa=c[e+14120>>2]|0;l=t;t=sa;while(1){aa=oa+(t>>>3)|0;ga=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(t&7);aa=ga>>>23;ha=b[u+(aa<<2)>>1]|0;ja=a[u+(aa<<2)+2|0]|0;ia=ja<<24>>24;if(ja<<24>>24<0){ja=ga<<9;la=t+9|0;ma=(ja>>>((ia+32|0)>>>0))+ha|0;ta=b[u+(ma<<2)>>1]|0;ua=ma;va=a[u+(ma<<2)+2|0]|0;wa=ja;xa=h>>>0>la>>>0?la:h}else{ta=ha;ua=aa;va=ia;wa=ga;xa=t}ga=wa<<va;ia=va+xa|0;aa=h>>>0>ia>>>0?ia:h;a:do{if((ta|0)==0){ia=(z|0)==1;if(!(ia|(ga|0)>-1)){ha=aa+1|0;la=h>>>0>ha>>>0?ha:h;ha=ga>>>22&511;ja=b[u+(ha<<2)>>1]|0;ma=a[u+(ha<<2)+2|0]|0;ka=ma<<24>>24;if(ma<<24>>24<0){ma=la+9|0;da=h>>>0>ma>>>0?ma:h;ma=oa+(da>>>3)|0;ea=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(da&7);ma=(ea>>>((ka+32|0)>>>0))+ja|0;ya=ma;za=a[u+(ma<<2)+2|0]|0;Aa=b[u+(ma<<2)>>1]|0;Ba=ea;Ca=da}else{ya=ha;za=ka;Aa=ja;Ba=ga<<1;Ca=la}la=d[u+(ya<<2)+3|0]|0;ja=za+Ca|0;ka=Ba<<za>>31;ha=((ba(a[(c[v+28+(la>>>7<<2)>>2]|0)+(la+63&63)|0]|0,x)|0)+Aa^ka)-ka|0;ka=(h>>>0>ja>>>0?ja:h)+1|0;Da=ha;Ea=la+l|0;Fa=h>>>0>ka>>>0?ka:h;break}do{if(ia){Ga=aa}else{if((ga&1073741824|0)==0){ka=aa+2|0;Ga=h>>>0>ka>>>0?ka:h;break}ka=aa+2|0;la=h>>>0>ka>>>0?ka:h;ka=ga>>>21&511;ha=b[u+(ka<<2)>>1]|0;ja=a[u+(ka<<2)+2|0]|0;da=ja<<24>>24;if(ja<<24>>24<0){ja=la+9|0;ea=h>>>0>ja>>>0?ja:h;ja=oa+(ea>>>3)|0;ma=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ea&7);ja=(ma>>>((da+32|0)>>>0))+ha|0;Ha=ja;Ia=b[u+(ja<<2)>>1]|0;Ja=a[u+(ja<<2)+2|0]|0;Ka=ma;La=ea}else{Ha=ka;Ia=ha;Ja=da;Ka=ga<<2;La=la}la=d[u+(Ha<<2)+3|0]|0;da=Ja+La|0;ha=Ka<<Ja>>31;ka=(h>>>0>da>>>0?da:h)+1|0;Da=(ha^Ia)-ha|0;Ea=l+qa+la+(a[(c[v+36+(la>>>7<<2)>>2]|0)+((Ia|0)/(x|0)|0)|0]|0)|0;Fa=h>>>0>ka>>>0?ka:h;break a}}while(0);ia=oa+(Ga>>>3)|0;ka=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(Ga&7);ia=ka<<1;do{if((z|0)<4){la=Ga+15|0;Ma=ka<<7>>24;Na=ka>>>25&63;Oa=h>>>0>la>>>0?la:h}else{la=Ga+1|0;ha=h>>>0>la>>>0?la:h;la=c[_>>2]|0;if((la|0)==0){do{if((c[A>>2]|0)<8){da=ka>>>28&7;ea=ha+3|0;ma=h>>>0>ea>>>0?ea:h;if((da|0)!=0){Pa=da;Qa=ka<<4;Ra=ma;break}da=ma+1|0;Pa=ka>>>27&1|8;Qa=ka<<5;Ra=h>>>0>da>>>0?da:h}else{if((ia|0)>-1){da=ha;ma=ia;ea=2;do{ea=ea+1|0;ma=ma<<1;ja=da+1|0;da=h>>>0>ja>>>0?ja:h;Sa=(ea|0)<8;}while(Sa&(ma|0)>-1);if(Sa){Ta=ea;Ua=ma;Va=da}else{Pa=ea;Qa=ma;Ra=da;break}}else{Ta=2;Ua=ia;Va=ha}ja=Va+1|0;Pa=Ta;Qa=Ua<<1;Ra=h>>>0>ja>>>0?ja:h}}while(0);c[_>>2]=Pa;ja=(Qa>>>30)+3|0;c[$>>2]=ja;ca=Ra+2|0;T=h>>>0>ca>>>0?ca:h;ca=oa+(T>>>3)|0;Wa=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(T&7);Xa=T;Ya=Pa;Za=ja}else{Wa=ia;Xa=ha;Ya=la;Za=c[$>>2]|0}ja=Wa>>>((32-Za|0)>>>0);T=Wa<<Za;ca=Za+Xa|0;W=(h>>>0>ca>>>0?ca:h)+1|0;ca=T<<1>>>((32-Ya|0)>>>0);X=(h>>>0>W>>>0?W:h)+Ya|0;W=h>>>0>X>>>0?X:h;if((T|0)>=0){Ma=ca;Na=ja;Oa=W;break}Ma=-ca|0;Na=ja;Oa=W}}while(0);ia=ba(Ma,x)|0;W=((Ma|0)>0?w:pa)+ia|0;ia=l+1+Na|0;if((ka|0)>=0){Da=W;Ea=ia;Fa=Oa;break}Da=W;Ea=ia+192|0;Fa=Oa}else{ia=ga>>31;W=aa+1|0;Da=(ta^ia)-ia|0;Ea=(d[u+(ua<<2)+3|0]|0)+l|0;Fa=h>>>0>W>>>0?W:h}}while(0);if((Ea|0)>62){break}b[f+(d[s+Ea|0]<<1)>>1]=Da;l=Ea;t=Fa}t=Ea-192|0;do{if(t>>>0>63>>>0){l=(c[e+14132>>2]|0)-sa|0;do{if((Ea|0)==64){if(!(((Da|0)/(x|0)|0|0)==-1)){B=87;break}if((l|0)>-1){B=89}}else{B=87}}while(0);if((B|0)==87){if((c[e+13740>>2]&131074|0)==0&(l|0)>-1){B=89}}if((B|0)==89){h=c[e+12480>>2]|0;yDb(c[e+4>>2]|0,16,2063952,(Z=i,i=i+16|0,c[Z>>2]=c[e+12476>>2],c[Z+8>>2]=h,Z)|0);i=Z;_a=63;break}h=c[e+12480>>2]|0;yDb(c[e+4>>2]|0,16,2060064,(Z=i,i=i+16|0,c[Z>>2]=c[e+12476>>2],c[Z+8>>2]=h,Z)|0);i=Z;C=-1;i=k;return C|0}else{b[f+(d[s+t|0]<<1)>>1]=Da;_a=t}}while(0);c[y>>2]=Fa;ra=_a}if((c[n>>2]|0)==0){$a=ra}else{_Ma(e,f,g,c[m>>2]|0);$a=(c[e+176>>2]|0)==0?ra:63}c[e+180+(g<<2)>>2]=(c[e+14092>>2]|0)>3&($a|0)>0?63:$a;C=0;i=k;return C|0}function YPa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[a+14060>>2]|0;j=c[1172524+(h*44|0)>>2]|0;k=a+14128|0;l=c[k>>2]|0;m=c[a+14136>>2]|0;n=c[a+14120>>2]|0;o=n+(l>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>23;o=b[j+(p<<2)>>1]|0;q=b[j+(p<<2)+2>>1]|0;p=q<<16>>16;if(q<<16>>16<0){q=l+9|0;r=m>>>0>q>>>0?q:m;q=n+(r>>>3)|0;s=((fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>((p+32|0)>>>0))+o|0;t=b[j+(s<<2)+2>>1]|0;u=b[j+(s<<2)>>1]|0;v=r}else{t=p;u=o;v=l}l=t+v|0;v=m>>>0>l>>>0?l:m;c[k>>2]=v;if((u|0)<0){l=c[a+12480>>2]|0;yDb(c[a+4>>2]|0,16,2055272,(t=i,i=i+16|0,c[t>>2]=c[a+12476>>2],c[t+8>>2]=l,t)|0);i=t;w=-1;i=g;return w|0}if((u|0)==(c[1172496+(h*44|0)>>2]|0)){t=n+(v>>>3)|0;l=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>26;t=v+6|0;v=m>>>0>t>>>0?t:m;c[k>>2]=v;t=n+(v>>>3)|0;n=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>26;t=v+6|0;c[k>>2]=m>>>0>t>>>0?t:m;x=n;y=l}else{x=d[(c[1172512+(h*44|0)>>2]|0)+u|0]|0;y=d[(c[1172508+(h*44|0)>>2]|0)+u|0]|0}u=y-32+(c[e>>2]|0)|0;y=x-32+(c[f>>2]|0)|0;if((u|0)<-63){z=u+64|0}else{z=(u|0)>63?u-64|0:u}if((y|0)<-63){A=y+64|0}else{A=(y|0)>63?y-64|0:y}c[e>>2]=z;c[f>>2]=A;w=0;i=g;return w|0}function ZPa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[646549]|0;g=a+14128|0;h=c[g>>2]|0;i=c[a+14136>>2]|0;j=c[a+14120>>2]|0;a=j+(h>>>3)|0;k=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(h&7)>>>23;a=b[f+(k<<2)>>1]|0;l=b[f+(k<<2)+2>>1]|0;k=l<<16>>16;if(l<<16>>16<0){l=h+9|0;m=i>>>0>l>>>0?l:i;l=j+(m>>>3)|0;n=((fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>((k+32|0)>>>0))+a|0;o=b[f+(n<<2)+2>>1]|0;p=b[f+(n<<2)>>1]|0;q=m}else{o=k;p=a;q=h}h=o+q|0;q=i>>>0>h>>>0?h:i;c[g>>2]=q;if((p|0)<0){r=65535;return r|0}if((p|0)==0){r=e;return r|0}h=d[j+(q>>>3)|0]|0;c[g>>2]=((q|0)<(i|0))+q;i=((h&128>>>((q&7)>>>0)|0)==0?p:-p|0)+e|0;if(!((i|0)<-63)){return((i|0)>63?i-64|0:i)|0}r=i+64|0;return r|0}function _Pa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b|0;f=c[e>>2]|0;g=b+4|0;h=c[g>>2]|0;i=(h|0)>1;if((d|0)==0){if(i){j=h-1|0;k=f<<1;c[e>>2]=k;c[g>>2]=j;return}else{l=fe(f<<h|0)|0;m=b+12|0;n=c[m>>2]|0;x=l;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;j=h+31|0;k=0;c[e>>2]=k;c[g>>2]=j;return}}if(i){o=h-1|0;p=f<<1|1}else{i=fe(1>>>((1-h|0)>>>0)|f<<h|0)|0;f=b+12|0;m=c[f>>2]|0;x=i;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;o=h+31|0;p=1}c[e>>2]=p;c[g>>2]=o;h=(d|0)>1|0;if((o|0)>1){j=o-1|0;k=p<<1|h;c[e>>2]=k;c[g>>2]=j;return}else{d=fe(h>>>((1-o|0)>>>0)|p<<o|0)|0;p=b+12|0;b=c[p>>2]|0;x=d;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;j=o+31|0;k=h;c[e>>2]=k;c[g>>2]=j;return}}function $Pa(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;Omb(f);if((c[f+14092>>2]|0)>3){c[f+13080>>2]=-255;c[f+13084>>2]=255}if(a[1174072]|0){return}a[1174072]=1;f=WDb(8192)|0;c[293129]=f;g=c[293124]|0;h=g&65535;i=0;do{b[f+(i<<1)>>1]=h;i=i+1|0;}while((i|0)<4096);if((g|0)>0){i=c[293127]|0;h=c[293128]|0;j=0;do{b[f+((d[h+j|0]|d[i+j|0]<<6)<<1)>>1]=j;j=j+1|0;}while((j|0)<(g|0))}g=WDb(8192)|0;c[293140]=g;j=c[293135]|0;i=j&65535;h=0;do{b[g+(h<<1)>>1]=i;h=h+1|0;}while((h|0)<4096);if((j|0)>0){h=c[293138]|0;i=c[293139]|0;f=0;do{b[g+((d[i+f|0]|d[h+f|0]<<6)<<1)>>1]=f;f=f+1|0;}while((f|0)<(j|0))}OOa(1146840,5396608);OOa(1147032,5396998);OOa(1147224,5397388);OOa(1147416,5397778);OOa(1147608,5398168);OOa(1147800,5398558);j=0;do{f=1146840+(j*192|0)|0;h=1146848+(j*192|0)|0;i=1;do{g=i-1|0;k=0;do{l=c[f>>2]|0;m=0;do{n=c[1146860+(j*192|0)+(m<<2)>>2]|0;o=d[n+k|0]|0;p=c[1146868+(j*192|0)+(m<<2)>>2]|0;q=a[p+k|0]|0;do{if((o|0)<(l|0)){if((q<<24>>24|0)<(i|0)){r=20;break}s=g+o|0;t=c[h>>2]|0;u=e[t+(s<<2)+2>>1]|0;if((s|0)==(l|0)){v=t;w=u;r=22;break}x=u+1&255}else{r=20}}while(0);if((r|0)==20){r=0;u=c[h>>2]|0;v=u;w=e[u+(l<<2)+2>>1]|0;r=22}a:do{if((r|0)==22){r=0;u=q<<24>>24;t=i-u|0;do{if((t|0)>=1){if((o|0)>=(l|0)|(u|0)<(t|0)){break}s=o-1+t|0;if((s|0)==(l|0)){break}x=w+2+(e[v+(s<<2)+2>>1]|0)&255;break a}}while(0);t=k-(a[(c[1146876+(j*192|0)+(m<<2)>>2]|0)+i|0]|0)-1|0;do{if((t|0)>=0){u=d[n+t|0]|0;if((u|0)>=(l|0)){break}if((a[p+t|0]|0)<(i|0)){break}s=g+u|0;if((s|0)==(l|0)){break}x=w+3+(e[v+(s<<2)+2>>1]|0)&255;break a}}while(0);x=w+17&255}}while(0);a[4546616+(j*8450|0)+(i*130|0)+(k<<1)+m|0]=x;m=m+1|0;}while((m|0)<2);k=k+1|0;}while((k|0)<65);i=i+1|0;}while((i|0)<65);j=j+1|0;}while((j|0)<6);return}function aQa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;e=b+14108|0;f=b+9992|0;g=2147483647;h=0;i=2147483647;j=0;k=0;while(1){l=(k|0)>0|0;m=k+3|0;n=0;o=l;p=l;while(1){l=0;q=p;r=o;while(1){if((l|0)>=65){s=q;t=r;break}u=c[e>>2]|0;v=(c[f>>2]|0)==1;w=c[u+101400+(n*520|0)+(l<<3)>>2]|0;y=ba(d[4546616+(k*8450|0)+(n*130|0)+(l<<1)|0]|0,c[u+67600+(n*520|0)+(l<<3)>>2]|0)|0;if(v){z=y;A=(ba(d[4546616+(m*8450|0)+(n*130|0)+(l<<1)|0]|0,w)|0)+r|0}else{z=(ba(d[4546616+(m*8450|0)+(n*130|0)+(l<<1)|0]|0,(c[u+33800+(n*520|0)+(l<<3)>>2]|0)+w+(c[u+(n*520|0)+(l<<3)>>2]|0)|0)|0)+y|0;A=r}y=c[u+101400+(n*520|0)+(l<<3)+4>>2]|0;w=ba(d[4546616+(k*8450|0)+(n*130|0)+(l<<1)+1|0]|0,c[u+67600+(n*520|0)+(l<<3)+4>>2]|0)|0;if(v){B=w;C=(ba(d[4546616+(m*8450|0)+(n*130|0)+(l<<1)+1|0]|0,y)|0)+A|0}else{B=(ba(d[4546616+(m*8450|0)+(n*130|0)+(l<<1)+1|0]|0,(c[u+33800+(n*520|0)+(l<<3)+4>>2]|0)+y+(c[u+(n*520|0)+(l<<3)+4>>2]|0)|0)|0)+w|0;C=A}w=z+q+B|0;if((q+r|0)==(w+C|0)){s=w;t=C;break}else{l=l+1|0;q=w;r=C}}r=n+1|0;if((r|0)<65){n=r;o=t;p=s}else{break}}p=(s|0)<(i|0);D=p?k:j;o=(t|0)<(g|0);E=o?k:h;n=k+1|0;if((n|0)<3){g=o?t:g;h=E;i=p?s:i;j=D;k=n}else{break}}k=(c[f>>2]|0)==2?D:E;TGb(c[e>>2]|0,0,135200)|0;e=b+14064|0;c[e>>2]=D;D=b+14068|0;c[D>>2]=k;k=c[f>>2]|0;do{if((k|0)!=(c[b+10004>>2]|0)){c[e>>2]=2;if((k|0)==1){c[D>>2]=1;break}else{c[D>>2]=2;break}}}while(0);k=b+784|0;K_(k);E=(c[f>>2]|0)-1|0;j=k|0;k=c[j>>2]|0;i=b+788|0;s=c[i>>2]|0;if((s|0)>2){F=s-2|0;G=k<<2|E}else{h=fe(E>>>((2-s|0)>>>0)|k<<s|0)|0;k=b+796|0;g=c[k>>2]|0;x=h;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;F=s+30|0;G=E}c[j>>2]=G;c[i>>2]=F;E=c[b+9960>>2]|0;if((F|0)>5){H=F-5|0;I=G<<5|E}else{s=fe(G<<F|E>>>((5-F|0)>>>0)|0)|0;G=b+796|0;k=c[G>>2]|0;x=s;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;H=F+27|0;I=E}c[j>>2]=I;c[i>>2]=H;E=b+14092|0;F=c[E>>2]|0;if((F|0)<3){c[e>>2]=2;c[D>>2]=2}G=b+14072|0;c[G>>2]=1;k=b+14060|0;c[k>>2]=1;c[b+14076>>2]=1;s=b+14096|0;c[s>>2]=0;if((F|0)==4){do{if((ba(c[b+12>>2]|0,c[b+8>>2]|0)|0)<76800){if((c[b+24>>2]|0)>=131073){J=0;break}J=(c[f>>2]|0)==2|0}else{J=0}}while(0);c[b+14112>>2]=J}if((c[f>>2]|0)!=1){if((H|0)>1){K=H-1|0;L=I<<1|1;M=F}else{f=fe(1>>>((1-H|0)>>>0)|I<<H|0)|0;J=b+796|0;g=c[J>>2]|0;x=f;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[J>>2]=(c[J>>2]|0)+4;K=H+31|0;L=1;M=c[E>>2]|0}c[j>>2]=L;c[i>>2]=K;do{if((M|0)==4){if((c[b+24>>2]|0)<=51200){N=K;O=L;break}J=c[s>>2]|0;if((K|0)>1){P=K-1|0;Q=L<<1|J;R=4}else{g=fe(L<<K|J>>>((1-K|0)>>>0)|0)|0;f=b+796|0;h=c[f>>2]|0;x=g;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;P=K+31|0;Q=J;R=c[E>>2]|0}c[j>>2]=Q;c[i>>2]=P;S=R;T=Q;U=P;V=79}else{S=M;T=L;U=K;V=79}}while(0);do{if((V|0)==79){if((S|0)>2){N=U;O=T;break}W=b+14100|0;c[W>>2]=0;X=b+14104|0;c[X>>2]=0;return}}while(0);if((c[s>>2]|0)==0){T=c[e>>2]|0;U=(N|0)>1;do{if((T|0)==0){if(U){Y=N-1|0;Z=O<<1;break}else{S=fe(O<<N|0)|0;V=b+796|0;K=c[V>>2]|0;x=S;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[V>>2]=(c[V>>2]|0)+4;Y=N+31|0;Z=0;break}}else{if(U){_=N-1|0;$=O<<1|1}else{V=fe(1>>>((1-N|0)>>>0)|O<<N|0)|0;K=b+796|0;S=c[K>>2]|0;x=V;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;c[K>>2]=(c[K>>2]|0)+4;_=N+31|0;$=1}c[j>>2]=$;c[i>>2]=_;K=(T|0)>1|0;if((_|0)>1){Y=_-1|0;Z=$<<1|K;break}else{S=fe(K>>>((1-_|0)>>>0)|$<<_|0)|0;V=b+796|0;L=c[V>>2]|0;x=S;a[L]=x;x=x>>8;a[L+1|0]=x;x=x>>8;a[L+2|0]=x;x=x>>8;a[L+3|0]=x;c[V>>2]=(c[V>>2]|0)+4;Y=_+31|0;Z=K;break}}}while(0);c[j>>2]=Z;c[i>>2]=Y;aa=Y;ca=Z}else{aa=N;ca=O}O=c[G>>2]|0;if((aa|0)>1){da=aa-1|0;ea=ca<<1|O}else{N=fe(ca<<aa|O>>>((1-aa|0)>>>0)|0)|0;ca=b+796|0;Z=c[ca>>2]|0;x=N;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;c[ca>>2]=(c[ca>>2]|0)+4;da=aa+31|0;ea=O}c[j>>2]=ea;c[i>>2]=da;O=c[k>>2]|0;if((da|0)>1){fa=da-1|0;ga=ea<<1|O}else{k=fe(ea<<da|O>>>((1-da|0)>>>0)|0)|0;ea=b+796|0;aa=c[ea>>2]|0;x=k;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;c[ea>>2]=(c[ea>>2]|0)+4;fa=da+31|0;ga=O}c[j>>2]=ga;c[i>>2]=fa;W=b+14100|0;c[W>>2]=0;X=b+14104|0;c[X>>2]=0;return}c[b+14080>>2]=c[b+120>>2];if((H|0)>5){ha=H-5|0;ia=I<<5|23;ja=F}else{F=fe(23>>>((5-H|0)>>>0)|I<<H|0)|0;I=b+796|0;fa=c[I>>2]|0;x=F;a[fa]=x;x=x>>8;a[fa+1|0]=x;x=x>>8;a[fa+2|0]=x;x=x>>8;a[fa+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;ha=H+27|0;ia=23;ja=c[E>>2]|0}c[j>>2]=ia;c[i>>2]=ha;if((ja|0)==4){bQa(b);if((c[b+24>>2]|0)>51200){ha=c[s>>2]|0;ia=c[j>>2]|0;H=c[i>>2]|0;if((H|0)>1){ka=H-1|0;la=ia<<1|ha}else{I=fe(ha>>>((1-H|0)>>>0)|ia<<H|0)|0;ia=b+796|0;fa=c[ia>>2]|0;x=I;a[fa]=x;x=x>>8;a[fa+1|0]=x;x=x>>8;a[fa+2|0]=x;x=x>>8;a[fa+3|0]=x;c[ia>>2]=(c[ia>>2]|0)+4;ka=H+31|0;la=ha}c[j>>2]=la;c[i>>2]=ka}ma=c[E>>2]|0}else{ma=ja}if((ma|0)<=2){W=b+14100|0;c[W>>2]=0;X=b+14104|0;c[X>>2]=0;return}if((c[s>>2]|0)==0){s=c[D>>2]|0;D=c[j>>2]|0;ma=c[i>>2]|0;ja=(ma|0)>1;do{if((s|0)==0){if(ja){na=ma-1|0;oa=D<<1;break}else{E=fe(D<<ma|0)|0;ka=b+796|0;la=c[ka>>2]|0;x=E;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;c[ka>>2]=(c[ka>>2]|0)+4;na=ma+31|0;oa=0;break}}else{if(ja){pa=ma-1|0;qa=D<<1|1}else{ka=fe(1>>>((1-ma|0)>>>0)|D<<ma|0)|0;la=b+796|0;E=c[la>>2]|0;x=ka;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[la>>2]=(c[la>>2]|0)+4;pa=ma+31|0;qa=1}c[j>>2]=qa;c[i>>2]=pa;la=(s|0)>1|0;if((pa|0)>1){na=pa-1|0;oa=qa<<1|la;break}else{E=fe(la>>>((1-pa|0)>>>0)|qa<<pa|0)|0;ka=b+796|0;ha=c[ka>>2]|0;x=E;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;c[ka>>2]=(c[ka>>2]|0)+4;na=pa+31|0;oa=la;break}}}while(0);c[j>>2]=oa;c[i>>2]=na;pa=c[e>>2]|0;e=(na|0)>1;do{if((pa|0)==0){if(e){ra=na-1|0;sa=oa<<1;break}else{qa=fe(oa<<na|0)|0;s=b+796|0;ma=c[s>>2]|0;x=qa;a[ma]=x;x=x>>8;a[ma+1|0]=x;x=x>>8;a[ma+2|0]=x;x=x>>8;a[ma+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;ra=na+31|0;sa=0;break}}else{if(e){ta=na-1|0;ua=oa<<1|1}else{s=fe(oa<<na|1>>>((1-na|0)>>>0)|0)|0;ma=b+796|0;qa=c[ma>>2]|0;x=s;a[qa]=x;x=x>>8;a[qa+1|0]=x;x=x>>8;a[qa+2|0]=x;x=x>>8;a[qa+3|0]=x;c[ma>>2]=(c[ma>>2]|0)+4;ta=na+31|0;ua=1}c[j>>2]=ua;c[i>>2]=ta;ma=(pa|0)>1|0;if((ta|0)>1){ra=ta-1|0;sa=ua<<1|ma;break}else{qa=fe(ma>>>((1-ta|0)>>>0)|ua<<ta|0)|0;s=b+796|0;D=c[s>>2]|0;x=qa;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;ra=ta+31|0;sa=ma;break}}}while(0);c[j>>2]=sa;c[i>>2]=ra;va=ra;wa=sa}else{va=c[i>>2]|0;wa=c[j>>2]|0}sa=c[G>>2]|0;if((va|0)>1){xa=va-1|0;ya=wa<<1|sa}else{G=fe(wa<<va|sa>>>((1-va|0)>>>0)|0)|0;wa=b+796|0;ra=c[wa>>2]|0;x=G;a[ra]=x;x=x>>8;a[ra+1|0]=x;x=x>>8;a[ra+2|0]=x;x=x>>8;a[ra+3|0]=x;c[wa>>2]=(c[wa>>2]|0)+4;xa=va+31|0;ya=sa}c[j>>2]=ya;c[i>>2]=xa;W=b+14100|0;c[W>>2]=0;X=b+14104|0;c[X>>2]=0;return}function bQa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[b+4>>2]|0;f=c[e+112>>2]|0;g=((c[e+108>>2]|0)/(c[e+104>>2]|0)|0|0)/(((f|0)>1?f:1)|0)|0;f=g>>>0>31>>>0?31:g;g=b+784|0;e=c[g>>2]|0;h=b+788|0;j=c[h>>2]|0;if((j|0)>5){k=j-5|0;l=e<<5|f}else{m=fe(f>>>((5-j|0)>>>0)|e<<j|0)|0;e=b+796|0;n=c[e>>2]|0;x=m;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[e>>2]=(c[e>>2]|0)+4;k=j+27|0;l=f}c[g>>2]=l;c[h>>2]=k;f=c[b+24>>2]|0;if((f|0)>2097151){o=2047}else{o=(f|0)/1024|0}if((k|0)>11){p=k-11|0;q=l<<11|o}else{f=fe(l<<k|o>>>((11-k|0)>>>0)|0)|0;l=b+796|0;j=c[l>>2]|0;x=f;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;p=k+21|0;q=o}c[g>>2]=q;c[h>>2]=p;o=c[b+14088>>2]|0;if((c[b+14092>>2]|0)<=2){if((o|0)==0){i=d;return}else{yDb(0,0,2245416,(k=i,i=i+24|0,c[k>>2]=2319616,c[k+8>>2]=2184776,c[k+16>>2]=284,k)|0);i=k;Cd()}}if((p|0)>1){r=p-1|0;s=q<<1|o}else{k=fe(q<<p|o>>>((1-p|0)>>>0)|0)|0;q=b+796|0;b=c[q>>2]|0;x=k;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;r=p+31|0;s=o}c[g>>2]=s;c[h>>2]=r;i=d;return}function cQa(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((f|0)<-63){h=f+64|0}else{h=(f|0)>63?f-64|0:f}if((g|0)<-63){i=g+64|0}else{i=(g|0)>63?g-64|0:g}g=h+32|0;h=i+32|0;i=c[b+14060>>2]|0;f=e[(c[1172516+(i*44|0)>>2]|0)+((h|g<<6)<<1)>>1]|0;j=d[(c[1172504+(i*44|0)>>2]|0)+f|0]|0;k=e[(c[1172500+(i*44|0)>>2]|0)+(f<<1)>>1]|0;l=b+784|0;m=c[l>>2]|0;n=b+788|0;o=c[n>>2]|0;if((o|0)>(j|0)){p=o-j|0;q=m<<j|k}else{r=fe(k>>>((j-o|0)>>>0)|m<<o|0)|0;m=b+796|0;s=c[m>>2]|0;x=r;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;p=32-j+o|0;q=k}c[l>>2]=q;c[n>>2]=p;if((f|0)!=(c[1172496+(i*44|0)>>2]|0)){return}if((p|0)>6){t=p-6|0;u=q<<6|g}else{i=fe(q<<p|g>>>((6-p|0)>>>0)|0)|0;q=b+796|0;f=c[q>>2]|0;x=i;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;t=p+26|0;u=g}c[l>>2]=u;c[n>>2]=t;if((t|0)>6){v=t-6|0;w=u<<6|h}else{g=fe(h>>>((6-t|0)>>>0)|u<<t|0)|0;u=b+796|0;b=c[u>>2]|0;x=g;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=t+26|0;w=h}c[l>>2]=w;c[n>>2]=v;return}function dQa(a){a=a|0;var b=0;if((c[a+12476>>2]|0)!=0){return}b=c[a+14080>>2]|0;do{if((b|0)!=0){if(((c[a+12480>>2]|0)%(b|0)|0|0)!=0){break}if((c[a+14092>>2]|0)<4){TMa(a)}c[a+14084>>2]=1;return}}while(0);c[a+14084>>2]=0;return}function eQa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;a:do{if((c[b+12476>>2]|0)==0){n=c[b+14080>>2]|0;do{if((n|0)!=0){if(((c[b+12480>>2]|0)%(n|0)|0|0)!=0){break}if((c[b+14092>>2]|0)<4){TMa(b)}c[b+14084>>2]=1;break a}}while(0);c[b+14084>>2]=0}}while(0);n=c[b+180>>2]|0;if((c[b+12488>>2]|0)==0){o=(n>>31)+32&-32;p=(c[b+184>>2]|0)>-1?o|16:o;o=(c[b+188>>2]|0)>-1?p|8:p;p=(c[b+192>>2]|0)>-1?o|4:o;o=(c[b+196>>2]|0)>-1?p|2:p;p=o|(c[b+200>>2]|0)>>>31^1;do{if((c[b+14076>>2]|0)!=0){q=b+784|0;r=c[q>>2]|0;s=b+788|0;t=c[s>>2]|0;u=(t|0)>1;if((h|g|p|0)!=0){if(u){v=t-1|0;w=r<<1}else{y=fe(r<<t|0)|0;z=b+796|0;A=c[z>>2]|0;x=y;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;v=t+31|0;w=0}c[q>>2]=w;c[s>>2]=v;break}if(u){B=t-1|0;C=r<<1|1}else{u=fe(1>>>((1-t|0)>>>0)|r<<t|0)|0;r=b+796|0;z=c[r>>2]|0;x=u;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;B=t+31|0;C=1}c[q>>2]=C;c[s>>2]=B;s=b+13700|0;c[s>>2]=(c[s>>2]|0)+1;s=b+13696|0;c[s>>2]=(c[s>>2]|0)+1;s=b+13692|0;c[s>>2]=(c[s>>2]|0)+1;i=j;return}}while(0);B=b+784|0;if((c[b+14092>>2]|0)<3){C=p&3;v=d[1107617+(C<<1)|0]|0;w=d[1107616+(C<<1)|0]|0;s=B|0;q=c[s>>2]|0;t=b+788|0;r=c[t>>2]|0;if((r|0)>(v|0)){D=r-v|0;E=q<<v|w}else{z=fe(w>>>((v-r|0)>>>0)|q<<r|0)|0;q=b+796|0;u=c[q>>2]|0;x=z;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;D=32-v+r|0;E=w}c[s>>2]=E;c[t>>2]=D;w=((C|0)==3?o:o^60)>>2;o=d[1211185+(w<<1)|0]|0;C=d[1211184+(w<<1)|0]|0;if((D|0)>(o|0)){F=D;G=E<<o|C;H=c[b+796>>2]|0}else{w=fe(C>>>((o-D|0)>>>0)|E<<D|0)|0;E=b+796|0;r=c[E>>2]|0;x=w;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[E>>2]|0)+4|0;c[E>>2]=r;F=D+32|0;G=C;H=r}r=F-o|0;c[s>>2]=G;c[t>>2]=r;t=(H-(c[b+792>>2]|0)<<3)+(32-r)|0;r=b+13700|0;H=c[r>>2]|0;c[r>>2]=t;r=b+13696|0;c[r>>2]=(c[r>>2]|0)-H+t;Bca(b,0,0,k,l)|0;fQa(b,g-(c[k>>2]|0)|0);fQa(b,h-(c[l>>2]|0)|0)}else{t=p+64|0;p=c[1125060+(t<<3)>>2]|0;H=c[1125056+(t<<3)>>2]|0;t=B|0;B=c[t>>2]|0;r=b+788|0;G=c[r>>2]|0;if((G|0)>(p|0)){I=G-p|0;J=B<<p|H;K=c[b+796>>2]|0}else{s=fe(H>>>((p-G|0)>>>0)|B<<G|0)|0;B=b+796|0;o=c[B>>2]|0;x=s;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=(c[B>>2]|0)+4|0;c[B>>2]=o;I=32-p+G|0;J=H;K=o}c[t>>2]=J;c[r>>2]=I;r=(K-(c[b+792>>2]|0)<<3)+(32-I)|0;I=b+13700|0;K=c[I>>2]|0;c[I>>2]=r;I=b+13696|0;c[I>>2]=(c[I>>2]|0)-K+r;Bca(b,0,0,k,l)|0;cQa(b,g-(c[k>>2]|0)|0,h-(c[l>>2]|0)|0)}l=b+788|0;h=b+792|0;k=b+796|0;g=((c[k>>2]|0)-(c[h>>2]|0)<<3)+(32-(c[l>>2]|0))|0;r=b+13700|0;K=c[r>>2]|0;c[r>>2]=g;I=b+13664|0;c[I>>2]=(c[I>>2]|0)-K+g;gQa(b,f|0,0);gQa(b,f+128|0,1);gQa(b,f+256|0,2);gQa(b,f+384|0,3);gQa(b,f+512|0,4);gQa(b,f+640|0,5);g=((c[k>>2]|0)-(c[h>>2]|0)<<3)+(32-(c[l>>2]|0))|0;l=c[r>>2]|0;c[r>>2]=g;r=b+13676|0;c[r>>2]=(c[r>>2]|0)-l+g;i=j;return}g=(n|0)>0;n=g&1;l=Pmb(b,0,m)|0;a[c[m>>2]|0]=g&1;g=(c[b+184>>2]|0)>0;r=g&1;h=Pmb(b,1,m)|0;a[c[m>>2]|0]=g&1;g=(c[b+188>>2]|0)>0;k=g&1;K=Pmb(b,2,m)|0;a[c[m>>2]|0]=g&1;g=(c[b+192>>2]|0)>0;I=g&1;J=I<<2|(k<<3|(r<<4|n<<5));t=Pmb(b,3,m)|0;a[c[m>>2]|0]=g&1;g=(c[b+196>>2]|0)>0|0;m=(c[b+200>>2]|0)>0|0;o=m|(g<<1|J);H=m|(g<<1|((t^I)<<2|((K^k)<<3|((h^r)<<4|(l^n)<<5))));n=(c[b+9992>>2]|0)==1;do{if((c[b+14092>>2]|0)<3){if(n){l=o&3;r=d[1107633+(l<<1)|0]|0;h=d[1107632+(l<<1)|0]|0;l=b+784|0;k=c[l>>2]|0;K=b+788|0;I=c[K>>2]|0;if((I|0)>(r|0)){L=I-r|0;M=k<<r|h}else{t=fe(h>>>((r-I|0)>>>0)|k<<I|0)|0;k=b+796|0;g=c[k>>2]|0;x=t;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;L=32-r+I|0;M=h}c[l>>2]=M;c[K>>2]=L;N=M;O=L}else{K=b+784|0;l=c[K>>2]|0;h=b+788|0;I=c[h>>2]|0;if((c[b+14076>>2]|0)==0){P=l;Q=I}else{if((I|0)>1){R=I-1|0;S=l<<1}else{r=fe(l<<I|0)|0;l=b+796|0;k=c[l>>2]|0;x=r;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;R=I+31|0;S=0}c[K>>2]=S;c[h>>2]=R;P=S;Q=R}h=o&3|4;K=d[1107617+(h<<1)|0]|0;I=d[1107616+(h<<1)|0]|0;if((Q|0)>(K|0)){T=Q-K|0;U=P<<K|I}else{h=fe(I>>>((K-Q|0)>>>0)|P<<Q|0)|0;l=b+796|0;k=c[l>>2]|0;x=h;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;T=32-K+Q|0;U=I}c[b+784>>2]=U;c[b+788>>2]=T;N=U;O=T}I=b+784|0;K=b+788|0;if((O|0)>1){V=O-1|0;W=N<<1}else{l=fe(N<<O|0)|0;k=b+796|0;h=c[k>>2]|0;x=l;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;V=O+31|0;W=0}c[I>>2]=W;c[K>>2]=V;k=J>>>2;h=d[1211185+(k<<1)|0]|0;l=d[1211184+(k<<1)|0]|0;if((V|0)>(h|0)){X=V;Y=W<<h|l}else{k=fe(l>>>((h-V|0)>>>0)|W<<V|0)|0;r=b+796|0;g=c[r>>2]|0;x=k;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;X=V+32|0;Y=l}l=X-h|0;c[I>>2]=Y;c[K>>2]=l;Z=l}else{if(n){l=e[1174082+(H<<2)>>1]|0;K=e[1174080+(H<<2)>>1]|0;I=b+784|0;h=c[I>>2]|0;r=b+788|0;g=c[r>>2]|0;if((g|0)>(l|0)){_=g-l|0;$=h<<l|K}else{k=fe(K>>>((l-g|0)>>>0)|h<<g|0)|0;h=b+796|0;t=c[h>>2]|0;x=k;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;_=32-l+g|0;$=K}c[I>>2]=$;c[r>>2]=_;aa=$;ba=_}else{r=b+784|0;I=c[r>>2]|0;K=b+788|0;g=c[K>>2]|0;if((c[b+14076>>2]|0)==0){ca=I;da=g}else{if((g|0)>1){ea=g-1|0;fa=I<<1}else{l=fe(I<<g|0)|0;I=b+796|0;h=c[I>>2]|0;x=l;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;ea=g+31|0;fa=0}c[r>>2]=fa;c[K>>2]=ea;ca=fa;da=ea}K=c[1125060+(o<<3)>>2]|0;r=c[1125056+(o<<3)>>2]|0;if((da|0)>(K|0)){ga=da-K|0;ha=ca<<K|r}else{g=fe(r>>>((K-da|0)>>>0)|ca<<da|0)|0;I=b+796|0;h=c[I>>2]|0;x=g;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;ga=32-K+da|0;ha=r}c[b+784>>2]=ha;c[b+788>>2]=ga;aa=ha;ba=ga}r=b+784|0;K=b+788|0;if((ba|0)>1){ia=ba-1|0;ja=aa<<1}else{I=fe(aa<<ba|0)|0;h=b+796|0;g=c[h>>2]|0;x=I;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;ia=ba+31|0;ja=0}c[r>>2]=ja;c[K>>2]=ia;if((c[b+14112>>2]|0)==0){Z=ia;break}c[b+13820>>2]=0;h=d[1126081]|0;g=d[1126080]|0;if((ia|0)>(h|0)){ka=ia-h|0;la=ja<<h|g}else{I=fe(g>>>((h-ia|0)>>>0)|ja<<ia|0)|0;l=b+796|0;t=c[l>>2]|0;x=I;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;ka=32-h+ia|0;la=g}c[r>>2]=la;c[K>>2]=ka;Z=ka}}while(0);ka=b+792|0;la=b+796|0;ia=((c[la>>2]|0)-(c[ka>>2]|0)<<3)+(32-Z)|0;Z=b+13700|0;ja=c[Z>>2]|0;c[Z>>2]=ia;ba=b+13696|0;c[ba>>2]=(c[ba>>2]|0)-ja+ia;gQa(b,f|0,0);gQa(b,f+128|0,1);gQa(b,f+256|0,2);gQa(b,f+384|0,3);gQa(b,f+512|0,4);gQa(b,f+640|0,5);f=((c[la>>2]|0)-(c[ka>>2]|0)<<3)+(32-(c[b+788>>2]|0))|0;ka=c[Z>>2]|0;c[Z>>2]=f;Z=b+13672|0;c[Z>>2]=(c[Z>>2]|0)-ka+f;f=b+13680|0;c[f>>2]=(c[f>>2]|0)+1;i=j;return}function fQa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((e|0)==0){f=d[1172137]|0;g=d[1172136]|0;h=b+784|0;i=c[h>>2]|0;j=b+788|0;k=c[j>>2]|0;if((k|0)>(f|0)){l=k-f|0;m=i<<f|g}else{n=fe(g>>>((f-k|0)>>>0)|i<<k|0)|0;i=b+796|0;o=c[i>>2]|0;x=n;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;l=32-f+k|0;m=g}c[h>>2]=m;c[j>>2]=l;return}l=c[b+11556>>2]|0;j=l-1|0;if((e|0)<-63){p=e+64|0}else{p=(e|0)>63?e-64|0:e}e=((p|0)>-1?p:-p|0)-1|0;m=(e>>j)+1|0;h=d[1172137+(m<<1)|0]|0;g=h+1|0;k=(d[1172136+(m<<1)|0]|0)<<1|p>>>31;p=b+784|0;m=c[p>>2]|0;f=b+788|0;i=c[f>>2]|0;if((i|0)>(g|0)){q=i-g|0;r=k|m<<g}else{o=fe(k>>>((g-i|0)>>>0)|m<<i|0)|0;m=b+796|0;g=c[m>>2]|0;x=o;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;q=31-h+i|0;r=k}c[p>>2]=r;c[f>>2]=q;if((j|0)<=0){return}k=e&(1<<j)-1;if((q|0)>(j|0)){s=q-j|0;t=r<<j|k}else{e=fe(r<<q|k>>>((j-q|0)>>>0)|0)|0;j=b+796|0;b=c[j>>2]|0;x=e;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;s=33-l+q|0;t=k}c[p>>2]=t;c[f>>2]=s;return}function gQa(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;j=i;i=i+16|0;k=j|0;l=f+12488|0;if((c[l>>2]|0)==0){m=c[f+14092>>2]|0;n=0;o=f+236|0;p=(c[f+14064>>2]|0)+3|0;q=(m|0)>2;r=m}else{m=b[g>>1]|0;s=Qmb(f,h,k,j+8|0)|0;t=(h|0)<4;if(t){u=(ba(c[f+168>>2]|0,m)|0)&65535;b[c[k>>2]>>1]=u}else{u=(ba(c[f+172>>2]|0,m)|0)&65535;b[c[k>>2]>>1]=u}u=m-s|0;s=f+14092|0;m=c[s>>2]|0;do{if((m|0)<3){k=f+784|0;v=u+256|0;if(t){w=c[5388420+(v<<3)>>2]|0;y=c[5388416+(v<<3)>>2]|0;z=k|0;A=c[z>>2]|0;B=f+788|0;C=c[B>>2]|0;if((C|0)>(w|0)){D=C-w|0;E=A<<w|y}else{F=fe(y>>>((w-C|0)>>>0)|A<<C|0)|0;A=f+796|0;G=c[A>>2]|0;x=F;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;D=32-w+C|0;E=y}c[z>>2]=E;c[B>>2]=D;break}else{B=c[5392516+(v<<3)>>2]|0;z=c[5392512+(v<<3)>>2]|0;v=k|0;k=c[v>>2]|0;y=f+788|0;C=c[y>>2]|0;if((C|0)>(B|0)){H=C-B|0;I=k<<B|z}else{w=fe(z>>>((B-C|0)>>>0)|k<<C|0)|0;k=f+796|0;A=c[k>>2]|0;x=w;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;H=32-B+C|0;I=z}c[v>>2]=I;c[y>>2]=H;break}}else{y=u>>>31;v=(u|0)<0?-u|0:u;do{if((v|0)>119){J=0;K=119}else{if((m|0)<=5){J=0;K=v;break}z=c[f+9960>>2]|0;if((z|0)==1){C=v+3|0;J=C&3;K=C>>2;break}else if((z|0)==2){z=v+1|0;J=z&1;K=z>>1;break}else{J=0;K=v;break}}}while(0);z=f+784|0;do{if((c[f+14072>>2]|0)==0){if(t){C=c[1128116+(K<<3)>>2]|0;B=c[1128112+(K<<3)>>2]|0;k=z|0;A=c[k>>2]|0;w=f+788|0;G=c[w>>2]|0;if((G|0)>(C|0)){L=G-C|0;M=A<<C|B}else{F=fe(B>>>((C-G|0)>>>0)|A<<G|0)|0;A=f+796|0;N=c[A>>2]|0;x=F;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;L=32-C+G|0;M=B}c[k>>2]=M;c[w>>2]=L;O=M;P=L;break}else{w=c[1129076+(K<<3)>>2]|0;k=c[1129072+(K<<3)>>2]|0;B=z|0;G=c[B>>2]|0;C=f+788|0;A=c[C>>2]|0;if((A|0)>(w|0)){Q=A-w|0;R=G<<w|k}else{N=fe(k>>>((w-A|0)>>>0)|G<<A|0)|0;G=f+796|0;F=c[G>>2]|0;x=N;a[F]=x;x=x>>8;a[F+1|0]=x;x=x>>8;a[F+2|0]=x;x=x>>8;a[F+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;Q=32-w+A|0;R=k}c[B>>2]=R;c[C>>2]=Q;O=R;P=Q;break}}else{if(t){C=c[1126196+(K<<3)>>2]|0;B=c[1126192+(K<<3)>>2]|0;k=z|0;A=c[k>>2]|0;w=f+788|0;G=c[w>>2]|0;if((G|0)>(C|0)){S=G-C|0;T=A<<C|B}else{F=fe(B>>>((C-G|0)>>>0)|A<<G|0)|0;A=f+796|0;N=c[A>>2]|0;x=F;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;S=32-C+G|0;T=B}c[k>>2]=T;c[w>>2]=S;O=T;P=S;break}else{w=c[1127156+(K<<3)>>2]|0;k=c[1127152+(K<<3)>>2]|0;B=z|0;G=c[B>>2]|0;C=f+788|0;A=c[C>>2]|0;if((A|0)>(w|0)){U=A-w|0;V=G<<w|k}else{N=fe(k>>>((w-A|0)>>>0)|G<<A|0)|0;G=f+796|0;F=c[G>>2]|0;x=N;a[F]=x;x=x>>8;a[F+1|0]=x;x=x>>8;a[F+2|0]=x;x=x>>8;a[F+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;U=32-w+A|0;V=k}c[B>>2]=V;c[C>>2]=U;O=V;P=U;break}}}while(0);if((c[s>>2]|0)>5){C=c[f+9960>>2]|0;W=(C|0)<3?3-C|0:0}else{W=0}do{if((K|0)==119){C=W+8|0;if((P|0)>(C|0)){X=P-C|0;Y=O<<C|v}else{B=fe(v>>>((C-P|0)>>>0)|O<<P|0)|0;C=f+796|0;k=c[C>>2]|0;x=B;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;X=P+24-W|0;Y=v}c[z>>2]=Y;c[f+788>>2]=X;Z=Y;_=X}else{if((W|0)<=0){Z=O;_=P;break}if((P|0)>(W|0)){$=P;aa=O<<W|J}else{C=fe(J>>>((W-P|0)>>>0)|O<<P|0)|0;k=f+796|0;B=c[k>>2]|0;x=C;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;$=P+32|0;aa=J}k=$-W|0;c[z>>2]=aa;c[f+788>>2]=k;Z=aa;_=k}}while(0);if((v|0)==0){break}if((_|0)>1){ca=_-1|0;da=Z<<1|y}else{k=fe(y>>>((1-_|0)>>>0)|Z<<_|0)|0;B=f+796|0;C=c[B>>2]|0;x=k;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;ca=_+31|0;da=y}c[z>>2]=da;c[f+788>>2]=ca}}while(0);if(t){ea=c[f+14064>>2]|0}else{ea=(c[f+14068>>2]|0)+3|0}t=c[s>>2]|0;n=1;o=f+368|0;p=ea;q=(t|0)>3;r=t}t=q&1;q=f+14092|0;ea=f+180+(h<<2)|0;s=c[ea>>2]|0;if((r-4|0)>>>0<2>>>0&(s|0)>0){r=63;while(1){if(!((r|0)>-1)){break}if((b[g+(d[o+r|0]<<1)>>1]|0)==0){r=r-1|0}else{break}}c[ea>>2]=r;fa=r}else{fa=s}if((n|0)>(fa|0)){i=j;return}s=(h|0)>3|0;h=f+14108|0;r=1146840+(p*192|0)|0;ea=1146848+(p*192|0)|0;ca=f+784|0;da=f+788|0;_=f+14100|0;Z=f+14104|0;aa=f+9960|0;W=f+796|0;f=n-1|0;$=n;while(1){n=b[g+(d[o+$|0]<<1)>>1]|0;J=n<<16>>16;a:do{if(n<<16>>16==0){ga=f}else{P=$-f-1|0;O=($|0)==(fa|0)|0;X=(n&65535)>>>15&65535;Y=n<<16>>16<0?-J|0:J;if((Y|0)<65&(P|0)<65){K=c[h>>2]|0;U=K+((c[l>>2]|0)*67600|0)+(s*33800|0)+(Y*520|0)+(P<<3)+(O<<2)|0;c[U>>2]=(c[U>>2]|0)+1;ha=K}else{ha=c[h>>2]|0}K=ha+((c[l>>2]|0)*67600|0)+(s*33800|0)+21304|0;c[K>>2]=(c[K>>2]|0)+1;K=1146860+(p*192|0)+(O<<2)|0;U=d[(c[K>>2]|0)+P|0]|0;V=c[r>>2]|0;do{if((U|0)<(V|0)){if((a[(c[1146868+(p*192|0)+(O<<2)>>2]|0)+P|0]|0)<(Y|0)){ia=V;break}ia=Y-1+U|0}else{ia=V}}while(0);V=c[ea>>2]|0;U=e[V+(ia<<2)+2>>1]|0;S=e[V+(ia<<2)>>1]|0;V=c[ca>>2]|0;T=c[da>>2]|0;if((T|0)>(U|0)){ja=T-U|0;ka=V<<U|S}else{Q=fe(S>>>((U-T|0)>>>0)|V<<T|0)|0;V=c[W>>2]|0;x=Q;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;ja=32-U+T|0;ka=S}c[ca>>2]=ka;c[da>>2]=ja;if((ia|0)!=(c[r>>2]|0)){if((ja|0)>1){la=ja-1|0;ma=ka<<1|X}else{S=fe(ka<<ja|X>>>((1-ja|0)>>>0)|0)|0;T=c[W>>2]|0;x=S;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;la=ja+31|0;ma=X}c[ca>>2]=ma;c[da>>2]=la;ga=$;break}T=1146868+(p*192|0)+(O<<2)|0;S=a[(c[T>>2]|0)+P|0]|0;U=Y-S|0;do{if((U|0)>=1){V=d[(c[K>>2]|0)+P|0]|0;if((V|0)>=(ia|0)|(S|0)<(U|0)){break}Q=U-1+V|0;if((Q|0)==(ia|0)){break}if((ja|0)>1){na=ja-1|0;oa=ka<<1|1}else{V=fe(1>>>((1-ja|0)>>>0)|ka<<ja|0)|0;R=c[W>>2]|0;x=V;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;na=ja+31|0;oa=1}c[ca>>2]=oa;c[da>>2]=na;R=c[ea>>2]|0;V=e[R+(Q<<2)+2>>1]|0;L=e[R+(Q<<2)>>1]|0;if((na|0)>(V|0)){pa=na;qa=oa<<V|L}else{Q=fe(L>>>((V-na|0)>>>0)|oa<<na|0)|0;R=c[W>>2]|0;x=Q;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;pa=na+32|0;qa=L}L=pa-V|0;c[ca>>2]=qa;c[da>>2]=L;if((L|0)>1){ra=L-1|0;sa=qa<<1|X}else{V=fe(X>>>((1-L|0)>>>0)|qa<<L|0)|0;R=c[W>>2]|0;x=V;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;ra=L+31|0;sa=X}c[ca>>2]=sa;c[da>>2]=ra;ga=$;break a}}while(0);if((ja|0)>1){ta=ja-1|0;ua=ka<<1}else{U=fe(ka<<ja|0)|0;S=c[W>>2]|0;x=U;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;ta=ja+31|0;ua=0}c[ca>>2]=ua;c[da>>2]=ta;do{if((Y|0)<=64){S=P-(a[(c[1146876+(p*192|0)+(O<<2)>>2]|0)+Y|0]|0)-t|0;if((S|0)<0){break}U=S+1|0;L=c[K>>2]|0;R=d[L+U|0]|0;V=c[r>>2]|0;do{if((R|0)<(V|0)){if((a[(c[T>>2]|0)+U|0]|0)<(Y|0)){va=V;break}va=Y-1+R|0}else{va=V}}while(0);if((c[q>>2]|0)==4&(va|0)==(V|0)){break}R=d[L+S|0]|0;if((R|0)>=(V|0)){break}if((a[(c[T>>2]|0)+S|0]|0)<(Y|0)){break}U=Y-1+R|0;if((U|0)==(V|0)){break}if((ta|0)>1){wa=ta-1|0;xa=ua<<1|1}else{R=fe(1>>>((1-ta|0)>>>0)|ua<<ta|0)|0;Q=c[W>>2]|0;x=R;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;wa=ta+31|0;xa=1}c[ca>>2]=xa;c[da>>2]=wa;Q=c[ea>>2]|0;R=e[Q+(U<<2)+2>>1]|0;M=e[Q+(U<<2)>>1]|0;if((wa|0)>(R|0)){ya=wa;za=xa<<R|M}else{U=fe(M>>>((R-wa|0)>>>0)|xa<<wa|0)|0;Q=c[W>>2]|0;x=U;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;ya=wa+32|0;za=M}M=ya-R|0;c[ca>>2]=za;c[da>>2]=M;if((M|0)>1){Aa=M-1|0;Ba=za<<1|X}else{R=fe(X>>>((1-M|0)>>>0)|za<<M|0)|0;Q=c[W>>2]|0;x=R;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Aa=M+31|0;Ba=X}c[ca>>2]=Ba;c[da>>2]=Aa;ga=$;break a}}while(0);if((ta|0)>1){Ca=ta-1|0;Da=ua<<1}else{T=fe(ua<<ta|0)|0;K=c[W>>2]|0;x=T;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Ca=ta+31|0;Da=0}c[ca>>2]=Da;c[da>>2]=Ca;if((Ca|0)>1){Ea=Ca-1|0;Fa=Da<<1|O}else{K=fe(O>>>((1-Ca|0)>>>0)|Da<<Ca|0)|0;T=c[W>>2]|0;x=K;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Ea=Ca+31|0;Fa=O}c[ca>>2]=Fa;c[da>>2]=Ea;T=c[q>>2]|0;if((T|0)<=3){if((Ea|0)>6){Ga=Ea-6|0;Ha=Fa<<6|P}else{K=fe(Fa<<Ea|P>>>((6-Ea|0)>>>0)|0)|0;M=c[W>>2]|0;x=K;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Ga=Ea+26|0;Ha=P}c[ca>>2]=Ha;c[da>>2]=Ga;M=J&255;if((Ga|0)>8){Ia=Ga-8|0;Ja=Ha<<8|M}else{K=fe(M>>>((8-Ga|0)>>>0)|Ha<<Ga|0)|0;Q=c[W>>2]|0;x=K;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Ia=Ga+24|0;Ja=M}c[ca>>2]=Ja;c[da>>2]=Ia;ga=$;break}do{if((c[_>>2]|0)==0){c[_>>2]=8;c[Z>>2]=6;if((c[aa>>2]|0)<8){M=(T|0)>5|6;if((Ea|0)>(M|0)){Ka=Ea;La=Fa<<M|3}else{Q=fe(3>>>((M-Ea|0)>>>0)|Fa<<Ea|0)|0;K=c[W>>2]|0;x=Q;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Ka=Ea+32|0;La=3}K=Ka-M|0;c[ca>>2]=La;c[da>>2]=K;Ma=La;Na=K;break}else{if((Ea|0)>8){Oa=Ea-8|0;Pa=Fa<<8|3}else{K=fe(3>>>((8-Ea|0)>>>0)|Fa<<Ea|0)|0;M=c[W>>2]|0;x=K;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Oa=Ea+24|0;Pa=3}c[ca>>2]=Pa;c[da>>2]=Oa;Ma=Pa;Na=Oa;break}}else{Ma=Fa;Na=Ea}}while(0);T=c[Z>>2]|0;if((Na|0)>(T|0)){Qa=Na-T|0;Ra=Ma<<T|P}else{O=fe(P>>>((T-Na|0)>>>0)|Ma<<Na|0)|0;M=c[W>>2]|0;x=O;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Qa=32-T+Na|0;Ra=P}c[ca>>2]=Ra;c[da>>2]=Qa;if((Qa|0)>1){Sa=Qa-1|0;Ta=Ra<<1|X}else{T=fe(X>>>((1-Qa|0)>>>0)|Ra<<Qa|0)|0;M=c[W>>2]|0;x=T;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Sa=Qa+31|0;Ta=X}c[ca>>2]=Ta;c[da>>2]=Sa;M=c[_>>2]|0;if((Sa|0)>(M|0)){Ua=Sa;Va=Ta<<M|Y}else{T=fe(Y>>>((M-Sa|0)>>>0)|Ta<<Sa|0)|0;O=c[W>>2]|0;x=T;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;Ua=Sa+32|0;Va=Y}c[ca>>2]=Va;c[da>>2]=Ua-M;ga=$}}while(0);J=$+1|0;if((J|0)>(fa|0)){break}else{f=ga;$=J}}i=j;return}function hQa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=c[a+792>>2]|0;if((f|0)==4|(f|0)==8){c[a+140>>2]=11}else if((f|0)==24){c[a+140>>2]=3}else if((f|0)==1){c[a+140>>2]=9}else{yDb(a,16,2004544,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1094995529;i=b;return g|0}f=ICb()|0;c[e+4>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}f=a+100|0;h=c[f>>2]|0;if((h|0)<=3){g=0;i=b;return g|0}j=a+96|0;a=e+28|0;e=0;k=h;while(1){if((k|0)>1024){l=256}else{l=(k|0)/4|0}if((e|0)>=(l|0)){g=0;break}h=(c[j>>2]|0)+(e<<2)|0;c[a+(e<<2)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|-16777216;e=e+1|0;k=c[f>>2]|0}i=b;return g|0}function iQa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;j=g+24|0;k=c[j>>2]|0;l=g+28|0;m=c[l>>2]|0;n=c[b+60>>2]|0;o=b+120|0;p=b+792|0;q=((ba(c[p>>2]|0,c[o>>2]|0)|0)+31&-32|0)/8|0;c[n+20>>2]=k;c[n+24>>2]=m;r=n+4|0;s=$$a(b,c[r>>2]|0)|0;if((s|0)<0){t=s;i=h;return t|0}if(((c[p>>2]|0)-2|0)>>>0<7>>>0){s=HZ(g,0,0)|0;g=c[r>>2]|0;if((s|0)==0){u=n+28|0}else{c[g+304>>2]=1;v=n+28|0;UGb(v|0,s|0,1024)|0;u=v}UGb(c[g+4>>2]|0,u|0,1024)|0}u=b+124|0;g=ba(c[u>>2]|0,q)|0;a:do{if((g|0)==(c[l>>2]|0)){v=cDb(c[b+140>>2]|0,c[o>>2]|0,0)|0;if((v|0)<0){t=v;i=h;return t|0}s=c[u>>2]|0;if((s|0)<=0){break}w=ba(s-1|0,q)|0;s=-q|0;x=c[c[r>>2]>>2]|0;y=(c[j>>2]|0)+w|0;w=1;while(1){do{if((c[p>>2]|0)==4){z=c[o>>2]|0;if((z-1|0)>0){A=0;while(1){B=y+(A>>1)|0;a[x+A|0]=(d[B]|0)>>>4;a[x+(A|1)|0]=a[B]&15;B=A+2|0;C=c[o>>2]|0;if((B|0)<(C-1|0)){A=B}else{D=B;E=C;break}}}else{D=0;E=z}if((E&1|0)==0){break}a[x+D|0]=(d[y+(D>>1)|0]|0)>>>4}else{UGb(x|0,y|0,v)|0}}while(0);if((w|0)>=(c[u>>2]|0)){break a}x=x+(c[(c[r>>2]|0)+32>>2]|0)|0;y=y+s|0;w=w+1|0}}else{w=n+8|0;if((m|0)>-1){c[w>>2]=k;c[n+16>>2]=k;c[n+12>>2]=k+m;kQa(b,c[r>>2]|0,c[p>>2]|0,w)|0;break}else{yDb(0,0,2184736,(w=i,i=i+24|0,c[w>>2]=2107712,c[w+8>>2]=2050152,c[w+16>>2]=135,w)|0);i=w;Cd();return 0}}}while(0);p=MCb(e,c[r>>2]|0)|0;if((p|0)<0){t=p;i=h;return t|0}c[f>>2]=1;t=m;i=h;return t|0}function jQa(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function kQa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;j=i;switch(g|0){case 8:case 16:case 24:case 32:{k=(c[e+124>>2]|0)-1|0;l=f+32|0;m=c[l>>2]|0;n=(m|0)>-1?m:-m|0;o=g>>3;p=(n|0)/(o|0)|0;q=f|0;r=c[q>>2]|0;s=ba(k,m)|0;m=h|0;t=c[m>>2]|0;u=h+4|0;v=c[u>>2]|0;a:do{if((v|0)!=(t|0)){w=o<<1;x=(g|0)==8;y=k;z=0;A=r+(n+s)|0;B=r+s|0;C=t;D=v;b:while(1){E=z;F=B;G=C;H=D;c:while(1){I=H;J=G;while(1){K=J+1|0;c[m>>2]=K;L=a[J]|0;M=L&255;if(L<<24>>24==0){if((I-K|0)<1){N=K;O=49;break c}P=J+2|0;c[m>>2]=P;Q=a[K]|0;R=Q&255;if((R|0)==1){S=0;O=107;break b}else if((R|0)==2){O=55;break c}else if((R|0)==0){N=P;O=49;break c}T=ba(R,o)|0;U=F+T|0;V=I-P|0;if(!(U>>>0>A>>>0)){O=65;break}W=J+((V>>>0>w>>>0?w:V)+2)|0;c[m>>2]=W;X=W}else{if((F+(ba(M,o)|0)|0)>>>0>A>>>0){X=K}else{O=81;break}}if((H|0)==(X|0)){break a}else{J=X}}do{if((O|0)==65){O=0;if(V>>>0<T>>>0){O=66;break b}if((g|0)==16){if(Q<<24>>24==0){Y=F;Z=R;_=P;break}W=R<<1;$=(Q&255)>>>0>1>>>0;aa=R<<1;ca=0;da=F;ea=P;while(1){fa=ea+2|0;c[m>>2]=fa;ga=ea;b[da>>1]=(d[ga]|d[ga+1|0]<<8)<<16>>16;ga=ca+1|0;if((ga|0)<(R|0)){ca=ga;da=da+2|0;ea=fa}else{break}}Y=F+((Q&255)>>>0>1>>>0?W:2)|0;Z=R;_=J+($?aa+2|0:4)|0;break}else if((g|0)==32){if(Q<<24>>24==0){Y=F;Z=R;_=P;break}ea=R<<2;da=(Q&255)>>>0>1>>>0;ca=R<<2;fa=0;ga=F;ha=P;while(1){ia=ha+4|0;c[m>>2]=ia;ja=ha;c[ga>>2]=d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24;ja=fa+1|0;if((ja|0)<(R|0)){fa=ja;ga=ga+4|0;ha=ia}else{break}}Y=F+((Q&255)>>>0>1>>>0?ea:4)|0;Z=R;_=J+(da?ca|2:6)|0;break}else if((g|0)==24|(g|0)==8){UGb(F|0,P|0,T)|0;ha=c[m>>2]|0;ga=ha+T|0;c[m>>2]=ga;if(!x){Y=U;Z=R;_=ga;break}if((R&1|0)==0){Y=U;Z=R;_=ga;break}fa=(c[u>>2]|0)-ga|0;ga=ha+((fa>>>0>1>>>0?1:fa)+T)|0;c[m>>2]=ga;Y=U;Z=R;_=ga;break}else{Y=F;Z=R;_=P;break}}else if((O|0)==81){O=0;if((g|0)==8){if((I-K|0)<1){ka=0}else{c[m>>2]=J+2;ka=a[K]|0}TGb(F|0,ka|0,M|0)|0;la=F+M|0}else if((g|0)==24){if((I-K|0)<1){ma=0;na=K}else{ga=J+2|0;c[m>>2]=ga;ma=a[K]|0;na=ga}if((I-na|0)<1){oa=0;pa=na}else{ga=na+1|0;c[m>>2]=ga;oa=a[na]|0;pa=ga}if((I-pa|0)<1){qa=0}else{c[m>>2]=pa+1;qa=a[pa]|0}ga=M*3|0;fa=0;ha=F;while(1){a[ha]=ma;a[ha+1|0]=oa;a[ha+2|0]=qa;aa=fa+1|0;if((aa|0)<(M|0)){fa=aa;ha=ha+3|0}else{break}}la=F+((L&255)>>>0>1>>>0?ga:3)|0}else if((g|0)==16){if((I-K|0)<2){ra=0}else{c[m>>2]=J+3;ha=K;ra=(d[ha]|d[ha+1|0]<<8)<<16>>16}ha=M<<1;fa=0;ca=F;while(1){b[ca>>1]=ra;da=fa+1|0;if((da|0)<(M|0)){fa=da;ca=ca+2|0}else{break}}la=F+((L&255)>>>0>1>>>0?ha:2)|0}else if((g|0)==32){if((I-K|0)<4){sa=0}else{c[m>>2]=J+5;ca=K;sa=d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0}ca=M<<2;fa=0;ga=F;while(1){c[ga>>2]=sa;da=fa+1|0;if((da|0)<(M|0)){fa=da;ga=ga+4|0}else{break}}la=F+((L&255)>>>0>1>>>0?ca:4)|0}else{la=F}Y=la;Z=M;_=c[m>>2]|0}}while(0);ga=c[u>>2]|0;if((ga|0)==(_|0)){break a}else{E=Z+E|0;F=Y;G=_;H=ga}}if((O|0)==49){O=0;G=y-1|0;if((G|0)<0){O=50;break}F=c[q>>2]|0;ga=c[l>>2]|0;fa=ba(ga,G)|0;ta=F+fa|0;ua=F+(((ga|0)>-1?ga:-ga|0)+fa)|0;va=0;wa=G;xa=N}else if((O|0)==55){O=0;if((I-P|0)<1){ya=0;za=P}else{G=J+3|0;c[m>>2]=G;ya=d[P]|0;za=G}if((I-za|0)<1){Aa=0;Ba=za}else{G=za+1|0;c[m>>2]=G;Aa=d[za]|0;Ba=G}G=y-Aa|0;fa=ya+E|0;if(!((G|0)>-1&fa>>>0<p>>>0)){O=60;break}ga=c[q>>2]|0;F=c[l>>2]|0;ha=ba(F,G)|0;da=ga+(ha+(ba(fa,o)|0))|0;ta=da;ua=ga+(((F|0)>-1?F:-F|0)+ha)|0;va=fa;wa=G;xa=Ba}if((H|0)==(xa|0)){break a}else{y=wa;z=va;A=ua;B=ta;C=xa;D=H}}if((O|0)==50){do{if((I-N|0)<2){Ca=N}else{D=N+2|0;c[m>>2]=D;C=N;if((d[C]|d[C+1|0]<<8)<<16>>16<<16>>16==256){S=0}else{Ca=D;break}i=j;return S|0}}while(0);yDb(e,16,2319544,(Da=i,i=i+8|0,c[Da>>2]=I-Ca,Da)|0);i=Da;S=-1094995529;i=j;return S|0}else if((O|0)==60){yDb(e,16,2184704,(Da=i,i=i+1|0,i=i+7&-8,c[Da>>2]=0,Da)|0);i=Da;S=-1;i=j;return S|0}else if((O|0)==66){yDb(e,16,2107680,(Da=i,i=i+1|0,i=i+7&-8,c[Da>>2]=0,Da)|0);i=Da;S=-1094995529;i=j;return S|0}else if((O|0)==107){i=j;return S|0}}}while(0);yDb(e,24,2050112,(Da=i,i=i+1|0,i=i+7&-8,c[Da>>2]=0,Da)|0);i=Da;S=0;i=j;return S|0};case 4:{Ca=c[f+32>>2]|0;I=c[e+124>>2]|0;N=ba(I-1|0,Ca)|0;m=ba(I,Ca)|0;I=h|0;xa=c[I>>2]|0;ta=h+4|0;h=c[ta>>2]|0;ua=(h|0)==(xa|0);do{if((N|0)>-1){va=e+120|0;wa=f|0;Ba=0;o=N;l=ua;q=xa;p=h;d:while(1){if(l){O=5;break}else{Ea=p;Fa=q;Ga=Ba}e:while(1){ya=Fa+1|0;c[I>>2]=ya;Aa=a[Fa]|0;za=Aa&255;f:do{if(Aa<<24>>24==0){Ha=Ea;if((Ha-ya|0)<1){Ia=Ca;Ja=0;Ka=ya;break e}La=Fa+2|0;c[I>>2]=La;P=d[ya]|0;if((P|0)==1){S=0;O=107;break d}else if((P|0)==2){O=10;break e}else if((P|0)==0){Ia=Ca;Ja=0;Ka=La;break e}J=(P+1|0)>>>1;if((Ga+o+P|0)>>>0>m>>>0){O=23;break d}if((Ha-La|0)>>>0<J>>>0){O=23;break d}if((J|0)==0){Ma=Ga;break}g:do{if((P&1|0)==0){_=Ga;Y=1;while(1){if(!(_>>>0<(c[va>>2]|0)>>>0)){Na=_;break g}Z=c[I>>2]|0;c[I>>2]=Z+1;u=a[Z]|0;a[(c[wa>>2]|0)+(_+o)|0]=(u&255)>>>4;Z=_+1|0;if(!(Z>>>0<(c[va>>2]|0)>>>0)){Na=Z;break g}a[(c[wa>>2]|0)+(Z+o)|0]=u&15;u=_+2|0;if((Y|0)>=(J|0)){Na=u;break g}_=u;Y=Y+1|0}}else{Y=Ga;_=1;while(1){if(!(Y>>>0<(c[va>>2]|0)>>>0)){Na=Y;break g}u=c[I>>2]|0;c[I>>2]=u+1;Z=a[u]|0;a[(c[wa>>2]|0)+(Y+o)|0]=(Z&255)>>>4;u=Y+1|0;if((_|0)==(J|0)){Na=u;break g}if(!(u>>>0<(c[va>>2]|0)>>>0)){Na=u;break g}a[(c[wa>>2]|0)+(u+o)|0]=Z&15;Z=Y+2|0;if((_|0)>=(J|0)){Na=Z;break g}Y=Z;_=_+1|0}}}while(0);if((J&1|0)==0){Ma=Na;break}P=c[I>>2]|0;ca=(c[ta>>2]|0)-P|0;c[I>>2]=P+(ca>>>0>1>>>0?1:ca);Ma=Na}else{if((Ga+o+za|0)>>>0>m>>>0){O=33;break d}if((Ea-ya|0)<1){Oa=0;Pa=0}else{c[I>>2]=Fa+2;ca=a[ya]|0;Oa=(ca&255)>>>4;Pa=ca&15}ca=Ga;P=0;while(1){if(!(ca>>>0<(c[va>>2]|0)>>>0)){Ma=ca;break f}a[(c[wa>>2]|0)+(ca+o)|0]=(P&1|0)==0?Oa:Pa;_=ca+1|0;Y=P+1|0;if((Y|0)<(za|0)){ca=_;P=Y}else{Ma=_;break}}}}while(0);za=c[I>>2]|0;ya=c[ta>>2]|0;if((ya|0)==(za|0)){O=5;break d}else{Ea=ya;Fa=za;Ga=Ma}}if((O|0)==10){O=0;if((Ha-La|0)<1){Qa=0;Ra=La}else{H=Fa+3|0;c[I>>2]=H;Qa=d[La]|0;Ra=H}if((Ha-Ra|0)<1){Sa=0;Ta=Ra}else{H=Ra+1|0;c[I>>2]=H;Sa=d[Ra]|0;Ta=H}Ia=ba(Sa,Ca)|0;Ja=Qa+Ga|0;Ka=Ta}H=o-Ia|0;Ua=(Ea|0)==(Ka|0);if((H|0)>-1){Ba=Ja;o=H;l=Ua;q=Ka;p=Ea}else{O=39;break}}if((O|0)==5){yDb(e,16,2004496,(Da=i,i=i+8|0,c[Da>>2]=o,Da)|0);i=Da;S=-1094995529;i=j;return S|0}else if((O|0)==23){yDb(e,16,1967136,(Da=i,i=i+1|0,i=i+7&-8,c[Da>>2]=0,Da)|0);i=Da;S=-1094995529;i=j;return S|0}else if((O|0)==33){yDb(e,16,1938872,(Da=i,i=i+1|0,i=i+7&-8,c[Da>>2]=0,Da)|0);i=Da;S=-1094995529;i=j;return S|0}else if((O|0)==39){if(Ua){S=0}else{Va=Ha-Ka|0;break}i=j;return S|0}else if((O|0)==107){i=j;return S|0}}else{if(ua){S=0}else{Va=h-xa|0;break}i=j;return S|0}}while(0);yDb(e,16,1914560,(Da=i,i=i+8|0,c[Da>>2]=Va,Da)|0);i=Da;S=-1094995529;i=j;return S|0};default:{yDb(e,16,2245336,(Da=i,i=i+8|0,c[Da>>2]=g,Da)|0);i=Da;S=-1;i=j;return S|0}}return 0}function lQa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;d=ICb()|0;c[b+1088>>2]=d;if((d|0)==0){e=-12;return e|0}d=xQa(b,0,b+1092|0,0)|0;c[a+140>>2]=11;e=d;return e|0}function mQa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;g=i;i=i+48|0;h=g|0;j=g+24|0;k=c[a+60>>2]|0;l=k;m=c[f+24>>2]|0;n=f+28|0;f=c[n>>2]|0;o=f>>>0>268435455>>>0?-8:f<<3;f=o>>>0>2147483639>>>0|(m|0)==0;p=f?0:m;m=f?0:o;c[h>>2]=p;c[h+12>>2]=m;o=m+8|0;c[h+16>>2]=o;c[h+4>>2]=p+(m>>3);m=h+8|0;c[m>>2]=0;if(f){q=f?-1094995529:0;i=g;return q|0}f=j|0;c[f>>2]=0;r=j+4|0;c[r>>2]=65535;s=p;p=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)>>>16;c[m>>2]=o>>>0>16>>>0?16:o;o=j+8|0;c[o>>2]=p;p=j+12|0;c[p>>2]=h;c[j+16>>2]=114;c[j+20>>2]=228;h=k+1088|0;m=$$a(a,c[h>>2]|0)|0;if((m|0)<0){q=m;i=g;return q|0}m=c[h>>2]|0;s=c[m+32>>2]|0;t=a+124|0;c[k+1028>>2]=(c[m>>2]|0)+(ba((c[t>>2]|0)-1|0,s)|0);c[k+1036>>2]=-s;s=c[r>>2]|0;u=c[f>>2]|0;v=c[o>>2]|0;w=((v<<1)-u|0)>=(s|0);x=(s+1-u>>1)+u|0;if(w){c[f>>2]=x;y=s;z=v}else{s=x-1|0;c[r>>2]=s;y=s;z=v}a:while(1){v=c[f>>2]|0;do{if((y|0)>32767){if((v|0)>=32768){s=z-32768|0;c[o>>2]=s;x=v-32768|0;c[f>>2]=x;u=y-32768|0;c[r>>2]=u;A=u;B=s;C=x;break}if(!((v|0)>16383&(y|0)<49152)){break a}x=z-16384|0;c[o>>2]=x;s=v-16384|0;c[f>>2]=s;u=y-16384|0;c[r>>2]=u;A=u;B=x;C=s}else{A=y;B=z;C=v}}while(0);c[o>>2]=B<<1;c[f>>2]=C<<1;c[r>>2]=A<<1|1;v=c[p>>2]|0;s=v+8|0;x=c[s>>2]|0;u=(d[(c[v>>2]|0)+(x>>>3)|0]|0)<<(x&7)>>>7;c[s>>2]=((x|0)<(c[v+16>>2]|0))+x;x=u&1|c[o>>2];c[o>>2]=x;y=c[r>>2]|0;z=x}c[k+1064>>2]=w&1^1;z=k+1076|0;do{if(w){if((c[z>>2]|0)==0){c[m+84>>2]=0;c[m+88>>2]=2;D=0;E=k+1092|0;break}else{q=-1094995529;i=g;return q|0}}else{c[z>>2]=0;y=k+1092|0;sQa(y);A=c[k+1060>>2]|0;if((A|0)==0){F=0}else{C=A+1|0;B=c[f>>2]|0;x=(c[r>>2]|0)-B+1|0;u=c[o>>2]|0;v=((ba(1-B+u|0,C)|0)-1|0)/(x|0)|0;s=ba(x,v)|0;G=B-1+((s+x|0)/(C|0)|0)|0;c[r>>2]=G;c[f>>2]=((s|0)/(C|0)|0)+B;B=G;G=u;b:while(1){H=c[f>>2]|0;do{if((B|0)>32767){if((H|0)>=32768){u=G-32768|0;c[o>>2]=u;C=H-32768|0;c[f>>2]=C;s=B-32768|0;c[r>>2]=s;I=s;J=u;K=C;break}if(!((H|0)>16383&(B|0)<49152)){break b}C=G-16384|0;c[o>>2]=C;u=H-16384|0;c[f>>2]=u;s=B-16384|0;c[r>>2]=s;I=s;J=C;K=u}else{I=B;J=G;K=H}}while(0);c[o>>2]=J<<1;c[f>>2]=K<<1;c[r>>2]=I<<1|1;u=c[p>>2]|0;C=u+8|0;s=c[C>>2]|0;x=(d[(c[u>>2]|0)+(s>>>3)|0]|0)<<(s&7)>>>7;c[C>>2]=((s|0)<(c[u+16>>2]|0))+s;s=x&1|c[o>>2];c[o>>2]=s;B=c[r>>2]|0;G=s}c:do{if((v|0)>0){s=1;x=l+4+(256-A<<2)|0;u=B;C=H;L=G;while(1){M=u-C+1|0;N=(L-C<<8|255|0)/(M|0)|0;O=ba(M,N)|0;P=C-1+(O+M>>8)|0;c[r>>2]=P;c[f>>2]=(O>>8)+C;O=P;P=L;d:while(1){Q=c[f>>2]|0;do{if((O|0)>32767){if((Q|0)>=32768){M=P-32768|0;c[o>>2]=M;R=Q-32768|0;c[f>>2]=R;S=O-32768|0;c[r>>2]=S;T=S;U=M;V=R;break}if(!((Q|0)>16383&(O|0)<49152)){break d}R=P-16384|0;c[o>>2]=R;M=Q-16384|0;c[f>>2]=M;S=O-16384|0;c[r>>2]=S;T=S;U=R;V=M}else{T=O;U=P;V=Q}}while(0);c[o>>2]=U<<1;c[f>>2]=V<<1;c[r>>2]=T<<1|1;M=c[p>>2]|0;R=M+8|0;S=c[R>>2]|0;W=(d[(c[M>>2]|0)+(S>>>3)|0]|0)<<(S&7)>>>7;c[R>>2]=((S|0)<(c[M+16>>2]|0))+S;S=W&1|c[o>>2];c[o>>2]=S;O=c[r>>2]|0;P=S}S=O-Q+1|0;W=(P-Q<<8|255|0)/(S|0)|0;M=ba(W,S)|0;R=Q-1+(M+S>>8)|0;c[r>>2]=R;c[f>>2]=(M>>8)+Q;M=R;R=P;e:while(1){X=c[f>>2]|0;do{if((M|0)>32767){if((X|0)>=32768){S=R-32768|0;c[o>>2]=S;Y=X-32768|0;c[f>>2]=Y;Z=M-32768|0;c[r>>2]=Z;_=Z;$=S;aa=Y;break}if(!((X|0)>16383&(M|0)<49152)){break e}Y=R-16384|0;c[o>>2]=Y;S=X-16384|0;c[f>>2]=S;Z=M-16384|0;c[r>>2]=Z;_=Z;$=Y;aa=S}else{_=M;$=R;aa=X}}while(0);c[o>>2]=$<<1;c[f>>2]=aa<<1;c[r>>2]=_<<1|1;S=c[p>>2]|0;Y=S+8|0;Z=c[Y>>2]|0;ca=(d[(c[S>>2]|0)+(Z>>>3)|0]|0)<<(Z&7)>>>7;c[Y>>2]=((Z|0)<(c[S+16>>2]|0))+Z;Z=ca&1|c[o>>2];c[o>>2]=Z;M=c[r>>2]|0;R=Z}P=M-X+1|0;O=(R-X<<8|255|0)/(P|0)|0;Z=ba(O,P)|0;ca=X-1+(Z+P>>8)|0;c[r>>2]=ca;c[f>>2]=(Z>>8)+X;Z=ca;ca=R;f:while(1){P=c[f>>2]|0;do{if((Z|0)>32767){if((P|0)>=32768){S=ca-32768|0;c[o>>2]=S;Y=P-32768|0;c[f>>2]=Y;da=Z-32768|0;c[r>>2]=da;ea=da;fa=S;ga=Y;break}if(!((P|0)>16383&(Z|0)<49152)){break f}Y=ca-16384|0;c[o>>2]=Y;S=P-16384|0;c[f>>2]=S;da=Z-16384|0;c[r>>2]=da;ea=da;fa=Y;ga=S}else{ea=Z;fa=ca;ga=P}}while(0);c[o>>2]=fa<<1;c[f>>2]=ga<<1;c[r>>2]=ea<<1|1;P=c[p>>2]|0;S=P+8|0;Y=c[S>>2]|0;da=(d[(c[P>>2]|0)+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[S>>2]=((Y|0)<(c[P+16>>2]|0))+Y;Y=da&1|c[o>>2];c[o>>2]=Y;Z=c[r>>2]|0;ca=Y}c[x>>2]=N<<16|W<<8|O|-16777216;if((s|0)>=(v|0)){break c}s=s+1|0;x=x+4|0;u=c[r>>2]|0;C=c[f>>2]|0;L=c[o>>2]|0}}}while(0);F=(v|0)!=0|0}G=c[h>>2]|0;c[G+84>>2]=1;c[G+88>>2]=1;D=F;E=y}}while(0);F=vQa(E,j,0,0,c[a+120>>2]|0,c[t>>2]|0)|0;c[z>>2]=F;if((F|0)!=0){q=-1094995529;i=g;return q|0}UGb(c[(c[h>>2]|0)+4>>2]|0,k+4|0,1024)|0;k=c[h>>2]|0;c[k+304>>2]=D;D=MCb(b,k)|0;if((D|0)<0){q=D;i=g;return q|0}c[e>>2]=1;q=c[n>>2]|0;i=g;return q|0}function nQa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+1088|0);zQa(b)|0;return 0}function oQa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+4|0;e=a|0;f=c[e>>2]|0;g=(c[d>>2]|0)-f+1|0;h=((ba(1-f+(c[a+8>>2]|0)|0,b)|0)-1|0)/(g|0)|0;i=ba(g,h)|0;c[d>>2]=f-1+((i+g|0)/(b|0)|0);c[e>>2]=f+((i|0)/(b|0)|0);pQa(a);return h|0}function pQa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+4|0;e=a|0;f=a+8|0;g=a+12|0;a:while(1){a=c[b>>2]|0;do{if((a|0)>32767){h=c[e>>2]|0;if((h|0)>=32768){i=(c[f>>2]|0)-32768|0;c[f>>2]=i;j=h-32768|0;c[e>>2]=j;k=a-32768|0;c[b>>2]=k;l=k;m=i;n=j;break}if(!((h|0)>16383&(a|0)<49152)){break a}j=(c[f>>2]|0)-16384|0;c[f>>2]=j;i=h-16384|0;c[e>>2]=i;h=a-16384|0;c[b>>2]=h;l=h;m=j;n=i}else{l=a;m=c[f>>2]|0;n=c[e>>2]|0}}while(0);c[f>>2]=m<<1;c[e>>2]=n<<1;c[b>>2]=l<<1|1;a=c[g>>2]|0;i=a+8|0;j=c[i>>2]|0;h=(d[(c[a>>2]|0)+(j>>>3)|0]|0)<<(j&7)>>>7;c[i>>2]=((j|0)<(c[a+16>>2]|0))+j;c[f>>2]=h&1|c[f>>2]}return}function qQa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a+4|0;g=a|0;h=c[g>>2]|0;i=(c[f>>2]|0)-h+1|0;j=b[e>>1]|0;k=((ba(j,1-h+(c[a+8>>2]|0)|0)|0)-1|0)/(i|0)|0;l=1;while(1){m=b[e+(l<<1)>>1]|0;if((m|0)>(k|0)){l=l+1|0}else{break}}c[f>>2]=h-1+((ba(b[e+(l-1<<1)>>1]|0,i)|0)/(j|0)|0);c[g>>2]=((ba(m,i)|0)/(j|0)|0)+h;h=d[e+1028+l|0]|0;rQa(e,l);pQa(a);return h|0}function rQa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[d+514+(e<<1)>>1]|0;do{if(f<<16>>16==(b[d+514+(e-1<<1)>>1]|0)){g=e;while(1){h=g-1|0;if((b[d+514+(h<<1)>>1]|0)==f<<16>>16){g=h}else{break}}if((g|0)==(e|0)){i=e;j=f;break}h=d+1028+e|0;k=a[h]|0;l=d+1028+g|0;a[h]=a[l]|0;a[l]=k;i=g;j=b[d+514+(g<<1)>>1]|0}else{i=e;j=f}}while(0);b[d+514+(i<<1)>>1]=j+1;if((i|0)>0){j=i;do{j=j-1|0;i=d+(j<<1)|0;b[i>>1]=(b[i>>1]|0)+1;}while((j|0)>0)}if((c[d+1292>>2]|0)==-1){j=(b[d+514+(c[d+1288>>2]<<1)>>1]<<1)-1|0;i=b[d>>1]|0;f=((j>>1)+(i<<16>>16<<2)|0)/(j|0)|0;j=(f|0)>16383?16383:f;c[d+1296>>2]=j;m=i;n=j}else{m=b[d>>1]|0;n=c[d+1296>>2]|0}j=d|0;i=d+1296|0;if((m<<16>>16|0)<=(n|0)){return}f=d+1288|0;e=m;m=n;while(1){n=c[f>>2]|0;if((n|0)>-1){k=n;n=0;while(1){b[d+(k<<1)>>1]=n;l=d+514+(k<<1)|0;h=((b[l>>1]|0)+1|0)>>>1&65535;b[l>>1]=h;if((k|0)>0){k=k-1|0;n=(h<<16>>16)+n|0}else{break}}o=b[j>>1]|0;p=c[i>>2]|0}else{o=e;p=m}if((o<<16>>16|0)>(p|0)){e=o;m=p}else{break}}return}function sQa(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=d+1292|0;do{if((c[e>>2]|0)<0){b[d+518>>1]=0}else{f=0;do{b[d+518+(f<<1)>>1]=1;b[d+4+(f<<1)>>1]=(c[e>>2]|0)-f;f=f+1|0;g=c[e>>2]|0;}while((f|0)<=(g|0));b[d+518>>1]=0;if((g|0)>0){h=0}else{break}while(1){f=h+1|0;a[d+1032+f|0]=h;if((f|0)<(c[e>>2]|0)){h=f}else{break}}}}while(0);h=d+2592|0;do{if((c[h>>2]|0)<0){b[d+1818>>1]=0}else{e=0;do{b[d+1818+(e<<1)>>1]=1;b[d+1304+(e<<1)>>1]=(c[h>>2]|0)-e;e=e+1|0;i=c[h>>2]|0;}while((e|0)<=(i|0));b[d+1818>>1]=0;if((i|0)>0){j=0}else{break}while(1){e=j+1|0;a[d+2332+e|0]=j;if((e|0)<(c[h>>2]|0)){j=e}else{break}}}}while(0);j=d+6492|0;do{if((c[j>>2]|0)<0){b[d+5718>>1]=0}else{h=0;do{b[d+5718+(h<<1)>>1]=1;b[d+5204+(h<<1)>>1]=(c[j>>2]|0)-h;h=h+1|0;k=c[j>>2]|0;}while((h|0)<=(k|0));b[d+5718>>1]=0;if((k|0)>0){l=0}else{break}while(1){h=l+1|0;a[d+6232+h|0]=l;if((h|0)<(c[j>>2]|0)){l=h}else{break}}}}while(0);l=d+5192|0;do{if((c[l>>2]|0)<0){b[d+4418>>1]=0}else{j=0;do{b[d+4418+(j<<1)>>1]=1;b[d+3904+(j<<1)>>1]=(c[l>>2]|0)-j;j=j+1|0;m=c[l>>2]|0;}while((j|0)<=(m|0));b[d+4418>>1]=0;if((m|0)>0){n=0}else{break}while(1){j=n+1|0;a[d+4932+j|0]=n;if((j|0)<(c[l>>2]|0)){n=j}else{break}}}}while(0);n=d+3892|0;if((c[n>>2]|0)<0){b[d+3118>>1]=0;o=d+6504|0;uQa(o);p=d+87128|0;uQa(p);return}else{q=0}do{b[d+3118+(q<<1)>>1]=1;b[d+2604+(q<<1)>>1]=(c[n>>2]|0)-q;q=q+1|0;r=c[n>>2]|0;}while((q|0)<=(r|0));b[d+3118>>1]=0;if((r|0)>0){s=0}else{o=d+6504|0;uQa(o);p=d+87128|0;uQa(p);return}while(1){r=s+1|0;a[d+3632+r|0]=s;if((r|0)<(c[n>>2]|0)){s=r}else{break}}o=d+6504|0;uQa(o);p=d+87128|0;uQa(p);return}function tQa(d){d=d|0;var e=0,f=0,g=0,h=0;e=d+1288|0;if((c[e>>2]|0)<0){b[d+514>>1]=0;return}else{f=0}do{b[d+514+(f<<1)>>1]=1;b[d+(f<<1)>>1]=(c[e>>2]|0)-f;f=f+1|0;g=c[e>>2]|0;}while((f|0)<=(g|0));b[d+514>>1]=0;if((g|0)>0){h=0}else{return}while(1){g=h+1|0;a[d+1028+g|0]=h;if((g|0)<(c[e>>2]|0)){h=g}else{break}}return}function uQa(b){b=b|0;var d=0,e=0;do{if((c[b+80620>>2]|0)==0){d=b|0;if((c[d>>2]|0)>0){e=0}else{break}do{a[b+8+e|0]=e;e=e+1|0;}while((e|0)<(c[d>>2]|0))}else{a[b+8|0]=1;a[b+9|0]=2;a[b+10|0]=4}}while(0);tQa(b+20|0);tQa(b+1320|0);e=0;do{tQa(b+2620+(e*5200|0)|0);tQa(b+2620+(e*5200|0)+1300|0);tQa(b+2620+(e*5200|0)+2600|0);tQa(b+2620+(e*5200|0)+3900|0);e=e+1|0;}while((e|0)<15);return}function vQa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;j=e+16|0;k=Oe[c[j>>2]&1023](e,b+5204|0)|0;do{if((k|0)==1){l=Oe[c[j>>2]&1023](e,b+3904|0)|0;m=(Oe[c[j>>2]&1023](e,b+2604|0)|0)+1|0;do{if((m|0)>2){n=((h+1|0)/2|0)-2|0;if((n|0)<1){o=-1;return o|0}else{p=(Oe[c[e+20>>2]&1023](e,n)|0)+3|0;break}}else{p=m}}while(0);if(!(p>>>0<h>>>0)){o=-1;return o|0}m=(l|0)==0?p:h-p|0;if((m|0)<1){o=-1;return o|0}if((vQa(b,e,f,g,m,i)|0)!=0){o=-1;return o|0}if((vQa(b,e,m+f|0,g,h-m|0,i)|0)==0){break}else{o=-1}return o|0}else if((k|0)==0){m=Oe[c[j>>2]&1023](e,b+3904|0)|0;n=(Oe[c[j>>2]&1023](e,b+2604|0)|0)+1|0;do{if((n|0)>2){q=((i+1|0)/2|0)-2|0;if((q|0)<1){o=-1;return o|0}else{r=(Oe[c[e+20>>2]&1023](e,q)|0)+3|0;break}}else{r=n}}while(0);if(!(r>>>0<i>>>0)){o=-1;return o|0}n=(m|0)==0?r:i-r|0;if((n|0)<1){o=-1;return o|0}if((vQa(b,e,f,g,h,n)|0)!=0){o=-1;return o|0}if((vQa(b,e,f,n+g|0,h,i-n|0)|0)==0){break}else{o=-1}return o|0}else if((k|0)==2){n=c[b>>2]|0;if((c[n+1064>>2]|0)!=0){wQa(b,e,f,g,h,i);o=0;return o|0}if((Oe[c[j>>2]&1023](e,b+1304|0)|0)==0){l=Oe[c[j>>2]&1023](e,b+87148|0)|0;a:do{if((l|0)<(c[b+87132>>2]|0)){s=d[b+87136+l|0]|0;t=l}else{q=Oe[c[j>>2]&1023](e,b+88448|0)|0;u=(c[b+87128>>2]|0)-1|0;v=0;while(1){if((v|0)>=(u|0)){s=q;t=v;break a}if((d[b+87136+v|0]|0|0)==(q|0)){s=q;t=v;break}else{v=v+1|0}}}}while(0);if((t|0)!=0){if((t|0)>0){l=t;while(1){m=l-1|0;a[b+87136+l|0]=a[b+87136+m|0]|0;if((m|0)>0){l=m}else{break}}}a[b+87136|0]=s}do{if((c[(c[n>>2]|0)+696>>2]&8|0)==0){w=32}else{if((c[n+1048>>2]|0)==0){if((s|0)==128){w=71;break}else if((s|0)==255){w=39;break}else{o=-1}return o|0}else{if((s-1|0)>>>0>1>>>0&(s|0)!=4){o=-1}else{w=32;break}return o|0}}}while(0);b:do{if((w|0)==32){if((s|0)==128){w=71;break}else if((s|0)==4){o=AQa(n,f,g,h,i)|0;return o|0}else if((s|0)!=2){w=39;break}l=n+1052|0;m=c[l>>2]|0;if((m|0)==0){w=71;break}v=i+g|0;if((i|0)<=0){w=71;break}q=n+1048|0;u=n+1056|0;x=f*3|0;y=h*3|0;z=n+1028|0;A=n+1036|0;B=n+1032|0;C=g;D=m;while(1){m=(ba(c[u>>2]|0,C)|0)+x|0;UGb((c[q>>2]|0)+m|0,D+m|0,y)|0;m=(ba(c[A>>2]|0,C)|0)+f|0;UGb((c[z>>2]|0)+m|0,(c[B>>2]|0)+m|0,h)|0;m=C+1|0;if((m|0)>=(v|0)){w=71;break b}C=m;D=c[l>>2]|0}}}while(0);if((w|0)==39){wQa(b,e,f,g,h,i);o=0;return o|0}else if((w|0)==71){o=0;return o|0}}l=n+1040|0;D=n+1044|0;BQa(e,c[l>>2]|0,0,f,g,h,i,c[D>>2]|0,0,b+87128|0,n+4|0);C=n+1028|0;v=n+1036|0;B=c[v>>2]|0;z=c[D>>2]|0;D=b+6504|0;A=n+1048|0;y=n+1056|0;if((i|0)<=0){o=0;return o|0}q=c[y>>2]|0;x=(ba(z,g)|0)+f|0;u=(ba(B,g)|0)+f|0;m=(ba(q,g)|0)+(f*3|0)|0;E=(h|0)>0;F=n|0;G=b+6524|0;H=b+6508|0;I=b+6512|0;J=b+7824|0;K=D|0;L=h-1|0;M=n+1052|0;N=n+1032|0;O=(c[l>>2]|0)+x|0;x=(c[C>>2]|0)+u|0;u=0;l=(c[A>>2]|0)+m|0;m=q;c:while(1){if(E){q=u+g|0;P=q+1|0;Q=0;do{do{if((c[(c[F>>2]|0)+696>>2]&8|0)==0){R=a[O+Q|0]|0}else{S=a[O+Q|0]|0;if((c[A>>2]|0)==0){if((S<<24>>24|0)==(-128|0)|(S<<24>>24|0)==(-1|0)){R=S;break}else{o=-1;w=73;break c}}else{if((S<<24>>24|0)==1|(S<<24>>24|0)==2|(S<<24>>24|0)==4){R=S;break}else{o=-1;w=73;break c}}}}while(0);d:do{if((R<<24>>24|0)==2){S=Q+f|0;T=c[M>>2]|0;if((T|0)==0){break}U=S*3|0;V=q;W=T;while(1){T=(ba(c[y>>2]|0,V)|0)+U|0;X=(c[A>>2]|0)+T|0;Y=W+T|0;a[X]=a[Y]|0;a[X+1|0]=a[Y+1|0]|0;a[X+2|0]=a[Y+2|0]|0;Y=(ba(c[v>>2]|0,V)|0)+S|0;a[(c[C>>2]|0)+Y|0]=a[(c[N>>2]|0)+Y|0]|0;Y=V+1|0;if((Y|0)>=(P|0)){break d}V=Y;W=c[M>>2]|0}}else if((R<<24>>24|0)==4){if((AQa(n,Q+f|0,q,1,1)|0)!=0){o=-1;w=73;break c}}else if((R<<24>>24|0)!=(-128|0)){do{if((Q|u|0)==0){W=Oe[c[j>>2]&1023](e,G)|0;e:do{if((W|0)<(c[H>>2]|0)){Z=d[b+6512+W|0]|0;_=W}else{V=Oe[c[j>>2]&1023](e,J)|0;S=(c[K>>2]|0)-1|0;U=0;while(1){if((U|0)>=(S|0)){Z=V;_=U;break e}if((d[b+6512+U|0]|0|0)==(V|0)){Z=V;_=U;break}else{U=U+1|0}}}}while(0);if((_|0)==0){$=Z;break}if((_|0)>0){W=_;while(1){U=W-1|0;a[b+6512+W|0]=a[b+6512+U|0]|0;if((U|0)>0){W=U}else{break}}}a[I]=Z;$=Z}else{$=CQa(e,D,x+Q|0,B,Q,u,L-Q|0)|0}}while(0);a[x+Q|0]=$;if((c[A>>2]|0)==0){break}W=n+4+($<<2)|0;U=Q*3|0;a[l+(U+2)|0]=c[W>>2];a[l+(U+1)|0]=(c[W>>2]|0)>>>8;a[l+U|0]=(c[W>>2]|0)>>>16}}while(0);Q=Q+1|0;}while((Q|0)<(h|0));aa=c[y>>2]|0}else{aa=m}Q=u+1|0;if((Q|0)<(i|0)){O=O+z|0;x=x+B|0;u=Q;l=l+aa|0;m=aa}else{o=0;w=73;break}}if((w|0)==73){return o|0}}else{o=-1;return o|0}}while(0);o=0;return o|0}function wQa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=c[b>>2]|0;k=e+16|0;if((Oe[c[k>>2]&1023](e,b+4|0)|0)!=0){BQa(e,c[j+1028>>2]|0,c[j+1048>>2]|0,f,g,h,i,c[j+1036>>2]|0,c[j+1056>>2]|0,b+6504|0,j+4|0);return}l=c[j+1036>>2]|0;m=c[j+1056>>2]|0;n=(c[j+1028>>2]|0)+((ba(l,g)|0)+f)|0;o=j+1048|0;p=(c[o>>2]|0)+((ba(m,g)|0)+(f*3|0))|0;f=Oe[c[k>>2]&1023](e,b+6524|0)|0;a:do{if((f|0)<(c[b+6508>>2]|0)){q=d[b+6512+f|0]|0;r=f}else{g=Oe[c[k>>2]&1023](e,b+7824|0)|0;s=(c[b+6504>>2]|0)-1|0;t=0;while(1){if((t|0)>=(s|0)){q=g;r=t;break a}if((d[b+6512+t|0]|0|0)==(g|0)){q=g;r=t;break}else{t=t+1|0}}}}while(0);if((r|0)!=0){if((r|0)>0){e=r;while(1){r=e-1|0;a[b+6512+e|0]=a[b+6512+r|0]|0;if((r|0)>0){e=r}else{break}}}a[b+6512|0]=q}b=c[j+4+(q<<2)>>2]|0;if((i|0)<=0){return}j=q&255;q=h*3|0;e=b&255;r=b>>>8&255;k=b>>>16&255;b=0;f=n;n=p;while(1){TGb(f|0,j|0,h|0)|0;if(!((c[o>>2]|0)==0|(q|0)<1)){p=0;do{a[n+(p+2)|0]=e;a[n+(p+1)|0]=r;a[n+p|0]=k;p=p+3|0;}while((p|0)<(q|0))}p=b+1|0;if((p|0)<(i|0)){b=p;f=f+l|0;n=n+m|0}else{break}}return}



function xQa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;j=i;l=c[a>>2]|0;m=l+100|0;n=c[m>>2]|0;if((n|0)<820){yDb(l,16,2245112,(o=i,i=i+8|0,c[o>>2]=n,o)|0);i=o;p=-1094995529;i=j;return p|0}q=l+96|0;r=c[q>>2]|0;s=r;t=fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;if(t>>>0<n>>>0){yDb(l,16,2319472,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=n,o)|0);i=o;p=-1094995529;i=j;return p|0}n=r+20|0;t=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=l+128|0;c[n>>2]=t;s=r+24|0;u=fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;s=l+132|0;c[s>>2]=u;if((t|0)>4096|(u|0)>4096){yDb(l,16,2184664,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=u,o)|0);i=o;p=-1094995529;i=j;return p|0}v=l;if((t|0)<1|(u|0)<1){yDb(v,16,2107640,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=u,o)|0);i=o;p=-1094995529;i=j;return p|0}u=r+4|0;t=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=r+8|0;r=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;yDb(v,48,2050080,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=r,o)|0);i=o;r=c[q>>2]|0;t=r+4|0;if(((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)>>>0>1>>>0|0)!=(b|0)){yDb(v,16,2004456,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=j;return p|0}t=r+48|0;r=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;c[a+1060>>2]=r;if(r>>>0>256>>>0){yDb(v,16,1967080,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;p=-1094995529;i=j;return p|0}yDb(v,48,1938848,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;r=c[q>>2]|0;t=r+12|0;u=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=r+16|0;r=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;yDb(v,48,1914528,(o=i,i=i+16|0,c[o>>2]=u,c[o+8>>2]=r,o)|0);i=o;r=c[s>>2]|0;yDb(v,48,1894096,(o=i,i=i+16|0,c[o>>2]=c[n>>2],c[o+8>>2]=r,o)|0);i=o;r=(c[q>>2]|0)+28|0;n=fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;w=(c[k>>2]=n,+g[k>>2]);yDb(v,48,2351312,(o=i,i=i+8|0,h[o>>3]=w,o)|0);i=o;n=(c[q>>2]|0)+32|0;r=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;yDb(v,48,2331240,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;r=(c[q>>2]|0)+36|0;n=fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;w=(c[k>>2]=n,+g[k>>2]);yDb(v,48,2306880,(o=i,i=i+8|0,h[o>>3]=w,o)|0);i=o;n=(c[q>>2]|0)+40|0;r=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;w=(c[k>>2]=r,+g[k>>2]);yDb(v,48,2288600,(o=i,i=i+8|0,h[o>>3]=w,o)|0);i=o;r=(c[q>>2]|0)+44|0;n=fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;w=(c[k>>2]=n,+g[k>>2]);yDb(v,48,2272328,(o=i,i=i+8|0,h[o>>3]=w,o)|0);i=o;n=(b|0)!=0;do{if(n){r=c[m>>2]|0;if((r|0)<828){yDb(v,16,2256992,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;p=-1094995529;i=j;return p|0}r=(c[q>>2]|0)+52|0;s=fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;c[a+1080>>2]=s;yDb(v,48,2242632,(o=i,i=i+8|0,c[o>>2]=s,o)|0);i=o;s=(c[q>>2]|0)+56|0;r=fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;c[a+1084>>2]=r;if(!((r-2|0)>>>0>254>>>0)){yDb(v,48,2218248,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;break}yDb(v,16,2230176,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;p=-1094995529;i=j;return p|0}else{c[a+1080>>2]=0;c[a+1084>>2]=256}}while(0);m=n?60:52;n=c[q>>2]|0;q=0;do{r=(q*3|0)+m|0;c[a+4+(q<<2)>>2]=(d[n+r|0]|0)<<16|(d[n+(r+1)|0]|0)<<8|(d[n+(r+2)|0]|0)|-16777216;q=q+1|0;}while((q|0)<256);q=(c[l+120>>2]|0)+15&-16;c[a+1044>>2]=q;n=WDb(ba(q,c[l+124>>2]|0)|0)|0;c[a+1040>>2]=n;if((n|0)==0){yDb(v,16,2208904,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-12;i=j;return p|0}c[e>>2]=a;o=a+1084|0;yQa(e,b,c[o>>2]|0);if((c[a+1080>>2]|0)!=0){c[f>>2]=a;yQa(f,b,c[o>>2]|0)}c[a+1076>>2]=1;p=0;i=j;return p|0}function yQa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[a+1292>>2]=2;c[a+1296>>2]=-1;c[a+1300>>2]=-2;c[a+2592>>2]=2;c[a+2596>>2]=-1;c[a+2600>>2]=-2;c[a+6492>>2]=3;c[a+6496>>2]=50;c[a+6500>>2]=150;c[a+5192>>2]=2;c[a+5196>>2]=50;c[a+5200>>2]=100;c[a+3892>>2]=3;c[a+3896>>2]=15;c[a+3900>>2]=45;c[a+6504>>2]=12;c[a+6508>>2]=8;c[a+87124>>2]=0;c[a+7812>>2]=9;c[a+7816>>2]=15;c[a+7820>>2]=135;c[a+9112>>2]=d;c[a+9116>>2]=50;e=d*50|0;c[a+9120>>2]=e;f=0;g=0;while(1){h=f+2|0;i=(f|0)!=0?15:-1;j=ba(i,h)|0;k=c[473064+(f<<2)>>2]|0;l=(k|0)>1;m=0;n=g;while(1){c[a+9124+(n*5200|0)+1288>>2]=h;c[a+9124+(n*5200|0)+1292>>2]=i;c[a+9124+(n*5200|0)+1296>>2]=j;c[a+9124+(n*5200|0)+2588>>2]=h;c[a+9124+(n*5200|0)+2592>>2]=i;c[a+9124+(n*5200|0)+2596>>2]=j;c[a+9124+(n*5200|0)+3888>>2]=h;c[a+9124+(n*5200|0)+3892>>2]=i;c[a+9124+(n*5200|0)+3896>>2]=j;c[a+9124+(n*5200|0)+5188>>2]=h;c[a+9124+(n*5200|0)+5192>>2]=i;c[a+9124+(n*5200|0)+5196>>2]=j;o=m+1|0;if((o|0)<(k|0)){m=o;n=n+1|0}else{break}}n=f+1|0;if((n|0)<4){f=n;g=(l?k:1)+g|0}else{break}}g=(b|0)!=0;b=g?3:2;c[a+87128>>2]=b|4;c[a+87132>>2]=b;c[a+167748>>2]=g&1;g=b+1|0;c[a+88436>>2]=g;c[a+88440>>2]=15;c[a+88444>>2]=g*15|0;c[a+89736>>2]=d;c[a+89740>>2]=50;c[a+89744>>2]=e;e=0;d=0;while(1){g=e+2|0;b=(e|0)!=0?15:-1;f=ba(b,g)|0;n=c[473064+(e<<2)>>2]|0;m=(n|0)>1;j=0;i=d;while(1){c[a+89748+(i*5200|0)+1288>>2]=g;c[a+89748+(i*5200|0)+1292>>2]=b;c[a+89748+(i*5200|0)+1296>>2]=f;c[a+89748+(i*5200|0)+2588>>2]=g;c[a+89748+(i*5200|0)+2592>>2]=b;c[a+89748+(i*5200|0)+2596>>2]=f;c[a+89748+(i*5200|0)+3888>>2]=g;c[a+89748+(i*5200|0)+3892>>2]=b;c[a+89748+(i*5200|0)+3896>>2]=f;c[a+89748+(i*5200|0)+5188>>2]=g;c[a+89748+(i*5200|0)+5192>>2]=b;c[a+89748+(i*5200|0)+5196>>2]=f;h=j+1|0;if((h|0)<(n|0)){j=h;i=i+1|0}else{break}}i=e+1|0;if((i|0)<4){e=i;d=(m?n:1)+d|0}else{break}}return}function zQa(a){a=a|0;$Db(a+1040|0);return 0}function AQa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=(c[a+1068>>2]|0)+b|0;if((g|0)<0){h=-1;return h|0}i=c[a>>2]|0;if((g+e|0)>(c[i+120>>2]|0)){h=-1;return h|0}j=(c[a+1072>>2]|0)+d|0;if((j|0)<0){h=-1;return h|0}if((j+f|0)>(c[i+124>>2]|0)){h=-1;return h|0}i=c[a+1048>>2]|0;if((i|0)==0){h=-1;return h|0}k=c[a+1028>>2]|0;l=a+1036|0;m=c[l>>2]|0;n=k+((ba(m,d)|0)+b)|0;o=a+1056|0;p=c[o>>2]|0;q=i+((ba(p,d)|0)+(b*3|0))|0;b=c[a+1052>>2]|0;if((b|0)==0){r=i+((ba(p,j)|0)+(g*3|0))|0;s=k+((ba(m,j)|0)+g)|0}else{r=b+((ba(p,j)|0)+(g*3|0))|0;s=(c[a+1032>>2]|0)+((ba(m,j)|0)+g)|0}if((f|0)<=0){h=0;return h|0}g=e*3|0;j=n;n=q;q=s;s=r;r=0;while(1){VGb(j|0,q|0,e|0)|0;VGb(n|0,s|0,g|0)|0;m=c[l>>2]|0;a=c[o>>2]|0;p=r+1|0;if((p|0)<(f|0)){j=j+m|0;n=n+a|0;q=q+m|0;s=s+a|0;r=p}else{h=0;break}}return h|0}function BQa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((j|0)<=0){return}o=(i|0)>0;p=b+16|0;q=m+20|0;r=m+4|0;s=m+8|0;t=m+1320|0;u=m|0;v=(f|0)==0;w=i-1|0;x=e+((ba(k,h)|0)+g)|0;e=0;y=f+((ba(l,h)|0)+(g*3|0))|0;while(1){a:do{if(o){if(v){z=0}else{g=0;while(1){do{if((g|e|0)==0){h=Oe[c[p>>2]&1023](b,q)|0;b:do{if((h|0)<(c[r>>2]|0)){A=d[m+8+h|0]|0;B=h}else{f=Oe[c[p>>2]&1023](b,t)|0;C=(c[u>>2]|0)-1|0;D=0;while(1){if((D|0)>=(C|0)){A=f;B=D;break b}if((d[m+8+D|0]|0|0)==(f|0)){A=f;B=D;break}else{D=D+1|0}}}}while(0);if((B|0)==0){E=A;break}if((B|0)>0){h=B;while(1){D=h-1|0;a[m+8+h|0]=a[m+8+D|0]|0;if((D|0)>0){h=D}else{break}}}a[s]=A;E=A}else{E=CQa(b,m,x+g|0,k,g,e,w-g|0)|0}}while(0);a[x+g|0]=E;h=n+(E<<2)|0;D=g*3|0;a[y+(D+2)|0]=c[h>>2];a[y+(D+1)|0]=(c[h>>2]|0)>>>8;a[y+D|0]=(c[h>>2]|0)>>>16;g=g+1|0;if((g|0)>=(i|0)){break a}}}do{do{if((z|e|0)==0){g=Oe[c[p>>2]&1023](b,q)|0;if((g|0)<(c[r>>2]|0)){F=a[m+8+g|0]|0;G=g}else{g=Oe[c[p>>2]&1023](b,t)|0;h=(c[u>>2]|0)-1|0;D=0;while(1){if((D|0)>=(h|0)){break}if((d[m+8+D|0]|0|0)==(g|0)){break}else{D=D+1|0}}F=g&255;G=D}if((G|0)==0){H=F;break}if((G|0)>0){h=G;while(1){f=h-1|0;a[m+8+h|0]=a[m+8+f|0]|0;if((f|0)>0){h=f}else{break}}}a[s]=F;H=F}else{H=(CQa(b,m,x+z|0,k,z,e,w-z|0)|0)&255}}while(0);a[x+z|0]=H;z=z+1|0;}while((z|0)<(i|0))}}while(0);h=e+1|0;if((h|0)<(j|0)){x=x+k|0;e=h;y=y+l|0}else{break}}return}function CQa(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;l=i;i=i+8|0;m=l|0;do{if((j|0)==0){n=a[f-1|0]|0;o=n;p=n;q=n;r=n}else{n=a[f+(-g|0)|0]|0;if((h|0)==0){s=n;t=n}else{s=a[f-1|0]|0;t=a[f+~g|0]|0}if((k|0)==0){o=s;p=n;q=t;r=n;break}o=s;p=n;q=t;r=a[f+(1-g)|0]|0}}while(0);if((h|0)>1){u=(a[f-2|0]|0)==o<<24>>24|0}else{u=0}if((j|0)>1){v=(a[f+(g*-2|0)|0]|0)==p<<24>>24?u|2:u}else{v=u}a[m|0]=q;u=0;while(1){if((u|0)>=1){break}if((a[m+u|0]|0)==p<<24>>24){break}else{u=u+1|0}}if((u|0)==1){a[m+1|0]=p;w=2}else{w=1}u=0;while(1){if((u|0)>=(w|0)){break}if((a[m+u|0]|0)==r<<24>>24){break}else{u=u+1|0}}if((u|0)==(w|0)){a[m+w|0]=r;x=w+1|0}else{x=w}w=0;while(1){if((w|0)>=(x|0)){break}if((a[m+w|0]|0)==o<<24>>24){break}else{w=w+1|0}}if((w|0)==(x|0)){a[m+x|0]=o;y=x+1|0}else{y=x}do{if((y|0)==2){x=r<<24>>24==q<<24>>24;if(p<<24>>24==q<<24>>24){if(x){z=1;break}z=o<<24>>24==q<<24>>24?2:3;break}w=o<<24>>24==q<<24>>24;if(x){z=w?4:5;break}else{z=w?6:7;break}}else if((y|0)==3){if(p<<24>>24==q<<24>>24){z=8;break}if(r<<24>>24==q<<24>>24){z=9;break}if(o<<24>>24==q<<24>>24){z=10;break}if(r<<24>>24==p<<24>>24){z=11;break}z=p<<24>>24==o<<24>>24?12:13}else if((y|0)==4){z=14}else{z=0}}while(0);o=b+16|0;p=Oe[c[o>>2]&1023](b,e+2620+(z*5200|0)+(v*1300|0)|0)|0;if((p|0)<(y|0)){A=d[m+p|0]|0;i=l;return A|0}p=Oe[c[o>>2]&1023](b,e+20|0)|0;a:do{if((p|0)<(c[e+4>>2]|0)){v=c[e>>2]|0;b:do{if((v|0)>0){z=0;r=0;while(1){q=e+8+z|0;w=0;while(1){if((w|0)>=(y|0)){break}if((a[q]|0)==(a[m+w|0]|0)){break}else{w=w+1|0}}if((w|0)==(y|0)){if((r|0)==(p|0)){B=z;break b}C=r+1|0}else{C=r}q=z+1|0;if((q|0)<(v|0)){z=q;r=C}else{B=q;break}}}else{B=0}}while(0);r=v-1|0;z=(B|0)>(r|0)?r:B;D=d[e+8+z|0]|0;E=z}else{z=Oe[c[o>>2]&1023](b,e+1320|0)|0;r=(c[e>>2]|0)-1|0;q=0;while(1){if((q|0)>=(r|0)){D=z;E=q;break a}if((d[e+8+q|0]|0)==(z|0)){D=z;E=q;break}else{q=q+1|0}}}}while(0);if((E|0)==0){A=D;i=l;return A|0}if((E|0)>0){b=E;while(1){E=b-1|0;a[e+8+b|0]=a[e+8+E|0]|0;if((E|0)>0){b=E}else{break}}}a[e+8|0]=D;A=D;i=l;return A|0}function DQa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a+60|0;d=c[b>>2]|0;e=d+19632|0;c[e>>2]=a;f=xQa(e,1,d+20736|0,d+188488|0)|0;if((f|0)!=0){g=f;return g|0}f=d+19628|0;c[f>>2]=ICb()|0;e=c[d+20676>>2]|0;h=d+20668|0;c[h>>2]=e;i=a+124|0;j=d+20660|0;c[j>>2]=cEb(ba(c[i>>2]|0,e)|0)|0;e=cEb(ba(c[i>>2]|0,c[h>>2]|0)|0)|0;c[d+20664>>2]=e;do{if(!((c[j>>2]|0)==0|(e|0)==0)){if((c[f>>2]|0)==0){break}h=c[b>>2]|0;i=h;c[h+4>>2]=a;k=b2a(i)|0;do{if((k|0)<0){l=k}else{I2a(h+15332|0);c[h+15660>>2]=1;c[h+15996>>2]=1080128;c[h+16e3>>2]=1080064;c[h+15584>>2]=0;c[h+15580>>2]=0;c[h+15664>>2]=7;c[h+15668>>2]=31;c[h+15588>>2]=0;c[h+15592>>2]=0;c[h+15596>>2]=1;c[h+15680>>2]=0;c[h+15684>>2]=0;c[h+15688>>2]=1;c[h+15692>>2]=1;c[h+15600>>2]=0;c[h+15696>>2]=0;c[h+19616>>2]=0;c[h+15604>>2]=0;c[a+156>>2]=0;c[h+68>>2]=0;c[h+15700>>2]=0;c[h+15704>>2]=0;c[h+15608>>2]=1;k2a(i);m=SPa(a)|0;if((m|0)<0){l=m;break}m=j2a(i)|0;if((m|0)<0){l=m;break}c[h+12452>>2]=h+10680;c[h+12456>>2]=h+10808;JQa(d+20720|0);c[a+140>>2]=(c[d+20692>>2]|0)==127?46:2;g=0;return g|0}}while(0);h=c[b>>2]|0;JCb(h+19628|0);zQa(h+19632|0)|0;$Db(h+20660|0);$Db(h+20664|0);l2a(a)|0;g=l;return g|0}}while(0);l=c[b>>2]|0;JCb(l+19628|0);zQa(l+19632|0)|0;$Db(l+20660|0);$Db(l+20664|0);l2a(a)|0;g=-12;return g|0}function EQa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0;j=i;i=i+464|0;k=j|0;l=j+24|0;m=j+40|0;n=j+64|0;o=c[h+24>>2]|0;p=h+28|0;h=c[p>>2]|0;q=e+60|0;r=c[q>>2]|0;s=r+19632|0;t=f;u=h>>>0>268435455>>>0?-8:h<<3;v=u>>>0>2147483639>>>0|(o|0)==0;w=v?0:o;x=v?0:u;u=k|0;c[u>>2]=w;y=k+12|0;c[y>>2]=x;z=x+8|0;A=k+16|0;c[A>>2]=z;B=k+4|0;c[B>>2]=w+(x>>3);x=k+8|0;c[x>>2]=0;if(v){C=v?-1094995529:0;i=j;return C|0}v=(d[w]|0)>>>7;D=(z|0)>0;E=(v|0)!=0;if(E){F=D?8:7;G=z>>>0>F>>>0?F:z}else{G=D&1}c[x>>2]=G;D=(d[w+(G>>>3)|0]|0)<<(G&7)>>>7;F=((G|0)<(z|0))+G|0;c[x>>2]=F;G=D&1;if(E){H=0;I=F}else{D=(d[w+(F>>>3)|0]|0)<<(F&7)>>>7;J=((F|0)<(z|0))+F|0;c[x>>2]=J;H=D&1;I=J}J=d[w+(I>>>3)|0]|0;D=((I|0)<(z|0))+I|0;c[x>>2]=D;F=(J&128>>>((I&7)>>>0)|0)!=0;if(F){I=d[w+(D>>>3)|0]|0;J=((D|0)<(z|0))+D|0;c[x>>2]=J;K=(I&128>>>((D&7)>>>0)|0)!=0;L=J}else{K=0;L=D}D=K&1;J=r+20712|0;I=c[J>>2]|0;do{if((I|0)>0){c[r+19624>>2]=I}else{if((I|0)>=0){c[r+19624>>2]=c[e+124>>2];break}M=d[w+(L>>>3)|0]|0;N=((L|0)<(z|0))+L|0;c[x>>2]=N;if((M&128>>>((L&7)>>>0)|0)==0){if(!E){break}c[r+19624>>2]=(c[e+124>>2]|0)/2|0;break}M=d[w+(N>>>3)|0]|0;O=((N|0)<(z|0))+N|0;c[x>>2]=O;P=w+(O>>>3)|0;if((M&128>>>((N&7)>>>0)|0)==0){N=P;M=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(O&7)>>>24;N=O+8|0;c[x>>2]=z>>>0>N>>>0?N:z;c[r+19624>>2]=M<<4;break}M=d[P]|0;P=((O|0)<(z|0))+O|0;c[x>>2]=P;N=w+(P>>>3)|0;Q=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(P&7);if((M&128>>>((O&7)>>>0)|0)==0){O=P+12|0;c[x>>2]=z>>>0>O>>>0?O:z;c[r+19624>>2]=Q>>>20;break}else{O=P+16|0;c[x>>2]=z>>>0>O>>>0?O:z;c[r+19624>>2]=Q>>>16;break}}}while(0);do{if((c[J>>2]|0)!=0){z=c[r+19624>>2]|0;if((z|0)<(D^1|0)){C=-1094995529;i=j;return C|0}if((z|0)>((c[e+124>>2]|0)-1|0)){C=-1094995529}else{break}i=j;return C|0}}while(0);D=c[x>>2]|0;z=-D&7;if((z|0)==0){R=D}else{w=c[A>>2]|0;L=z+D|0;D=w>>>0>L>>>0?L:w;c[x>>2]=D;R=D}D=R>>3;R=o+D|0;w=h-D|0;if((w|0)<1){C=-1094995529;i=j;return C|0}do{if(K){if((H|G|0)!=0){C=-1094995529;i=j;return C|0}if((c[J>>2]|0)==0){break}if((c[r+19624>>2]|0)==0){break}else{C=-1094995529}i=j;return C|0}}while(0);L=K?46:2;z=e+140|0;c[z>>2]=L;I=r+19628|0;Q=c[I>>2]|0;if((c[Q+80>>2]|0)!=(L|0)){KCb(Q)}Q=(G|0)!=0;do{if(Q){if(!((w+2|0)>-1)){yDb(0,0,2050048,(S=i,i=i+24|0,c[S>>2]=2272312,c[S+8>>2]=2256968,c[S+16>>2]=135,S)|0);i=S;Cd();return 0}G=l|0;c[G>>2]=R;c[l+8>>2]=R;L=o+(h+2)|0;c[l+4>>2]=L;O=m|0;c[O>>2]=0;P=m+4|0;c[P>>2]=16777215;if((L-R|0)<3){T=0}else{c[G>>2]=o+(D+3);T=(d[o+(D+1)|0]|0)<<8|(d[R]|0)<<16|(d[o+(D+2)|0]|0)}G=m+8|0;c[G>>2]=T;c[m+12>>2]=l;c[m+16>>2]=842;c[m+20>>2]=672;L=(T<<1|0)>16777214;if(L){c[O>>2]=8388608;U=16777215;V=8388608}else{c[P>>2]=8388607;U=8388607;V=0}M=m+12|0;if(((U>>>15)-(V>>>15)|0)<2){N=U;W=V;X=T;while(1){if(((N^W)&65536|0)==0){Y=N;Z=W;_=X}else{$=N^32768;c[P>>2]=$;aa=X^32768;c[G>>2]=aa;ca=W^32768;c[O>>2]=ca;Y=$;Z=ca;_=aa}aa=Y<<8&16776960;ca=aa|255;c[P>>2]=ca;$=c[M>>2]|0;da=$|0;ea=c[da>>2]|0;if(((c[$+4>>2]|0)-ea|0)<1){fa=0}else{c[da>>2]=ea+1;fa=d[ea]|0}ea=fa|_<<8&16776960;c[G>>2]=ea;da=Z<<8&16776960;c[O>>2]=da;if(((aa>>>15)-(da>>>15)|0)<2){N=ca;W=da;X=ea}else{ga=ca;ha=da;ia=ea;break}}}else{ga=U;ha=V;ia=T}X=L&1^1;W=e+120|0;N=e+124|0;ea=0;da=ga;ca=ha;aa=ia;while(1){$=((aa<<1)-ca|0)>=(da|0);ja=(da+1-ca>>1)+ca|0;if($){c[O>>2]=ja;ka=da;la=ja}else{ma=ja-1|0;c[P>>2]=ma;ka=ma;la=ca}if(((ka>>15)-(la>>15)|0)<2){ma=ka;ja=la;na=aa;while(1){if(((ma^ja)&65536|0)==0){oa=ma;pa=ja;qa=na}else{ra=ma^32768;c[P>>2]=ra;sa=na^32768;c[G>>2]=sa;ta=ja^32768;c[O>>2]=ta;oa=ra;pa=ta;qa=sa}sa=oa<<8&16776960;ta=sa|255;c[P>>2]=ta;ra=c[M>>2]|0;ua=ra|0;va=c[ua>>2]|0;if(((c[ra+4>>2]|0)-va|0)<1){wa=0}else{c[ua>>2]=va+1;wa=d[va]|0}va=wa|qa<<8&16776960;c[G>>2]=va;ua=pa<<8&16776960;c[O>>2]=ua;if(((sa>>>15)-(ua>>>15)|0)<2){ma=ta;ja=ua;na=va}else{xa=ta;ya=ua;break}}}else{xa=ka;ya=la}if(!$){break}if((ea|0)==20){C=-1094995529;za=254;break}na=c[W>>2]|0;if((ea|0)==0){ja=GQa(m,na)|0;c[n+4>>2]=ja;Aa=ja}else{ja=c[n+((ea-1|0)*20|0)+4>>2]|0;ma=ja+(GQa(m,na-ja|0)|0)|0;c[n+(ea*20|0)+4>>2]=ma;Aa=ma}ma=GQa(m,c[N>>2]|0)|0;c[n+(ea*20|0)+8>>2]=ma;c[n+(ea*20|0)+12>>2]=(GQa(m,(c[W>>2]|0)-Aa|0)|0)+1;c[n+(ea*20|0)+16>>2]=(GQa(m,(c[N>>2]|0)-ma|0)|0)+1;ea=ea+1|0;da=c[P>>2]|0;ca=c[O>>2]|0;aa=c[G>>2]|0}if((za|0)==254){i=j;return C|0}if(!(L|(ea|0)==0)){yDb(e,16,2184584,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}if(L){if((ea|0)>0){Ba=ea;za=67}else{Ca=0;Da=xa;Ea=ya;Fa=ea}}else{c[n+4>>2]=0;c[n+8>>2]=0;c[n+12>>2]=c[W>>2];c[n+16>>2]=c[N>>2];Ba=1;za=67}do{if((za|0)==67){aa=0;ca=0;while(1){if(L){da=c[P>>2]|0;ma=c[O>>2]|0;ja=c[G>>2]|0;na=((ja<<1)-ma|0)>=(da|0);ua=(da+1-ma>>1)+ma|0;if(na){c[O>>2]=ua;Ga=da;Ha=ua}else{da=ua-1|0;c[P>>2]=da;Ga=da;Ha=ma}if(((Ga>>15)-(Ha>>15)|0)<2){ma=Ga;da=Ha;ua=ja;do{if(((ma^da)&65536|0)==0){Ia=ma;Ja=da;Ka=ua}else{ja=ma^32768;c[P>>2]=ja;ta=ua^32768;c[G>>2]=ta;va=da^32768;c[O>>2]=va;Ia=ja;Ja=va;Ka=ta}ta=Ia<<8&16776960;ma=ta|255;c[P>>2]=ma;va=c[M>>2]|0;ja=va|0;sa=c[ja>>2]|0;if(((c[va+4>>2]|0)-sa|0)<1){La=0}else{c[ja>>2]=sa+1;La=d[sa]|0}ua=La|Ka<<8&16776960;c[G>>2]=ua;da=Ja<<8&16776960;c[O>>2]=da;}while(((ta>>>15)-(da>>>15)|0)<2)}if(na){break}}do{if((aa|0)==0){da=c[P>>2]|0;ua=c[O>>2]|0;ma=c[G>>2]|0;ta=((ma<<1)-ua|0)>=(da|0);sa=(da+1-ua>>1)+ua|0;if(ta){c[O>>2]=sa;Ma=da;Na=sa}else{da=sa-1|0;c[P>>2]=da;Ma=da;Na=ua}if(((Ma>>15)-(Na>>15)|0)<2){ua=Ma;da=Na;sa=ma;do{if(((ua^da)&65536|0)==0){Oa=ua;Pa=da;Qa=sa}else{ma=ua^32768;c[P>>2]=ma;ja=sa^32768;c[G>>2]=ja;va=da^32768;c[O>>2]=va;Oa=ma;Pa=va;Qa=ja}ja=Oa<<8&16776960;ua=ja|255;c[P>>2]=ua;va=c[M>>2]|0;ma=va|0;ra=c[ma>>2]|0;if(((c[va+4>>2]|0)-ra|0)<1){Ra=0}else{c[ma>>2]=ra+1;Ra=d[ra]|0}sa=Ra|Qa<<8&16776960;c[G>>2]=sa;da=Pa<<8&16776960;c[O>>2]=da;}while(((ja>>>15)-(da>>>15)|0)<2)}if(!ta){Sa=(ta^1)<<31>>31;break}Sa=GQa(m,256)|0}else{Sa=ca}}while(0);c[n+(aa*20|0)>>2]=GQa(m,2)|0;na=aa+1|0;if((na|0)<(Ba|0)){aa=na;ca=Sa}else{za=93;break}}if((za|0)==93){Ca=Sa;Da=c[P>>2]|0;Ea=c[O>>2]|0;Fa=Ba;break}yDb(e,16,2107608,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}}while(0);O=Da>>16;P=Ea>>16;G=O-P|0;L=c[M>>2]|0;N=(c[L>>2]|0)-(c[L+8>>2]|0)<<3;L=(G&128|0)==0;if(L){W=G;ea=1;while(1){ca=ea+1|0;aa=W<<1;if((aa&128|0)==0){W=aa;ea=ca}else{Ta=ca;break}}}else{Ta=1}ea=N-17|0;W=(P+1|0)==(O|0)|0;M=o+(W+D+(ea+Ta>>3))|0;if(L){ca=G;aa=1;while(1){$=aa+1|0;na=ca<<1;if((na&128|0)==0){ca=na;aa=$}else{Ua=$;break}}}else{Ua=1}aa=w-W-(ea+Ua>>3)|0;if((aa|0)<1){C=-1094995529}else{Va=M;Wa=aa;Xa=Fa;Ya=Ca;Za=X;break}i=j;return C|0}else{Va=R;Wa=w;Xa=0;Ya=0;Za=0}}while(0);w=r+20704|0;c[w>>2]=0;R=r+20700|0;c[R>>2]=0;do{if(K|E^1){if((H|0)==0){_a=Wa;$a=Va;za=112;break}Ca=Wa-4|0;if((Ca|0)<1){C=-1094995529;i=j;return C|0}else{Fa=Va;Ua=(de((d[Fa]|d[Fa+1|0]<<8)<<16>>16|0)|0)&65535;Fa=Ua-(c[e+120>>2]|0)|0;c[R>>2]=Fa;Ua=Va+2|0;Ta=(de((d[Ua]|d[Ua+1|0]<<8)<<16>>16|0)|0)&65535;c[w>>2]=Ta-(c[e+124>>2]|0);ab=Va+4|0;bb=Ca;cb=Fa;za=111;break}}else{Fa=c[r+20692>>2]|0;Ca=s+4+(256-Fa<<2)|0;if((Fa|0)==0){db=0;eb=0}else{Ta=a[Va]|0;Ua=Ta&255;if((Ua|0)>(Fa|0)){C=-1094995529;i=j;return C|0}Fa=Ua*3|0;if((Fa+2|0)>(Wa|0)){C=-1094995529;i=j;return C|0}if(Ta<<24>>24==0){fb=0}else{Ta=0;D=Ca;while(1){Ca=Ta*3|0;c[D>>2]=(d[Va+(Ca+2)|0]|0)<<8|(d[Va+(Ca+1)|0]|0)<<16|(d[Va+(Ca+3)|0]|0);Ca=Ta+1|0;if((Ca|0)<(Ua|0)){Ta=Ca;D=D+4|0}else{break}}fb=c[R>>2]|0}db=Fa+1|0;eb=fb}ab=Va+db|0;bb=Wa-db|0;cb=eb;za=111}}while(0);if((za|0)==111){if((cb|0)<0){gb=bb;hb=ab;za=113}else{_a=bb;$a=ab;za=112}}do{if((za|0)==112){if((c[w>>2]|0)<0){gb=_a;hb=$a;za=113;break}ab=$$a(e,c[I>>2]|0)|0;if((ab|0)<0){C=ab;i=j;return C|0}ab=MCb(t,c[I>>2]|0)|0;if((ab|0)<0){C=ab;i=j;return C|0}else{c[r+20684>>2]=0;ib=c[e+124>>2]|0;jb=c[f+32>>2]|0;kb=_a;lb=$a;break}}}while(0);do{if((za|0)==113){$a=r+20664|0;_a=c[$a>>2]|0;ab=r+20660|0;c[$a>>2]=c[ab>>2];c[ab>>2]=_a;_a=_$a(e,t,1)|0;if((_a|0)<0){C=_a;i=j;return C|0}_a=c[I>>2]|0;ab=c[_a>>2]|0;if((ab|0)==0){yDb(e,16,1938824,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}$a=c[f+32>>2]|0;if(($a|0)==(c[_a+32>>2]|0)){_a=c[e+124>>2]|0;c[r+20684>>2]=ab+(ba(_a-1|0,$a)|0);ib=_a;jb=$a;kb=gb;lb=hb;break}else{yDb(0,0,2050048,(S=i,i=i+24|0,c[S>>2]=2004368,c[S+8>>2]=1967040,c[S+16>>2]=600,S)|0);i=S;Cd();return 0}}}while(0);hb=e+124|0;gb=r+20680|0;c[gb>>2]=(c[f>>2]|0)+(ba(ib-1|0,jb)|0);ib=r+20688|0;c[ib>>2]=-jb;c[f+84>>2]=v;c[f+88>>2]=E?1:2;do{if(K){if(!((kb|0)>-1)){yDb(0,0,2050048,(S=i,i=i+24|0,c[S>>2]=2272312,c[S+8>>2]=2256968,c[S+16>>2]=135,S)|0);i=S;Cd();return 0}f=l|0;c[f>>2]=lb;c[l+8>>2]=lb;jb=lb+kb|0;c[l+4>>2]=jb;$a=c[gb>>2]|0;_a=c[ib>>2]>>1;ab=c[e+120>>2]|0;bb=c[hb>>2]|0;do{if((v|0)==0){cb=jb;if((kb|0)<1){mb=0;nb=lb}else{eb=lb+1|0;c[f>>2]=eb;mb=(d[lb]|0)<<4;nb=eb}if((cb-nb|0)<1){ob=0;pb=nb}else{eb=nb+1|0;c[f>>2]=eb;ob=d[nb]|0;pb=eb}eb=ob>>>4|mb;if((cb-pb|0)<1){qb=0;rb=pb}else{db=pb+1|0;c[f>>2]=db;qb=d[pb]|0;rb=db}db=qb|ob<<8&3840;if((cb-rb|0)<1){sb=0;tb=rb}else{Wa=rb+1|0;c[f>>2]=Wa;sb=(d[rb]|0)<<4;tb=Wa}if((cb-tb|0)<1){ub=0;vb=tb}else{Wa=tb+1|0;c[f>>2]=Wa;ub=d[tb]|0;vb=Wa}Wa=ub>>>4|sb;if((cb-vb|0)<1){wb=0;xb=vb}else{cb=vb+1|0;c[f>>2]=cb;wb=d[vb]|0;xb=cb}cb=wb|ub<<8&3840;if((cb|0)>=(bb|0)|(db|0)>=(ab|0)|(eb|0)>(db|0)|(Wa|0)>(cb|0)){C=-1094995529;i=j;return C|0}else{yb=$a+((ba(Wa,_a)|0)+eb<<1)|0;zb=(Wa|0)!=0|0;Ab=1-Wa+cb|0;Bb=1-eb+db|0;Cb=xb;break}}else{yb=$a;zb=0;Ab=bb;Bb=ab;Cb=lb}}while(0);ab=-_a|0;bb=yb;$a=zb;Fa=0;db=0;eb=Ab;cb=Cb;while(1){Wa=bb+(Bb<<1)|0;Va=Wa;if(($a|0)==0){fb=bb;s=Fa;H=db;D=cb;while(1){Ta=s-1|0;a:do{if((s|0)<1){Ua=jb;do{if((Ua-D|0)<1){Db=0;Eb=D}else{X=D+1|0;c[f>>2]=X;M=a[D]|0;ea=M&255;if(M<<24>>24>-1){Db=ea;Eb=X;break}if(!((M&255)>>>0>129>>>0)){Fb=Ta;Gb=127-ea|0;Hb=X;za=155;break a}if((M&255)>>>0>130>>>0){M=0;W=ea;ea=X;while(1){Ca=W-1|0;if((Ua-ea|0)<1){Ib=0;Jb=ea}else{o=ea+1|0;c[f>>2]=o;Ib=d[ea]|0;Jb=o}o=(Ib|M<<8)+1|0;if((Ca|0)>130){M=o;W=Ca;ea=Jb}else{Kb=o;Lb=Jb;break}}}else{Kb=0;Lb=X}if(!((H|0)==-2)){Fb=Kb;Gb=H;Hb=Lb;za=155;break a}ea=Va-fb>>1;W=Kb>>>0>ea>>>0?ea:Kb;Mb=-2;Nb=Kb-W|0;Ob=fb+(W<<1)|0;Pb=Lb;break a}}while(0);if((Ua-Eb|0)<1){Qb=0;Rb=Eb}else{ta=Eb+1|0;c[f>>2]=ta;Qb=d[Eb]|0;Rb=ta}Fb=Ta;Gb=Qb|Db<<8;Hb=Rb;za=155}else{Fb=Ta;Gb=H;Hb=D;za=155}}while(0);do{if((za|0)==155){za=0;if(!((Gb|0)>-1)){Mb=Gb;Nb=Fb;Ob=fb;Pb=Hb;break}b[fb>>1]=Gb;Mb=Gb;Nb=Fb;Ob=fb;Pb=Hb}}while(0);Ta=Ob+2|0;if(Ta>>>0<Wa>>>0){fb=Ta;s=Nb;H=Mb;D=Pb}else{Sb=Nb;Tb=Mb;Ub=Pb;break}}}else{D=bb;H=Fa;s=db;fb=cb;while(1){Ta=H-1|0;b:do{if((H|0)<1){ta=jb;do{if((ta-fb|0)<1){Vb=0;Wb=fb}else{W=fb+1|0;c[f>>2]=W;ea=a[fb]|0;M=ea&255;if(ea<<24>>24>-1){Vb=M;Wb=W;break}if(!((ea&255)>>>0>129>>>0)){Xb=Ta;Yb=127-M|0;Zb=W;za=173;break b}if((ea&255)>>>0>130>>>0){ea=0;o=M;M=W;while(1){Ca=o-1|0;if((ta-M|0)<1){_b=0;$b=M}else{Ea=M+1|0;c[f>>2]=Ea;_b=d[M]|0;$b=Ea}Ea=(_b|ea<<8)+1|0;if((Ca|0)>130){ea=Ea;o=Ca;M=$b}else{ac=Ea;bc=$b;break}}}else{ac=0;bc=W}if(!((s|0)==-2)){Xb=ac;Yb=s;Zb=bc;za=173;break b}M=Va-D>>1;o=ac>>>0>M>>>0?M:ac;cc=-2;dc=ac-o|0;ec=D+(o<<1)|0;fc=bc;break b}}while(0);if((ta-Wb|0)<1){gc=0;hc=Wb}else{Ua=Wb+1|0;c[f>>2]=Ua;gc=d[Wb]|0;hc=Ua}Xb=Ta;Yb=gc|Vb<<8;Zb=hc;za=173}else{Xb=Ta;Yb=s;Zb=fb;za=173}}while(0);do{if((za|0)==173){za=0;if((Yb|0)>-1){b[D>>1]=Yb;cc=Yb;dc=Xb;ec=D;fc=Zb;break}if(!((Yb|0)==-1)){cc=Yb;dc=Xb;ec=D;fc=Zb;break}b[D>>1]=b[D+(ab<<1)>>1]|0;cc=-1;dc=Xb;ec=D;fc=Zb}}while(0);Ta=ec+2|0;if(Ta>>>0<Wa>>>0){D=Ta;H=dc;s=cc;fb=fc}else{Sb=dc;Tb=cc;Ub=fc;break}}}fb=eb-1|0;if((fb|0)==0){break}else{bb=bb+(_a<<1)|0;$a=1;Fa=Sb;db=Tb;eb=fb;cb=Ub}}ic=lb;jc=kb-Ub+lb|0}else{do{if(E){c[r+20708>>2]=0;sQa(r+20736|0);if((c[J>>2]|0)==0){break}sQa(r+188488|0)}}while(0);if(F){cb=kb>>>0>268435455>>>0?-8:kb<<3;eb=cb>>>0>2147483639>>>0|(lb|0)==0;db=eb?0:lb;Fa=eb?0:cb;c[u>>2]=db;c[y>>2]=Fa;c[A>>2]=Fa+8;c[B>>2]=db+(Fa>>3);c[x>>2]=0;if(eb){C=eb?-1094995529:0;i=j;return C|0}eb=r+20660|0;Fa=r+20668|0;db=r+19636|0;cb=r+19624|0;$a=e+120|0;_a=HQa(k,c[eb>>2]|0,c[Fa>>2]|0,c[gb>>2]|0,c[ib>>2]|0,db,v,c[cb>>2]|0,0,c[$a>>2]|0,c[hb>>2]|0)|0;if((_a|0)!=0){C=_a;i=j;return C|0}_a=c[x>>2]|0;bb=-_a&7;if((bb|0)==0){kc=_a}else{ab=c[A>>2]|0;f=bb+_a|0;_a=ab>>>0>f>>>0?f:ab;c[x>>2]=_a;kc=_a}do{if((c[J>>2]|0)==0){lc=kc}else{_a=HQa(k,c[eb>>2]|0,c[Fa>>2]|0,c[gb>>2]|0,c[ib>>2]|0,db,v,c[cb>>2]|0,1,c[$a>>2]|0,c[hb>>2]|0)|0;if((_a|0)==0){lc=c[x>>2]|0;break}else{C=_a;i=j;return C|0}}}while(0);$a=-lc&7;if(($a|0)==0){mc=lc}else{cb=c[A>>2]|0;db=$a+lc|0;$a=cb>>>0>db>>>0?db:cb;c[x>>2]=$a;mc=$a}$a=mc>>3;ic=lb+$a|0;jc=kb-$a|0;break}if((Za|0)!=0&(Ya|0)==-1){TGb(c[r+20660>>2]|0,0,ba(c[hb>>2]|0,c[r+20668>>2]|0)|0)|0;ic=lb;jc=kb;break}$a=r+20708|0;if((c[$a>>2]|0)!=0){C=-1094995529;i=j;return C|0}cb=kb+2|0;if(!((cb|0)>-1)){yDb(0,0,2050048,(S=i,i=i+24|0,c[S>>2]=2272312,c[S+8>>2]=2256968,c[S+16>>2]=135,S)|0);i=S;Cd();return 0}db=l|0;c[db>>2]=lb;Fa=l+8|0;c[Fa>>2]=lb;eb=l+4|0;c[eb>>2]=lb+cb;cb=m|0;c[cb>>2]=0;_a=m+4|0;c[_a>>2]=16777215;if((kb+2|0)<3){nc=0}else{c[db>>2]=lb+3;nc=(d[lb+1|0]|0)<<8|(d[lb]|0)<<16|(d[lb+2|0]|0)}ab=m+8|0;c[ab>>2]=nc;f=m+12|0;bb=l;c[f>>2]=bb;jb=m+16|0;c[jb>>2]=842;fb=m+20|0;c[fb>>2]=672;c[r+20696>>2]=v;s=e+120|0;H=r+19624|0;D=vQa(r+20736|0,m,0,0,c[s>>2]|0,c[H>>2]|0)|0;c[$a>>2]=D;if((D|0)!=0){C=-1094995529;i=j;return C|0}D=c[_a>>2]>>16;Wa=c[cb>>2]>>16;Va=D-Wa|0;Ta=m+12|0;Ua=c[Ta>>2]|0;o=(c[Ua>>2]|0)-(c[Ua+8>>2]|0)<<3;Ua=(Va&128|0)==0;if(Ua){M=Va;ea=1;while(1){X=ea+1|0;Ea=M<<1;if((Ea&128|0)==0){M=Ea;ea=X}else{oc=X;break}}}else{oc=1}ea=o-17|0;M=(Wa+1|0)==(D|0)|0;X=(ea+oc>>3)+M|0;Ea=lb+X|0;if(Ua){Ca=Va;Da=1;while(1){Ba=Da+1|0;Sa=Ca<<1;if((Sa&128|0)==0){Ca=Sa;Da=Ba}else{pc=Ba;break}}}else{pc=1}Da=kb-M-(ea+pc>>3)|0;if((c[J>>2]|0)==0){ic=Ea;jc=Da;break}if((Da|0)<1){C=-1094995529;i=j;return C|0}Ca=Da+2|0;if(!((Ca|0)>-1)){yDb(0,0,2050048,(S=i,i=i+24|0,c[S>>2]=2272312,c[S+8>>2]=2256968,c[S+16>>2]=135,S)|0);i=S;Cd();return 0}c[db>>2]=Ea;c[Fa>>2]=Ea;Va=lb+(Ca+X)|0;c[eb>>2]=Va;c[cb>>2]=0;c[_a>>2]=16777215;if((Va-Ea|0)<3){qc=0}else{c[db>>2]=lb+(X+3);qc=(d[lb+(X+1)|0]|0)<<8|(d[Ea]|0)<<16|(d[lb+(X+2)|0]|0)}c[ab>>2]=qc;c[f>>2]=bb;c[jb>>2]=842;c[fb>>2]=672;Va=c[H>>2]|0;Ca=vQa(r+188488|0,m,0,Va,c[s>>2]|0,(c[hb>>2]|0)-Va|0)|0;c[$a>>2]=Ca;if((Ca|0)!=0){C=-1094995529;i=j;return C|0}Ca=c[_a>>2]>>16;Va=c[cb>>2]>>16;Ua=Ca-Va|0;D=c[Ta>>2]|0;Wa=(c[D>>2]|0)-(c[D+8>>2]|0)<<3;D=(Ua&128|0)==0;if(D){o=Ua;Ba=1;while(1){Sa=Ba+1|0;Pa=o<<1;if((Pa&128|0)==0){o=Pa;Ba=Sa}else{rc=Sa;break}}}else{rc=1}Ba=Wa-17|0;o=(Va+1|0)==(Ca|0)|0;Ta=lb+(o+X+(Ba+rc>>3))|0;if(D){cb=Ua;_a=1;while(1){$a=_a+1|0;s=cb<<1;if((s&128|0)==0){cb=s;_a=$a}else{sc=$a;break}}}else{sc=1}ic=Ta;jc=Da-o-(Ba+sc>>3)|0}}while(0);c:do{if(Q&(Xa|0)>0){sc=(Ya|0)==-1;rc=r+20728|0;lb=r+20660|0;hb=r+20668|0;m=e+848|0;qc=0;J=jc;pc=ic;d:while(1){kb=c[n+(qc*20|0)+4>>2]|0;oc=c[n+(qc*20|0)+8>>2]|0;v=c[n+(qc*20|0)+12>>2]|0;l=c[n+(qc*20|0)+16>>2]|0;do{if((c[n+(qc*20|0)>>2]|0)==0){nc=c[ib>>2]|0;Za=(c[gb>>2]|0)+((ba(nc,oc)|0)+(kb*3|0))|0;if(!sc){mc=c[hb>>2]|0;x=(c[lb>>2]|0)+((ba(mc,oc)|0)+kb)|0;Ke[c[rc>>2]&1023](Za,nc,Ya,x,mc,v,l);tc=pc;uc=J;break}mc=v*3|0;x=Za;Za=l;while(1){TGb(x|0,-128|0,mc|0)|0;nc=Za-1|0;if((nc|0)==0){tc=pc;uc=J;break}else{x=x+(c[ib>>2]|0)|0;Za=nc}}}else{if((J|0)<4){C=-1094995529;za=254;break d}Za=(d[pc+1|0]|0)<<8|(d[pc+2|0]|0)<<16|(d[pc]|0);if((Za|0)==0){C=-1094995529;za=254;break d}x=pc+3|0;mc=J-3|0;vc=c[q>>2]|0;nc=vc;lc=vc;bPa(e);A=vc+14120|0;k=mc<<3;kc=mc>>>0>268435455>>>0?-8:k;mc=kc>>>0>2147483639>>>0|(x|0)==0;B=mc?0:x;x=mc?0:kc;c[A>>2]=B;c[vc+14132>>2]=x;c[vc+14136>>2]=x+8;c[vc+14124>>2]=B+(x>>3);c[vc+14128>>2]=0;if(mc){C=-1094995529;za=254;break d}c[vc+13836>>2]=(c[m>>2]|0)<48;if((Z1a(nc,A)|0)<0){za=225;break d}if((c[vc+9992>>2]|0)!=1){za=227;break d}c[z>>2]=0;wc=ROa(lc,e)|0;if((wc|0)<0){za=229;break d}ePa(lc);c[vc+15576>>2]=k;k=v+15>>4;A=vc+19608|0;c[A>>2]=k;mc=l+15>>4;x=vc+812|0;c[x>>2]=mc;B=vc+16073|0;kc=a[B]|0;if(!((kc&1)==0)){c[A>>2]=k+1>>1}if(!((kc&2)==0)){c[x>>2]=mc+1>>1}e2a(nc);Mkb(vc+14424|0);SOa(lc);lc=vc+7624|0;nc=a[B]|0;if((nc<<24>>24|0)==3){B=vc+20732|0;cf[c[B>>2]&1023](c[lc>>2]|0,c[vc+7656>>2]|0,v,l);mc=v+1>>1;x=l+1>>1;cf[c[B>>2]&1023](c[vc+7628>>2]|0,c[vc+7660>>2]|0,mc,x);cf[c[B>>2]&1023](c[vc+7632>>2]|0,c[vc+7664>>2]|0,mc,x)}else if((nc<<24>>24|0)!=0){DDb(c[vc+4>>2]|0,2306760,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}nc=vc+7656|0;x=c[vc+7660>>2]|0;if((x|0)!=(c[vc+7664>>2]|0)){za=238;break d}if(sc){mc=c[vc+20688>>2]|0;B=(c[vc+20680>>2]|0)+((ba(mc,oc)|0)+(kb*3|0))|0;Le[c[vc+20720>>2]&255](B,mc,c[lc>>2]|0,c[nc>>2]|0,c[vc+7628>>2]|0,c[vc+7632>>2]|0,x,v,l)}else{mc=c[vc+20688>>2]|0;B=(c[vc+20680>>2]|0)+((ba(mc,oc)|0)+(kb*3|0))|0;kc=c[vc+20668>>2]|0;k=(c[vc+20660>>2]|0)+((ba(kc,oc)|0)+kb)|0;Ue[c[vc+20724>>2]&127](B,mc,Ya,k,kc,c[lc>>2]|0,c[nc>>2]|0,c[vc+7628>>2]|0,c[vc+7632>>2]|0,x,v,l)}c[z>>2]=2;x=Za+3|0;tc=pc+x|0;uc=J-x|0}}while(0);l=qc+1|0;if((l|0)<(Xa|0)){qc=l;J=uc;pc=tc}else{xc=uc;break c}}if((za|0)==225){yDb(c[vc+4>>2]|0,16,1894080,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}else if((za|0)==227){yDb(c[vc+4>>2]|0,16,2351288,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}else if((za|0)==229){yDb(c[vc+4>>2]|0,16,2331208,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;c[z>>2]=2;C=wc;i=j;return C|0}else if((za|0)==238){yDb(0,0,2050048,(S=i,i=i+24|0,c[S>>2]=2288560,c[S+8>>2]=1967040,c[S+16>>2]=430,S)|0);i=S;Cd();return 0}else if((za|0)==254){i=j;return C|0}}else{xc=jc}}while(0);if((xc|0)!=0){yDb(e,24,1914496,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}if((c[R>>2]|0)<0){za=252}else{if((c[w>>2]|0)<0){za=252}}do{if((za|0)==252){KCb(c[I>>2]|0);w=MCb(c[I>>2]|0,t)|0;if((w|0)<0){C=w}else{break}i=j;return C|0}}while(0);c[g>>2]=1;C=c[p>>2]|0;i=j;return C|0}function FQa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+19628|0);zQa(b+19632|0)|0;$Db(b+20660|0);$Db(b+20664|0);l2a(a)|0;return 0}function GQa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=a+4|0;f=a|0;g=c[f>>2]|0;h=(c[e>>2]|0)-g+1|0;i=h>>>0>65535>>>0;j=i?h>>>16:h;k=i?16:0;if((j&65280|0)==0){l=k;m=j}else{l=k|8;m=j>>>8}j=b>>>0>65535>>>0;k=j?b>>>16:b;i=j?16:0;if((k&65280|0)==0){n=i;o=k}else{n=i|8;o=k>>>8}k=(d[1191992+m|0]|0)+l-n-(d[1191992+o|0]|0)|0;o=(((b<<k|0)>(h|0))<<31>>31)+k|0;k=a+8|0;n=c[k>>2]|0;l=n-g|0;m=(b<<o<<1)-h|0;if((m|0)<(l|0)){p=(l-m>>1)+m|0}else{p=l}l=p>>o;p=l<<o;h=l+1<<o;if((m|0)<(h|0)){q=(h-m<<1)+m|0}else{q=h}h=q-1+g|0;c[e>>2]=h;if((m|0)<(p|0)){r=(p-m<<1)+m+g|0}else{r=g+p|0}c[f>>2]=r;if(((h>>15)-(r>>15)|0)>=2){return l|0}p=a+12|0;a=h;h=r;r=n;do{if(((a^h)&65536|0)==0){s=a;t=h;u=r}else{n=a^32768;c[e>>2]=n;g=r^32768;c[k>>2]=g;m=h^32768;c[f>>2]=m;s=n;t=m;u=g}g=s<<8&16776960;a=g|255;c[e>>2]=a;m=c[p>>2]|0;n=m|0;q=c[n>>2]|0;if(((c[m+4>>2]|0)-q|0)<1){v=0}else{c[n>>2]=q+1;v=d[q]|0}r=v|u<<8&16776960;c[k>>2]=r;h=t<<8&16776960;c[f>>2]=h;}while(((g>>>15)-(h>>>15)|0)<2);return l|0}function HQa(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;q=i;i=i+1376|0;r=q|0;s=q+272|0;t=q+1352|0;u=r|0;TGb(u|0,0,270)|0;v=270-l|0;do{if((l|0)==0){w=e+8|0;x=c[w>>2]|0;y=c[e+16>>2]|0;z=c[e>>2]|0;A=z+(x>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(x&7)>>>20;A=x+12|0;x=y>>>0>A>>>0?A:y;c[w>>2]=x;A=z+(x>>>3)|0;C=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(x&7)>>>20;A=x+12|0;x=y>>>0>A>>>0?A:y;c[w>>2]=x;A=z+(x>>>3)|0;D=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(x&7)>>>20;A=x+12|0;x=y>>>0>A>>>0?A:y;c[w>>2]=x;A=D+1|0;D=z+(x>>>3)|0;z=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(x&7)>>>20;D=x+12|0;c[w>>2]=y>>>0>D>>>0?D:y;y=z+1|0;if((A+B|0)>(o|0)){E=-1094995529;i=q;return E|0}if((y+C|0)>(p|0)){E=-1094995529;i=q;return E|0}else{F=f+((ba(C,g)|0)+B)|0;G=h+((ba(C,j)|0)+(B*3|0))|0;H=A;I=y;J=(C|0)!=0|0;break}}else{if((n|0)<=0){F=f;G=h;H=o;I=m;J=0;break}F=f+(ba(m,g)|0)|0;G=h+(ba(m,j)|0)|0;H=o;I=p-m|0;J=1}}while(0);m=e+8|0;p=e+16|0;o=e|0;e=204-l|0;h=14-l|0;l=0;f=0;n=0;C=0;a:while(1){y=l;A=f;B=n;while(1){K=A-1|0;if((A|0)!=0){break}L=y+1|0;M=B<<1;z=(1<<L)-M|0;D=z<<1;w=D>>>0>65535>>>0;x=w?z>>>15&65535:D;D=w?16:0;if((x&65280|0)==0){N=D;O=x}else{N=D|8;O=x>>>8}x=(d[1191992+O|0]|0)+N|0;D=c[m>>2]|0;w=c[p>>2]|0;P=(c[o>>2]|0)+(D>>>3)|0;Q=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(D&7)>>>((32-x|0)>>>0);P=x+D|0;c[m>>2]=w>>>0>P>>>0?P:w;if((L|0)>22|(Q|0)>(z|0)){E=-1094995529;R=51;break a}if((Q|0)==(z|0)){R=20;break a}else{y=L;A=Q;B=M}}A=c[m>>2]|0;Q=c[p>>2]|0;z=c[o>>2]|0;w=z+(A>>>3)|0;P=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(A&7);w=P>>>24;D=A+8|0;A=Q>>>0>D>>>0?D:Q;c[m>>2]=A;do{if((w|0)<(e|0)){if(!(P>>>0>3187671039>>>0)){S=w;break}D=d[z+(A>>>3)|0]<<(A&7)>>>7;c[m>>2]=((A|0)<(Q|0))+A;S=(D&1|w<<1)-190|0}else{S=h+w|0}}while(0);w=r+S|0;if((a[w]|0)!=0){E=-1094995529;R=51;break}a[w]=y;c[s+(S<<2)>>2]=B;l=y;f=K;n=B+1|0;C=C+1|0}if((R|0)==20){n=C-v|0;C=L;L=M;while(1){M=L<<1;T=(2<<C)-M+n|0;if((T|0)<0){C=C+1|0;L=M}else{break}}if((v|0)>0){n=L;M=T;T=0;K=C;while(1){f=r+T|0;if((a[f]|0)==0){if((M|0)==0){U=K+1|0;V=n<<1}else{U=K;V=n}a[f]=U;c[s+(T<<2)>>2]=V;W=U;X=M-1|0;Y=V+1|0}else{W=K;X=M;Y=n}f=T+1|0;if((f|0)<(v|0)){n=Y;M=X;T=f;K=W}else{Z=Y;_=W;break}}}else{Z=L;_=C}if((Z|0)!=(1<<_|0)){E=-1094995529;i=q;return E|0}_=N_(t,9,v,u,1,1,s,4,4,0,0,0,0)|0;if((_|0)!=0){E=_;i=q;return E|0}_=t+4|0;s=-g|0;u=-j|0;v=F;F=G;G=I;I=J;J=0;Z=0;while(1){C=v+H|0;L=C;W=(I|0)==0;Y=F;K=v;T=J;X=Z;while(1){M=T-1|0;do{if((T|0)<1){n=c[_>>2]|0;V=c[m>>2]|0;U=c[p>>2]|0;r=c[o>>2]|0;f=r+(V>>>3)|0;l=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(V&7)>>>23;f=b[n+(l<<2)>>1]|0;S=b[n+(l<<2)+2>>1]|0;l=S<<16>>16;do{if(S<<16>>16<0){h=V+9|0;e=U>>>0>h>>>0?h:U;h=r+(e>>>3)|0;N=((fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(e&7)>>>((l+32|0)>>>0))+f|0;h=b[n+(N<<2)>>1]|0;O=b[n+(N<<2)+2>>1]|0;N=O<<16>>16;if(!(O<<16>>16<0)){$=N;aa=h;ca=e;break}O=e-l|0;e=U>>>0>O>>>0?O:U;O=r+(e>>>3)|0;w=((fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(e&7)>>>((N+32|0)>>>0))+h|0;$=b[n+(w<<2)+2>>1]|0;aa=b[n+(w<<2)>>1]|0;ca=e}else{$=l;aa=f;ca=V}}while(0);V=$+ca|0;f=U>>>0>V>>>0?V:U;c[m>>2]=f;if((aa|0)<256){da=M;ea=aa;R=44;break}if((aa|0)>=268){da=M;ea=267-aa|0;R=44;break}V=aa-256|0;if((aa|0)==267){l=r+(f>>>3)|0;n=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(f&7)>>>28;l=f+4|0;S=U>>>0>l>>>0?l:U;c[m>>2]=S;fa=n+10|0;ga=S;R=40}else if((aa|0)==256){ha=0;ia=0}else{fa=V;ga=f;R=40}if((R|0)==40){R=0;f=r+(ga>>>3)|0;V=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(ga&7)>>>((32-fa|0)>>>0);f=ga+fa|0;c[m>>2]=U>>>0>f>>>0?f:U;ha=V;ia=fa}V=(1<<ia)-1+ha|0;if(!((X|0)==-2)){da=V;ea=X;R=44;break}f=L-K|0;S=(V|0)>(f|0)?f:V;ja=-2;ka=V-S|0;la=K+S|0;ma=Y+(S*3|0)|0}else{da=M;ea=X;R=44}}while(0);do{if((R|0)==44){R=0;if((ea|0)>-1){a[K]=ea;M=k+(ea<<2)|0;a[Y+2|0]=c[M>>2];a[Y+1|0]=(c[M>>2]|0)>>>8;a[Y]=(c[M>>2]|0)>>>16;ja=ea;ka=da;la=K;ma=Y;break}if((ea|0)!=-1|W){ja=ea;ka=da;la=K;ma=Y;break}a[K]=a[K+s|0]|0;M=Y+u|0;a[Y]=a[M]|0;a[Y+1|0]=a[M+1|0]|0;a[Y+2|0]=a[M+2|0]|0;ja=-1;ka=da;la=K;ma=Y}}while(0);M=la+1|0;if(M>>>0<C>>>0){Y=ma+3|0;K=M;T=ka;X=ja}else{break}}X=G-1|0;if((X|0)==0){break}else{v=v+g|0;F=F+j|0;G=X;I=1;J=ka;Z=ja}}Q_(t);E=0;i=q;return E|0}else if((R|0)==51){i=q;return E|0}return 0}function IQa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=a+4|0;g=a|0;h=c[g>>2]|0;i=(c[f>>2]|0)-h+1|0;j=b[e>>1]|0;k=j<<16>>16;l=i>>>0>65535>>>0;m=l?i>>>16:i;n=l?16:0;if((m&65280|0)==0){o=n;p=m}else{o=n|8;p=m>>>8}m=j<<16>>16<0;j=m?k>>>16:k;n=m?16:0;if((j&65280|0)==0){q=n;r=j}else{q=n|8;r=j>>>8}j=(d[1191992+p|0]|0)+o-q-(d[1191992+r|0]|0)|0;r=(((k<<j|0)>(i|0))<<31>>31)+j|0;j=a+8|0;q=(c[j>>2]|0)-h|0;o=(k<<r<<1)-i|0;if((o|0)<(q|0)){s=(q-o>>1)+o|0}else{s=q}q=s>>r;s=0;while(1){t=s+1|0;u=b[e+(t<<1)>>1]|0;if((u|0)>(q|0)){s=t}else{break}}q=u<<r;u=b[e+(s<<1)>>1]<<r;if((o|0)<(u|0)){v=(u-o<<1)+o|0}else{v=u}c[f>>2]=h-1+v;if((o|0)<(q|0)){w=o+h+(q-o<<1)|0}else{w=q+h|0}c[g>>2]=w;w=d[e+1028+t|0]|0;rQa(e,t);t=c[f>>2]|0;e=c[g>>2]|0;if(((t>>15)-(e>>15)|0)>=2){return w|0}h=a+12|0;a=t;t=e;do{if(((a^t)&65536|0)==0){x=a;y=t;z=c[j>>2]|0}else{e=a^32768;c[f>>2]=e;q=c[j>>2]^32768;c[j>>2]=q;o=t^32768;c[g>>2]=o;x=e;y=o;z=q}q=x<<8&16776960;a=q|255;c[f>>2]=a;o=c[h>>2]|0;e=o|0;v=c[e>>2]|0;if(((c[o+4>>2]|0)-v|0)<1){A=0}else{c[e>>2]=v+1;A=d[v]|0}c[j>>2]=A|z<<8&16776960;t=y<<8&16776960;c[g>>2]=t;}while(((q>>>15)-(t>>>15)|0)<2);return w|0}function JQa(a){a=a|0;c[a>>2]=24;c[a+4>>2]=62;c[a+8>>2]=238;c[a+12>>2]=790;return}function KQa(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((k|0)<=0){return}l=(j|0)>0;m=h;h=g;g=0;n=e;e=b;while(1){if(l){b=0;o=0;p=0;while(1){q=d[n+b|0]|0;r=(d[h+o|0]|0)-128|0;s=(d[m+o|0]|0)-128|0;t=((s*91881|0)+32768>>16)+q|0;if(t>>>0>255>>>0){u=-t>>31&255}else{u=t&255}a[e+p|0]=u;t=((r*-22554|0)+32768+(s*-46802|0)>>16)+q|0;if(t>>>0>255>>>0){v=-t>>31&255}else{v=t&255}a[e+(p+1)|0]=v;t=((r*116130|0)+32768>>16)+q|0;if(t>>>0>255>>>0){w=-t>>31&255}else{w=t&255}a[e+(p+2)|0]=w;t=(b&1)+o|0;q=b+1|0;if((q|0)<(j|0)){b=q;o=t;p=p+3|0}else{break}}}p=-(g&1)&i;o=g+1|0;if((o|0)<(k|0)){m=m+p|0;h=h+p|0;g=o;n=n+f|0;e=e+c|0}else{break}}return}function LQa(b,c,e,f,g,h,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((n|0)<=0){return}o=(m|0)>0;p=k;k=j;j=0;q=h;h=f;f=b;while(1){if(o){b=0;r=0;s=0;while(1){if((d[h+b|0]|0|0)==(e|0)){t=d[q+b|0]|0;u=(d[k+r|0]|0)-128|0;v=(d[p+r|0]|0)-128|0;w=((v*91881|0)+32768>>16)+t|0;if(w>>>0>255>>>0){x=-w>>31&255}else{x=w&255}a[f+s|0]=x;w=((u*-22554|0)+32768+(v*-46802|0)>>16)+t|0;if(w>>>0>255>>>0){y=-w>>31&255}else{y=w&255}a[f+(s+1)|0]=y;w=((u*116130|0)+32768>>16)+t|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[f+(s+2)|0]=z}w=(b&1)+r|0;t=b+1|0;if((t|0)<(m|0)){b=t;r=w;s=s+3|0}else{break}}}s=-(j&1)&l;r=j+1|0;if((r|0)<(n|0)){p=p+s|0;k=k+s|0;j=r;q=q+i|0;h=h+g|0;f=f+c|0}else{break}}return}function MQa(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((i|0)>0&(h|0)>0){j=0;k=f;l=b}else{return}while(1){b=0;f=0;while(1){if((d[k+b|0]|0|0)==(e|0)){a[l+(f+2)|0]=-128;a[l+(f+1)|0]=-128;a[l+f|0]=-128}m=b+1|0;if((m|0)<(h|0)){b=m;f=f+3|0}else{break}}f=j+1|0;if((f|0)<(i|0)){j=f;k=k+g|0;l=l+c|0}else{break}}return}function NQa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((e|0)==0|(f|0)==0){return}g=(e&1)+e|0;e=f-1+(f&1)|0;UGb(b+(ba(e,c)|0)|0,b+(ba(e>>1,c)|0)|0,g)|0;f=e-2|0;if((f|0)>0){h=g-1>>1;i=(h|0)>-1;j=e;k=f;while(1){f=j-1|0;l=ba(f,c)|0;m=ba(k,c)|0;n=ba(f>>1,c)|0;f=ba(k>>1,c)|0;if(i){o=h;while(1){p=d[b+(o+n)|0]|0;q=d[b+(o+f)|0]|0;a[b+(o+l)|0]=(q+2+(p*3|0)|0)>>>2;a[b+(o+m)|0]=(p+2+(q*3|0)|0)>>>2;if((o|0)>0){o=o-1|0}else{break}}}o=k-2|0;if((o|0)>0){j=k;k=o}else{break}}}if(!((e|0)>-1)){return}k=g-1|0;j=k>>1;h=g-3|0;g=(h|0)>0;i=e;while(1){e=ba(i,c)|0;a[b+(e+k)|0]=a[b+(e+j)|0]|0;if(g){o=k;m=h;while(1){l=o-1|0;f=d[b+((m>>1)+e)|0]|0;n=d[b+((l>>1)+e)|0]|0;a[b+(m+e)|0]=(n+1+(f*3|0)|0)>>>2;a[b+(l+e)|0]=(f+1+(n*3|0)|0)>>>2;n=m-2|0;if((n|0)>0){o=m;m=n}else{break}}}if((i|0)>0){i=i-1|0}else{break}}return}function OQa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;d=a+60|0;e=c[d>>2]|0;f=e;c[e>>2]=a;g=a+120|0;do{if((c[g>>2]&15|0)==0){h=a+124|0;if((c[h>>2]&15|0)!=0){break}c[e+8>>2]=0;j=e+72704|0;k=0;while(1){if((k|0)>=3){break}l=(k|0)!=0|2;m=c[g>>2]>>l;n=c[h>>2]>>l;c[j+(k*2656|0)+4>>2]=m;c[j+(k*2656|0)+8>>2]=n;l=WDb(ba(m<<2,n)|0)|0;c[j+(k*2656|0)>>2]=l;if((l|0)==0){o=7;break}else{k=k+1|0}}if((o|0)==7){yDb(a,16,2306736,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;JCb(e+4|0);if((k|0)>-1){q=k}else{r=-12;i=b;return r|0}while(1){$Db(j+(q*2656|0)|0);if((q|0)>0){q=q-1|0}else{r=-12;break}}i=b;return r|0}j=ICb()|0;c[e+4>>2]=j;if((j|0)==0){j=c[d>>2]|0;JCb(j+4|0);$Db(j+72704|0);$Db(j+75360|0);$Db(j+78016|0);r=-12;i=b;return r|0}c[a+140>>2]=0;j=0;while(1){k=0;do{h=f+32+(j*744|0)+4+(k*148|0)+128|0;c[h>>2]=5;c[f+32+(j*744|0)+4+(k*148|0)+140>>2]=88;c[f+32+(j*744|0)+4+(k*148|0)+132>>2]=0;l=0;do{c[f+32+(j*744|0)+4+(k*148|0)+(l<<2)>>2]=1;l=l+1|0;s=(c[h>>2]|0)-1|0;}while((l|0)<(s|0));c[f+32+(j*744|0)+4+(k*148|0)+(s<<2)>>2]=0;l=c[h>>2]|0;n=f+32+(j*744|0)+4+(k*148|0)+136|0;c[n>>2]=l;m=f+32+(j*744|0)+4+(k*148|0)+144|0;c[m>>2]=1;TQa(f+32+(j*744|0)+4+(k*148|0)|0,l-1|0);l=(c[h>>2]|0)+6>>1;c[n>>2]=l;c[m>>2]=l;k=k+1|0;}while((k|0)<5);k=f+2264+(j*152|0)+132|0;c[k>>2]=12;c[f+2264+(j*152|0)+144>>2]=144;c[f+2264+(j*152|0)+136>>2]=0;l=0;do{c[f+2264+(j*152|0)+4+(l<<2)>>2]=1;l=l+1|0;t=(c[k>>2]|0)-1|0;}while((l|0)<(t|0));c[f+2264+(j*152|0)+4+(t<<2)>>2]=0;l=c[k>>2]|0;m=f+2264+(j*152|0)+140|0;c[m>>2]=l;n=f+2264+(j*152|0)+148|0;c[n>>2]=1;TQa(f+2264+(j*152|0)+4|0,l-1|0);l=(c[k>>2]|0)+6>>1;c[m>>2]=l;c[n>>2]=l;c[f+2720+(j*23328|0)+2332>>2]=2096;c[f+2720+(j*23328|0)+2324>>2]=66;l=0;do{c[f+2720+(j*23328|0)+(l<<2)>>2]=1;l=l+1|0;}while((l|0)<255);c[f+2720+(j*23328|0)+1020>>2]=0;c[f+2720+(j*23328|0)+2048>>2]=0;l=f+2720+(j*23328|0)+2328|0;c[l>>2]=256;k=f+2720+(j*23328|0)+2336|0;c[k>>2]=1;UQa(f+2720+(j*23328|0)|0,255);c[l>>2]=131;c[k>>2]=131;c[f+2720+(j*23328|0)+4672>>2]=2096;c[f+2720+(j*23328|0)+4664>>2]=66;k=0;do{c[f+2720+(j*23328|0)+2340+(k<<2)>>2]=1;k=k+1|0;}while((k|0)<255);c[f+2720+(j*23328|0)+3360>>2]=0;c[f+2720+(j*23328|0)+4388>>2]=0;k=f+2720+(j*23328|0)+4668|0;c[k>>2]=256;l=f+2720+(j*23328|0)+4676|0;c[l>>2]=1;UQa(f+2720+(j*23328|0)+2340|0,255);c[k>>2]=131;c[l>>2]=131;l=f+2720+(j*23328|0)+4808|0;c[l>>2]=3;c[f+2720+(j*23328|0)+4820>>2]=72;c[f+2720+(j*23328|0)+4812>>2]=0;k=0;do{c[f+2720+(j*23328|0)+4680+(k<<2)>>2]=1;k=k+1|0;u=(c[l>>2]|0)-1|0;}while((k|0)<(u|0));c[f+2720+(j*23328|0)+4680+(u<<2)>>2]=0;k=c[l>>2]|0;n=f+2720+(j*23328|0)+4816|0;c[n>>2]=k;m=f+2720+(j*23328|0)+4824|0;c[m>>2]=1;TQa(f+2720+(j*23328|0)+4680|0,k-1|0);k=(c[l>>2]|0)+6>>1;c[n>>2]=k;c[m>>2]=k;k=0;do{m=f+2720+(j*23328|0)+4828+(k*148|0)+128|0;c[m>>2]=5;c[f+2720+(j*23328|0)+4828+(k*148|0)+140>>2]=88;c[f+2720+(j*23328|0)+4828+(k*148|0)+132>>2]=0;n=0;do{c[f+2720+(j*23328|0)+4828+(k*148|0)+(n<<2)>>2]=1;n=n+1|0;v=(c[m>>2]|0)-1|0;}while((n|0)<(v|0));c[f+2720+(j*23328|0)+4828+(k*148|0)+(v<<2)>>2]=0;n=c[m>>2]|0;h=f+2720+(j*23328|0)+4828+(k*148|0)+136|0;c[h>>2]=n;w=f+2720+(j*23328|0)+4828+(k*148|0)+144|0;c[w>>2]=1;TQa(f+2720+(j*23328|0)+4828+(k*148|0)|0,n-1|0);n=(c[m>>2]|0)+6>>1;c[h>>2]=n;c[w>>2]=n;k=k+1|0;}while((k|0)<125);k=f+72704+(j*2656|0)+272|0;c[k>>2]=12;c[f+72704+(j*2656|0)+284>>2]=144;c[f+72704+(j*2656|0)+276>>2]=0;l=0;do{c[f+72704+(j*2656|0)+144+(l<<2)>>2]=1;l=l+1|0;x=(c[k>>2]|0)-1|0;}while((l|0)<(x|0));c[f+72704+(j*2656|0)+144+(x<<2)>>2]=0;l=c[k>>2]|0;n=f+72704+(j*2656|0)+280|0;c[n>>2]=l;w=f+72704+(j*2656|0)+288|0;c[w>>2]=1;TQa(f+72704+(j*2656|0)+144|0,l-1|0);l=(c[k>>2]|0)+6>>1;c[n>>2]=l;c[w>>2]=l;c[f+72704+(j*2656|0)+2648>>2]=2096;c[f+72704+(j*2656|0)+2640>>2]=66;l=0;do{c[f+72704+(j*2656|0)+316+(l<<2)>>2]=1;l=l+1|0;}while((l|0)<255);c[f+72704+(j*2656|0)+1336>>2]=0;c[f+72704+(j*2656|0)+2364>>2]=0;l=f+72704+(j*2656|0)+2644|0;c[l>>2]=256;k=f+72704+(j*2656|0)+2652|0;c[k>>2]=1;UQa(f+72704+(j*2656|0)+316|0,255);c[l>>2]=131;c[k>>2]=131;k=f+80672+(j*2496|0)+2476|0;c[k>>2]=12;c[f+80672+(j*2496|0)+2488>>2]=144;c[f+80672+(j*2496|0)+2480>>2]=0;l=0;do{c[f+80672+(j*2496|0)+2348+(l<<2)>>2]=1;l=l+1|0;y=(c[k>>2]|0)-1|0;}while((l|0)<(y|0));c[f+80672+(j*2496|0)+2348+(y<<2)>>2]=0;l=c[k>>2]|0;w=f+80672+(j*2496|0)+2484|0;c[w>>2]=l;n=f+80672+(j*2496|0)+2492|0;c[n>>2]=1;TQa(f+80672+(j*2496|0)+2348|0,l-1|0);l=(c[k>>2]|0)+6>>1;c[w>>2]=l;c[n>>2]=l;c[f+80672+(j*2496|0)+2340>>2]=2096;c[f+80672+(j*2496|0)+2332>>2]=66;l=0;do{c[f+80672+(j*2496|0)+8+(l<<2)>>2]=1;l=l+1|0;}while((l|0)<255);c[f+80672+(j*2496|0)+1028>>2]=0;c[f+80672+(j*2496|0)+2056>>2]=0;l=f+80672+(j*2496|0)+2336|0;c[l>>2]=256;k=f+80672+(j*2496|0)+2344|0;c[k>>2]=1;UQa(f+80672+(j*2496|0)+8|0,255);c[l>>2]=131;c[k>>2]=131;k=j+1|0;if((k|0)<3){j=k}else{r=0;break}}i=b;return r|0}}while(0);yDb(a,16,2331160,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;r=-1094995529;i=b;return r|0}function PQa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0;j=i;i=i+96|0;k=j|0;l=j+16|0;m=j+80|0;n=c[h+24>>2]|0;o=c[h+28>>2]|0;h=c[b+60>>2]|0;p=h;q=h+12|0;r=q;if((o|0)<27){yDb(b,16,2184512,(s=i,i=i+16|0,c[s>>2]=27,c[s+8>>2]=o,s)|0);i=s;t=-1094995529;i=j;return t|0}u=n+o|0;v=u;w=n;x=fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;if((x&-770|0)!=0){yDb(b,16,2107536,(s=i,i=i+8|0,c[s>>2]=x,s)|0);i=s;t=-1094995529;i=j;return t|0}w=x&1;x=(w|0)==0;y=w^1;z=v-(n+4)|0;A=z>>>0>6>>>0?6:z;z=n+(A+4)|0;if((v-z|0)<2){B=0;C=z}else{D=z;B=(de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;C=n+(A+6)|0}if((v-C|0)<2){E=0;F=C}else{A=C;E=(de((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535;F=C+2|0}if((v-F|0)<2){G=0;H=F}else{C=F;G=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;H=F+2|0}if((v-H|0)<2){I=0;J=H}else{F=H;I=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;J=H+2|0}do{if((G+B|0)<=(c[b+120>>2]|0)){if((I+E|0)>(c[b+124>>2]|0)){break}if(((I|G)&15|0)!=0){break}H=v-J|0;F=H>>>0>4>>>0?4:H;H=J+F|0;do{if((v-H|0)<1){K=0}else{C=F+1|0;A=d[H]|0;if((A-1|0)>>>0>99>>>0){K=A;break}D=v-(J+C)|0;z=J+((D>>>0>4>>>0?4:D)+C)|0;do{if(x){if((u|0)!=(z|0)){L=h+8|0;break}yDb(b,16,1966968,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}else{C=h+8|0;if((c[C>>2]|0)==0){L=C;break}else{t=o}i=j;return t|0}}while(0);c[L>>2]=0;C=h+4|0;D=$$a(b,c[C>>2]|0)|0;if((D|0)<0){t=D;i=j;return t|0}D=c[C>>2]|0;c[D+84>>2]=y;c[D+88>>2]=w+1;if((u|0)==(z|0)){M=MCb(f,D)|0;if((M|0)<0){t=M;i=j;return t|0}c[g>>2]=1;t=o;i=j;return t|0}M=17-(((A*7|0)>>>0)/50|0)|0;D=0;do{c[p+32+(D*744|0)>>2]=4;N=0;do{O=p+32+(D*744|0)+4+(N*148|0)|0;c[p+32+(D*744|0)+4+(N*148|0)+132>>2]=0;P=p+32+(D*744|0)+4+(N*148|0)+128|0;Q=(c[P>>2]|0)-1|0;if((Q|0)>0){R=0;while(1){c[p+32+(D*744|0)+4+(N*148|0)+(R<<2)>>2]=1;S=R+1|0;T=(c[P>>2]|0)-1|0;if((S|0)<(T|0)){R=S}else{U=T;break}}}else{U=Q}c[p+32+(D*744|0)+4+(N*148|0)+(U<<2)>>2]=0;R=c[P>>2]|0;T=p+32+(D*744|0)+4+(N*148|0)+136|0;c[T>>2]=R;S=p+32+(D*744|0)+4+(N*148|0)+144|0;c[S>>2]=1;TQa(O,R-1|0);R=(c[P>>2]|0)+6>>1;c[T>>2]=R;c[S>>2]=R;N=N+1|0;}while((N|0)<5);c[p+2264+(D*152|0)>>2]=0;N=p+2264+(D*152|0)+4|0;c[p+2264+(D*152|0)+136>>2]=0;R=p+2264+(D*152|0)+132|0;S=(c[R>>2]|0)-1|0;if((S|0)>0){T=0;while(1){c[p+2264+(D*152|0)+4+(T<<2)>>2]=1;V=T+1|0;W=(c[R>>2]|0)-1|0;if((V|0)<(W|0)){T=V}else{X=W;break}}}else{X=S}c[p+2264+(D*152|0)+4+(X<<2)>>2]=0;T=c[R>>2]|0;W=p+2264+(D*152|0)+140|0;c[W>>2]=T;V=p+2264+(D*152|0)+148|0;c[V>>2]=1;TQa(N,T-1|0);T=(c[R>>2]|0)+6>>1;c[W>>2]=T;c[V>>2]=T;T=0;do{c[p+2720+(D*23328|0)+(T<<2)>>2]=1;T=T+1|0;}while((T|0)<255);c[p+2720+(D*23328|0)+1020>>2]=0;c[p+2720+(D*23328|0)+2048>>2]=0;T=p+2720+(D*23328|0)+2328|0;c[T>>2]=256;R=p+2720+(D*23328|0)+2336|0;c[R>>2]=1;UQa(p+2720+(D*23328|0)|0,255);c[T>>2]=131;c[R>>2]=131;R=0;do{c[p+2720+(D*23328|0)+2340+(R<<2)>>2]=1;R=R+1|0;}while((R|0)<255);c[p+2720+(D*23328|0)+3360>>2]=0;c[p+2720+(D*23328|0)+4388>>2]=0;R=p+2720+(D*23328|0)+4668|0;c[R>>2]=256;T=p+2720+(D*23328|0)+4676|0;c[T>>2]=1;UQa(p+2720+(D*23328|0)+2340|0,255);c[R>>2]=131;c[T>>2]=131;T=p+2720+(D*23328|0)+4680|0;c[p+2720+(D*23328|0)+4812>>2]=0;R=p+2720+(D*23328|0)+4808|0;N=(c[R>>2]|0)-1|0;if((N|0)>0){S=0;while(1){c[p+2720+(D*23328|0)+4680+(S<<2)>>2]=1;V=S+1|0;W=(c[R>>2]|0)-1|0;if((V|0)<(W|0)){S=V}else{Y=W;break}}}else{Y=N}c[p+2720+(D*23328|0)+4680+(Y<<2)>>2]=0;S=c[R>>2]|0;W=p+2720+(D*23328|0)+4816|0;c[W>>2]=S;V=p+2720+(D*23328|0)+4824|0;c[V>>2]=1;TQa(T,S-1|0);S=(c[R>>2]|0)+6>>1;c[W>>2]=S;c[V>>2]=S;S=0;do{V=p+2720+(D*23328|0)+4828+(S*148|0)|0;c[p+2720+(D*23328|0)+4828+(S*148|0)+132>>2]=0;W=p+2720+(D*23328|0)+4828+(S*148|0)+128|0;Z=(c[W>>2]|0)-1|0;if((Z|0)>0){_=0;while(1){c[p+2720+(D*23328|0)+4828+(S*148|0)+(_<<2)>>2]=1;$=_+1|0;aa=(c[W>>2]|0)-1|0;if(($|0)<(aa|0)){_=$}else{ca=aa;break}}}else{ca=Z}c[p+2720+(D*23328|0)+4828+(S*148|0)+(ca<<2)>>2]=0;_=c[W>>2]|0;P=p+2720+(D*23328|0)+4828+(S*148|0)+136|0;c[P>>2]=_;O=p+2720+(D*23328|0)+4828+(S*148|0)+144|0;c[O>>2]=1;TQa(V,_-1|0);_=(c[W>>2]|0)+6>>1;c[P>>2]=_;c[O>>2]=_;S=S+1|0;}while((S|0)<125);S=p+72704+(D*2656|0)+12|0;if((c[S>>2]|0)!=(A|0)){c[S>>2]=A;VQa(p+72704+(D*2656|0)+16|0,A,(D|0)==0|0)}TGb(c[p+72704+(D*2656|0)>>2]|0,0,ba(c[p+72704+(D*2656|0)+4>>2]<<2,c[p+72704+(D*2656|0)+8>>2]|0)|0)|0;S=p+72704+(D*2656|0)+144|0;c[p+72704+(D*2656|0)+276>>2]=0;R=p+72704+(D*2656|0)+272|0;T=(c[R>>2]|0)-1|0;if((T|0)>0){N=0;while(1){c[p+72704+(D*2656|0)+144+(N<<2)>>2]=1;_=N+1|0;O=(c[R>>2]|0)-1|0;if((_|0)<(O|0)){N=_}else{da=O;break}}}else{da=T}c[p+72704+(D*2656|0)+144+(da<<2)>>2]=0;N=c[R>>2]|0;O=p+72704+(D*2656|0)+280|0;c[O>>2]=N;_=p+72704+(D*2656|0)+288|0;c[_>>2]=1;TQa(S,N-1|0);N=(c[R>>2]|0)+6>>1;c[O>>2]=N;c[_>>2]=N;c[p+72704+(D*2656|0)+304>>2]=1;c[p+72704+(D*2656|0)+312>>2]=2;c[p+72704+(D*2656|0)+300>>2]=4096;c[p+72704+(D*2656|0)+308>>2]=8192;c[p+72704+(D*2656|0)+292>>2]=4;c[p+72704+(D*2656|0)+296>>2]=4;N=0;do{c[p+72704+(D*2656|0)+316+(N<<2)>>2]=1;N=N+1|0;}while((N|0)<255);c[p+72704+(D*2656|0)+1336>>2]=0;c[p+72704+(D*2656|0)+2364>>2]=0;N=p+72704+(D*2656|0)+2644|0;c[N>>2]=256;R=p+72704+(D*2656|0)+2652|0;c[R>>2]=1;UQa(p+72704+(D*2656|0)+316|0,255);c[N>>2]=131;c[R>>2]=131;R=p+80672+(D*2496|0)|0;if((c[R>>2]|0)!=(A|0)){c[R>>2]=A;c[p+80672+(D*2496|0)+4>>2]=M}R=p+80672+(D*2496|0)+2348|0;c[p+80672+(D*2496|0)+2480>>2]=0;N=p+80672+(D*2496|0)+2476|0;S=(c[N>>2]|0)-1|0;if((S|0)>0){T=0;while(1){c[p+80672+(D*2496|0)+2348+(T<<2)>>2]=1;_=T+1|0;O=(c[N>>2]|0)-1|0;if((_|0)<(O|0)){T=_}else{ea=O;break}}}else{ea=S}c[p+80672+(D*2496|0)+2348+(ea<<2)>>2]=0;T=c[N>>2]|0;O=p+80672+(D*2496|0)+2484|0;c[O>>2]=T;_=p+80672+(D*2496|0)+2492|0;c[_>>2]=1;TQa(R,T-1|0);T=(c[N>>2]|0)+6>>1;c[O>>2]=T;c[_>>2]=T;T=0;do{c[p+80672+(D*2496|0)+8+(T<<2)>>2]=1;T=T+1|0;}while((T|0)<255);c[p+80672+(D*2496|0)+1028>>2]=0;c[p+80672+(D*2496|0)+2056>>2]=0;T=p+80672+(D*2496|0)+2336|0;c[T>>2]=256;N=p+80672+(D*2496|0)+2344|0;c[N>>2]=1;UQa(p+80672+(D*2496|0)+8|0,255);c[T>>2]=131;c[N>>2]=131;D=D+1|0;}while((D|0)<3);D=n+27|0;M=o-27|0;A=q;c[A>>2]=D;z=h+16|0;c[z>>2]=u;N=h+24|0;c[N>>2]=0;T=(M|0)>4?4:M;if((T|0)>0){M=0;R=0;S=D;while(1){D=S+1|0;c[A>>2]=D;_=d[S]|0|R<<8;c[N>>2]=_;O=M+1|0;if((O|0)<(T|0)){M=O;R=_;S=D}else{break}}}S=h+20|0;c[S>>2]=-1;R=h+28|0;c[R>>2]=0;M=G>>>4;T=I>>>4;D=c[C>>2]|0;_=(c[D>>2]|0)+((ba(c[D+32>>2]|0,E)|0)+B)|0;O=m|0;c[O>>2]=_;P=B>>>1;Q=E>>>1;aa=(c[D+4>>2]|0)+((ba(c[D+36>>2]|0,Q)|0)+P)|0;$=m+4|0;c[$>>2]=aa;fa=(c[D+8>>2]|0)+((ba(c[D+40>>2]|0,Q)|0)+P)|0;P=m+8|0;c[P>>2]=fa;a:do{if((T|0)==0){ga=D}else{Q=(M|0)==0;ha=h+32|0;ia=h+2264|0;ja=h+2720|0;ka=l;la=h+72704|0;ma=h+88160|0;na=ma;oa=h+80672|0;pa=h+88416|0;qa=0;ra=D;sa=_;ta=aa;ua=fa;b:while(1){if(Q){va=ra;wa=sa;xa=ta;ya=ua}else{za=0;while(1){Aa=0;while(1){if((Aa|0)>=3){break}Ba=(Aa|0)==0|0;Ca=ha+(Aa*744|0)|0;Da=c[Ca>>2]|0;Ea=c[S>>2]|0;Fa=Ea>>>15;c[S>>2]=Fa;Ga=c[ha+(Aa*744|0)+4+(Da*148|0)+128>>2]|0;Ha=c[N>>2]|0;Ia=Ga;Ja=Ga>>1;Ga=0;Ka=0;La=Ea;do{Ea=ba(c[ha+(Aa*744|0)+4+(Da*148|0)+64+(Ja<<2)>>2]|0,Fa)|0;Ma=Ea>>>0>Ha>>>0;La=Ma?Ea:La;Ka=Ma?Ka:Ea;Ga=Ma?Ga:Ja;Ia=Ma?Ja:Ia;Ja=Ia+Ga>>1;}while((Ja|0)!=(Ga|0));Ja=8<<Ba;Ia=ha+(Aa*744|0)+4+(Da*148|0)|0;Fa=Ha-Ka|0;c[N>>2]=Fa;Ma=La-Ka|0;c[S>>2]=Ma;if(Ma>>>0<16777216>>>0){Ea=c[z>>2]|0;Na=Ma;Ma=Fa;Fa=c[A>>2]|0;while(1){Oa=Na<<8;c[S>>2]=Oa;Pa=Ma<<8;c[N>>2]=Pa;do{if(Fa>>>0<Ea>>>0){Qa=Fa+1|0;c[A>>2]=Qa;Ra=d[Fa]|0|Pa;c[N>>2]=Ra;Sa=Ra;Ta=Qa}else{if((Pa|0)!=0){Sa=Pa;Ta=Fa;break}c[R>>2]=1;c[N>>2]=1;Sa=1;Ta=Fa}}while(0);if(Oa>>>0>16777215>>>0){break}else{Na=Oa;Ma=Sa;Fa=Ta}}}TQa(Ia,Ga);c[Ca>>2]=Ga;c:do{if((Ga|0)==0){Fa=c[m+(Aa<<2)>>2]|0;Ma=c[(c[C>>2]|0)+32+(Aa<<2)>>2]|0;Na=SQa(r,ia+(Aa*152|0)+4|0)|0;Ea=ia+(Aa*152|0)|0;Ka=(c[Ea>>2]|0)+Na|0;c[Ea>>2]=Ka;if((Ja|0)<=0){break}Na=Fa+(ba(Ja,za)|0)|0;TGb(Na|0,Ka&255|0,Ja|0)|0;if((Ja|0)>1){Ua=1;Va=Na}else{break}do{Va=Va+Ma|0;Ua=Ua+1|0;TGb(Va|0,c[Ea>>2]&255|0,Ja|0)|0;}while((Ua|0)<(Ja|0))}else if((Ga|0)==1){Ea=c[m+(Aa<<2)>>2]|0;Ma=ba(Ja,za)|0;Oa=c[(c[C>>2]|0)+32+(Aa<<2)>>2]|0;Na=c[S>>2]|0;Ka=Na>>>15;c[S>>2]=Ka;Fa=c[ja+(Aa*23328|0)+4808>>2]|0;La=c[N>>2]|0;Ha=Fa;Da=Fa>>1;Fa=0;Ba=0;Pa=Na;do{Na=ba(c[ja+(Aa*23328|0)+4744+(Da<<2)>>2]|0,Ka)|0;Qa=Na>>>0>La>>>0;Pa=Qa?Na:Pa;Ba=Qa?Ba:Na;Fa=Qa?Fa:Da;Ha=Qa?Da:Ha;Da=Ha+Fa>>1;}while((Da|0)!=(Fa|0));Da=Ea+Ma|0;Ha=ja+(Aa*23328|0)+4680|0;Ka=La-Ba|0;c[N>>2]=Ka;Qa=Pa-Ba|0;c[S>>2]=Qa;if(Qa>>>0<16777216>>>0){Na=c[z>>2]|0;Ra=Qa;Qa=Ka;Ka=c[A>>2]|0;while(1){Wa=Ra<<8;c[S>>2]=Wa;Xa=Qa<<8;c[N>>2]=Xa;do{if(Ka>>>0<Na>>>0){Ya=Ka+1|0;c[A>>2]=Ya;Za=d[Ka]|0|Xa;c[N>>2]=Za;_a=Za;$a=Ya}else{if((Xa|0)!=0){_a=Xa;$a=Ka;break}c[R>>2]=1;c[N>>2]=1;_a=1;$a=Ka}}while(0);if(Wa>>>0>16777215>>>0){break}else{Ra=Wa;Qa=_a;Ka=$a}}}TQa(Ha,Fa);Ka=Fa+2|0;if((Ka|0)>0){Qa=ja+(Aa*23328|0)+2340|0;Ra=0;do{c[k+(Ra<<2)>>2]=RQa(r,Qa)|0;Ra=Ra+1|0;}while((Ra|0)<(Ka|0));if((Ka|0)<4){ab=Ka;bb=91}}else{ab=0;bb=91}if((bb|0)==91){bb=0;TGb(k+(ab<<2)|0,0,16-(ab<<2)|0)|0}TGb(ka|0,0,64)|0;if((Ja|0)<=0){break}Ra=ja+(Aa*23328|0)|0;Qa=0;Fa=Da;while(1){Ha=0;Na=0;Ba=0;while(1){Pa=l+(Ha<<2)|0;La=c[Pa>>2]|0;Ma=Na+Ba+(La*5|0)|0;Ea=c[S>>2]|0;Xa=Ea>>>15;c[S>>2]=Xa;Ya=c[ja+(Aa*23328|0)+4828+(Ma*148|0)+128>>2]|0;Za=c[N>>2]|0;cb=Ya;db=Ya>>1;Ya=0;eb=0;fb=Ea;do{Ea=ba(c[ja+(Aa*23328|0)+4828+(Ma*148|0)+64+(db<<2)>>2]|0,Xa)|0;gb=Ea>>>0>Za>>>0;fb=gb?Ea:fb;eb=gb?eb:Ea;Ya=gb?Ya:db;cb=gb?db:cb;db=cb+Ya>>1;}while((db|0)!=(Ya|0));db=ja+(Aa*23328|0)+4828+(Ma*148|0)|0;cb=Za-eb|0;c[N>>2]=cb;Xa=fb-eb|0;c[S>>2]=Xa;if(Xa>>>0<16777216>>>0){gb=c[z>>2]|0;Ea=Xa;Xa=cb;cb=c[A>>2]|0;while(1){hb=Ea<<8;c[S>>2]=hb;ib=Xa<<8;c[N>>2]=ib;do{if(cb>>>0<gb>>>0){jb=cb+1|0;c[A>>2]=jb;kb=d[cb]|0|ib;c[N>>2]=kb;lb=kb;mb=jb}else{if((ib|0)!=0){lb=ib;mb=cb;break}c[R>>2]=1;c[N>>2]=1;lb=1;mb=cb}}while(0);if(hb>>>0>16777215>>>0){break}else{Ea=hb;Xa=lb;cb=mb}}}TQa(db,Ya);c[Pa>>2]=Ya;if((Ya|0)<4){a[Fa+Ha|0]=c[k+(Ya<<2)>>2]}else{a[Fa+Ha|0]=RQa(r,Ra)|0}cb=Ha+1|0;if((cb|0)<(Ja|0)){Ha=cb;Na=Ya;Ba=La*25|0}else{break}}Ba=Qa+1|0;if((Ba|0)<(Ja|0)){Qa=Ba;Fa=Fa+Oa|0}else{break}}}else if((Ga|0)==2){Oa=c[(c[C>>2]|0)+32+(Aa<<2)>>2]|0;Fa=Ja>>3;Qa=ba(Fa,za)|0;Ra=ba(Fa,qa)|0;if((Fa|0)<=0){break}Da=ba(Ja,za)|0;Ka=Oa<<3;Ba=la+(Aa*2656|0)+4|0;Na=la+(Aa*2656|0)+144|0;Ha=la+(Aa*2656|0)|0;Wa=la+(Aa*2656|0)+16|0;cb=la+(Aa*2656|0)+316|0;Xa=la+(Aa*2656|0)+300|0;Ea=la+(Aa*2656|0)+296|0;gb=la+(Aa*2656|0)+292|0;eb=la+(Aa*2656|0)+312|0;fb=la+(Aa*2656|0)+304|0;Za=la+(Aa*2656|0)+308|0;Ma=0;ib=(c[m+(Aa<<2)>>2]|0)+Da|0;d:while(1){Da=Ma+Ra|0;jb=(Da|0)==0;kb=0;do{nb=kb+Qa|0;ob=(ba(c[Ba>>2]|0,Da)|0)+nb|0;TGb(ma|0,0,256)|0;pb=SQa(r,Na)|0;qb=(nb|0)!=0;do{if(jb){if(qb){rb=c[Ha>>2]|0;sb=(c[rb+(nb-1<<2)>>2]|0)+pb|0;tb=rb;break}else{sb=pb;tb=c[Ha>>2]|0;break}}else{if(!qb){rb=c[Ha>>2]|0;sb=(c[rb+(ob-(c[Ba>>2]|0)<<2)>>2]|0)+pb|0;tb=rb;break}rb=ob-1|0;ub=c[Ha>>2]|0;vb=c[ub+(rb<<2)>>2]|0;wb=c[Ba>>2]|0;xb=c[ub+(rb-wb<<2)>>2]|0;rb=c[ub+(ob-wb<<2)>>2]|0;wb=rb-xb|0;yb=vb-xb|0;if((((wb|0)>-1?wb:-wb|0)|0)>(((yb|0)>-1?yb:-yb|0)|0)){sb=rb+pb|0;tb=ub;break}else{sb=vb+pb|0;tb=ub;break}}}while(0);c[tb+(ob<<2)>>2]=sb;c[na>>2]=ba(e[Wa>>1]|0,sb)|0;pb=1;while(1){qb=RQa(r,cb)|0;if((qb|0)==240){zb=pb+16|0}else if((qb|0)==0){break}else{nb=qb&15;if((nb|0)==0){break d}La=(qb>>4)+pb|0;if((La|0)>63){break d}qb=c[S>>2]|0;Ya=ba(qb>>>13,c[Xa>>2]|0)|0;Pa=c[N>>2]|0;db=Pa>>>0>=Ya>>>0;if(db){ub=Pa-Ya|0;c[N>>2]=ub;Ab=qb-Ya|0;Bb=ub}else{Ab=Ya;Bb=Pa}c[S>>2]=Ab;if(Ab>>>0<16777216>>>0){Pa=c[z>>2]|0;Ya=Ab;ub=Bb;qb=c[A>>2]|0;while(1){vb=Ya<<8;c[S>>2]=vb;rb=ub<<8;c[N>>2]=rb;do{if(qb>>>0<Pa>>>0){yb=qb+1|0;c[A>>2]=yb;wb=d[qb]|0|rb;c[N>>2]=wb;Cb=wb;Db=yb}else{if((rb|0)!=0){Cb=rb;Db=qb;break}c[R>>2]=1;c[N>>2]=1;Cb=1;Db=qb}}while(0);if(vb>>>0>16777215>>>0){break}else{Ya=vb;ub=Cb;qb=Db}}}if(!db){c[fb>>2]=(c[fb>>2]|0)+1}qb=(c[Ea>>2]|0)-1|0;c[Ea>>2]=qb;if((qb|0)==0){qb=c[gb>>2]|0;ub=(c[eb>>2]|0)+qb|0;c[eb>>2]=ub;do{if(ub>>>0>8192>>>0){Ya=(ub+1|0)>>>1;c[eb>>2]=Ya;Pa=((c[fb>>2]|0)+1|0)>>>1;c[fb>>2]=Pa;if((Ya|0)!=(Pa|0)){Eb=Ya;Fb=Pa;break}Pa=Ya+1|0;c[eb>>2]=Pa;Eb=Pa;Fb=Ya}else{Eb=ub;Fb=c[fb>>2]|0}}while(0);ub=(qb*5|0)>>2;Ya=(ub|0)>64?64:ub;c[gb>>2]=Ya;ub=2147483648/(Eb>>>0)|0;c[Xa>>2]=(ba(ub,Fb)|0)>>>18;c[Za>>2]=(ba(ub,Eb)|0)>>>18;c[Ea>>2]=Ya}if(nb>>>0>1>>>0){Ya=nb-1|0;ub=1<<Ya;Pa=(c[S>>2]|0)>>>(Ya>>>0);c[S>>2]=Pa;Ya=c[N>>2]|0;hb=(Ya>>>0)/(Pa>>>0)|0;rb=Ya-(ba(hb,Pa)|0)|0;c[N>>2]=rb;if(Pa>>>0<16777216>>>0){Ya=c[z>>2]|0;yb=Pa;Pa=rb;rb=c[A>>2]|0;while(1){wb=yb<<8;c[S>>2]=wb;xb=Pa<<8;c[N>>2]=xb;do{if(rb>>>0<Ya>>>0){Gb=rb+1|0;c[A>>2]=Gb;Hb=d[rb]|0|xb;c[N>>2]=Hb;Ib=Hb;Jb=Gb}else{if((xb|0)!=0){Ib=xb;Jb=rb;break}c[R>>2]=1;c[N>>2]=1;Ib=1;Jb=rb}}while(0);if(wb>>>0>16777215>>>0){break}else{yb=wb;Pa=Ib;rb=Jb}}}Kb=hb+ub|0}else{Kb=nb}rb=d[1075976+La|0]|0;c[na+(rb<<2)>>2]=ba(e[la+(Aa*2656|0)+16+(rb<<1)>>1]|0,db?Kb:-Kb|0)|0;zb=La+1|0}if((zb|0)<64){pb=zb}else{bb=155;break}}if((bb|0)==155){bb=0;if((zb|0)!=64){break d}}WQa(ib+(kb<<3)|0,Oa,na);kb=kb+1|0;}while((kb|0)<(Fa|0));kb=Ma+1|0;if((kb|0)<(Fa|0)){Ma=kb;ib=ib+Ka|0}else{break c}}c[R>>2]=1}else if((Ga|0)==3){Ka=(c[m+(Aa<<2)>>2]|0)+(ba(Ja,za)|0)|0;ib=c[(c[C>>2]|0)+32+(Aa<<2)>>2]|0;Ma=Ja>>1;if((Ja|0)>0){Fa=oa+(Aa*2496|0)+8|0;Oa=oa+(Aa*2496|0)+4|0;Ea=oa+(Aa*2496|0)+2348|0;Za=pa;Xa=0;while(1){gb=(Xa|0)<(Ma|0);fb=0;do{if((fb|0)<(Ma|0)&gb){eb=RQa(r,Fa)|0;c[Za+(fb<<2)>>2]=eb;Lb=eb}else{eb=SQa(r,Ea)|0;c[Za+(fb<<2)>>2]=eb;Lb=eb}c[Za+(fb<<2)>>2]=ba(c[Oa>>2]|0,Lb)|0;fb=fb+1|0;}while((fb|0)<(Ja|0));fb=Xa+1|0;if((fb|0)<(Ja|0)){Za=Za+(Ja<<2)|0;Xa=fb}else{break}}Mb=pa+((ba(Ja,Ja)|0)<<2)|0}else{Mb=pa}if((Ma|0)<=0){break}Xa=ib<<1;Za=ba(Ma,Ja)|0;Oa=Mb+((ba(Ja,-Ja|0)|0)<<2)|0;Ea=Ka;Fa=0;while(1){fb=0;do{gb=c[Oa+(fb<<2)>>2]|0;eb=c[Oa+(fb+Ma<<2)>>2]|0;cb=fb+Za|0;Wa=c[Oa+(cb<<2)>>2]|0;Ba=c[Oa+(cb+Ma<<2)>>2]|0;cb=gb-eb|0;Ha=Wa-Ba|0;Na=eb+gb|0;gb=Ba+Wa|0;Wa=cb-Ha|0;if(Wa>>>0>255>>>0){Nb=-Wa>>31&255}else{Nb=Wa&255}Wa=fb<<1;a[Ea+Wa|0]=Nb;Ba=Ha+cb|0;if(Ba>>>0>255>>>0){Ob=-Ba>>31&255}else{Ob=Ba&255}a[Ea+(Wa+ib)|0]=Ob;Ba=Na-gb|0;if(Ba>>>0>255>>>0){Pb=-Ba>>31&255}else{Pb=Ba&255}Ba=Wa|1;a[Ea+Ba|0]=Pb;Wa=gb+Na|0;if(Wa>>>0>255>>>0){Qb=-Wa>>31&255}else{Qb=Wa&255}a[Ea+(Ba+ib)|0]=Qb;fb=fb+1|0;}while((fb|0)<(Ma|0));fb=Fa+1|0;if((fb|0)<(Ma|0)){Oa=Oa+(Ja<<2)|0;Ea=Ea+Xa|0;Fa=fb}else{break}}}}while(0);if((c[L>>2]|0)!=0){break b}if((c[R>>2]|0)==0){Aa=Aa+1|0}else{break b}}Aa=za+1|0;if((Aa|0)<(M|0)){za=Aa}else{break}}va=c[C>>2]|0;wa=c[O>>2]|0;xa=c[$>>2]|0;ya=c[P>>2]|0}W=wa+(c[va+32>>2]<<4)|0;c[O>>2]=W;V=xa+(c[va+36>>2]<<3)|0;c[$>>2]=V;Z=ya+(c[va+40>>2]<<3)|0;c[P>>2]=Z;Aa=qa+1|0;if((Aa|0)<(T|0)){qa=Aa;ra=va;sa=W;ta=V;ua=Z}else{ga=va;break a}}yDb(b,16,1938792,(s=i,i=i+16|0,c[s>>2]=za,c[s+8>>2]=qa,s)|0);i=s;c[L>>2]=1;t=-1094995529;i=j;return t|0}}while(0);T=MCb(f,ga)|0;if((T|0)<0){t=T;i=j;return t|0}c[g>>2]=1;t=o;i=j;return t|0}}while(0);yDb(b,16,2004320,(s=i,i=i+8|0,c[s>>2]=K,s)|0);i=s;t=-1094995529;i=j;return t|0}}while(0);yDb(b,16,2049976,(s=i,i=i+32|0,c[s>>2]=G,c[s+8>>2]=I,c[s+16>>2]=B,c[s+24>>2]=E,s)|0);i=s;t=-1094995529;i=j;return t|0}function QQa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);$Db(b+72704|0);$Db(b+75360|0);$Db(b+78016|0);return 0}function RQa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=a+8|0;f=c[e>>2]|0;g=f>>>15;c[e>>2]=g;h=a+12|0;i=c[h>>2]|0;j=(i>>>0)/(g>>>0)|0;k=j>>9;l=c[b+2052+(k<<2)>>2]|0;m=(c[b+2052+(k+1<<2)>>2]|0)+1|0;k=l+1|0;if((m|0)>(k|0)){n=l;o=m;while(1){m=o+n>>1;p=(c[b+1024+(m<<2)>>2]|0)>(j|0);q=p?n:m;r=p?m:o;m=q+1|0;if((r|0)>(m|0)){n=q;o=r}else{s=q;t=m;break}}}else{s=l;t=k}k=ba(g,c[b+1024+(s<<2)>>2]|0)|0;if((s|0)==255){u=f}else{u=ba(c[b+1024+(t<<2)>>2]|0,g)|0}g=i-k|0;c[h>>2]=g;i=u-k|0;c[e>>2]=i;if(!(i>>>0<16777216>>>0)){UQa(b,s);return s|0}k=a|0;u=a+16|0;t=c[a+4>>2]|0;a=i;i=g;g=c[k>>2]|0;while(1){f=a<<8;c[e>>2]=f;l=i<<8;c[h>>2]=l;do{if(g>>>0<t>>>0){o=g+1|0;c[k>>2]=o;n=d[g]|0|l;c[h>>2]=n;v=n;w=o}else{if((l|0)!=0){v=l;w=g;break}c[u>>2]=1;c[h>>2]=1;v=1;w=g}}while(0);if(f>>>0>16777215>>>0){break}else{a=f;i=v;g=w}}UQa(b,s);return s|0}function SQa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=a+8|0;f=c[e>>2]|0;g=f>>>15;c[e>>2]=g;h=c[b+128>>2]|0;i=a+12|0;j=c[i>>2]|0;k=h;l=h>>1;h=0;m=0;n=f;do{f=ba(c[b+64+(l<<2)>>2]|0,g)|0;o=f>>>0>j>>>0;n=o?f:n;m=o?m:f;h=o?h:l;k=o?l:k;l=k+h>>1;}while((l|0)!=(h|0));l=j-m|0;c[i>>2]=l;j=n-m|0;c[e>>2]=j;if(j>>>0<16777216>>>0){m=a|0;n=a+16|0;k=c[a+4>>2]|0;g=j;j=l;l=c[m>>2]|0;while(1){o=g<<8;c[e>>2]=o;f=j<<8;c[i>>2]=f;do{if(l>>>0<k>>>0){p=l+1|0;c[m>>2]=p;q=d[l]|0|f;c[i>>2]=q;r=q;s=p}else{if((f|0)!=0){r=f;s=l;break}c[n>>2]=1;c[i>>2]=1;r=1;s=l}}while(0);if(o>>>0>16777215>>>0){break}else{g=o;j=r;l=s}}}TQa(b,h);if((h|0)==0){t=0;return t|0}b=c[e>>2]|0;s=b>>>1;c[e>>2]=s;l=c[i>>2]|0;r=s>>>0<=l>>>0;if(r){j=l-s|0;c[i>>2]=j;u=j}else{u=l}if(b>>>0<33554432>>>0){b=a|0;l=a+16|0;j=c[a+4>>2]|0;g=s;n=u;m=c[b>>2]|0;while(1){k=g<<8;c[e>>2]=k;f=n<<8;c[i>>2]=f;do{if(m>>>0<j>>>0){p=m+1|0;c[b>>2]=p;q=d[m]|0|f;c[i>>2]=q;v=q;w=p}else{if((f|0)!=0){v=f;w=m;break}c[l>>2]=1;c[i>>2]=1;v=1;w=m}}while(0);if(k>>>0>16777215>>>0){x=k;y=v;break}else{g=k;n=v;m=w}}}else{x=s;y=u}if((h|0)>1){u=h-1|0;s=1<<u;w=x>>>(u>>>0);c[e>>2]=w;u=(y>>>0)/(w>>>0)|0;x=y-(ba(u,w)|0)|0;c[i>>2]=x;if(w>>>0<16777216>>>0){y=a|0;m=a+16|0;v=c[a+4>>2]|0;a=w;w=x;x=c[y>>2]|0;while(1){n=a<<8;c[e>>2]=n;g=w<<8;c[i>>2]=g;do{if(x>>>0<v>>>0){l=x+1|0;c[y>>2]=l;b=d[x]|0|g;c[i>>2]=b;z=b;A=l}else{if((g|0)!=0){z=g;A=x;break}c[m>>2]=1;c[i>>2]=1;z=1;A=x}}while(0);if(n>>>0>16777215>>>0){break}else{a=n;w=z;x=A}}}B=u+s|0}else{B=h}if(r){t=B;return t|0}t=-B|0;return t|0}function TQa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a+(b<<2)|0;c[d>>2]=(c[d>>2]|0)+1;d=a+144|0;b=(c[d>>2]|0)-1|0;c[d>>2]=b;if((b|0)!=0){return}b=a+136|0;e=a+132|0;f=(c[e>>2]|0)+(c[b>>2]|0)|0;c[e>>2]=f;do{if((f|0)>32768){c[e>>2]=0;g=a+128|0;if((c[g>>2]|0)>0){h=0}else{break}while(1){i=a+(h<<2)|0;j=(c[i>>2]|0)+1>>1;c[i>>2]=j;i=j+(c[e>>2]|0)|0;c[e>>2]=i;j=h+1|0;k=c[g>>2]|0;if((j|0)<(k|0)){h=j}else{l=i;m=k;n=6;break}}}else{l=f;m=c[a+128>>2]|0;n=6}}while(0);do{if((n|0)==6){f=2147483648/(l>>>0)|0;h=a+128|0;if((m|0)>0){o=0;p=0}else{break}while(1){c[a+64+(p<<2)>>2]=(ba(o,f)|0)>>>16;e=p+1|0;if((e|0)<(c[h>>2]|0)){o=(c[a+(p<<2)>>2]|0)+o|0;p=e}else{break}}}}while(0);p=((c[b>>2]|0)*5|0)>>2;c[b>>2]=p;o=c[a+140>>2]|0;if((p|0)>(o|0)){c[b>>2]=o;q=o}else{q=p}c[d>>2]=q;return}function UQa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a+(b<<2)|0;c[d>>2]=(c[d>>2]|0)+1;d=a+2336|0;b=(c[d>>2]|0)-1|0;c[d>>2]=b;if((b|0)!=0){return}b=a+2328|0;e=a+2048|0;f=(c[e>>2]|0)+(c[b>>2]|0)|0;c[e>>2]=f;if((f|0)>32768){c[e>>2]=0;g=0;while(1){h=a+(g<<2)|0;i=(c[h>>2]|0)+1>>1;c[h>>2]=i;h=i+(c[e>>2]|0)|0;c[e>>2]=h;i=g+1|0;if((i|0)<256){g=i}else{j=h;break}}}else{j=f}f=2147483648/(j>>>0)|0;c[a+2052>>2]=0;j=0;g=0;e=1;while(1){h=ba(j,f)|0;c[a+1024+(g<<2)>>2]=h>>>16;i=(c[a+(g<<2)>>2]|0)+j|0;k=h>>>25;if((e|0)>(k|0)){l=e}else{h=g-1|0;m=e;while(1){n=m+1|0;c[a+2052+(m<<2)>>2]=h;if((n|0)>(k|0)){break}else{m=n}}l=k+1|0}m=g+1|0;if((m|0)<256){j=i;g=m;e=l}else{break}}e=a+2324|0;if((l|0)<(c[e>>2]|0)){g=l;while(1){l=g+1|0;c[a+2052+(g<<2)>>2]=255;if((l|0)<(c[e>>2]|0)){g=l}else{break}}}g=((c[b>>2]|0)*5|0)>>2;c[b>>2]=g;e=c[a+2332>>2]|0;if((g|0)>(e|0)){c[b>>2]=e;o=e}else{o=g}c[d>>2]=o;return}function VQa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0;f=(e|0)!=0?688200:1485944;if((c|0)<=49){e=0;do{b[a+(e<<1)>>1]=((((d[f+e|0]|0)*5e3|0|0)/(c|0)|0)+50|0)/100|0;e=e+1|0;}while((e|0)<64);return}e=200-(c<<1)|0;c=0;do{b[a+(c<<1)>>1]=((ba(d[f+c|0]|0,e)|0)+50|0)/100|0;c=c+1|0;}while((c|0)<64);return}function WQa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=e;g=0;while(1){h=f+28|0;i=c[h>>2]|0;j=f+4|0;k=c[j>>2]|0;l=f+20|0;m=c[l>>2]|0;n=f+12|0;o=c[n>>2]|0;p=o+i|0;q=m+k|0;r=(p*77062|0)+(q*51491|0)|0;s=(p*-51491|0)+(q*77062|0)|0;q=f+8|0;p=c[q>>2]|0;t=f+24|0;u=c[t>>2]|0;v=(u*-85623|0)+(p*35470|0)|0;w=(u*35470|0)+(p*85623|0)|0;p=c[f>>2]|0;u=f+16|0;x=c[u>>2]|0;y=p-x<<16|8192;z=x+p<<16|8192;p=(k*39410|0)+(i*-58980|0)+r|0;c[f>>2]=p+w+z>>13;x=(o*33410|0)+(m*-167963|0)+s|0;c[j>>2]=x+v+y>>13;j=(o*-167963|0)+(m*-33410|0)+r|0;c[q>>2]=j-v+y>>13;q=(k*-58980|0)+(i*-39409|0)+s|0;c[n>>2]=q-w+z>>13;c[u>>2]=z-(q+w)>>13;c[l>>2]=y-(j+v)>>13;c[t>>2]=v-x+y>>13;c[h>>2]=w-p+z>>13;z=g+1|0;if((z|0)<8){f=f+32|0;g=z}else{A=e;B=0;break}}while(1){g=A+224|0;f=c[g>>2]|0;z=A+32|0;p=c[z>>2]|0;w=A+160|0;h=c[w>>2]|0;y=A+96|0;x=c[y>>2]|0;v=x+f|0;t=h+p|0;j=(v*77062|0)+(t*51491|0)|0;l=(v*-51491|0)+(t*77062|0)|0;t=A+64|0;v=c[t>>2]|0;q=A+192|0;u=c[q>>2]|0;n=(u*-85623|0)+(v*35470|0)|0;s=(u*35470|0)+(v*85623|0)|0;v=c[A>>2]|0;u=A+128|0;i=c[u>>2]|0;k=(v-i<<16)+2097152|0;r=(i+v<<16)+2097152|0;v=(p*39410|0)+(f*-58980|0)+j|0;c[A>>2]=v+s+r>>22;i=(x*33410|0)+(h*-167963|0)+l|0;c[z>>2]=i+n+k>>22;z=(x*-167963|0)+(h*-33410|0)+j|0;c[t>>2]=z-n+k>>22;t=(p*-58980|0)+(f*-39409|0)+l|0;c[y>>2]=t-s+r>>22;c[u>>2]=r-(t+s)>>22;c[w>>2]=k-(z+n)>>22;c[q>>2]=n-i+k>>22;c[g>>2]=s-v+r>>22;r=B+1|0;if((r|0)<8){A=A+4|0;B=r}else{C=e;D=0;E=b;break}}while(1){b=c[C>>2]|0;e=b+128|0;if(e>>>0>255>>>0){F=-128-b>>31&255}else{F=e&255}a[E]=F;e=c[C+4>>2]|0;b=e+128|0;if(b>>>0>255>>>0){G=-128-e>>31&255}else{G=b&255}a[E+1|0]=G;b=c[C+8>>2]|0;e=b+128|0;if(e>>>0>255>>>0){H=-128-b>>31&255}else{H=e&255}a[E+2|0]=H;e=c[C+12>>2]|0;b=e+128|0;if(b>>>0>255>>>0){I=-128-e>>31&255}else{I=b&255}a[E+3|0]=I;b=c[C+16>>2]|0;e=b+128|0;if(e>>>0>255>>>0){J=-128-b>>31&255}else{J=e&255}a[E+4|0]=J;e=c[C+20>>2]|0;b=e+128|0;if(b>>>0>255>>>0){K=-128-e>>31&255}else{K=b&255}a[E+5|0]=K;b=c[C+24>>2]|0;e=b+128|0;if(e>>>0>255>>>0){L=-128-b>>31&255}else{L=e&255}a[E+6|0]=L;e=c[C+28>>2]|0;b=e+128|0;if(b>>>0>255>>>0){M=-128-e>>31&255}else{M=b&255}a[E+7|0]=M;b=D+1|0;if((b|0)<8){C=C+32|0;D=b;E=E+d|0}else{break}}return}function XQa(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+496|0;f=e|0;g=e+168|0;h=d+60|0;j=c[h>>2]|0;k=j;l=f|0;m=g;n=0;while(1){if((n|0)<2){o=0;p=0;q=0;r=0}else{break}while(1){s=a[643936+(n<<4)+o|0]|0;t=o+1|0;if(s<<24>>24==0){u=p;v=q;w=r}else{x=s&255;s=x>>>0>1>>>0?x:1;TGb(f+r|0,t&255|0,s|0)|0;y=0;z=p;A=r;while(1){b[g+(A<<1)>>1]=z;B=y+1|0;if((B|0)<(x|0)){y=B;z=z+1|0;A=A+1|0}else{break}}u=s+p|0;v=t;w=s+r|0}if((t|0)<16){o=t;p=u<<1;q=v;r=w}else{break}}if((N_(k+4+(n*20|0)|0,(v|0)>9?9:v,12,l,1,1,m,2,2,0,1,1,0)|0)==0){C=0;D=0;E=0;F=0}else{G=22;break}while(1){A=a[644296+(n<<4)+C|0]|0;z=C+1|0;if(A<<24>>24==0){H=D;I=E;J=F}else{y=A&255;A=y>>>0>1>>>0?y:1;TGb(f+F|0,z&255|0,A|0)|0;x=0;B=D;K=F;while(1){b[g+(K<<1)>>1]=B;L=x+1|0;if((L|0)<(y|0)){x=L;B=B+1|0;K=K+1|0}else{break}}H=A+D|0;I=z;J=A+F|0}if((z|0)<16){C=z;D=H<<1;E=I;F=J}else{break}}if((N_(k+44+(n*20|0)|0,(I|0)>9?9:I,162,l,1,1,m,2,2,643968+(n*162|0)|0,1,1,0)|0)==0){M=0;N=0;O=0;P=0}else{G=22;break}while(1){K=a[643904+(n<<4)+M|0]|0;B=M+1|0;if(K<<24>>24==0){Q=N;R=O;S=P}else{x=K&255;K=x>>>0>1>>>0?x:1;TGb(f+P|0,B&255|0,K|0)|0;y=0;t=N;s=P;while(1){b[g+(s<<1)>>1]=t;L=y+1|0;if((L|0)<(x|0)){y=L;t=t+1|0;s=s+1|0}else{break}}Q=K+N|0;R=B;S=K+P|0}if((B|0)<16){M=B;N=Q<<1;O=R;P=S}else{break}}if((N_(k+84+(n*20|0)|0,(R|0)>9?9:R,9,l,1,1,m,2,2,643880+(n*9|0)|0,1,1,0)|0)==0){n=n+1|0}else{G=22;break}}if((G|0)==22){yDb(d,16,2288536,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;Q_(j+4|0);Q_(j+44|0);Q_(j+84|0);Q_(j+24|0);Q_(j+64|0);Q_(j+104|0);U=-12;i=e;return U|0}n=d+120|0;m=j+1420|0;l=j+1408|0;R=0;while(1){if((R|0)>=3){break}k=((c[n>>2]|0)+15&-16)>>((R|0)!=0|2);c[m+(R<<2)>>2]=k;S=WDb(k<<2)|0;c[l+(R<<2)>>2]=S;if((S|0)==0){G=25;break}else{R=R+1|0}}if((G|0)==25){yDb(d,16,2272288,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;Q_(j+4|0);Q_(j+44|0);Q_(j+84|0);Q_(j+24|0);Q_(j+64|0);Q_(j+104|0);U=-12;i=e;return U|0}T=ICb()|0;c[j>>2]=T;if((T|0)==0){T=c[h>>2]|0;JCb(T);$Db(T+1408|0);$Db(T+1412|0);$Db(T+1416|0);Q_(T+4|0);Q_(T+44|0);Q_(T+84|0);Q_(T+24|0);Q_(T+64|0);Q_(T+104|0);U=-12;i=e;return U|0}else{c[d+140>>2]=5;U=0;i=e;return U|0}return 0}function YQa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0;j=i;i=i+216|0;k=j|0;l=j+16|0;m=j+32|0;n=j+48|0;o=j+64|0;p=j+80|0;q=j+96|0;r=j+160|0;s=j+176|0;t=j+200|0;u=c[h+24>>2]|0;v=c[h+28>>2]|0;h=c[e+60>>2]|0;w=h;if((v|0)<8){yDb(e,16,2184456,(x=i,i=i+16|0,c[x>>2]=8,c[x+8>>2]=v,x)|0);i=x;y=-1094995529;i=j;return y|0}z=u+v|0;A=z;B=u+2|0;C=u;D=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;if((A-B|0)<2){E=0;F=B}else{C=B;E=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;F=u+4|0}C=A-F|0;B=C>>>0>2>>>0?2:C;C=F+B|0;if((A-C|0)<1){G=0;H=C}else{G=d[C]|0;H=F+(B+1)|0}if((A-H|0)<1){I=0;J=H}else{I=d[H]|0;J=H+1|0}do{if((D|0)<=(c[e+120>>2]|0)){if((E|0)!=(c[e+124>>2]|0)){break}if((G-1|0)>>>0>99>>>0){yDb(e,16,2049944,(x=i,i=i+8|0,c[x>>2]=G,x)|0);i=x;y=-1094995529;i=j;return y|0}if(I>>>0>2>>>0){yDb(e,16,2004296,(x=i,i=i+8|0,c[x>>2]=I,x)|0);i=x;y=-1094995529;i=j;return y|0}H=(I|0)==2;if((z|0)==(J|0)&(H^1)){yDb(e,16,1966920,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=j;return y|0}A=h;B=$$a(e,c[A>>2]|0)|0;if((B|0)<0){y=B;i=j;return y|0}B=(I|0)==0;F=c[A>>2]|0;c[F+84>>2]=B&1;c[F+88>>2]=B?1:2;if(H){c[g>>2]=1;H=MCb(f,F)|0;y=(H|0)<0?H:v;i=j;return y|0}H=h+1148|0;if((c[H>>2]|0)==(G|0)){K=F}else{c[H>>2]=G;VQa(h+1152|0,G,1);VQa(h+1280|0,G,0);K=c[A>>2]|0}F=u+8|0;C=v-8|0;L=C>>>0>268435455>>>0?-8:C<<3;C=L>>>0>2147483639>>>0|(F|0)==0;M=C?0:F;F=C?0:L;L=s|0;c[L>>2]=M;c[s+12>>2]=F;C=s+16|0;c[C>>2]=F+8;c[s+4>>2]=M+(F>>3);F=s+8|0;c[F>>2]=0;M=(D+15|0)>>>4;N=(E+15|0)>>>4;O=c[K>>2]|0;P=t|0;c[P>>2]=O;Q=c[K+4>>2]|0;R=t+4|0;c[R>>2]=Q;S=c[K+8>>2]|0;T=t+8|0;c[T>>2]=S;TGb(h+1496|0,0,48)|0;a:do{if((N|0)==0){U=K}else{V=h+1432|0;W=(M|0)==0;X=h+1408|0;Y=h+1440|0;Z=V;_=h+1456|0;$=h+1448|0;aa=h+1412|0;ca=h+1472|0;da=h+1464|0;ea=h+1416|0;fa=h+1488|0;ga=h+1480|0;ha=h+4|0;ia=h+44|0;ja=h+124|0;ka=h+1152|0;la=h+1436|0;ma=h+1452|0;na=h+24|0;oa=h+64|0;pa=h+1280|0;qa=o;ra=p;sa=q;ta=h+380|0;ua=r|0;va=h+636|0;wa=r+4|0;xa=h+892|0;ya=r+8|0;za=o|0;Aa=o+4|0;Ba=o+8|0;Ca=n|0;Da=m|0;Ea=q|0;Fa=0;Ga=K;Ha=O;Ia=Q;Ja=S;b:while(1){TGb(V|0,0,64)|0;if(W){Ka=Ga;La=Ha;Ma=Ia;Na=Ja}else{Oa=Fa<<1;Pa=Oa|1;Qa=0;while(1){Ra=c[F>>2]|0;Sa=c[L>>2]|0;Ta=d[Sa+(Ra>>>3)|0]|0;Ua=c[C>>2]|0;Va=((Ra|0)<(Ua|0))+Ra|0;c[F>>2]=Va;c:do{if((Ta&128>>>((Ra&7)>>>0)|0)==0){if(B){Wa=117;break b}else{Wa=119}}else{Xa=d[Sa+(Va>>>3)|0]<<(Va&7)>>>7;Ya=((Va|0)<(Ua|0))+Va|0;c[F>>2]=Ya;Za=Xa&1;d:do{if((Za|0)==0){Xa=c[P>>2]|0;_a=Qa<<1;c[la>>2]=c[Y>>2];c[Y>>2]=c[(c[X>>2]|0)+(_a<<2)>>2];$a=cRa(s,ha,ia,ja,Z,_a,Oa,ka)|0;e:do{if(($a|0)==0){c[(c[X>>2]|0)+(_a<<2)>>2]=c[Z>>2];ab=Qa<<4;WQa(Xa+ab|0,c[(c[A>>2]|0)+32>>2]|0,ja);bb=_a|1;c[la>>2]=c[Y>>2];c[Y>>2]=c[(c[X>>2]|0)+(bb<<2)>>2];cb=cRa(s,ha,ia,ja,Z,bb,Oa,ka)|0;if((cb|0)!=0){db=cb;break}c[(c[X>>2]|0)+(bb<<2)>>2]=c[Z>>2];cb=bb<<3;WQa(Xa+cb|0,c[(c[A>>2]|0)+32>>2]|0,ja);eb=c[(c[A>>2]|0)+32>>2]<<3;c[ma>>2]=c[_>>2];c[_>>2]=c[(c[X>>2]|0)+(_a<<2)>>2];fb=cRa(s,ha,ia,ja,$,_a,Pa,ka)|0;if((fb|0)!=0){db=fb;break}c[(c[X>>2]|0)+(_a<<2)>>2]=c[$>>2];WQa(Xa+(eb+ab)|0,c[(c[A>>2]|0)+32>>2]|0,ja);c[ma>>2]=c[_>>2];c[_>>2]=c[(c[X>>2]|0)+(bb<<2)>>2];fb=cRa(s,ha,ia,ja,$,bb,Pa,ka)|0;if((fb|0)!=0){db=fb;break}c[(c[X>>2]|0)+(bb<<2)>>2]=c[$>>2];WQa(Xa+(eb+cb)|0,c[(c[A>>2]|0)+32>>2]|0,ja);cb=1;while(1){eb=cb+1|0;bb=w+1432+(eb<<4)+8|0;c[w+1432+(eb<<4)+4>>2]=c[bb>>2];fb=w+1408+(cb<<2)|0;c[bb>>2]=c[(c[fb>>2]|0)+(Qa<<2)>>2];bb=w+1432+(eb<<4)|0;gb=cRa(s,na,oa,ja,bb,Qa,Fa,pa)|0;if((gb|0)!=0){db=gb;break e}c[(c[fb>>2]|0)+(Qa<<2)>>2]=c[bb>>2];WQa(w+380+(cb<<8)|0,8,ja);bb=0;fb=(c[t+(cb<<2)>>2]|0)+ab|0;while(1){gb=bb<<2;hb=gb&-8;b[fb>>1]=(d[w+380+(cb<<8)+hb|0]|0)*257;b[fb+2>>1]=(d[(hb|1)+(w+380+(cb<<8))|0]|0)*257;b[fb+4>>1]=(d[(hb|2)+(w+380+(cb<<8))|0]|0)*257;b[fb+6>>1]=(d[(hb|3)+(w+380+(cb<<8))|0]|0)*257;b[fb+8>>1]=(d[(gb|4)+(w+380+(cb<<8))|0]|0)*257;b[fb+10>>1]=(d[(gb|5)+(w+380+(cb<<8))|0]|0)*257;b[fb+12>>1]=(d[(gb|6)+(w+380+(cb<<8))|0]|0)*257;b[fb+14>>1]=(d[(gb|7)+(w+380+(cb<<8))|0]|0)*257;gb=bb+1|0;if((gb|0)<16){bb=gb;fb=fb+(c[(c[A>>2]|0)+32+(cb<<2)>>2]|0)|0}else{break}}if((eb|0)<3){cb=eb}else{break d}}}else{db=$a}}while(0);if((db|0)<0){Wa=39;break b}}else if((Za|0)==1){TGb(qa|0,0,12)|0;TGb(ra|0,0,12)|0;TGb(sa|0,0,64)|0;$a=c[H>>2]|0;c[ua>>2]=ta;c[wa>>2]=va;c[ya>>2]=xa;Xa=0;_a=Ya;while(1){cb=0;ab=_a;while(1){if((cb|0)>=3){ib=ab;break}fb=d[Sa+(ab>>>3)|0]|0;bb=((ab|0)<(Ua|0))+ab|0;c[F>>2]=bb;if((fb&128>>>((ab&7)>>>0)|0)==0){ib=bb;break}else{cb=cb+1|0;ab=bb}}ab=(Xa|0)!=0|0;bb=a[142e3+(ab<<2)+cb|0]|0;fb=bb&255;c[l+(Xa<<2)>>2]=fb;if(bb<<24>>24==0){jb=ib}else{gb=w+84+(ab*20|0)|0;hb=w+84+(ab*20|0)+4|0;ab=0;kb=ib;while(1){lb=c[gb>>2]|0;mb=c[hb>>2]|0;nb=Sa+(kb>>>3)|0;ob=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(kb&7)>>>((32-lb|0)>>>0);nb=b[mb+(ob<<2)>>1]|0;pb=b[mb+(ob<<2)+2>>1]|0;ob=pb<<16>>16;if(pb<<16>>16<0){pb=kb+lb|0;lb=Ua>>>0>pb>>>0?pb:Ua;pb=Sa+(lb>>>3)|0;qb=((fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(lb&7)>>>((ob+32|0)>>>0))+nb|0;rb=b[mb+(qb<<2)+2>>1]|0;sb=b[mb+(qb<<2)>>1]|0;tb=lb}else{rb=ob;sb=nb;tb=kb}nb=rb+tb|0;ob=Ua>>>0>nb>>>0?nb:Ua;do{if((sb|0)==0){ub=0;vb=ob}else{nb=Sa+(ob>>>3)|0;lb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(ob&7)>>>((32-sb|0)>>>0);nb=ob+sb|0;qb=Ua>>>0>nb>>>0?nb:Ua;if((lb|0)>=(1<<sb-1|0)){ub=lb;vb=qb;break}ub=(-1<<sb)+1+lb|0;vb=qb}}while(0);ob=w+1496+(Xa<<4)+(ab<<2)|0;eb=(c[ob>>2]|0)+ub|0;a[k+(Xa<<2)+ab|0]=eb;c[ob>>2]=eb&255;eb=ab+1|0;if((eb|0)<(fb|0)){ab=eb;kb=vb}else{break}}c[F>>2]=vb;jb=vb}c[n+(Xa<<2)>>2]=(bb&255)>>>0>1>>>0;c[m+(Xa<<2)>>2]=(bb&255)>>>0>2>>>0?fb-2|0:0;kb=Xa+1|0;if((kb|0)<3){Xa=kb;_a=jb}else{break}}_a=($a|0)==100?0:2;Xa=8-_a|0;kb=32-Xa|0;ab=1;hb=0;gb=0;cb=jb;eb=Sa;ob=Ua;while(1){qb=((cb|0)<(ob|0))+cb|0;lb=(d[eb+(cb>>>3)|0]&128>>>((cb&7)>>>0)|0)==0;nb=d[eb+(qb>>>3)|0]|0;mb=((qb|0)<(ob|0))+qb|0;c[F>>2]=mb;pb=(128>>>((qb&7)>>>0)&nb|0)==0;f:do{if(lb){if(pb){wb=gb;xb=mb}else{nb=eb+(mb>>>3)|0;qb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(mb&7)>>>28;nb=mb+4|0;yb=ob>>>0>nb>>>0?nb:ob;c[F>>2]=yb;wb=((qb|0)>=(gb|0))+qb|0;xb=yb}if((wb|0)==0){zb=xb;Ab=eb;Bb=ob}else{yb=c[Ea>>2]|0;c[za>>2]=yb&7;c[Aa>>2]=yb>>>3&7;c[Ba>>2]=yb>>6;yb=(wb|0)>0;qb=0;do{if(yb){nb=o+(qb<<2)|0;Cb=c[l+(qb<<2)>>2]|0;Db=r+(qb<<2)|0;Eb=p+(qb<<2)|0;Fb=c[Db>>2]|0;Gb=0;Hb=Fb;while(1){Ib=c[nb>>2]|0;do{if((Ib|0)<(Cb|0)){Jb=a[k+(qb<<2)+Ib|0]|0}else{Kb=c[F>>2]|0;Lb=c[L>>2]|0;Mb=d[Lb+(Kb>>>3)|0]|0;Nb=c[C>>2]|0;Ob=((Kb|0)<(Nb|0))+Kb|0;c[F>>2]=Ob;if((Mb&128>>>((Kb&7)>>>0)|0)==0){Jb=c[Eb>>2]&255;break}else{Kb=Lb+(Ob>>>3)|0;Lb=(fe(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(Ob&7)>>>(kb>>>0);Kb=Ob+Xa|0;c[F>>2]=Nb>>>0>Kb>>>0?Kb:Nb;Nb=Lb<<_a;c[Eb>>2]=Nb;Jb=Nb&255;break}}}while(0);a[Hb]=Jb;c[q+(Gb<<2)>>2]=c[Aa>>2]<<3|c[za>>2]|c[Ba>>2]<<6;Ib=Gb+1|0;if((Ib|0)>=(wb|0)){break}Gb=Ib;Hb=Hb+1|0}c[Db>>2]=Fb+wb}qb=qb+1|0;}while((qb|0)<3);if((wb|0)==16){Pb=16;Qb=hb;break}zb=c[F>>2]|0;Ab=c[L>>2]|0;Bb=c[C>>2]|0}c[za>>2]=hb&7;c[Aa>>2]=hb>>>3&7;c[Ba>>2]=hb>>6;qb=d[Ab+(zb>>>3)|0]|0;c[F>>2]=((zb|0)<(Bb|0))+zb;if((qb&128>>>((zb&7)>>>0)|0)==0){Rb=hb}else{bRa(s,za,Ca,Da,za);Rb=c[Aa>>2]<<3|c[za>>2]|c[Ba>>2]<<6}qb=16-wb|0;yb=(qb|0)>0;Hb=0;while(1){if(yb){Gb=o+(Hb<<2)|0;Eb=c[l+(Hb<<2)>>2]|0;Cb=r+(Hb<<2)|0;nb=p+(Hb<<2)|0;Ib=c[Cb>>2]|0;Nb=0;Lb=Ib;while(1){Kb=c[Gb>>2]|0;do{if((Kb|0)<(Eb|0)){Sb=a[k+(Hb<<2)+Kb|0]|0}else{Ob=c[F>>2]|0;Mb=c[L>>2]|0;Tb=d[Mb+(Ob>>>3)|0]|0;Ub=c[C>>2]|0;Vb=((Ob|0)<(Ub|0))+Ob|0;c[F>>2]=Vb;if((Tb&128>>>((Ob&7)>>>0)|0)==0){Sb=c[nb>>2]&255;break}else{Ob=Mb+(Vb>>>3)|0;Mb=(fe(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Vb&7)>>>(kb>>>0);Ob=Vb+Xa|0;c[F>>2]=Ub>>>0>Ob>>>0?Ob:Ub;Ub=Mb<<_a;c[nb>>2]=Ub;Sb=Ub&255;break}}}while(0);a[Lb]=Sb;c[q+(Nb+wb<<2)>>2]=c[Aa>>2]<<3|c[za>>2]|c[Ba>>2]<<6;Kb=Nb+1|0;if((Kb|0)>=(qb|0)){break}Nb=Kb;Lb=Lb+1|0}c[Cb>>2]=Ib+qb}Lb=Hb+1|0;if((Lb|0)<3){Hb=Lb}else{Pb=wb;Qb=Rb;break}}}else{if(!pb){c[Ea>>2]=0;c[Ba>>2]=0;c[Aa>>2]=0;c[za>>2]=0;Hb=0;qb=eb;yb=ob;Lb=0;Nb=mb;while(1){nb=d[qb+(Nb>>>3)|0]|0;c[F>>2]=((Nb|0)<(yb|0))+Nb;if((nb&128>>>((Nb&7)>>>0)|0)==0){Wb=qb;Xb=yb;Yb=Lb}else{bRa(s,za,Ca,Da,za);Wb=c[L>>2]|0;Xb=c[C>>2]|0;Yb=c[za>>2]|0}do{if((Yb|0)<(c[l>>2]|0)){Zb=a[k+Yb|0]|0}else{nb=c[F>>2]|0;Eb=d[Wb+(nb>>>3)|0]|0;Gb=((nb|0)<(Xb|0))+nb|0;c[F>>2]=Gb;if((Eb&128>>>((nb&7)>>>0)|0)==0){Zb=c[p>>2]&255;break}else{nb=Wb+(Gb>>>3)|0;Eb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Gb&7)>>>(kb>>>0);nb=Gb+Xa|0;c[F>>2]=Xb>>>0>nb>>>0?nb:Xb;nb=Eb<<_a;c[p>>2]=nb;Zb=nb&255;break}}}while(0);Ib=c[ua>>2]|0;c[ua>>2]=Ib+1;a[Ib]=Zb;Ib=c[Aa>>2]|0;do{if((Ib|0)<(c[l+4>>2]|0)){_b=a[k+4+Ib|0]|0}else{Cb=c[F>>2]|0;nb=d[Wb+(Cb>>>3)|0]|0;Eb=((Cb|0)<(Xb|0))+Cb|0;c[F>>2]=Eb;if((nb&128>>>((Cb&7)>>>0)|0)==0){_b=c[p+4>>2]&255;break}else{Cb=Wb+(Eb>>>3)|0;nb=(fe(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0)<<(Eb&7)>>>(kb>>>0);Cb=Eb+Xa|0;c[F>>2]=Xb>>>0>Cb>>>0?Cb:Xb;Cb=nb<<_a;c[p+4>>2]=Cb;_b=Cb&255;break}}}while(0);Cb=c[wa>>2]|0;c[wa>>2]=Cb+1;a[Cb]=_b;Cb=c[Ba>>2]|0;do{if((Cb|0)<(c[l+8>>2]|0)){$b=a[k+8+Cb|0]|0}else{nb=c[F>>2]|0;Eb=d[Wb+(nb>>>3)|0]|0;Gb=((nb|0)<(Xb|0))+nb|0;c[F>>2]=Gb;if((Eb&128>>>((nb&7)>>>0)|0)==0){$b=c[p+8>>2]&255;break}else{nb=Wb+(Gb>>>3)|0;Eb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Gb&7)>>>(kb>>>0);nb=Gb+Xa|0;c[F>>2]=Xb>>>0>nb>>>0?nb:Xb;nb=Eb<<_a;c[p+8>>2]=nb;$b=nb&255;break}}}while(0);nb=c[ya>>2]|0;c[ya>>2]=nb+1;a[nb]=$b;c[q+(Hb<<2)>>2]=Ib<<3|Yb|Cb<<6;nb=Hb+1|0;if((nb|0)>=16){Pb=gb;Qb=hb;break f}Hb=nb;qb=Wb;yb=Xb;Lb=Yb;Nb=c[F>>2]|0}}Nb=d[eb+(mb>>>3)|0]|0;Lb=((mb|0)<(ob|0))+mb|0;c[F>>2]=Lb;if((Nb&128>>>((mb&7)>>>0)|0)==0){ac=0;bc=0}else{Nb=eb+(Lb>>>3)|0;yb=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Lb&7)>>>28;Nb=Lb+4|0;c[F>>2]=ob>>>0>Nb>>>0?Nb:ob;ac=yb;bc=1}yb=0;Nb=eb;Lb=ob;while(1){qb=q+(yb<<2)|0;Hb=c[qb>>2]|0;nb=Hb&7;c[za>>2]=nb;c[Aa>>2]=Hb>>>3&7;c[Ba>>2]=Hb>>6;if(bc&(yb|0)==(ac|0)){bRa(s,za,Ca,Da,za);cc=c[L>>2]|0;dc=c[C>>2]|0;ec=c[za>>2]|0}else{cc=Nb;dc=Lb;ec=nb}do{if((ec|0)<(c[l>>2]|0)){fc=a[k+ec|0]|0}else{nb=c[F>>2]|0;Hb=d[cc+(nb>>>3)|0]|0;Eb=((nb|0)<(dc|0))+nb|0;c[F>>2]=Eb;if((Hb&128>>>((nb&7)>>>0)|0)==0){fc=c[p>>2]&255;break}else{nb=cc+(Eb>>>3)|0;Hb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Eb&7)>>>(kb>>>0);nb=Eb+Xa|0;c[F>>2]=dc>>>0>nb>>>0?nb:dc;nb=Hb<<_a;c[p>>2]=nb;fc=nb&255;break}}}while(0);Cb=c[ua>>2]|0;c[ua>>2]=Cb+1;a[Cb]=fc;Cb=c[Aa>>2]|0;do{if((Cb|0)<(c[l+4>>2]|0)){gc=a[k+4+Cb|0]|0}else{Ib=c[F>>2]|0;nb=d[cc+(Ib>>>3)|0]|0;Hb=((Ib|0)<(dc|0))+Ib|0;c[F>>2]=Hb;if((nb&128>>>((Ib&7)>>>0)|0)==0){gc=c[p+4>>2]&255;break}else{Ib=cc+(Hb>>>3)|0;nb=(fe(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)|0)<<(Hb&7)>>>(kb>>>0);Ib=Hb+Xa|0;c[F>>2]=dc>>>0>Ib>>>0?Ib:dc;Ib=nb<<_a;c[p+4>>2]=Ib;gc=Ib&255;break}}}while(0);Ib=c[wa>>2]|0;c[wa>>2]=Ib+1;a[Ib]=gc;Ib=c[Ba>>2]|0;do{if((Ib|0)<(c[l+8>>2]|0)){hc=a[k+8+Ib|0]|0}else{nb=c[F>>2]|0;Hb=d[cc+(nb>>>3)|0]|0;Eb=((nb|0)<(dc|0))+nb|0;c[F>>2]=Eb;if((Hb&128>>>((nb&7)>>>0)|0)==0){hc=c[p+8>>2]&255;break}else{nb=cc+(Eb>>>3)|0;Hb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Eb&7)>>>(kb>>>0);nb=Eb+Xa|0;c[F>>2]=dc>>>0>nb>>>0?nb:dc;nb=Hb<<_a;c[p+8>>2]=nb;hc=nb&255;break}}}while(0);nb=c[ya>>2]|0;c[ya>>2]=nb+1;a[nb]=hc;c[qb>>2]=Cb<<3|ec|Ib<<6;nb=yb+1|0;if((nb|0)<16){yb=nb;Nb=cc;Lb=dc}else{Pb=gb;Qb=hb;break}}}}while(0);if((ab|0)>=16){break}ab=ab+1|0;hb=Qb;gb=Pb;cb=c[F>>2]|0;eb=c[L>>2]|0;ob=c[C>>2]|0}ob=Qa<<4;eb=c[P>>2]|0;cb=0;do{UGb(eb+((ba(c[(c[A>>2]|0)+32>>2]|0,cb)|0)+ob)|0,(cb<<4)+(w+380)|0,16)|0;cb=cb+1|0;}while((cb|0)<16);cb=c[R>>2]|0;eb=0;do{UGb(cb+((ba(c[(c[A>>2]|0)+36>>2]|0,eb)|0)+ob)|0,(eb<<4)+(w+636)|0,16)|0;eb=eb+1|0;}while((eb|0)<16);eb=c[T>>2]|0;cb=0;do{UGb(eb+((ba(c[(c[A>>2]|0)+40>>2]|0,cb)|0)+ob)|0,(cb<<4)+(w+892)|0,16)|0;cb=cb+1|0;}while((cb|0)<16)}else{Wa=119;break c}}while(0);if((Za|0)!=0){Wa=119}}}while(0);if((Wa|0)==119){Wa=0;Ua=Qa<<1;Sa=c[X>>2]|0;c[Y>>2]=c[Sa+((Ua|1)<<2)>>2];c[Z>>2]=0;c[_>>2]=0;c[$>>2]=0;Va=Sa+(Ua<<2)|0;c[Va>>2]=0;c[Va+4>>2]=0;Va=(c[aa>>2]|0)+(Qa<<2)|0;c[ca>>2]=c[Va>>2];c[da>>2]=0;c[Va>>2]=0;Va=(c[ea>>2]|0)+(Qa<<2)|0;c[fa>>2]=c[Va>>2];c[ga>>2]=0;c[Va>>2]=0}Va=Qa+1|0;if((Va|0)<(M|0)){Qa=Va}else{break}}Ka=c[A>>2]|0;La=c[P>>2]|0;Ma=c[R>>2]|0;Na=c[T>>2]|0}Pa=La+(c[Ka+32>>2]<<4)|0;c[P>>2]=Pa;Oa=Ma+(c[Ka+36>>2]<<4)|0;c[R>>2]=Oa;Va=Na+(c[Ka+40>>2]<<4)|0;c[T>>2]=Va;Ua=Fa+1|0;if((Ua|0)<(N|0)){Fa=Ua;Ga=Ka;Ha=Pa;Ia=Oa;Ja=Va}else{U=Ka;break a}}if((Wa|0)==39){yDb(e,16,1938760,(x=i,i=i+16|0,c[x>>2]=Qa,c[x+8>>2]=Fa,x)|0);i=x;y=-1094995529;i=j;return y|0}else if((Wa|0)==117){yDb(e,16,1894048,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=j;return y|0}}}while(0);N=MCb(f,U)|0;if((N|0)<0){y=N;i=j;return y|0}c[g>>2]=1;y=v;i=j;return y|0}}while(0);yDb(e,16,2107456,(x=i,i=i+16|0,c[x>>2]=D,c[x+8>>2]=E,x)|0);i=x;y=-1094995529;i=j;return y|0}function ZQa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b);$Db(b+1408|0);$Db(b+1412|0);$Db(b+1416|0);_Qa(b);return 0}function _Qa(a){a=a|0;Q_(a+4|0);Q_(a+44|0);Q_(a+84|0);Q_(a+24|0);Q_(a+64|0);Q_(a+104|0);return}function $Qa(a){a=a|0;var b=0,e=0,f=0;b=a+8|0;e=c[b>>2]|0;f=(d[(c[a>>2]|0)+(e>>>3)|0]|0)<<(e&7)>>>7;c[b>>2]=((e|0)<(c[a+16>>2]|0))+e;return f&1|0}function aRa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(f>>>3)|0;a=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(f&7)>>>((32-b|0)>>>0);h=f+b|0;c[e>>2]=g>>>0>h>>>0?h:g;return a|0}function bRa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;do{if((c[d+8>>2]|0)==0){c[b+8>>2]=0;g=0}else{if(($Qa(a)|0)==0){c[b+8>>2]=c[f+8>>2];g=0;break}h=c[e+8>>2]|0;i=c[f+8>>2]|0;if((h|0)<=0){c[b+8>>2]=(i|0)==0;g=1;break}j=aRa(a,h)|0;h=b+8|0;c[h>>2]=j;if((j|0)<(i|0)){g=1;break}c[h>>2]=j+1;g=1}}while(0);do{if((c[d+4>>2]|0)==0){c[b+4>>2]=0;k=g}else{if(($Qa(a)|0)==0){c[b+4>>2]=c[f+4>>2];k=g;break}j=c[e+4>>2]|0;h=c[f+4>>2]|0;if((j|0)<=0){c[b+4>>2]=(h|0)==0;k=1;break}i=aRa(a,j)|0;j=b+4|0;c[j>>2]=i;if((i|0)<(h|0)){k=1;break}c[j>>2]=i+1;k=1}}while(0);if((c[d>>2]|0)==0){c[b>>2]=0;return}do{if((k|0)!=0){if(($Qa(a)|0)!=0){break}c[b>>2]=c[f>>2];return}}while(0);k=c[e>>2]|0;e=c[f>>2]|0;if((k|0)<=0){c[b>>2]=(e|0)==0;return}f=aRa(a,k)|0;c[b>>2]=f;if((f|0)<(e|0)){return}c[b>>2]=f+1;return}function cRa(a,f,g,h,i,j,k,l){a=a|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;TGb(h|0,0,256)|0;m=c[f>>2]|0;n=c[f+4>>2]|0;f=a+8|0;o=c[f>>2]|0;p=a+16|0;q=c[p>>2]|0;r=c[a>>2]|0;a=r+(o>>>3)|0;s=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(o&7)>>>((32-m|0)>>>0);a=b[n+(s<<2)>>1]|0;t=b[n+(s<<2)+2>>1]|0;s=t<<16>>16;if(t<<16>>16<0){t=o+m|0;m=q>>>0>t>>>0?t:q;t=r+(m>>>3)|0;u=((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(m&7)>>>((s+32|0)>>>0))+a|0;v=b[n+(u<<2)+2>>1]|0;w=b[n+(u<<2)>>1]|0;x=m}else{v=s;w=a;x=o}o=v+x|0;x=q>>>0>o>>>0?o:q;c[f>>2]=x;do{if((w|0)==0){y=0}else{o=r+(x>>>3)|0;v=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(x&7)>>>((32-w|0)>>>0);o=x+w|0;c[f>>2]=q>>>0>o>>>0?o:q;if((v|0)>=(1<<w-1|0)){y=v;break}y=(-1<<w)+1+v|0}}while(0);w=(j|0)!=0;do{if((k|0)==0){if(!w){z=y;break}z=(c[i>>2]|0)+y|0}else{if(!w){z=(c[i+8>>2]|0)+y|0;break}j=c[i>>2]|0;q=c[i+4>>2]|0;x=c[i+8>>2]|0;v=x-q|0;o=j-q|0;if((((v|0)>-1?v:-v|0)|0)>(((o|0)>-1?o:-o|0)|0)){z=x+y|0;break}else{z=j+y|0;break}}}while(0);c[i>>2]=z;c[h>>2]=ba(e[l>>1]|0,z)|0;z=c[g+4>>2]|0;g=1;while(1){i=c[f>>2]|0;y=c[p>>2]|0;w=r+(i>>>3)|0;k=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(i&7)>>>23;w=b[z+(k<<2)>>1]|0;j=b[z+(k<<2)+2>>1]|0;k=j<<16>>16;if(j<<16>>16<0){j=i+9|0;x=y>>>0>j>>>0?j:y;j=r+(x>>>3)|0;o=((fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(x&7)>>>((k+32|0)>>>0))+w|0;A=b[z+(o<<2)+2>>1]|0;B=b[z+(o<<2)>>1]|0;C=x}else{A=k;B=w;C=i}i=A+C|0;w=y>>>0>i>>>0?i:y;c[f>>2]=w;if((B|0)==(-1|0)){D=-1;E=27;break}else if((B|0)==0){F=0;E=26;break}else if((B|0)==240){G=g+16|0}else{i=B>>4;k=B&15;do{if((k|0)==0){H=0}else{x=r+(w>>>3)|0;o=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(w&7)>>>((32-k|0)>>>0);x=w+k|0;c[f>>2]=y>>>0>x>>>0?x:y;if((o|0)>=(1<<k-1|0)){H=o;break}H=(-1<<k)+1+o|0}}while(0);k=i+g|0;if((k|0)>63){F=-1;E=26;break}y=d[1075976+k|0]|0;c[h+(y<<2)>>2]=ba(e[l+(y<<1)>>1]|0,H)|0;G=k+1|0}if((G|0)<64){g=G}else{E=25;break}}if((E|0)==25){D=((G|0)!=64)<<31>>31;return D|0}else if((E|0)==26){D=F;return D|0}else if((E|0)==27){return D|0}return 0}function dRa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b>>2]=a;d=b+16|0;do{if((c[a+792>>2]|0)==8){c[d>>2]=1;c[a+140>>2]=11;if((c[a+100>>2]|0)<=1023){break}UGb(b+20|0,c[a+96>>2]|0,1024)|0}else{c[d>>2]=0;c[a+140>>2]=46}}while(0);a=ICb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function eRa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;j=i;i=i+24|0;k=j|0;l=j+16|0;m=c[h+28>>2]|0;n=c[e+60>>2]|0;o=n+8|0;c[o>>2]=c[h+24>>2];p=n+12|0;c[p>>2]=m;q=n+4|0;r=$$a(e,c[q>>2]|0)|0;if((r|0)<0){s=r;i=j;return s|0}r=n+16|0;a:do{if((c[r>>2]|0)==0){t=33}else{e=HZ(h,0,0)|0;if((e|0)!=0){UGb(n+20|0,e|0,1024)|0;c[(c[q>>2]|0)+304>>2]=1}if((c[r>>2]|0)==0){t=33;break}e=l;u=l;v=c[q>>2]|0;w=c[v>>2]|0;x=c[v+32>>2]|0;v=n;y=c[v>>2]|0;z=c[y+120>>2]|0;A=(z|0)/4|0;B=c[y+124>>2]|0;C=(B|0)/4|0;do{if((B|0)>3){D=(z|0)>3;E=u+1|0;F=-4-x+4|0;G=x*-2|0;H=x*-3|0;I=C;J=0;K=ba(C,A)|0;L=0;M=0;b:while(1){if(D){N=ba((C-M<<2)-1|0,x)|0;O=A;P=J;Q=K;R=L;S=ba((I<<2)-1|0,x)|0;T=0;while(1){U=N+(T<<2)|0;c:do{if((R|0)==0){V=P+2|0;W=c[p>>2]|0;if((V|0)>(W|0)){t=13;break b}X=c[o>>2]|0;Y=a[X+P|0]|0;Z=a[X+(P+1)|0]|0;_=Y&255;if((Z|Y)<<24>>24==0&(Q|0)==0){break a}$=Z&255;if(($&252|0)==132){aa=(($<<8)-33792|_)-1|0;ca=V;break}if(Z<<24>>24>-1){da=P+4|0;if((da|0)>(W|0)){t=19;break b}a[e]=a[X+V|0]|0;a[E]=a[X+(P+3)|0]|0;ea=0;fa=($<<8|_)&65535;ga=S;while(1){a[w+ga|0]=a[u+(fa&1^1)|0]|0;a[w+(ga+1)|0]=a[u+((fa&65535)>>>1&1^1)|0]|0;a[w+(ga+2)|0]=a[u+((fa&65535)>>>2&1^1)|0]|0;a[w+(ga+3)|0]=a[u+((fa&65535)>>>3&1^1)|0]|0;ha=ea+1|0;if((ha|0)<4){ea=ha;fa=(fa&65535)>>>4;ga=F+ga|0}else{aa=0;ca=da;break c}}}if(!((Z&255)>>>0>143>>>0)){a[e]=Y;TGb(w+U|0,Y|0,4)|0;TGb(w+(U-x)|0,Y|0,4)|0;TGb(w+(U+G)|0,Y|0,4)|0;TGb(w+(U+H)|0,Y|0,4)|0;aa=0;ca=V;break}ia=P+10|0;if((ia|0)>(W|0)){t=24;break b}ga=X+V|0;fa=ga|0;ea=ga+4|0;ga=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0;c[l>>2]=d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24;c[l+4>>2]=ga;ga=0;fa=($<<8|_)&65535;ea=S;while(1){ha=ga<<1&4;a[w+ea|0]=a[u+((ha|fa&1)^1)|0]|0;a[w+(ea+1)|0]=a[u+((ha|(fa&65535)>>>1&1)^1)|0]|0;ja=ha|2;a[w+(ea+2)|0]=a[u+((ja|(fa&65535)>>>2&1)^1)|0]|0;a[w+(ea+3)|0]=a[u+((ja|(fa&65535)>>>3&1)^1)|0]|0;ja=ga+1|0;if((ja|0)<4){ga=ja;fa=(fa&65535)>>>4;ea=F+ea|0}else{aa=0;ca=ia;break}}}else{aa=R-1|0;ca=P}}while(0);U=Q-1|0;ea=O-1|0;if((ea|0)>0){O=ea;P=ca;Q=U;R=aa;S=S+4|0;T=T+1|0}else{ka=ca;la=U;ma=aa;break}}}else{ka=J;la=K;ma=L}T=I-1|0;if((T|0)>0){I=T;J=ka;K=la;L=ma;M=M+1|0}else{t=30;break}}if((t|0)==13){yDb(c[v>>2]|0,16,2184272,(na=i,i=i+16|0,c[na>>2]=V,c[na+8>>2]=W,na)|0);i=na;break a}else if((t|0)==19){yDb(c[v>>2]|0,16,2184272,(na=i,i=i+16|0,c[na>>2]=da,c[na+8>>2]=W,na)|0);i=na;break a}else if((t|0)==24){yDb(c[v>>2]|0,16,2184272,(na=i,i=i+16|0,c[na>>2]=ia,c[na+8>>2]=W,na)|0);i=na;break a}else if((t|0)==30){oa=c[v>>2]|0;break}}else{oa=y}}while(0);if((c[oa+140>>2]|0)!=11){break}UGb(c[(c[q>>2]|0)+4>>2]|0,n+20|0,1024)|0}}while(0);d:do{if((t|0)==33){oa=c[q>>2]|0;W=c[oa>>2]|0;ia=(c[oa+32>>2]|0)/2|0;oa=c[n>>2]|0;da=c[oa+120>>2]|0;V=(da|0)/4|0;ma=c[oa+124>>2]|0;la=(ma|0)/4|0;if((ma|0)<=3){break}ma=(da|0)>3;da=k|0;ka=k+2|0;aa=k+4|0;ca=k+6|0;l=k+8|0;r=k+10|0;h=k+12|0;y=k+14|0;v=-4-ia+4|0;u=la;w=0;x=ba(la,V)|0;la=0;e:while(1){if(ma){e=V;A=w;C=x;z=la;B=ba((u<<2)-1|0,ia)|0;while(1){f:do{if((z|0)==0){pa=A+2|0;qa=c[p>>2]|0;if((pa|0)>(qa|0)){t=40;break e}M=c[o>>2]|0;L=a[M+A|0]|0;K=a[M+(A+1)|0]|0;J=L&255;if((K|L)<<24>>24==0&(C|0)==0){break d}L=K&255;if((L&252|0)==132){ra=((L<<8)-33792|J)-1|0;sa=pa;break}I=(L<<8|J)&65535;if(!(K<<24>>24>-1)){b[da>>1]=I;b[W+(B<<1)>>1]=I;b[W+(B+1<<1)>>1]=I;b[W+(B+2<<1)>>1]=I;b[W+(B+3<<1)>>1]=I;K=v+B|0;b[W+(K<<1)>>1]=I;b[W+(K+1<<1)>>1]=I;b[W+(K+2<<1)>>1]=I;b[W+(K+3<<1)>>1]=I;J=v+K|0;b[W+(J<<1)>>1]=I;b[W+(J+1<<1)>>1]=I;b[W+(J+2<<1)>>1]=I;b[W+(J+3<<1)>>1]=I;K=v+J|0;b[W+(K<<1)>>1]=I;b[W+(K+1<<1)>>1]=I;b[W+(K+2<<1)>>1]=I;b[W+(K+3<<1)>>1]=I;ra=0;sa=pa;break}ta=A+6|0;if((ta|0)>(qa|0)){t=46;break e}K=M+pa|0;J=(d[K]|d[K+1|0]<<8)<<16>>16;b[da>>1]=J;K=M+(A+4)|0;b[ka>>1]=(d[K]|d[K+1|0]<<8)<<16>>16;if(!(J<<16>>16<0)){J=0;K=I;L=B;while(1){b[W+(L<<1)>>1]=b[k+((K&1^1)<<1)>>1]|0;b[W+(L+1<<1)>>1]=b[k+(((K&65535)>>>1&1^1)<<1)>>1]|0;b[W+(L+2<<1)>>1]=b[k+(((K&65535)>>>2&1^1)<<1)>>1]|0;b[W+(L+3<<1)>>1]=b[k+(((K&65535)>>>3&1^1)<<1)>>1]|0;F=J+1|0;if((F|0)<4){J=F;K=(K&65535)>>>4;L=v+L|0}else{ra=0;sa=ta;break f}}}ua=A+18|0;if((ua|0)>(qa|0)){t=49;break e}L=M+ta|0;b[aa>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+8)|0;b[ca>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+10)|0;b[l>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+12)|0;b[r>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+14)|0;b[h>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+16)|0;b[y>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=0;K=I;J=B;while(1){F=L<<1&4;b[W+(J<<1)>>1]=b[k+(((F|K&1)^1)<<1)>>1]|0;b[W+(J+1<<1)>>1]=b[k+(((F|(K&65535)>>>1&1)^1)<<1)>>1]|0;H=F|2;b[W+(J+2<<1)>>1]=b[k+(((H|(K&65535)>>>2&1)^1)<<1)>>1]|0;b[W+(J+3<<1)>>1]=b[k+(((H|(K&65535)>>>3&1)^1)<<1)>>1]|0;H=L+1|0;if((H|0)<4){L=H;K=(K&65535)>>>4;J=v+J|0}else{ra=0;sa=ua;break}}}else{ra=z-1|0;sa=A}}while(0);J=C-1|0;K=e-1|0;if((K|0)>0){e=K;A=sa;C=J;z=ra;B=B+4|0}else{va=sa;wa=J;xa=ra;break}}}else{va=w;wa=x;xa=la}B=u-1|0;if((B|0)>0){u=B;w=va;x=wa;la=xa}else{break d}}if((t|0)==40){yDb(oa,16,2184272,(na=i,i=i+16|0,c[na>>2]=pa,c[na+8>>2]=qa,na)|0);i=na;break}else if((t|0)==46){yDb(oa,16,2184272,(na=i,i=i+16|0,c[na>>2]=ta,c[na+8>>2]=qa,na)|0);i=na;break}else if((t|0)==49){yDb(oa,16,2184272,(na=i,i=i+16|0,c[na>>2]=ua,c[na+8>>2]=qa,na)|0);i=na;break}}}while(0);na=MCb(f,c[q>>2]|0)|0;if((na|0)<0){s=na;i=j;return s|0}c[g>>2]=1;s=m;i=j;return s|0}function fRa(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function gRa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;e=a+120|0;f=a+124|0;g=a;if((hDb(c[e>>2]|0,c[f>>2]|0,0,g)|0)<0){h=-1;i=b;return h|0}do{if((c[e>>2]&3|0)==0){if((c[f>>2]&3|0)!=0){break}c[a+792>>2]=16;c[d+1244>>2]=c[a+360>>2];oDb(d+4|0,1);h=0;i=b;return h|0}}while(0);yDb(g,16,2184224,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1;i=b;return h|0}function hRa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;i=c[b+60>>2]|0;j=b+120|0;k=b+124|0;l=(ba((c[j>>2]|0)*9|0,c[k>>2]|0)|0)+16384|0;m=r0a(b,f,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){n=m;return n|0}m=c[f+24>>2]|0;l=i+264|0;o=c[l>>2]|0;if((o|0)==0){p=WDb(ba((c[j>>2]|0)*3|0,(c[k>>2]|0)+3|0)|0)|0;c[l>>2]=p;q=p}else{q=o}o=c[k>>2]|0;p=(o+3&-4)-1|0;l=g+32|0;r=i+1244|0;s=(c[r>>2]|0)<(c[b+360>>2]|0);b=s&1^1;do{if((o|0)>0){t=c[l>>2]|0;u=c[j>>2]|0;v=ba(p,t)|0;w=i+460|0;y=w;z=i+268|0;A=z;B=z;z=i+1228|0;C=z;D=i+844|0;E=D;F=D;G=i+4|0;H=i+652|0;I=H;J=H;K=i+904|0;L=w;w=i+748|0;M=w;N=i+1036|0;O=N;P=N;N=i+1096|0;Q=w;w=i+1232|0;R=i+1236|0;S=i+752|0;T=i+756|0;U=i+656|0;V=i+660|0;W=i+664|0;X=i+668|0;Y=i+672|0;Z=m;_=0;$=0;aa=1;ca=q+(ba(u*3|0,p)|0)|0;da=(c[g>>2]|0)+v|0;v=u;u=t;t=o;while(1){if((v|0)>0){ea=Z;fa=0;ga=$;ha=aa;while(1){ia=0;do{ja=ia<<2;ka=0;do{la=e[da+(ka+fa+((ba(c[l>>2]|0,ia)|0)/-2|0)<<1)>>1]|0;ma=ka+ja|0;na=(c[549072+(ma<<2)>>2]|0)*3|0;oa=ma*3|0;ma=la>>>10&31;c[y+(na<<2)>>2]=ma;c[A+(oa<<2)>>2]=ma;ma=la>>>5&31;c[y+(na+1<<2)>>2]=ma;c[A+(oa+1<<2)>>2]=ma;ma=la&31;c[y+(na+2<<2)>>2]=ma;c[A+(oa+2<<2)>>2]=ma;ka=ka+1|0;}while((ka|0)<4);ia=ia+1|0;}while((ia|0)<4);if(s){ia=fa*3|0;ka=c[j>>2]|0;ja=0;ma=0;while(1){oa=(d[ca+(ma+ia)|0]|0)-(c[A+(ma<<2)>>2]|0)|0;na=(ba(oa,oa)|0)+ja|0;oa=ma+1|0;if((oa|0)<12){ja=na;ma=oa}else{pa=na;qa=0;break}}while(1){ma=(d[ca+(qa+ia+(ka*-3|0))|0]|0)-(c[A+(qa+12<<2)>>2]|0)|0;ja=(ba(ma,ma)|0)+pa|0;ma=qa+1|0;if((ma|0)<12){pa=ja;qa=ma}else{ra=ja;sa=0;break}}while(1){ja=(d[ca+(sa+ia+(ka*-6|0))|0]|0)-(c[A+(sa+24<<2)>>2]|0)|0;ma=(ba(ja,ja)|0)+ra|0;ja=sa+1|0;if((ja|0)<12){ra=ma;sa=ja}else{ta=ma;ua=0;break}}do{ma=(d[ca+(ua+ia+(ka*-9|0))|0]|0)-(c[A+(ua+36<<2)>>2]|0)|0;ta=(ba(ma,ma)|0)+ta|0;ua=ua+1|0;}while((ua|0)<12);va=(ta|0)/24|0}else{va=2147483647}D8(B,3,16,C,1,1,F,G);E8(B,3,16,C,1,1,F,G);ka=c[C>>2]|0;if((ka|0)==1){c[C>>2]=0;wa=0}else{wa=ka}ka=i+1232|0;ia=c[ka>>2]|0;ma=i+1236|0;ja=c[ma>>2]|0;na=0;oa=0;do{la=oa<<2;xa=z;ya=oa*12|0;za=wa-(c[A+(ya<<2)>>2]|0)|0;Aa=(ba(za,za)|0)+na|0;za=ia-(c[A+((ya|1)<<2)>>2]|0)|0;Ba=(ba(za,za)|0)+Aa|0;Aa=ja-(c[A+((ya|2)<<2)>>2]|0)|0;ya=(ba(Aa,Aa)|0)+Ba|0;Ba=(la|1)*3|0;Aa=wa-(c[A+(Ba<<2)>>2]|0)|0;za=(ba(Aa,Aa)|0)+ya|0;ya=ia-(c[A+(Ba+1<<2)>>2]|0)|0;Aa=(ba(ya,ya)|0)+za|0;za=ja-(c[A+(Ba+2<<2)>>2]|0)|0;Ba=(ba(za,za)|0)+Aa|0;Aa=(la|2)*3|0;za=wa-(c[A+(Aa<<2)>>2]|0)|0;ya=(ba(za,za)|0)+Ba|0;Ba=ia-(c[A+((Aa|1)<<2)>>2]|0)|0;za=(ba(Ba,Ba)|0)+ya|0;ya=ja-(c[A+(Aa+2<<2)>>2]|0)|0;Aa=(ba(ya,ya)|0)+za|0;za=(la|3)*3|0;la=wa-(c[A+(za<<2)>>2]|0)|0;ya=(ba(la,la)|0)+Aa|0;Aa=ia-(c[A+(za+1<<2)>>2]|0)|0;la=(ba(Aa,Aa)|0)+ya|0;ya=ja-(c[A+(za+2<<2)>>2]|0)|0;na=(ba(ya,ya)|0)+la|0;oa=oa+1|0;}while((oa|0)<4);oa=((na|0)/24|0)+2|0;ja=(oa|0)<(va|0);ia=ja&1;la=ja?oa:va;D8(B,3,16,J,2,1,F,G);E8(B,3,16,J,2,1,F,G);if((c[K>>2]|0)==0){oa=i+664|0;ja=c[oa>>2]|0;ya=H;c[oa>>2]=c[ya>>2];c[ya>>2]=ja&255;ja=i+668|0;ya=c[ja>>2]|0;oa=i+656|0;c[ja>>2]=c[oa>>2];c[oa>>2]=ya&255;ya=i+672|0;oa=c[ya>>2]|0;ja=i+660|0;c[ya>>2]=c[ja>>2];c[ja>>2]=oa&255;oa=D;c[oa>>2]=c[oa>>2]^1;oa=i+848|0;c[oa>>2]=c[oa>>2]^1;oa=i+852|0;c[oa>>2]=c[oa>>2]^1;oa=i+856|0;c[oa>>2]=c[oa>>2]^1;oa=i+860|0;c[oa>>2]=c[oa>>2]^1;oa=i+864|0;c[oa>>2]=c[oa>>2]^1;oa=i+868|0;c[oa>>2]=c[oa>>2]^1;oa=i+872|0;c[oa>>2]=c[oa>>2]^1;oa=i+876|0;c[oa>>2]=c[oa>>2]^1;oa=i+880|0;c[oa>>2]=c[oa>>2]^1;oa=i+884|0;c[oa>>2]=c[oa>>2]^1;oa=i+888|0;c[oa>>2]=c[oa>>2]^1;oa=i+892|0;c[oa>>2]=c[oa>>2]^1;oa=i+896|0;c[oa>>2]=c[oa>>2]^1;oa=i+900|0;c[oa>>2]=c[oa>>2]^1;c[i+904>>2]=1;Ca=0;Da=0}else{Ca=0;Da=0}do{oa=Da<<2;ja=Da*12|0;ya=(c[E+(oa<<2)>>2]|0)*3|0;za=(c[I+(ya<<2)>>2]|0)-(c[A+(ja<<2)>>2]|0)|0;Aa=(ba(za,za)|0)+Ca|0;za=(c[I+(ya+1<<2)>>2]|0)-(c[A+((ja|1)<<2)>>2]|0)|0;Ba=(ba(za,za)|0)+Aa|0;Aa=(c[I+(ya+2<<2)>>2]|0)-(c[A+((ja|2)<<2)>>2]|0)|0;ya=(ba(Aa,Aa)|0)+Ba|0;Ba=(c[E+((oa|1)<<2)>>2]|0)*3|0;Aa=ja|3;za=(c[I+(Ba<<2)>>2]|0)-(c[A+(Aa<<2)>>2]|0)|0;Ea=(ba(za,za)|0)+ya|0;ya=(c[I+(Ba+1<<2)>>2]|0)-(c[A+(Aa+1<<2)>>2]|0)|0;za=(ba(ya,ya)|0)+Ea|0;Ea=(c[I+(Ba+2<<2)>>2]|0)-(c[A+(Aa+2<<2)>>2]|0)|0;Aa=(ba(Ea,Ea)|0)+za|0;za=(c[E+((oa|2)<<2)>>2]|0)*3|0;Ea=(c[I+(za<<2)>>2]|0)-(c[A+(ja+6<<2)>>2]|0)|0;Ba=(ba(Ea,Ea)|0)+Aa|0;Aa=(c[I+(za+1<<2)>>2]|0)-(c[A+(ja+7<<2)>>2]|0)|0;Ea=(ba(Aa,Aa)|0)+Ba|0;Ba=(c[I+(za+2<<2)>>2]|0)-(c[A+(ja+8<<2)>>2]|0)|0;za=(ba(Ba,Ba)|0)+Ea|0;Ea=(c[E+((oa|3)<<2)>>2]|0)*3|0;oa=(c[I+(Ea<<2)>>2]|0)-(c[A+(ja+9<<2)>>2]|0)|0;Ba=(ba(oa,oa)|0)+za|0;za=(c[I+(Ea+1<<2)>>2]|0)-(c[A+(ja+10<<2)>>2]|0)|0;oa=(ba(za,za)|0)+Ba|0;Ba=(c[I+(Ea+2<<2)>>2]|0)-(c[A+(ja+11<<2)>>2]|0)|0;Ca=(ba(Ba,Ba)|0)+oa|0;Da=Da+1|0;}while((Da|0)<4);na=((Ca|0)/24|0)+6|0;oa=(na|0)<(la|0);Ba=oa?2:ia;D8(L,3,4,M,2,1,O,G);E8(L,3,4,M,2,1,O,G);ja=i+508|0;Ea=i+772|0;za=i+1052|0;D8(ja,3,4,Ea,2,1,za,G);E8(ja,3,4,Ea,2,1,za,G);za=i+556|0;Ea=i+796|0;ja=i+1068|0;D8(za,3,4,Ea,2,1,ja,G);E8(za,3,4,Ea,2,1,ja,G);ja=i+604|0;Ea=i+820|0;za=i+1084|0;D8(ja,3,4,Ea,2,1,za,G);E8(ja,3,4,Ea,2,1,za,G);za=oa?na:la;if((c[N>>2]|0)==0){na=i+832|0;oa=c[na>>2]|0;Ea=i+820|0;c[na>>2]=c[Ea>>2];c[Ea>>2]=oa&255;oa=i+836|0;Ea=c[oa>>2]|0;na=i+824|0;c[oa>>2]=c[na>>2];c[na>>2]=Ea&255;Ea=i+840|0;na=c[Ea>>2]|0;oa=i+828|0;c[Ea>>2]=c[oa>>2];c[oa>>2]=na&255;na=i+1084|0;c[na>>2]=c[na>>2]^1;na=i+1088|0;c[na>>2]=c[na>>2]^1;na=i+1092|0;c[na>>2]=c[na>>2]^1;c[i+1096>>2]=1;Fa=0;Ga=0}else{Fa=0;Ga=0}while(1){na=Ga<<2;oa=Ga<<1&4;Ea=Ga*12|0;Ha=Fa;ja=0;do{Aa=((ja&2|oa)+(c[P+(c[549072+(ja+na<<2)>>2]<<2)>>2]|0)|0)*3|0;ya=(ja*3|0)+Ea|0;Ia=(c[Q+(Aa<<2)>>2]|0)-(c[A+(ya<<2)>>2]|0)|0;Ja=(ba(Ia,Ia)|0)+Ha|0;Ia=(c[Q+(Aa+1<<2)>>2]|0)-(c[A+(ya+1<<2)>>2]|0)|0;Ka=(ba(Ia,Ia)|0)+Ja|0;Ja=(c[Q+(Aa+2<<2)>>2]|0)-(c[A+(ya+2<<2)>>2]|0)|0;Ha=(ba(Ja,Ja)|0)+Ka|0;ja=ja+1|0;}while((ja|0)<4);ja=Ga+1|0;if((ja|0)<4){Fa=Ha;Ga=ja}else{break}}la=(((Ha|0)/24|0)+18|0)<(za|0)?3:Ba;ia=(la|0)==0;ja=(ia&1)+ga|0;La=ia?0:ha;if(ia){if((ja|0)==1023){Ma=29}else{Na=ea;Oa=ja}}else{if((ja|0)==0){Pa=ea;Ma=30}else{Ma=29}}if((Ma|0)==29){Ma=0;ia=ea;x=(ja|33792)&65535;a[ia]=x;x=x>>8;a[ia+1|0]=x;Pa=ea+2|0;Ma=30}do{if((Ma|0)==30){Ma=0;if((la|0)==3){ia=0;ja=0;while(1){Ea=ja<<2;na=ja<<1&4;oa=ja*3|0;Qa=ia;Ka=0;do{Ja=Ka+Ea|0;ya=P+(c[549072+(Ja<<2)>>2]<<2)|0;Aa=c[ya>>2]|0;Ia=Ka&2|na;Ra=(Ka+fa|0)*3|0;a[ca+(Ra-(ba(oa,c[j>>2]|0)|0))|0]=c[Q+(((Ia+Aa|0)*3|0)<<2)>>2];a[ca+(Ra+1-(ba(oa,c[j>>2]|0)|0))|0]=c[Q+(((Ia+(c[ya>>2]|0)|0)*3|0)+1<<2)>>2];a[ca+(Ra+2-(ba(oa,c[j>>2]|0)|0))|0]=c[Q+(((Ia+(c[ya>>2]|0)|0)*3|0)+2<<2)>>2];Qa=(Aa^1)<<Ja|Qa;Ka=Ka+1|0;}while((Ka|0)<4);Ka=ja+1|0;if((Ka|0)<4){ia=Qa;ja=Ka}else{break}}ja=Pa;x=Qa&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;ja=Pa+2|0;x=(c[M>>2]<<10|c[S>>2]<<5|c[T>>2]|32768)&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;ja=Pa+4|0;x=(c[i+764>>2]<<5|c[i+760>>2]<<10|c[i+768>>2])&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;ja=Pa+6|0;x=(c[i+776>>2]<<5|c[i+772>>2]<<10|c[i+780>>2])&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;ja=Pa+8|0;x=(c[i+788>>2]<<5|c[i+784>>2]<<10|c[i+792>>2])&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;ja=Pa+10|0;x=(c[i+800>>2]<<5|c[i+796>>2]<<10|c[i+804>>2])&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;ja=Pa+12|0;x=(c[i+812>>2]<<5|c[i+808>>2]<<10|c[i+816>>2])&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;ja=Pa+14|0;x=(c[i+824>>2]<<5|c[i+820>>2]<<10|c[i+828>>2])&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;ja=Pa+16|0;x=(c[i+836>>2]<<5|c[i+832>>2]<<10|c[i+840>>2])&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;Na=Pa+18|0;Oa=0;break}else if((la|0)==1){ja=Pa;x=(c[C>>2]<<10|c[w>>2]<<5|c[R>>2]|32768)&65535;a[ja]=x;x=x>>8;a[ja+1|0]=x;ja=0;do{ia=ja*3|0;Ka=fa*3|0;a[ca+(Ka-(ba(ia,c[j>>2]|0)|0))|0]=c[xa>>2];a[ca+((Ka|1)-(ba(ia,c[j>>2]|0)|0))|0]=c[ka>>2];a[ca+((Ka|2)-(ba(ia,c[j>>2]|0)|0))|0]=c[ma>>2];Ka=(fa|1)*3|0;a[ca+(Ka-(ba(ia,c[j>>2]|0)|0))|0]=c[xa>>2];a[ca+(Ka+1-(ba(ia,c[j>>2]|0)|0))|0]=c[ka>>2];a[ca+(Ka+2-(ba(ia,c[j>>2]|0)|0))|0]=c[ma>>2];Ka=(fa|2)*3|0;a[ca+(Ka-(ba(ia,c[j>>2]|0)|0))|0]=c[xa>>2];a[ca+((Ka|1)-(ba(ia,c[j>>2]|0)|0))|0]=c[ka>>2];a[ca+(Ka+2-(ba(ia,c[j>>2]|0)|0))|0]=c[ma>>2];Ka=(fa|3)*3|0;a[ca+(Ka-(ba(ia,c[j>>2]|0)|0))|0]=c[xa>>2];a[ca+(Ka+1-(ba(ia,c[j>>2]|0)|0))|0]=c[ka>>2];a[ca+(Ka+2-(ba(ia,c[j>>2]|0)|0))|0]=c[ma>>2];ja=ja+1|0;}while((ja|0)<4);Na=Pa+2|0;Oa=0;break}else if((la|0)==2){ja=0;ia=0;while(1){Ka=ia<<2;oa=ia*3|0;Sa=ja;na=0;do{Ea=na+Ka|0;Ja=E+(Ea<<2)|0;Aa=c[Ja>>2]|0;ya=(na+fa|0)*3|0;a[ca+(ya-(ba(oa,c[j>>2]|0)|0))|0]=c[I+((Aa*3|0)<<2)>>2];a[ca+(ya+1-(ba(oa,c[j>>2]|0)|0))|0]=c[I+(((c[Ja>>2]|0)*3|0)+1<<2)>>2];a[ca+(ya+2-(ba(oa,c[j>>2]|0)|0))|0]=c[I+(((c[Ja>>2]|0)*3|0)+2<<2)>>2];Sa=(Aa^1)<<Ea|Sa;na=na+1|0;}while((na|0)<4);na=ia+1|0;if((na|0)<4){ja=Sa;ia=na}else{break}}ia=Pa;x=Sa&65535;a[ia]=x;x=x>>8;a[ia+1|0]=x;ia=Pa+2|0;x=(c[U>>2]<<5|c[J>>2]<<10|c[V>>2])&65535;a[ia]=x;x=x>>8;a[ia+1|0]=x;ia=Pa+4|0;x=(c[X>>2]<<5|c[W>>2]<<10|c[Y>>2])&65535;a[ia]=x;x=x>>8;a[ia+1|0]=x;Na=Pa+6|0;Oa=0;break}else{Na=Pa;Oa=0;break}}}while(0);la=fa+4|0;Ta=c[j>>2]|0;if((la|0)<(Ta|0)){ea=Na;fa=la;ga=Oa;ha=La}else{break}}Ua=Na;Va=Oa;Wa=La;Xa=Ta;Ya=c[l>>2]|0;Za=c[k>>2]|0}else{Ua=Z;Va=$;Wa=aa;Xa=v;Ya=u;Za=t}ha=_+4|0;if((ha|0)<(Za|0)){Z=Ua;_=ha;$=Va;aa=Wa;ca=ca+(Xa*-12|0)|0;da=da+(-(Ya<<1)<<1)|0;v=Xa;u=Ya;t=Za}else{break}}if((Va|0)==0){_a=Ua;$a=Wa;break}t=Ua;x=(Va|33792)&65535;a[t]=x;x=x>>8;a[t+1|0]=x;_a=Ua+2|0;$a=Wa}else{_a=m;$a=1}}while(0);a[_a]=0;a[_a+1|0]=0;if(($a|b|0)==0){c[r>>2]=(c[r>>2]|0)+1}else{c[r>>2]=0;r=f+36|0;c[r>>2]=c[r>>2]|1}c[f+28>>2]=_a+2-m;c[h>>2]=1;n=0;return n|0}function iRa(a){a=a|0;$Db((c[a+60>>2]|0)+264|0);return 0}function jRa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+60>>2]|0;d=c[a+120>>2]|0;e=c[a+124>>2]|0;f=a+48|0;if((c[f>>2]|0)==1297498929){g=e+3|0;h=d+3|0}else{g=e;h=d}d=V$a(a,h&-4,g&-4)|0;if((d|0)<0){i=d;return i|0}c[a+140>>2]=(c[f>>2]|0)==1297498929?46:30;f=ICb()|0;c[b>>2]=f;if((f|0)==0){i=-12;return i|0}f=c[a+100>>2]|0;if((f|0)>8){j=(PGb((c[a+96>>2]|0)+(f-9)|0,2351272,9)|0)==0|0}else{j=0}c[b+4>>2]=j;i=0;return i|0}function kRa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;j=i;i=i+528|0;k=j|0;l=j+512|0;m=c[e+60>>2]|0;n=m;o=$$a(e,c[n>>2]|0)|0;if((o|0)<0){p=o;i=j;return p|0}o=c[h+24>>2]|0;q=h+28|0;h=c[q>>2]|0;if(!((h|0)>-1)){yDb(0,0,1938728,(r=i,i=i+24|0,c[r>>2]=1914480,c[r+8>>2]=1894024,c[r+16>>2]=135,r)|0);i=r;Cd();return 0}s=o+h|0;t=c[n>>2]|0;u=c[t>>2]|0;v=c[e+120>>2]|0;w=c[e+124>>2]|0;x=c[t+32>>2]|0;a:do{if((c[e+48>>2]|0)==1297498929){t=l|0;y=l+2|0;z=l+12|0;A=l+8|0;B=l+4|0;C=l+14|0;D=l+10|0;E=l+6|0;F=s;G=0;H=o;b:while(1){I=ba(G,x)|0;J=ba(G|1,x)|0;K=ba(G|2,x)|0;L=ba(G|3,x)|0;M=0;N=H;while(1){if(!((F-N|0)>>>0>5>>>0)){break a}O=N;P=(de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=N+2|0;Q=de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0;b[t>>1]=Q;O=N+6|0;R=N+4|0;S=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;b[y>>1]=S;if(Q<<16>>16<0){if((F-O|0)>>>0<12>>>0){break b}R=O;b[B>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+8|0;b[E>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+10|0;b[A>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+12|0;b[D>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+14|0;b[z>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+16|0;b[C>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;T=N+18|0}else{b[z>>1]=Q;b[A>>1]=Q;b[B>>1]=Q;b[C>>1]=S;b[D>>1]=S;b[E>>1]=S;T=O}O=M<<1;S=O+I|0;b[u+S>>1]=b[l+((P&1^1)<<1)>>1]&32767;b[u+(S|2)>>1]=b[l+((P>>>1&1^1)<<1)>>1]&32767;b[u+(S+4)>>1]=b[l+((P>>>2&1^3)<<1)>>1]&32767;b[u+(S+6)>>1]=b[l+((P>>>3&1^3)<<1)>>1]&32767;S=O+J|0;b[u+S>>1]=b[l+((P>>>4&1^1)<<1)>>1]&32767;b[u+(S+2)>>1]=b[l+((P>>>5&1^1)<<1)>>1]&32767;b[u+(S+4)>>1]=b[l+((P>>>6&1^3)<<1)>>1]&32767;b[u+(S+6)>>1]=b[l+((P>>>7&1^3)<<1)>>1]&32767;S=O+K|0;b[u+S>>1]=b[l+((P>>>8&1^5)<<1)>>1]&32767;b[u+(S+2)>>1]=b[l+((P>>>9&1^5)<<1)>>1]&32767;b[u+(S+4)>>1]=b[l+((P>>>10&1^7)<<1)>>1]&32767;b[u+(S+6)>>1]=b[l+((P>>>11&1^7)<<1)>>1]&32767;S=O+L|0;b[u+S>>1]=b[l+((P>>>12&1^5)<<1)>>1]&32767;b[u+(S+2)>>1]=b[l+((P>>>13&1^5)<<1)>>1]&32767;b[u+(S+4)>>1]=b[l+((P>>>14&1^7)<<1)>>1]&32767;b[u+(S+6)>>1]=b[l+((P>>>15^7)<<1)>>1]&32767;P=M+4|0;if((P|0)<(v|0)){M=P;N=T}else{break}}N=G+4|0;if((N|0)<(w|0)){G=N;H=T}else{break a}}yDb(e,24,1966896,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=-1094995529;i=j;return p|0}else{H=c[m+4>>2]|0;G=s;if(h>>>0<6>>>0){p=-1094995529;i=j;return p|0}E=o;D=o+4|0;if(((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65532|0)==(v|0)){E=o+2|0;if(((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65532|0)!=(w|0)){U=18}}else{U=18}if((U|0)==18){yDb(e,24,2049896,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}if((a[D]|0)!=0){DDb(e,2004248,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=-1163346256;i=j;return p|0}D=o+6|0;E=a[o+5|0]|0;C=E&255;B=C*3|0;if((G-D|0)>>>0<B>>>0){p=-1094995529;i=j;return p|0}A=(E&255)>>>0>128>>>0;E=A?128:C;if((E|0)==0){V=D}else{C=E>>>0>1>>>0?(E*3|0)+6|0:9;z=0;F=D;while(1){c[k+(z<<2)>>2]=d[F]<<16|d[F+1|0]<<8|d[F+2|0]|-16777216;D=z+1|0;if((D|0)<(E|0)){z=D;F=F+3|0}else{break}}V=o+C|0}if(A){F=B-384|0;z=G-V|0;W=V+(z>>>0>F>>>0?F:z)|0}else{W=V}if((H|0)==0){X=u;Y=x}else{X=u+(ba(w-1|0,x)|0)|0;Y=-x|0}z=Y+4|0;F=Y+8|0;E=Y+12|0;D=Y<<1;y=D+4|0;t=D+8|0;N=D+12|0;M=Y*3|0;L=M+4|0;K=M+8|0;J=M+12|0;I=0;P=W;c:while(1){S=ba(I,Y)|0;O=ba(I|1,Y)|0;Q=ba(I|2,Y)|0;R=ba(I|3,Y)|0;Z=0;_=P;while(1){if((s|0)==(_|0)){break a}$=_+1|0;aa=d[_]|0;do{if((aa&128|0)==0){if((s|0)==($|0)){p=-1094995529;U=50;break c}ca=_+2|0;da=d[$]|0;if((da&128|0)==0){if((G-ca|0)>>>0<8>>>0){p=-1094995529;U=50;break c}ea=c[k+((aa&127)<<2)>>2]|0;fa=c[k+((da&127)<<2)>>2]|0;ga=c[k+((a[ca]&127)<<2)>>2]|0;ha=c[k+((a[_+3|0]&127)<<2)>>2]|0;ia=c[k+((a[_+4|0]&127)<<2)>>2]|0;ja=c[k+((a[_+5|0]&127)<<2)>>2]|0;ka=c[k+((a[_+6|0]&127)<<2)>>2]|0;la=c[k+((a[_+7|0]&127)<<2)>>2]|0;ma=_+8|0;na=(d[ma]|d[ma+1|0]<<8)<<16>>16&65535;ma=Z<<2;oa=ma+S|0;c[X+oa>>2]=(na&1|0)==0?ea:fa;c[X+(oa+4)>>2]=(na&2|0)==0?ea:fa;c[X+(oa+8)>>2]=(na&4|0)==0?ga:ha;c[X+(oa+12)>>2]=(na&8|0)==0?ga:ha;oa=ma+O|0;c[X+oa>>2]=(na&16|0)==0?ea:fa;c[X+(oa+4)>>2]=(na&32|0)==0?ea:fa;c[X+(oa+8)>>2]=(na&64|0)==0?ga:ha;c[X+(oa+12)>>2]=(na&128|0)==0?ga:ha;ha=ma+Q|0;c[X+ha>>2]=(na&256|0)==0?ia:ja;c[X+(ha+4)>>2]=(na&512|0)==0?ia:ja;c[X+(ha+8)>>2]=(na&1024|0)==0?ka:la;c[X+(ha+12)>>2]=(na&2048|0)==0?ka:la;ha=ma+R|0;c[X+ha>>2]=(na&4096|0)==0?ia:ja;c[X+(ha+4)>>2]=(na&8192|0)==0?ia:ja;c[X+(ha+8)>>2]=(na&16384|0)==0?ka:la;c[X+(ha+12)>>2]=(na&32768|0)==0?ka:la;pa=_+10|0;break}la=aa&127;ka=da&127;if((la|0)==(ka|0)){da=(Z<<2)+S|0;na=c[k+(la<<2)>>2]|0;c[X+da>>2]=na;c[X+(da+4)>>2]=na;c[X+(da+8)>>2]=na;c[X+(da+12)>>2]=na;c[X+(da+Y)>>2]=na;c[X+(da+z)>>2]=na;c[X+(da+F)>>2]=na;c[X+(da+E)>>2]=na;c[X+(da+D)>>2]=na;c[X+(da+y)>>2]=na;c[X+(da+t)>>2]=na;c[X+(da+N)>>2]=na;c[X+(da+M)>>2]=na;c[X+(da+L)>>2]=na;c[X+(da+K)>>2]=na;c[X+(da+J)>>2]=na;pa=ca;break}if((G-ca|0)>>>0<2>>>0){p=-1094995529;U=50;break c}na=c[k+(la<<2)>>2]|0;la=c[k+(ka<<2)>>2]|0;ka=ca;ca=(d[ka]|d[ka+1|0]<<8)<<16>>16&65535;ka=Z<<2;da=ka+S|0;c[X+da>>2]=(ca&1|0)==0?na:la;c[X+(da+4)>>2]=(ca&2|0)==0?na:la;c[X+(da+8)>>2]=(ca&4|0)==0?na:la;c[X+(da+12)>>2]=(ca&8|0)==0?na:la;da=ka+O|0;c[X+da>>2]=(ca&16|0)==0?na:la;c[X+(da+4)>>2]=(ca&32|0)==0?na:la;c[X+(da+8)>>2]=(ca&64|0)==0?na:la;c[X+(da+12)>>2]=(ca&128|0)==0?na:la;da=ka+Q|0;c[X+da>>2]=(ca&256|0)==0?na:la;c[X+(da+4)>>2]=(ca&512|0)==0?na:la;c[X+(da+8)>>2]=(ca&1024|0)==0?na:la;c[X+(da+12)>>2]=(ca&2048|0)==0?na:la;da=ka+R|0;c[X+da>>2]=(ca&4096|0)==0?na:la;c[X+(da+4)>>2]=(ca&8192|0)==0?na:la;c[X+(da+8)>>2]=(ca&16384|0)==0?na:la;c[X+(da+12)>>2]=(ca&32768|0)==0?na:la;pa=_+4|0}else{la=aa&63;na=la<<2|la>>>4;if((aa&64|0)!=0){la=(Z<<2)+S|0;ca=na|na<<8|na<<16|-16777216;c[X+la>>2]=ca;c[X+(la+4)>>2]=ca;c[X+(la+8)>>2]=ca;c[X+(la+12)>>2]=ca;c[X+(la+Y)>>2]=ca;c[X+(la+z)>>2]=ca;c[X+(la+F)>>2]=ca;c[X+(la+E)>>2]=ca;c[X+(la+D)>>2]=ca;c[X+(la+y)>>2]=ca;c[X+(la+t)>>2]=ca;c[X+(la+N)>>2]=ca;c[X+(la+M)>>2]=ca;c[X+(la+L)>>2]=ca;c[X+(la+K)>>2]=ca;c[X+(la+J)>>2]=ca;pa=$;break}if((G-$|0)>>>0<2>>>0){p=-1094995529;U=50;break c}ca=(Z<<2)+S|0;la=na|d[$]<<8|d[_+2|0]<<16|-16777216;c[X+ca>>2]=la;c[X+(ca+4)>>2]=la;c[X+(ca+8)>>2]=la;c[X+(ca+12)>>2]=la;c[X+(ca+Y)>>2]=la;c[X+(ca+z)>>2]=la;c[X+(ca+F)>>2]=la;c[X+(ca+E)>>2]=la;c[X+(ca+D)>>2]=la;c[X+(ca+y)>>2]=la;c[X+(ca+t)>>2]=la;c[X+(ca+N)>>2]=la;c[X+(ca+M)>>2]=la;c[X+(ca+L)>>2]=la;c[X+(ca+K)>>2]=la;c[X+(ca+J)>>2]=la;pa=_+3|0}}while(0);$=Z+4|0;if(($|0)<(v|0)){Z=$;_=pa}else{break}}_=I+4|0;if((_|0)<(w|0)){I=_;P=pa}else{break a}}if((U|0)==50){i=j;return p|0}}}while(0);c[g>>2]=1;g=MCb(f,c[n>>2]|0)|0;if((g|0)<0){p=g;i=j;return p|0}p=c[q>>2]|0;i=j;return p|0}function lRa(a){a=a|0;JCb(c[a+60>>2]|0);return 0}function mRa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+60|0;d=c[b>>2]|0;e=d+3008|0;c[e>>2]=ICb()|0;f=ICb()|0;c[d+3012>>2]=f;g=c[e>>2]|0;if((g|0)==0|(f|0)==0){f=c[b>>2]|0;c[f+1140>>2]=0;CLa(a)|0;JCb(f+3008|0);JCb(f+3012|0);c[f+3032>>2]=0;$Db(f+3028|0);$Db(f+3040|0);h=-12;return h|0}else{c[d+1140>>2]=g;h=uLa(a)|0;return h|0}return 0}function nRa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;o=g;c[j>>2]=m;p=m+n|0;q=g+1144|0;c[q>>2]=0;r=g+3024|0;c[r>>2]=0;a:do{if((n|0)>0){s=g+8|0;t=g+20|0;u=g+24|0;v=g+12|0;w=g+16|0;x=g+3044|0;y=g+3048|0;z=g+4|0;A=g+3032|0;B=g+3028|0;C=B;D=g+3036|0;E=g+3040|0;F=E;G=g+3020|0;H=g+816|0;I=b;J=g+812|0;K=g+1140|0;L=b+696|0;M=g+3016|0;N=g+3008|0;O=g+900|0;P=g+904|0;b:while(1){Q=ALa(o,j,p,k,l)|0;if((Q|0)<0){R=62;break a}S=c[k>>2]|0;T=c[l>>2]<<3;U=T>>>0>2147483639>>>0|(S|0)==0;V=U?0:S;S=U?0:T;c[s>>2]=V;c[t>>2]=S;T=S+8|0;c[u>>2]=T;c[v>>2]=V+(S>>3);c[w>>2]=0;do{if((Q-224|0)>>>0<16>>>0){S=c[l>>2]|0;if((S|0)<2){break}V=c[k>>2]|0;U=(de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535;V=((U|0)>(S|0)?S:U)<<3;c[w>>2]=T>>>0>V>>>0?V:T}}while(0);c:do{switch(Q|0){case 192:{c[G>>2]=0;W=yLa(o)|0;if((W|0)<0){R=32;break b}if((c[H>>2]|0)!=0){R=34;break b}c[G>>2]=1;break};case 254:{T=c[k>>2]|0;V=c[l>>2]|0;if((V|0)<2){break c}U=T;S=de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0;U=S&65535;X=(U|0)>(V|0);d:do{if((S&65535)>>>0<15>>>0|X){Y=0}else{if((RGb(T+2|0,2331128,3)|0)!=0){Y=0;break}Z=T+6|0;_=(d[Z]|d[Z+1|0]<<8)<<16>>16&65535;c[x>>2]=_;Z=T+8|0;$=(d[Z]|d[Z+1|0]<<8)<<16>>16&65535;c[y>>2]=$;Z=((ba($,_)|0)+7|0)>>>3;if(Z>>>0>(U-14|0)>>>0){yDb(c[z>>2]|0,16,2306704,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;Y=-22;break}do{if((c[A>>2]|0)!=(Z|0)){c[A>>2]=0;$Db(B);_=WDb(Z)|0;c[C>>2]=_;if((_|0)==0){yDb(c[z>>2]|0,16,2288496,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;Y=-12;break d}$Db(E);_=cEb(Z)|0;c[F>>2]=_;if((_|0)==0){yDb(c[z>>2]|0,16,2272240,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;Y=-12;break d}else{c[A>>2]=Z;break}}}while(0);UGb(c[C>>2]|0,T+14|0,Z)|0;c[r>>2]=1;if((c[D>>2]|0)!=0){Y=0;break}if((Z|0)==0){ca=1}else{_=0;$=255;da=c[F>>2]|0;do{ea=da+_|0;a[ea]=a[ea]|a[(c[C>>2]|0)+_|0];da=c[F>>2]|0;$=(d[da+_|0]|0)&$;_=_+1|0;}while(_>>>0<Z>>>0);ca=($|0)==255|0}c[D>>2]=ca;Y=0}}while(0);T=c[u>>2]|0;S=(c[w>>2]|0)+((X?V:U)<<3)|0;c[w>>2]=T>>>0>S>>>0?S:T;if((Y|0)<0){fa=Y;R=70;break b}break};case 217:{R=62;break a;break};case 196:{ga=vLa(o)|0;if((ga|0)<0){R=12;break b}break};case 216:{if((c[q>>2]|0)!=0){ha=K;R=64;break a}break};case 218:{if((c[G>>2]|0)==0){yDb(I,24,1966816,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;break c}if((c[q>>2]|0)==0){if((c[J>>2]|0)!=0){yDb(I,24,1938656,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;break c}if((c[r>>2]|0)==0){yDb(I,24,1914440,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;break c}KCb(c[K>>2]|0);T=_$a(b,c[K>>2]|0,1)|0;if((T|0)<0){fa=T;R=70;break b}T=c[K>>2]|0;c[T+88>>2]=2;c[T+84>>2]=0;c[q>>2]=1;ia=T}else{T=c[K>>2]|0;c[T+88>>2]=1;c[T+84>>2]=1;ia=T}if((c[r>>2]|0)==0){T=zLa(o,0,0,0)|0;if((T|0)>=0){break c}if((c[L>>2]&8|0)==0){break c}else{fa=T;R=70;break b}}T=c[N+((c[M>>2]^1)<<2)>>2]|0;do{if(((c[O>>2]|0)+15>>4|0)==(c[x>>2]|0)){if(((c[P>>2]|0)+15>>4|0)!=(c[y>>2]|0)){break}S=(c[T>>2]|0)==0;do{if(S){R=56}else{Z=0;while(1){if((Z|0)>=4){R=55;break}if((c[T+(Z<<2)>>2]|0)==0^(c[ia+(Z<<2)>>2]|0)==0){R=54;break}if((c[T+32+(Z<<2)>>2]|0)==(c[ia+32+(Z<<2)>>2]|0)){Z=Z+1|0}else{R=54;break}}if((R|0)==54){R=0;yDb(c[z>>2]|0,16,2351216,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;break c}else if((R|0)==55){R=0;if(S){R=56;break}else{break}}}}while(0);if((R|0)==56){R=0;S=_$a(b,T,1)|0;if((S|0)<0){fa=S;R=70;break b}}S=zLa(o,c[C>>2]|0,c[A>>2]|0,T)|0;if((S|0)>=0){break c}if((c[L>>2]&8|0)==0){break c}else{fa=S;R=70;break b}}}while(0);yDb(c[z>>2]|0,16,1893960,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;break};case 219:{ja=wLa(o)|0;if((ja|0)<0){R=10;break b}break};default:{}}}while(0);Q=(c[j>>2]|0)+((c[w>>2]|0)+7>>3)|0;c[j>>2]=Q;if(!(Q>>>0<p>>>0)){R=62;break a}}if((R|0)==10){yDb(I,16,2184152,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;fa=ja;i=h;return fa|0}else if((R|0)==12){yDb(I,16,2107344,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;fa=ga;i=h;return fa|0}else if((R|0)==32){yDb(I,16,2049832,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;fa=W;i=h;return fa|0}else if((R|0)==34){yDb(I,16,2004160,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;fa=-22;i=h;return fa|0}else if((R|0)==70){i=h;return fa|0}}else{R=62}}while(0);do{if((R|0)==62){if((c[q>>2]|0)==0){break}ha=g+1140|0;R=64}}while(0);do{if((R|0)==64){q=MCb(e,c[ha>>2]|0)|0;if((q|0)<0){fa=q;i=h;return fa|0}c[f>>2]=1;q=g+3016|0;aa=c[q>>2]^1;c[q>>2]=aa;c[ha>>2]=c[g+3008+(aa<<2)>>2];aa=g+3036|0;if((c[aa>>2]|0)!=0){break}if((c[r>>2]|0)==0){c[aa>>2]=1;break}else{c[f>>2]=0;break}}}while(0);fa=(c[j>>2]|0)-m|0;i=h;return fa|0}function oRa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+1140>>2]=0;CLa(a)|0;JCb(b+3008|0);JCb(b+3012|0);c[b+3032>>2]=0;$Db(b+3028|0);$Db(b+3040|0);return 0}function pRa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+1440>>2]=b+416;c[b+1444>>2]=b+928;oDb(b+4|0,0);aLa(b+324|0,8,1,1.0)|0;fCb(b+288|0,c[a+88>>2]&8388608);g[b+284>>2]=3814697265625.0e-18;c[a+420>>2]=3;if(!(+g[1365577]!=0.0)){VXa(7)}c[a+416>>2]=1;b=a+448|0;c[b>>2]=4;c[b+4>>2]=0;return 0}function qRa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0,U=0.0,V=0.0,W=0,X=0,Y=0,Z=0,_=0;l=i;i=i+1504|0;m=l|0;n=l+496|0;o=l+992|0;p=h;q=c[k+24>>2]|0;r=HZ(k,70,0)|0;s=c[k+28>>2]|0;k=c[f+60>>2]|0;t=k;u=(s|0)/64|0;if((s|0)<64){yDb(f,16,2184128,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=l;return w|0}x=(s|0)%64|0;if((x|0)!=0){yDb(f,24,2107320,(v=i,i=i+8|0,c[v>>2]=x,v)|0);i=v}do{if((r|0)!=0&(s|0)>127){v=f+412|0;if(((c[v>>2]|0)%11025|0|0)!=0){break}if((1<<((d[r]|0)>>>2&3)|0)!=(u|0)){break}c[v>>2]=((s|0)/128|0)*11025|0}}while(0);c[h+76>>2]=u<<8;r=_$a(f,p,0)|0;if((r|0)<0){w=r;i=l;return w|0}if((s|0)>63){r=k+264|0;p=k+276|0;f=k+280|0;v=k+268|0;x=k+272|0;y=m|0;m=n|0;z=k+284|0;A=o|0;B=k+260|0;C=k+324|0;D=k+368|0;E=k+1440|0;F=k+304|0;G=k+1444|0;k=q;q=0;H=c[h>>2]|0;while(1){h=(k|0)==0?0:512;c[r>>2]=k;c[p>>2]=h;I=h|8;c[f>>2]=I;J=k+(h>>>3)|0;c[v>>2]=J;c[x>>2]=0;K=k;L=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24)&63;c[x>>2]=6;K=m;M=+((e[117e4+(L<<1)>>1]|0)>>>0);L=y;N=0;O=6;while(1){if((N|0)>0){P=k+(O>>>3)|0;Q=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((O&7)>>>0)&31;P=O+5|0;R=I>>>0>P>>>0?P:I;c[x>>2]=R;S=M+ +(b[1170640+(Q<<1)>>1]|0);T=R}else{S=M;T=O}U=-0.0- +Wc(+(S*.00048828125));V=+g[z>>2]*U;R=a[1170704+N|0]|0;if(R<<24>>24==0){W=K;X=L}else{Q=R&255;R=Q>>>0>1>>>0?Q:1;P=K;Y=L;Z=0;while(1){g[Y>>2]=S;g[P>>2]=V;_=Z+1|0;if((_|0)<(Q|0)){P=P+4|0;Y=Y+4|0;Z=_}else{break}}W=K+(R<<2)|0;X=L+(R<<2)|0}Z=N+1|0;if((Z|0)<23){K=W;M=S;L=X;N=Z;O=T}else{break}}Rmb(y,A);O=0;do{N=O<<7;c[r>>2]=k;c[p>>2]=h;c[f>>2]=I;c[v>>2]=J;L=(O*198|0)+116|0;c[x>>2]=(I|0)<(L|0)?I:L;L=0;do{K=c[o+(L<<2)>>2]|0;do{if((K|0)<1){M=+g[n+(L<<2)>>2]*.7071067811865476;Z=H+(L+N<<2)|0;g[Z>>2]=M;Y=c[B>>2]|0;c[t+4+((Y&63)<<2)>>2]=(c[t+4+((Y+9&63)<<2)>>2]|0)+(c[t+4+((Y+40&63)<<2)>>2]|0);Y=c[B>>2]|0;c[B>>2]=Y+1;if((c[t+4+((Y&63)<<2)>>2]&1|0)==0){break}g[Z>>2]=M*-1.0}else{Z=c[x>>2]|0;Y=c[f>>2]|0;P=(c[r>>2]|0)+(Z>>>3)|0;Q=32-K|0;_=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((Z&7)>>>0)<<Q>>>(Q>>>0);Q=Z+K|0;c[x>>2]=Y>>>0>Q>>>0?Q:Y;g[H+(L+N<<2)>>2]=+g[1170128+((1<<K)-1+(_&255)<<2)>>2]*+g[n+(L<<2)>>2]}}while(0);L=L+1|0;}while((L|0)<124);L=H+(N<<2)|0;TGb(H+((N|124)<<2)|0,0,16)|0;Xe[c[D>>2]&4095](C,c[E>>2]|0,L);le[c[F>>2]&1023](L,(c[G>>2]|0)+256|0,c[E>>2]|0,5461800,64);L=c[G>>2]|0;c[G>>2]=c[E>>2];c[E>>2]=L;O=O+1|0;}while((O|0)<2);O=q+1|0;if((O|0)<(u|0)){k=k+64|0;q=O;H=H+1024|0}else{break}}}c[j>>2]=1;w=s;i=l;return w|0}function rRa(a){a=a|0;bLa((c[a+60>>2]|0)+324|0);return 0}function sRa(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a+60|0;e=c[d>>2]|0;if((c[a+416>>2]|0)!=1){yDb(a,16,2184088,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;h=-22;i=b;return h|0}j=c[a+412>>2]|0;do{if(!((j|0)==8e3|(j|0)==16e3|(j|0)==11025|(j|0)==22050|(j|0)==44100)){if(!((c[a+680>>2]|0)>-1)){break}yDb(a,16,2107240,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;h=-22;i=b;return h|0}}while(0);c[a+424>>2]=256;c[a+116>>2]=128;Qhb(a,e+108|0);f=e;c[f>>2]=a;j=aLa(e+44|0,8,0,32768.0)|0;do{if((j|0)<0){k=j}else{fCb(e+8|0,c[a+88>>2]&8388608);VXa(7);l=0;do{g[4641016+(l<<2)>>2]=-0.0- +Wc(+(+(-l|0)*.00048828125+-3.0+3.0));l=l+1|0;}while((l|0)<2048);if((c[(c[f>>2]|0)+600>>2]|0)==0){h=0;i=b;return h|0}l=e+3744|0;c[l>>2]=WDb(3290656)|0;m=WDb(822664)|0;c[e+3748>>2]=m;if((c[l>>2]|0)==0|(m|0)==0){k=-12;break}else{h=0}i=b;return h|0}}while(0);e=c[d>>2]|0;bLa(e+44|0);if((c[(c[e>>2]|0)+600>>2]|0)!=0){ZDb(c[e+3744>>2]|0);ZDb(c[e+3748>>2]|0)}Rhb(e+108|0);h=k;i=b;return h|0}function tRa(f,h,j,l){f=f|0;h=h|0;j=j|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0.0,Z=0,_=0,aa=0,ba=0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;m=i;i=i+1200|0;n=m|0;o=m+496|0;p=m+1008|0;q=m+1104|0;s=c[f+60>>2]|0;t=s;u=s+4|0;if((c[u>>2]|0)!=0){v=0;i=m;return v|0}w=s+2208|0;y=s+3232|0;UGb(w|0,y|0,512)|0;z=s+2720|0;A=z;do{if((j|0)==0){TGb(z|0,0,1024)|0;c[u>>2]=1}else{B=j+76|0;UGb(z|0,c[j>>2]|0,c[B>>2]<<2)|0;C=c[B>>2]|0;do{if((C|0)<256){TGb(A+(C<<2)|0,0,256-C<<2|0)|0;if((c[B>>2]|0)<=127){break}c[u>>2]=1}}while(0);B=Shb(s+108|0,j)|0;if((B|0)<0){v=B}else{break}i=m;return v|0}}while(0);j=r0a(f,h,64,0)|0;if((j|0)<0){v=j;i=m;return v|0}j=c[h+24>>2]|0;u=c[h+28>>2]|0;z=s+8|0;B=s+1184|0;cf[c[z>>2]&1023](B,w,5461800,128);w=s+32|0;C=s+1696|0;cf[c[w>>2]&1023](C,A,5461800,128);D=s+44|0;E=s+92|0;Xe[c[E>>2]&4095](D,s+160|0,B);cf[c[z>>2]&1023](B,A,5461800,128);cf[c[w>>2]&1023](C,y,5461800,128);Xe[c[E>>2]&4095](D,s+672|0,B);B=u&268435456;D=0;E=0;while(1){y=a[1170704+D|0]|0;C=y&255;if(y<<24>>24==0){F=0.0;G=E}else{y=C>>>0>1>>>0;w=0;H=0.0;A=E;while(1){I=+g[t+160+(A<<2)>>2];J=+g[t+160+(A+128<<2)>>2];K=H+(I*I+J*J);z=w+1|0;if((z|0)<(C|0)){w=z;H=K;A=A+1|0}else{break}}F=K;G=(y?C:1)+E|0}H=F/+(C<<7|0);if(H<1.0){L=1.0}else{L=H}g[q+(D<<2)>>2]=+$(L)*1024.0/.6931471805599453;A=D+1|0;if((A|0)<23){D=A;E=G}else{break}}G=(B|0)!=0?0:j;B=q|0;E=p|0;a:do{if((c[(c[s>>2]|0)+600>>2]|0)==0){L=+g[B>>2];D=((Gc(+L)|0)>>8)-20|0;if((D|0)<0){M=0}else{M=(D|0)>95?95:D}D=d[470344+M|0]|0;F=+Q(+(L- +(e[117e4+(D<<1)>>1]|0)));A=D+1|0;w=F>+Q(+(L- +(e[117e4+(A<<1)>>1]|0)));z=w?A:D;c[E>>2]=z;D=e[117e4+(z<<1)>>1]|0;z=1;while(1){L=+g[q+(z<<2)>>2]- +(D|0);A=((Gc(+L)|0)>>8)+37|0;if((A|0)<0){N=0}else{N=(A|0)>77?77:A}A=d[470440+N|0]|0;F=+Q(+(L- +(b[1170640+(A<<1)>>1]|0)));w=A+1|0;O=F>+Q(+(L- +(b[1170640+(w<<1)>>1]|0)));P=O?w:A;c[p+(z<<2)>>2]=P;A=z+1|0;if((A|0)<23){D=(b[1170640+(P<<1)>>1]|0)+D|0;z=A}else{R=G;S=32;T=0;U=0;V=0;W=0;break}}}else{z=c[s+3744>>2]|0;D=c[s+3748>>2]|0;C=0;do{g[z+(C<<2)>>2]=r;C=C+1|0;}while((C|0)<822664);L=+g[B>>2];C=0;while(1){y=b[117e4+(C<<1)>>1]|0;F=L- +((y&65535)>>>0);A=y&65535;g[z+(A<<2)>>2]=F*F;a[D+A|0]=C;A=C+1|0;if((A|0)<64){C=A}else{X=1;Y=L;break}}while(1){L=+g[q+(X<<2)>>2];C=X-1|0;A=q+(C<<2)|0;y=1e3;do{F=+(y|0);K=L-F;if(K<0.0){Z=0}else{Z=~~K}K=Y+F;P=K<35768.0;if(P){_=~~K}else{_=35768}H=Y-F;if(H<0.0){aa=0}else{aa=~~H}if(+(aa|0)<(P?K:35768.0)){P=0;w=aa;K=Y;while(1){O=z+(C*143072|0)+(w<<2)|0;if(((g[k>>2]=+g[O>>2],c[k>>2]|0)&2147483647|0)==2139095040){ba=P;ca=K}else{da=P;ea=0;while(1){fa=(b[1170640+(ea<<1)>>1]|0)+w|0;if((fa|0)>(_|0)){ga=da;break}do{if((fa|0)<(Z|0)){ha=da}else{H=+(fa|0)-L;J=H*H+ +g[O>>2];ia=z+(X*143072|0)+(fa<<2)|0;if(!(+g[ia>>2]>J)){ha=da;break}g[ia>>2]=J;a[D+(X*35768|0)+fa|0]=ea;ha=1}}while(0);fa=ea+1|0;if((fa|0)<32){da=ha;ea=fa}else{ga=ha;break}}ba=ga;ca=+g[A>>2]}ea=w+1|0;J=F+ca;if(+(ea|0)<(J<35768.0?J:35768.0)){P=ba;w=ea;K=ca}else{ja=ba;break}}}else{ja=0}y=y<<2;}while((ja|0)==0&(y|0)<35768);y=X+1|0;if((y|0)<23){X=y;Y=L}else{ka=r;la=-1;ma=0;break}}while(1){K=+g[z+3147584+(ma<<2)>>2];y=ka>K;A=y?ma:la;C=ma+1|0;if((C|0)<35768){ka=y?K:ka;la=A;ma=C}else{na=A;oa=22;break}}while(1){z=d[D+(oa*35768|0)+na|0]|0;c[p+(oa<<2)>>2]=z;if((oa|0)==0){R=G;S=32;T=0;U=0;V=0;W=0;break a}if((oa|0)>0){na=na-(b[1170640+(z<<1)>>1]|0)|0;oa=oa-1|0}else{R=G;S=32;T=0;U=0;V=0;W=0;break}}}}while(0);while(1){if((V|0)==0){oa=c[E>>2]|0;na=e[117e4+(oa<<1)>>1]|0;ma=oa<<32-S|T;if((S|0)>6){pa=S;qa=ma;ra=R}else{la=R;x=ma;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;pa=S+32|0;qa=oa>>>(S>>>0);ra=R+4|0}sa=na;ta=qa;ua=pa-6|0;va=ra}else{na=c[p+(V<<2)>>2]|0;oa=(b[1170640+(na<<1)>>1]|0)+U|0;la=na<<32-S|T;if((S|0)>5){wa=S;xa=la;ya=R}else{ma=R;x=la;a[ma]=x;x=x>>8;a[ma+1|0]=x;x=x>>8;a[ma+2|0]=x;x=x>>8;a[ma+3|0]=x;wa=S+32|0;xa=na>>>(S>>>0);ya=R+4|0}sa=oa;ta=xa;ua=wa-5|0;va=ya}ka=+g[4641016+((sa&2047)<<2)>>2]/+(1<<(sa>>11)+3|0);oa=a[1170704+V|0]|0;if(oa<<24>>24==0){za=W}else{Y=+(sa|0);na=oa&255;oa=na>>>0>1>>>0;ma=0;la=W;while(1){X=t+160+(la<<2)|0;g[X>>2]=ka*+g[X>>2];X=t+160+(la+128<<2)|0;g[X>>2]=ka*+g[X>>2];g[n+(la<<2)>>2]=Y;X=ma+1|0;if((X|0)<(na|0)){ma=X;la=la+1|0}else{break}}za=(oa?na:1)+W|0}la=V+1|0;if((la|0)<23){R=va;S=ua;T=ta;U=sa;V=la;W=za}else{break}}Rmb(n|0,o|0);n=G;G=va;va=ua;ua=ta;ta=0;while(1){za=ta<<7;W=G;V=va;sa=ua;U=0;while(1){T=c[o+(U<<2)>>2]|0;if((T|0)>0){S=1<<T;Y=+g[t+160+(U+za<<2)>>2];R=~~(Y*+g[552568+(T<<2)>>2]+ +g[552600+(T<<2)>>2]);ya=d[552560+T|0]|0;wa=(d[T+552561|0]|0)-1|0;if((R|0)<(ya|0)){Aa=ya}else{Aa=(R|0)>(wa|0)?wa:R}R=d[552632+Aa|0]|0;ka=+Q(+(Y- +g[1170128+(S-1+R<<2)>>2]));wa=(ka>+Q(+(Y- +g[1170128+(R+S<<2)>>2])))+R|0;R=wa<<32-V|sa;if((V|0)>(T|0)){Ba=V;Ca=R;Da=W}else{S=W;x=R;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;Ba=V+32|0;Ca=(V|0)==32?0:wa>>>(V>>>0);Da=W+4|0}Ea=Ca;Fa=Ba-T|0;Ga=Da}else{Ea=sa;Fa=V;Ga=W}T=U+1|0;if((T|0)<124){W=Ga;V=Fa;sa=Ea;U=T}else{break}}if((ta|0)==0){U=Fa+282-(Ga-n<<3)|0;if((Fa|0)>(U|0)){Ha=Fa;Ia=Ea;Ja=Ga}else{sa=Ga;x=Ea;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;Ha=Fa+32|0;Ia=0;Ja=Ga+4|0}Ka=Ia;La=Ha-U|0;Ma=Ja}else{Ka=Ea;La=Fa;Ma=Ga}U=ta+1|0;if((U|0)<2){G=Ma;va=La;ua=Ka;ta=U}else{break}}if((La|0)<32){ta=31-La|0;ua=Ka&255;va=Ka;Ka=La;La=Ma;while(1){a[La]=ua;G=va>>>8;Ga=Ka+8|0;if((Ga|0)<32){ua=G&255;va=G;Ka=Ga;La=La+1|0}else{break}}Na=Ma+((ta>>>3)+1)|0}else{Na=Ma}TGb(Na|0,0,j+u-Na|0)|0;Thb(s+108|0,c[f+424>>2]|0,h+8|0,h+48|0);c[l>>2]=1;v=0;i=m;return v|0}function uRa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;bLa(b+44|0);if((c[(c[b>>2]|0)+600>>2]|0)==0){d=b+108|0;e=d;Rhb(e);return 0}ZDb(c[b+3744>>2]|0);ZDb(c[b+3748>>2]|0);d=b+108|0;e=d;Rhb(e);return 0}function vRa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=c[a+60>>2]|0;f=e;g=ICb()|0;c[e>>2]=g;if((g|0)==0){h=-12;i=b;return h|0}c[a+140>>2]=0;c[e+24>>2]=0;c[e+8>>2]=-1;c[e+12>>2]=0;c[e+16>>2]=0;c[e+4>>2]=(c[a+52>>2]|0)==1196444242;g=c[a+100>>2]|0;do{if((g|0)!=0){j=c[a+96>>2]|0;if((g|0)<512){yDb(a,16,2351184,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;break}else{l=j;m=0}while(1){k=l;c[f+28+(m<<2)>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=m+1|0;if((k|0)<64){l=l+4|0;m=k}else{break}}k=j+256|0;n=0;while(1){o=k;c[f+284+(n<<2)>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+1|0;if((o|0)<64){k=k+4|0;n=o}else{break}}}}while(0);Z3(e+1264|0,a);e=yRa(a,c[a+120>>2]|0,c[a+124>>2]|0,-1)|0;h=(e|0)<0?e:0;i=b;return h|0}function wRa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;i=i+80|0;j=h|0;k=h+64|0;l=h+72|0;m=g+24|0;n=c[m>>2]|0;o=g+28|0;g=c[o>>2]|0;p=c[b+60>>2]|0;q=p;r=e;e=(c[b+428>>2]|0)==0|0;if((g|0)<12){yDb(b,16,2184064,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}u=a[n]|0;do{if((u<<24>>24|0)==68){if((a[n+1|0]|0)!=82){break}if((g-12|0)<512){yDb(b,16,2351184,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}v=n+12|0;w=0;while(1){x=v;c[q+28+(w<<2)>>2]=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24;x=w+1|0;if((x|0)<64){v=v+4|0;w=x}else{break}}w=n+268|0;v=0;while(1){x=w;c[q+284+(v<<2)>>2]=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24;x=v+1|0;if((x|0)<64){w=w+4|0;v=x}else{break}}$Ua(p+544|0,p+1264|0,c[p+12>>2]|0,c[p+16>>2]|0,p+28|0,p+284|0);t=g;i=h;return t|0}else if((u<<24>>24|0)==86){v=a[n+1|0]|0;w=v&255;if((w|0)==50|(w|0)==49){y=(a[n+2|0]|0)==0|0}else if((w|0)==76){y=0}else{y=1}x=p+20|0;z=p+24|0;A=p+4|0;a:do{if((v-50&255)>>>0<2>>>0){B=n;C=g;D=0;while(1){c[k>>2]=(c[x>>2]|0)-16;c[l>>2]=C-12;if((FDb(c[z>>2]|0,k,B+12|0,l)|0)!=0){break}E=c[z>>2]|0;F=(c[x>>2]|0)-16-(c[k>>2]|0)|0;TGb(E+F|0,0,16)|0;if((c[A>>2]|0)==0){G=E;H=F;I=D;break a}if((F|0)<12){J=28;break a}if((a[E]|0)!=86){K=E+4|0;if(!((d[K]|d[K+1|0]<<8)<<16>>16<<16>>16==12)){J=31;break a}}K=E+6|0;L=E+8|0;M=yRa(b,(d[K]|d[K+1|0]<<8)<<16>>16&65535,(d[L]|d[L+1|0]<<8)<<16>>16&65535,d[E+10|0]|0)|0;if((M|0)<0){t=M;J=51;break}if((M|0)==0){N=D;O=F;P=E;J=35;break a}B=c[m>>2]|0;C=c[o>>2]|0;D=1}if((J|0)==51){i=h;return t|0}yDb(b,16,2049800,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else{D=n;C=g;B=0;while(1){E=D+12|0;F=C-12|0;if((c[A>>2]|0)==0){G=E;H=F;I=B;break a}if((F|0)<12){J=28;break a}if((a[E]|0)!=86){M=D+16|0;if(!((d[M]|d[M+1|0]<<8)<<16>>16<<16>>16==12)){J=31;break a}}M=D+18|0;L=D+20|0;K=yRa(b,(d[M]|d[M+1|0]<<8)<<16>>16&65535,(d[L]|d[L+1|0]<<8)<<16>>16&65535,d[D+22|0]|0)|0;if((K|0)<0){t=K;break}if((K|0)==0){N=B;O=F;P=E;J=35;break a}D=c[m>>2]|0;C=c[o>>2]|0;B=1}i=h;return t|0}}while(0);if((J|0)==28){yDb(b,16,2004128,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else if((J|0)==31){yDb(b,16,1966760,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else if((J|0)==35){G=P+12|0;H=O-12|0;I=N}A=p;if((y|I|0)==0){Q=e}else{KCb(c[A>>2]|0);Q=1}x=$$a(b,c[A>>2]|0)|0;if((x|0)<0){t=x;i=h;return t|0}if((Q|0)!=0){x=c[A>>2]|0;z=b+124|0;TGb(c[x>>2]|0,0,ba(c[x+32>>2]|0,c[z>>2]|0)|0)|0;x=c[A>>2]|0;TGb(c[x+4>>2]|0,-128|0,(ba(c[x+36>>2]|0,c[z>>2]|0)|0)/2|0|0)|0;x=c[A>>2]|0;TGb(c[x+8>>2]|0,-128|0,(ba(c[x+40>>2]|0,c[z>>2]|0)|0)/2|0|0)|0}z=c[A>>2]|0;c[z+88>>2]=(y|0)!=0?1:2;c[z+84>>2]=y;b:do{switch(w|0){case 50:case 49:{x=ZUa(p+544|0,z,G,H)|0;if((x|0)<0){t=x}else{break b}i=h;return t|0};case 51:case 48:{x=c[p+16>>2]|0;v=p+12|0;B=c[v>>2]|0;if((H|0)<((ba(x*3|0,B)|0)/2|0|0)){yDb(b,16,1938608,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;C=c[v>>2]|0;R=(((H|0)/(C|0)|0|0)/3|0)<<1;S=C}else{R=x;S=B}if((R|0)<=0){break b}B=c[A>>2]|0;OZ(j,G,0,S,R)|0;TZ(B,j,0,S,R);break};case 76:{break};case 78:{B=p+12|0;x=p+16|0;TGb(c[z>>2]|0,0,ba(c[x>>2]|0,c[B>>2]|0)|0)|0;TGb(c[(c[A>>2]|0)+4>>2]|0,-128|0,(ba(c[x>>2]|0,c[B>>2]|0)|0)/4|0|0)|0;TGb(c[(c[A>>2]|0)+8>>2]|0,-128|0,(ba(c[x>>2]|0,c[B>>2]|0)|0)/4|0|0)|0;break};default:{yDb(b,16,1914416,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}}}while(0);z=MCb(r,c[A>>2]|0)|0;if((z|0)<0){t=z;i=h;return t|0}c[f>>2]=1;t=g;i=h;return t|0}}while(0);yDb(b,16,2107216,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}function xRa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+24|0);JCb(b);return 0}function yRa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=c[a+60>>2]|0;j=b+1&-2;b=e+1&-2;if((f|0)>-1){e=h;k=(f|0)>1?f:1;l=0;do{c[e+28+(l<<2)>>2]=((d[1317544+l|0]|0)<<7|0)/(k|0)|0;c[e+284+(l<<2)>>2]=((d[1317608+l|0]|0)<<7|0)/(k|0)|0;l=l+1|0;}while((l|0)<64)}l=h+12|0;do{if((j|0)==(c[l>>2]|0)){if((b|0)!=(c[h+16>>2]|0)){break}if((c[h+8>>2]|0)==(f|0)){m=0;i=g;return m|0}$Ua(h+544|0,h+1264|0,j,b,h+28|0,h+284|0);m=0;i=g;return m|0}}while(0);f=((ba(j*3|0,b)|0)/2|0)+28|0;if((f|0)>268435455){m=-1;i=g;return m|0}k=a;e=hDb(b,j,0,k)|0;if((e|0)<0){m=e;i=g;return m|0}c[l>>2]=j;c[a+120>>2]=j;j=h+16|0;c[j>>2]=b;c[a+124>>2]=b;b=h+24|0;kEb(b,h+20|0,f);if((c[b>>2]|0)==0){yDb(k,16,1893920,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;m=-12;i=g;return m|0}else{$Ua(h+544|0,h+1264|0,c[l>>2]|0,c[j>>2]|0,h+28|0,h+284|0);KCb(c[h>>2]|0);m=1;i=g;return m|0}return 0}function zRa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a;TGb(e|0,0,960)|0;c[a>>2]=1781448;f=(b|0)!=0;do{if(f){g=c[b+8>>2]|0;c[a+8>>2]=g;c[a+48>>2]=c[b+12>>2];if((g|0)==1){h=8;break}else if((g|0)!=0){j=g;k=5;break}h=16}else{c[a+8>>2]=-1;j=-1;k=5}}while(0);if((k|0)==5){h=(j|0)==3?32:0}EEb(e,h,h);c[a+104>>2]=0;c[a+108>>2]=1;c[a+484>>2]=48;c[a+152>>2]=136;c[a+824>>2]=32;c[a+828>>2]=44;c[a+224>>2]=0;c[a+228>>2]=1;c[a+140>>2]=-1;c[a+420>>2]=-1;h=a+616|0;c[h>>2]=-1;c[h+4>>2]=-1;h=a+704|0;c[h>>2]=0;c[h+4>>2]=-2147483648;if(!f){l=0;i=d;return l|0}f=c[b+52>>2]|0;do{if((f|0)!=0){h=a+60|0;j=c[h>>2]|0;do{if((j|0)==0){g=cEb(f)|0;c[h>>2]=g;if((g|0)==0){l=-12}else{m=g;break}i=d;return l|0}else{m=j}}while(0);j=c[b+44>>2]|0;if((j|0)==0){break}c[m>>2]=j;DEb(c[h>>2]|0)}}while(0);m=c[b+68>>2]|0;if((m|0)==0){l=0;i=d;return l|0}else{n=m}while(1){m=c[n>>2]|0;if((m|0)==0){l=0;k=16;break}if((rEb(e,m,c[n+4>>2]|0,0)|0)>-1){n=n+8|0}else{k=15;break}}if((k|0)==15){yDb(0,0,2239768,(n=i,i=i+24|0,c[n>>2]=2318848,c[n+8>>2]=2184040,c[n+16>>2]=136,n)|0);i=n;Cd();return 0}else if((k|0)==16){i=d;return l|0}return 0}function ARa(a){a=a|0;var b=0,c=0,d=0;b=WDb(960)|0;c=b;do{if((b|0)==0){d=0}else{if((zRa(c,a)|0)>=0){d=c;break}ZDb(b);d=0}}while(0);return d|0}function BRa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;f=b;if((o0a(b)|0)!=0){yDb(f,16,2107152,(g=i,i=i+16|0,c[g>>2]=d,c[g+8>>2]=b,g)|0);i=g;h=-22;i=e;return h|0}HEb(f);g=b+60|0;ZDb(c[g>>2]|0);UGb(f|0,d|0,960)|0;c[g>>2]=0;c[b+12>>2]=0;c[b+220>>2]=0;c[b+712>>2]=0;c[b+64>>2]=0;g=b+536|0;c[g>>2]=0;f=b+96|0;c[f>>2]=0;j=b+300|0;c[j>>2]=0;k=b+304|0;c[k>>2]=0;l=b+532|0;c[l>>2]=0;m=c[d+536>>2]|0;do{if((m|0)!=0){n=eEb(m)|0;c[g>>2]=n;if((n|0)==0){h=-12}else{break}i=e;return h|0}}while(0);m=d+96|0;do{if((c[m>>2]|0)==0){o=9}else{n=d+100|0;p=c[n>>2]|0;if((p|0)<=0){o=9;break}q=WDb(p+16|0)|0;c[f>>2]=q;if((q|0)==0){break}p=c[n>>2]|0;UGb(q|0,c[m>>2]|0,p)|0;TGb(q+p|0,0,16)|0;o=9}}while(0);a:do{if((o|0)==9){m=d+300|0;if((c[m>>2]|0)!=0){p=WDb(128)|0;c[j>>2]=p;if((p|0)==0){break}UGb(p|0,c[m>>2]|0,128)|0}m=d+304|0;if((c[m>>2]|0)!=0){p=WDb(128)|0;c[k>>2]=p;if((p|0)==0){break}UGb(p|0,c[m>>2]|0,128)|0}m=d+532|0;do{if((c[m>>2]|0)!=0){p=d+528|0;q=c[p>>2]<<4;if((q|0)==0){break}n=WDb(q)|0;c[l>>2]=n;if((n|0)==0){break a}UGb(n|0,c[m>>2]|0,c[p>>2]<<4)|0}}while(0);m=d+860|0;if((c[m>>2]|0)==0){h=0;i=e;return h|0}p=d+864|0;n=c[p>>2]|0;if((n|0)<=0){h=0;i=e;return h|0}q=WDb(n+1|0)|0;c[b+860>>2]=q;if((q|0)==0){break}n=c[p>>2]|0;UGb(q|0,c[m>>2]|0,n)|0;a[q+n|0]=0;h=0;i=e;return h|0}}while(0);$Db(l);$Db(j);$Db(k);$Db(f);$Db(g);h=-12;i=e;return h|0}function CRa(){return 1781448}function DRa(){return 1781248}function ERa(a){a=a|0;var b=0,d=0,e=0;do{if((a|0)!=0){b=c[a+12>>2]|0;if((b|0)==0){break}d=c[b>>2]|0;if((d|0)==0){break}else{e=d}return e|0}}while(0);e=1984288;return e|0}function FRa(a,b){a=a|0;b=b|0;var d=0,e=0;do{if((b|0)==0){d=c[a+12>>2]|0;if((d|0)==0){break}if((c[d+44>>2]|0)==0){break}d=c[a+60>>2]|0;if((d|0)==0){break}else{e=d}return e|0}}while(0);e=0;return e|0}function GRa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;a:do{if((a|0)==0){b=0}else{d=0;while(1){e=Q$a(d)|0;if((e|0)==0){b=0;break a}if((c[e+44>>2]|0)==(a|0)){b=e;break}else{d=e}}}}while(0);while(1){a=Q$a(b)|0;if((a|0)==0){f=0;g=6;break}d=c[a+44>>2]|0;if((d|0)==0){b=a}else{f=d;g=6;break}}if((g|0)==6){return f|0}return 0}function HRa(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;do{if((b|0)!=0){if((c[b+88>>2]|0)==0){break}else{d=6}return d|0}}while(0);d=5;return d|0}function IRa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a+60|0;e=c[d>>2]|0;f=a+124|0;do{if((c[f>>2]&3|0)==0){g=a+120|0;if((c[g>>2]&3|0)!=0){break}c[a+140>>2]=11;h=ICb()|0;c[e>>2]=h;if((h|0)==0){j=-12;i=b;return j|0}h=e+36|0;c[h>>2]=ba((c[f>>2]|0)+255&-256,c[g>>2]|0)|0;c[e+40>>2]=ba(c[g>>2]|0,c[f>>2]|0)|0;g=e+20|0;k=0;while(1){if((k|0)>=4){j=0;l=9;break}m=cEb(c[h>>2]|0)|0;c[g+(k<<2)>>2]=m;if((m|0)==0){break}else{k=k+1|0}}if((l|0)==9){i=b;return j|0}k=c[d>>2]|0;JCb(k);$Db(k+20|0);$Db(k+24|0);$Db(k+28|0);$Db(k+32|0);j=-12;i=b;return j|0}}while(0);yDb(a,16,1893792,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-1094995529;i=b;return j|0}function JRa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;h=i;j=b+60|0;k=c[j>>2]|0;l=k;m=$$a(b,c[l>>2]|0)|0;if((m|0)<0){n=m;i=h;return n|0}m=g+24|0;o=c[m>>2]|0;p=g+28|0;g=c[p>>2]|0;if(!((g|0)>-1)){yDb(0,0,1966448,(q=i,i=i+24|0,c[q>>2]=1938440,c[q+8>>2]=1914264,c[q+16>>2]=135,q)|0);i=q;Cd();return 0}r=k+4|0;c[r>>2]=o;c[k+12>>2]=o;s=k+8|0;c[s>>2]=o+g;do{if((g|0)<1){t=0;u=0;v=7}else{c[r>>2]=o+1;w=a[o]|0;y=w&255;if((y&32|0)==0){t=y;u=w;v=7;break}z=k+36|0;TGb(c[k+20>>2]|0,0,c[z>>2]|0)|0;TGb(c[k+24>>2]|0,0,c[z>>2]|0)|0;TGb(c[k+28>>2]|0,0,c[z>>2]|0)|0;TGb(c[k+32>>2]|0,0,c[z>>2]|0)|0;TGb(c[(c[l>>2]|0)+4>>2]|0,0,1024)|0;c[k+16>>2]=0;z=c[l>>2]|0;c[z+84>>2]=1;c[z+88>>2]=1;A=y;B=w;C=z}}while(0);if((v|0)==7){o=c[l>>2]|0;c[o+84>>2]=0;c[o+88>>2]=2;A=t;B=u;C=o}if((A&64|0)!=0){o=c[C+4>>2]|0;u=c[r>>2]|0;t=c[s>>2]|0;if((t-u|0)<1){D=0;E=u}else{g=u+1|0;c[r>>2]=g;D=d[u]|0;E=g}if((t-E|0)<1){F=1;G=E}else{g=E+1|0;c[r>>2]=g;F=(d[E]|0)+1|0;G=g}if((F+D|0)>256){n=-1094995529;i=h;return n|0}if((t-G|0)>>>0<(F*3|0)>>>0){n=-1094995529;i=h;return n|0}if((F|0)>0){t=o+(D<<2)|0;D=0;o=G;while(1){G=o+1|0;c[r>>2]=G;g=d[o]|0;E=o+2|0;c[r>>2]=E;u=d[G]|0;G=o+3|0;c[r>>2]=G;z=d[E]|0;c[t>>2]=(g<<2|g>>>4)<<16|z>>>4|z<<2|(u<<2|u>>>4)<<8|-16777216;u=D+1|0;if((u|0)<(F|0)){t=t+4|0;D=u;o=G}else{break}}}c[C+304>>2]=1}C=A&15;a:do{if((C|0)==4){A=c[k+20+(c[k+16>>2]<<2)>>2]|0;o=c[k+40>>2]|0;D=A+o|0;t=c[s>>2]|0;F=c[r>>2]|0;G=t-F|0;u=F+(G>>>0>2>>>0?2:G)|0;c[r>>2]=u;if((o|0)>0){H=A;I=u;J=t}else{break}while(1){t=J;if((t-I|0)>>>0<2>>>0){n=-1094995529;v=135;break}u=I+1|0;c[r>>2]=u;A=a[I]|0;o=(A&255)<<24;G=A<<24>>24;A=((o|0)>-16777216?G:-G|0)+1|0;G=H+A|0;if(G>>>0>D>>>0){n=-1094995529;v=135;break}if((o|0)<0){c[r>>2]=I+2;TGb(H|0,a[u]|0,A|0)|0}else{o=t-u|0;t=o>>>0>A>>>0?A:o;UGb(H|0,u|0,t)|0;c[r>>2]=(c[r>>2]|0)+t}if(!(G>>>0<D>>>0)){break a}H=G;I=c[r>>2]|0;J=c[s>>2]|0}if((v|0)==135){i=h;return n|0}}else if((C|0)==2){D=c[r>>2]|0;do{if(((c[s>>2]|0)-D|0)<1){K=0}else{c[r>>2]=D+1;G=a[D]|0;if((G&255)>>>0>3>>>0){n=-1094995529}else{K=G&255;break}i=h;return n|0}}while(0);D=c[k+16>>2]|0;if((K|0)==(D|0)){break}G=k+20|0;UGb(c[G+(D<<2)>>2]|0,c[G+(K<<2)>>2]|0,c[k+36>>2]|0)|0}else if((C|0)==1){G=c[k+20+(c[k+16>>2]<<2)>>2]|0;D=c[r>>2]|0;t=c[s>>2]|0;u=t-D|0;o=D+(u>>>0>2>>>0?2:u)|0;c[r>>2]=o;u=c[k+40>>2]|0;if((t-o|0)>>>0<u>>>0){n=-1094995529;i=h;return n|0}else{UGb(G|0,o|0,u)|0;c[r>>2]=(c[r>>2]|0)+u;break}}else if((C|0)==0){u=c[m>>2]|0;o=c[j>>2]|0;G=o+8|0;t=c[G>>2]|0;D=o+4|0;A=c[D>>2]|0;F=t;b:do{if((F-A|0)>=1){z=A+1|0;c[D>>2]=z;g=a[A]|0;E=g&255;if(g<<24>>24==0){break}do{if((B&16)==0){L=z}else{g=z;w=g-(c[o+12>>2]|0)&3;if((w|0)==0){L=z;break}y=4-w|0;w=F-g|0;g=A+((w>>>0>y>>>0?y:w)+1)|0;c[D>>2]=g;L=g}}while(0);z=o+20|0;g=b+120|0;w=o+36|0;y=E;M=t;N=L;c:while(1){O=M;if((O-N|0)<1){P=0;Q=N}else{R=N+1|0;c[D>>2]=R;P=d[N]|0;Q=R}if((O-Q|0)<1){S=0;T=Q}else{R=Q+1|0;c[D>>2]=R;S=d[Q]|0;T=R}R=c[z+(P>>>6<<2)>>2]|0;U=c[g>>2]|0;V=S<<1&254;W=(ba(U<<1,S>>>7|P<<1&126)|0)+V|0;X=c[w>>2]|0;Y=R+X|0;if((O-T|0)<2){Z=0}else{c[D>>2]=T+2;O=T;Z=(d[O]|d[O+1|0]<<8)<<16>>16&65535}O=Z+V|0;if((W+((U*3|0)+4)|0)>(X|0)){n=-1094995529;v=135;break}X=R+W|0;W=V|1;while(1){V=c[j>>2]|0;R=V+8|0;U=V+4|0;V=c[U>>2]|0;_=(c[R>>2]|0)-V|0;$=_>>>0>4>>>0?4:_;UGb(X|0,V|0,$)|0;V=(c[U>>2]|0)+$|0;c[U>>2]=V;$=c[g>>2]|0;_=(c[R>>2]|0)-V|0;aa=_>>>0>4>>>0?4:_;UGb(X+$|0,V|0,aa)|0;V=(c[U>>2]|0)+aa|0;c[U>>2]=V;aa=(c[g>>2]|0)+$|0;$=(c[R>>2]|0)-V|0;_=$>>>0>4>>>0?4:$;UGb(X+aa|0,V|0,_)|0;V=(c[U>>2]|0)+_|0;c[U>>2]=V;_=(c[R>>2]|0)-V|0;R=_>>>0>4>>>0?4:_;UGb(X+((c[g>>2]|0)+aa)|0,V|0,R)|0;c[U>>2]=(c[U>>2]|0)+R;if((W&63|0)==0){ca=X+((c[g>>2]|0)*3|0)|0}else{ca=X}if(!(W>>>0<O>>>0)){break}if((ca+(((c[g>>2]|0)*3|0)+8)|0)>>>0>Y>>>0){n=-1094995529;v=135;break c}else{X=ca+4|0;W=W+1|0}}W=y-1|0;if((W|0)==0){break b}y=W;M=c[G>>2]|0;N=c[D>>2]|0}if((v|0)==135){i=h;return n|0}}}while(0);t=o+16|0;A=o+20|0;F=c[A+(c[t>>2]<<2)>>2]|0;N=o+36|0;M=F+(c[N>>2]|0)|0;y=b+120|0;g=o+40|0;w=1;z=F;while(1){F=c[D>>2]|0;E=c[G>>2]|0;if((E-F|0)<1){da=0;ea=F}else{W=F+1|0;c[D>>2]=W;da=d[F]|0;ea=W}if((E-ea|0)<1){fa=0}else{c[D>>2]=ea+1;fa=d[ea]|0}E=c[A+(da>>>6<<2)>>2]|0;W=c[y>>2]|0;F=W<<1;X=(ba(F,fa>>>7|da<<1&126)|0)+(fa<<1&254)|0;ga=E+X|0;Y=c[N>>2]|0;ha=E+Y|0;O=(W*3|0)+4|0;if((X+O|0)>(Y|0)){n=-1094995529;v=135;break}if((z+O|0)>>>0>M>>>0){n=-1094995529;v=135;break}O=ga;Y=z;x=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;Y=E+(X+W)|0;O=z+W|0;x=d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;O=E+(X+F)|0;Y=z+F|0;x=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;Y=F+W|0;W=E+(X+Y)|0;X=z+Y|0;x=d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;if((w&63|0)==0){ia=z+((c[y>>2]|0)*3|0)|0}else{ia=z}if((w|0)>=((c[g>>2]|0)/16|0|0)){v=51;break}w=w+1|0;z=ia+4|0}if((v|0)==51){z=c[D>>2]|0;w=c[G>>2]|0;if((w-z|0)<2){ja=0;ka=z}else{g=z+2|0;c[D>>2]=g;M=z;ja=(d[M]|d[M+1|0]<<8)<<16>>16&65535;ka=g}g=w-ka|0;M=g>>>0>2>>>0?2:g;g=ka+M|0;c[D>>2]=g;z=g;if((w-z|0)>>>0<ja>>>0){n=-1094995529;i=h;return n|0}w=z-(c[o+12>>2]|0)|0;c[D>>2]=ka+(M+ja);M=b+124|0;z=c[M>>2]|0;if((z|0)<=0){break}g=c[A+(c[t>>2]<<2)>>2]|0;X=0;W=ga;Y=ha;E=0;F=0;O=c[y>>2]|0;R=z;d:while(1){if((O|0)>0){z=g;U=X;V=W;aa=Y;_=0;$=F;while(1){if($>>>0>ja>>>0){n=-1094995529;v=135;break d}la=d[u+(w+$)|0]|0;if((_&4|0)==0){ma=la>>>4;na=$}else{ma=la&15;na=$+1|0}la=0;oa=aa;pa=V;qa=U;e:while(1){ra=la;sa=oa;ta=pa;f:while(1){ua=ra;g:while(1){va=a[1680328+(ma<<3)+ua|0]|0;if(va<<24>>24==0){break e}wa=c[y>>2]|0;xa=wa<<1;ya=ua+1|0;switch(va&255|0){case 4:{v=69;break f;break};case 5:{v=87;break g;break};case 6:{za=xa;v=88;break g;break};case 2:{v=66;break f;break};case 3:{Aa=xa;v=67;break f;break};case 7:{Ba=sa;Ca=ta;Da=xa;break g;break};default:{ua=ya}}}if((v|0)==87){v=0;za=0;v=88}if((v|0)==88){v=0;ua=c[D>>2]|0;va=c[G>>2]|0;if((va-ua|0)<1){Ea=0;Fa=ua}else{Ga=ua+1|0;c[D>>2]=Ga;Ea=d[ua]|0;Fa=Ga}if((va-Fa|0)<1){Ha=0}else{c[D>>2]=Fa+1;Ha=d[Fa]|0}va=c[A+(Ea>>>6<<2)>>2]|0;Ga=va+((ba(Ha>>>7|Ea<<1&126,xa)|0)+(Ha<<1&254))|0;Ba=va+(c[N>>2]|0)|0;Ca=Ga;Da=za}if((Ca+(wa+4+Da)|0)>>>0>Ba>>>0){n=-1094995529;v=135;break d}Ga=c[D>>2]|0;if(((c[G>>2]|0)-Ga|0)<1){ra=ya;sa=Ba;ta=Ca;continue}c[D>>2]=Ga+1;va=d[Ga]|0;Ga=va>>>4;if((Ga&8|0)!=0){a[z+Da|0]=a[Ca+Da|0]|0}if((va&8|0)!=0){ua=(c[y>>2]|0)+Da|0;a[z+ua|0]=a[Ca+ua|0]|0}if((Ga&4|0)!=0){ua=Da+1|0;a[z+ua|0]=a[Ca+ua|0]|0}if((va&4|0)!=0){ua=Da+1+(c[y>>2]|0)|0;a[z+ua|0]=a[Ca+ua|0]|0}if((Ga&2|0)!=0){ua=Da+2|0;a[z+ua|0]=a[Ca+ua|0]|0}if((va&2|0)!=0){ua=Da+2+(c[y>>2]|0)|0;a[z+ua|0]=a[Ca+ua|0]|0}if((Ga&1|0)!=0){Ga=Da+3|0;a[z+Ga|0]=a[Ca+Ga|0]|0}if((va&1|0)==0){ra=ya;sa=Ba;ta=Ca;continue}va=Da+3+(c[y>>2]|0)|0;a[z+va|0]=a[Ca+va|0]|0;ra=ya;sa=Ba;ta=Ca}if((v|0)==66){v=0;Aa=0;v=67}else if((v|0)==69){v=0;Ia=qa;Ja=xa;Ka=c[G>>2]|0;La=c[D>>2]|0}do{if((v|0)==67){v=0;ra=c[G>>2]|0;va=c[D>>2]|0;if((ra-va|0)<1){Ia=0;Ja=Aa;Ka=ra;La=va;break}Ga=va+1|0;c[D>>2]=Ga;Ia=a[va]|0;Ja=Aa;Ka=ra;La=Ga}}while(0);if((Ka-La|0)<1){la=ya;oa=sa;pa=ta;qa=Ia;continue}c[D>>2]=La+1;Ga=d[La]|0;ra=Ga>>>4;if((ra&8|0)!=0){a[z+Ja|0]=Ia}if((Ga&8|0)!=0){a[z+((c[y>>2]|0)+Ja)|0]=Ia}if((ra&4|0)!=0){a[z+(Ja+1)|0]=Ia}if((Ga&4|0)!=0){a[z+(Ja+1+(c[y>>2]|0))|0]=Ia}if((ra&2|0)!=0){a[z+(Ja+2)|0]=Ia}if((Ga&2|0)!=0){a[z+(Ja+2+(c[y>>2]|0))|0]=Ia}if((ra&1|0)!=0){a[z+(Ja+3)|0]=Ia}if((Ga&1|0)==0){la=ya;oa=sa;pa=ta;qa=Ia;continue}a[z+(Ja+3+(c[y>>2]|0))|0]=Ia;la=ya;oa=sa;pa=ta;qa=Ia}pa=_+4|0;Ma=z+4|0;Na=c[y>>2]|0;if((pa|0)<(Na|0)){z=Ma;U=qa;V=ta;aa=sa;_=pa;$=na}else{break}}Oa=Ma;Pa=qa;Qa=ta;Ra=sa;Sa=na;Ta=Na;Ua=c[M>>2]|0}else{Oa=g;Pa=X;Qa=W;Ra=Y;Sa=F;Ta=O;Ua=R}$=E+4|0;if(($|0)<(Ua|0)){g=Oa+(Ta*3|0)|0;X=Pa;W=Qa;Y=Ra;E=$;F=Sa;O=Ta;R=Ua}else{break a}}if((v|0)==135){i=h;return n|0}}else if((v|0)==135){i=h;return n|0}}else{DDb(b,2003928,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}}while(0);q=k+16|0;v=b+124|0;if((c[v>>2]|0)>0){Ua=b+120|0;b=0;Ta=c[k+20+(c[q>>2]<<2)>>2]|0;k=c[c[l>>2]>>2]|0;Sa=c[Ua>>2]|0;while(1){UGb(k|0,Ta|0,Sa)|0;Ra=c[l>>2]|0;Qa=c[Ua>>2]|0;Pa=b+1|0;if((Pa|0)<(c[v>>2]|0)){b=Pa;Ta=Ta+Qa|0;k=k+(c[Ra+32>>2]|0)|0;Sa=Qa}else{Va=Ra;break}}}else{Va=c[l>>2]|0}c[q>>2]=(c[q>>2]|0)+1&3;q=MCb(e,Va)|0;if((q|0)<0){n=q;i=h;return n|0}c[f>>2]=1;n=c[p>>2]|0;i=h;return n|0}function KRa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b);$Db(b+20|0);$Db(b+24|0);$Db(b+28|0);$Db(b+32|0);return 0}function LRa(a){a=a|0;var b=0,d=0,e=0;b=i;if((c[a+416>>2]|0)==2){d=a+448|0;c[d>>2]=3;c[d+4>>2]=0;c[a+420>>2]=1;e=0;i=b;return e|0}else{yDb(a,16,2049568,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1094995529;i=b;return e|0}return 0}function MRa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=c[g+24>>2]|0;i=g+28|0;g=c[i>>2]|0;j=(g|0)/4922|0;if((g|0)<4922){k=-1094995529;return k|0}c[e+76>>2]=j*2205|0;g=_$a(a,e,0)|0;if((g|0)<0){k=g;return k|0}g=c[e>>2]|0;e=h;h=0;while(1){a=g;l=e+512|0;m=0;while(1){n=e+((d[l]|0)<<1)|0;b[a>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=e+((d[l+1|0]|0)<<1)|0;b[a+2>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=m+1|0;if((n|0)<2205){a=a+4|0;l=l+2|0;m=n}else{break}}m=h+1|0;if((m|0)<(j|0)){g=g+8820|0;e=e+4922|0;h=m}else{break}}c[f>>2]=1;k=c[i>>2]|0;return k|0}function NRa(a){a=a|0;var b=0,d=0;b=ICb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+88>>2]=1;c[b+84>>2]=1;d=0;return d|0}function ORa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=i;j=c[b+124>>2]|0;k=c[b+120>>2]|0;l=b+140|0;switch(c[l>>2]|0){case 66:{m=2049552;n=255;o=2;p=k<<1;break};case 10:{m=2183920;n=1;o=1;p=k;break};case 2:{m=2003920;n=255;o=3;p=k*3|0;break};case 291:{m=1966432;n=65535;o=4;p=k<<3;break};case 31:{m=2106936;n=65535;o=1;p=k<<1;break};case 8:{m=2106936;n=255;o=1;p=k;break};case 41:{m=2003920;n=65535;o=3;p=k*6|0;break};case 28:{m=1966432;n=255;o=4;p=k<<2;break};default:{q=-1;i=h;return q|0}}r=ba(p,j)|0;s=r+200|0;t=r0a(b,e,s,(s|0)<0|0?-1:0)|0;if((t|0)<0){q=t;i=h;return q|0}t=c[e+24>>2]|0;s=e+28|0;b=t;Lb(t|0,c[s>>2]|0,1938376,(u=i,i=i+40|0,c[u>>2]=k,c[u+8>>2]=j,c[u+16>>2]=o,c[u+24>>2]=n,c[u+32>>2]=m,u)|0)|0;i=u;u=SGb(t|0)|0;m=t+u|0;n=c[f>>2]|0;o=c[f+32>>2]|0;f=(j|0)>0;do{if((c[l>>2]|0)==10){if(f&(k|0)>0){v=0;w=m;x=n}else{y=m;break}while(1){z=w;A=0;while(1){a[z]=(d[x+(A>>3)|0]|0)>>>((7-A&7)>>>0)&1;B=A+1|0;if((B|0)<(k|0)){z=z+1|0;A=B}else{break}}A=w+k|0;z=v+1|0;if((z|0)<(j|0)){v=z;w=A;x=x+o|0}else{y=A;break}}}else{if(!f){y=m;break}A=u+r|0;z=0;B=m;C=n;while(1){UGb(B|0,C|0,p)|0;D=z+1|0;if((D|0)<(j|0)){z=D;B=B+p|0;C=C+o|0}else{break}}y=t+A|0}}while(0);c[s>>2]=y-b;b=e+36|0;c[b>>2]=c[b>>2]|1;c[g>>2]=1;q=0;i=h;return q|0}function PRa(a){a=a|0;JCb(a+804|0);return 0}function QRa(a){a=a|0;var b=0,d=0;b=a+40|0;d=a;do{a=c[2220796]|0;c[b>>2]=a;}while((a|0)!=((D=c[2220796]|0,(c[2220796]|0)==(a|0)?(c[2220796]=d)|0:0,D)|0));return}function RRa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((a|0)==0){b=0;return b|0}else{d=8883184}while(1){e=c[d>>2]|0;if((e|0)==0){b=0;f=15;break}if((c[e>>2]|0)==(a|0)){break}if((c[e+4>>2]|0)==(a|0)){break}if((c[e+8>>2]|0)==(a|0)){break}if((c[e+12>>2]|0)==(a|0)){break}if((c[e+16>>2]|0)==(a|0)){break}else{d=e+40|0}}if((f|0)==15){return b|0}f=cEb(320)|0;d=f;if((f|0)!=0){c[f+4>>2]=e;a=cEb(c[e+20>>2]|0)|0;c[f>>2]=a;do{if((a|0)!=0){c[f+72>>2]=1;c[f+32>>2]=1;g=c[e+24>>2]|0;if((g|0)!=0){if((re[g&4095](d)|0)!=0){break}}c[f+224>>2]=-1;g=f+232|0;c[g>>2]=0;c[g+4>>2]=0;c[f+240>>2]=-2147483648;c[f+244>>2]=-2147483648;c[f+248>>2]=-2147483648;b=d;return b|0}}while(0);$Db(f)}ZDb(f);b=0;return b|0}function SRa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=a+40|0;c[e>>2]=0;c[e+4>>2]=-2147483648;f=a+48|0;c[f>>2]=0;c[f+4>>2]=-2147483648;g=a+288|0;c[g>>2]=-1;c[g+4>>2]=-1;h=a+184|0;c[h>>2]=0;c[h+4>>2]=0;i=a+16|0;j=b;k=(b|0)<0|0?-1:0;b=a+8|0;l=a+24|0;m=c[i>>2]|0;n=c[i+4>>2]|0;if((d|0)==0){d=0;a:while(1){o=YGb(m,n,j,k)|0;p=F;q=a+80+(d<<3)|0;r=c[q>>2]|0;s=c[q+4>>2]|0;do{if(!((p|0)<(s|0)|(p|0)==(s|0)&o>>>0<r>>>0)){t=c[b>>2]|0;u=c[b+4>>2]|0;if(!((u|0)<(s|0)|(u|0)==(s|0)&t>>>0<r>>>0)){if(!((t|0)==0&(u|0)==0)){break}if(!((c[l>>2]|0)==0&(c[l+4>>2]|0)==0)){break}}u=a+192+(d<<3)|0;if((c[u>>2]|0)==0&(c[u+4>>2]|0)==0){break}t=a+144+(d<<3)|0;v=c[t+4>>2]|0;c[f>>2]=c[t>>2];c[f+4>>2]=v;v=a+112+(d<<3)|0;t=c[v+4>>2]|0;c[e>>2]=c[v>>2];c[e+4>>2]=t;t=a+256+(d<<3)|0;v=c[t+4>>2]|0;c[g>>2]=c[t>>2];c[g+4>>2]=v;v=ZGb(c[l>>2]|0,c[l+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[h>>2]=v;c[h+4>>2]=F;v=c[u+4>>2]|0;if((p|0)<(v|0)|(p|0)==(v|0)&o>>>0<(c[u>>2]|0)>>>0){w=16;break a}}}while(0);o=d+1|0;if((o|0)<4){d=o}else{w=16;break}}if((w|0)==16){return}}else{d=0;o=n;n=m;b:while(1){m=YGb(n,o,j,k)|0;p=F;q=a+80+(d<<3)|0;r=c[q>>2]|0;s=c[q+4>>2]|0;do{if((p|0)<(s|0)|(p|0)==(s|0)&m>>>0<r>>>0){x=o;y=n}else{u=c[b>>2]|0;v=c[b+4>>2]|0;if(!((v|0)<(s|0)|(v|0)==(s|0)&u>>>0<r>>>0)){if(!((u|0)==0&(v|0)==0)){x=o;y=n;break}if(!((c[l>>2]|0)==0&(c[l+4>>2]|0)==0)){x=o;y=n;break}}v=a+192+(d<<3)|0;if((c[v>>2]|0)==0&(c[v+4>>2]|0)==0){x=o;y=n;break}u=a+144+(d<<3)|0;t=c[u+4>>2]|0;c[f>>2]=c[u>>2];c[f+4>>2]=t;t=a+112+(d<<3)|0;u=c[t+4>>2]|0;c[e>>2]=c[t>>2];c[e+4>>2]=u;u=a+256+(d<<3)|0;t=c[u+4>>2]|0;c[g>>2]=c[u>>2];c[g+4>>2]=t;t=ZGb(c[l>>2]|0,c[l+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[h>>2]=t;c[h+4>>2]=F;c[q>>2]=-1;c[q+4>>2]=2147483647;t=c[i>>2]|0;u=c[i+4>>2]|0;z=YGb(t,u,j,k)|0;A=F;B=c[v+4>>2]|0;if((A|0)<(B|0)|(A|0)==(B|0)&z>>>0<(c[v>>2]|0)>>>0){w=16;break b}else{x=u;y=t}}}while(0);q=d+1|0;if((q|0)<4){d=q;o=x;n=y}else{w=16;break}}if((w|0)==16){return}}}function TRa(a,b,d,e,f,g,h,j,k,l,m,n){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;o=i;i=i+16|0;p=a+176|0;q=c[p>>2]|0;if((q&4|0)==0){r=a+16|0;c[r>>2]=m;c[r+4>>2]=n;r=a+24|0;c[r>>2]=m;c[r+4>>2]=n;c[p>>2]=q|4}do{if((g|0)==0){q=o|0;TGb(q|0,0,16)|0;s=q}else{q=a+16|0;p=c[q>>2]|0;r=c[q+4>>2]|0;t=g;u=(g|0)<0|0?-1:0;v=YGb(p,r,t,u)|0;w=a+76|0;x=c[w>>2]|0;y=a+192+(x<<3)|0;if((v|0)==(c[y>>2]|0)&(F|0)==(c[y+4>>2]|0)){s=f;break}y=x+1&3;c[w>>2]=y;w=a+80+(y<<3)|0;c[w>>2]=p;c[w+4>>2]=r;r=YGb(c[q>>2]|0,c[q+4>>2]|0,t,u)|0;u=a+192+(y<<3)|0;c[u>>2]=r;c[u+4>>2]=F;u=a+112+(y<<3)|0;c[u>>2]=h;c[u+4>>2]=j;u=a+144+(y<<3)|0;c[u>>2]=k;c[u+4>>2]=l;u=a+256+(y<<3)|0;c[u>>2]=m;c[u+4>>2]=n;s=f}}while(0);f=a+72|0;a:do{if((c[f>>2]|0)!=0){c[f>>2]=0;n=a+40|0;m=c[n+4>>2]|0;l=a+56|0;c[l>>2]=c[n>>2];c[l+4>>2]=m;m=a+48|0;l=c[m+4>>2]|0;k=a+64|0;c[k>>2]=c[m>>2];c[k+4>>2]=l;l=a+288|0;k=c[l+4>>2]|0;j=a+296|0;c[j>>2]=c[l>>2];c[j+4>>2]=k;c[n>>2]=0;c[n+4>>2]=-2147483648;c[m>>2]=0;c[m+4>>2]=-2147483648;c[l>>2]=-1;c[l+4>>2]=-1;k=a+184|0;c[k>>2]=0;c[k+4>>2]=0;j=a+16|0;h=a+8|0;u=a+24|0;y=c[j>>2]|0;r=c[j+4>>2]|0;j=a+80|0;t=c[j>>2]|0;q=c[j+4>>2]|0;do{if(!((r|0)<(q|0)|(r|0)==(q|0)&y>>>0<t>>>0)){j=c[h>>2]|0;w=c[h+4>>2]|0;if(!((w|0)<(q|0)|(w|0)==(q|0)&j>>>0<t>>>0)){if(!((j|0)==0&(w|0)==0)){break}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==0)){break}}w=a+192|0;j=c[w>>2]|0;p=c[w+4>>2]|0;if((j|0)==0&(p|0)==0){break}w=a+144|0;x=c[w+4>>2]|0;c[m>>2]=c[w>>2];c[m+4>>2]=x;x=a+112|0;w=c[x+4>>2]|0;c[n>>2]=c[x>>2];c[n+4>>2]=w;w=a+256|0;x=c[w+4>>2]|0;c[l>>2]=c[w>>2];c[l+4>>2]=x;x=ZGb(c[u>>2]|0,c[u+4>>2]|0,t,q)|0;c[k>>2]=x;c[k+4>>2]=F;if((r|0)<(p|0)|(r|0)==(p|0)&y>>>0<j>>>0){break a}}}while(0);q=a+88|0;t=c[q>>2]|0;j=c[q+4>>2]|0;do{if(!((r|0)<(j|0)|(r|0)==(j|0)&y>>>0<t>>>0)){q=c[h>>2]|0;p=c[h+4>>2]|0;if(!((p|0)<(j|0)|(p|0)==(j|0)&q>>>0<t>>>0)){if(!((q|0)==0&(p|0)==0)){break}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==0)){break}}p=a+200|0;q=c[p>>2]|0;x=c[p+4>>2]|0;if((q|0)==0&(x|0)==0){break}p=a+152|0;w=c[p+4>>2]|0;c[m>>2]=c[p>>2];c[m+4>>2]=w;w=a+120|0;p=c[w+4>>2]|0;c[n>>2]=c[w>>2];c[n+4>>2]=p;p=a+264|0;w=c[p+4>>2]|0;c[l>>2]=c[p>>2];c[l+4>>2]=w;w=ZGb(c[u>>2]|0,c[u+4>>2]|0,t,j)|0;c[k>>2]=w;c[k+4>>2]=F;if((r|0)<(x|0)|(r|0)==(x|0)&y>>>0<q>>>0){break a}}}while(0);j=a+96|0;t=c[j>>2]|0;q=c[j+4>>2]|0;do{if(!((r|0)<(q|0)|(r|0)==(q|0)&y>>>0<t>>>0)){j=c[h>>2]|0;x=c[h+4>>2]|0;if(!((x|0)<(q|0)|(x|0)==(q|0)&j>>>0<t>>>0)){if(!((j|0)==0&(x|0)==0)){break}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==0)){break}}x=a+208|0;j=c[x>>2]|0;w=c[x+4>>2]|0;if((j|0)==0&(w|0)==0){break}x=a+160|0;p=c[x+4>>2]|0;c[m>>2]=c[x>>2];c[m+4>>2]=p;p=a+128|0;x=c[p+4>>2]|0;c[n>>2]=c[p>>2];c[n+4>>2]=x;x=a+272|0;p=c[x+4>>2]|0;c[l>>2]=c[x>>2];c[l+4>>2]=p;p=ZGb(c[u>>2]|0,c[u+4>>2]|0,t,q)|0;c[k>>2]=p;c[k+4>>2]=F;if((r|0)<(w|0)|(r|0)==(w|0)&y>>>0<j>>>0){break a}}}while(0);q=a+104|0;t=c[q>>2]|0;j=c[q+4>>2]|0;if((r|0)<(j|0)|(r|0)==(j|0)&y>>>0<t>>>0){break}q=c[h>>2]|0;w=c[h+4>>2]|0;if(!((w|0)<(j|0)|(w|0)==(j|0)&q>>>0<t>>>0)){if(!((q|0)==0&(w|0)==0)){break}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==0)){break}}w=a+216|0;if((c[w>>2]|0)==0&(c[w+4>>2]|0)==0){break}w=a+168|0;q=c[w+4>>2]|0;c[m>>2]=c[w>>2];c[m+4>>2]=q;q=a+136|0;w=c[q+4>>2]|0;c[n>>2]=c[q>>2];c[n+4>>2]=w;w=a+280|0;q=c[w+4>>2]|0;c[l>>2]=c[w>>2];c[l+4>>2]=q;q=ZGb(c[u>>2]|0,c[u+4>>2]|0,t,j)|0;c[k>>2]=q;c[k+4>>2]=F}}while(0);q=oe[c[(c[a+4>>2]|0)+28>>2]&63](a,b,d,e,s,g)|0;if((c[e>>2]|0)==0){e=a+16|0;z=c[e+4>>2]|0;A=c[e>>2]|0;B=(q|0)<0;C=B?0:q;D=C;E=(C|0)<0|0?-1:0;G=a+16|0;H=YGb(A,z,D,E)|0;I=F;J=G|0;c[J>>2]=H;K=G+4|0;c[K>>2]=I;i=o;return C|0}else{e=a+24|0;g=c[e+4>>2]|0;s=a+8|0;c[s>>2]=c[e>>2];c[s+4>>2]=g;g=a+16|0;s=c[g>>2]|0;d=c[g+4>>2]|0;g=YGb(s,d,q,(q|0)<0|0?-1:0)|0;c[e>>2]=g;c[e+4>>2]=F;c[f>>2]=1;z=d;A=s;B=(q|0)<0;C=B?0:q;D=C;E=(C|0)<0|0?-1:0;G=a+16|0;H=YGb(A,z,D,E)|0;I=F;J=G|0;c[J>>2]=H;K=G+4|0;c[K>>2]=I;i=o;return C|0}return 0}function URa(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;do{if((a|0)==0){i=f;j=g}else{k=c[(c[a+4>>2]|0)+36>>2]|0;if((k|0)==0){i=f;j=g;break}if((c[b+88>>2]&4194304|0)==0){if((c[b+92>>2]&8|0)==0){i=f;j=g;break}}l=ze[k&511](b,f,g)|0;i=f+l|0;j=g-l|0}}while(0);c[d>>2]=i;c[e>>2]=j;g=b+96|0;if((c[g>>2]|0)==0|(h|0)==0){m=0;return m|0}if((c[b+92>>2]&8|0)==0){m=0;return m|0}h=b+100|0;b=(c[h>>2]|0)+j|0;c[e>>2]=b;e=WDb(b+16|0)|0;c[d>>2]=e;d=c[h>>2]|0;UGb(e|0,c[g>>2]|0,d)|0;UGb(e+d|0,i|0,j+16|0)|0;m=1;return m|0}function VRa(a){a=a|0;var b=0;if((a|0)==0){return}b=c[(c[a+4>>2]|0)+32>>2]|0;if((b|0)!=0){me[b&511](a)}ZDb(c[a>>2]|0);ZDb(a);return}function WRa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=b+24|0;if((c[h>>2]|0)>0){i=b+28|0;j=b|0;k=b+4|0;while(1){l=c[i>>2]|0;c[i>>2]=l+1;m=c[j>>2]|0;n=a[m+l|0]|0;l=c[k>>2]|0;c[k>>2]=l+1;a[m+l|0]=n;n=(c[h>>2]|0)-1|0;c[h>>2]=n;if((n|0)<=0){o=k;break}}}else{o=b+4|0}k=(c[g>>2]|0)==0&(e|0)==-100?0:e;e=c[o>>2]|0;j=b+8|0;c[j>>2]=e;if((k|0)==-100){i=b|0;n=jEb(c[i>>2]|0,b+12|0,(c[g>>2]|0)+16+e|0)|0;if((n|0)==0){c[o>>2]=0;p=-12;return p|0}else{c[i>>2]=n;UGb(n+(c[o>>2]|0)|0,c[f>>2]|0,c[g>>2]|0)|0;c[o>>2]=(c[o>>2]|0)+(c[g>>2]|0);p=-1;return p|0}}n=e+k|0;e=b+28|0;c[e>>2]=n;c[g>>2]=n;n=c[o>>2]|0;if((n|0)!=0){g=b|0;i=k+16|0;l=jEb(c[g>>2]|0,b+12|0,i+n|0)|0;if((l|0)==0){c[o>>2]=0;c[e>>2]=0;p=-12;return p|0}c[g>>2]=l;if((k|0)>-16){UGb(l+(c[o>>2]|0)|0,c[f>>2]|0,i)|0;q=c[g>>2]|0}else{q=l}c[o>>2]=0;c[f>>2]=q}if((k|0)>=0){p=0;return p|0}q=b+16|0;f=b+32|0;o=c[j>>2]|0;j=c[b>>2]|0;b=k;k=c[q>>2]|0;l=c[f+4>>2]|0;g=c[f>>2]|0;i=c[h>>2]|0;while(1){e=j+(o+b)|0;n=d[e]|0|k<<8;c[q>>2]=n;m=d[e]|0|(g<<8|0>>>24);e=l<<8|g>>>24|0;c[f>>2]=m;c[f+4>>2]=e;r=i+1|0;c[h>>2]=r;s=b+1|0;if((s|0)<0){b=s;k=n;l=e;g=m;i=r}else{p=0;break}}return p|0}function XRa(a){a=a|0;$Db(c[a>>2]|0);return}function YRa(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0;if((c|0)>0){e=0;f=-256}else{g=0;return g|0}while(1){a=d[b+e|0]|0|f;if((a|0)==438|(a|0)==435){break}h=e+1|0;if((h|0)<(c|0)){e=h;f=a<<8}else{g=0;i=5;break}}if((i|0)==5){return g|0}g=e-3|0;return g|0}function ZRa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;k=f;l=c[h+24>>2]|0;m=c[h+28>>2]|0;if((m|0)<4){yDb(e,16,2183896,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}h=l+2|0;p=(d[h]|0)>>>4;q=(d[l+3|0]|0)>>>6;r=d[590232+q|0]|0;c[e+792>>2]=r;if(!((q|0)==1|(q|0)==3)){yDb(e,16,1966400,(n=i,i=i+8|0,c[n>>2]=r,n)|0);i=n;o=-1094995529;i=j;return o|0}s=(q|0)==1;q=e+420|0;c[q>>2]=s?1:2;if(!s){c[e+796>>2]=r}t=a[h]&15;if((t|0)==5){c[e+412>>2]=192e3;u=192e3}else if((t|0)==4){c[e+412>>2]=96e3;u=96e3}else if((t|0)==1){c[e+412>>2]=48e3;u=48e3}else{c[e+412>>2]=0;yDb(e,16,1938344,(n=i,i=i+8|0,c[n>>2]=a[h]&15,n)|0);i=n;o=-1094995529;i=j;return o|0}h=p&255;p=e+448|0;c[p>>2]=c[590168+(h<<2)>>2];c[p+4>>2]=0;t=d[590152+h|0]|0;v=e+416|0;c[v>>2]=t;if((4090>>>(h>>>0)&1|0)==0){yDb(e,16,1914216,(n=i,i=i+8|0,c[n>>2]=h,n)|0);i=n;o=-1094995529;i=j;return o|0}h=t+1|0;c[e+72>>2]=ba(ba(u,r)|0,h&510)|0;r=l+4|0;u=m-4|0;if(!((u|0)>-1)){yDb(0,0,2106904,(n=i,i=i+24|0,c[n>>2]=2049536,c[n+8>>2]=2003896,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}n=l+m|0;m=h&2147483646;h=(u|0)/((ba(s?16:24,m)|0)>>>3|0)|0;c[f+76>>2]=h;s=_$a(e,k,0)|0;if((s|0)<0){o=s;i=j;return o|0}s=c[f>>2]|0;f=s;k=s;a:do{if((h|0)==0){w=r}else{s=c[p>>2]|0;e=c[p+4>>2]|0;u=1599;t=0;x=1551;y=0;z=1543;A=0;B=259;C=0;D=7;E=0;F=4;G=0;H=1539;I=0;J=263;K=0;L=3;M=0;if((s|0)==1591&(e|0)==0){N=n;if((c[q>>2]|0)==1){O=f;P=h;Q=r;while(1){R=Q;b[O>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+2|0;b[O+2>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+4|0;b[O+4>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+6|0;b[O+10>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+8|0;b[O+6>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+10|0;b[O+8>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+12|0;b[O+12>>1]=de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N-(Q+14)|0;S=Q+(R>>>0>2>>>0?16:R+14|0)|0;R=P-1|0;if((R|0)==0){w=S;break}else{O=O+14|0;P=R;Q=S}}}else{Q=k;P=h;O=r;while(1){c[Q>>2]=((d[O+1|0]|0)<<8|(d[O]|0)<<16|(d[O+2|0]|0))<<8;c[Q+4>>2]=((d[O+4|0]|0)<<8|(d[O+3|0]|0)<<16|(d[O+5|0]|0))<<8;c[Q+8>>2]=((d[O+7|0]|0)<<8|(d[O+6|0]|0)<<16|(d[O+8|0]|0))<<8;c[Q+20>>2]=((d[O+10|0]|0)<<8|(d[O+9|0]|0)<<16|(d[O+11|0]|0))<<8;c[Q+12>>2]=((d[O+13|0]|0)<<8|(d[O+12|0]|0)<<16|(d[O+14|0]|0))<<8;c[Q+16>>2]=((d[O+16|0]|0)<<8|(d[O+15|0]|0)<<16|(d[O+17|0]|0))<<8;c[Q+24>>2]=((d[O+19|0]|0)<<8|(d[O+18|0]|0)<<16|(d[O+20|0]|0))<<8;S=N-(O+21)|0;R=O+(S>>>0>3>>>0?24:S+21|0)|0;S=P-1|0;if((S|0)==0){w=R;break}else{Q=Q+28|0;P=S;O=R}}}}else if((s|0)==(L|0)&(e|0)==(M|0)|(s|0)==(J|0)&(e|0)==(K|0)|(s|0)==(H|0)&(e|0)==(I|0)){O=ba(h,m)|0;if((c[q>>2]|0)==1){P=(O<<1)+4|0;Q=f;N=O;R=r;while(1){S=R;b[Q>>1]=de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0;S=N-1|0;if((S|0)==0){break}else{Q=Q+2|0;N=S;R=R+2|0}}w=l+P|0;break}else{R=(O*3|0)+4|0;N=k;Q=O;I=r;while(1){c[N>>2]=((d[I+1|0]|0)<<8|(d[I]|0)<<16|(d[I+2|0]|0))<<8;H=Q-1|0;if((H|0)==0){break}else{N=N+4|0;Q=H;I=I+3|0}}w=l+R|0;break}}else if((s|0)==(F|0)&(e|0)==(G|0)|(s|0)==(D|0)&(e|0)==(E|0)|(s|0)==(B|0)&(e|0)==(C|0)|(s|0)==(z|0)&(e|0)==(A|0)){I=n;if((c[q>>2]|0)!=1){Q=k;N=h;O=r;while(1){P=c[v>>2]|0;H=P*3|0;K=Q;J=P;M=O;while(1){c[K>>2]=((d[M+1|0]|0)<<8|(d[M]|0)<<16|(d[M+2|0]|0))<<8;L=J-1|0;if((L|0)==0){break}else{K=K+4|0;J=L;M=M+3|0}}M=I-(O+H)|0;J=O+(H-3+(M>>>0>3>>>0?6:M+3|0))|0;M=N-1|0;if((M|0)==0){w=J;break a}else{Q=Q+(P<<2)|0;N=M;O=J}}}O=c[v>>2]|0;N=f;Q=h;A=r;while(1){z=O<<1;C=N;B=O;E=A;while(1){D=E;b[C>>1]=de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0;D=B-1|0;if((D|0)==0){break}else{C=C+2|0;B=D;E=E+2|0}}E=I-(A+z)|0;B=A+(z-2+(E>>>0>2>>>0?4:E+2|0))|0;E=Q-1|0;if((E|0)==0){w=B;break}else{N=N+(O<<1)|0;Q=E;A=B}}}else if((s|0)==(u|0)&(e|0)==(t|0)){if((c[q>>2]|0)==1){A=h<<4|4;Q=f;O=h;N=r;while(1){I=N;b[Q>>1]=de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0;I=N+2|0;b[Q+2>>1]=de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0;I=N+4|0;b[Q+4>>1]=de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0;I=N+6|0;b[Q+12>>1]=de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0;I=N+8|0;b[Q+8>>1]=de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0;I=N+10|0;b[Q+10>>1]=de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0;I=N+12|0;b[Q+14>>1]=de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0;I=N+14|0;b[Q+6>>1]=de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0;I=O-1|0;if((I|0)==0){break}else{Q=Q+16|0;O=I;N=N+16|0}}w=l+A|0;break}else{N=h*24|0|4;O=k;Q=h;t=r;while(1){c[O>>2]=((d[t+1|0]|0)<<8|(d[t]|0)<<16|(d[t+2|0]|0))<<8;c[O+4>>2]=((d[t+4|0]|0)<<8|(d[t+3|0]|0)<<16|(d[t+5|0]|0))<<8;c[O+8>>2]=((d[t+7|0]|0)<<8|(d[t+6|0]|0)<<16|(d[t+8|0]|0))<<8;c[O+24>>2]=((d[t+10|0]|0)<<8|(d[t+9|0]|0)<<16|(d[t+11|0]|0))<<8;c[O+16>>2]=((d[t+13|0]|0)<<8|(d[t+12|0]|0)<<16|(d[t+14|0]|0))<<8;c[O+20>>2]=((d[t+16|0]|0)<<8|(d[t+15|0]|0)<<16|(d[t+17|0]|0))<<8;c[O+28>>2]=((d[t+19|0]|0)<<8|(d[t+18|0]|0)<<16|(d[t+20|0]|0))<<8;c[O+12>>2]=((d[t+22|0]|0)<<8|(d[t+21|0]|0)<<16|(d[t+23|0]|0))<<8;u=Q-1|0;if((u|0)==0){break}else{O=O+32|0;Q=u;t=t+24|0}}w=l+N|0;break}}else if((s|0)==(x|0)&(e|0)==(y|0)){if((c[q>>2]|0)==1){t=(h*12|0)+4|0;Q=f;O=h;A=r;while(1){u=A;b[Q>>1]=de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=A+2|0;b[Q+2>>1]=de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=A+4|0;b[Q+4>>1]=de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=A+6|0;b[Q+8>>1]=de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=A+8|0;b[Q+10>>1]=de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=A+10|0;b[Q+6>>1]=de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=O-1|0;if((u|0)==0){break}else{Q=Q+12|0;O=u;A=A+12|0}}w=l+t|0;break}else{A=(h*18|0)+4|0;O=k;Q=h;y=r;while(1){c[O>>2]=((d[y+1|0]|0)<<8|(d[y]|0)<<16|(d[y+2|0]|0))<<8;c[O+4>>2]=((d[y+4|0]|0)<<8|(d[y+3|0]|0)<<16|(d[y+5|0]|0))<<8;c[O+8>>2]=((d[y+7|0]|0)<<8|(d[y+6|0]|0)<<16|(d[y+8|0]|0))<<8;c[O+16>>2]=((d[y+10|0]|0)<<8|(d[y+9|0]|0)<<16|(d[y+11|0]|0))<<8;c[O+20>>2]=((d[y+13|0]|0)<<8|(d[y+12|0]|0)<<16|(d[y+14|0]|0))<<8;c[O+12>>2]=((d[y+16|0]|0)<<8|(d[y+15|0]|0)<<16|(d[y+17|0]|0))<<8;e=Q-1|0;if((e|0)==0){break}else{O=O+24|0;Q=e;y=y+18|0}}w=l+A|0;break}}else{w=r;break}}}while(0);c[g>>2]=1;o=4-r+w|0;i=j;return o|0}function _Ra(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=-1;a=WDb(96)|0;c[b+20>>2]=a;return((a|0)==0?-12:0)|0}function $Ra(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;j=e;k=c[g+24>>2]|0;l=g+28|0;g=c[l>>2]|0;m=c[b+60>>2]|0;if((g|0)<3){yDb(b,16,2183872,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}p=k+1|0;q=(d[p]|0)<<8|a[k]&224|(d[k+2|0]|0)<<16;r=m;if((c[r>>2]|0)!=(q|0)){c[r>>2]=-1;c[m+24>>2]=0;s=(d[p]|0)>>>6<<2|16;c[b+792>>2]=s;if((s|0)==28){yDb(b,16,1938304,(n=i,i=i+8|0,c[n>>2]=28,n)|0);i=n;o=-1094995529;i=h;return o|0}t=(s|0)==16;c[b+420>>2]=t?1:2;c[b+796>>2]=s;u=c[590136+(((d[p]|0)>>>4&3)<<2)>>2]|0;c[b+412>>2]=u;v=a[p]&7;p=v+1|0;w=b+416|0;c[w>>2]=p;c[b+72>>2]=ba(ba(u,s)|0,p)|0;do{if(t){c[m+12>>2]=1;c[m+4>>2]=c[w>>2]<<1}else{if((v|0)==0|(v|0)==1|(v|0)==3){c[m+4>>2]=s>>>1;c[m+12>>2]=4/(c[w>>2]|0)|0;c[m+16>>2]=1;break}else if((v|0)==7){c[m+4>>2]=s;c[m+12>>2]=1;c[m+16>>2]=2;break}else{c[m+4>>2]=(ba(s<<2,p)|0)/8|0;c[m+12>>2]=4;c[m+16>>2]=c[w>>2];break}}}while(0);c[r>>2]=q}q=m+8|0;r=c[q>>2]|0;w=m+4|0;do{if((r|0)!=0){p=c[w>>2]|0;if((r|0)==(p|0)){break}yDb(b,24,2106864,(n=i,i=i+16|0,c[n>>2]=r,c[n+8>>2]=p,n)|0);i=n;c[m+24>>2]=0}}while(0);n=c[w>>2]|0;c[q>>2]=n;q=k+3|0;r=g-3|0;g=m+24|0;p=((c[g>>2]|0)+r|0)/(n|0)|0;c[e+76>>2]=ba(c[m+12>>2]|0,p)|0;n=_$a(b,j,0)|0;if((n|0)<0){o=n;i=h;return o|0}n=c[e>>2]|0;e=c[g>>2]|0;do{if((e|0)==0){x=n;y=p;z=q;A=r}else{j=(c[w>>2]|0)-e|0;s=m+20|0;v=(c[s>>2]|0)+e|0;if((r|0)>=(j|0)){UGb(v|0,q|0,j)|0;t=bSa(b,c[s>>2]|0,n,1)|0;c[g>>2]=0;x=t;y=p-1|0;z=k+(j+3)|0;A=r-j|0;break}UGb(v|0,q|0,r)|0;c[g>>2]=(c[g>>2]|0)+r;o=c[l>>2]|0;i=h;return o|0}}while(0);if((y|0)==0){B=A}else{bSa(b,z,x,y)|0;B=A-(ba(c[w>>2]|0,y)|0)|0}if((B|0)!=0){A=z+(ba(c[w>>2]|0,y)|0)|0;UGb(c[m+20>>2]|0,A|0,B)|0;c[g>>2]=B}c[f>>2]=1;o=c[l>>2]|0;i=h;return o|0}function aSa(a){a=a|0;$Db((c[a+60>>2]|0)+20|0);return 0}function bSa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=i;j=c[a+60>>2]|0;k=f;if(!((ba(c[j+4>>2]|0,g)|0)>-1)){yDb(0,0,2049504,(l=i,i=i+24|0,c[l>>2]=2003880,c[l+8>>2]=1966376,c[l+16>>2]=135,l)|0);i=l;Cd();return 0}l=c[a+792>>2]|0;if((l|0)==16){m=ba(c[a+416>>2]|0,g)|0;n=f+(m<<1)|0;o=m;m=f;p=e;while(1){q=p;b[m>>1]=de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=o-1|0;if((q|0)==0){r=n;break}else{o=q;m=m+2|0;p=p+2|0}}i=h;return r|0}else if((l|0)==20){if((c[a+416>>2]|0)==1){p=f+(g<<4)|0;m=k;o=g;n=e;while(1){q=n;s=((de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[m>>2]=s;q=n+2|0;t=((de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<16;q=m+4|0;c[q>>2]=t;u=d[n+4|0]|0;c[m>>2]=u<<8&61440|s;s=m+8|0;c[q>>2]=u<<12&61440|t;t=n+5|0;u=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[s>>2]=u;t=n+7|0;q=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<16;t=m+12|0;c[t>>2]=q;v=d[n+9|0]|0;c[s>>2]=v<<8&61440|u;c[t>>2]=v<<12&61440|q;q=o-1|0;if((q|0)==0){break}else{m=m+16|0;o=q;n=n+10|0}}w=p}else{p=j+16|0;n=k;o=g;m=e;while(1){q=c[p>>2]|0;if((q|0)==0){x=m;y=n}else{v=q<<2;t=q*10|0;u=m;s=n;z=q;while(1){q=u;A=((de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[s>>2]=A;q=u+2|0;B=((de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<16;q=s+4|0;c[q>>2]=B;C=u+4|0;D=((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)<<16;C=s+8|0;c[C>>2]=D;E=u+6|0;F=((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)<<16;E=s+12|0;c[E>>2]=F;G=d[u+8|0]|0;c[s>>2]=G<<8&61440|A;c[q>>2]=G<<12&61440|B;B=d[u+9|0]|0;c[C>>2]=B<<8&61440|D;c[E>>2]=B<<12&61440|F;F=z-1|0;if((F|0)==0){break}else{u=u+10|0;s=s+16|0;z=F}}x=m+t|0;y=n+(v<<2)|0}z=o-1|0;if((z|0)==0){w=y;break}else{n=y;o=z;m=x}}}r=w;i=h;return r|0}else if((l|0)==24){if((c[a+416>>2]|0)==1){a=f+(g<<4)|0;f=k;l=g;w=e;while(1){x=w;m=((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[f>>2]=m;x=w+2|0;o=((de((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<16;x=f+4|0;c[x>>2]=o;c[f>>2]=(d[w+4|0]|0)<<8|m;m=f+8|0;c[x>>2]=(d[w+5|0]|0)<<8|o;o=w+6|0;x=((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[m>>2]=x;o=w+8|0;y=((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<16;o=f+12|0;c[o>>2]=y;c[m>>2]=(d[w+10|0]|0)<<8|x;c[o>>2]=(d[w+11|0]|0)<<8|y;y=l-1|0;if((y|0)==0){break}else{f=f+16|0;l=y;w=w+12|0}}H=a}else{a=j+16|0;j=k;k=g;g=e;while(1){e=c[a>>2]|0;if((e|0)==0){I=g;J=j}else{w=e<<2;l=e*12|0;f=g;y=j;o=e;while(1){e=f;x=((de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[y>>2]=x;e=f+2|0;m=((de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535)<<16;e=y+4|0;c[e>>2]=m;n=f+4|0;p=((de((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<16;n=y+8|0;c[n>>2]=p;z=f+6|0;s=((de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<16;z=y+12|0;c[z>>2]=s;c[y>>2]=(d[f+8|0]|0)<<8|x;c[e>>2]=(d[f+9|0]|0)<<8|m;c[n>>2]=(d[f+10|0]|0)<<8|p;c[z>>2]=(d[f+11|0]|0)<<8|s;s=o-1|0;if((s|0)==0){break}else{f=f+12|0;y=y+16|0;o=s}}I=g+l|0;J=j+(w<<2)|0}o=k-1|0;if((o|0)==0){H=J;break}else{j=J;k=o;g=I}}}r=H;i=h;return r|0}else{r=0;i=h;return r|0}return 0}function cSa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[b+424>>2]=0;d=b+12|0;e=c[(c[d>>2]|0)+12>>2]|0;if((e|0)==65542){f=0;g=0;while(1){if((g|0)==127){h=8192}else{i=~((g^255)&255)&255;j=(i<<3&120|132)<<(i>>>4&7);k=~((g+1^255)&255)&255;l=(k<<3&120|132)<<(k>>>4&7);h=((i&128|0)!=0?132-j|0:j-132|0)+4+((k&128|0)!=0?132-l|0:l-132|0)>>3}if((f|0)<(h|0)){l=(g^255)&255;k=(g^127)&255;j=f;while(1){a[j+4987488|0]=l;if((j|0)>0){a[4979296+(8192-j)|0]=k}i=j+1|0;if((i|0)<(h|0)){j=i}else{m=h;break}}}else{m=f}j=g+1|0;if((j|0)<128){f=m;g=j}else{break}}a[4979296]=a[4979297]|0}else if((e|0)==65543){e=0;g=0;while(1){if((g|0)==127){n=8192}else{m=((g^213)&255^85)&255;f=m>>>4&7;h=m<<1&30;if((f|0)==0){o=h<<3|8}else{o=(h|33)<<f+2}f=((g+1^213)&255^85)&255;h=f>>>4&7;j=f<<1&30;if((h|0)==0){p=j<<3|8}else{p=(j|33)<<h+2}n=((m&128|0)!=0?o:-o|0)+4+((f&128|0)!=0?p:-p|0)>>3}if((e|0)<(n|0)){f=(g^213)&255;m=(g^85)&255;h=e;while(1){a[h+5003872|0]=f;if((h|0)>0){a[4995680+(8192-h)|0]=m}j=h+1|0;if((j|0)<(n|0)){h=j}else{q=n;break}}}else{q=e}h=g+1|0;if((h|0)<128){e=q;g=h}else{break}}a[4995680]=a[4995681]|0}g=u0a(c[(c[d>>2]|0)+12>>2]|0)|0;c[b+792>>2]=g;d=(ba(c[b+416>>2]|0,g)|0)/8|0;c[b+432>>2]=d;c[b+72>>2]=ba(d<<3,c[b+412>>2]|0)|0;return 0}function dSa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;h=d+12|0;i=(u0a(c[(c[h>>2]|0)+12>>2]|0)|0)/8|0;j=d+416|0;k=ba(c[j>>2]|0,c[f+76>>2]|0)|0;l=c[f>>2]|0;m=l;n=ba(k,i)|0;o=r0a(d,e,n,(n|0)<0|0?-1:0)|0;if((o|0)<0){p=o;return p|0}o=c[e+24>>2]|0;e=c[(c[h>>2]|0)+12>>2]|0;a:do{if((e|0)==65543){if((k|0)>0){q=o;r=m;s=k}else{break}while(1){a[q]=a[4995680+((b[r>>1]|0)+32768>>2)|0]|0;h=s-1|0;if((h|0)>0){q=q+1|0;r=r+2|0;s=h}else{break}}}else if((e|0)==65548){if((k|0)<=0){break}h=o;d=l;t=k;while(1){u=c[d>>2]>>8;a[h]=u;a[h+1|0]=u>>>8;a[h+2|0]=u>>>16;u=t-1|0;if((u|0)>0){h=h+3|0;d=d+4|0;t=u}else{break}}}else if((e|0)==65539){if((k|0)>0){v=o;w=m;y=k}else{break}while(1){t=v;x=de(b[w>>1]^-32768|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;t=y-1|0;if((t|0)>0){v=v+2|0;w=w+2|0;y=t}else{break}}}else if((e|0)==65549){if((k|0)<=0){break}t=o;d=l;h=k;while(1){u=c[d>>2]>>8;a[t+2|0]=u;a[t+1|0]=u>>>8;a[t]=u>>>16;u=h-1|0;if((u|0)>0){t=t+3|0;d=d+4|0;h=u}else{break}}}else if((e|0)==65542){if((k|0)>0){z=o;A=m;B=k}else{break}while(1){a[z]=a[4979296+((b[A>>1]|0)+32768>>2)|0]|0;h=B-1|0;if((h|0)>0){z=z+1|0;A=A+2|0;B=h}else{break}}}else if((e|0)==65547){if((k|0)<=0){break}h=o;d=l;t=k;while(1){u=h;x=fe(c[d>>2]^-2147483648|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;u=t-1|0;if((u|0)>0){h=h+4|0;d=d+4|0;t=u}else{break}}}else if((e|0)==65546){if((k|0)<=0){break}t=o;d=l;h=k;while(1){u=t;x=c[d>>2]^-2147483648;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;u=h-1|0;if((u|0)>0){t=t+4|0;d=d+4|0;h=u}else{break}}}else if((e|0)==407917392){h=c[j>>2]|0;d=(k|0)/(h|0)|0;if((h|0)<=0){break}t=f+64|0;if((d|0)<=0){u=0;while(1){u=u+1|0;if((u|0)>=(h|0)){break a}}}h=d*3|0;u=o;C=0;while(1){D=u;E=d;F=c[(c[t>>2]|0)+(C<<2)>>2]|0;while(1){G=c[F>>2]>>8;a[D]=G;a[D+1|0]=G>>>8;a[D+2|0]=G>>>16;G=E-1|0;if((G|0)>0){D=D+3|0;E=G;F=F+4|0}else{break}}F=C+1|0;if((F|0)<(c[j>>2]|0)){u=u+h|0;C=F}else{break}}}else if((e|0)==65540){if((k|0)>0){H=o;I=l;J=k}else{break}while(1){a[H]=a[I]^-128;C=J-1|0;if((C|0)>0){H=H+1|0;I=I+1|0;J=C}else{break}}}else if((e|0)==65558){if((k|0)<=0){break}C=o;h=l;u=k;while(1){t=c[h+4>>2]|0;d=fe(c[h>>2]|0)|0;F=C;E=F|0;x=fe(t|0)|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;E=F+4|0;x=d|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;E=u-1|0;if((E|0)>0){C=C+8|0;h=h+8|0;u=E}else{break}}}else if((e|0)==65556|(e|0)==65545){if((k|0)<=0){break}u=o;h=l;C=k;while(1){E=u;x=fe(c[h>>2]|0)|0;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;E=C-1|0;if((E|0)>0){u=u+4|0;h=h+4|0;C=E}else{break}}}else if((e|0)==65537){if((k|0)>0){K=o;L=m;M=k}else{break}while(1){C=K;x=de(b[L>>1]|0)|0;a[C]=x;x=x>>8;a[C+1|0]=x;C=M-1|0;if((C|0)>0){K=K+2|0;L=L+2|0;M=C}else{break}}}else if((e|0)==65563){C=c[j>>2]|0;h=(k|0)/(C|0)|0;if((C|0)<=0){break}u=f+64|0;if((h|0)>0){N=o;O=0}else{E=0;while(1){E=E+1|0;if((E|0)>=(C|0)){break a}}}while(1){C=N;E=h;d=c[(c[u>>2]|0)+(O<<2)>>2]|0;while(1){a[C]=a[d]^-128;F=E-1|0;if((F|0)>0){C=C+1|0;E=F;d=d+1|0}else{break}}d=O+1|0;if((d|0)<(c[j>>2]|0)){N=N+h|0;O=d}else{break}}}else if((e|0)==65551){if((k|0)<=0){break}h=o;u=l;d=k;while(1){E=((c[u>>2]|0)>>>8)+8388608|0;a[h+2|0]=E;a[h+1|0]=E>>>8;a[h]=E>>>16;E=d-1|0;if((E|0)>0){h=h+3|0;u=u+4|0;d=E}else{break}}}else if((e|0)==65550){if((k|0)<=0){break}d=o;u=l;h=k;while(1){E=((c[u>>2]|0)>>>8)+8388608|0;a[d]=E;a[d+1|0]=E>>>8;a[d+2|0]=E>>>16;E=h-1|0;if((E|0)>0){d=d+3|0;u=u+4|0;h=E}else{break}}}else if((e|0)==65554|(e|0)==542135120){h=c[j>>2]|0;if((h|0)<=0){break}u=f+64|0;d=ba((k|0)/(h|0)|0,i)|0;h=o;E=0;while(1){UGb(h|0,c[(c[u>>2]|0)+(E<<2)>>2]|0,d)|0;C=E+1|0;if((C|0)<(c[j>>2]|0)){h=h+d|0;E=C}else{break}}}else if((e|0)==1347637264){E=c[j>>2]|0;d=(k|0)/(E|0)|0;if((E|0)<=0){break}h=f+64|0;if((d|0)<=0){u=0;while(1){u=u+1|0;if((u|0)>=(E|0)){break a}}}E=d<<1;u=o;C=0;while(1){F=u;t=c[(c[h>>2]|0)+(C<<2)>>2]|0;D=d;while(1){G=F;x=de(b[t>>1]|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x;G=D-1|0;if((G|0)>0){F=F+2|0;t=t+2|0;D=G}else{break}}D=C+1|0;if((D|0)<(c[j>>2]|0)){u=u+E|0;C=D}else{break}}}else if((e|0)==65559|(e|0)==65557|(e|0)==65544|(e|0)==65536|(e|0)==65541){UGb(o|0,l|0,n)|0}else if((e|0)==65552){if((k|0)>0){P=o;Q=m;R=k}else{break}while(1){C=b[Q>>1]|0;E=a[1148864+(C>>>8&255)|0]|0;u=a[1148864+(C&255)|0]|0;a[P+2|0]=E<<4;a[P+1|0]=((u&255)<<8|E&255)>>>4;a[P]=(u&255)>>>4;u=R-1|0;if((u|0)>0){P=P+3|0;Q=Q+2|0;R=u}else{break}}}else if((e|0)==65538){if((k|0)>0){S=o;T=m;U=k}else{break}while(1){u=S;x=b[T>>1]^-32768;a[u]=x;x=x>>8;a[u+1|0]=x;u=U-1|0;if((u|0)>0){S=S+2|0;T=T+2|0;U=u}else{break}}}else{p=-1;return p|0}}while(0);c[g>>2]=1;p=0;return p|0}function eSa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=c[a+60>>2]|0;if((c[a+416>>2]|0)<1){yDb(a,16,2324744,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=d;return g|0}f=c[a+48>>2]|0;if((f|0)==65542){h=e;j=0;do{k=~(j&255)&255;l=(k<<3&120|132)<<(k>>>4&7);b[h+(j<<1)>>1]=(k&128|0)!=0?132-l|0:l+65404|0;j=j+1|0;}while((j|0)<256)}else if((f|0)==65543){j=e;e=0;do{h=(e&255^85)&255;l=h>>>4&7;k=h<<1&30;if((l|0)==0){m=k<<3|8}else{m=(k|33)<<l+2}b[j+(e<<1)>>1]=(h&128|0)!=0?m:-m|0;e=e+1|0;}while((e|0)<256)}e=c[c[(c[a+12>>2]|0)+32>>2]>>2]|0;c[a+420>>2]=e;if((e|0)!=2){g=0;i=d;return g|0}c[a+796>>2]=u0a(f)|0;g=0;i=d;return g|0}function fSa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=c[e+60>>2]|0;m=f;n=e+48|0;o=(u0a(c[n>>2]|0)|0)/8|0;p=c[n>>2]|0;q=(p|0)==65561;r=q?2:1;s=q?5:o;if((s|0)==0){yDb(e,16,2338064,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-22;i=j;return u|0}o=e+416|0;q=c[o>>2]|0;if((q|0)==0){yDb(e,16,2336632,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-22;i=j;return u|0}if((p|0)!=(c[(c[e+12>>2]|0)+12>>2]|0)){yDb(e,16,2334112,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-22;i=j;return u|0}p=ba(q,s)|0;do{if((p|0)==0){v=l}else{w=(l|0)%(p|0)|0;if((w|0)==0){v=l;break}if((l|0)>=(p|0)){v=l-w|0;break}yDb(e,16,2327736,(t=i,i=i+16|0,c[t>>2]=l,c[t+8>>2]=p,t)|0);i=t;u=-1094995529;i=j;return u|0}}while(0);t=(v|0)/(s|0)|0;c[f+76>>2]=(ba(t,r)|0)/(q|0)|0;q=_$a(e,m,0)|0;if((q|0)<0){u=q;i=j;return u|0}q=c[f>>2]|0;m=c[n>>2]|0;a:do{if((m|0)==65559|(m|0)==65557|(m|0)==65544|(m|0)==65536|(m|0)==65541){UGb(q|0,k|0,ba(t,s)|0)|0}else if((m|0)==65547){if((t|0)>0){x=k;y=q;z=t}else{break}while(1){n=x;c[y>>2]=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)^-2147483648;n=z-1|0;if((n|0)>0){x=x+4|0;y=y+4|0;z=n}else{break}}}else if((m|0)==65561){n=c[o>>2]|0;e=(t|0)/(n|0)|0;if((n|0)<=0){break}r=f+64|0;p=(e|0)>0;l=e*5|0;w=k;A=0;B=n;while(1){if(p){n=w;C=c[(c[r>>2]|0)+(A<<2)>>2]|0;D=0;while(1){E=n+2|0;F=d[E]|0;G=d[n+1|0]|0;c[C>>2]=G|F<<28|G<<20|F<<8&3840|(d[n]|0)<<12;F=d[n+4|0]|0;G=d[n+3|0]|0;c[C+4>>2]=F<<4|F<<24|G<<16|G>>>4|(d[E]|0)<<8&61440;E=D+1|0;if((E|0)<(e|0)){n=n+5|0;C=C+8|0;D=E}else{break}}H=w+l|0;I=c[o>>2]|0}else{H=w;I=B}D=A+1|0;if((D|0)<(I|0)){w=H;A=D;B=I}else{break}}}else if((m|0)==65553){if((t|0)>0){J=k;K=q;L=t}else{break}while(1){B=a[J]|0;a[K]=B<<24>>24>-1?-128-B&255:B;B=L-1|0;if((B|0)>0){J=J+1|0;K=K+1|0;L=B}else{break}}}else if((m|0)==65549){if((t|0)>0){M=k;N=q;O=t}else{break}while(1){c[N>>2]=((d[M+1|0]|0)<<8|(d[M]|0)<<16|(d[M+2|0]|0))<<8;B=O-1|0;if((B|0)>0){M=M+3|0;N=N+4|0;O=B}else{break}}}else if((m|0)==1347637264){B=c[o>>2]|0;A=(t|0)/(B|0)|0;if((B|0)<=0){break}w=f+64|0;l=(A|0)>0;e=A<<1;r=k;p=0;D=B;while(1){if(l){B=r;C=c[(c[w>>2]|0)+(p<<2)>>2]|0;n=A;while(1){E=B;b[C>>1]=de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0;E=n-1|0;if((E|0)>0){B=B+2|0;C=C+2|0;n=E}else{break}}P=r+e|0;Q=c[o>>2]|0}else{P=r;Q=D}n=p+1|0;if((n|0)<(Q|0)){r=P;p=n;D=Q}else{break}}}else if((m|0)==65543|(m|0)==65542){if((t|0)<=0){break}D=h;p=k;r=q;e=t;while(1){b[r>>1]=b[D+((d[p]|0)<<1)>>1]|0;A=e-1|0;if((A|0)>0){p=p+1|0;r=r+2|0;e=A}else{break}}}else if((m|0)==407917392){e=c[o>>2]|0;r=(t|0)/(e|0)|0;if((e|0)<=0){break}p=f+64|0;if((r|0)<=0){D=0;while(1){D=D+1|0;if((D|0)>=(e|0)){break a}}}e=r*3|0;D=k;A=0;while(1){w=D;l=r;n=c[(c[p>>2]|0)+(A<<2)>>2]|0;while(1){c[n>>2]=((d[w+1|0]|0)<<8|(d[w+2|0]|0)<<16|(d[w]|0))<<8;C=l-1|0;if((C|0)>0){w=w+3|0;l=C;n=n+4|0}else{break}}n=A+1|0;if((n|0)<(c[o>>2]|0)){D=D+e|0;A=n}else{break}}}else if((m|0)==65558){if((t|0)>0){R=k;S=q;T=t}else{break}while(1){A=R;e=A|0;D=A+4|0;A=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;e=S;c[e>>2]=fe(A|0)|0;c[e+4>>2]=D;D=T-1|0;if((D|0)>0){R=R+8|0;S=S+8|0;T=D}else{break}}}else if((m|0)==65540){if((t|0)>0){U=k;V=q;W=t}else{break}while(1){a[V]=a[U]^-128;D=W-1|0;if((D|0)>0){U=U+1|0;V=V+1|0;W=D}else{break}}}else if((m|0)==65552){if((t|0)>0){X=k;Y=q;Z=t}else{break}while(1){D=(d[X+1|0]|0)<<8;b[Y>>1]=(d[1148864+((D|(d[X+2|0]|0))>>>4&255)|0]|0)<<8|(d[1148864+((D|(d[X]|0)<<16)>>>12&255)|0]|0);D=Z-1|0;if((D|0)>0){X=X+3|0;Y=Y+2|0;Z=D}else{break}}}else if((m|0)==65538){if((t|0)>0){_=k;$=q;aa=t}else{break}while(1){D=_;b[$>>1]=(d[D]|d[D+1|0]<<8)<<16>>16^-32768;D=aa-1|0;if((D|0)>0){_=_+2|0;$=$+2|0;aa=D}else{break}}}else if((m|0)==65548){if((t|0)>0){ca=k;da=q;ea=t}else{break}while(1){c[da>>2]=((d[ca+1|0]|0)<<8|(d[ca+2|0]|0)<<16|(d[ca]|0))<<8;D=ea-1|0;if((D|0)>0){ca=ca+3|0;da=da+4|0;ea=D}else{break}}}else if((m|0)==65563){D=c[o>>2]|0;e=(t|0)/(D|0)|0;if((D|0)<=0){break}A=f+64|0;if((e|0)>0){fa=k;ga=0}else{p=0;while(1){p=p+1|0;if((p|0)>=(D|0)){break a}}}while(1){D=fa;p=c[(c[A>>2]|0)+(ga<<2)>>2]|0;r=e;while(1){a[p]=a[D]^-128;n=r-1|0;if((n|0)>0){D=D+1|0;p=p+1|0;r=n}else{break}}r=ga+1|0;if((r|0)<(c[o>>2]|0)){fa=fa+e|0;ga=r}else{break}}}else if((m|0)==65539){if((t|0)>0){ha=k;ia=q;ja=t}else{break}while(1){e=ha;b[ia>>1]=(de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)^-32768;e=ja-1|0;if((e|0)>0){ha=ha+2|0;ia=ia+2|0;ja=e}else{break}}}else if((m|0)==65550){if((t|0)>0){ka=k;la=q;ma=t}else{break}while(1){c[la>>2]=((d[ka+1|0]|0)<<8|(d[ka+2|0]|0)<<16|(d[ka]|0))<<8^-2147483648;e=ma-1|0;if((e|0)>0){ka=ka+3|0;la=la+4|0;ma=e}else{break}}}else if((m|0)==65556|(m|0)==65545){if((t|0)>0){na=k;oa=q;pa=t}else{break}while(1){e=na;c[oa>>2]=fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;e=pa-1|0;if((e|0)>0){na=na+4|0;oa=oa+4|0;pa=e}else{break}}}else if((m|0)==65551){if((t|0)>0){qa=k;ra=q;sa=t}else{break}while(1){c[ra>>2]=((d[qa+1|0]|0)<<8|(d[qa]|0)<<16|(d[qa+2|0]|0))<<8^-2147483648;e=sa-1|0;if((e|0)>0){qa=qa+3|0;ra=ra+4|0;sa=e}else{break}}}else if((m|0)==65537){if((t|0)>0){ta=k;ua=q;va=t}else{break}while(1){e=ta;b[ua>>1]=de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0;e=va-1|0;if((e|0)>0){ta=ta+2|0;ua=ua+2|0;va=e}else{break}}}else if((m|0)==65554|(m|0)==542135120){e=c[o>>2]|0;if((e|0)<=0){break}A=f+64|0;r=ba((t|0)/(e|0)|0,s)|0;e=k;p=0;while(1){UGb(c[(c[A>>2]|0)+(p<<2)>>2]|0,e|0,r)|0;D=p+1|0;if((D|0)<(c[o>>2]|0)){e=e+r|0;p=D}else{break}}}else if((m|0)==65546){if((t|0)>0){wa=k;xa=q;ya=t}else{break}while(1){p=wa;c[xa>>2]=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24)^-2147483648;p=ya-1|0;if((p|0)>0){wa=wa+4|0;xa=xa+4|0;ya=p}else{break}}}else{u=-1;i=j;return u|0}}while(0);c[g>>2]=1;u=v;i=j;return u|0}function gSa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;h=i;j=e;k=g+28|0;l=c[k>>2]|0;if((l|0)<128){m=-1094995529;i=h;return m|0}n=c[g+24>>2]|0;g=n+l|0;do{if((a[n]|0)==10){if((d[n+1|0]|0)>>>0>5>>>0){break}o=a[n+2|0]|0;p=a[n+3|0]|0;q=p&255;r=n+4|0;s=(d[r]|d[r+1|0]<<8)<<16>>16;r=n+6|0;t=(d[r]|d[r+1|0]<<8)<<16>>16;r=n+8|0;u=(d[r]|d[r+1|0]<<8)<<16>>16;r=n+10|0;v=(d[r]|d[r+1|0]<<8)<<16>>16;r=n+12|0;c[b+224>>2]=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=n+14|0;c[b+228>>2]=(d[r]|d[r+1|0]<<8)<<16>>16&65535;if((u&65535)>>>0<(s&65535)>>>0|(v&65535)>>>0<(t&65535)>>>0){yDb(b,16,2106752,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;m=-1094995529;i=h;return m|0}r=u&65535;u=s&65535;s=r-u+1|0;x=(v&65535)-(t&65535)+1|0;t=a[n+65|0]|0;v=t&255;y=n+68|0;z=n+66|0;A=(d[z]|d[z+1|0]<<8)<<16>>16&65535;z=ba(A,v)|0;do{if(!(z>>>0<((ba(ba(s,q)|0,v)|0)+7|0)>>>3>>>0)){B=o<<24>>24==0;if(B){if(z>>>0>(((g-y|0)>>>0)/(x>>>0)|0)>>>0){break}}switch(v<<8|q|0){case 264:case 260:case 258:case 257:case 1025:case 769:case 513:{c[b+140>>2]=11;break};case 776:{c[b+140>>2]=2;break};default:{yDb(b,16,2003808,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;m=-1094995529;i=h;return m|0}}C=n+128|0;D=V$a(b,s,x)|0;if((D|0)<0){m=D;i=h;return m|0}D=_$a(b,j,0)|0;if((D|0)<0){m=D;i=h;return m|0}c[e+88>>2]=1;D=c[e>>2]|0;E=c[e+32>>2]|0;F=WDb(z+16|0)|0;if((F|0)==0){m=-12;i=h;return m|0}G=p<<24>>24==8;a:do{if(t<<24>>24==3&G){if((x|0)==0){H=C;I=99;break}J=g;K=(s|0)!=0;L=A<<1;M=(z|0)==0;if(B){N=C;O=D;P=0;while(1){Q=J-N|0;R=Q>>>0>z>>>0?z:Q;UGb(F|0,N|0,R)|0;Q=N+R|0;if(K){R=0;do{S=R*3|0;a[O+S|0]=a[F+R|0]|0;a[O+(S+1)|0]=a[F+(R+A)|0]|0;a[O+(S+2)|0]=a[F+(R+L)|0]|0;R=R+1|0;}while(R>>>0<s>>>0)}R=P+1|0;if(R>>>0<x>>>0){N=Q;O=O+E|0;P=R}else{H=Q;I=99;break a}}}else{T=C;U=D;V=0}while(1){b:do{if(M){W=T}else{P=0;O=T;while(1){if((g|0)==(O|0)){W=g;break b}do{if((J-O|0)<1){X=0;Y=1;Z=O}else{N=O+1|0;R=a[O]|0;if((R&255)>>>0<192>>>0|(g|0)==(N|0)){X=R;Y=1;Z=N;break}S=R&63;if((J-N|0)<1){X=0;Y=S;Z=N;break}X=a[N]|0;Y=S;Z=O+2|0}}while(0);if(P>>>0>=z>>>0|Y<<24>>24==0){_=P}else{S=P-z|0;N=~(Y-1&255);R=S>>>0>N>>>0?S:N;TGb(F+P|0,X|0,-R|0)|0;_=P-R|0}if(_>>>0<z>>>0){P=_;O=Z}else{W=Z;break}}}}while(0);if(K){Q=0;do{O=Q*3|0;a[U+O|0]=a[F+Q|0]|0;a[U+(O+1)|0]=a[F+(Q+A)|0]|0;a[U+(O+2)|0]=a[F+(Q+L)|0]|0;Q=Q+1|0;}while(Q>>>0<s>>>0)}Q=V+1|0;if(Q>>>0<x>>>0){T=W;U=U+E|0;V=Q}else{H=W;I=99;break}}}else{L=t<<24>>24==1;if(L&G){K=c[k>>2]|0;J=K-769|0;if((K|0)<769){yDb(b,16,1966328,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if((c[b+696>>2]&8|0)!=0){$=-1094995529;break}$=c[k>>2]|0;break}if((x|0)==0){aa=C}else{K=g;M=(z|0)==0;Q=C;O=D;P=0;while(1){c:do{if(B){R=K-Q|0;N=R>>>0>z>>>0?z:R;UGb(F|0,Q|0,N)|0;ca=Q+N|0}else{if(M){ca=Q;break}else{da=0;ea=Q}while(1){if((g|0)==(ea|0)){ca=g;break c}do{if((K-ea|0)<1){fa=0;ga=1;ha=ea}else{N=ea+1|0;R=a[ea]|0;if((R&255)>>>0<192>>>0|(g|0)==(N|0)){fa=R;ga=1;ha=N;break}S=R&63;if((K-N|0)<1){fa=0;ga=S;ha=N;break}fa=a[N]|0;ga=S;ha=ea+2|0}}while(0);if(da>>>0>=z>>>0|ga<<24>>24==0){ia=da}else{S=da-z|0;N=~(ga-1&255);R=S>>>0>N>>>0?S:N;TGb(F+da|0,fa|0,-R|0)|0;ia=da-R|0}if(ia>>>0<z>>>0){da=ia;ea=ha}else{ca=ha;break}}}}while(0);UGb(O|0,F|0,s)|0;R=P+1|0;if(R>>>0<x>>>0){Q=ca;O=O+E|0;P=R}else{aa=ca;break}}}if((aa-n|0)==(J|0)){ja=aa}else{yDb(b,24,1938232,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if((J|0)<0){ka=0}else{ka=(l|0)<(J|0)?l:J}ja=n+ka|0}if((g-ja|0)>=1){if((a[ja]|0)==12){H=ja+1|0;I=99;break}}yDb(b,16,1914104,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if((c[b+696>>2]&8|0)!=0){$=-1094995529;break}$=c[k>>2]|0;break}P=(x|0)==0;if(L){if(P){H=C;I=99;break}O=(z<<3)+8|0;Q=g;K=(s|0)==0;M=32-q|0;R=(z|0)==0;N=C;S=D;la=0;while(1){d:do{if(B){ma=Q-N|0;na=ma>>>0>z>>>0?z:ma;UGb(F|0,N|0,na)|0;oa=N+na|0}else{if(R){oa=N;break}else{pa=0;qa=N}while(1){if((g|0)==(qa|0)){oa=g;break d}do{if((Q-qa|0)<1){ra=0;sa=1;ta=qa}else{na=qa+1|0;ma=a[qa]|0;if((ma&255)>>>0<192>>>0|(g|0)==(na|0)){ra=ma;sa=1;ta=na;break}ua=ma&63;if((Q-na|0)<1){ra=0;sa=ua;ta=na;break}ra=a[na]|0;sa=ua;ta=qa+2|0}}while(0);if(pa>>>0>=z>>>0|sa<<24>>24==0){va=pa}else{ua=pa-z|0;na=~(sa-1&255);ma=ua>>>0>na>>>0?ua:na;TGb(F+pa|0,ra|0,-ma|0)|0;va=pa-ma|0}if(va>>>0<z>>>0){pa=va;qa=ta}else{oa=ta;break}}}}while(0);if(!K){ma=0;na=0;while(1){ua=F+(ma>>>3)|0;wa=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(ma&7)>>>(M>>>0);ua=ma+q|0;a[S+na|0]=wa;wa=na+1|0;if(wa>>>0<s>>>0){ma=O>>>0>ua>>>0?ua:O;na=wa}else{break}}}na=la+1|0;if(na>>>0<x>>>0){N=oa;S=S+E|0;la=na}else{H=oa;I=99;break a}}}if(P){H=C;I=99;break}la=g;S=(s|0)==0;N=v-1|0;O=(N|0)>-1;M=(z|0)==0;K=r+1-u|0;Q=C;R=D;L=0;while(1){J=D+(ba(E,L)|0)|0;e:do{if(B){na=la-Q|0;ma=na>>>0>z>>>0?z:na;UGb(F|0,Q|0,ma)|0;xa=Q+ma|0}else{if(M){xa=Q;break}else{ya=0;za=Q}while(1){if((g|0)==(za|0)){xa=g;break e}do{if((la-za|0)<1){Aa=0;Ba=1;Ca=za}else{ma=za+1|0;na=a[za]|0;if((na&255)>>>0<192>>>0|(g|0)==(ma|0)){Aa=na;Ba=1;Ca=ma;break}wa=na&63;if((la-ma|0)<1){Aa=0;Ba=wa;Ca=ma;break}Aa=a[ma]|0;Ba=wa;Ca=za+2|0}}while(0);if(ya>>>0>=z>>>0|Ba<<24>>24==0){Da=ya}else{wa=ya-z|0;ma=~(Ba-1&255);na=wa>>>0>ma>>>0?wa:ma;TGb(F+ya|0,Aa|0,-na|0)|0;Da=ya-na|0}if(Da>>>0<z>>>0){ya=Da;za=Ca}else{xa=Ca;break}}}}while(0);do{if(!S){if(O){Ea=0}else{TGb(J|0,0,K|0)|0;break}do{na=128>>>((Ea&7)>>>0);ma=Ea>>>3;wa=0;ua=N;do{wa=(d[F+((ba(ua,A)|0)+ma)|0]&na|0)!=0|wa<<1;ua=ua-1|0;}while((ua|0)>-1);a[R+Ea|0]=wa;Ea=Ea+1|0;}while(Ea>>>0<s>>>0)}}while(0);J=L+1|0;if(J>>>0<x>>>0){Q=xa;R=R+E|0;L=J}else{H=xa;I=99;break}}}}while(0);if((I|0)==99){E=H;B=E-n|0;do{if(t<<24>>24==1&G){D=c[e+4>>2]|0;C=g-E|0;L=(C>>>0)/3|0;R=C>>>0<768>>>0;Q=R?L:256;if((Q|0)==0){Fa=D;I=104}else{N=C>>>0>770>>>0;C=D;K=0;O=H;while(1){c[C>>2]=d[O]<<16|d[O+1|0]<<8|d[O+2|0]|-16777216;S=K+1|0;if((S|0)<(Q|0)){C=C+4|0;K=S;O=O+3|0}else{break}}if(R){Fa=D+((N?256:L)<<2)|0;I=104}}if((I|0)==104){TGb(Fa|0,0,256-Q<<2|0)|0}Ga=B+768|0}else{if((ba(v,q)|0)==1){O=e+4|0;c[c[O>>2]>>2]=-16777216;c[(c[O>>2]|0)+4>>2]=-1;Ga=B;break}if(!((p&255)>>>0<8>>>0)){Ga=B;break}O=n+((l|0)<16?l:16)|0;K=c[e+4>>2]|0;C=g-O|0;S=(C>>>0)/3|0;la=S>>>0<16>>>0?S:16;if((la|0)==0){Ha=K}else{M=C>>>0>50>>>0;C=K;P=0;J=O;while(1){c[C>>2]=d[J]<<16|d[J+1|0]<<8|d[J+2|0]|-16777216;O=P+1|0;if((O|0)<(la|0)){C=C+4|0;P=O;J=J+3|0}else{break}}if(la>>>0<256>>>0){Ha=K+((M?16:S)<<2)|0}else{Ga=B;break}}TGb(Ha|0,0,256-la<<2|0)|0;Ga=B}}while(0);c[f>>2]=1;$=Ga}ZDb(F);m=$;i=h;return m|0}}while(0);yDb(b,16,2049432,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;m=-1094995529;i=h;return m|0}}while(0);yDb(b,16,2183768,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;m=-1094995529;i=h;return m|0}function hSa(a){a=a|0;var b=0,d=0;b=ICb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+88>>2]=1;c[b+84>>2]=1;d=0;return d|0}function iSa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;g=i;i=i+1040|0;h=g|0;j=g+8|0;k=g+16|0;l=b+120|0;m=c[l>>2]|0;do{if((m|0)<=65535){n=b+124|0;o=c[n>>2]|0;if((o|0)>65535){break}p=c[b+140>>2]|0;switch(p|0){case 22:case 19:case 24:case 21:case 8:{q=k|0;fDb(q,p)|0;r=q;s=8;t=1;u=c[l>>2]|0;v=c[n>>2]|0;break};case 11:{r=c[e+4>>2]|0;s=8;t=1;u=m;v=o;break};case 2:{r=0;s=8;t=3;u=m;v=o;break};case 10:{r=676624;s=1;t=1;u=m;v=o;break};default:{yDb(b,16,2106712,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=-1;i=g;return y|0}}o=((ba(u,s)|0)+7>>3)+1&-2;q=ba(ba(t<<1,v)|0,o)|0;p=(r|0)!=0;z=(p?897:128)+q|0;q=r0a(b,d,z,(z|0)<0|0?-1:0)|0;if((q|0)<0){y=q;i=g;return y|0}q=d+24|0;z=c[q>>2]|0;A=d+28|0;B=z+(c[A>>2]|0)|0;C=c[b+224>>2]|0;c[h>>2]=C;D=c[b+228>>2]|0;c[j>>2]=D;if(C>>>0>65535>>>0|D>>>0>65535>>>0){iFb(h,j,C,(C|0)<0|0?-1:0,D,(D|0)<0|0?-1:0,65535,0)|0}a[z]=10;a[z+1|0]=5;a[z+2|0]=1;a[z+3|0]=s;D=z+4|0;x=0;a[D]=x;x=x>>8;a[D+1|0]=x;D=z+6|0;x=0;a[D]=x;x=x>>8;a[D+1|0]=x;D=z+8|0;x=(c[l>>2]|0)+65535&65535;a[D]=x;x=x>>8;a[D+1|0]=x;D=z+10|0;x=(c[n>>2]|0)+65535&65535;a[D]=x;x=x>>8;a[D+1|0]=x;D=z+12|0;x=c[h>>2]&65535;a[D]=x;x=x>>8;a[D+1|0]=x;D=z+14|0;x=c[j>>2]&65535;a[D]=x;x=x>>8;a[D+1|0]=x;D=z+16|0;if(p){p=D;C=0;while(1){E=c[r+(C<<2)>>2]|0;a[p+2|0]=E;a[p+1|0]=E>>>8;a[p]=E>>>16;E=C+1|0;if((E|0)<16){p=p+3|0;C=E}else{break}}}else{a[z+18|0]=0;a[z+17|0]=0;a[D]=0;a[z+21|0]=0;a[z+20|0]=0;a[z+19|0]=0;a[z+24|0]=0;a[z+23|0]=0;a[z+22|0]=0;a[z+27|0]=0;a[z+26|0]=0;a[z+25|0]=0;a[z+30|0]=0;a[z+29|0]=0;a[z+28|0]=0;a[z+33|0]=0;a[z+32|0]=0;a[z+31|0]=0;a[z+36|0]=0;a[z+35|0]=0;a[z+34|0]=0;a[z+39|0]=0;a[z+38|0]=0;a[z+37|0]=0;a[z+42|0]=0;a[z+41|0]=0;a[z+40|0]=0;a[z+45|0]=0;a[z+44|0]=0;a[z+43|0]=0;a[z+48|0]=0;a[z+47|0]=0;a[z+46|0]=0;a[z+51|0]=0;a[z+50|0]=0;a[z+49|0]=0;a[z+54|0]=0;a[z+53|0]=0;a[z+52|0]=0;a[z+57|0]=0;a[z+56|0]=0;a[z+55|0]=0;a[z+60|0]=0;a[z+59|0]=0;a[z+58|0]=0;a[z+63|0]=0;a[z+62|0]=0;a[z+61|0]=0}a[z+64|0]=0;a[z+65|0]=t;C=z+66|0;x=o&65535;a[C]=x;x=x>>8;a[C+1|0]=x;C=z+68|0;if((C-(c[q>>2]|0)|0)<128){p=C;while(1){E=p+1|0;a[p]=0;if((E-(c[q>>2]|0)|0)<128){p=E}else{G=E;break}}}else{G=C}a:do{if((c[n>>2]|0)>0){p=c[e>>2]|0;z=B;D=t;E=gHb(D<<1|0>>>31,0<<1|D>>>31,o,(o|0)<0|0?-1:0)|0;D=F;H=ba(o,t)|0;I=e+32|0;b:do{if((o|0)>=1){J=G;K=0;L=p;while(1){M=J;N=z-M|0;O=(N|0)<0|0?-1:0;if((O|0)<(D|0)|(O|0)==(D|0)&N>>>0<E>>>0){break b}else{P=0;Q=J}while(1){N=L+(P+H)|0;O=a[L+P|0]|0;R=L+(P+t)|0;S=1;T=Q;while(1){do{if(R>>>0<N>>>0){if(!((a[R]|0)==O<<24>>24&(S|0)<63)){U=23;break}V=O;W=S+1|0;X=T}else{U=23}}while(0);if((U|0)==23){U=0;if((S|0)!=1|(O&255)>>>0>191>>>0){a[T]=S|192;Y=T+1|0}else{Y=T}Z=Y+1|0;a[Y]=O;if((R|0)==(N|0)){break}V=a[R]|0;W=1;X=Z}O=V;R=R+t|0;S=W;T=X}T=P+1|0;if((T|0)<(t|0)){P=T;Q=Z}else{break}}T=Z-M|0;if((T|0)<0){break b}S=J+T|0;T=K+1|0;if((T|0)<(c[n>>2]|0)){J=S;K=T;L=L+(c[I>>2]|0)|0}else{_=S;break a}}}}while(0);yDb(b,16,2049408,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=-1;i=g;return y|0}else{_=G}}while(0);if((t|0)==1&(s|0)==8){if((B-_|0)<257){yDb(b,16,2049408,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=-1;i=g;return y|0}a[_]=12;n=_+1|0;o=0;while(1){C=c[r+(o<<2)>>2]|0;a[n+2|0]=C;a[n+1|0]=C>>>8;a[n]=C>>>16;C=o+1|0;if((C|0)<256){n=n+3|0;o=C}else{break}}$=_+769|0}else{$=_}c[A>>2]=$-(c[q>>2]|0);o=d+36|0;c[o>>2]=c[o>>2]|1;c[f>>2]=1;y=0;i=g;return y|0}}while(0);yDb(b,16,2183704,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=-1;i=g;return y|0}function jSa(a){a=a|0;JCb(a+804|0);return 0}function kSa(a){a=a|0;c[a+140>>2]=11;return 0}function lSa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;c[g>>2]=0;if((l|0)<3){m=-1;i=j;return m|0}h=k+l|0;n=e+60|0;o=f+24|0;p=f+4|0;q=f+8|0;r=f;s=f+12|0;t=f+16|0;u=e;v=h;w=e+120|0;x=e+124|0;y=k;a:while(1){k=a[y]|0;z=k&255;A=y+3|0;B=y+1|0;C=de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0;B=C&65535;b:do{if(k<<24>>24==-128){D=32}else{if((B|0)>(v-A|0)){m=l;D=67;break a}switch(z|0){case 22:{E=c[o>>2]|0;F=c[o+4>>2]|0;G=c[n>>2]|0;H=A;I=(de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;H=y+5|0;J=(de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;H=G+24|0;c[H>>2]=E;c[H+4>>2]=F;F=V$a(e,I,J)|0;if((F|0)<0){m=F;D=67;break a}F=y+8|0;c[G+8>>2]=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=a[y+13|0]|0;J=F&255;K=G+12|0;c[K>>2]=J;if(F<<24>>24==0){break b}if((B-11|0)<(J<<3|0)){D=24;break a}J=G+16|0;G=J;$Db(J);J=WDb(c[K>>2]<<4)|0;F=J;c[G>>2]=F;if((J|0)==0){D=27;break a}if((c[K>>2]|0)>0){L=y+14|0;M=1;N=0;O=F}else{break b}while(1){F=L;c[O+(N<<4)+8>>2]=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;c[O+(N<<4)+12>>2]=d[L+3|0]|0;F=L+4|0;J=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=O+(N<<4)|0;c[F>>2]=J;I=L+6|0;H=(de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535;I=O+(N<<4)+4|0;c[I>>2]=H;E=c[w>>2]|0;P=c[x>>2]|0;if((J|0)>(E|0)|(H|0)>(P|0)){yDb(u,16,1966240,(Q=i,i=i+32|0,c[Q>>2]=J,c[Q+8>>2]=H,c[Q+16>>2]=E,c[Q+24>>2]=P,Q)|0);i=Q;c[F>>2]=0;c[I>>2]=0}I=M&65535;if((I|0)>=(c[K>>2]|0)){break b}L=L+8|0;M=M+1&65535;N=I;O=c[G>>2]|0}break};case 128:{D=32;break b;break};case 21:{G=c[n>>2]|0;if((C&65535)>>>0<5>>>0){break b}I=B-4|0;F=A;P=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=y+7|0;if((a[y+6|0]|0)>-1){E=G+1056|0;H=E+(P*24|0)+20|0;if(I>>>0>(c[H>>2]|0)>>>0){break b}J=E+(P*24|0)+16|0;UGb((c[E+(P*24|0)+8>>2]|0)+(c[J>>2]|0)|0,F|0,I)|0;c[J>>2]=(c[J>>2]|0)+I;c[H>>2]=(c[H>>2]|0)-I;break b}if((I|0)<8){break b}I=B-11|0;H=(d[y+8|0]<<8|d[F]<<16|d[y+9|0])-4|0;F=y+10|0;J=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=y+14|0;E=y+12|0;R=(de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;do{if(!((c[w>>2]|0)>>>0<J>>>0)){if((c[x>>2]|0)>>>0<R>>>0){break}if(I>>>0>H>>>0){yDb(u,16,1914080,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;break b}E=G+1056|0;c[E+(P*24|0)>>2]=J;c[E+(P*24|0)+4>>2]=R;S=E+(P*24|0)+8|0;O$a(S,E+(P*24|0)+12|0,H);T=c[S>>2]|0;if((T|0)==0){break b}UGb(T|0,F|0,I)|0;c[E+(P*24|0)+16>>2]=I;c[E+(P*24|0)+20>>2]=H-I;break b}}while(0);yDb(u,16,1938192,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;break b;break};case 20:{I=y+(B+3)|0;if(!((C&65535)>>>0>2>>>0)){break b}H=(c[n>>2]|0)+32|0;P=y+5|0;while(1){F=P+5|0;R=(d[P+3|0]|0)-128|0;J=(d[P+2|0]|0)-128|0;G=d[P+1|0]<<10|512;c[H+(d[P]<<2)>>2]=d[((J*1436|0)+G>>10)+1236056|0]<<16|d[P+4|0]<<24|d[((J*-731|0)+G+(R*-352|0)>>10)+1236056|0]<<8|d[((R*1815|0)+G>>10)+1236056|0];if(F>>>0<I>>>0){P=F}else{break}}break};case 23:{break b;break};default:{yDb(u,16,2183656,(Q=i,i=i+16|0,c[Q>>2]=z,c[Q+8>>2]=B,Q)|0);i=Q;break b}}}}while(0);if((D|0)==32){D=0;z=c[n>>2]|0;C=z+24|0;A=c[C>>2]|0;k=c[C+4>>2]|0;if((A|0)==0&(k|0)==(-2147483648|0)){U=c[o+4>>2]|0;V=c[o>>2]|0}else{U=k;V=A}TGb(f|0,0,24)|0;c[o>>2]=V;c[o+4>>2]=U;c[C>>2]=0;c[C+4>>2]=-2147483648;C=z+12|0;c:do{if((c[C>>2]|0)==0){W=1}else{c[p>>2]=0;c[q>>2]=2e4;b[r>>1]=0;A=c[C>>2]|0;c[s>>2]=A;c[t>>2]=cEb(A<<2)|0;if((c[s>>2]|0)==0){W=1;break}A=z+16|0;k=z+1056|0;P=z+1573896|0;I=z+32|0;H=1;F=0;while(1){G=c[(c[A>>2]|0)+(F<<4)+8>>2]|0;R=cEb(100)|0;c[(c[t>>2]|0)+(F<<2)>>2]=R;R=c[A>>2]|0;J=c[(c[t>>2]|0)+(F<<2)>>2]|0;c[J>>2]=c[R+(F<<4)>>2];c[J+4>>2]=c[R+(F<<4)+4>>2];R=G&65535;G=k+(R*24|0)|0;E=c[G>>2]|0;c[J+8>>2]=E;T=c[k+(R*24|0)+4>>2]|0;c[J+12>>2]=T;c[J+84>>2]=1;c[J+52>>2]=c[G>>2];G=k+(R*24|0)+8|0;S=c[G>>2]|0;if((S|0)==0){X=J}else{J=c[k+(R*24|0)+20>>2]|0;Y=k+(R*24|0)+16|0;if((J|0)==0){Z=S;_=E;$=T}else{yDb(u,16,2106656,(Q=i,i=i+16|0,c[Q>>2]=c[Y>>2],c[Q+8>>2]=J,Q)|0);i=Q;J=c[(c[t>>2]|0)+(F<<2)>>2]|0;Z=c[G>>2]|0;_=c[J+8>>2]|0;$=c[J+12>>2]|0}J=Z+(c[Y>>2]|0)|0;Y=WDb(ba(_,$)|0)|0;c[(c[(c[t>>2]|0)+(F<<2)>>2]|0)+20>>2]=Y;Y=c[t>>2]|0;G=c[Y+(F<<2)>>2]|0;if((c[G+20>>2]|0)==0){W=0;break c}T=c[G+12>>2]|0;E=G+8|0;d:do{if((T|0)>0){S=Z;R=0;aa=0;ca=G;da=T;ea=E;fa=Y;while(1){ga=S;ha=aa;ia=ca;ja=da;ka=ea;la=fa;e:while(1){ma=ga;while(1){if(!(ma>>>0<J>>>0)){na=ia;oa=ja;pa=ka;qa=R;break d}ra=ma+1|0;sa=a[ma]|0;if(sa<<24>>24==0){ta=ma+2|0;ua=d[ra]|0;va=ua&63;if((ua&64|0)==0){wa=va;xa=ta}else{wa=d[ta]|va<<8;xa=ma+3|0}if((ua&128|0)==0){ya=0;za=xa}else{ya=a[xa]|0;za=xa+1|0}if((wa|0)>0){Aa=za;Ba=ya;Ca=wa;D=51}else{Da=za;Ea=wa}}else{Aa=ra;Ba=sa;Ca=1;D=51}if((D|0)==51){D=0;Fa=Ca+R|0;if((Fa|0)>(ba(c[ka>>2]|0,ja)|0)){Da=Aa;Ea=Ca}else{break e}}if((Ea|0)==0){break}else{ma=Da}}ma=c[ka>>2]|0;sa=(R|0)%(ma|0)|0;if((sa|0)>0){yDb(u,16,2049352,(Q=i,i=i+16|0,c[Q>>2]=sa,c[Q+8>>2]=ma,Q)|0);i=Q;Ga=c[t>>2]|0}else{Ga=la}ma=ha+1|0;sa=c[Ga+(F<<2)>>2]|0;ra=c[sa+12>>2]|0;ua=sa+8|0;if((ma|0)<(ra|0)){ga=Da;ha=ma;ia=sa;ja=ra;ka=ua;la=Ga}else{na=sa;oa=ra;pa=ua;qa=R;break d}}TGb((c[ia+20>>2]|0)+R|0,Ba|0,Ca|0)|0;la=c[t>>2]|0;ka=c[la+(F<<2)>>2]|0;ja=c[ka+12>>2]|0;ga=ka+8|0;if((ha|0)<(ja|0)){S=Aa;R=Fa;aa=ha;ca=ka;da=ja;ea=ga;fa=la}else{na=ka;oa=ja;pa=ga;qa=Fa;break}}}else{na=G;oa=T;pa=E;qa=0}}while(0);if((qa|0)<(ba(c[pa>>2]|0,oa)|0)){break}else{X=na}}c[X+16>>2]=256;E=cEb(1024)|0;c[(c[(c[t>>2]|0)+(F<<2)>>2]|0)+24>>2]=E;E=(c[A>>2]|0)+(F<<4)+12|0;T=c[(c[t>>2]|0)+(F<<2)>>2]|0;c[T+96>>2]=(c[E>>2]|0)>>>6&1;if((c[P>>2]|0)==0){D=61}else{if((c[E>>2]&64|0)!=0){D=61}}if((D|0)==61){D=0;UGb(c[T+24>>2]|0,I|0,c[T+16>>2]<<2)|0}T=H&65535;if(!(T>>>0<(c[s>>2]|0)>>>0)){W=1;break c}H=H+1&65535;F=T}yDb(u,16,2003768,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;W=0}}while(0);c[g>>2]=W}z=y+(B+3)|0;if(z>>>0<h>>>0){y=z}else{m=l;D=67;break}}if((D|0)==24){c[K>>2]=0;m=-1094995529;i=j;return m|0}else if((D|0)==27){c[K>>2]=0;m=-12;i=j;return m|0}else if((D|0)==67){i=j;return m|0}return 0}function mSa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;$Db(b+16|0);c[b+12>>2]=0;a=b+1056|0;b=0;do{d=b&65535;$Db(a+(d*24|0)+8|0);c[a+(d*24|0)+12>>2]=0;b=b+1&65535;}while(!(b<<16>>16==-1));return 0}function nSa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0;h=i;j=c[b+60>>2]|0;k=e;l=c[g+24>>2]|0;m=g+28|0;g=c[m>>2]|0;if(!((g|0)>-1)){yDb(0,0,2106624,(n=i,i=i+24|0,c[n>>2]=2049336,c[n+8>>2]=2003744,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}o=j+12|0;c[o>>2]=l;p=j+20|0;c[p>>2]=l;q=l+g|0;r=j+16|0;c[r>>2]=q;s=q;if(g>>>0<11>>>0){t=-1094995529;i=h;return t|0}g=l+2|0;c[o>>2]=g;q=l;if(!((d[q]|d[q+1|0]<<8)<<16>>16<<16>>16==4660)){t=-1094995529;i=h;return t|0}q=l+4|0;c[o>>2]=q;u=g;g=(d[u]|d[u+1|0]<<8)<<16>>16&65535;u=j;c[u>>2]=g;v=l+6|0;c[o>>2]=v;w=q;q=(d[w]|d[w+1|0]<<8)<<16>>16&65535;w=j+4|0;c[w>>2]=q;x=s-v|0;v=x>>>0>4>>>0?4:x;x=v+7|0;y=l+x|0;c[o>>2]=y;z=d[l+(v+6)|0]|0;v=z&15;A=(z>>>4)+1|0;z=j+8|0;c[z>>2]=A;j=ba(A,v)|0;do{if(!(v>>>0>8>>>0)){if((j-1|0)>>>0>31>>>0){break}A=s-y|0;if((A|0)<1){B=10}else{if((a[y]|0)==-1){B=11}else{B=10}}if((B|0)==10){if((j|0)==8|(j|0)==4|(j|0)==1){B=11}else{C=-1;D=0}}do{if((B|0)==11){E=A>>>0>2>>>0?2:A;F=l+(x+E)|0;c[o>>2]=F;if((s-F|0)<2){G=0;H=F}else{I=l+(x+(E+2))|0;c[o>>2]=I;E=F;G=(d[E]|d[E+1|0]<<8)<<16>>16&65535;H=I}if((s-H|0)<2){J=0;K=H}else{I=H+2|0;c[o>>2]=I;E=H;J=(d[E]|d[E+1|0]<<8)<<16>>16&65535;K=I}if((s-K|0)>>>0<J>>>0){t=-1094995529}else{C=G;D=J;break}i=h;return t|0}}while(0);c[b+140>>2]=11;if((hDb(g,q,0,b)|0)<0){t=-1;i=h;return t|0}A=c[u>>2]|0;I=b+120|0;do{if((A|0)!=(c[I>>2]|0)){E=c[w>>2]|0;if((E|0)==(c[b+124>>2]|0)){break}F=V$a(b,A,E)|0;if((F|0)<0){t=F}else{break}i=h;return t|0}}while(0);A=_$a(b,k,0)|0;if((A|0)<0){t=A;i=h;return t|0}A=e;F=e+32|0;TGb(c[A>>2]|0,0,ba(c[F>>2]|0,c[w>>2]|0)|0)|0;c[e+88>>2]=1;c[e+304>>2]=1;E=c[o>>2]|0;L=E;M=L-(c[p>>2]|0)+D|0;N=c[e+4>>2]|0;O=N;do{if((C|0)==1&(D|0)>1){if(((c[r>>2]|0)-L|0)<1){P=0}else{if(!((d[E]|0)>>>0<6>>>0)){B=26;break}c[o>>2]=E+1;P=d[E]|0}c[O>>2]=c[1244144+(d[1493760+(P<<2)|0]<<2)>>2];c[N+4>>2]=c[1244144+(d[1493761+(P<<2)|0]<<2)>>2];c[N+8>>2]=c[1244144+(d[1493762+(P<<2)|0]<<2)>>2];c[N+12>>2]=c[1244144+(d[1493763+(P<<2)|0]<<2)>>2];Q=4}else{B=26}}while(0);do{if((B|0)==26){if((C|0)==3){L=(D|0)>16?16:D;if((L|0)<=0){Q=L;break}R=c[r>>2]|0;S=0;T=E;while(1){if((R-T|0)<1){U=0;V=T}else{W=T+1|0;c[o>>2]=W;U=d[T]|0;V=W}c[O+(S<<2)>>2]=c[1223040+((U>>>0>63>>>0?63:U)<<2)>>2];W=S+1|0;if((W|0)<(L|0)){S=W;T=V}else{Q=L;break}}}else if((C|0)==2){L=(D|0)>16?16:D;if((L|0)<=0){Q=L;break}T=c[r>>2]|0;S=0;R=E;while(1){if((T-R|0)<1){X=0;Y=R}else{W=R+1|0;c[o>>2]=W;X=d[R]|0;Y=W}c[O+(S<<2)>>2]=c[1244144+((X>>>0>15>>>0?15:X)<<2)>>2];W=S+1|0;if((W|0)<(L|0)){S=W;R=Y}else{Q=L;break}}}else{if(!((C-4|0)>>>0<2>>>0)){if((j|0)==2){c[O>>2]=c[311036];c[N+4>>2]=c[311039];c[N+8>>2]=c[311041];c[N+12>>2]=c[311043];Q=4;break}else if((j|0)==1){c[O>>2]=-16777216;c[N+4>>2]=-1;Q=2;break}else{UGb(N|0,1244144,64)|0;Q=16;break}}if((D|0)>770){Z=256}else{L=(D|0)/3|0;if((D|0)>2){Z=L}else{Q=L;break}}L=c[r>>2]|0;R=0;S=E;while(1){if((L-S|0)<3){_=0;$=S}else{T=S+3|0;c[o>>2]=T;_=d[S+1|0]<<8|d[S]<<16|d[S+2|0];$=T}c[O+(R<<2)>>2]=_<<2|_>>>4&197379|-16777216;T=R+1|0;if((T|0)<(Z|0)){R=T;S=$}else{Q=Z;break}}}}}while(0);TGb(O+(Q<<2)|0,0,1024-(Q<<2)|0)|0;E=c[r>>2]|0;N=c[p>>2]|0;S=E;R=S-N|0;if((M|0)<0){aa=0}else{aa=(R|0)<(M|0)?R:M}R=N+aa|0;c[o>>2]=R;L=c[w>>2]|0;T=L-1|0;a:do{if((S-R|0)<2){ca=R;B=51}else{W=N+(aa+2)|0;c[o>>2]=W;da=R;if((d[da]|d[da+1|0]<<8)<<16>>16<<16>>16==0){ca=W;B=51;break}da=S-W|0;if(da>>>0>5>>>0){ea=(v|0)==8;fa=(1<<v)-1|0;ga=0;ha=T;ia=0;ja=0;ka=da;da=E;la=W;while(1){W=da;if((W-la|0)<2){ma=0;na=la}else{oa=la+2|0;c[o>>2]=oa;pa=la;ma=(d[pa]|d[pa+1|0]<<8)<<16>>16&65535;na=oa}oa=ka-((ka|0)>(ma|0)?ma:ka)|0;pa=W-na|0;qa=pa>>>0>2>>>0?2:pa;pa=na+qa|0;c[o>>2]=pa;if((W-pa|0)<1){ra=0}else{c[o>>2]=na+(qa+1);ra=d[pa]|0}pa=ja;qa=ia;W=ha;sa=ga;b:while(1){ta=ba(qa,v)|0;ua=pa;va=W;wa=sa;while(1){xa=c[z>>2]|0;if(!ea){ya=ua;break}if((qa|0)>=(xa|0)){za=ua;break b}Aa=c[o>>2]|0;Ba=c[r>>2]|0;Ca=Ba;Da=Ca-Aa|0;if(!(Da>>>0>oa>>>0)){za=ua;break b}if((Da|0)<1){Ea=0;Fa=Aa}else{Da=Aa+1|0;c[o>>2]=Da;Ea=d[Aa]|0;Fa=Da}do{if((Ea|0)==(ra|0)){if((Ca-Fa|0)<1){Ga=Fa;B=70}else{Da=Fa+1|0;c[o>>2]=Da;Aa=a[Fa]|0;if(Aa<<24>>24==0){Ga=Da;B=70}else{Ha=Aa&255;Ia=Da}}do{if((B|0)==70){B=0;if((Ca-Ga|0)<2){Ha=0;Ia=Ga;break}Da=Ga+2|0;c[o>>2]=Da;Aa=Ga;Ha=(d[Aa]|d[Aa+1|0]<<8)<<16>>16&65535;Ia=Da}}while(0);if((Ca-Ia|0)<1){Ja=Ha;Ka=0;La=Ia;break}Da=Ia+1|0;c[o>>2]=Da;Ja=Ha;Ka=d[Ia]|0;La=Da}else{Ja=1;Ka=Ea;La=Fa}}while(0);if((Ba|0)==(La|0)){za=Ka;break b}Ca=Ka&255;Da=Ja;Aa=va;Ma=wa;while(1){if((Da|0)<=0){Na=Ma;break}Oa=c[A>>2]|0;Pa=ba(c[F>>2]|0,Aa)|0;Qa=Da+Ma|0;Ra=c[u>>2]|0;if((Qa|0)<(Ra|0)){B=91;break}Sa=Ra-Ma|0;TGb(Oa+(Pa+Ma)|0,Ca|0,Sa|0)|0;Ra=Aa-1|0;if((Ra|0)<0){break a}else{Da=Da-Sa|0;Aa=Ra;Ma=0}}if((B|0)==91){B=0;TGb(Oa+(Pa+Ma)|0,Ca|0,Da|0)|0;Na=Qa}if((Aa|0)<0){break a}else{ua=Ka;va=Aa;wa=Na}}while(1){if((qa|0)>=(xa|0)){za=ya;break b}ua=c[o>>2]|0;Ba=c[r>>2]|0;Ra=Ba;Sa=Ra-ua|0;if(!(Sa>>>0>oa>>>0)){za=ya;break b}if((Sa|0)<1){Ta=0;Ua=ua}else{Sa=ua+1|0;c[o>>2]=Sa;Ta=d[ua]|0;Ua=Sa}do{if((Ta|0)==(ra|0)){if((Ra-Ua|0)<1){Va=Ua;B=82}else{Sa=Ua+1|0;c[o>>2]=Sa;ua=a[Ua]|0;if(ua<<24>>24==0){Va=Sa;B=82}else{Wa=ua&255;Xa=Sa}}do{if((B|0)==82){B=0;if((Ra-Va|0)<2){Wa=0;Xa=Va;break}Sa=Va+2|0;c[o>>2]=Sa;ua=Va;Wa=(d[ua]|d[ua+1|0]<<8)<<16>>16&65535;Xa=Sa}}while(0);if((Ra-Xa|0)<1){Ya=Wa;Za=0;_a=Xa;break}Sa=Xa+1|0;c[o>>2]=Sa;Ya=Wa;Za=d[Xa]|0;_a=Sa}else{Ya=1;Za=Ta;_a=Ua}}while(0);if((Ba|0)==(_a|0)){za=Za;break b}if((Ya|0)>0){break}else{ya=Za}}Ra=Ya;Aa=Za<<ta;Da=fa<<ta;Ca=qa;Ma=va;Sa=wa;while(1){ua=8;$a=Da;ab=Aa;bb=Ca;cb=Ma;db=Sa;c:while(1){eb=ua-v|0;if((eb|0)>-1){fb=eb;gb=db;hb=cb}else{ib=$a;jb=ab;kb=bb;lb=cb;mb=db;break}while(1){eb=(c[A>>2]|0)+((ba(c[F>>2]|0,hb)|0)+gb)|0;a[eb]=d[eb]|ab>>fb&$a;eb=gb+1|0;if((eb|0)==(c[u>>2]|0)){nb=hb-1|0;if((nb|0)<0){break}else{ob=0;pb=nb}}else{ob=eb;pb=hb}eb=fb-v|0;if((eb|0)>-1){fb=eb;gb=ob;hb=pb}else{ib=$a;jb=ab;kb=bb;lb=pb;mb=ob;break c}}eb=(c[w>>2]|0)-1|0;nb=bb+1|0;qb=ab<<v;rb=$a<<v;if((nb|0)<(c[z>>2]|0)){ua=fb;$a=rb;ab=qb;bb=nb;cb=eb;db=0}else{ib=rb;jb=qb;kb=nb;lb=eb;mb=0;break}}db=Ra-1|0;if((db|0)>0){Ra=db;Aa=jb;Da=ib;Ca=kb;Ma=lb;Sa=mb}else{pa=Za;qa=kb;W=lb;sa=mb;continue b}}}sa=c[o>>2]|0;W=c[r>>2]|0;pa=W-sa|0;if(pa>>>0>5>>>0){ga=wa;ha=va;ia=qa;ja=za;ka=pa;da=W;la=sa}else{sb=wa;tb=va;ub=qa;vb=za;break}}}else{sb=0;tb=T;ub=0;vb=0}la=c[I>>2]|0;if((sb|0)>=(la|0)){break}da=(ba(la,tb+1|0)|0)-sb|0;if((v|0)==8){la=vb&255;ka=da;ja=tb;ia=sb;while(1){if((ka|0)<=0){break a}wb=c[A>>2]|0;xb=ba(c[F>>2]|0,ja)|0;ha=c[u>>2]|0;if((ka+ia|0)<(ha|0)){break}ga=ha-ia|0;TGb(wb+(xb+ia)|0,la|0,ga|0)|0;ha=ja-1|0;if((ha|0)<0){break a}else{ka=ka-ga|0;ja=ha;ia=0}}TGb(wb+(xb+ia)|0,la|0,ka|0)|0;break}ja=(da|0)/(8/(v>>>0)|0|0)|0;ha=ba(ub,v)|0;if((ja|0)<=0){break}ga=ja;ja=vb<<ha;fa=(1<<v)-1<<ha;ha=ub;ea=tb;sa=sb;while(1){W=8;pa=fa;oa=ja;Sa=ha;Ma=ea;Ca=sa;d:while(1){Da=W-v|0;if((Da|0)>-1){yb=Da;zb=Ca;Ab=Ma}else{Bb=pa;Cb=oa;Db=Sa;Eb=Ma;Fb=Ca;break}while(1){Da=(c[A>>2]|0)+((ba(c[F>>2]|0,Ab)|0)+zb)|0;a[Da]=d[Da]|oa>>yb&pa;Da=zb+1|0;if((Da|0)==(c[u>>2]|0)){Aa=Ab-1|0;if((Aa|0)<0){break}else{Gb=0;Hb=Aa}}else{Gb=Da;Hb=Ab}Da=yb-v|0;if((Da|0)>-1){yb=Da;zb=Gb;Ab=Hb}else{Bb=pa;Cb=oa;Db=Sa;Eb=Hb;Fb=Gb;break d}}Da=(c[w>>2]|0)-1|0;Aa=Sa+1|0;Ra=oa<<v;ta=pa<<v;if((Aa|0)<(c[z>>2]|0)){W=yb;pa=ta;oa=Ra;Sa=Aa;Ma=Da;Ca=0}else{Bb=ta;Cb=Ra;Db=Aa;Eb=Da;Fb=0;break}}Ca=ga-1|0;if((Ca|0)>0){ga=Ca;ja=Cb;fa=Bb;ha=Db;ea=Eb;sa=Fb}else{break}}}}while(0);e:do{if((B|0)==51){if((L|0)>0){Ib=T;Jb=ca;Kb=E}else{break}while(1){S=Kb-Jb|0;if((Kb|0)==(Jb|0)){break e}R=(c[A>>2]|0)+(ba(c[F>>2]|0,Ib)|0)|0;N=c[I>>2]|0;UGb(R|0,Jb|0,N>>>0>S>>>0?S:N)|0;N=c[I>>2]|0;S=c[r>>2]|0;R=c[o>>2]|0;M=S-R|0;O=R+(M>>>0>N>>>0?N:M)|0;c[o>>2]=O;if((Ib|0)>0){Ib=Ib-1|0;Jb=O;Kb=S}else{break}}}}while(0);c[f>>2]=1;t=c[m>>2]|0;i=h;return t|0}}while(0);DDb(b,2183632,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;t=-1163346256;i=h;return t|0}function oSa(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((e|0)>0){g=0}else{return}do{h=g-f|0;i=a[b+h|0]|0;j=a[d+g|0]|0;k=a[d+h|0]|0;h=k&255;l=(j&255)-h|0;m=(i&255)-h|0;h=(l|0)>-1?l:-l|0;n=(m|0)>-1?m:-m|0;o=l+m|0;m=(o|0)>-1?o:-o|0;if((h|0)>(n|0)|(h|0)>(m|0)){p=(n|0)>(m|0)?k:j}else{p=i}a[b+g|0]=(a[c+g|0]|0)+p;g=g+1|0;}while((g|0)<(e|0));return}function pSa(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;c[b+8>>2]=a;d=b+24|0;c[d>>2]=ICb()|0;e=ICb()|0;c[b+36>>2]=e;if((c[d>>2]|0)==0|(e|0)==0){f=-12;return f|0}e=c[a+64>>2]|0;if((c[e>>2]|0)!=0){f=0;return f|0}c[e+4>>2]=1;uSa(b);f=0;return f|0}function qSa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0;j=i;i=i+24|0;k=j|0;l=c[e+60>>2]|0;m=c[h+24>>2]|0;n=c[h+28>>2]|0;c[k>>2]=0;o=l+24|0;p=o;U0a(e,p);q=j+8|0;c[q>>2]=c[o>>2];c[q+4>>2]=c[o+4>>2];c[q+8>>2]=c[o+8>>2];r=l+36|0;s=r;c[o>>2]=c[r>>2];c[o+4>>2]=c[r+4>>2];c[o+8>>2]=c[r+8>>2];c[r>>2]=c[q>>2];c[r+4>>2]=c[q+4>>2];c[r+8>>2]=c[q+8>>2];q=r;r=c[q>>2]|0;if(!((n|0)>-1)){yDb(0,0,2208736,(t=i,i=i+24|0,c[t>>2]=2200256,c[t+8>>2]=2191632,c[t+16>>2]=135,t)|0);i=t;Cd();return 0}u=l+12|0;c[u>>2]=m;v=l+20|0;c[v>>2]=m;w=l+16|0;c[w>>2]=m+n;do{if((n|0)>=8){c[u>>2]=m+8;x=m;y=x|0;z=x+4|0;x=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=fe(x|0)|0;x=z|0;if(!((y|0)==218765834&(x|0)==(-1974645177|0)|(y|0)==218765834&(x|0)==(-1991225785|0))){break}x=l+48|0;c[x>>2]=0;y=l+1168|0;c[y>>2]=0;z=l+1172|0;A=z;c[l+1204>>2]=36;c[l+1208>>2]=20;c[l+1212>>2]=0;B=Qd(A|0,2106600,56)|0;if((B|0)!=0){yDb(e,16,2049272,(t=i,i=i+8|0,c[t>>2]=B,t)|0);i=t;C=-542398533;i=j;return C|0}B=c[u>>2]|0;D=c[w>>2]|0;a:do{if((D|0)==(B|0)){E=e;F=l+1124|0;G=11}else{H=e+688|0;I=l+52|0;J=l+56|0;K=e;L=l+60|0;M=l+64|0;N=l+68|0;O=l+76|0;P=l+72|0;Q=e+224|0;R=e+228|0;S=e+120|0;T=e+124|0;U=l+80|0;V=l+84|0;W=l+88|0;X=l+1160|0;Y=e+140|0;Z=r+88|0;_=r+84|0;$=r+296|0;aa=l+1156|0;ca=r|0;da=l+92|0;ea=r+32|0;fa=l+96|0;ga=r+4|0;ha=l+100|0;ia=l+1128|0;ja=ia;ka=l+1132|0;la=l+1136|0;ma=la;na=l+1140|0;oa=l+1144|0;pa=oa;qa=l+1148|0;ra=l+1124|0;sa=l+1188|0;ta=l+1184|0;ua=l+1152|0;va=l+1164|0;wa=l+1176|0;xa=z;ya=l;za=ha;Aa=D;Ba=B;b:while(1){Ca=Aa;if((Ca-Ba|0)<4){Da=0;Ea=Ba}else{Fa=Ba+4|0;c[u>>2]=Fa;Ga=Ba;Ha=fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0;if((Ha|0)<0){G=15;break}if(Ha>>>0>(Ca-Fa|0)>>>0){G=15;break}else{Da=Ha;Ea=Fa}}if((Ca-Ea|0)<4){Ia=0}else{c[u>>2]=Ea+4;Ca=Ea;Ia=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0}if((c[H>>2]&256|0)!=0){yDb(K,48,1938136,(t=i,i=i+40|0,c[t>>2]=Ia&255,c[t+8>>2]=Ia>>>8&255,c[t+16>>2]=Ia>>>16&255,c[t+24>>2]=Ia>>>24,c[t+32>>2]=Da,t)|0);i=t}do{if((Ia|0)==1951945850){if((sSa(c[u>>2]|0,Da,1,k)|0)<0){yDb(K,24,2272120,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}Ca=Da+4|0;Fa=c[w>>2]|0;Ha=c[u>>2]|0;Ga=Fa-Ha|0;Ja=Ha+(Ga>>>0>Ca>>>0?Ca:Ga)|0;c[u>>2]=Ja;Ka=Ja;La=Fa}else if((Ia|0)==1163152464){if(((Da>>>0)%3|0|0)!=0|Da>>>0>768>>>0){G=180;break}Fa=(Da>>>0)/3|0;if(Da>>>0>2>>>0){Ja=Fa>>>0>1>>>0;Ga=0;do{Ca=c[u>>2]|0;Ha=c[w>>2]|0;if((Ha-Ca|0)<1){Ma=-16777216;Na=Ca}else{Oa=Ca+1|0;c[u>>2]=Oa;Ma=(d[Ca]|0)<<16|-16777216;Na=Oa}if((Ha-Na|0)<1){Pa=0;Qa=Na}else{Oa=Na+1|0;c[u>>2]=Oa;Pa=(d[Na]|0)<<8;Qa=Oa}if((Ha-Qa|0)<1){Ra=0}else{c[u>>2]=Qa+1;Ra=d[Qa]|0}c[za+(Ga<<2)>>2]=Ma|Pa|Ra;Ga=Ga+1|0;}while((Ga|0)<(Fa|0));Ga=Ja?Fa:1;if(Ga>>>0<256>>>0){Sa=Ga;G=161}}else{Sa=0;G=161}if((G|0)==161){while(1){G=0;c[za+(Sa<<2)>>2]=-16777216;Ga=Sa+1|0;if((Ga|0)<256){Sa=Ga;G=161}else{break}}}c[x>>2]=c[x>>2]|8;Fa=c[w>>2]|0;Ja=c[u>>2]|0;Ga=Fa-Ja|0;Ha=Ja+(Ga>>>0>4>>>0?4:Ga)|0;c[u>>2]=Ha;Ka=Ha;La=Fa}else if((Ia|0)==1935231088){if((c[x>>2]&2|0)!=0){G=42;break b}Fa=c[w>>2]|0;Ha=c[u>>2]|0;Ga=Fa;if((Ga-Ha|0)<4){Ta=0;Ua=Ha}else{Ja=Ha+4|0;c[u>>2]=Ja;Oa=Ha;Ta=fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0;Ua=Ja}c[Q>>2]=Ta;if((Ga-Ua|0)<4){Va=0;Wa=Ua}else{Ga=Ua+4|0;c[u>>2]=Ga;Ja=Ua;Va=fe(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0;Wa=Ga}c[R>>2]=Va;if((Ta|Va|0)<0){c[Q>>2]=0;c[R>>2]=1;Xa=c[w>>2]|0;Ya=c[u>>2]|0}else{Xa=Fa;Ya=Wa}Fa=Xa;Ga=Fa-Ya|0;Ja=Ga>>>0>1>>>0?1:Ga;Ga=Fa-(Ya+Ja)|0;Fa=Ya+((Ga>>>0>4>>>0?4:Ga)+Ja)|0;c[u>>2]=Fa;Ka=Fa;La=Xa}else if((Ia|0)==1380206665){if((Da|0)!=13){Za=ra;G=243;break a}Fa=c[u>>2]|0;Ja=c[w>>2]|0;if((Ja-Fa|0)<4){_a=0;$a=Fa}else{Ga=Fa+4|0;c[u>>2]=Ga;Oa=Fa;_a=fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0;$a=Ga}c[I>>2]=_a;if((Ja-$a|0)<4){ab=0}else{c[u>>2]=$a+4;Ja=$a;ab=fe(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0}c[J>>2]=ab;if((hDb(_a,ab,0,K)|0)!=0){G=27;break b}Ja=c[w>>2]|0;Ga=c[u>>2]|0;Oa=Ja;if((Oa-Ga|0)<1){bb=0;cb=Ga}else{Fa=Ga+1|0;c[u>>2]=Fa;bb=d[Ga]|0;cb=Fa}c[L>>2]=bb;if((Oa-cb|0)<1){db=0;eb=cb}else{Fa=cb+1|0;c[u>>2]=Fa;db=d[cb]|0;eb=Fa}c[M>>2]=db;if((Oa-eb|0)<1){fb=0;gb=eb}else{Fa=eb+1|0;c[u>>2]=Fa;fb=d[eb]|0;gb=Fa}c[N>>2]=fb;if((Oa-gb|0)<1){hb=0;ib=gb}else{Fa=gb+1|0;c[u>>2]=Fa;hb=d[gb]|0;ib=Fa}c[O>>2]=hb;if((Oa-ib|0)<1){jb=0;kb=ib}else{Fa=ib+1|0;c[u>>2]=Fa;jb=d[ib]|0;kb=Fa}c[P>>2]=jb;Fa=Oa-kb|0;Oa=kb+(Fa>>>0>4>>>0?4:Fa)|0;c[u>>2]=Oa;c[x>>2]=c[x>>2]|1;if((c[H>>2]&1|0)==0){Ka=Oa;La=Ja;break}Ja=c[J>>2]|0;yDb(K,48,1893624,(t=i,i=i+56|0,c[t>>2]=c[I>>2],c[t+8>>2]=Ja,c[t+16>>2]=bb,c[t+24>>2]=db,c[t+32>>2]=fb,c[t+40>>2]=hb,c[t+48>>2]=jb,t)|0);i=t;Ka=c[u>>2]|0;La=c[w>>2]|0}else if((Ia|0)==1145980233){G=176;break b}else if((Ia|0)==1397641844){if((c[M>>2]|0)!=3|Da>>>0>256>>>0){G=180;break}if((c[x>>2]&8|0)==0){G=180;break}Ja=c[w>>2]|0;Oa=c[u>>2]|0;Fa=Ja-Oa|0;if((Da|0)==0){lb=Oa;mb=Fa;nb=Ja}else{Ja=0;Ga=Oa;Oa=Fa;while(1){if((Oa|0)<1){ob=0}else{c[u>>2]=Ga+1;ob=(d[Ga]|0)<<24}Fa=za+(Ja<<2)|0;c[Fa>>2]=c[Fa>>2]&16777215|ob;Fa=Ja+1|0;Ha=c[w>>2]|0;Ca=c[u>>2]|0;pb=Ha-Ca|0;if(Fa>>>0<Da>>>0){Ja=Fa;Ga=Ca;Oa=pb}else{lb=Ca;mb=pb;nb=Ha;break}}}Oa=lb+(mb>>>0>4>>>0?4:mb)|0;c[u>>2]=Oa;Ka=Oa;La=nb}else if((Ia|0)==1951942004){if((sSa(c[u>>2]|0,Da,0,k)|0)<0){yDb(K,24,2288352,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}Oa=Da+4|0;Ga=c[w>>2]|0;Ja=c[u>>2]|0;Ha=Ga-Ja|0;pb=Ja+(Ha>>>0>Oa>>>0?Oa:Ha)|0;c[u>>2]=pb;Ka=pb;La=Ga}else if((Ia|0)==1413563465){Ga=c[x>>2]|0;if((Ga&1|0)==0){G=51;break b}if((Ga&2|0)==0){c[S>>2]=c[I>>2];c[T>>2]=c[J>>2];pb=Umb(c[M>>2]|0)|0;c[U>>2]=pb;qb=c[L>>2]|0;Ha=ba(qb,pb)|0;c[V>>2]=Ha;c[W>>2]=Ha+7>>3;c[X>>2]=(ba(Ha,c[S>>2]|0)|0)+7>>3;do{if((qb|0)==16){G=63}else if((qb|0)==2|(qb|0)==4|(qb|0)==8){if((c[M>>2]|0)==2){c[Y>>2]=2;break}if((qb|0)==16){G=63;break}else if(!((qb|0)==2|(qb|0)==4|(qb|0)==8)){G=68;break}if((c[M>>2]|0)==6){c[Y>>2]=28;break}if((qb|0)==16){G=63;break}else if(!((qb|0)==2|(qb|0)==4|(qb|0)==8)){G=68;break}if((c[M>>2]|0)==0){c[Y>>2]=8;break}else{if((qb|0)==16){G=63;break}else{G=68;break}}}else{G=68}}while(0);do{if((G|0)==63){G=0;if((c[M>>2]|0)==0){c[Y>>2]=31;break}pb=c[M>>2]|0;if((pb|0)==2){c[Y>>2]=41;break}else if((pb|0)==6){c[Y>>2]=291;break}else{G=68;break}}}while(0);c:do{if((G|0)==68){G=0;do{if((Ha|0)==1|(Ha|0)==2|(Ha|0)==4|(Ha|0)==8){if((c[M>>2]|0)!=3){break}c[Y>>2]=11;break c}}while(0);if((qb|0)==1){c[Y>>2]=10;break}else if((qb|0)!=8){G=72;break b}pb=c[M>>2]|0;if((pb|0)!=4){rb=pb;break b}c[Y>>2]=66}}while(0);if((W0a(e,s,1)|0)<0){Za=ra;G=243;break a}X0a(e);c[Z>>2]=1;c[_>>2]=1;c[$>>2]=(c[P>>2]|0)!=0;if((c[P>>2]|0)==0){sb=c[X>>2]|0}else{c[ua>>2]=0;Ha=Vmb(0,c[V>>2]|0,c[I>>2]|0)|0;c[va>>2]=Ha;sb=Ha}c[aa>>2]=sb+1;c[da>>2]=c[ca>>2];c[fa>>2]=c[ea>>2];if((c[Y>>2]|0)==11){UGb(c[ga>>2]|0,ha|0,1024)|0}P$a(ia,ka,c[X>>2]|0);if((c[ja>>2]|0)==0){Za=ra;G=243;break a}if((c[P>>2]|0)==0){if((c[M>>2]|0)==6){G=86}}else{G=86}if((G|0)==86){G=0;O$a(la,na,c[X>>2]|0);if((c[ma>>2]|0)==0){Za=ra;G=243;break a}}O$a(oa,qa,(c[X>>2]|0)+16|0);Ha=c[pa>>2]|0;if((Ha|0)==0){Za=ra;G=243;break a}pb=Ha+15|0;c[ra>>2]=pb;c[sa>>2]=c[aa>>2];c[ta>>2]=pb;tb=c[x>>2]|0}else{tb=Ga}c[x>>2]=tb|2;pb=c[u>>2]|0;Ha=(c[w>>2]|0)-pb|0;Oa=Ha>>>0<Da>>>0?Ha:Da;c[wa>>2]=Oa;c[xa>>2]=pb;c[u>>2]=pb+(Ha>>>0>Da>>>0?Da:Ha);Ha=Oa;while(1){if((Ha|0)==0){break}ub=$c(A|0,1)|0;if(ub>>>0>1>>>0){G=148;break b}if((c[sa>>2]|0)==0){d:do{if((c[x>>2]&4|0)==0){if((c[P>>2]|0)==0){Oa=c[da>>2]|0;pb=c[fa>>2]|0;Ja=c[y>>2]|0;Ca=ba(Ja,pb)|0;Fa=Oa+Ca|0;if((Ja|0)==0){vb=c[ja>>2]|0}else{vb=Oa+(Ca-pb)|0}pb=c[ra>>2]|0;tSa(ya,Fa,d[pb]|0,pb+1|0,vb,c[X>>2]|0,c[W>>2]|0);do{if((c[O>>2]|0)==64){if((c[y>>2]|0)<=0){break}pb=Ca-(c[fa>>2]|0)|0;if((c[L>>2]|0)==16){Ja=Oa+pb|0;wb=c[X>>2]|0;xb=(wb|0)/2|0;if((wb|0)<=1){break}wb=(c[M>>2]|0)==6?4:3;yb=0;do{zb=b[Ja+(yb+1<<1)>>1]|0;Ab=Ja+(yb<<1)|0;b[Ab>>1]=(b[Ab>>1]|0)+zb;Ab=Ja+(yb+2<<1)|0;b[Ab>>1]=(b[Ab>>1]|0)+zb;yb=yb+wb|0;}while((yb|0)<(xb|0))}else{xb=c[X>>2]|0;if((xb|0)<=0){break}yb=(c[M>>2]|0)==6?4:3;wb=pb+1|0;Ja=pb+2|0;zb=0;do{Ab=a[Oa+(wb+zb)|0]|0;Bb=Oa+(zb+pb)|0;a[Bb]=(a[Bb]|0)+Ab;Bb=Oa+(Ja+zb)|0;a[Bb]=(a[Bb]|0)+Ab;zb=zb+yb|0;}while((zb|0)<(xb|0))}}}while(0);xb=(c[y>>2]|0)+1|0;c[y>>2]=xb;if((xb|0)!=(c[J>>2]|0)){break}c[x>>2]=c[x>>2]|4;if((c[O>>2]|0)!=64){break}if((c[L>>2]|0)==16){xb=Fa;zb=c[X>>2]|0;yb=(zb|0)/2|0;if((zb|0)<=1){break}zb=(c[M>>2]|0)==6?4:3;Ja=0;while(1){pb=b[xb+(Ja+1<<1)>>1]|0;wb=xb+(Ja<<1)|0;b[wb>>1]=(b[wb>>1]|0)+pb;wb=xb+(Ja+2<<1)|0;b[wb>>1]=(b[wb>>1]|0)+pb;Ja=Ja+zb|0;if((Ja|0)>=(yb|0)){break d}}}else{yb=c[X>>2]|0;if((yb|0)<=0){break}Ja=(c[M>>2]|0)==6?4:3;zb=Ca+1|0;xb=Ca+2|0;Fa=0;while(1){pb=a[Oa+(zb+Fa)|0]|0;wb=Oa+(Fa+Ca)|0;a[wb]=(a[wb]|0)+pb;wb=Oa+(xb+Fa)|0;a[wb]=(a[wb]|0)+pb;Fa=Fa+Ja|0;if((Fa|0)>=(yb|0)){break d}}}}else{Cb=0}e:while(1){yb=c[da>>2]|0;Fa=c[y>>2]|0;Ja=ba(Fa,c[fa>>2]|0)|0;xb=yb+Ja|0;Oa=c[ua>>2]|0;if(((d[1155552+Oa|0]|0)&128>>>((Fa&7)>>>0)|0)==0){Db=Cb;Eb=Oa;Fb=Fa}else{if((Cb|0)!=0){break d}Fa=c[ra>>2]|0;tSa(ya,c[ma>>2]|0,d[Fa]|0,Fa+1|0,c[ja>>2]|0,c[va>>2]|0,c[W>>2]|0);Fa=c[ma>>2]|0;c[ma>>2]=c[ja>>2];c[ja>>2]=Fa;Fa=c[na>>2]|0;c[na>>2]=c[ka>>2];c[ka>>2]=Fa;Db=1;Eb=c[ua>>2]|0;Fb=c[y>>2]|0}do{if(((d[563648+Eb|0]|0)&128>>>((Fb&7)>>>0)|0)!=0){Fa=c[I>>2]|0;Oa=c[V>>2]|0;Ca=c[ja>>2]|0;zb=d[563640+Eb|0]|0;pb=d[563656+Eb|0]|0;if((Oa|0)==4){if((Fa|0)>0){Gb=0;Hb=0}else{break}while(1){wb=Hb<<2&4;Ab=128>>>((Hb&7)>>>0);if((Ab&pb|0)!=0){Bb=yb+((Hb>>1)+Ja)|0;a[Bb]=((d[Ca+(Gb>>1)|0]|0)>>>((Gb<<2&4^4)>>>0)&15)<<4-wb|(d[Bb]|0)&65295>>>(wb>>>0)}wb=Hb+1|0;if((wb|0)<(Fa|0)){Gb=((Ab&zb|0)!=0)+Gb|0;Hb=wb}else{break}}}else if((Oa|0)==2){if((Fa|0)>0){Ib=0;Jb=0}else{break}while(1){wb=Jb<<1&6;Ab=128>>>((Jb&7)>>>0);if((Ab&pb|0)!=0){Bb=yb+((Jb>>2)+Ja)|0;a[Bb]=((d[Ca+(Ib>>2)|0]|0)>>>((Ib<<1&6^6)>>>0)&3)<<6-wb|(d[Bb]|0)&65343>>>(wb>>>0)}wb=Jb+1|0;if((wb|0)<(Fa|0)){Ib=((Ab&zb|0)!=0)+Ib|0;Jb=wb}else{break}}}else if((Oa|0)==1){if((Fa|0)>0){Kb=0;Lb=0}else{break}while(1){wb=Lb&7;Ab=128>>>(wb>>>0);if((Ab&pb|0)!=0){Bb=yb+((Lb>>3)+Ja)|0;a[Bb]=((d[Ca+(Kb>>3)|0]|0)>>>((Kb&7^7)>>>0)&1)<<(wb^7)|(d[Bb]|0)&65407>>>(wb>>>0)}wb=Lb+1|0;if((wb|0)<(Fa|0)){Kb=((Ab&zb|0)!=0)+Kb|0;Lb=wb}else{break}}}else{wb=Oa>>3;if((Fa|0)>0){Mb=xb;Nb=Ca;Ob=0}else{break}while(1){Ab=128>>>((Ob&7)>>>0);if((Ab&pb|0)!=0){UGb(Mb|0,Nb|0,wb)|0}if((Ab&zb|0)==0){Pb=Nb}else{Pb=Nb+wb|0}Ab=Ob+1|0;if((Ab|0)<(Fa|0)){Mb=Mb+wb|0;Nb=Pb;Ob=Ab}else{break}}}}}while(0);xb=(c[y>>2]|0)+1|0;c[y>>2]=xb;if((xb|0)!=(c[J>>2]|0)){Cb=Db;continue}TGb(c[ja>>2]|0,0,c[X>>2]|0)|0;while(1){xb=c[ua>>2]|0;if((xb|0)==6){break e}Ja=xb+1|0;c[ua>>2]=Ja;c[y>>2]=0;xb=Vmb(Ja,c[V>>2]|0,c[I>>2]|0)|0;c[va>>2]=xb;c[aa>>2]=xb+1;if((xb|0)!=0){Cb=Db;continue e}}}c[x>>2]=c[x>>2]|4}}while(0);c[sa>>2]=c[aa>>2];c[ta>>2]=c[ra>>2]}Qb=c[wa>>2]|0;if((ub|0)==1){G=146;break}else{Ha=Qb}}do{if((G|0)==146){G=0;if((Qb|0)==0){break}yDb(0,24,2218120,(t=i,i=i+8|0,c[t>>2]=Qb,t)|0);i=t}}while(0);Ha=c[w>>2]|0;Ga=c[u>>2]|0;xb=Ha-Ga|0;Ja=Ga+(xb>>>0>4>>>0?4:xb)|0;c[u>>2]=Ja;Ka=Ja;La=Ha}else{G=180}}while(0);if((G|0)==180){G=0;Ha=Da+4|0;Ja=c[w>>2]|0;xb=c[u>>2]|0;Ga=Ja-xb|0;yb=xb+(Ga>>>0>Ha>>>0?Ha:Ga)|0;c[u>>2]=yb;Ka=yb;La=Ja}if((La|0)==(Ka|0)){E=K;F=ra;G=11;break a}else{Aa=La;Ba=Ka}}if((G|0)==15){yDb(K,16,1966224,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Za=ra;G=243;break}else if((G|0)==27){c[J>>2]=0;c[I>>2]=0;yDb(K,16,1914056,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Za=ra;G=243;break}else if((G|0)==42){yDb(K,16,2351064,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Za=ra;G=243;break}else if((G|0)==51){yDb(K,16,2330952,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Za=ra;G=243;break}else if((G|0)==72){rb=c[M>>2]|0}else if((G|0)==148){yDb(c[l+8>>2]|0,16,2230008,(t=i,i=i+8|0,c[t>>2]=ub,t)|0);i=t;Za=ra;G=243;break}else if((G|0)==176){Ba=c[x>>2]|0;if((Ba&4|0)==0){yDb(K,16,2256768,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Rb=c[x>>2]|0}else{Rb=Ba}if((Rb&6|0)==0){Za=ra;G=243;break}Ba=c[u>>2]|0;Aa=(c[w>>2]|0)-Ba|0;c[u>>2]=Ba+(Aa>>>0>4>>>0?4:Aa);Aa=c[V>>2]|0;do{if((Aa|0)==1){if((c[M>>2]|0)!=3){break}if((c[J>>2]|0)<=0){break}Ba=1;wa=c[ca>>2]|0;while(1){ta=c[I>>2]|0;aa=(ta|0)/8|0;sa=wa+aa|0;va=aa<<3;if((ta&7|0)==7){a[wa+(va|6)|0]=(d[sa]|0)>>>1&1;Sb=c[I>>2]|0}else{Sb=ta}if((Sb&6)>>>0<6>>>0){Tb=Sb}else{a[wa+(va|5)|0]=(d[sa]|0)>>>2&1;Tb=c[I>>2]|0}if((Tb&7)>>>0<5>>>0){Ub=Tb}else{a[wa+(va|4)|0]=(d[sa]|0)>>>3&1;Ub=c[I>>2]|0}if((Ub&4)>>>0<4>>>0){Vb=Ub}else{a[wa+(va|3)|0]=(d[sa]|0)>>>4&1;Vb=c[I>>2]|0}if((Vb&7)>>>0<3>>>0){Wb=Vb}else{a[wa+(va|2)|0]=(d[sa]|0)>>>5&1;Wb=c[I>>2]|0}if((Wb&6)>>>0<2>>>0){Xb=Wb}else{a[wa+(va|1)|0]=(d[sa]|0)>>>6&1;Xb=c[I>>2]|0}if((Xb&7|0)!=0){a[wa+va|0]=(d[sa]|0)>>>7}if((ta|0)>7){ta=aa;do{ta=ta-1|0;aa=wa+ta|0;sa=ta<<3;a[wa+(sa|7)|0]=a[aa]&1;a[wa+(sa|6)|0]=(d[aa]|0)>>>1&1;a[wa+(sa|5)|0]=(d[aa]|0)>>>2&1;a[wa+(sa|4)|0]=(d[aa]|0)>>>3&1;a[wa+(sa|3)|0]=(d[aa]|0)>>>4&1;a[wa+(sa|2)|0]=(d[aa]|0)>>>5&1;a[wa+(sa|1)|0]=(d[aa]|0)>>>6&1;a[wa+sa|0]=(d[aa]|0)>>>7;}while((ta|0)>0)}if((Ba|0)>=(c[J>>2]|0)){break}Ba=Ba+1|0;wa=wa+(c[fa>>2]|0)|0}Yb=c[V>>2]|0;G=191}else{Yb=Aa;G=191}}while(0);f:do{if((G|0)==191){do{if((Yb|0)==2){if((c[J>>2]|0)<=0){Zb=Yb;break}Aa=1;wa=c[ca>>2]|0;while(1){Ba=c[I>>2]|0;ta=(Ba|0)/4|0;aa=(Ba&3|0)==3;do{if((c[M>>2]|0)==3){if(aa){a[wa+(ta<<2|2)|0]=(d[wa+ta|0]|0)>>>2&3;_b=c[I>>2]|0}else{_b=Ba}if((_b&2)>>>0>1>>>0){a[wa+(ta<<2|1)|0]=(d[wa+ta|0]|0)>>>4&3;$b=c[I>>2]|0}else{$b=_b}if(($b&3|0)!=0){a[wa+(ta<<2)|0]=(d[wa+ta|0]|0)>>>6}if((Ba|0)>3){ac=ta}else{break}do{ac=ac-1|0;sa=wa+ac|0;va=ac<<2;a[wa+(va|3)|0]=a[sa]&3;a[wa+(va|2)|0]=(d[sa]|0)>>>2&3;a[wa+(va|1)|0]=(d[sa]|0)>>>4&3;a[wa+va|0]=(d[sa]|0)>>>6;}while((ac|0)>0)}else{if(aa){a[wa+(ta<<2|2)|0]=((d[wa+ta|0]|0)>>>2&3)*85;bc=c[I>>2]|0}else{bc=Ba}if((bc&2)>>>0>1>>>0){a[wa+(ta<<2|1)|0]=((d[wa+ta|0]|0)>>>4&3)*85;cc=c[I>>2]|0}else{cc=bc}if((cc&3|0)!=0){a[wa+(ta<<2)|0]=((d[wa+ta|0]|0)>>>6)*85}if((Ba|0)>3){dc=ta}else{break}do{dc=dc-1|0;sa=wa+dc|0;va=dc<<2;a[wa+(va|3)|0]=(a[sa]&3)*85;a[wa+(va|2)|0]=((d[sa]|0)>>>2&3)*85;a[wa+(va|1)|0]=((d[sa]|0)>>>4&3)*85;a[wa+va|0]=((d[sa]|0)>>>6)*85;}while((dc|0)>0)}}while(0);if((Aa|0)>=(c[J>>2]|0)){break}Aa=Aa+1|0;wa=wa+(c[fa>>2]|0)|0}Zb=c[V>>2]|0}else{Zb=Yb}}while(0);if((Zb|0)!=4){break}if((c[J>>2]|0)<=0){break}wa=1;Aa=c[ca>>2]|0;while(1){ta=c[I>>2]|0;Ba=(ta|0)/2|0;aa=(ta&1|0)!=0;do{if((c[M>>2]|0)==3){if(aa){a[Aa+(Ba<<1)|0]=(d[Aa+Ba|0]|0)>>>4}if((ta|0)>1){ec=Ba}else{break}do{ec=ec-1|0;sa=Aa+ec|0;va=ec<<1;a[Aa+(va|1)|0]=a[sa]&15;a[Aa+va|0]=(d[sa]|0)>>>4;}while((ec|0)>0)}else{if(aa){a[Aa+(Ba<<1)|0]=((d[Aa+Ba|0]|0)>>>4)*17}if((ta|0)>1){fc=Ba}else{break}do{fc=fc-1|0;sa=Aa+fc|0;va=fc<<1;a[Aa+(va|1)|0]=(a[sa]&15)*17;a[Aa+va|0]=((d[sa]|0)>>>4)*17;}while((fc|0)>0)}}while(0);if((wa|0)>=(c[J>>2]|0)){break f}wa=wa+1|0;Aa=Aa+(c[fa>>2]|0)|0}}}while(0);M=c[o>>2]|0;V=c[M>>2]|0;do{if((V|0)!=0){if((c[h+36>>2]&1|0)!=0){break}if((c[e+52>>2]|0)==1196314701){break}if((c[M+68>>2]|0)!=(c[r+68>>2]|0)){break}if((c[M+72>>2]|0)!=(c[r+72>>2]|0)){break}if((c[M+80>>2]|0)!=(c[r+80>>2]|0)){break}Aa=c[ca>>2]|0;Z0a(p,2147483647,0);wa=c[J>>2]|0;if((wa|0)<=0){break}Ba=0;ta=Aa;Aa=V;aa=c[I>>2]|0;sa=c[W>>2]|0;va=wa;while(1){if((ba(sa,aa)|0)>0){wa=0;do{ua=ta+wa|0;a[ua]=(a[ua]|0)+(a[Aa+wa|0]|0);wa=wa+1|0;gc=c[I>>2]|0;hc=c[W>>2]|0;}while((wa|0)<(ba(hc,gc)|0));ic=gc;jc=hc;kc=c[J>>2]|0}else{ic=aa;jc=sa;kc=va}wa=c[fa>>2]|0;ua=Ba+1|0;if((ua|0)<(kc|0)){Ba=ua;ta=ta+wa|0;Aa=Aa+wa|0;aa=ic;sa=jc;va=kc}else{break}}}}while(0);Y0a(s,2147483647,0);yCb(r,c[k>>2]|0);c[k>>2]=0;fa=MCb(f,c[q>>2]|0)|0;if((fa|0)<0){C=fa;i=j;return C|0}else{c[g>>2]=1;lc=(c[u>>2]|0)-(c[v>>2]|0)|0;mc=ra;break}}yDb(K,16,2306528,(t=i,i=i+16|0,c[t>>2]=qb,c[t+8>>2]=rb,t)|0);i=t;Za=ra;G=243}}while(0);if((G|0)==11){yDb(E,16,2003704,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Za=F;G=243}if((G|0)==243){DBb(k);Y0a(s,2147483647,0);lc=-1094995529;mc=Za}he(A|0)|0;c[mc>>2]=0;C=lc;i=j;return C|0}}while(0);yDb(e,16,2183560,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;C=-1094995529;i=j;return C|0}function rSa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;d=b+24|0;U0a(a,d);JCb(d);d=b+36|0;U0a(a,d);JCb(d);$Db(b+1144|0);c[b+1148>>2]=0;$Db(b+1128|0);c[b+1132>>2]=0;$Db(b+1136|0);c[b+1140>>2]=0;return 0}function sSa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+1104|0;j=h|0;k=h+56|0;l=h+64|0;m=h+72|0;n=h+80|0;o=b+e|0;p=o;q=b;r=Ib(b|0,0,e|0)|0;if((r|0)==0){s=-1094995529;i=h;return s|0}e=r+1|0;do{if((f|0)==0){c[m>>2]=e;t=p-e|0;u=e}else{if((e|0)==(o|0)){s=-1094995529;i=h;return s|0}v=r+2|0;if((a[e]|0)!=0){s=-1094995529;i=h;return s|0}c[j+32>>2]=36;c[j+36>>2]=20;c[j+40>>2]=0;do{if((Qd(j|0,2106600,56)|0)==0){c[j>>2]=v;w=j+4|0;c[w>>2]=p-v;IAb(n,0,-1);x=j+12|0;y=j+16|0;z=n+4|0;while(1){if((c[w>>2]|0)==0){A=11;break}OAb(n,1,k,l);B=c[l>>2]|0;if((B|0)==0){C=-12;A=12;break}c[x>>2]=c[k>>2];c[y>>2]=B;B=$c(j|0,1)|0;if(B>>>0>1>>>0){C=-542398533;A=12;break}c[z>>2]=(c[x>>2]|0)-(c[k>>2]|0)+(c[z>>2]|0);if((B|0)==1){A=11;break}}if((A|0)==11){he(j|0)|0;a[(c[n>>2]|0)+(c[z>>2]|0)|0]=0;D=0;break}else if((A|0)==12){he(j|0)|0;QAb(n,0)|0;D=C;break}}else{D=-542398533}}while(0);if((D|0)<0){s=D;i=h;return s|0}x=c[n+4>>2]|0;QAb(n,m)|0;if((c[m>>2]|0)==0){s=-12}else{t=x;u=v;break}i=h;return s|0}}while(0);n=r-q|0;q=(r|0)==(b|0);if(q){E=0}else{r=0;D=0;while(1){C=((d[b+D|0]|0)>>>7&255)+r|0;j=D+1|0;if(j>>>0<n>>>0){r=C;D=j}else{E=C;break}}}do{if((n|0)==-1|E>>>0>(-2-n|0)>>>0){F=0}else{D=WDb(n+1+E|0)|0;if((D|0)==0){F=0;break}if(q){G=D}else{r=0;C=D;while(1){j=b+r|0;A=a[j]|0;if(A<<24>>24<0){k=C+1|0;a[C]=(A&255)>>>6|-64;a[k]=a[j]&63|-128;H=k}else{a[C]=A;H=C}A=H+1|0;k=r+1|0;if(k>>>0<n>>>0){r=k;C=A}else{G=A;break}}}a[G]=0;F=D}}while(0);G=c[m>>2]|0;n=(t|0)==0;if(n){I=0}else{H=0;b=0;while(1){q=((d[G+b|0]|0)>>>7&255)+H|0;E=b+1|0;if(E>>>0<t>>>0){H=q;b=E}else{I=q;break}}}do{if((t|0)==-1|I>>>0>(-2-t|0)>>>0){J=0}else{b=WDb(t+1+I|0)|0;if((b|0)==0){J=0;break}if(n){K=b}else{H=0;q=b;while(1){E=G+H|0;C=a[E]|0;if(C<<24>>24<0){r=q+1|0;a[q]=(C&255)>>>6|-64;a[r]=a[E]&63|-128;L=r}else{a[q]=C;L=q}C=L+1|0;r=H+1|0;if(r>>>0<t>>>0){H=r;q=C}else{K=C;break}}}a[K]=0;J=b}}while(0);K=c[m>>2]|0;if((K|0)!=(u|0)){ZDb(K)}if((F|0)==0|(J|0)==0){ZDb(F);ZDb(J);s=-12;i=h;return s|0}else{CBb(g,F,J,12)|0;s=0;i=h;return s|0}return 0}function tSa(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;switch(f|0){case 3:{if((j|0)>0){f=0;while(1){a[e+f|0]=((d[h+f|0]|0)>>>1)+(a[g+f|0]|0);k=f+1|0;if((k|0)<(j|0)){f=k}else{l=j;break}}}else{l=0}do{if((j|0)==1){f=i-1|0;if((l|0)>(f|0)){m=l;break}k=d[e]|0;n=l;while(1){o=(((d[h+n|0]|0)+k|0)>>>1)+(d[g+n|0]|0)|0;a[e+n|0]=o;p=n+1|0;if((p|0)>(f|0)){m=p;break}else{k=o&255;n=p}}}else if((j|0)==2){n=i-2|0;if((l|0)>(n|0)){m=l;break}k=d[e]|0;f=d[e+1|0]|0;p=l;while(1){o=(((d[h+p|0]|0)+k|0)>>>1)+(d[g+p|0]|0)|0;a[e+p|0]=o;q=p+1|0;r=(((d[h+q|0]|0)+f|0)>>>1)+(d[g+q|0]|0)|0;a[e+q|0]=r;q=p+2|0;if((q|0)>(n|0)){m=q;break}else{k=o&255;f=r&255;p=q}}}else if((j|0)==3){p=i-3|0;if((l|0)>(p|0)){m=l;break}f=d[e]|0;k=d[e+1|0]|0;n=d[e+2|0]|0;q=l;while(1){r=(((d[h+q|0]|0)+f|0)>>>1)+(d[g+q|0]|0)|0;a[e+q|0]=r;o=q+1|0;s=(((d[h+o|0]|0)+k|0)>>>1)+(d[g+o|0]|0)|0;a[e+o|0]=s;o=q+2|0;t=(((d[h+o|0]|0)+n|0)>>>1)+(d[g+o|0]|0)|0;a[e+o|0]=t;o=q+3|0;if((o|0)>(p|0)){m=o;break}else{f=r&255;k=s&255;n=t&255;q=o}}}else if((j|0)==4){q=i-4|0;if((l|0)>(q|0)){m=l;break}n=d[e]|0;k=d[e+1|0]|0;f=d[e+2|0]|0;p=d[e+3|0]|0;o=l;while(1){t=(((d[h+o|0]|0)+n|0)>>>1)+(d[g+o|0]|0)|0;a[e+o|0]=t;s=o+1|0;r=(((d[h+s|0]|0)+k|0)>>>1)+(d[g+s|0]|0)|0;a[e+s|0]=r;s=o+2|0;u=(((d[h+s|0]|0)+f|0)>>>1)+(d[g+s|0]|0)|0;a[e+s|0]=u;s=o+3|0;v=(((d[h+s|0]|0)+p|0)>>>1)+(d[g+s|0]|0)|0;a[e+s|0]=v;s=o+4|0;if((s|0)>(q|0)){m=s;break}else{n=t&255;k=r&255;f=u&255;p=v&255;o=s}}}else{m=l}}while(0);if((m|0)<(i|0)){w=m}else{return}do{a[e+w|0]=(((d[h+w|0]|0)+(d[e+(w-j)|0]|0)|0)>>>1)+(d[g+w|0]|0);w=w+1|0;}while((w|0)<(i|0));return};case 2:{cf[c[b>>2]&1023](e,g,h,i);return};case 0:{UGb(e|0,g|0,i)|0;return};case 1:{if((j|0)>0){w=0;while(1){a[e+w|0]=a[g+w|0]|0;m=w+1|0;if((m|0)<(j|0)){w=m}else{x=j;break}}}else{x=0}do{if((j|0)==3){w=i-3|0;if((x|0)>(w|0)){y=x;break}m=d[e]|0;l=d[e+1|0]|0;o=d[e+2|0]|0;p=x;while(1){f=(d[g+p|0]|0)+m|0;a[e+p|0]=f;k=p+1|0;n=(d[g+k|0]|0)+l|0;a[e+k|0]=n;k=p+2|0;q=(d[g+k|0]|0)+o|0;a[e+k|0]=q;k=p+3|0;if((k|0)>(w|0)){y=k;break}else{m=f;l=n;o=q;p=k}}}else if((j|0)==1){p=i-1|0;if((x|0)>(p|0)){y=x;break}o=d[e]|0;l=x;while(1){m=(d[g+l|0]|0)+o|0;a[e+l|0]=m;w=l+1|0;if((w|0)>(p|0)){y=w;break}else{o=m;l=w}}}else if((j|0)==4){if((x|0)>=(i|0)){return}l=c[e>>2]|0;o=x;do{p=c[g+o>>2]|0;l=(p&2139062143)+(l&2139062143)^(p^l)&-2139062144;c[e+o>>2]=l;o=o+4|0;}while((o|0)<(i|0));return}else if((j|0)==2){o=i-2|0;if((x|0)>(o|0)){y=x;break}l=d[e]|0;p=d[e+1|0]|0;w=x;while(1){m=(d[g+w|0]|0)+l|0;a[e+w|0]=m;k=w+1|0;q=(d[g+k|0]|0)+p|0;a[e+k|0]=q;k=w+2|0;if((k|0)>(o|0)){y=k;break}else{l=m;p=q;w=k}}}else{y=x}}while(0);if((y|0)<(i|0)){z=y}else{return}do{a[e+z|0]=(a[g+z|0]|0)+(a[e+(z-j)|0]|0);z=z+1|0;}while((z|0)<(i|0));return};case 4:{do{if((j|0)>0){z=0;do{a[e+z|0]=(a[g+z|0]|0)+(a[h+z|0]|0);z=z+1|0;}while((z|0)<(j|0));if(!((j|0)>2&(i|0)>4)){A=j;break}z=(j|0)==4?i:i-3|0;le[c[b+4>>2]&1023](e+j|0,g+j|0,h+j|0,z-j|0,j);A=z}else{A=0}}while(0);b=i-A|0;if((b|0)>0){B=0}else{return}do{i=B-j+A|0;z=a[e+i|0]|0;y=B+A|0;x=a[h+y|0]|0;w=a[h+i|0]|0;i=w&255;p=(x&255)-i|0;l=(z&255)-i|0;i=(p|0)>-1?p:-p|0;o=(l|0)>-1?l:-l|0;k=p+l|0;l=(k|0)>-1?k:-k|0;if((i|0)>(o|0)|(i|0)>(l|0)){C=(o|0)>(l|0)?w:x}else{C=z}a[e+y|0]=(a[g+y|0]|0)+C;B=B+1|0;}while((B|0)<(b|0));return};default:{return}}}function uSa(a){a=a|0;c[a>>2]=68;c[a+4>>2]=330;return}function vSa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f-4|0;if((g|0)<0){h=0}else{i=0;while(1){j=c[d+i>>2]|0;k=c[e+i>>2]|0;c[b+i>>2]=(k&2139062143)+(j&2139062143)^(k^j)&-2139062144;j=i+4|0;if((j|0)>(g|0)){h=j;break}else{i=j}}}if((h|0)<(f|0)){l=h}else{return}do{a[b+l|0]=(a[e+l|0]|0)+(a[d+l|0]|0);l=l+1|0;}while((l|0)<(f|0));return}function wSa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;e=a+140|0;switch(c[e>>2]|0){case 8:{c[a+792>>2]=40;break};case 10:{c[a+792>>2]=1;break};case 11:{c[a+792>>2]=8;break};case 2:{c[a+792>>2]=24;break};case 28:{c[a+792>>2]=32;break};default:{}}f=ICb()|0;c[a+804>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}c[f+88>>2]=1;c[f+84>>2]=1;Z3(d+4|0,a);f=c[a+216>>2]|0;if((f|0)<0){h=0}else{h=(f|0)>5?5:f}f=d+1260|0;c[f>>2]=h;if((c[e>>2]|0)==10){c[f>>2]=0}f=c[d+5416>>2]|0;if((f|0)==0){g=0;i=b;return g|0}e=d+5420|0;if((c[e>>2]|0)==0){c[e>>2]=(f*1e4|0|0)/254|0;g=0;i=b;return g|0}else{yDb(a,16,1966168,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-22;i=b;return g|0}return 0}function xSa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0;h=i;i=i+64|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;r=c[b+60>>2]|0;s=r;t=c[b+88>>2]&262144;u=(t|0)!=0;switch(c[b+140>>2]|0){case 8:{v=8;w=0;break};case 28:{v=8;w=6;break};case 10:{v=1;w=0;break};case 2:{v=8;w=2;break};case 31:{v=16;w=0;break};case 11:{v=8;w=3;break};case 66:{v=8;w=4;break};case 41:{v=16;w=2;break};case 291:{v=16;w=6;break};default:{y=-1;i=h;return y|0}}z=ba(Umb(w)|0,v)|0;A=b+120|0;B=(ba(c[A>>2]|0,z)|0)+7>>3;C=r+1264|0;D=C;c[r+1296>>2]=36;c[r+1300>>2]=20;c[r+1304>>2]=0;E=c[b+84>>2]|0;do{if((E|0)==-1){G=-1}else{if((E|0)<0){G=0;break}G=(E|0)>9?9:E}}while(0);if((xc(D|0,G|0,8,15,8,0,2183488,56)|0)!=0){y=-1;i=h;return y|0}G=ob(D|0,B|0)|0;E=b+124|0;H=c[E>>2]|0;I=(((G+4095|0)/4096|0)*12|0)+G|0;G=gHb(I,(I|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;H=YGb(G,F,16384,0)|0;G=F;I=0;if((G|0)>(I|0)|(G|0)==(I|0)&H>>>0>2147483647>>>0){y=-12;i=h;return y|0}I=r0a(b,e,H,G)|0;if((I|0)<0){y=I;i=h;return y|0}I=e+24|0;G=c[I>>2]|0;H=r+1248|0;c[H>>2]=G;J=r+1252|0;c[J>>2]=G;G=e+28|0;K=r+1256|0;c[K>>2]=(c[I>>2]|0)+(c[G>>2]|0);I=WDb(B+32<<((c[r+1260>>2]|0)==5))|0;a:do{if((I|0)==0){L=0;M=0;N=-1}else{O=I+15|0;if(u){P=B+1|0;Q=WDb(P)|0;if((Q|0)==0){L=0;M=0;N=-1;break}R=WDb(P)|0;if((R|0)==0){L=0;M=Q;N=-1;break}else{S=R;T=Q}}else{S=0;T=0}Q=c[H>>2]|0;R=Q|0;x=1196314761;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;R=Q+4|0;x=169478669;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;R=(c[H>>2]|0)+8|0;c[H>>2]=R;Q=r+1320|0;P=Q;x=fe(c[A>>2]|0)|0;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;U=r+1324|0;x=fe(c[E>>2]|0)|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;V=r+1328|0;a[V]=v;a[r+1329|0]=w;a[r+1330|0]=0;a[r+1331|0]=0;a[r+1332|0]=t>>>18;W=R;x=218103808;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;W=Hc(0,0,0)|0;c[o>>2]=1380206665;R=Hc(W|0,o|0,4)|0;W=c[H>>2]|0;x=1380206665;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;W=Hc(R|0,Q|0,13)|0;UGb(c[H>>2]|0,Q|0,13)|0;R=(c[H>>2]|0)+13|0;c[H>>2]=R;X=R;x=fe(W|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;X=c[r+5420>>2]|0;if((X|0)==0){x=fe(c[b+224>>2]|0)|0;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;Y=0;Z=c[b+228>>2]|0}else{x=fe(X|0)|0;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;Y=1;Z=X}x=fe(Z|0)|0;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;a[V]=Y;V=c[H>>2]|0;x=150994944;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;V=Hc(0,0,0)|0;c[n>>2]=1935231088;U=Hc(V|0,n|0,4)|0;V=c[H>>2]|0;x=1935231088;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;V=Hc(U|0,Q|0,9)|0;UGb(c[H>>2]|0,Q|0,9)|0;U=(c[H>>2]|0)+9|0;c[H>>2]=U;X=U;x=fe(V|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;do{if((w|0)==3){X=c[f+4>>2]|0;V=r+2088|0;U=Q;P=0;W=0;R=V;while(1){_=c[X+(W<<2)>>2]|0;$=_>>>24;aa=($|0)==255?P:1;a[R]=$;a[U+2|0]=_;a[U+1|0]=_>>>8;a[U]=_>>>16;_=W+1|0;if((_|0)<256){U=U+3|0;P=aa;W=_;R=R+1|0}else{break}}R=c[H>>2]|0;x=196608;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;R=Hc(0,0,0)|0;c[m>>2]=1163152464;W=Hc(R|0,m|0,4)|0;R=c[H>>2]|0;x=1163152464;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;R=Hc(W|0,Q|0,768)|0;UGb(c[H>>2]|0,Q|0,768)|0;W=(c[H>>2]|0)+768|0;c[H>>2]=W;P=W;x=fe(R|0)|0;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;if((aa|0)==0){break}P=c[H>>2]|0;x=65536;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;P=Hc(0,0,0)|0;c[l>>2]=1397641844;R=Hc(P|0,l|0,4)|0;P=c[H>>2]|0;x=1397641844;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;P=Hc(R|0,V|0,256)|0;UGb(c[H>>2]|0,V|0,256)|0;R=(c[H>>2]|0)+256|0;c[H>>2]=R;W=R;x=fe(P|0)|0;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;c[H>>2]=(c[H>>2]|0)+4}}while(0);W=r+1280|0;c[W>>2]=4096;P=r+1276|0;c[P>>2]=Q;b:do{if(u){R=f|0;U=f+32|0;X=(z|0)==1;_=z>>3;$=r+1268|0;ca=C;da=k;ea=T;fa=S;ga=0;while(1){ha=Vmb(ga,z,c[A>>2]|0)|0;do{if((ha|0)>0){if((c[E>>2]|0)<=0){ia=fa;ja=ea;break}ka=d[1155552+ga|0]|0;la=563664+(ga<<2)|0;ma=ha+1|0;na=(ma|0)==0;oa=0;pa=ea;qa=fa;ra=0;while(1){c:do{if((ka&128>>>((ra&7)>>>0)|0)==0){sa=qa;ta=pa;ua=oa}else{va=c[R>>2]|0;wa=ba(c[U>>2]|0,ra)|0;xa=c[A>>2]|0;ya=c[la>>2]|0;do{if(X){TGb(qa|0,0,ha|0)|0;if((xa|0)>0){za=0;Aa=0}else{break}while(1){Ba=Aa&7;if((128>>>(Ba>>>0)&ya|0)==0){Ca=za}else{Da=qa+(za>>3)|0;a[Da]=((d[va+((Aa>>3)+wa)|0]|0)>>>((Ba^7)>>>0)&1)<<(za&7^7)|(d[Da]|0);Ca=za+1|0}Da=Aa+1|0;if((Da|0)<(xa|0)){za=Ca;Aa=Da}else{break}}}else{if((xa|0)<=0){break}Da=0;Ba=qa;Ea=va+wa|0;while(1){if((128>>>((Da&7)>>>0)&ya|0)==0){Fa=Ba}else{UGb(Ba|0,Ea|0,_)|0;Fa=Ba+_|0}Ga=Da+1|0;if((Ga|0)<(xa|0)){Da=Ga;Ba=Fa;Ea=Ea+_|0}else{break}}}}while(0);xa=zSa(s,O,qa,oa,ha,_)|0;c[$>>2]=ma;c[ca>>2]=xa;if(na){sa=pa;ta=qa;ua=qa;break}while(1){if((Yd(D|0,0)|0)!=0){sa=pa;ta=qa;ua=qa;break c}if((c[W>>2]|0)==0){xa=c[H>>2]|0;if(((c[K>>2]|0)-xa|0)>4196){ya=xa;x=1048576;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;ya=Hc(0,0,0)|0;c[k>>2]=1413563465;xa=Hc(ya|0,da|0,4)|0;ya=c[H>>2]|0;x=1413563465;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;ya=Hc(xa|0,Q|0,4096)|0;UGb(c[H>>2]|0,Q|0,4096)|0;xa=(c[H>>2]|0)+4096|0;c[H>>2]=xa;wa=xa;x=fe(ya|0)|0;a[wa]=x;x=x>>8;a[wa+1|0]=x;x=x>>8;a[wa+2|0]=x;x=x>>8;a[wa+3|0]=x;c[H>>2]=(c[H>>2]|0)+4}c[W>>2]=4096;c[P>>2]=Q}if((c[$>>2]|0)==0){sa=pa;ta=qa;ua=qa;break}}}}while(0);wa=ra+1|0;if((wa|0)<(c[E>>2]|0)){oa=ua;pa=ta;qa=sa;ra=wa}else{ia=sa;ja=ta;break}}}else{ia=fa;ja=ea}}while(0);ha=ga+1|0;if((ha|0)<7){ea=ja;fa=ia;ga=ha}else{Ha=ia;Ia=ja;break}}}else{if((c[E>>2]|0)<=0){Ha=S;Ia=T;break}ga=f|0;fa=f+32|0;ea=z>>3;$=B+1|0;da=r+1268|0;ca=C;_=j;if(($|0)==0){X=0;U=0;while(1){R=(c[ga>>2]|0)+(ba(c[fa>>2]|0,U)|0)|0;V=zSa(s,O,R,X,B,ea)|0;c[da>>2]=0;c[ca>>2]=V;V=U+1|0;if((V|0)<(c[E>>2]|0)){X=R;U=V}else{Ha=S;Ia=T;break b}}}else{Ja=0;Ka=0}while(1){U=(c[ga>>2]|0)+(ba(c[fa>>2]|0,Ka)|0)|0;X=zSa(s,O,U,Ja,B,ea)|0;c[da>>2]=$;c[ca>>2]=X;do{if((Yd(D|0,0)|0)!=0){break}if((c[W>>2]|0)==0){X=c[H>>2]|0;if(((c[K>>2]|0)-X|0)>4196){V=X;x=1048576;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;V=Hc(0,0,0)|0;c[j>>2]=1413563465;X=Hc(V|0,_|0,4)|0;V=c[H>>2]|0;x=1413563465;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;V=Hc(X|0,Q|0,4096)|0;UGb(c[H>>2]|0,Q|0,4096)|0;X=(c[H>>2]|0)+4096|0;c[H>>2]=X;R=X;x=fe(V|0)|0;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[H>>2]=(c[H>>2]|0)+4}c[W>>2]=4096;c[P>>2]=Q}}while((c[da>>2]|0)!=0);R=Ka+1|0;if((R|0)<(c[E>>2]|0)){Ja=U;Ka=R}else{Ha=S;Ia=T;break}}}}while(0);O=p;do{da=Yd(D|0,4)|0;_=(da|0)==1;if(!(da>>>0<2>>>0)){L=Ha;M=Ia;N=-1;break a}da=4096-(c[W>>2]|0)|0;do{if((da|0)>0){ca=c[H>>2]|0;if(((c[K>>2]|0)-ca|0)<=(da+100|0)){break}$=ca;x=fe(da|0)|0;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;$=Hc(0,0,0)|0;c[p>>2]=1413563465;ca=Hc($|0,O|0,4)|0;$=c[H>>2]|0;x=1413563465;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;$=Hc(ca|0,Q|0,da|0)|0;UGb(c[H>>2]|0,Q|0,da)|0;ca=(c[H>>2]|0)+da|0;c[H>>2]=ca;ea=ca;x=fe($|0)|0;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;c[H>>2]=(c[H>>2]|0)+4}}while(0);c[W>>2]=4096;c[P>>2]=Q}while(!_);Q=c[H>>2]|0;x=0;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;Q=Hc(0,0,0)|0;c[q>>2]=1145980233;P=Hc(Q|0,q|0,4)|0;Q=c[H>>2]|0;x=1145980233;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=(c[H>>2]|0)+4|0;c[H>>2]=Q;W=Q;x=fe(P|0)|0;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;c[G>>2]=(c[H>>2]|0)-(c[J>>2]|0);W=e+36|0;c[W>>2]=c[W>>2]|1;c[g>>2]=1;L=Ha;M=Ia;N=0}}while(0);ZDb(I);ZDb(M);ZDb(L);Zc(D|0)|0;y=N;i=h;return y|0}function ySa(a){a=a|0;JCb(a+804|0);return 0}function zSa(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;k=c[b+1260>>2]|0;l=(k|0)==0;if(!((h|0)!=0|l)){yDb(0,0,2106520,(m=i,i=i+24|0,c[m>>2]=2049224,c[m+8>>2]=2003680,c[m+16>>2]=165,m)|0);i=m;Cd();return 0}m=(f|0)!=0|l?k:1;if((m|0)!=5){ASa(b+4|0,d+1|0,m,e,f,g,h);a[d]=m;n=d;i=j;return n|0}m=d+(g+16)|0;k=b+4|0;ASa(k,d+1|0,0,e,f,g,h);a[d]=0;if((g|0)<0){b=d+(g+17)|0;ASa(k,b,1,e,f,g,h);a[m]=1;ASa(k,b,2,e,f,g,h);a[m]=2;ASa(k,b,3,e,f,g,h);a[m]=3;ASa(k,b,4,e,f,g,h);a[m]=4;n=d;i=j;return n|0}else{o=1;p=0;q=0}while(1){b=q<<24>>24;r=(q<<24>>24>-1?b:-b|0)+p|0;if((o|0)>(g|0)){break}b=a[d+o|0]|0;o=o+1|0;p=r;q=b}q=(r|0)!=2147483647;p=q?m:d;o=q?d:m;ASa(k,p+1|0,1,e,f,g,h);a[p]=1;m=1;d=0;q=1;while(1){b=q<<24>>24;s=(q<<24>>24>-1?b:-b|0)+d|0;if((m|0)>(g|0)){break}b=a[p+m|0]|0;m=m+1|0;d=s;q=b}q=(s|0)<(r|0);d=q?s:r;r=q?o:p;s=q?p:o;ASa(k,r+1|0,2,e,f,g,h);a[r]=2;o=1;p=0;q=2;while(1){m=q<<24>>24;t=(q<<24>>24>-1?m:-m|0)+p|0;if((o|0)>(g|0)){break}m=a[r+o|0]|0;o=o+1|0;p=t;q=m}q=(t|0)<(d|0);p=q?t:d;d=q?s:r;t=q?r:s;ASa(k,d+1|0,3,e,f,g,h);a[d]=3;s=1;r=0;q=3;while(1){o=q<<24>>24;u=(q<<24>>24>-1?o:-o|0)+r|0;if((s|0)>(g|0)){break}o=a[d+s|0]|0;s=s+1|0;r=u;q=o}q=(u|0)<(p|0);r=q?u:p;p=q?t:d;u=q?d:t;ASa(k,p+1|0,4,e,f,g,h);a[p]=4;h=1;f=0;e=4;while(1){k=e<<24>>24;v=(e<<24>>24>-1?k:-k|0)+f|0;if((h|0)>(g|0)){break}k=a[p+h|0]|0;h=h+1|0;f=v;e=k}n=(v|0)<(r|0)?p:u;i=j;return n|0}function ASa(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;switch(f|0){case 1:{f=g+j|0;UGb(e|0,g|0,j)|0;k=e+j|0;l=i-j|0;m=32-j|0;n=(m|0)>(l|0)?l:m;if((n|0)>0){m=j-1|0;o=m-i|0;p=j-33|0;q=(o|0)>(p|0)?o:p;p=~q;o=f;r=g;s=0;t=k;while(1){a[t]=(a[o]|0)-(a[r]|0);u=s+1|0;if((u|0)<(n|0)){o=o+1|0;r=r+1|0;s=u;t=t+1|0}else{break}}t=m-q|0;v=g+t|0;w=g+p|0;x=e+t|0}else{v=f;w=g;x=k}cf[c[b+1076>>2]&1023](x,v,w,l-n|0);return};case 3:{if((j|0)>0){n=0;while(1){a[e+n|0]=(a[g+n|0]|0)-((d[h+n|0]|0)>>>1);l=n+1|0;if((l|0)<(j|0)){n=l}else{y=j;break}}}else{y=0}if((y|0)<(i|0)){z=y}else{return}do{a[e+z|0]=(d[g+z|0]|0)-(((d[h+z|0]|0)+(d[g+(z-j)|0]|0)|0)>>>1);z=z+1|0;}while((z|0)<(i|0));return};case 0:{UGb(e|0,g|0,i)|0;return};case 4:{if((j|0)>0){z=0;while(1){a[e+z|0]=(a[g+z|0]|0)-(a[h+z|0]|0);y=z+1|0;if((y|0)<(j|0)){z=y}else{A=j;break}}}else{A=0}z=i-A|0;if((z|0)>0){B=0}else{return}do{y=B-j+A|0;n=a[g+y|0]|0;l=B+A|0;w=a[h+l|0]|0;v=a[h+y|0]|0;y=v&255;x=(w&255)-y|0;k=(n&255)-y|0;y=(x|0)>-1?x:-x|0;f=(k|0)>-1?k:-k|0;t=x+k|0;k=(t|0)>-1?t:-t|0;if((y|0)>(f|0)|(y|0)>(k|0)){C=(f|0)>(k|0)?v:w}else{C=n}a[e+l|0]=(a[g+l|0]|0)-C;B=B+1|0;}while((B|0)<(z|0));return};case 2:{cf[c[b+1076>>2]&1023](e,g,h,i);return};default:{return}}}function BSa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=c[e+60>>2]|0;m=h;c[m>>2]=k;n=h+4|0;c[n>>2]=k;o=h+8|0;c[o>>2]=k+l;l=Wmb(e,h)|0;if((l|0)<0){p=l;i=j;return p|0}l=_$a(e,f,0)|0;if((l|0)<0){p=l;i=j;return p|0}c[f+88>>2]=1;c[f+84>>2]=1;l=h+12|0;k=c[l>>2]|0;q=k>>>0>65535>>>0;r=q?k>>>16:k;k=q?16:0;if((r&65280|0)==0){s=k;t=r}else{s=k|8;t=r>>>8}c[e+796>>2]=s+1+(d[1191992+t|0]|0);a:do{switch(c[e+140>>2]|0){case 0:case 70:case 72:{t=c[f>>2]|0;s=c[f+32>>2]|0;r=c[l>>2]|0;k=c[e+120>>2]<<((r|0)>255);q=c[m>>2]|0;u=e+124|0;v=c[u>>2]|0;if((q+((ba(v*3|0,k)|0)/2|0)|0)>>>0>(c[o>>2]|0)>>>0){p=-1094995529;i=j;return p|0}b:do{if((v|0)>0){w=(k|0)/2|0;if((k|0)>1){y=t;z=1;A=q;B=v;C=r}else{D=t;E=1;F=q;G=v;H=r;while(1){if((H|0)<256){UGb(D|0,F|0,k)|0;I=c[m>>2]|0;J=c[u>>2]|0}else{I=F;J=G}K=I+k|0;c[m>>2]=K;if((E|0)>=(J|0)){L=J;M=K;break b}D=D+s|0;E=E+1|0;F=K;G=J;H=c[l>>2]|0}}while(1){if((C|0)<256){UGb(y|0,A|0,k)|0;N=c[m>>2]|0;O=c[u>>2]|0}else{H=y;G=0;while(1){F=A+(G<<1)|0;b[H+(G<<1)>>1]=de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0;F=G+1|0;if((F|0)<(w|0)){G=F}else{N=A;O=B;break}}}G=N+k|0;c[m>>2]=G;if((z|0)>=(O|0)){L=O;M=G;break b}y=y+s|0;z=z+1|0;A=G;B=O;C=c[l>>2]|0}}else{L=v;M=q}}while(0);q=k>>1;v=L>>1;if((v|0)<=0){P=M;break a}s=f+36|0;u=f+40|0;r=(q|0)/2|0;t=(q|0)>1;w=1;G=c[f+4>>2]|0;H=c[f+8>>2]|0;F=M;while(1){E=c[l>>2]|0;do{if((E|0)<256){UGb(G|0,F|0,q)|0;Q=c[m>>2]|0;R=c[l>>2]|0}else{if(!t){Q=F;R=E;break}D=G;K=0;while(1){S=F+(K<<1)|0;b[D+(K<<1)>>1]=de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0;S=K+1|0;if((S|0)<(r|0)){K=S}else{Q=F;R=E;break}}}}while(0);E=Q+q|0;c[m>>2]=E;do{if((R|0)<256){UGb(H|0,E|0,q)|0;T=c[m>>2]|0}else{if(!t){T=E;break}K=H;D=0;while(1){S=Q+((D<<1)+q)|0;b[K+(D<<1)>>1]=de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0;S=D+1|0;if((S|0)<(r|0)){D=S}else{T=E;break}}}}while(0);E=T+q|0;c[m>>2]=E;if((w|0)>=(v|0)){P=E;break a}w=w+1|0;G=G+(c[s>>2]|0)|0;H=H+(c[u>>2]|0)|0;F=E}break};case 292:{F=c[e+120>>2]|0;U=F<<3;V=16;W=4;X=0;Y=(c[l>>2]|0)<65535?2:0;Z=F;_=14;break};case 66:{F=c[e+120>>2]|0;U=F<<1;V=8;W=2;X=0;Y=0;Z=F;_=14;break};case 2:{F=c[e+120>>2]|0;U=F*3|0;V=8;W=3;X=0;Y=(c[l>>2]|0)<255|0;Z=F;_=14;break};case 54:{F=c[l>>2]|0;u=(((F|0)/2|0)+2147450880|0)/(F|0)|0;F=c[e+120>>2]|0;H=F<<1;s=c[f+32>>2]|0;G=c[m>>2]|0;w=c[e+124>>2]|0;v=G+((ba(F*6|0,w)|0)/2|0)|0;if(v>>>0>(c[o>>2]|0)>>>0){p=-1094995529;i=j;return p|0}if((w|0)>0){v=(F|0)==0;q=(ba(F,(w|0)>1?w:1)|0)<<1;r=c[f>>2]|0;t=0;k=G;while(1){if(!v){E=r;D=0;do{b[E+(D<<1)>>1]=((ba((de(b[k+(D<<1)>>1]|0)|0)&65535,u)|0)+16384|0)>>>15;D=D+1|0;}while(D>>>0<F>>>0)}D=t+1|0;if((D|0)<(w|0)){r=r+s|0;t=D;k=k+H|0}else{break}}k=G+q|0;c[m>>2]=k;$=k}else{$=G}k=w>>1;if((k|0)<=0){P=$;break a}t=(F|0)/2|0;s=(F+1|0)>>>0>2>>>0;r=(c[f+36>>2]|0)/2|0;v=(c[f+40>>2]|0)/2|0;D=(ba(F,k)|0)<<1;E=0;K=c[f+4>>2]|0;S=c[f+8>>2]|0;aa=$;while(1){do{if(s){ca=0;do{b[K+(ca<<1)>>1]=((ba((de(b[aa+(ca<<1)>>1]|0)|0)&65535,u)|0)+16384|0)>>>15;ca=ca+1|0;}while(ca>>>0<t>>>0);ca=aa+F|0;if(s){da=0}else{break}do{b[S+(da<<1)>>1]=((ba((de(b[ca+(da<<1)>>1]|0)|0)&65535,u)|0)+16384|0)>>>15;da=da+1|0;}while(da>>>0<t>>>0)}}while(0);ca=E+1|0;if((ca|0)<(k|0)){E=ca;K=K+(r<<1)|0;S=S+(v<<1)|0;aa=aa+H|0}else{break}}H=$+D|0;c[m>>2]=H;P=H;break};case 28:{H=c[e+120>>2]|0;U=H<<2;V=8;W=4;X=0;Y=0;Z=H;_=14;break};case 9:case 10:{H=c[e+120>>2]|0;U=H+7>>3;V=1;W=1;X=1;Y=0;Z=H;_=14;break};case 8:{H=c[e+120>>2]|0;U=H;V=8;W=1;X=0;Y=(c[l>>2]|0)<255|0;Z=H;_=14;break};case 42:{H=c[e+120>>2]|0;U=H*6|0;V=16;W=3;X=0;Y=(c[l>>2]|0)<65535?2:0;Z=H;_=14;break};case 32:{H=c[e+120>>2]|0;U=H<<1;V=16;W=1;X=0;Y=(c[l>>2]|0)<65535?2:0;Z=H;_=14;break};default:{p=-22;i=j;return p|0}}}while(0);c:do{if((_|0)==14){$=c[f>>2]|0;da=c[f+32>>2]|0;T=c[m>>2]|0;Q=e+124|0;R=c[Q>>2]|0;M=T+(ba(R,U)|0)|0;if(M>>>0>(c[o>>2]|0)>>>0){p=-1094995529;i=j;return p|0}M=h+16|0;L=c[M>>2]|0;do{if((L|0)>=4){if((X|0)!=0&(L|0)==7){break}if((R|0)<=0){P=T;break c}C=(U|0)/2|0;O=(U|0)>1;B=(U|0)==0;A=(U+1|0)>>>0>2>>>0;z=$;y=0;N=T;while(1){d:do{if((Y|0)==0){if((c[l>>2]|0)<256){UGb(z|0,N|0,U)|0;break}if(!O){break}J=z;I=0;do{H=N+(I<<1)|0;b[J+(I<<1)>>1]=de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0;I=I+1|0;}while((I|0)<(C|0))}else if((Y|0)==2){I=c[l>>2]|0;J=(((I|0)/2|0)+2147450880|0)/(I|0)|0;if(!A){break}I=N;H=z;aa=0;do{b[H+(aa<<1)>>1]=((ba((de(b[I+(aa<<1)>>1]|0)|0)&65535,J)|0)+16384|0)>>>15;aa=aa+1|0;}while(aa>>>0<C>>>0)}else if((Y|0)==1){aa=c[l>>2]|0;J=(((aa|0)/2|0)+32640|0)/(aa|0)|0;if(B){break}else{ea=0;fa=N}while(1){a[z+ea|0]=((ba(d[fa+ea|0]|0,J)|0)+64|0)>>>7;aa=ea+1|0;if(!(aa>>>0<U>>>0)){break d}ea=aa;fa=c[m>>2]|0}}}while(0);J=(c[m>>2]|0)+U|0;c[m>>2]=J;aa=y+1|0;if((aa|0)<(c[Q>>2]|0)){z=z+da|0;y=aa;N=J}else{P=J;break c}}}}while(0);if((R|0)<=0){P=T;break}L=(da|0)<0;D=e+120|0;N=(X|0)==0;y=(V|0)==16;z=(1<<V)-1|0;B=32-V|0;C=$;A=1;O=Z;e:while(1){J=L?0:C;aa=0;f:do{if((ba(O,W)|0)>0){I=C;if(N){ga=J;ha=32;ia=0;ja=O}else{H=J;v=32;S=0;r=O;while(1){K=c[m>>2]|0;E=c[o>>2]|0;g:do{if((c[M>>2]|0)<4&K>>>0<E>>>0){k=K;while(1){if(!(((a[k]|0)-48&255)>>>0>9>>>0)){ka=k;break g}t=k+1|0;c[m>>2]=t;if(t>>>0<E>>>0){k=t}else{ka=t;break}}}else{ka=K}}while(0);if(!(ka>>>0<E>>>0)){p=-1094995529;_=111;break e}c[m>>2]=ka+1;K=c[l>>2]|0;k=((K>>1)+(z&-(a[ka]&1))|0)/(K|0)|0;if(y){b[I+(S<<1)>>1]=k;la=v;ma=H;na=r}else{K=aa;if((v|0)>(V|0)){oa=v-V|0;pa=K<<V|k;qa=H;ra=r}else{t=H;x=fe(K<<v|k>>>((V-v|0)>>>0)|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;oa=B+v|0;pa=k;qa=H+4|0;ra=c[D>>2]|0}aa=pa;la=oa;ma=qa;na=ra}k=S+1|0;if((k|0)<(ba(na,W)|0)){H=ma;v=la;S=k;r=na}else{sa=ma;ta=la;break f}}}while(1){r=c[m>>2]|0;S=c[o>>2]|0;h:do{if((c[M>>2]|0)<4&r>>>0<S>>>0){v=r;while(1){if(!(((a[v]|0)-48&255)>>>0>9>>>0)){ua=v;break h}H=v+1|0;c[m>>2]=H;if(H>>>0<S>>>0){v=H}else{ua=H;break}}}else{ua=r}}while(0);if(ua>>>0<S>>>0){va=0;wa=0;xa=ua}else{p=-1094995529;_=111;break e}while(1){ya=(va*10|0)+wa|0;r=xa+1|0;c[m>>2]=r;E=(d[xa]|0)-48|0;if(E>>>0<10>>>0){va=ya;wa=E;xa=r}else{break}}S=ba(ya,z)|0;r=c[l>>2]|0;E=((r>>1)+S|0)/(r|0)|0;if(y){b[I+(ia<<1)>>1]=E;za=ha;Aa=ga;Ba=ja}else{r=aa;if((ha|0)>(V|0)){Ca=ha-V|0;Da=r<<V|E;Ea=ga;Fa=ja}else{S=ga;x=fe(r<<ha|E>>>((V-ha|0)>>>0)|0)|0;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;Ca=B+ha|0;Da=E;Ea=ga+4|0;Fa=c[D>>2]|0}aa=Da;za=Ca;Aa=Ea;Ba=Fa}E=ia+1|0;if((E|0)<(ba(Ba,W)|0)){ga=Aa;ha=za;ia=E;ja=Ba}else{sa=Aa;ta=za;break}}}else{sa=J;ta=32}}while(0);if(!y){if((ta|0)<32){J=aa<<ta;aa=J;I=J>>>24&255;J=ta;E=sa;while(1){a[E]=I;S=aa;aa=S<<8;r=J+8|0;if((r|0)<32){I=S>>>16&255;J=r;E=E+1|0}else{break}}}aa=0}if((A|0)>=(c[Q>>2]|0)){_=108;break}C=C+da|0;A=A+1|0;O=c[D>>2]|0}if((_|0)==108){P=c[m>>2]|0;break}else if((_|0)==111){i=j;return p|0}}}while(0);c[g>>2]=1;p=P-(c[n>>2]|0)|0;i=j;return p|0}function CSa(a){a=a|0;var b=0,d=0;b=ICb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+88>>2]=1;c[b+84>>2]=1;d=0;return d|0}function DSa(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;h=a+140|0;j=a+120|0;k=a+124|0;l=(QZ(c[h>>2]|0,c[j>>2]|0,c[k>>2]|0)|0)+200|0;m=r0a(a,b,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){n=m;i=g;return n|0}m=c[b+24>>2]|0;l=b+28|0;o=c[l>>2]|0;p=c[k>>2]|0;a:do{switch(c[h>>2]|0){case 0:{k=c[j>>2]|0;do{if((k&1|0)==0){if((p&1|0)!=0){break}q=k;r=53;s=(p*3|0|0)/2|0;t=k;break a}}while(0);yDb(a,16,2330696,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;n=-22;i=g;return n|0};case 41:{k=c[j>>2]|0;q=k*6|0;r=54;s=p;t=k;break};case 31:{k=c[j>>2]|0;q=k<<1;r=53;s=p;t=k;break};case 2:{k=c[j>>2]|0;q=k*3|0;r=54;s=p;t=k;break};case 8:{k=c[j>>2]|0;q=k;r=53;s=p;t=k;break};case 55:{k=c[j>>2]|0;q=k<<1;r=53;s=(p*3|0|0)/2|0;t=k;break};case 9:{k=c[j>>2]|0;q=k+7>>3;r=52;s=p;t=k;break};default:{n=-1;i=g;return n|0}}}while(0);j=m;Lb(m|0,o|0,2306512,(u=i,i=i+24|0,c[u>>2]=r,c[u+8>>2]=t,c[u+16>>2]=s,u)|0)|0;i=u;s=SGb(m|0)|0;t=m+s|0;r=c[h>>2]|0;if((r|0)==9){v=t}else{a=(1<<((e[(bFb(r)|0)+8>>1]|0)>>>11&15)+1)-1|0;Lb(t|0,o-s|0,2288344,(u=i,i=i+8|0,c[u>>2]=a,u)|0)|0;i=u;v=m+((SGb(t|0)|0)+s)|0}s=c[d+32>>2]|0;if((p|0)>0){t=ba(q,p)|0;m=0;u=v;a=c[d>>2]|0;while(1){UGb(u|0,a|0,q)|0;o=m+1|0;if((o|0)<(p|0)){m=o;u=u+q|0;a=a+s|0}else{break}}w=v+t|0}else{w=v}v=c[h>>2]|0;do{if((v|0)==0|(v|0)==55){h=p>>1;t=q>>1;if((h|0)<=0){x=w;break}s=t<<1;a=d+36|0;u=d+40|0;m=(ba(h,t)|0)<<1;o=0;r=w;k=c[d+4>>2]|0;y=c[d+8>>2]|0;while(1){UGb(r|0,k|0,t)|0;UGb(r+t|0,y|0,t)|0;z=o+1|0;if((z|0)<(h|0)){o=z;r=r+s|0;k=k+(c[a>>2]|0)|0;y=y+(c[u>>2]|0)|0}else{break}}x=w+m|0}else{x=w}}while(0);c[l>>2]=x-j;j=b+36|0;c[j>>2]=c[j>>2]|1;c[f>>2]=1;n=0;i=g;return n|0}function ESa(a){a=a|0;JCb(a+804|0);return 0}function FSa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+64|0;f=e|0;g=c[b+60>>2]|0;c[b+796>>2]=10;Z3(g,b);h=g+1244|0;SSa(h,b);y2(f|0,c[h>>2]|0);h=0;while(1){a[g+(h+1468)|0]=a[f+(d[1154480+h|0]|0)|0]|0;b=h+1|0;if((b|0)<64){h=b}else{j=0;break}}do{a[g+(j+1532)|0]=a[f+(d[1154768+j|0]|0)|0]|0;j=j+1|0;}while((j|0)<64);i=e;return 0}function GSa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;h=i;j=b+60|0;k=c[j>>2]|0;l=k;m=e;n=c[g+24>>2]|0;o=g+28|0;g=c[o>>2]|0;do{if((g|0)>=28){p=n+4|0;if((d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)!=1718641513){break}c[k+1316>>2]=m;c[e+88>>2]=1;c[e+84>>2]=1;p=k+1600|0;c[p>>2]=1;q=g-8|0;r=n+8|0;s=(de((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535;if((s|0)>(q|0)){yDb(b,16,2256736,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}r=n+10|0;v=de((d[r]|d[r+1|0]<<8)<<16>>16|0)|0;if((v&65535)>>>0>1>>>0){yDb(b,16,2242416,(t=i,i=i+8|0,c[t>>2]=v&65535,t)|0);i=t;u=-1163346256;i=h;return u|0}v=n+16|0;r=(de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535;v=n+18|0;w=(de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535;v=b+120|0;x=c[v>>2]|0;y=b+124|0;z=c[y>>2]|0;if(!((r|0)==(x|0)&(w|0)==(z|0))){yDb(b,16,2229960,(t=i,i=i+32|0,c[t>>2]=x,c[t+8>>2]=z,c[t+16>>2]=r,c[t+24>>2]=w,t)|0);i=t;u=-1163346256;i=h;return u|0}w=n+20|0;r=(d[w]|0)>>>2&3;z=k+1320|0;c[z>>2]=r;x=a[n+25|0]&15;A=k+1604|0;c[A>>2]=x;if(x>>>0>2>>>0){yDb(b,16,2218096,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;u=-1094995529;i=h;return u|0}if((c[b+944>>2]|0)==0){B=x}else{c[A>>2]=0;B=0}if((r|0)==0){c[k+1596>>2]=k+1468;C=B}else{c[k+1596>>2]=k+1532;c[e+296>>2]=1;c[e+300>>2]=(c[z>>2]|0)==1;C=c[A>>2]|0}A=(a[w]&-64)<<24>>24==-64;if((C|0)==0){c[b+140>>2]=A?78:74}else{c[b+140>>2]=A?102:100}A=d[n+27|0]|0;do{if((A&2|0)==0){TGb(k+1324|0,4,64)|0;D=n+28|0}else{if((g-28|0)<64){yDb(b,16,2208712,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}else{w=0;do{a[l+1324+w|0]=a[n+((d[l+1248+w|0]|0)+28)|0]|0;w=w+1|0;}while((w|0)<64);D=n+92|0;break}}}while(0);a:do{if((A&1|0)==0){TGb(k+1388|0,4,64)|0}else{if((n+g-D|0)>=64){w=0;while(1){a[l+1388+w|0]=a[D+(d[l+1248+w|0]|0)|0]|0;w=w+1|0;if((w|0)>=64){break a}}}yDb(b,16,2208712,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}}while(0);A=n+(s+8)|0;w=q-s|0;r=_$a(b,m,0)|0;if((r|0)<0){u=r;i=h;return u|0}r=a[A]|0;x=(r&255)>>>3;b:do{if((r&255)>>>0<64>>>0|(x|0)>(w|0)){E=34}else{F=b+828|0;G=w;H=A;I=x;c:while(1){J=c[j>>2]|0;K=H+1|0;L=fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0;if(L>>>0>G>>>0){E=36;break}K=a[H+7|0]|0;M=K&255;N=M>>>4;O=M&15;if(!((K&255)>>>0<64>>>0&(O|0)==0)){E=38;break}K=J+1460|0;c[K>>2]=(c[v>>2]|0)+15>>4;M=c[y>>2]|0;if((c[J+1320>>2]|0)==0){c[J+1464>>2]=M+15>>4}else{c[J+1464>>2]=M+31>>5}M=H+5|0;P=(d[M]|d[M+1|0]<<8)<<16>>16;M=(de(P|0)|0)&65535;Q=J+1456|0;R=J+1452|0;S=R;if((c[Q>>2]|0)==(M|0)){T=c[S>>2]|0;if((T|0)==0){E=44}else{U=T}}else{E=44}if((E|0)==44){E=0;$Db(R);R=cEb(M*24|0)|0;T=R;c[S>>2]=T;if((R|0)==0){V=-12;E=61;break}c[Q>>2]=M;U=T}if(P<<16>>16==0){V=-22;E=61;break}P=(M<<1)+I|0;if((P|0)>(G|0)){E=48;break}T=1<<N;Q=H+G|0;R=T;W=0;X=0;Y=H+P|0;P=0;Z=c[K>>2]|0;_=U;while(1){c[_+(P*24|0)>>2]=Y;$=H+((P<<1)+I)|0;aa=de((d[$]|d[$+1|0]<<8)<<16>>16|0)|0;$=Z-W|0;ba=R;while(1){if($>>>0<ba>>>0){ba=ba>>1}else{break}}$=aa&65535;ca=Y+$|0;c[_+(P*24|0)+4>>2]=W;c[_+(P*24|0)+8>>2]=X;c[_+(P*24|0)+12>>2]=ba;c[_+(P*24|0)+16>>2]=$;if((aa&65535)>>>0<6>>>0){E=53;break c}$=ba+W|0;da=c[K>>2]|0;ea=($|0)==(da|0);if(ca>>>0>Q>>>0){E=55;break c}fa=(ea&1)+X|0;ga=ea?0:$;$=P+1|0;if(($|0)>=(M|0)){break}R=ea?T:ba;W=ga;X=fa;Y=ca;P=$;Z=da;_=c[S>>2]|0}ha=c[J+1464>>2]|0;if(!((ga|0)==0&(fa|0)==(ha|0))){E=59;break}if((L|0)<0){V=L;E=61;break}S=c[j>>2]|0;_=S+1456|0;Pe[c[F>>2]&255](b,8,0,0,c[_>>2]|0)|0;Z=S+1452|0;S=c[_>>2]|0;_=0;while(1){if((_|0)>=(S|0)){break}ia=c[(c[Z>>2]|0)+(_*24|0)+20>>2]|0;if((ia|0)<0){E=66;break c}else{_=_+1|0}}_=H+L|0;Z=G-L|0;if(!((c[z>>2]|0)!=0&(Z|0)>0)){E=70;break}if((c[p>>2]|0)==0){E=70;break}c[p>>2]=0;S=a[_]|0;J=(S&255)>>>3;if((S&255)>>>0<64>>>0|(J|0)>(Z|0)){E=34;break b}else{G=Z;H=_;I=J}}if((E|0)==36){I=b;yDb(I,16,1893448,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==38){I=b;yDb(I,16,2351016,(t=i,i=i+16|0,c[t>>2]=1<<N,c[t+8>>2]=1<<O,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==48){I=b;yDb(I,16,2330664,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==53){I=b;yDb(I,16,2306480,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==55){I=b;yDb(I,16,2288304,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==59){I=b;yDb(I,16,2272064,(t=i,i=i+16|0,c[t>>2]=fa,c[t+8>>2]=ha,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==61){ja=V;ka=b;break}else if((E|0)==66){yDb(b,16,2003576,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=ia;i=h;return u|0}else if((E|0)==70){c[f>>2]=1;u=c[o>>2]|0;i=h;return u|0}}}while(0);if((E|0)==34){p=b;yDb(p,16,1913976,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=p}yDb(ka,16,2049128,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=ja;i=h;return u|0}}while(0);yDb(b,16,2106352,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}function HSa(a){a=a|0;$Db((c[a+60>>2]|0)+1452|0);return 0}function ISa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;h=i;i=i+4376|0;f=h|0;j=h+24|0;k=h+4120|0;l=h+4248|0;m=e+60|0;n=c[m>>2]|0;o=c[n+1452>>2]|0;p=o+(g*24|0)|0;q=c[p>>2]|0;r=c[n+1316>>2]|0;s=o+(g*24|0)+20|0;c[s>>2]=-1;t=a[q]|0;u=(t&255)>>>3;v=a[q+1|0]|0;w=v&255;do{if(v<<24>>24==0){x=1}else{y=w>>>0>224>>>0?224:w;if(!(y>>>0>128>>>0)){x=y;break}x=(y<<2)-384|0}}while(0);w=q+2|0;v=(de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535;w=q+4|0;y=(de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535;w=c[o+(g*24|0)+16>>2]|0;z=v+u|0;A=w-z-y|0;if((t&255)>>>0>63>>>0){t=q+6|0;B=(de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535;C=B;D=w-(y+v)-B|0;E=7}else{if((A|0)>=0){C=A;D=u;E=7}}do{if((E|0)==7){A=D-u|0;B=z+y|0;t=B+C|0;if(t>>>0>w>>>0){break}else{F=0}do{b[k+(F<<1)>>1]=ba(d[n+(F+1324)|0]|0,x)|0;b[l+(F<<1)>>1]=ba(d[n+(F+1388)|0]|0,x)|0;F=F+1|0;}while((F|0)<64);G=q+u|0;H=(c[n+1320>>2]|0)==0;I=c[r+32>>2]|0;if(H){J=c[r+36>>2]|0;K=J;L=I;M=J}else{J=c[r+36>>2]|0;K=J<<1;L=I<<1;M=J}J=c[e+140>>2]|0;if((J|0)==78|(J|0)==102){N=5;O=2}else{N=4;O=1}J=c[r>>2]|0;P=c[o+(g*24|0)+8>>2]<<4;Q=ba(P,L)|0;R=c[o+(g*24|0)+4>>2]|0;S=Q+(R<<5)|0;Q=J+S|0;T=c[r+4>>2]|0;U=(ba(P,K)|0)+(R<<N)|0;R=T+U|0;P=c[r+8>>2]|0;V=P+U|0;W=r+12|0;X=c[W>>2]|0;Y=X+S|0;do{if(H){Z=Y;_=V;$=R;aa=Q}else{if((c[n+1600>>2]|0)==(c[r+300>>2]|0)){Z=Y;_=V;$=R;aa=Q;break}Z=X+((c[r+44>>2]|0)+S)|0;_=P+((c[r+40>>2]|0)+U)|0;$=T+(M+U)|0;aa=J+(I+S)|0}}while(0);S=aa;I=k|0;J=j;U=j|0;T=o+(g*24|0)+12|0;P=c[T>>2]|0;X=P<<2;if((X|0)>0){Q=n+36|0;R=0;do{me[c[Q>>2]&511](j+(R<<6<<1)|0);R=R+1|0;}while((R|0)<(X|0))}R=(G|0)==0?0:v<<3;Q=R+8|0;V=G|0;Y=fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0;V=Y>>>0>65535>>>0;H=V?Y>>>16:Y;ca=V?16:0;if((H&65280|0)==0){da=ca;ea=H}else{da=ca|8;ea=H>>>8}H=(d[1191992+ea|0]|0)+da|0;ca=31-H|0;if((H|0)==31){H=ca+1|0;V=(Q>>>0>H>>>0?H:Q)+5|0;fa=Y<<H>>>27|ca<<5;ga=Q>>>0>V>>>0?V:Q}else{V=ca<<1;ca=V+6|0;fa=(Y>>>((26-V|0)>>>0))-32|0;ga=Q>>>0>ca>>>0?ca:Q}ca=(fa>>>1^-(fa&1))&65535;b[U>>1]=ca;if((X|0)>1){V=ga;Y=0;H=1;ha=5;ia=ca;ca=U;while(1){ja=ca+128|0;ka=q+((V>>>3)+u)|0;la=ka|0;ma=ka+4|0;ka=d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0;ma=fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0;la=$Gb(fe(ka|0)|0,ma|0,32-(V&7)|0)|0;ma=la;la=d[1407976+(ha>>>0>6>>>0?6:ha)|0]|0;ka=la&3;na=la>>>5;oa=la>>>2&7;la=ma>>>0>65535>>>0;pa=la?ma>>>16:ma;qa=la?16:0;if((pa&65280|0)==0){ra=qa;sa=pa}else{ra=qa|8;sa=pa>>>8}pa=31-ra-(d[1191992+sa|0]|0)|0;do{if(pa>>>0>ka>>>0){qa=(pa<<1)+(oa-ka)|0;la=qa+V|0;ta=(ka+1<<na)+(-1<<oa)+(ma>>>((32-qa|0)>>>0))|0;ua=Q>>>0>la>>>0?la:Q}else{la=pa+1|0;if((na|0)==0){qa=la+V|0;ta=pa;ua=Q>>>0>qa>>>0?qa:Q;break}else{qa=la+V|0;va=(Q>>>0>qa>>>0?qa:Q)+na|0;ta=(ma<<la>>>((32-na|0)>>>0))+(pa<<na)|0;ua=Q>>>0>va>>>0?va:Q;break}}}while(0);if((ta|0)==0){wa=0}else{wa=Y^-(ta&1)}na=(ia&65535)-wa+(wa^(ta+1|0)>>>1)&65535;b[ja>>1]=na;pa=H+1|0;if((pa|0)<(X|0)){V=ua;Y=wa;H=pa;ha=ta;ia=na;ca=ja}else{xa=ua;break}}}else{xa=ga}ca=c[m>>2]|0;ia=X>>>0>65535>>>0;ha=ia?P>>>14&65535:X;H=ia?16:0;if((ha&65280|0)==0){ya=H;za=ha}else{ya=H|8;za=ha>>>8}ha=(d[1191992+za|0]|0)+ya|0;H=q+((xa>>>3)+u)|0;ia=H|0;Y=H+4|0;H=64<<ha;V=X-1|0;a:do{if((R|0)!=(xa|0)){G=d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0;na=fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0;pa=$Gb(fe(G|0)|0,na|0,32-(xa&7)|0)|0;na=ca+1596|0;G=pa;pa=2;ma=4;oa=V;ka=xa;while(1){va=R-ka|0;if((va|0)<32){if((G>>>((32-va|0)>>>0)|0)==0){break a}}va=q+((ka>>>3)+u)|0;la=va|0;qa=va+4|0;va=d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0;qa=fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0;la=$Gb(fe(va|0)|0,qa|0,32-(ka&7)|0)|0;qa=la;la=d[545576+(ma>>>0>15>>>0?15:ma)|0]|0;va=la&3;Aa=la>>>5;Ba=la>>>2&7;la=qa>>>0>65535>>>0;Ca=la?qa>>>16:qa;Da=la?16:0;if((Ca&65280|0)==0){Ea=Da;Fa=Ca}else{Ea=Da|8;Fa=Ca>>>8}Ca=31-Ea-(d[1191992+Fa|0]|0)|0;do{if(Ca>>>0>va>>>0){Da=(Ca<<1)+(Ba-va)|0;la=Da+ka|0;Ga=(va+1<<Aa)+(-1<<Ba)+(qa>>>((32-Da|0)>>>0))|0;Ha=Q>>>0>la>>>0?la:Q}else{la=Ca+1|0;if((Aa|0)==0){Da=la+ka|0;Ga=Ca;Ha=Q>>>0>Da>>>0?Da:Q;break}else{Da=la+ka|0;Ia=(Q>>>0>Da>>>0?Da:Q)+Aa|0;Ga=(qa<<la>>>((32-Aa|0)>>>0))+(Ca<<Aa)|0;Ha=Q>>>0>Ia>>>0?Ia:Q;break}}}while(0);Ja=oa+1+Ga|0;if(!(Ja>>>0<H>>>0)){break}Aa=q+((Ha>>>3)+u)|0;Ca=Aa|0;qa=Aa+4|0;Aa=d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0;qa=fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0;Ca=$Gb(fe(Aa|0)|0,qa|0,32-(Ha&7)|0)|0;qa=Ca;Ca=d[856616+(pa>>>0>9>>>0?9:pa)|0]|0;Aa=Ca&3;Ba=Ca>>>5;va=Ca>>>2&7;Ca=qa>>>0>65535>>>0;Ia=Ca?qa>>>16:qa;la=Ca?16:0;if((Ia&65280|0)==0){Ka=la;La=Ia}else{Ka=la|8;La=Ia>>>8}Ia=31-Ka-(d[1191992+La|0]|0)|0;do{if(Ia>>>0>Aa>>>0){la=(Ia<<1)+(va-Aa)|0;Ca=la+Ha|0;Ma=(Aa+1<<Ba)+(-1<<va)+(qa>>>((32-la|0)>>>0))|0;Na=Q>>>0>Ca>>>0?Ca:Q;Oa=qa<<la}else{la=Ia+1|0;Ca=qa<<la;Da=la+Ha|0;la=Q>>>0>Da>>>0?Da:Q;if((Ba|0)==0){Ma=Ia;Na=la;Oa=Ca;break}Da=la+Ba|0;Ma=(Ca>>>((32-Ba|0)>>>0))+(Ia<<Ba)|0;Na=Q>>>0>Da>>>0?Da:Q;Oa=Ca<<Ba}}while(0);Ba=Ma+1|0;Ia=Oa>>31;qa=Na+1|0;va=Q>>>0>qa>>>0?qa:Q;b[j+((d[(c[na>>2]|0)+(Ja>>>(ha>>>0))|0]|0)+((Ja&V)<<6)<<1)>>1]=(Ba^Ia)-Ia;if((R|0)==(va|0)){break a}else{G=Oa<<1;pa=Ba;ma=Ga;oa=Ja;ka=va}}yDb(e,16,1938032,(Pa=i,i=i+16|0,c[Pa>>2]=Ja,c[Pa+8>>2]=H,Pa)|0);i=Pa;Qa=-1094995529;i=h;return Qa|0}}while(0);if((c[T>>2]|0)!=0){H=n+1312|0;R=L<<2;V=R+8|0;ha=U;Q=0;ca=S;while(1){cf[c[H>>2]&1023](ca,L,ha,I);cf[c[H>>2]&1023](ca+16|0,L,ha+128|0,I);cf[c[H>>2]&1023](ca+(R<<1)|0,L,ha+256|0,I);cf[c[H>>2]&1023](ca+(V<<1)|0,L,ha+384|0,I);ia=Q+1|0;if(ia>>>0<(c[T>>2]|0)>>>0){ha=ha+512|0;Q=ia;ca=ca+32|0}else{break}}}do{if((c[e+88>>2]&8192|0)==0){ca=l|0;Q=JSa(e,p,$,K,q+z|0,y,ca,O)|0;if((Q|0)<0){Qa=Q;i=h;return Qa|0}Q=JSa(e,p,_,K,q+B|0,C,ca,O)|0;if((Q|0)<0){Qa=Q}else{break}i=h;return Qa|0}}while(0);B=n+1604|0;Q=c[B>>2]|0;do{if((Q|0)!=0){if((c[W>>2]|0)==0|(D|0)==(u|0)){break}ca=Z;ha=q+t|0;I=c[T>>2]|0;V=I<<2;if((V|0)>0){H=n+36|0;R=0;do{me[c[H>>2]&511](j+(R<<6<<1)|0);R=R+1|0;}while((R|0)<(V|0));Ra=c[B>>2]|0}else{Ra=Q}V=A<<3;R=V>>>0>2147483639>>>0|(ha|0)==0;H=R?0:ha;S=R?0:V;c[f>>2]=H;c[f+12>>2]=S;c[f+16>>2]=S+8;c[f+4>>2]=H+(S>>3);c[f+8>>2]=0;S=I<<8;if((Ra|0)==2){KSa(f,U,S,16)}else{KSa(f,U,S,8)}S=I<<4;H=I<<5;V=L>>1;UGb(Z|0,J|0,H)|0;UGb(ca+(V<<1)|0,j+(S<<1)|0,H)|0;R=V<<1;UGb(ca+(R<<1)|0,j+(H<<1)|0,H)|0;ia=R+V|0;R=H+S|0;UGb(ca+(ia<<1)|0,j+(R<<1)|0,H)|0;Y=ia+V|0;ia=R+S|0;UGb(ca+(Y<<1)|0,j+(ia<<1)|0,H)|0;R=Y+V|0;Y=ia+S|0;UGb(ca+(R<<1)|0,j+(Y<<1)|0,H)|0;ia=R+V|0;R=Y+S|0;UGb(ca+(ia<<1)|0,j+(R<<1)|0,H)|0;Y=ia+V|0;ia=R+S|0;UGb(ca+(Y<<1)|0,j+(ia<<1)|0,H)|0;R=Y+V|0;Y=ia+S|0;UGb(ca+(R<<1)|0,j+(Y<<1)|0,H)|0;ia=R+V|0;R=Y+S|0;UGb(ca+(ia<<1)|0,j+(R<<1)|0,H)|0;Y=ia+V|0;ia=R+S|0;UGb(ca+(Y<<1)|0,j+(ia<<1)|0,H)|0;R=Y+V|0;Y=ia+S|0;UGb(ca+(R<<1)|0,j+(Y<<1)|0,H)|0;ia=R+V|0;R=Y+S|0;UGb(ca+(ia<<1)|0,j+(R<<1)|0,H)|0;Y=ia+V|0;ia=R+S|0;UGb(ca+(Y<<1)|0,j+(ia<<1)|0,H)|0;R=Y+V|0;Y=ia+S|0;UGb(ca+(R<<1)|0,j+(Y<<1)|0,H)|0;UGb(ca+(R+V<<1)|0,j+(Y+S<<1)|0,H)|0}}while(0);c[s>>2]=0;Qa=0;i=h;return Qa|0}}while(0);yDb(e,16,1966008,(Pa=i,i=i+1|0,i=i+7&-8,c[Pa>>2]=0,Pa)|0);i=Pa;Qa=-1094995529;i=h;return Qa|0}function JSa(a,e,f,g,h,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;m=i;i=i+4096|0;n=m|0;o=a+60|0;p=c[o>>2]|0;q=n|0;r=e+12|0;e=c[r>>2]<<l;if((e|0)>0){s=p+36|0;t=0;do{me[c[s>>2]&511](n+(t<<6<<1)|0);t=t+1|0;}while((t|0)<(e|0))}t=j<<3;j=t>>>0>2147483639>>>0|(h|0)==0;s=j?0:h;h=j?0:t;t=h+8|0;j=s|0;u=fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;j=u>>>0>65535>>>0;v=j?u>>>16:u;w=j?16:0;if((v&65280|0)==0){x=w;y=v}else{x=w|8;y=v>>>8}v=(d[1191992+y|0]|0)+x|0;x=31-v|0;if((v|0)==31){v=x+1|0;y=(t>>>0>v>>>0?v:t)+5|0;z=u<<v>>>27|x<<5;A=t>>>0>y>>>0?y:t}else{y=x<<1;x=y+6|0;z=(u>>>((26-y|0)>>>0))-32|0;A=t>>>0>x>>>0?x:t}x=(z>>>1^-(z&1))&65535;b[q>>1]=x;if((e|0)>1){z=A;y=0;u=1;v=5;w=x;x=q;while(1){j=x+128|0;B=s+(z>>>3)|0;C=B|0;D=B+4|0;B=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=$Gb(fe(B|0)|0,D|0,32-(z&7)|0)|0;D=C;C=d[1407976+(v>>>0>6>>>0?6:v)|0]|0;B=C&3;E=C>>>5;F=C>>>2&7;C=D>>>0>65535>>>0;G=C?D>>>16:D;H=C?16:0;if((G&65280|0)==0){I=H;J=G}else{I=H|8;J=G>>>8}G=31-I-(d[1191992+J|0]|0)|0;do{if(G>>>0>B>>>0){H=(G<<1)+(F-B)|0;C=H+z|0;K=(B+1<<E)+(-1<<F)+(D>>>((32-H|0)>>>0))|0;L=t>>>0>C>>>0?C:t}else{C=G+1|0;if((E|0)==0){H=C+z|0;K=G;L=t>>>0>H>>>0?H:t;break}else{H=C+z|0;M=(t>>>0>H>>>0?H:t)+E|0;K=(D<<C>>>((32-E|0)>>>0))+(G<<E)|0;L=t>>>0>M>>>0?M:t;break}}}while(0);if((K|0)==0){N=0}else{N=y^-(K&1)}E=(w&65535)-N+(N^(K+1|0)>>>1)&65535;b[j>>1]=E;G=u+1|0;if((G|0)<(e|0)){z=L;y=N;u=G;v=K;w=E;x=j}else{O=L;break}}}else{O=A}A=c[o>>2]|0;o=e>>>0>65535>>>0;L=o?e>>>16:e;x=o?16:0;if((L&65280|0)==0){P=x;Q=L}else{P=x|8;Q=L>>>8}L=(d[1191992+Q|0]|0)+P|0;P=s+(O>>>3)|0;Q=P|0;x=P+4|0;P=64<<L;o=e-1|0;a:do{if((h|0)!=(O|0)){e=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;w=fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;K=$Gb(fe(e|0)|0,w|0,32-(O&7)|0)|0;w=A+1596|0;e=K;K=2;v=4;u=o;N=O;while(1){y=h-N|0;if((y|0)<32){if((e>>>((32-y|0)>>>0)|0)==0){break a}}y=s+(N>>>3)|0;z=y|0;J=y+4|0;y=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;J=fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0;z=$Gb(fe(y|0)|0,J|0,32-(N&7)|0)|0;J=z;z=d[545576+(v>>>0>15>>>0?15:v)|0]|0;y=z&3;I=z>>>5;E=z>>>2&7;z=J>>>0>65535>>>0;G=z?J>>>16:J;D=z?16:0;if((G&65280|0)==0){R=D;S=G}else{R=D|8;S=G>>>8}G=31-R-(d[1191992+S|0]|0)|0;do{if(G>>>0>y>>>0){D=(G<<1)+(E-y)|0;z=D+N|0;T=(y+1<<I)+(-1<<E)+(J>>>((32-D|0)>>>0))|0;U=t>>>0>z>>>0?z:t}else{z=G+1|0;if((I|0)==0){D=z+N|0;T=G;U=t>>>0>D>>>0?D:t;break}else{D=z+N|0;F=(t>>>0>D>>>0?D:t)+I|0;T=(J<<z>>>((32-I|0)>>>0))+(G<<I)|0;U=t>>>0>F>>>0?F:t;break}}}while(0);V=u+1+T|0;if(!(V>>>0<P>>>0)){break}I=s+(U>>>3)|0;G=I|0;J=I+4|0;I=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;J=fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0;G=$Gb(fe(I|0)|0,J|0,32-(U&7)|0)|0;J=G;G=d[856616+(K>>>0>9>>>0?9:K)|0]|0;I=G&3;E=G>>>5;y=G>>>2&7;G=J>>>0>65535>>>0;F=G?J>>>16:J;z=G?16:0;if((F&65280|0)==0){W=z;X=F}else{W=z|8;X=F>>>8}F=31-W-(d[1191992+X|0]|0)|0;do{if(F>>>0>I>>>0){z=(F<<1)+(y-I)|0;G=z+U|0;Y=(I+1<<E)+(-1<<y)+(J>>>((32-z|0)>>>0))|0;Z=t>>>0>G>>>0?G:t;_=J<<z}else{z=F+1|0;G=J<<z;D=z+U|0;z=t>>>0>D>>>0?D:t;if((E|0)==0){Y=F;Z=z;_=G;break}D=z+E|0;Y=(G>>>((32-E|0)>>>0))+(F<<E)|0;Z=t>>>0>D>>>0?D:t;_=G<<E}}while(0);E=Y+1|0;F=_>>31;J=Z+1|0;y=t>>>0>J>>>0?J:t;b[n+((d[(c[w>>2]|0)+(V>>>(L>>>0))|0]|0)+((V&o)<<6)<<1)>>1]=(E^F)-F;if((h|0)==(y|0)){break a}else{e=_<<1;K=E;v=T;u=V;N=y}}yDb(a,16,1938032,(N=i,i=i+16|0,c[N>>2]=V,c[N+8>>2]=P,N)|0);i=N;$=-1094995529;i=m;return $|0}}while(0);P=c[r>>2]|0;if((P|0)==0){$=0;i=m;return $|0}V=p+1312|0;p=g<<2;if((l|0)<=0){a=0;while(1){T=a+1|0;if(T>>>0<P>>>0){a=T}else{$=0;break}}i=m;return $|0}a=l<<3;P=l<<7;T=q;q=0;_=f;while(1){f=_+(a<<1)|0;h=T;o=0;L=_;while(1){cf[c[V>>2]&1023](L,g,h,k);cf[c[V>>2]&1023](L+(p<<1)|0,g,h+128|0,k);n=o+1|0;if((n|0)<(l|0)){h=h+256|0;o=n;L=L+16|0}else{break}}L=q+1|0;if(L>>>0<(c[r>>2]|0)>>>0){T=T+(P<<1)|0;q=L;_=f}else{$=0;break}}i=m;return $|0}function KSa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=(1<<g)-1|0;i=a+8|0;j=(g|0)==16;k=j?7:4;l=32-k|0;m=a+12|0;n=32-g|0;o=~f;p=c[a>>2]|0;q=c[a+16>>2]|0;a=h;r=0;s=c[i>>2]|0;a:while(1){t=d[p+(s>>>3)|0]|0;u=((s|0)<(q|0))+s|0;c[i>>2]=u;v=p+(u>>>3)|0;w=v|0;x=v+4|0;v=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;w=$Gb(fe(v|0)|0,x|0,32-(u&7)|0)|0;x=w;do{if((t&128>>>((s&7)>>>0)|0)==0){w=x>>>(l>>>0);v=u+k|0;y=q>>>0>v>>>0?v:q;c[i>>2]=y;v=w+2>>1;if((w&1|0)==0){z=v;A=y;break}z=-v|0;A=y}else{y=u+g|0;v=q>>>0>y>>>0?y:q;c[i>>2]=v;z=x>>>(n>>>0);A=v}}while(0);x=z+a&h;if(j){b[e+(r<<1)>>1]=x>>>6}else{b[e+(r<<1)>>1]=x<<2|x>>>6}u=r+1|0;do{if((u|0)<(f|0)){if(((c[m>>2]|0)-A|0)<=0){B=A;break}t=d[p+(A>>>3)|0]|0;v=((A|0)<(q|0))+A|0;c[i>>2]=v;if((t&128>>>((A&7)>>>0)|0)==0){B=v}else{a=x;r=u;s=v;continue a}}else{B=A}}while(0);v=p+(B>>>3)|0;t=v|0;y=v+4|0;v=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=$Gb(fe(v|0)|0,y|0,32-(B&7)|0)|0;y=t>>>28;t=B+4|0;v=q>>>0>t>>>0?t:q;c[i>>2]=v;if((y|0)==0){t=p+(v>>>3)|0;w=t|0;C=t+4|0;t=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;C=fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;w=$Gb(fe(t|0)|0,C|0,32-(v&7)|0)|0;C=v+11|0;t=q>>>0>C>>>0?C:q;c[i>>2]=t;D=w>>>21;E=t}else{D=y;E=v}v=(D+u|0)>(f|0)?f-u|0:D;y=(v|0)>0;do{if(j){if(!y){F=u;break}t=x>>>6&65535;w=-2-r-D|0;C=(w|0)<(o|0)?o:w;w=u;G=0;while(1){b[e+(w<<1)>>1]=t;H=G+1|0;if((H|0)<(v|0)){w=w+1|0;G=H}else{break}}F=~C}else{if(!y){F=u;break}G=(x<<2|x>>>6)&65535;w=-2-r-D|0;t=(w|0)<(o|0)?o:w;w=u;H=0;while(1){b[e+(w<<1)>>1]=G;I=H+1|0;if((I|0)<(v|0)){w=w+1|0;H=I}else{break}}F=~t}}while(0);if((F|0)<(f|0)){a=x;r=F;s=E}else{break}}return}function LSa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+352>>2]=0;c[b+356>>2]=0;c[a+796>>2]=10;SSa(b,a);c[b+208>>2]=-1;TGb(b+220|0,4,128)|0;return 0}function MSa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;h=i;j=c[b+60>>2]|0;k=c[g+24>>2]|0;l=g+28|0;g=c[l>>2]|0;m=e;n=j+72|0;c[n>>2]=m;c[e+88>>2]=1;c[e+84>>2]=1;do{if((g|0)>=28){e=k;if(g>>>0<(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)>>>0){break}e=k+4|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)!=1718641513){break}e=k+8|0;o=g-8|0;p=e;q=(de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;if((q|0)>(o|0)){yDb(b,16,2330640,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}p=k+10|0;t=de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0;if((t&65535)>>>0>1>>>0){yDb(b,16,2306448,(r=i,i=i+8|0,c[r>>2]=t&65535,r)|0);i=r;s=-1094995529;i=h;return s|0}t=k+16|0;p=(de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535;t=k+18|0;u=(de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535;t=b+120|0;v=c[t>>2]|0;w=b+124|0;x=c[w>>2]|0;if(!((p|0)==(v|0)&(u|0)==(x|0))){yDb(b,16,2288248,(r=i,i=i+32|0,c[r>>2]=v,c[r+8>>2]=x,c[r+16>>2]=p,c[r+24>>2]=u,r)|0);i=r;s=-1094995529;i=h;return s|0}u=k+20|0;p=(d[u]|0)>>>2&3;x=j+212|0;c[x>>2]=p;if((p|0)==3){yDb(b,16,2272032,(r=i,i=i+8|0,c[r>>2]=3,r)|0);i=r;s=-1094995529;i=h;return s|0}v=(d[u]|0)>>>6;c[j+364>>2]=v;c[j+368>>2]=v+2;c[j+372>>2]=1<<v>>1;u=a[k+25|0]&15;y=j+400|0;c[y>>2]=u;if(u>>>0>2>>>0){yDb(b,16,2256712,(r=i,i=i+8|0,c[r>>2]=u,r)|0);i=r;s=-1094995529;i=h;return s|0}if((c[b+944>>2]|0)==0){z=u}else{c[y>>2]=0;z=0}if((v|0)==2){c[b+140>>2]=(z|0)!=0?100:74}else if((v|0)==3){c[b+140>>2]=(z|0)!=0?102:78}else{yDb(b,16,2242384,(r=i,i=i+8|0,c[r>>2]=c[j+216>>2],r)|0);i=r;s=-1094995529;i=h;return s|0}v=j+208|0;if((c[v>>2]|0)==(p|0)){A=p;B=m}else{y=j+4|0;u=j+76|0;if((p|0)==0){x2(y,u,1154480)}else{x2(y,u,1154768)}u=c[x>>2]|0;c[v>>2]=u;A=u;B=c[n>>2]|0}u=B+296|0;if((A|0)==0){c[u>>2]=0}else{c[u>>2]=1;c[B+300>>2]=c[x>>2]&1}c[b+384>>2]=d[k+22|0]|0;c[b+388>>2]=d[k+23|0]|0;c[b+392>>2]=d[k+24|0]|0;x=j+348|0;c[x>>2]=0;u=k+28|0;v=d[k+27|0]|0;if((v&2|0)==0){TGb(j+220|0,4,64)|0;c[x>>2]=1;C=u}else{if((q-64|0)<20){yDb(b,16,2229936,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}y=j+220|0;if((PGb(y,u,64)|0)!=0){UGb(y|0,u|0,64)|0;c[x>>2]=1}C=k+92|0}do{if((v&1|0)==0){TGb(j+284|0,4,64)|0;c[x>>2]=1}else{if((C-e|0)>(q-64|0)){yDb(b,16,2229936,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else{u=j+284|0;if((PGb(u,C,64)|0)==0){break}UGb(u|0,C|0,64)|0;c[x>>2]=1;break}}}while(0);if((_$a(b,B,0)|0)<0){s=-1;i=h;return s|0}x=c[n>>2]|0;a:do{if(!((c[x+296>>2]|0)==-1)){e=j+384|0;v=j+388|0;u=j+392|0;y=j+396|0;p=j+352|0;D=j+356|0;E=D;F=j+360|0;G=b+824|0;H=o-q|0;I=k+(q+8)|0;J=0;K=x;while(1){if((H|0)<=0){L=47;break}M=a[I]|0;N=(M&255)>>>3;if((M&255)>>>0<64>>>0|(N|0)>(H|0)){L=47;break}M=I+1|0;O=fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0;if((O|0)>(H|0)){L=49;break}M=a[I+7|0]|0;P=M&255;Q=P>>>4;R=P&15;if(!((M&255)>>>0<64>>>0&(R|0)==0)){L=51;break}c[e>>2]=Q;c[v>>2]=0;M=(c[t>>2]|0)+15>>4;c[u>>2]=M;P=(c[K+296>>2]|0)+4|0;S=(c[w>>2]|0)-1+(1<<P)>>P;c[y>>2]=S;P=M&(1<<Q)-1;T=ba((P&1)+(M>>Q)+(P>>>1&1)+(P>>>2&1)|0,S)|0;S=I+5|0;if((T|0)!=((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535|0)){L=53;break}if((c[p>>2]|0)!=(T|0)){$Db(D);S=WDb((T*4384|0)+4384|0)|0;c[E>>2]=S;if((S|0)==0){s=-1094995529;L=76;break}c[p>>2]=T}S=(T<<1)+N|0;if((S|0)>(H|0)){L=58;break}P=I+S|0;c[c[E>>2]>>2]=P;S=c[E>>2]|0;c[S+20>>2]=0;if((T|0)>0){M=0;U=P;V=S;while(1){W=I+((M<<1)+N)|0;X=U+((de((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)|0;W=M+1|0;c[V+(W*4384|0)>>2]=X;Y=c[E>>2]|0;c[Y+(W*4384|0)+20>>2]=0;if((W|0)<(T|0)){M=W;U=X;V=Y}else{Z=X;_=Y;break}}}else{Z=P;_=S}if(Z>>>0>(I+H|0)>>>0){L=62;break}if((O|0)<0){s=-1094995529;L=76;break}c[F>>2]=J;V=c[y>>2]|0;if((V|0)>0){U=0;M=0;T=c[u>>2]|0;N=V;while(1){if((T|0)<1){$=U;aa=T;ca=N}else{V=U;Y=1<<c[e>>2];X=0;W=T;while(1){da=W-X|0;ea=Y;while(1){if((da|0)<(ea|0)){ea=ea>>1}else{break}}c[_+(V*4384|0)+4>>2]=V;c[_+(V*4384|0)+8>>2]=X;c[_+(V*4384|0)+12>>2]=M;c[_+(V*4384|0)+16>>2]=ea;fa=V+1|0;da=ea+X|0;ga=c[u>>2]|0;if((da|0)>=(ga|0)|(ea|0)==0){break}else{V=fa;Y=ea;X=da;W=ga}}$=fa;aa=ga;ca=c[y>>2]|0}W=M+1|0;if((W|0)<(ca|0)){U=$;M=W;T=aa;N=ca}else{ha=$;break}}}else{ha=0}if((oe[c[G>>2]&63](b,862,_,0,ha,4384)|0)!=0){s=-1;L=76;break}N=J+1|0;T=c[n>>2]|0;if(((c[T+296>>2]|0)-N|0)==-1){break a}else{H=H-O|0;I=I+O|0;J=N;K=T}}if((L|0)==47){yDb(b,16,2003544,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==49){yDb(b,16,1965984,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==51){yDb(b,16,1937992,(r=i,i=i+16|0,c[r>>2]=1<<Q,c[r+8>>2]=1<<R,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==53){yDb(b,16,1913944,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==58){yDb(b,16,1893424,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==62){yDb(b,16,2350992,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==76){i=h;return s|0}}}while(0);c[n>>2]=0;c[f>>2]=1;s=c[l>>2]|0;i=h;return s|0}}while(0);yDb(b,16,2183392,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}function NSa(a){a=a|0;$Db((c[a+60>>2]|0)+356|0);return 0}function OSa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=i;i=i+24|0;h=g|0;j=f;k=c[e+60>>2]|0;l=k;m=c[f+8>>2]|0;n=c[f+12>>2]|0;o=c[f+4>>2]|0;p=c[f+16>>2]|0;q=c[k+72>>2]|0;r=c[k+356>>2]|0;s=c[r+(o*4384|0)>>2]|0;t=(c[r+((o+1|0)*4384|0)>>2]|0)-s|0;o=p>>>0>65535>>>0;r=o?p>>>16:p;u=o?16:0;if((r&65280|0)==0){v=u;w=r}else{v=u|8;w=r>>>8}r=(d[1191992+w|0]|0)+v|0;v=c[q>>2]|0;w=c[q+4>>2]|0;u=c[q+8>>2]|0;o=c[q+12>>2]|0;x=c[q+32>>2]|0;y=c[q+36>>2]|0;z=c[q+40>>2]|0;A=c[q+44>>2]|0;if((c[q+296>>2]|0)==0){B=v;C=w;D=u;E=A;F=z;G=y;H=x;I=o}else{do{if((c[k+360>>2]|0)==(c[q+300>>2]|0)){J=v+x|0;K=w+y|0;L=u+z|0;if((o|0)==0){M=J;N=K;O=L;P=0;break}M=J;N=K;O=L;P=o+A|0}else{M=v;N=w;O=u;P=o}}while(0);B=M;C=N;D=O;E=A<<1;F=z<<1;G=y<<1;H=x<<1;I=P}P=n<<4;n=m<<5;x=B+((ba(H,P)|0)+n)|0;B=ba(G,P)|0;y=m<<c[k+368>>2];m=C+(y+B)|0;B=D+(y+(ba(F,P)|0))|0;if((I|0)==0){Q=0}else{Q=I+((ba(E,P)|0)+n)|0}if((t|0)<6){yDb(e,16,2106312,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;S=-1094995529;i=g;return S|0}n=a[s]|0;P=(n&255)>>>3;I=s+2|0;y=(de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535;I=y+P|0;D=s+4|0;C=(de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;D=C+I|0;if((n&255)>>>0>63>>>0){z=s+6|0;T=(de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535}else{T=t-D|0}z=T+D|0;A=k+400|0;O=(c[A>>2]|0)==0?0:t-z|0;if((O|T|0)<0|(n&255)>>>0<48>>>0){yDb(e,16,2049080,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;S=-1094995529;i=g;return S|0}R=a[s+1|0]|0;e=R&255;do{if(R<<24>>24==0){U=1}else{n=e>>>0>224>>>0?224:e;if(!(n>>>0>128>>>0)){U=n;break}U=(n<<2)-384|0}}while(0);e=f+20|0;do{if((c[k+348>>2]|0)==0){if((U|0)!=(c[e>>2]|0)){V=23;break}W=f+4128|0}else{V=23}}while(0);if((V|0)==23){c[e>>2]=U;e=f+4128|0;V=e;R=f+4256|0;n=0;while(1){t=(ba(d[k+(n+220)|0]|0,U)|0)&65535;N=k+(n+4)|0;b[V+((d[N]|0)<<1)>>1]=t;t=(ba(d[k+(n+284)|0]|0,U)|0)&65535;b[R+((d[N]|0)<<1)>>1]=t;t=n+1|0;if((t|0)<64){n=t}else{W=e;break}}}e=PSa(l,j,s+P|0,y,x,H,p,4,r+2|0,W,0)|0;if((e|0)<0){S=e;i=g;return S|0}e=k+372|0;W=k+364|0;k=r-1|0;r=f+4256|0;H=PSa(l,j,s+I|0,C,m,G,p,c[e>>2]|0,k+(c[W>>2]|0)|0,r,1)|0;if((H|0)<0){S=H;i=g;return S|0}H=PSa(l,j,s+D|0,T,B,F,p,c[e>>2]|0,k+(c[W>>2]|0)|0,r,1)|0;if((H|0)<0){S=H;i=g;return S|0}if((Q|0)==0|(O|0)==0){S=0;i=g;return S|0}H=s+z|0;z=Q;s=f+32|0;TGb(s|0,0,4096)|0;f=O<<3;O=f>>>0>2147483639>>>0|(H|0)==0;r=O?0:H;H=O?0:f;c[h>>2]=r;c[h+12>>2]=H;c[h+16>>2]=H+8;c[h+4>>2]=r+(H>>3);c[h+8>>2]=0;H=s;r=p<<8;if((c[A>>2]|0)==2){QSa(h,H,r,16)}else{QSa(h,H,r,8)}r=p<<4;H=p<<5;p=E>>1;UGb(Q|0,s|0,H)|0;UGb(z+(p<<1)|0,j+32+(r<<1)|0,H)|0;s=p<<1;UGb(z+(s<<1)|0,j+32+(H<<1)|0,H)|0;Q=s+p|0;s=H+r|0;UGb(z+(Q<<1)|0,j+32+(s<<1)|0,H)|0;E=Q+p|0;Q=s+r|0;UGb(z+(E<<1)|0,j+32+(Q<<1)|0,H)|0;s=E+p|0;E=Q+r|0;UGb(z+(s<<1)|0,j+32+(E<<1)|0,H)|0;Q=s+p|0;s=E+r|0;UGb(z+(Q<<1)|0,j+32+(s<<1)|0,H)|0;E=Q+p|0;Q=s+r|0;UGb(z+(E<<1)|0,j+32+(Q<<1)|0,H)|0;s=E+p|0;E=Q+r|0;UGb(z+(s<<1)|0,j+32+(E<<1)|0,H)|0;Q=s+p|0;s=E+r|0;UGb(z+(Q<<1)|0,j+32+(s<<1)|0,H)|0;E=Q+p|0;Q=s+r|0;UGb(z+(E<<1)|0,j+32+(Q<<1)|0,H)|0;s=E+p|0;E=Q+r|0;UGb(z+(s<<1)|0,j+32+(E<<1)|0,H)|0;Q=s+p|0;s=E+r|0;UGb(z+(Q<<1)|0,j+32+(s<<1)|0,H)|0;E=Q+p|0;Q=s+r|0;UGb(z+(E<<1)|0,j+32+(Q<<1)|0,H)|0;s=E+p|0;E=Q+r|0;UGb(z+(s<<1)|0,j+32+(E<<1)|0,H)|0;UGb(z+(s+p<<1)|0,j+32+(E+r<<1)|0,H)|0;S=0;i=g;return S|0}function PSa(a,e,f,g,h,j,k,l,m,n,o){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;p=i;i=i+24|0;q=p|0;r=ba(l,k)|0;s=e+32|0;TGb(s|0,0,4096)|0;t=g<<3;g=t>>>0>2147483639>>>0|(f|0)==0;u=g?0:f;f=g?0:t;t=q|0;c[t>>2]=u;g=q+12|0;c[g>>2]=f;v=f+8|0;w=q+16|0;c[w>>2]=v;c[q+4>>2]=u+(f>>3);f=q+8|0;c[f>>2]=0;x=s|0;s=u|0;u=fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;s=u>>>0>65535>>>0;y=s?u>>>16:u;z=s?16:0;if((y&65280|0)==0){A=z;B=y}else{A=z|8;B=y>>>8}y=d[1191992+B|0]|0;B=31-A|0;A=B-y|0;if((B|0)==(y|0)){y=A+6|0;C=u<<A+1>>>27|A<<5;D=v>>>0>y>>>0?y:v}else{y=A<<1;A=y+6|0;C=(u>>>((26-y|0)>>>0))-32|0;D=v>>>0>A>>>0?A:v}c[f>>2]=D;D=(C>>>1^-(C&1))&65535;b[x>>1]=D;if((r|0)>1){C=D;D=1;v=3;A=x;while(1){y=A+128|0;u=(v|0)>-1?v:-v|0;B=RSa(q,d[1155040+((u|0)>3?3:u)|0]|0)|0;u=(B^v>>>15)&1;z=((B+1|0)>>>1^-u)+u&65535;u=z+C&65535;b[y>>1]=u;B=D+1|0;if((B|0)<(r|0)){C=u;D=B;v=z<<16>>16;A=y}else{break}}}A=r<<6;v=r-1|0;a:do{if((v|0)<(A|0)){r=c[f>>2]|0;D=(c[g>>2]|0)-r|0;if((D|0)<1){break}else{E=r;F=v;G=1154468;H=1154650;I=D}while(1){D=d[G]|0;r=d[H]|0;if((I|0)<9){C=(c[t>>2]|0)+(E>>>3)|0;y=C|0;z=C+4|0;C=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=$Gb(fe(C|0)|0,z|0,32-(E&7)|0)|0;if((y>>>((32-I|0)>>>0)|0)==0){break a}}y=RSa(q,d[1155152+D|0]|0)|0;if((y|0)<0){J=-1094995529;K=28;break}D=c[f>>2]|0;z=(c[g>>2]|0)-D|0;if((z|0)<1){J=-1094995529;K=28;break}if((z|0)<9){C=(c[t>>2]|0)+(D>>>3)|0;B=C|0;u=C+4|0;C=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0;B=$Gb(fe(C|0)|0,u|0,32-(D&7)|0)|0;if((B>>>((32-z|0)>>>0)|0)==0){J=-1094995529;K=28;break}}z=(RSa(q,d[1155152+r|0]|0)|0)+1|0;if((z|0)<0){J=-1094995529;K=28;break}r=F+1+y|0;if((r|0)>=(A|0)){break a}B=c[f>>2]|0;D=c[w>>2]|0;u=(c[t>>2]|0)+(B>>>3)|0;C=u|0;s=u+4|0;u=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=$Gb(fe(u|0)|0,s|0,32-(B&7)|0)|0;s=C>>31;C=B+1|0;B=D>>>0>C>>>0?C:D;c[f>>2]=B;b[e+32+((d[(r>>m)+(a+80)|0]|0)+((r&v)<<6)<<1)>>1]=(s^z)-s;s=(c[g>>2]|0)-B|0;if((s|0)<1){break a}else{E=B;F=r;G=1154464+((y|0)>15?15:y)|0;H=1154648+((z|0)>9?9:z)|0;I=s}}if((K|0)==28){i=p;return J|0}}}while(0);K=(k|0)>0;if((o|0)==0){if(!K){J=0;i=p;return J|0}o=a+68|0;I=j<<2;H=I+8|0;G=l<<2;if((l|0)>2){F=x;E=0;g=h;while(1){cf[c[o>>2]&1023](g,j,F,n);cf[c[o>>2]&1023](g+16|0,j,F+128|0,n);cf[c[o>>2]&1023](g+(I<<1)|0,j,F+256|0,n);cf[c[o>>2]&1023](g+(H<<1)|0,j,F+384|0,n);v=E+1|0;if((v|0)<(k|0)){F=F+512|0;E=v;g=g+(G<<1)|0}else{J=0;break}}i=p;return J|0}else{g=x;E=0;F=h;while(1){cf[c[o>>2]&1023](F,j,g,n);cf[c[o>>2]&1023](F+(I<<1)|0,j,g+128|0,n);H=E+1|0;if((H|0)<(k|0)){g=g+256|0;E=H;F=F+(G<<1)|0}else{J=0;break}}i=p;return J|0}}else{if(!K){J=0;i=p;return J|0}K=a+68|0;a=j<<2;G=a+8|0;F=l<<2;if((l|0)>2){l=x;E=0;g=h;while(1){cf[c[K>>2]&1023](g,j,l,n);cf[c[K>>2]&1023](g+(a<<1)|0,j,l+128|0,n);cf[c[K>>2]&1023](g+16|0,j,l+256|0,n);cf[c[K>>2]&1023](g+(G<<1)|0,j,l+384|0,n);I=E+1|0;if((I|0)<(k|0)){l=l+512|0;E=I;g=g+(F<<1)|0}else{J=0;break}}i=p;return J|0}else{g=x;x=0;E=h;while(1){cf[c[K>>2]&1023](E,j,g,n);cf[c[K>>2]&1023](E+(a<<1)|0,j,g+128|0,n);h=x+1|0;if((h|0)<(k|0)){g=g+256|0;x=h;E=E+(F<<1)|0}else{J=0;break}}i=p;return J|0}}return 0}function QSa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=(1<<g)-1|0;i=a+8|0;j=(g|0)==16;k=j?7:4;l=32-k|0;m=32-g|0;n=~f;o=c[a>>2]|0;p=c[a+16>>2]|0;a=h;q=0;r=c[i>>2]|0;while(1){s=d[o+(r>>>3)|0]|0;t=((r|0)<(p|0))+r|0;c[i>>2]=t;u=o+(t>>>3)|0;v=u|0;w=u+4|0;u=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;v=$Gb(fe(u|0)|0,w|0,32-(t&7)|0)|0;w=v;do{if((s&128>>>((r&7)>>>0)|0)==0){v=w>>>(l>>>0);u=t+k|0;x=p>>>0>u>>>0?u:p;c[i>>2]=x;u=v+2>>1;if((v&1|0)==0){y=u;z=x;break}y=-u|0;z=x}else{x=t+g|0;u=p>>>0>x>>>0?x:p;c[i>>2]=u;y=w>>>(m>>>0);z=u}}while(0);w=y+a&h;if(j){b[e+(q<<1)>>1]=w>>>6}else{b[e+(q<<1)>>1]=w<<2|w>>>6}t=q+1|0;if((t|0)<(f|0)){s=d[o+(z>>>3)|0]|0;u=((z|0)<(p|0))+z|0;c[i>>2]=u;if((s&128>>>((z&7)>>>0)|0)==0){A=u}else{a=w;q=t;r=u;continue}}else{A=z}u=o+(A>>>3)|0;s=u|0;x=u+4|0;u=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;s=$Gb(fe(u|0)|0,x|0,32-(A&7)|0)|0;x=s>>>28;s=A+4|0;u=p>>>0>s>>>0?s:p;c[i>>2]=u;if((x|0)==0){s=o+(u>>>3)|0;v=s|0;B=s+4|0;s=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;v=$Gb(fe(s|0)|0,B|0,32-(u&7)|0)|0;B=u+11|0;s=p>>>0>B>>>0?B:p;c[i>>2]=s;C=v>>>21;D=s}else{C=x;D=u}u=(C+t|0)>(f|0)?f-t|0:C;x=(u|0)>0;do{if(j){if(!x){E=t;break}s=w>>>6&65535;v=-2-q-C|0;B=(v|0)<(n|0)?n:v;v=t;F=0;while(1){b[e+(v<<1)>>1]=s;G=F+1|0;if((G|0)<(u|0)){v=v+1|0;F=G}else{break}}E=~B}else{if(!x){E=t;break}F=(w<<2|w>>>6)&65535;v=-2-q-C|0;s=(v|0)<(n|0)?n:v;v=t;G=0;while(1){b[e+(v<<1)>>1]=F;H=G+1|0;if((H|0)<(u|0)){v=v+1|0;G=H}else{break}}E=~s}}while(0);if((E|0)<(f|0)){a=w;q=E;r=D}else{break}}return}function RSa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(f>>>3)|0;a=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0;a=$Gb(fe(h|0)|0,i|0,32-(f&7)|0)|0;i=a;a=(b&3)+1|0;h=b>>>5;j=b>>>2&7;b=i>>>0>65535>>>0;k=b?i>>>16:i;l=b?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=31-m-(d[1191992+n|0]|0)|0;if(!(k>>>0<a>>>0)){n=(k<<1)-a+j|0;m=f+1+n|0;o=(a<<h)+(-1<<j)+(i>>>((31-n|0)>>>0))|0;p=g>>>0>m>>>0?m:g;c[e>>2]=p;return o|0}m=k+1|0;if((h|0)==0){n=m+f|0;o=k;p=g>>>0>n>>>0?n:g;c[e>>2]=p;return o|0}else{n=f+h+m|0;o=(i<<m>>>((32-h|0)>>>0))+(k<<h)|0;p=g>>>0>n>>>0?n:g;c[e>>2]=p;return o|0}return 0}function SSa(a,b){a=a|0;b=b|0;c[a+68>>2]=644;c[a>>2]=1;y2(a+4|0,1);return}function TSa(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;TXa(d,e);e=c>>1;c=0;f=0;while(1){g=c<<3;h=b[d+(g<<1)>>1]|0;if(h<<16>>16<4){i=4}else{i=h<<16>>16>1019?1019:h}b[a+(f<<1)>>1]=i;h=b[d+((g|1)<<1)>>1]|0;if(h<<16>>16<4){j=4}else{j=h<<16>>16>1019?1019:h}b[a+(f+1<<1)>>1]=j;h=b[d+((g|2)<<1)>>1]|0;if(h<<16>>16<4){k=4}else{k=h<<16>>16>1019?1019:h}b[a+(f+2<<1)>>1]=k;h=b[d+((g|3)<<1)>>1]|0;if(h<<16>>16<4){l=4}else{l=h<<16>>16>1019?1019:h}b[a+(f+3<<1)>>1]=l;h=b[d+((g|4)<<1)>>1]|0;if(h<<16>>16<4){m=4}else{m=h<<16>>16>1019?1019:h}b[a+(f+4<<1)>>1]=m;h=b[d+((g|5)<<1)>>1]|0;if(h<<16>>16<4){n=4}else{n=h<<16>>16>1019?1019:h}b[a+(f+5<<1)>>1]=n;h=b[d+((g|6)<<1)>>1]|0;if(h<<16>>16<4){o=4}else{o=h<<16>>16>1019?1019:h}b[a+(f+6<<1)>>1]=o;h=b[d+((g|7)<<1)>>1]|0;if(h<<16>>16<4){p=4}else{p=h<<16>>16>1019?1019:h}b[a+(f+7<<1)>>1]=p;h=c+1|0;if((h|0)<8){c=h;f=f+e|0}else{break}}return}function USa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;e=c[a+60>>2]|0;if((c[a+140>>2]|0)!=74){yDb(a,16,1965968,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1;i=b;return g|0}h=c[a+120>>2]|0;if((h&1|0)!=0){yDb(a,16,1937952,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1;i=b;return g|0}if((c[a+124>>2]&15|0)==0){if((h&15|0)!=0){j=7}}else{j=7}do{if((j|0)==7){h=WDb(8192)|0;c[e>>2]=h;if((h|0)==0){g=-12;i=b;return g|0}else{c[e+4>>2]=h+4096;c[e+8>>2]=h+6144;break}}}while(0);j=a+840|0;h=c[j>>2]|0;do{if((h|0)==-99){c[j>>2]=2;yDb(a,32,1913896,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;k=c[j>>2]|0}else{if(!(h>>>0>3>>>0)){k=h;break}yDb(a,16,1893344,(f=i,i=i+8|0,c[f>>2]=h,f)|0);i=f;g=-1;i=b;return g|0}}while(0);f=c[561676+(k<<3)>>2]|0;c[a+52>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e+12|0;h=e+4108|0;e=1;l=k;while(1){k=e-1|0;m=0;do{c[f+(k<<8)+(m<<2)>>2]=ba(d[2362568+(l<<6)+m|0]|0,e)|0;m=m+1|0;}while((m|0)<64);m=c[j>>2]|0;n=0;do{c[h+(k<<8)+(n<<2)>>2]=ba(d[2362824+(m<<6)+n|0]|0,e)|0;n=n+1|0;}while((n|0)<64);n=e+1|0;if((n|0)>=17){break}e=n;l=c[j>>2]|0}j=ICb()|0;c[a+804>>2]=j;c[j+84>>2]=1;c[j+88>>2]=1;g=0;i=b;return g|0}function VSa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;g=b+120|0;h=b+124|0;i=(ba((c[g>>2]<<4)+240&-256,(c[h>>2]|0)+15&-16)|0|500)+32768|0;j=r0a(b,d,i,(i|0)<0|0?-1:0)|0;if((j|0)<0){k=j;return k|0}j=c[d+24>>2]|0;i=d+28|0;l=c[i>>2]|0;m=(c[g>>2]|0)+15>>4;n=c[h>>2]|0;o=a[1192e3]|0;p=o&255;q=0;r=m;while(1){s=(r>>p)+q|0;t=(1<<p)-1&r;if((p|0)>0){p=p-1|0;q=s;r=t}else{break}}r=j+156|0;q=n+15>>4;n=b+840|0;p=ba(s,q)|0;s=j+((p<<1)+164)|0;if((q|0)>0){t=(m|0)>0;u=b+60|0;v=e+32|0;w=e+36|0;y=e|0;z=e+4|0;A=e+8|0;e=b+88|0;b=q-1|0;B=c[555760+(c[n>>2]<<2)>>2]|0;C=j+164|0;D=l-164|0;l=0;E=s;while(1){if(t){F=l<<4;G=(l|0)==(b|0);H=B;I=C;J=D;K=E;L=0;M=8;while(1){N=m-L|0;O=M;while(1){if((N|0)<(O|0)){O=O>>1}else{break}}N=c[h>>2]|0;P=c[g>>2]|0;if((P&15|0)==0){Q=0}else{Q=(O+L|0)==(m|0)}R=c[u>>2]|0;S=ba(c[1685136+(c[n>>2]<<2)>>2]|0,O)|0;T=S>>>2;U=S>>>5;S=T-U>>3;V=(T+U|0)>>>3;U=c[v>>2]|0;T=c[w>>2]|0;W=c[y>>2]|0;X=W+((ba(U,F)|0)+(L<<5))|0;Y=L<<4;Z=(ba(T,F)|0)+Y|0;_=(c[z>>2]|0)+Z|0;$=(c[A>>2]|0)+Z|0;a:do{if(G&(N&15|0)!=0|Q){Z=R;aa=O<<4;XSa(W,Y,F,U,P,N,c[Z>>2]|0,aa);ca=L<<3;da=R+4|0;ea=O<<3;XSa(c[z>>2]|0,ca,F,T,c[g>>2]>>1,c[h>>2]|0,c[da>>2]|0,ea);fa=R+8|0;XSa(c[A>>2]|0,ca,F,T,c[g>>2]>>1,c[h>>2]|0,c[fa>>2]|0,ea);ea=c[da>>2]|0;da=c[fa>>2]|0;fa=J-6|0;ca=c[u>>2]|0;ga=H-1|0;ha=YSa(O,c[Z>>2]|0,O<<5,K+6|0,fa,ca+12+(ga<<8)|0,0)|0;if((c[e>>2]&8192|0)!=0){ia=0;ja=0;ka=ha;la=H;break}Z=ha+6|0;ma=fa-ha|0;fa=ca+4108+(ga<<8)|0;ga=YSa(O,ea,aa,K+Z|0,ma,fa,1)|0;ia=YSa(O,da,aa,K+(ga+Z)|0,ma-ga|0,fa,1)|0;ja=ga;ka=ha;la=H}else{ha=K+6|0;ga=J-6|0;fa=H-1|0;ma=YSa(O,X,U,ha,ga,R+12+(fa<<8)|0,0)|0;if((c[e>>2]&8192|0)==0){Z=ma+6|0;aa=ga-ma|0;da=R+4108+(fa<<8)|0;fa=YSa(O,_,T,K+Z|0,aa,da,1)|0;na=YSa(O,$,T,K+(fa+Z)|0,aa-fa|0,da,1)|0;oa=fa}else{na=0;oa=0}fa=oa+ma+na|0;do{if((fa|0)>(V|0)){if((H|0)<(c[555776+(c[n>>2]<<2)>>2]|0)){pa=na;qa=oa;ra=H}else{break}while(1){da=ra+1|0;aa=c[u>>2]|0;Z=YSa(O,X,U,ha,ga,aa+12+(ra<<8)|0,0)|0;if((c[e>>2]&8192|0)==0){ea=Z+6|0;ca=ga-Z|0;sa=aa+4108+(ra<<8)|0;aa=YSa(O,_,T,K+ea|0,ca,sa,1)|0;ta=YSa(O,$,T,K+(aa+ea)|0,ca-aa|0,sa,1)|0;ua=aa}else{ta=pa;ua=qa}if((ua+Z+ta|0)<=(V|0)){ia=ta;ja=ua;ka=Z;la=da;break a}if((da|0)<(c[555776+(c[n>>2]<<2)>>2]|0)){pa=ta;qa=ua;ra=da}else{ia=ta;ja=ua;ka=Z;la=da;break a}}}}while(0);if((fa|0)>=(S|0)){ia=na;ja=oa;ka=ma;la=H;break}if((H|0)>(c[555760+(c[n>>2]<<2)>>2]|0)){va=na;wa=oa;xa=H}else{ia=na;ja=oa;ka=ma;la=H;break}while(1){da=xa-1|0;Z=c[u>>2]|0;aa=xa-2|0;sa=YSa(O,X,U,ha,ga,Z+12+(aa<<8)|0,0)|0;if((c[e>>2]&8192|0)==0){ca=sa+6|0;ea=ga-sa|0;ya=Z+4108+(aa<<8)|0;aa=YSa(O,_,T,K+ca|0,ea,ya,1)|0;za=YSa(O,$,T,K+(aa+ca)|0,ea-aa|0,ya,1)|0;Aa=aa}else{za=va;Aa=wa}if((Aa+sa+za|0)>=(S|0)){ia=za;ja=Aa;ka=sa;la=da;break a}if((da|0)>(c[555760+(c[n>>2]<<2)>>2]|0)){va=za;wa=Aa;xa=da}else{ia=za;ja=Aa;ka=sa;la=da;break}}}}while(0);a[K]=48;a[K+1|0]=la;S=K+2|0;x=de(ka&65535|0)|0;a[S]=x;x=x>>8;a[S+1|0]=x;S=K+4|0;x=de(ja&65535|0)|0;a[S]=x;x=x>>8;a[S+1|0]=x;S=ka+6+ja+ia|0;T=I;x=de(S&65535|0)|0;a[T]=x;x=x>>8;a[T+1|0]=x;T=I+2|0;$=K+S|0;_=J-S|0;S=O+L|0;if((S|0)<(m|0)){H=la;I=T;J=_;K=$;L=S;M=O}else{Ba=la;Ca=T;Da=_;Ea=$;break}}}else{Ba=B;Ca=C;Da=D;Ea=E}M=l+1|0;if((M|0)<(q|0)){B=Ba;C=Ca;D=Da;l=M;E=Ea}else{Fa=Ea;break}}}else{Fa=s}a[r]=64;s=Fa-r|0;r=j+157|0;x=fe(s|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=j+161|0;x=de(p&65535|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;a[j+163|0]=o<<4;o=s+156|0;s=j;x=fe(o|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=j+4|0;x=1718641513;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=j+8|0;x=-27648;a[s]=x;x=x>>8;a[s+1|0]=x;s=j+10|0;x=0;a[s]=x;x=x>>8;a[s+1|0]=x;s=j+12|0;x=1735421286;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=j+16|0;x=de(c[g>>2]&65535|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;s=j+18|0;x=de(c[h>>2]&65535|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;a[j+20|0]=-125;a[j+21|0]=0;a[j+22|0]=2;a[j+23|0]=2;a[j+24|0]=6;a[j+25|0]=32;a[j+26|0]=0;a[j+27|0]=3;UGb(j+28|0,2362568+(c[n>>2]<<6)|0,64)|0;UGb(j+92|0,2362824+(c[n>>2]<<6)|0,64)|0;n=d+36|0;c[n>>2]=c[n>>2]|1;c[i>>2]=o;c[f>>2]=1;k=0;return k|0}function WSa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(a+804|0);$Db(b);return 0}function XSa(a,c,d,e,f,g,h,i){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=h;k=f-c|0;l=k>>>0>i>>>0?i:k;k=g-d|0;m=k>>>0>16>>>0?16:k;k=e>>>1;e=a+((ba(k,d)|0)+c<<1)|0;do{if((m|0)>0){if((l|0)>0){a=~i;n=c-1-f|0;o=n>>>0<a>>>0?a:n;n=~o;a=d-1-g|0;p=a>>>0>4294967279>>>0?a:-17;a=0;q=h;r=e;while(1){s=0;do{b[q+(s<<1)>>1]=b[r+(s<<1)>>1]|0;s=s+1|0;}while((s|0)<(l|0));s=b[q+(-2-o<<1)>>1]|0;if(n>>>0<i>>>0){t=n;do{b[q+(t<<1)>>1]=s;t=t+1|0;}while(t>>>0<i>>>0)}t=a+1|0;if((t|0)<(m|0)){a=t;q=q+(i<<1)|0;r=r+(k<<1)|0}else{u=p;break}}}else{p=d-1-g|0;r=p>>>0>4294967279>>>0?p:-17;p=0;q=h;while(1){a=b[q-2>>1]|0;if((i|0)!=0){n=0;do{b[q+(n<<1)>>1]=a;n=n+1|0;}while(n>>>0<i>>>0)}n=p+1|0;if((n|0)<(m|0)){p=n;q=q+(i<<1)|0}else{u=r;break}}}r=j+(ba(-2-(u<<1)|0,i)|0)|0;if(u>>>0>4294967279>>>0){v=r;w=~u;break}return}else{v=h;w=0}}while(0);if((i|0)==0){return}else{x=w;y=v}while(1){w=0;do{b[y+(w<<1)>>1]=b[v+(w-i<<1)>>1]|0;w=w+1|0;}while(w>>>0<i>>>0);w=x+1|0;if(w>>>0<16>>>0){x=w;y=y+(i<<1)|0}else{break}}return}function YSa(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;m=i;i=i+4120|0;n=m|0;o=m+4096|0;p=n|0;if((e|0)>0){q=g>>1;r=g<<3;g=2-l|0;s=g<<6;t=(l|0)==0;u=r+16|0;v=256>>>(l>>>0);w=32>>>(l>>>0);y=p;z=0;A=f;while(1){f=y;B=A;C=0;while(1){b[f>>1]=b[B>>1]|0;b[f+2>>1]=b[B+2>>1]|0;b[f+4>>1]=b[B+4>>1]|0;b[f+6>>1]=b[B+6>>1]|0;b[f+8>>1]=b[B+8>>1]|0;b[f+10>>1]=b[B+10>>1]|0;b[f+12>>1]=b[B+12>>1]|0;b[f+14>>1]=b[B+14>>1]|0;D=C+1|0;if((D|0)<8){f=f+16|0;B=B+(q<<1)|0;C=D}else{break}}kJa(y);C=y+(s<<1)|0;B=C;f=A+r|0;D=0;while(1){b[B>>1]=b[f>>1]|0;b[B+2>>1]=b[f+2>>1]|0;b[B+4>>1]=b[f+4>>1]|0;b[B+6>>1]=b[f+6>>1]|0;b[B+8>>1]=b[f+8>>1]|0;b[B+10>>1]=b[f+10>>1]|0;b[B+12>>1]=b[f+12>>1]|0;b[B+14>>1]=b[f+14>>1]|0;E=D+1|0;if((E|0)<8){B=B+16|0;f=f+(q<<1)|0;D=E}else{break}}kJa(C);if(t){D=y+128|0;f=D;B=A+16|0;E=0;while(1){b[f>>1]=b[B>>1]|0;b[f+2>>1]=b[B+2>>1]|0;b[f+4>>1]=b[B+4>>1]|0;b[f+6>>1]=b[B+6>>1]|0;b[f+8>>1]=b[B+8>>1]|0;b[f+10>>1]=b[B+10>>1]|0;b[f+12>>1]=b[B+12>>1]|0;b[f+14>>1]=b[B+14>>1]|0;F=E+1|0;if((F|0)<8){f=f+16|0;B=B+(q<<1)|0;E=F}else{break}}kJa(D);E=y+384|0;B=E;f=A+u|0;C=0;while(1){b[B>>1]=b[f>>1]|0;b[B+2>>1]=b[f+2>>1]|0;b[B+4>>1]=b[f+4>>1]|0;b[B+6>>1]=b[f+6>>1]|0;b[B+8>>1]=b[f+8>>1]|0;b[B+10>>1]=b[f+10>>1]|0;b[B+12>>1]=b[f+12>>1]|0;b[B+14>>1]=b[f+14>>1]|0;F=C+1|0;if((F|0)<8){B=B+16|0;f=f+(q<<1)|0;C=F}else{break}}kJa(E)}C=z+1|0;if((C|0)<(e|0)){y=y+(v<<1)|0;z=C;A=A+w|0}else{break}}G=(b[p>>1]|0)-16384|0;H=g}else{G=-16384;H=2-l|0}l=e<<H;H=j<<3;j=(H|0)<0;e=j?0:h;h=j?0:H;c[o+20>>2]=h<<3;H=o+8|0;c[H>>2]=e;c[o+16>>2]=e+h;h=o+12|0;c[h>>2]=e;e=o+4|0;c[e>>2]=32;j=o|0;c[j>>2]=0;g=(G|0)/(c[k>>2]|0)|0;ZSa(o,g<<1^g>>31,184);if((l|0)>1){G=64;p=0;w=1;A=5;z=g;while(1){g=((b[n+(G<<1)>>1]|0)-16384|0)/(c[k>>2]|0)|0;v=g-z|0;y=v>>31;if((g|0)==(z|0)){I=0}else{I=((y^v)-y<<1)+(y^p)|0}ZSa(o,I,d[1407968+((A|0)>6?6:A)|0]|0);v=w+1|0;if((v|0)<(l|0)){G=G+64|0;p=y;w=v;A=I;z=g}else{break}}}if((l|0)>0){z=0;I=1;A=2;w=4;while(1){p=d[561552+I|0]|0;G=k+(p<<2)|0;g=z;v=0;y=A;q=w;while(1){u=(b[n+((v<<6)+p<<1)>>1]|0)/(c[G>>2]|0)|0;if((u|0)==0){J=q;K=y;L=g+1|0}else{ZSa(o,g,d[545560+((q|0)>15?15:q)|0]|0);t=u>>31;r=(t^u)-t|0;ZSa(o,r-1|0,d[856600+((y|0)>9?9:y)|0]|0);t=u>>>31;u=c[j>>2]|0;s=c[e>>2]|0;if((s|0)>1){M=s-1|0;N=u<<1|t}else{C=fe(t>>>((1-s|0)>>>0)|u<<s|0)|0;u=c[h>>2]|0;x=C;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;M=s+31|0;N=t}c[j>>2]=N;c[e>>2]=M;J=g;K=r;L=0}r=v+1|0;if((r|0)<(l|0)){g=L;v=r;y=K;q=J}else{break}}q=I+1|0;if((q|0)<64){z=L;I=q;A=K;w=J}else{break}}}J=c[e>>2]|0;if((J|0)>=32){c[e>>2]=32;c[j>>2]=0;O=c[h>>2]|0;P=c[H>>2]|0;Q=O;R=P;S=Q-R|0;i=m;return S|0}w=c[j>>2]<<J;c[j>>2]=w;J=w>>>24&255;while(1){w=c[h>>2]|0;c[h>>2]=w+1;a[w]=J;w=c[j>>2]|0;c[j>>2]=w<<8;K=(c[e>>2]|0)+8|0;c[e>>2]=K;if((K|0)>=32){break}J=w>>>16&255}c[e>>2]=32;c[j>>2]=0;O=c[h>>2]|0;P=c[H>>2]|0;Q=O;R=P;S=Q-R|0;i=m;return S|0}function ZSa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0;g=f&3;h=f>>5;i=f>>>2&7;f=g+1<<h;if(!(f>>>0>e>>>0)){j=e-f+(1<<i)|0;f=j>>>0>65535>>>0;k=f?j>>>16:j;l=f?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=(d[1191992+n|0]|0)+m|0;m=k-i+g|0;g=m+1|0;i=b|0;n=c[i>>2]|0;l=b+4|0;f=c[l>>2]|0;if((f|0)>(g|0)){o=f-g|0;p=n<<g}else{g=fe(n<<f|0)|0;n=b+12|0;q=c[n>>2]|0;x=g;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;o=f+31-m|0;p=0}c[i>>2]=p;c[l>>2]=o;m=k+1|0;if((o|0)>(m|0)){r=o-m|0;s=p<<m|j}else{f=fe(j>>>((m-o|0)>>>0)|p<<o|0)|0;p=b+12|0;m=c[p>>2]|0;x=f;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;r=31-k+o|0;s=j}c[i>>2]=s;c[l>>2]=r;return}if((h|0)==0){r=b|0;l=c[r>>2]|0;s=b+4|0;i=c[s>>2]|0;if((i|0)>(e|0)){t=i-e|0;u=l<<e}else{j=fe(l<<i|0)|0;l=b+12|0;o=c[l>>2]|0;x=j;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;t=32-e+i|0;u=0}c[r>>2]=u;c[s>>2]=t;if((t|0)>1){v=t-1|0;w=u<<1|1}else{i=fe(1>>>((1-t|0)>>>0)|u<<t|0)|0;u=b+12|0;l=c[u>>2]|0;x=i;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=t+31|0;w=1}c[r>>2]=w;c[s>>2]=v;return}v=e>>h;s=b|0;w=c[s>>2]|0;r=b+4|0;t=c[r>>2]|0;if((t|0)>(v|0)){y=t-v|0;z=w<<v}else{u=fe(w<<t|0)|0;w=b+12|0;l=c[w>>2]|0;x=u;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;y=32-v+t|0;z=0}c[s>>2]=z;c[r>>2]=y;if((y|0)>1){A=y-1|0;B=z<<1|1}else{t=fe(1>>>((1-y|0)>>>0)|z<<y|0)|0;z=b+12|0;v=c[z>>2]|0;x=t;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;A=y+31|0;B=1}c[s>>2]=B;c[r>>2]=A;y=(1<<h)-1&e;if((A|0)>(h|0)){C=A-h|0;D=B<<h|y}else{e=fe(y>>>((h-A|0)>>>0)|B<<A|0)|0;B=b+12|0;b=c[B>>2]|0;x=e;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;C=32-h+A|0;D=y}c[s>>2]=D;c[r>>2]=C;return}function _Sa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;g=e+60|0;h=c[g>>2]|0;j=c[e+88>>2]&262144;k=(j|0)!=0;l=j>>>18;c[e+796>>2]=10;j=ICb()|0;m=e+804|0;c[m>>2]=j;if((j|0)==0){n=-12;i=f;return n|0}c[h+19096>>2]=774;c[h+19092>>2]=k?1154768:1154480;Z3(h+19100|0,e);j=c[h+20352>>2]|0;if((j-1&j|0)!=0){yDb(e,16,2183328,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-22;i=f;return n|0}p=e+140|0;q=h+20392|0;do{if((a[(bFb(c[p>>2]|0)|0)+7|0]|0)<0){r=c[q>>2]|0;if((r&7|0)==0){s=r;break}yDb(e,16,2106272,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-22;i=f;return n|0}else{c[q>>2]=0;s=0}}while(0);q=h+20360|0;c[q>>2]=(c[p>>2]|0)==74?2:3;p=h+20408|0;r=c[p>>2]|0;t=h+20412|0;c[t>>2]=561352+(r*36|0);u=h+20380|0;c[u>>2]=(s|0)!=0?4:3;s=(c[e+120>>2]|0)+15>>4;c[h+20344>>2]=s;v=c[e+124>>2]|0;if(k){w=v+31>>5;c[h+20348>>2]=w;x=w}else{w=v+15>>4;c[h+20348>>2]=w;x=w}w=(s|0)/(j|0)|0;v=h+20364|0;y=s-(ba(w,j)|0)|0;z=y-(y>>>1&1431655765)|0;y=(z>>>2&858993459)+(z&858993459)|0;z=(y>>>4)+y&252645135;y=(z>>>8)+z|0;z=((y>>>16)+y&63)+w|0;c[v>>2]=z;w=h+20368|0;c[w>>2]=ba(z,x)|0;z=l+1|0;l=h+20372|0;c[l>>2]=z;y=c[h+20400>>2]|0;if((y|0)==-1){A=561032+(c[561384+(r*36|0)>>2]<<6)|0;c[h+19088>>2]=A;B=A}else{A=561032+(y<<6)|0;c[h+19088>>2]=A;B=A}if((SGb(c[h+20396>>2]|0)|0)!=4){yDb(e,16,2049048,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=f;return n|0}A=c[e+80>>2]|0;y=(A|0)/118|0;C=h+20388|0;c[C>>2]=y;do{if((A+117|0)>>>0>234>>>0){if((A|0)>7669){yDb(e,16,1965928,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=f;return n|0}D=h+19088|0;E=h+16912|0;F=0;G=0;H=B;I=y;while(1){J=(ba(d[H+F|0]|0,I)|0)&65535;b[E+(F<<1)>>1]=J;K=2048/(J<<16>>16|0)|0;J=K>>>0>65535>>>0;L=J?K>>>16:K;K=J?16:0;if((L&65280|0)==0){M=K;N=L}else{M=K|8;N=L>>>8}O=((d[1191992+N|0]|0)+M<<1|1)+G|0;L=F+1|0;if((L|0)>=64){break}F=L;G=O;H=c[D>>2]|0;I=c[C>>2]|0}I=O<<3;D=h+20384|0;c[D>>2]=I;if((c[q>>2]|0)==3){H=I+(O<<2)|0;c[D>>2]=H;P=H}else{P=I}I=c[u>>2]|0;if((I|0)!=4){Q=I;R=P;break}I=P+(O<<2)|0;c[D>>2]=I;Q=4;R=I}else{I=h+20384|0;D=c[I>>2]|0;do{if((D|0)==0){H=0;while(1){if((H|0)>=3){break}if((c[561536+(H<<2)>>2]|0)<(ba(ba(x,s)|0,z)|0)){H=H+1|0}else{break}}c[I>>2]=c[561368+(r*36|0)+(H<<2)>>2]}else{if((D|0)>=128){break}yDb(e,16,2003464,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=f;return n|0}}while(0);D=c[561360+(r*36|0)>>2]|0;G=c[561364+(r*36|0)>>2]|0;F=h+19088|0;E=h+16912|0;L=D;do{K=0;do{b[E+(L<<7)+(K<<1)>>1]=ba(d[(c[F>>2]|0)+K|0]|0,L)|0;K=K+1|0;}while((K|0)<64);L=L+1|0;}while((L|0)<16);L=WDb(c[w>>2]<<2)|0;c[h+20416>>2]=L;if((L|0)==0){L=c[g>>2]|0;$Db(m);F=L+20420|0;E=F;K=c[E>>2]|0;do{if((K|0)!=0){H=e+808|0;if((c[H>>2]|0)<=0){break}ZDb(c[K+17024>>2]|0);if((c[H>>2]|0)>1){S=1}else{break}do{ZDb(c[(c[E>>2]|0)+(S*17040|0)+17024>>2]|0);S=S+1|0;}while((S|0)<(c[H>>2]|0))}}while(0);$Db(F);$Db(L+20416|0);n=-12;i=f;return n|0}E=e+808|0;K=cEb((c[E>>2]|0)*17040|0)|0;H=h+20420|0;c[H>>2]=K;if((K|0)==0){K=c[g>>2]|0;$Db(m);J=K+20420|0;T=J;U=c[T>>2]|0;do{if((U|0)!=0){if((c[E>>2]|0)<=0){break}ZDb(c[U+17024>>2]|0);if((c[E>>2]|0)>1){V=1}else{break}do{ZDb(c[(c[T>>2]|0)+(V*17040|0)+17024>>2]|0);V=V+1|0;}while((V|0)<(c[E>>2]|0))}}while(0);$Db(J);$Db(K+20416|0);n=-12;i=f;return n|0}a:do{if((c[E>>2]|0)>0){T=G+2|0;b:do{if((D|0)<(T|0)){U=0;while(1){L=WDb((c[v>>2]<<8)+256|0)|0;c[(c[H>>2]|0)+(U*17040|0)+17024>>2]=L;L=c[(c[H>>2]|0)+(U*17040|0)+17024>>2]|0;if((L|0)==0){break b}else{W=D}do{c[L+(W<<4)>>2]=-1;c[L+(W<<4)+8>>2]=0;c[L+(W<<4)+12>>2]=0;W=W+1|0;}while((W|0)<(T|0));U=U+1|0;if((U|0)>=(c[E>>2]|0)){break a}}}else{U=0;while(1){L=WDb((c[v>>2]<<8)+256|0)|0;c[(c[H>>2]|0)+(U*17040|0)+17024>>2]=L;if((c[(c[H>>2]|0)+(U*17040|0)+17024>>2]|0)==0){break b}U=U+1|0;if((U|0)>=(c[E>>2]|0)){break a}}}}while(0);T=c[g>>2]|0;$Db(m);U=T+20420|0;L=U;F=c[L>>2]|0;do{if((F|0)!=0){if((c[E>>2]|0)<=0){break}ZDb(c[F+17024>>2]|0);if((c[E>>2]|0)>1){X=1}else{break}do{ZDb(c[(c[L>>2]|0)+(X*17040|0)+17024>>2]|0);X=X+1|0;}while((X|0)<(c[E>>2]|0))}}while(0);$Db(U);$Db(T+20416|0);n=-12;i=f;return n|0}}while(0);Q=c[u>>2]|0;R=c[I>>2]|0}}while(0);u=h+20404|0;c[u>>2]=(ba(ba(c[w>>2]|0,c[l>>2]|0)|0,(Q<<1)+2+((ba(R,j)|0)/8|0)|0)|0)+200;c[e+52>>2]=c[(c[t>>2]|0)+4>>2];t=e;e=ba(c[l>>2]|0,c[w>>2]|0)|0;w=c[h+20384>>2]|0;yDb(t,48,1937896,(o=i,i=i+32|0,c[o>>2]=c[p>>2],c[o+8>>2]=e,c[o+16>>2]=k?1913888:1893336,c[o+24>>2]=w,o)|0);i=o;yDb(t,48,2350952,(o=i,i=i+8|0,c[o>>2]=c[u>>2],o)|0);i=o;n=0;i=f;return n|0}function $Sa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0;k=i;i=i+40|0;l=k|0;m=k+24|0;n=f+60|0;o=c[n>>2]|0;TGb(m|0,0,16)|0;p=o+20380|0;q=c[p>>2]|0;r=q<<1;s=f+804|0;UGb(c[s>>2]|0,h|0,472)|0;t=c[s>>2]|0;c[t+88>>2]=1;c[t+84>>2]=1;t=(c[o+20404>>2]|0)+16384|0;s=r0a(f,g,t,(t|0)<0|0?-1:0)|0;if((s|0)<0){u=s;i=k;return u|0}s=c[g+24>>2]|0;v=s+4|0;x=1718641513;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;v=s+8|0;w=s+10|0;x=0;a[w]=x;x=x>>8;a[w+1|0]=x;w=c[o+20396>>2]|0;y=s+12|0;x=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;y=f+120|0;w=s+16|0;x=de(c[y>>2]&65535|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;w=f+124|0;z=s+18|0;x=de(c[w>>2]&65535|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x;z=c[o+20360>>2]<<6;if((c[f+88>>2]&262144|0)==0){A=z&255}else{A=(((c[h+300>>2]|0)!=0?4:8)|z)&255}a[s+20|0]=A;a[s+21|0]=0;a[s+22|0]=c[f+384>>2];a[s+23|0]=c[f+388>>2];a[s+24|0]=c[f+392>>2];a[s+25|0]=(c[o+20392>>2]|0)>>>3|64;a[s+26|0]=0;A=s+27|0;if((c[o+20400>>2]|0)==4){a[A]=0;B=s+28|0}else{a[A]=3;A=o+19088|0;z=s+28|0;C=0;while(1){a[z]=a[(c[A>>2]|0)+C|0]|0;D=C+1|0;if((D|0)<64){z=z+1|0;C=D}else{break}}C=s+92|0;z=0;while(1){a[C]=a[(c[A>>2]|0)+z|0]|0;D=z+1|0;if((D|0)<64){C=C+1|0;z=D}else{break}}B=s+156|0}z=v;C=v;x=de(B-z&65535|0)|0;a[C]=x;x=x>>8;a[C+1|0]=x;C=o+20376|0;c[C>>2]=0;v=o+20372|0;a:do{if((c[v>>2]|0)>0){A=o+20368|0;D=o+20352|0;E=o+20388|0;F=f+828|0;G=o+20348|0;H=o+20344|0;I=o+20364|0;J=o+20416|0;K=q<<4&255;L=z+t|0;M=l+20|0;N=l+8|0;O=l+16|0;P=l+12|0;Q=l+4|0;R=l|0;S=d[1154468]|0;T=d[1154650]|0;U=h+300|0;V=B;while(1){W=V+1|0;a[V]=64;X=V+5|0;x=de(c[A>>2]&65535|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;X=c[D>>2]|0;Y=X>>>0>65535>>>0;Z=Y?X>>>16:X;X=Y?16:0;if((Z&65280|0)==0){_=X;$=Z}else{_=X|8;$=Z>>>8}a[V+7|0]=(d[1191992+$|0]|0)+_<<4;Z=V+8|0;X=V+((c[A>>2]<<1)+8)|0;if((c[E>>2]|0)==0){Y=Pe[c[F>>2]&255](f,588,0,0,c[G>>2]|0)|0;if((Y|0)!=0){u=Y;break}}Y=c[G>>2]|0;if((Y|0)>0){aa=X;ca=Z;Z=0;da=c[H>>2]|0;ea=Y;while(1){if((da|0)>0){Y=Z<<4;fa=aa;ga=ca;ha=0;ia=0;ja=c[D>>2]|0;ka=da;while(1){la=c[E>>2]|0;if((la|0)==0){ma=(ba(c[I>>2]|0,Z)|0)+ha|0;na=c[(c[J>>2]|0)+(ma<<2)>>2]|0}else{na=la}la=ka-ia|0;ma=ja;while(1){if((la|0)<(ma|0)){ma=ma>>1}else{break}}a[fa]=K;la=fa+1|0;oa=fa+r|0;pa=L-oa<<3;qa=(pa|0)<0;ra=qa?0:oa;oa=qa?0:pa;c[M>>2]=oa<<3;c[N>>2]=ra;c[O>>2]=ra+oa;c[P>>2]=ra;c[Q>>2]=32;c[R>>2]=0;oa=c[n>>2]|0;pa=oa;qa=oa+20372|0;if((c[qa>>2]|0)==1){sa=0}else{sa=(c[U>>2]|0)==0^c[oa+20376>>2]}do{if((c[oa+20388>>2]|0)==0){if((na|0)<16){ta=oa+16912+(na<<7)|0;break}ua=oa+18960|0;va=oa+19088|0;wa=0;while(1){b[ua+(wa<<1)>>1]=ba(d[(c[va>>2]|0)+wa|0]|0,na)|0;xa=wa+1|0;if((xa|0)<64){wa=xa}else{ta=ua;break}}}else{ta=oa+16912|0}}while(0);ua=oa+20380|0;if((c[ua>>2]|0)>0){wa=oa+20360|0;va=ia<<3;xa=ia<<4;ya=oa+16|0;za=oa+16400|0;Aa=oa+19092|0;Ba=oa+20392|0;Ca=ma<<8;Da=0;Ea=ra;Fa=ra;while(1){Ga=(Da-1|0)>>>0<2>>>0;Ha=Ga&1;do{if(Ga){if((c[wa>>2]|0)==3){Ia=37;break}Ja=va;Ka=c[y>>2]>>1;La=2}else{Ia=37}}while(0);if((Ia|0)==37){Ia=0;Ja=xa;Ka=c[y>>2]|0;La=4}Ga=c[h+32+(Da<<2)>>2]|0;Ma=c[qa>>2]|0;Na=ba(Ma,Ga)|0;Oa=(c[h+(Da<<2)>>2]|0)+((ba(Na,Y)|0)+(ba(Ga,sa)|0))+(Ja<<1)|0;Ga=(c[w>>2]|0)/(Ma|0)|0;if((Da|0)<3){cTa(pa,Oa,Na,Ja,Y,Ka,Ga,ya,za,ma,La,Ha);Ma=Fa;Pa=Ea;Qa=ba(La,ma)|0;Ra=b[ta>>1]|0;Sa=((b[ya>>1]|0)-16384|0)/(Ra|0)|0;fTa(l,184,Sa<<1^Sa>>31);if((Qa|0)>1){Ta=3;Ua=Sa;Sa=1;Va=0;Wa=ya;while(1){Xa=Wa+128|0;Ya=((b[Xa>>1]|0)-16384|0)/(Ra|0)|0;Za=Ya-Ua|0;_a=(Za^Va)-Va|0;$a=_a<<1^_a>>31;fTa(l,d[1155040+Ta|0]|0,$a);_a=($a&1)+$a>>1;$a=Sa+1|0;if(($a|0)<(Qa|0)){Ta=(_a|0)>3?3:_a;Ua=Ya;Sa=$a;Va=Za>>31;Wa=Xa}else{break}}}Wa=c[Aa>>2]|0;Va=Qa<<6;Sa=0;Ua=S;Ta=T;Ra=1;while(1){Ha=Wa+Ra|0;Xa=a[Ha]|0;Za=Xa&255;b:do{if((Za|0)<(Va|0)){$a=Sa;Ya=Ua;_a=Ta;ab=Za;bb=Xa;while(1){cb=(b[ya+(ab<<1)>>1]|0)/(b[ta+((bb&255)<<1)>>1]|0)|0;if((cb|0)==0){db=_a;eb=Ya;fb=$a+1|0}else{gb=(cb|0)>-1?cb:-cb|0;fTa(l,d[1155152+Ya|0]|0,$a);fTa(l,d[1155152+_a|0]|0,gb-1|0);hb=cb>>>31;cb=c[R>>2]|0;ib=c[Q>>2]|0;if((ib|0)>1){jb=ib-1|0;kb=cb<<1|hb}else{lb=fe(hb>>>((1-ib|0)>>>0)|cb<<ib|0)|0;cb=c[P>>2]|0;mb=cb;x=lb;a[mb]=x;x=x>>8;a[mb+1|0]=x;x=x>>8;a[mb+2|0]=x;x=x>>8;a[mb+3|0]=x;c[P>>2]=cb+4;jb=ib+31|0;kb=hb}c[R>>2]=kb;c[Q>>2]=jb;db=d[1154648+((gb|0)>9?9:gb)|0]|0;eb=d[1154464+(($a|0)>15?15:$a)|0]|0;fb=0}gb=ab+64|0;if((gb|0)>=(Va|0)){nb=fb;ob=eb;pb=db;break b}$a=fb;Ya=eb;_a=db;ab=gb;bb=a[Ha]|0}}else{nb=Sa;ob=Ua;pb=Ta}}while(0);Ha=Ra+1|0;if((Ha|0)<64){Sa=nb;Ua=ob;Ta=pb;Ra=Ha}else{break}}Ra=c[Q>>2]|0;if((Ra|0)<32){Ta=c[R>>2]<<Ra;c[R>>2]=Ta;Ua=c[P>>2]|0;Sa=Ra+8|0;Va=(((Sa|0)>32?Ra+7|0:31)-Ra|0)>>>3;Wa=Va<<3;Qa=Ta>>>24&255;Ha=Ua;Xa=Ta;Ta=Ra;while(1){a[Ha]=Qa;qb=Xa<<8;Ra=Ta+8|0;if((Ra|0)<32){Qa=Xa>>>16&255;Ha=Ha+1|0;Xa=qb;Ta=Ra}else{break}}Ta=Ua+(Va+1)|0;c[P>>2]=Ta;c[R>>2]=qb;c[Q>>2]=Sa+Wa;rb=Ta}else{rb=c[P>>2]|0}c[Q>>2]=32;c[R>>2]=0;Ta=c[N>>2]|0;c[m+(Da<<2)>>2]=Pa-Ma-Ta+rb<<3>>3;sb=Ta;tb=rb}else{dTa(Oa,Na,Ja,Y,Ka,Ga,ya,ma,c[Ba>>2]|0);Ta=c[Ba>>2]|0;Xa=e[ya>>1]|0;eTa(l,Xa,(1<<Ta)-1|0,Ta);Ha=0;Qa=1;Ra=Xa;while(1){Xa=Qa+1|0;Za=e[ya+(Qa<<1)>>1]|0;if((Za|0)==(Ra|0)){ub=Ha+1|0;vb=Ra}else{bb=c[R>>2]|0;ab=c[Q>>2]|0;_a=(ab|0)>1;do{if((Ha|0)==0){if(_a){wb=ab-1|0;xb=bb<<1|1}else{Ya=fe(1>>>((1-ab|0)>>>0)|bb<<ab|0)|0;$a=c[P>>2]|0;gb=$a;x=Ya;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;c[P>>2]=$a+4;wb=ab+31|0;xb=1}c[R>>2]=xb;c[Q>>2]=wb}else{if(_a){yb=ab-1|0;zb=bb<<1}else{$a=fe(bb<<ab|0)|0;gb=c[P>>2]|0;Ya=gb;x=$a;a[Ya]=x;x=x>>8;a[Ya+1|0]=x;x=x>>8;a[Ya+2|0]=x;x=x>>8;a[Ya+3|0]=x;c[P>>2]=gb+4;yb=ab+31|0;zb=0}c[R>>2]=zb;c[Q>>2]=yb;if((Ha|0)<16){if((yb|0)>4){Ab=yb-4|0;Bb=zb<<4|Ha}else{gb=fe(Ha>>>((4-yb|0)>>>0)|zb<<yb|0)|0;Ya=c[P>>2]|0;$a=Ya;x=gb;a[$a]=x;x=x>>8;a[$a+1|0]=x;x=x>>8;a[$a+2|0]=x;x=x>>8;a[$a+3|0]=x;c[P>>2]=Ya+4;Ab=yb+28|0;Bb=Ha}c[R>>2]=Bb;c[Q>>2]=Ab;break}else{if((yb|0)>15){Cb=yb-15|0;Db=zb<<15|Ha}else{Ya=fe(Ha>>>((15-yb|0)>>>0)|zb<<yb|0)|0;$a=c[P>>2]|0;gb=$a;x=Ya;a[gb]=x;x=x>>8;a[gb+1|0]=x;x=x>>8;a[gb+2|0]=x;x=x>>8;a[gb+3|0]=x;c[P>>2]=$a+4;Cb=yb+17|0;Db=Ha}c[R>>2]=Db;c[Q>>2]=Cb;break}}}while(0);eTa(l,Za,Ra,Ta);ub=0;vb=Za}if((Xa|0)<(Ca|0)){Ha=ub;Qa=Xa;Ra=vb}else{break}}Ra=Fa;Qa=Ea;do{if((ub|0)==0){Eb=c[Q>>2]|0}else{Ha=c[R>>2]|0;Ta=c[Q>>2]|0;if((Ta|0)>1){Fb=Ta-1|0;Gb=Ha<<1}else{Ga=fe(Ha<<Ta|0)|0;Ha=c[P>>2]|0;Na=Ha;x=Ga;a[Na]=x;x=x>>8;a[Na+1|0]=x;x=x>>8;a[Na+2|0]=x;x=x>>8;a[Na+3|0]=x;c[P>>2]=Ha+4;Fb=Ta+31|0;Gb=0}c[R>>2]=Gb;c[Q>>2]=Fb;if((ub|0)<16){if((Fb|0)>4){Hb=Fb-4|0;Ib=Gb<<4|ub}else{Ta=fe(ub>>>((4-Fb|0)>>>0)|Gb<<Fb|0)|0;Ha=c[P>>2]|0;Na=Ha;x=Ta;a[Na]=x;x=x>>8;a[Na+1|0]=x;x=x>>8;a[Na+2|0]=x;x=x>>8;a[Na+3|0]=x;c[P>>2]=Ha+4;Hb=Fb+28|0;Ib=ub}c[R>>2]=Ib;c[Q>>2]=Hb;Eb=Hb;break}else{if((Fb|0)>15){Jb=Fb-15|0;Kb=Gb<<15|ub}else{Ha=fe(ub>>>((15-Fb|0)>>>0)|Gb<<Fb|0)|0;Na=c[P>>2]|0;Ta=Na;x=Ha;a[Ta]=x;x=x>>8;a[Ta+1|0]=x;x=x>>8;a[Ta+2|0]=x;x=x>>8;a[Ta+3|0]=x;c[P>>2]=Na+4;Jb=Fb+17|0;Kb=ub}c[R>>2]=Kb;c[Q>>2]=Jb;Eb=Jb;break}}}while(0);if((Eb|0)<32){Na=c[R>>2]<<Eb;c[R>>2]=Na;Ta=c[P>>2]|0;Ha=Eb+8|0;Ga=(((Ha|0)>32?Eb+7|0:31)-Eb|0)>>>3;Oa=Ga<<3;Ma=Na>>>24&255;Pa=Ta;Wa=Na;Na=Eb;while(1){a[Pa]=Ma;Lb=Wa<<8;Sa=Na+8|0;if((Sa|0)<32){Ma=Wa>>>16&255;Pa=Pa+1|0;Wa=Lb;Na=Sa}else{break}}Na=Ta+(Ga+1)|0;c[P>>2]=Na;c[R>>2]=Lb;c[Q>>2]=Ha+Oa;Mb=Na}else{Mb=c[P>>2]|0}c[Q>>2]=32;c[R>>2]=0;Na=c[N>>2]|0;c[m+(Da<<2)>>2]=Qa-Ra-Na+Mb<<3>>3;sb=Na;tb=Mb}Na=Da+1|0;if((Na|0)<(c[ua>>2]|0)){Da=Na;Ea=sb;Fa=tb}else{break}}}a[la]=na;Fa=(c[p>>2]|0)-1|0;Ea=(c[m+(Fa<<2)>>2]|0)+r|0;if((Fa|0)>0){Fa=0;Da=Ea;ua=fa;while(1){Ca=ua+2|0;ya=m+(Fa<<2)|0;Ba=Ca;x=de(c[ya>>2]&65535|0)|0;a[Ba]=x;x=x>>8;a[Ba+1|0]=x;Ba=(c[ya>>2]|0)+Da|0;ya=Fa+1|0;if((ya|0)<((c[p>>2]|0)-1|0)){Fa=ya;Da=Ba;ua=Ca}else{Nb=Ba;break}}}else{Nb=Ea}ua=ga;x=de(Nb&65535|0)|0;a[ua]=x;x=x>>8;a[ua+1|0]=x;Ob=ga+2|0;Pb=fa+Nb|0;ua=ma+ia|0;Qb=c[H>>2]|0;if((ua|0)>=(Qb|0)){break}fa=Pb;ga=Ob;ha=ha+1|0;ia=ua;ja=ma;ka=Qb}Rb=Pb;Sb=Ob;Tb=Qb;Ub=c[G>>2]|0}else{Rb=aa;Sb=ca;Tb=da;Ub=ea}ka=Z+1|0;if((ka|0)<(Ub|0)){aa=Rb;ca=Sb;Z=ka;da=Tb;ea=Ub}else{Vb=Rb;break}}}else{Vb=X}ea=W;x=fe(Vb-V|0)|0;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;ea=(c[C>>2]|0)+1|0;c[C>>2]=ea;if((ea|0)<(c[v>>2]|0)){V=Vb}else{Wb=Vb;break a}}i=k;return u|0}else{Wb=B}}while(0);B=Wb-s|0;Wb=s;x=fe(B|0)|0;a[Wb]=x;x=x>>8;a[Wb+1|0]=x;x=x>>8;a[Wb+2|0]=x;x=x>>8;a[Wb+3|0]=x;c[g+28>>2]=B;B=g+36|0;c[B>>2]=c[B>>2]|1;c[j>>2]=1;u=0;i=k;return u|0}function aTa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+60>>2]|0;$Db(a+804|0);d=b+20420|0;e=d;f=c[e>>2]|0;a:do{if((f|0)!=0){g=a+808|0;if((c[g>>2]|0)>0){h=0;i=f}else{break}while(1){ZDb(c[i+(h*17040|0)+17024>>2]|0);j=h+1|0;if((j|0)>=(c[g>>2]|0)){break a}h=j;i=c[e>>2]|0}}}while(0);$Db(d);$Db(b+20416|0);return 0}function bTa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;e=i;i=i+168|0;h=e|0;j=e+16|0;k=e+32|0;l=e+40|0;m=e+104|0;n=a+60|0;o=c[n>>2]|0;p=c[o+20420>>2]|0;q=p+(g*17040|0)|0;r=o+20344|0;s=c[r>>2]|0;if((s|0)>0){t=a+804|0;u=a+120|0;v=f<<4;w=a+124|0;a=p+(g*17040|0)+16384|0;x=j+4|0;y=p+(g*17040|0)+17024|0;z=p+(g*17040|0)+12288|0;A=p+(g*17040|0)+16896|0;B=0;C=c[o+20352>>2]|0;D=0;E=s;while(1){s=E-B|0;F=C;while(1){if((s|0)<(F|0)){F=F>>1}else{break}}s=c[t>>2]|0;G=D+1|0;H=G<<4;I=c[n>>2]|0;J=I;K=c[I+20412>>2]|0;L=c[K+8>>2]|0;M=c[K+12>>2]|0;K=I+20372|0;if((c[K>>2]|0)==1){N=0}else{N=(c[s+300>>2]|0)==0^c[I+20376>>2]}O=F+B|0;P=I+20380|0;if((c[P>>2]|0)>0){Q=I+20360|0;R=B<<3;S=B<<4;T=I+20392|0;U=0;do{if((U|0)==1){c[x>>2]=1;V=x;W=15}else{X=(U|0)==2;Y=j+(U<<2)|0;c[Y>>2]=X&1;if(X){V=Y;W=15}else{Z=Y;W=16}}do{if((W|0)==15){W=0;if((c[Q>>2]|0)==3){Z=V;W=16;break}c[h+(U<<2)>>2]=2;_=R;$=c[u>>2]>>1;aa=V;ca=2}}while(0);if((W|0)==16){W=0;c[h+(U<<2)>>2]=4;_=S;$=c[u>>2]|0;aa=Z;ca=4}Y=c[s+32+(U<<2)>>2]|0;X=c[K>>2]|0;da=ba(X,Y)|0;ea=(c[s+(U<<2)>>2]|0)+((ba(da,v)|0)+(ba(Y,N)|0))+(_<<1)|0;Y=(c[w>>2]|0)/(X|0)|0;X=p+(g*17040|0)+(U<<12)|0;if((U|0)<3){cTa(J,ea,da,_,v,$,Y,X,a,F,ca,c[aa>>2]|0)}else{dTa(ea,da,_,v,$,Y,X,F,c[T>>2]|0)}U=U+1|0;}while((U|0)<(c[P>>2]|0))}U=M+2|0;T=(L|0)<(U|0);if(T){s=c[y>>2]|0;K=L;do{S=K+H|0;c[s+(S<<4)>>2]=-1;c[s+(S<<4)+4>>2]=K;K=K+1|0;}while((K|0)<(U|0))}a:do{if((L|0)>(M|0)){fa=0}else{K=I+20392|0;s=F<<8;S=I+16912|0;R=L;Q=c[P>>2]|0;X=c[K>>2]|0;while(1){c[k>>2]=0;Y=(X|0)!=0;if((Q-(Y&1)|0)>0){da=S+(R<<7)|0;ea=0;ga=0;while(1){ha=(gTa(J,k,ga,F,c[h+(ga<<2)>>2]|0,da,q)|0)+ea|0;ia=ga+1|0;ja=c[P>>2]|0;ka=c[K>>2]|0;la=(ka|0)!=0;if((ia|0)<(ja-(la&1)|0)){ea=ha;ga=ia}else{ma=ha;na=la;oa=ja;pa=ka;break}}}else{ma=0;na=Y;oa=Q;pa=X}if(na){ga=1<<pa;ea=ga-1|0;c[k>>2]=0;da=b[z>>1]|0;ka=(pa|0)==8?4:7;ja=1<<ka-1;la=da-ea&ea;ha=ga-ja|0;ia=(la|0)<(ha|0)?0:ga;qa=la-ia|0;ra=-ja|0;if((qa|0)<(ra|0)){sa=pa}else{sa=(qa|0)<=(ja|0)&(la|0)!=(ia|0)?ka:pa}ia=sa+1|0;la=0;qa=1;ta=da;while(1){da=qa+1|0;ua=b[p+(g*17040|0)+12288+(qa<<1)>>1]|0;if((ua|0)==(ta|0)){va=ia;wa=la+1|0;xa=ta}else{do{if((la|0)==0){ya=ia+1|0}else{if((la|0)<16){ya=ia+4|0;break}else{ya=ia+15|0;break}}}while(0);za=ua-ta&ea;Aa=(za|0)<(ha|0)?0:ga;Ba=za-Aa|0;if((Ba|0)<(ra|0)){Ca=pa}else{Ca=(Ba|0)<=(ja|0)&(za|0)!=(Aa|0)?ka:pa}va=ya+1+Ca|0;wa=0;xa=ua}if((da|0)<(s|0)){ia=va;la=wa;qa=da;ta=xa}else{break}}do{if((wa|0)==0){Da=va}else{if((wa|0)<16){Da=va+4|0;break}else{Da=va+15|0;break}}}while(0);Ea=Da+ma|0}else{Ea=ma}if((Ea|0)>52e4){break}c[l+(R<<2)>>2]=Ea;c[m+(R<<2)>>2]=c[k>>2];ta=R+1|0;if((ta|0)>(M|0)){fa=Ea;break a}else{R=ta;Q=oa;X=pa}}c[k>>2]=1073741823;fa=Ea}}while(0);X=c[l+(M<<2)>>2]|0;Q=I+20384|0;R=M+1|0;if((X|0)>(ba(c[Q>>2]|0,F)|0)){s=I+16912|0;K=I+20392|0;S=F<<8;ta=I+19088|0;qa=R;la=fa;while(1){if((qa|0)>=128){Fa=la;break}c[k>>2]=0;if((qa|0)<16){Ga=s+(qa<<7)|0}else{ia=c[ta>>2]|0;ka=0;while(1){b[p+(g*17040|0)+16896+(ka<<1)>>1]=ba(d[ia+ka|0]|0,qa)|0;ja=ka+1|0;if((ja|0)<64){ka=ja}else{Ga=A;break}}}ka=c[K>>2]|0;ia=(ka|0)!=0;if(((c[P>>2]|0)-(ia&1)|0)>0){ja=0;ra=0;while(1){ga=(gTa(J,k,ra,F,c[h+(ra<<2)>>2]|0,Ga,q)|0)+ja|0;ha=ra+1|0;ea=c[K>>2]|0;Y=(ea|0)!=0;if((ha|0)<((c[P>>2]|0)-(Y&1)|0)){ja=ga;ra=ha}else{Ha=ga;Ia=Y;Ja=ea;break}}}else{Ha=0;Ia=ia;Ja=ka}if(Ia){ra=1<<Ja;ja=ra-1|0;c[k>>2]=0;ea=b[z>>1]|0;Y=(Ja|0)==8?4:7;ga=1<<Y-1;ha=ea-ja&ja;Aa=ra-ga|0;za=(ha|0)<(Aa|0)?0:ra;Ba=ha-za|0;Ka=-ga|0;if((Ba|0)<(Ka|0)){La=Ja}else{La=(Ba|0)<=(ga|0)&(ha|0)!=(za|0)?Y:Ja}za=La+1|0;ha=0;Ba=1;Ma=ea;while(1){ea=Ba+1|0;Na=b[p+(g*17040|0)+12288+(Ba<<1)>>1]|0;if((Na|0)==(Ma|0)){Oa=za;Pa=ha+1|0;Qa=Ma}else{do{if((ha|0)==0){Ra=za+1|0}else{if((ha|0)<16){Ra=za+4|0;break}else{Ra=za+15|0;break}}}while(0);Sa=Na-Ma&ja;Ta=(Sa|0)<(Aa|0)?0:ra;Ua=Sa-Ta|0;if((Ua|0)<(Ka|0)){Va=Ja}else{Va=(Ua|0)<=(ga|0)&(Sa|0)!=(Ta|0)?Y:Ja}Oa=Ra+1+Va|0;Pa=0;Qa=Na}if((ea|0)<(S|0)){za=Oa;ha=Pa;Ba=ea;Ma=Qa}else{break}}do{if((Pa|0)==0){Wa=Oa}else{if((Pa|0)<16){Wa=Oa+4|0;break}else{Wa=Oa+15|0;break}}}while(0);Xa=Wa+Ha|0}else{Xa=Ha}if((Xa|0)>(ba(c[Q>>2]|0,F)|0)){qa=qa+1|0;la=Xa}else{Fa=Xa;break}}c[l+(R<<2)>>2]=Fa;c[m+(R<<2)>>2]=c[k>>2];Ya=qa}else{c[l+(R<<2)>>2]=X;c[m+(R<<2)>>2]=(c[m+(M<<2)>>2]|0)+1;Ya=M}la=c[y>>2]|0;c[la+(M+(H|1)<<4)+4>>2]=Ya;S=ba(c[Q>>2]|0,O)|0;if(T){P=H-16|0;K=L;do{J=P+K|0;ta=la+(J<<4)+8|0;s=la+(J<<4)+12|0;I=L;do{Ma=I+H|0;Ba=(c[l+(I<<2)>>2]|0)+(c[ta>>2]|0)|0;Za=(Ba|0)>(S|0)?1073741823:c[m+(I<<2)>>2]|0;ha=c[s>>2]|0;if((ha|0)<1073741823){_a=(Za|0)<1073741823?Za+ha|0:1073741823}else{_a=1073741823}ha=la+(Ma<<4)|0;za=la+(Ma<<4)+12|0;if((c[ha>>2]|0)==-1){W=90}else{if((c[za>>2]|0)>=(_a|0)){W=90}}if((W|0)==90){W=0;c[la+(Ma<<4)+8>>2]=Ba;c[za>>2]=_a;c[ha>>2]=J}I=I+1|0;}while((I|0)<(U|0));K=K+1|0;}while((K|0)<(U|0));c[k>>2]=Za}K=L+H|0;S=L;P=K;T=c[la+(K<<4)+12>>2]|0;b:while(1){K=S;while(1){Q=K+1|0;if((Q|0)>=(U|0)){break b}M=Q+H|0;R=c[la+(M<<4)+12>>2]|0;if((R|0)>(T|0)){K=Q}else{S=Q;P=M;T=R;continue b}}}c[k>>2]=T;S=c[r>>2]|0;if((O|0)<(S|0)){B=O;C=F;D=G;E=S}else{$a=P;break}}}else{$a=0}E=o+20364|0;D=c[E>>2]|0;if((D|0)<=0){i=e;return 0}C=c[p+(g*17040|0)+17024>>2]|0;g=c[o+20416>>2]|0;o=$a;$a=D;p=D;while(1){D=$a-1|0;c[g+((ba(p,f)|0)+D<<2)>>2]=c[C+(o<<4)+4>>2];if((D|0)<=0){break}o=c[C+(o<<4)>>2]|0;$a=D;p=c[E>>2]|0}i=e;return 0}function cTa(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;o=m<<2;if((l|0)<=0){return}p=i-g|0;q=(p|0)>16?16:p;p=(q|0)>0;r=k+((q<<4)-16<<1)|0;s=m<<3;t=(n|0)==0;n=a+19096|0;u=a+19100|0;a=(m|0)>2;v=(g+16|0)>(i|0);w=g-1-i|0;i=(w|0)>-17?~w:16;w=0;g=j;j=f;f=d;while(1){if((j|0)>=(h|0)){break}d=j+o|0;do{if((d|0)>(h|0)|v){x=h-j|0;y=(x|0)>(o|0)?o:x;if(p){x=f;z=y<<1;A=y-1|0;if((y|0)<(o|0)){B=0;do{C=B<<4;UGb(k+(C<<1)|0,x+(ba(B,e)|0)|0,z)|0;D=b[k+(A+C<<1)>>1]|0;E=y;do{b[k+(E+C<<1)>>1]=D;E=E+1|0;}while((E|0)<(o|0));B=B+1|0;}while((B|0)<(q|0))}else{B=0;do{UGb(k+(B<<4<<1)|0,x+(ba(B,e)|0)|0,z)|0;B=B+1|0;}while((B|0)<(q|0))}if((i|0)<16){F=i}else{G=32;H=k;break}}else{F=0}while(1){UGb(k+(F<<4<<1)|0,r|0,s)|0;B=F+1|0;if((B|0)<16){F=B}else{G=32;H=k;break}}}else{G=e;H=f}}while(0);cf[c[n>>2]&1023](u,H,G,g);B=g+128|0;do{if(t){if(a){cf[c[n>>2]&1023](u,H+16|0,G,B);I=g+256|0}else{I=B}z=G<<2;cf[c[n>>2]&1023](u,H+(z<<1)|0,G,I);x=I+128|0;if(!a){J=x;break}cf[c[n>>2]&1023](u,H+(z+8<<1)|0,G,x);J=I+256|0}else{x=G<<2;cf[c[n>>2]&1023](u,H+(x<<1)|0,G,B);z=g+256|0;if(!a){J=z;break}cf[c[n>>2]&1023](u,H+16|0,G,z);cf[c[n>>2]&1023](u,H+(x+8<<1)|0,G,g+384|0);J=g+512|0}}while(0);B=w+1|0;if((B|0)<(l|0)){w=B;g=J;j=d;f=f+(o<<1)|0}else{K=22;break}}if((K|0)==22){return}TGb(g|0,0,ba(m<<7,l-w|0)|0)|0;return}function dTa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=h;l=i<<4;m=f-d|0;d=(m|0)>(l|0)?l:m;m=g-e|0;f=(m|0)>16?16:m;do{if((f|0)>0){m=d<<1;n=(d|0)>0;o=(d|0)<(l|0);p=c>>1;q=d-1|0;r=e-1-g|0;s=(r|0)>-17;t=s?r:-17;if((j|0)==8){r=0;u=h;v=a;while(1){UGb(u|0,v|0,m)|0;if(n){w=0;do{x=u+(w<<1)|0;b[x>>1]=(b[x>>1]|0)>>>2;w=w+1|0;}while((w|0)<(d|0))}if(o){w=u+(q<<1)|0;x=d;do{b[u+(x<<1)>>1]=b[w>>1]|0;x=x+1|0;}while((x|0)<(l|0))}x=r+1|0;if((x|0)<(f|0)){r=x;u=u+(l<<1)|0;v=v+(p<<1)|0}else{break}}}else{v=0;u=h;r=a;while(1){UGb(u|0,r|0,m)|0;if(n){x=0;do{w=u+(x<<1)|0;y=b[w>>1]|0;b[w>>1]=y<<6|y>>>4;x=x+1|0;}while((x|0)<(d|0))}if(o){x=u+(q<<1)|0;y=d;do{b[u+(y<<1)>>1]=b[x>>1]|0;y=y+1|0;}while((y|0)<(l|0))}y=v+1|0;if((y|0)<(f|0)){v=y;u=u+(l<<1)|0;r=r+(p<<1)|0}else{break}}}p=k+(ba(-32-(t<<5)|0,i)|0)|0;if(s){z=p;A=~t;break}return}else{z=h;A=0}}while(0);h=-l|0;k=i<<5;i=A;A=z;while(1){UGb(A|0,A+(h<<1)|0,k)|0;z=i+1|0;if((z|0)<16){i=z;A=A+(l<<1)|0}else{break}}return}function eTa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;g=1<<f;h=(f|0)==8?3:6;i=1<<h;j=g-1&d-e;e=(j|0)<(g-i|0)?0:g;g=j-e|0;do{if((g|0)>=(-i|0)){if(!((g|0)<=(i|0)&(j|0)!=(e|0))){break}d=b|0;k=c[d>>2]|0;l=b+4|0;m=c[l>>2]|0;if((m|0)>1){n=m-1|0;o=k<<1}else{p=fe(k<<m|0)|0;k=b+12|0;q=c[k>>2]|0;x=p;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;n=m+31|0;o=0}c[d>>2]=o;c[l>>2]=n;m=((g|0)>-1?g:-g|0)-1|0;if((n|0)>(h|0)){r=n-h|0;s=o<<h|m}else{k=fe(m>>>((h-n|0)>>>0)|o<<n|0)|0;q=b+12|0;p=c[q>>2]|0;x=k;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;r=32-h+n|0;s=m}c[d>>2]=s;c[l>>2]=r;m=g>>>31;if((r|0)>1){t=r-1|0;u=s<<1|m}else{q=fe(m>>>((1-r|0)>>>0)|s<<r|0)|0;p=b+12|0;k=c[p>>2]|0;x=q;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;t=r+31|0;u=m}c[d>>2]=u;c[l>>2]=t;return}}while(0);t=b|0;u=c[t>>2]|0;r=b+4|0;s=c[r>>2]|0;if((s|0)>1){v=s-1|0;w=u<<1|1}else{n=fe(1>>>((1-s|0)>>>0)|u<<s|0)|0;u=b+12|0;h=c[u>>2]|0;x=n;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=s+31|0;w=1}c[t>>2]=w;c[r>>2]=v;if((v|0)>(f|0)){y=v-f|0;z=w<<f|g}else{s=fe(g>>>((f-v|0)>>>0)|w<<v|0)|0;w=b+12|0;b=c[w>>2]|0;x=s;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;y=32-f+v|0;z=g}c[t>>2]=z;c[r>>2]=y;return}function fTa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;g=(e&3)+1|0;h=e>>>5;i=e>>>2&7;e=g<<h;if(!(e>>>0>f>>>0)){j=(1<<i)-e+f|0;e=j>>>0>65535>>>0;k=e?j>>>16:j;l=e?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=(d[1191992+n|0]|0)+m|0;m=k-i+g|0;g=b|0;i=c[g>>2]|0;n=b+4|0;l=c[n>>2]|0;if((l|0)>(m|0)){o=l;p=i<<m}else{e=fe(i<<l|0)|0;i=b+12|0;q=c[i>>2]|0;x=e;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;o=l+32|0;p=0}l=o-m|0;c[g>>2]=p;c[n>>2]=l;m=k+1|0;if((l|0)>(m|0)){r=l-m|0;s=p<<m|j}else{o=fe(j>>>((m-l|0)>>>0)|p<<l|0)|0;p=b+12|0;m=c[p>>2]|0;x=o;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;r=31-k+l|0;s=j}c[g>>2]=s;c[n>>2]=r;return}r=f>>h;n=b|0;s=c[n>>2]|0;g=b+4|0;j=c[g>>2]|0;if((r|0)==0){t=s;u=j}else{if((j|0)>(r|0)){v=j-r|0;w=s<<r}else{l=fe(s<<j|0)|0;s=b+12|0;k=c[s>>2]|0;x=l;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;v=32-r+j|0;w=0}c[n>>2]=w;c[g>>2]=v;t=w;u=v}v=b|0;w=b+4|0;if((u|0)>1){y=u-1|0;z=t<<1|1}else{g=fe(1>>>((1-u|0)>>>0)|t<<u|0)|0;t=b+12|0;n=c[t>>2]|0;x=g;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;y=u+31|0;z=1}c[v>>2]=z;c[w>>2]=y;if((h|0)==0){return}u=(1<<h)-1&f;if((y|0)>(h|0)){A=y-h|0;B=z<<h|u}else{f=fe(z<<y|u>>>((h-y|0)>>>0)|0)|0;z=b+12|0;b=c[z>>2]|0;x=f;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;A=32-h+y|0;B=u}c[v>>2]=B;c[w>>2]=A;return}function gTa(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;l=ba(i,h)|0;h=b[j>>1]|0;i=((b[k+(g<<12)>>1]|0)-16384|0)/(h|0)|0;m=i<<1^i>>31;if(m>>>0<32>>>0){n=(m>>5)+5|0}else{o=m+32|0;m=o>>>0>65535>>>0;p=m?o>>>16:o;o=m?16:0;if((p&65280|0)==0){q=o;r=p}else{q=o|8;r=p>>>8}n=((d[1191992+r|0]|0)+q<<1)-5|0}q=n+1|0;n=k+(g<<12)+128|0;r=b[n>>1]|0;p=r<<16>>16;o=p-16384|0;m=(c[f>>2]|0)+((((o|0)>-1?o:16384-p|0)|0)%(h|0)|0)|0;c[f>>2]=m;a:do{if((l|0)>1){p=3;o=i;s=2;t=0;u=n;v=q;w=m;x=r;while(1){y=x<<16>>16;z=y-16384|0;A=(z|0)/(h|0)|0;B=((((z|0)>-1?z:16384-y|0)|0)%(h|0)|0)+w|0;c[f>>2]=B;y=A-o|0;z=y>>31;C=(y^t)-t|0;y=C<<1^C>>31;C=d[1155040+p|0]|0;D=(C&3)+1|0;E=C>>>5;F=C>>>2&7;C=D<<E;if(C>>>0>y>>>0){G=(y>>E)+E|0}else{E=(1<<F)-C+y|0;C=E>>>0>65535>>>0;H=C?E>>>16:E;E=C?16:0;if((H&65280|0)==0){I=E;J=H}else{I=E|8;J=H>>>8}G=D-F+((d[1191992+J|0]|0)+I<<1)|0}F=v+1+G|0;D=(y&1)+y>>1;y=u+128|0;if((s|0)>=(l|0)){K=F;L=B;break a}p=(D|0)>3?3:D;o=A;s=s+1|0;t=z;u=y;v=F;w=B;x=b[y>>1]|0}}else{K=q;L=m}}while(0);m=c[e+19092>>2]|0;e=l<<6;l=0;q=d[1154468]|0;G=d[1154650]|0;I=1;J=0;h=L;while(1){L=m+I|0;r=a[L]|0;n=r&255;b:do{if((n|0)<(e|0)){i=l;x=q;w=G;v=n;u=J;t=h;s=r;while(1){o=b[k+(g<<12)+(v<<1)>>1]|0;p=o<<16>>16;y=b[j+((s&255)<<1)>>1]|0;B=(p|0)/(y|0)|0;F=(((o<<16>>16>-1?p:-p|0)|0)%(y|0)|0)+t|0;c[f>>2]=F;if((B|0)==0){M=u;N=w;O=x;P=i+1|0}else{y=(B|0)>-1?B:-B|0;B=d[1155152+x|0]|0;p=(B&3)+1|0;o=B>>>5;z=B>>>2&7;B=p<<o;if(B>>>0>i>>>0){Q=(i>>o)+o|0}else{o=(1<<z)-B+i|0;B=o>>>0>65535>>>0;A=B?o>>>16:o;o=B?16:0;if((A&65280|0)==0){R=o;S=A}else{R=o|8;S=A>>>8}Q=p-z+((d[1191992+S|0]|0)+R<<1)|0}z=d[1155152+w|0]|0;p=y-1|0;A=(z&3)+1|0;o=z>>>5;B=z>>>2&7;z=A<<o;if(z>>>0>p>>>0){T=(p>>o)+o|0}else{o=(1<<B)-z+p|0;p=o>>>0>65535>>>0;z=p?o>>>16:o;o=p?16:0;if((z&65280|0)==0){U=o;V=z}else{U=o|8;V=z>>>8}T=A-B+((d[1191992+V|0]|0)+U<<1)|0}M=u+3+Q+T|0;N=d[1154648+((y|0)>9?9:y)|0]|0;O=d[1154464+((i|0)>15?15:i)|0]|0;P=0}y=v+64|0;if((y|0)>=(e|0)){W=P;X=O;Y=N;Z=M;_=F;break b}i=P;x=O;w=N;v=y;u=M;t=F;s=a[L]|0}}else{W=l;X=q;Y=G;Z=J;_=h}}while(0);L=I+1|0;if((L|0)<64){l=W;q=X;G=Y;I=L;J=Z;h=_}else{break}}return K+7+Z&-8|0}function hTa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=e>>1;e=0;h=d;while(1){d=e<<3;b[f+(d<<1)>>1]=b[h>>1]|0;b[f+((d|1)<<1)>>1]=b[h+2>>1]|0;b[f+((d|2)<<1)>>1]=b[h+4>>1]|0;b[f+((d|3)<<1)>>1]=b[h+6>>1]|0;b[f+((d|4)<<1)>>1]=b[h+8>>1]|0;b[f+((d|5)<<1)>>1]=b[h+10>>1]|0;b[f+((d|6)<<1)>>1]=b[h+12>>1]|0;b[f+((d|7)<<1)>>1]=b[h+14>>1]|0;d=e+1|0;if((d|0)<8){e=d;h=h+(g<<1)|0}else{break}}me[c[a+1108>>2]&511](f);return}function iTa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=c[j>>2]|0;k=h+f|0;if((f|0)<14){l=-1094995529;i=g;return l|0}m=h;n=(d[m]|d[m+1|0]<<8)<<16>>16;m=n&65535;o=h+8|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=h+10|0;q=(d[o]|d[o+1|0]<<8)<<16>>16;o=q&65535;r=h+12|0;if(!(((d[r]|d[r+1|0]<<8)<<16>>16&-8)<<16>>16==16)){DDb(a,2183232,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;l=-1163346256;i=g;return l|0}c[a+140>>2]=50;if(f>>>0<m>>>0){l=-1094995529;i=g;return l|0}if(!(n<<16>>16==44)){DDb(a,2106216,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}n=V$a(a,p,o)|0;if((n|0)<0){l=n;i=g;return l|0}n=_$a(a,b,0)|0;if((n|0)<0){l=n;i=g;return l|0}c[b+88>>2]=1;n=c[b+32>>2]|0;a:do{if(!(q<<16>>16==0)){f=p<<1;r=0;t=h+m|0;u=c[b>>2]|0;while(1){if((k-t|0)>>>0<f>>>0){break}UGb(u|0,t|0,f)|0;v=r+1|0;if(v>>>0<o>>>0){r=v;t=t+f|0;u=u+n|0}else{break a}}c[e>>2]=1;yDb(a,24,2049024,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;l=c[j>>2]|0;i=g;return l|0}}while(0);c[e>>2]=1;l=((ba(o,p)|0)<<1)+m|0;i=g;return l|0}function jTa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[a+416>>2]=1;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;c[a+420>>2]=3;g[b+100>>2]=.09090909361839294;g[b+104>>2]=.1818181872367859;g[b+108>>2]=.27272728085517883;g[b+112>>2]=.3636363744735718;g[b+116>>2]=.4545454680919647;g[b+120>>2]=.5454545617103577;g[b+124>>2]=.6363636255264282;g[b+128>>2]=.7272727489471436;g[b+132>>2]=.8181818127632141;g[b+136>>2]=.9090909361839294;return 0}function kTa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0.0;l=i;i=i+1544|0;m=l|0;n=l+40|0;o=l+80|0;p=l+760|0;q=l+1400|0;r=l+1440|0;s=l+1480|0;t=c[k+24>>2]|0;u=c[k+28>>2]|0;k=f+60|0;v=c[k>>2]|0;w=v;c[h+76>>2]=160;x=_$a(f,h,0)|0;if((x|0)<0){y=x;i=l;return y|0}x=c[h>>2]|0;switch(u|0){case 35:{z=4;A=7;break};case 34:{B=4;A=18;break};case 0:{B=0;A=18;break};case 3:{B=1;A=18;break};case 17:{z=3;A=7;break};case 16:{B=3;A=18;break};case 1:{C=0;D=d[t]|0;A=11;break};case 7:{B=2;A=18;break};case 8:{z=2;A=7;break};case 4:{z=1;A=7;break};default:{A=21}}do{if((A|0)==7){h=a[t]|0;E=h&255;if(!(z>>>0>E>>>0)){C=z;D=E;A=11;break}E=(c[k>>2]|0)+4042|0;if((a[E]|0)==0){yDb(f,24,1893288,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;a[E]=1;G=a[t]|0}else{G=h}H=G&255;A=13}else if((A|0)==18){yDb(f,24,2330560,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;I=B;J=t;A=19}}while(0);do{if((A|0)==11){if((C|0)>=(D|0)){H=C;A=13;break}yDb(f,16,2350904,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;A=21}}while(0);if((A|0)==13){I=H;J=t+1|0;A=19}else if((A|0)==21){t=v+20|0;c[t>>2]=-1;K=t;A=23}a:do{if((A|0)==19){b:do{if((I|0)==0){DDb(f,2306376,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;t=v+20|0;c[t>>2]=0;L=t}else{t=v+20|0;c[t>>2]=I;do{if((I|0)==1){H=J;C=(d[H]|d[H+1|0]<<8)<<16>>16;b[v+4040>>1]=de(C|0)|0;if(!(C<<16>>16==-1)){M=1;break}yDb(f,24,1913864,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2106168,F)|0);i=F;N=t;A=45;break a}else if((I|0)==(-1|0)){K=t;A=23;break a}else{if((I|0)>0){M=I}else{L=t;break b}}}while(0);C=c[556480+(M<<2)>>2]|0;H=C+((e[556504+(M<<1)>>1]|0)*3|0)|0;D=u<<3;B=D>>>0>2147483639>>>0|(J|0)==0;G=B?0:J;k=B?0:D;D=v;c[D>>2]=G;c[v+12>>2]=k;B=k+8|0;z=v+16|0;c[z>>2]=B;c[v+4>>2]=G+(k>>3);k=v+8|0;c[k>>2]=0;TGb(v+24|0,0,71)|0;do{if((M|0)!=0){h=C;E=0;O=B;P=G;while(1){Q=d[h+2|0]|0;R=P+(E>>>3)|0;S=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(E&7)>>>((32-Q|0)>>>0);R=E+Q|0;c[k>>2]=O>>>0>R>>>0?R:O;R=v+((d[h|0]|0)+24)|0;a[R]=d[R]|S<<d[h+1|0];S=h+3|0;if(!(S>>>0<H>>>0)){break}h=S;E=c[k>>2]|0;O=c[z>>2]|0;P=c[D>>2]|0}if((a[v+94|0]|0)==0){break}yDb(f,24,1913864,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2048984,F)|0);i=F;N=t;A=45;break a}}while(0);D=c[t>>2]|0;c:do{if((D|0)==2){z=0;k=1;while(1){if((k|0)>=5){break c}H=(d[v+(k+40)|0]|0)-(d[v+(k+39)|0]|0)|0;if((((H|0)>-1?H:-H|0)|0)>10){break}G=H-z|0;if((((G|0)>-1?G:-G|0)|0)>12){break}else{z=H;k=k+1|0}}yDb(f,24,1913864,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2003424,F)|0);i=F;N=t;A=45;break a}}while(0);if((D|0)<=2){L=t;break}if((a[v+76|0]|0)==0){A=41}else{if(!((d[v+72|0]|0)>>>0>123>>>0)){A=41}}do{if((A|0)==41){if((a[v+77|0]|0)!=0){if((d[v+73|0]|0)>>>0>123>>>0){break}}if((a[v+78|0]|0)!=0){if((d[v+74|0]|0)>>>0>123>>>0){break}}if((a[v+79|0]|0)==0){L=t;break b}if(!((d[v+75|0]|0)>>>0>123>>>0)){L=t;break b}}}while(0);yDb(f,24,1913864,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=1965888,F)|0);i=F;N=t;A=45;break a}}while(0);D=s|0;lTa(w,D);mTa(w,D,x);if((nTa(w,q|0)|0)<0){yDb(f,24,1913864,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=1937856,F)|0);i=F;N=L;A=45;break}oTa(w,x);if((c[L>>2]|0)==-1){N=L;A=45;break}a[v+95|0]=0;T=L}}while(0);if((A|0)==23){yDb(f,24,1913864,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2183200,F)|0);i=F;N=K;A=45}if((A|0)==45){c[N>>2]=-1;A=v+95|0;a[A]=(a[A]|0)+1;A=s|0;lTa(w,A);mTa(w,A,x);nTa(w,q|0)|0;oTa(w,x);T=N}N=v+3364|0;w=q|0;A=r|0;s=v+20|0;K=m|0;F=v+100|0;f=F;L=N;M=0;while(1){J=c[s>>2]|0;I=(J|0)>1;if(I){U=+(M+1|0)*.25}else{U=(J|0)==1&(M|0)==0?.625:1.0}d:do{if(U!=1.0){Mgb(K,w,f,U,1.0-U,10);pTa(K,A)}else{do{if(!I){if((J|0)==-1&(M|0)==0){break}if((J|M|0)!=0){break d}pTa(f,A);break d}}while(0);pTa(w,A)}}while(0);y$(L,A,x+((M*40|0)<<2)|0,40,10);J=M+1|0;if((J|0)<4){L=L+160|0;M=J}else{break}}U=+g[A>>2];g[K>>2]=U*.625;A=n|0;g[A>>2]=U*.7749999761581421;U=+g[r+4>>2];g[m+4>>2]=U*.390625;g[n+4>>2]=U*.6006249785423279;U=+g[r+8>>2];g[m+8>>2]=U*.24414099752902985;g[n+8>>2]=U*.46548399329185486;U=+g[r+12>>2];g[m+12>>2]=U*.15258799493312836;g[n+12>>2]=U*.3607499897480011;U=+g[r+16>>2];g[m+16>>2]=U*.09536699950695038;g[n+16>>2]=U*.2795819938182831;U=+g[r+20>>2];g[m+20>>2]=U*.05960499867796898;g[n+20>>2]=U*.2166759967803955;U=+g[r+24>>2];g[m+24>>2]=U*.0372529998421669;g[n+24>>2]=U*.16792400181293488;U=+g[r+28>>2];g[m+28>>2]=U*.02328299917280674;g[n+28>>2]=U*.1301410049200058;U=+g[r+32>>2];g[m+32>>2]=U*.014551999978721142;g[n+32>>2]=U*.10085900127887726;U=+g[r+36>>2];g[m+36>>2]=U*.009095000103116035;g[n+36>>2]=U*.07816600054502487;n=p|0;z$(n,K,N,160,10);K=v+4044|0;UGb(o|0,K|0,40)|0;p=o+40|0;y$(p,A,n,160,10);UGb(K|0,o+640|0,40)|0;Agb(v+4088|0,.30000001192092896,p,160);Ngb(x,p,+eCb(N,N,160),160,.9375,v+4084|0);UGb(v+3324|0,v+3964|0,40)|0;UGb(F|0,q|0,40)|0;c[v+4016>>2]=c[T>>2];c[j>>2]=1;y=u;i=l;return y|0}function lTa(b,e){b=b|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0;f=i;i=i+64|0;h=f|0;j=b+20|0;k=c[j>>2]|0;if((k|0)<=1){do{if((k|0)==0){i=f;return}else if((k|0)==1){l=c[b+4012>>2]|0;m=((l+(c[b+4008>>2]|0)|0)/2|0)-5|0;if((m|0)<0){n=0}else{n=(m|0)>54?54:m}m=n+(d[b+40|0]<<1)|0;c[h>>2]=m;o=8;p=m;q=l}else{l=c[b+4012>>2]|0;m=h|0;c[m>>2]=l;r=d[b+95|0]|0;if((r|0)==1){s=l}else if((r|0)==2){t=l-1|0;c[m>>2]=t;s=t}else if((r|0)==3){r=l-2|0;c[m>>2]=r;s=r}else{r=l-6|0;c[m>>2]=r;s=r}if((s|0)>=0){o=4;p=s;q=l;break}c[m>>2]=0;o=4;p=0;q=l}}while(0);s=b+4004|0;u=+g[s>>2];v=(+g[559240+(p<<2)>>2]-u)*.5/+(o|0);n=o|1;l=n>>>0>2>>>0;m=1;w=u;while(1){g[e+(m-1<<2)>>2]=v*+(m|0)+w;r=m+1|0;if((r|0)>(o|0)){break}m=r;w=+g[s>>2]}g[s>>2]=+g[e+((l?n-2|0:0)<<2)>>2];c[b+4008>>2]=q;c[b+4012>>2]=p;i=f;return}if((k|0)==4){x=16}else if((k|0)==3){x=4}else{x=5}p=0;q=k;while(1){k=d[b+40+p|0]<<2;n=h+(p<<2)|0;c[n>>2]=k;do{if((q|0)==4){if((p+1&3|0)!=0){y=k;break}l=(((c[h+(p-2<<2)>>2]|0)+(c[h+(p-1<<2)>>2]|0)+(c[h+(p-3<<2)>>2]|0)|0)/3|0)-6|0;if((l|0)<0){z=0}else{z=(l|0)>32?32:l}l=z+k|0;c[n>>2]=l;y=l}else{y=k}}while(0);w=+g[559240+(y<<2)>>2];k=e+(p<<2)|0;g[k>>2]=w;if((a[b+24+p|0]|0)!=0){g[k>>2]=-0.0-w;k=b+56+p|0;a[k]=(a[k]|0)+39&127}k=p+1|0;if((k|0)>=(x|0)){break}p=k;q=c[j>>2]|0}c[b+4008>>2]=c[h+(x-2<<2)>>2];q=c[h+(x-1<<2)>>2]|0;c[b+4012>>2]=q;g[b+4004>>2]=+g[559240+(q<<2)>>2];if((c[j>>2]|0)!=2){i=f;return}j=e+16|0;w=+g[j>>2];g[e+28>>2]=w;q=e+12|0;v=+g[q>>2];u=v;g[e+24>>2]=u*.4+w*.6;g[e+20>>2]=v;b=e+8|0;v=+g[b>>2]*.8;g[j>>2]=v+u*.2;j=e+4|0;u=+g[j>>2];w=u;g[q>>2]=w*.2+v;g[b>>2]=u;g[j>>2]=+g[e>>2]*.6+w*.4;i=f;return}function mTa(e,f,i){e=e|0;f=f|0;i=i|0;var j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;switch(c[e+20>>2]|0){case 2:{j=i;k=0;l=d[e+87|0]<<8&16128|d[e+88|0]<<14|d[e+86|0]<<1&192|d[e+85|0]<<3&56|(a[e+84|0]&255)>>>3&7;m=e+2684|0;while(1){n=+g[f+(k<<2)>>2]*41921422912597656.0e-21;o=m+80|0;p=j;q=0;r=l;s=m;while(1){t=(r*521&65535)+259&65535;g[s>>2]=+(t<<16>>16|0);u=0;v=0.0;while(1){w=u+1|0;x=v+ +h[556520+(u<<3)>>3]*(+g[s+(-u<<2)>>2]+ +g[s+(u-20<<2)>>2]);if((w|0)<10){u=w;v=x}else{break}}g[p>>2]=n*(x+ +g[s-40>>2]*.8985137);u=q+1|0;if((u|0)<20){p=p+4|0;q=u;r=t;s=s+4|0}else{break}}s=k+1|0;if((s|0)<8){j=j+80|0;k=s;l=t;m=o}else{break}}UGb(e+2604|0,e+3244|0,80)|0;return};case 3:{x=+g[f>>2]*.5;m=i;t=0;l=-(d[e+56|0]|0)&65535;while(1){g[m>>2]=x*+(a[556696+(l&127)|0]|0);k=t+1|0;if((k|0)<40){m=m+4|0;t=k;l=l+1&65535}else{break}}x=+g[f+4>>2]*.5;l=i+160|0;t=0;m=-(d[e+57|0]|0)&65535;while(1){g[l>>2]=x*+(a[556696+(m&127)|0]|0);k=t+1|0;if((k|0)<40){l=l+4|0;t=k;m=m+1&65535}else{break}}x=+g[f+8>>2]*.5;m=i+320|0;t=0;l=-(d[e+58|0]|0)&65535;while(1){g[m>>2]=x*+(a[556696+(l&127)|0]|0);k=t+1|0;if((k|0)<40){m=m+4|0;t=k;l=l+1&65535}else{break}}x=+g[f+12>>2]*.5;l=i+480|0;t=0;m=-(d[e+59|0]|0)&65535;while(1){g[l>>2]=x*+(a[556696+(m&127)|0]|0);k=t+1|0;if((k|0)<40){l=l+4|0;t=k;m=m+1&65535}else{break}}return};case 1:{x=+g[f>>2]*41921422912597656.0e-21;m=i;t=0;l=b[e+4040>>1]|0;while(1){y=(l*521&65535)+259&65535;g[m>>2]=x*+(y<<16>>16|0);k=t+1|0;if((k|0)<20){m=m+4|0;t=k;l=y}else{break}}x=+g[f+4>>2]*41921422912597656.0e-21;l=i+80|0;t=0;m=y;while(1){z=(m*521&65535)+259&65535;g[l>>2]=x*+(z<<16>>16|0);y=t+1|0;if((y|0)<20){l=l+4|0;t=y;m=z}else{break}}x=+g[f+8>>2]*41921422912597656.0e-21;m=i+160|0;t=0;l=z;while(1){A=(l*521&65535)+259&65535;g[m>>2]=x*+(A<<16>>16|0);z=t+1|0;if((z|0)<20){m=m+4|0;t=z;l=A}else{break}}x=+g[f+12>>2]*41921422912597656.0e-21;l=i+240|0;t=0;m=A;while(1){B=(m*521&65535)+259&65535;g[l>>2]=x*+(B<<16>>16|0);A=t+1|0;if((A|0)<20){l=l+4|0;t=A;m=B}else{break}}x=+g[f+16>>2]*41921422912597656.0e-21;m=i+320|0;t=0;l=B;while(1){C=(l*521&65535)+259&65535;g[m>>2]=x*+(C<<16>>16|0);B=t+1|0;if((B|0)<20){m=m+4|0;t=B;l=C}else{break}}x=+g[f+20>>2]*41921422912597656.0e-21;l=i+400|0;t=0;m=C;while(1){D=(m*521&65535)+259&65535;g[l>>2]=x*+(D<<16>>16|0);C=t+1|0;if((C|0)<20){l=l+4|0;t=C;m=D}else{break}}x=+g[f+24>>2]*41921422912597656.0e-21;m=i+480|0;t=0;l=D;while(1){E=(l*521&65535)+259&65535;g[m>>2]=x*+(E<<16>>16|0);D=t+1|0;if((D|0)<20){m=m+4|0;t=D;l=E}else{break}}x=+g[f+28>>2]*41921422912597656.0e-21;l=i+560|0;t=0;m=E;while(1){E=(m*521&65535)+259&65535;g[l>>2]=x*+(E<<16>>16|0);D=t+1|0;if((D|0)<20){l=l+4|0;t=D;m=E}else{break}}return};case 0:{TGb(i|0,0,640)|0;return};case-1:{x=+g[f>>2]*.01;m=i+160|0;t=i;l=0;E=-44;while(1){g[t>>2]=x*+(b[556928+((E&127)<<1)>>1]|0);D=l+1|0;if((D|0)<40){t=t+4|0;l=D;E=E+1&65535}else{break}}x=+g[f+4>>2]*.01;E=i+320|0;l=m;m=0;t=-4;while(1){g[l>>2]=x*+(b[556928+((t&127)<<1)>>1]|0);D=m+1|0;if((D|0)<40){l=l+4|0;m=D;t=t+1&65535}else{break}}x=+g[f+8>>2]*.01;t=i+480|0;m=E;E=0;l=36;while(1){g[m>>2]=x*+(b[556928+((l&127)<<1)>>1]|0);D=E+1|0;if((D|0)<40){m=m+4|0;E=D;l=l+1&65535}else{break}}x=+g[f+12>>2]*.01;l=t;t=0;E=76;while(1){g[l>>2]=x*+(b[556928+((E&127)<<1)>>1]|0);m=t+1|0;if((m|0)<40){l=l+4|0;t=m;E=E+1&65535}else{break}}return};case 4:{E=i;i=0;while(1){x=+g[f+(i<<2)>>2]*.01;t=d[e+56+i|0]|0;l=1-t&65535;g[E>>2]=x*+(b[556928+((-t&65535&127)<<1)>>1]|0);g[E+4>>2]=x*+(b[556928+((l&127)<<1)>>1]|0);g[E+8>>2]=x*+(b[556928+((l+1&65535&127)<<1)>>1]|0);g[E+12>>2]=x*+(b[556928+((l+2&65535&127)<<1)>>1]|0);g[E+16>>2]=x*+(b[556928+((l+3&65535&127)<<1)>>1]|0);g[E+20>>2]=x*+(b[556928+((l+4&65535&127)<<1)>>1]|0);g[E+24>>2]=x*+(b[556928+((l+5&65535&127)<<1)>>1]|0);g[E+28>>2]=x*+(b[556928+((l+6&65535&127)<<1)>>1]|0);g[E+32>>2]=x*+(b[556928+((l+7&65535&127)<<1)>>1]|0);g[E+36>>2]=x*+(b[556928+((l+8&65535&127)<<1)>>1]|0);l=i+1|0;if((l|0)<16){E=E+40|0;i=l}else{break}}return};default:{return}}}function nTa(b,f){b=b|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,R=0;h=b+20|0;i=c[h>>2]|0;if((i|0)==1|(i|0)==(-1|0)){j=c[b+4016>>2]|0;if((j|0)==1|(j|0)==(-1|0)){k=b+140|0}else{k=b+100|0}if((i|0)==1){i=b+96|0;a[i]=(a[i]|0)+1;j=0;while(1){l=j+1|0;m=+(l|0)*.008522727272727272+(((a[b+84+j|0]|0)!=0?.02:-.02)+ +g[k+(j<<2)>>2]*29.0*.03125);g[f+(j<<2)>>2]=m;g[b+140+(j<<2)>>2]=m;if((l|0)<10){j=l}else{break}}n=(d[i]|0)>>>0<10>>>0?.875:.10000000149011612;o=f+4|0;p=f+8|0;q=f+12|0;r=f+16|0;s=f+20|0;t=f+24|0;u=f+28|0;v=f+32|0;w=f+36|0}else{i=a[b+95|0]|0;if((i&255)>>>0>1>>>0){x=(i&255)>>>0<4>>>0?.815625011920929:.6343749761581421}else{x=.90625}m=1.0-x;y=m/11.0+x*+g[k>>2];g[f>>2]=y;g[b+140>>2]=y;y=m*2.0/11.0+x*+g[k+4>>2];i=f+4|0;g[i>>2]=y;g[b+144>>2]=y;y=m*3.0/11.0+x*+g[k+8>>2];j=f+8|0;g[j>>2]=y;g[b+148>>2]=y;y=m*4.0/11.0+x*+g[k+12>>2];l=f+12|0;g[l>>2]=y;g[b+152>>2]=y;y=m*5.0/11.0+x*+g[k+16>>2];z=f+16|0;g[z>>2]=y;g[b+156>>2]=y;y=m*6.0/11.0+x*+g[k+20>>2];A=f+20|0;g[A>>2]=y;g[b+160>>2]=y;y=m*7.0/11.0+x*+g[k+24>>2];B=f+24|0;g[B>>2]=y;g[b+164>>2]=y;y=m*8.0/11.0+x*+g[k+28>>2];C=f+28|0;g[C>>2]=y;g[b+168>>2]=y;y=m*9.0/11.0+x*+g[k+32>>2];D=f+32|0;g[D>>2]=y;g[b+172>>2]=y;y=m*10.0/11.0+x*+g[k+36>>2];k=f+36|0;g[k>>2]=y;g[b+176>>2]=y;n=.125;o=i;p=j;q=l;r=z;s=A;t=B;u=C;v=D;w=k}y=+g[f>>2];x=+g[o>>2];m=y>.02?y:.019999999552965164;y=m+.02;E=+g[p>>2];F=x>y?x:y;y=F+.02;x=+g[q>>2];G=E>y?E:y;y=G+.02;E=+g[r>>2];H=x>y?x:y;y=H+.02;x=+g[s>>2];I=E>y?E:y;y=I+.02;E=+g[t>>2];J=x>y?x:y;y=J+.02;x=+g[u>>2];K=E>y?E:y;y=K+.02;E=+g[v>>2];L=x>y?x:y;y=L+.02;x=+g[w>>2];M=E>y?E:y;y=M+.02;E=x>y?x:y;y=E>.98?.9800000190734863:E;g[w>>2]=y;E=y+-.02;y=M>E?E:M;g[v>>2]=y;M=y+-.02;y=L>M?M:L;g[u>>2]=y;L=y+-.02;y=K>L?L:K;g[t>>2]=y;K=y+-.02;y=J>K?K:J;g[s>>2]=y;J=y+-.02;y=I>J?J:I;g[r>>2]=y;I=y+-.02;y=H>I?I:H;g[q>>2]=y;H=y+-.02;y=G>H?H:G;g[p>>2]=y;G=y+-.02;y=F>G?G:F;g[o>>2]=y;F=y+-.02;g[f>>2]=m>F?F:m;Mgb(f,f,b+100|0,n,1.0-n,10);N=0;return N|0}a[b+96|0]=0;o=0;n=0.0;do{p=b+84+o|0;q=c[559216+(o<<2)>>2]|0;m=n+ +(e[q+(d[p]<<2)>>1]|0)*1.0e-4;r=o<<1;g[f+(r<<2)>>2]=m;n=m+ +(e[q+(d[p]<<2)+2>>1]|0)*1.0e-4;g[f+((r|1)<<2)>>2]=n;o=o+1|0;}while((o|0)<5);n=+g[f+36>>2];if((c[h>>2]|0)==2){if(n>.7&n<.97){O=3}else{N=-1;return N|0}while(1){if((O|0)>=10){N=0;P=22;break}if(+Q(+(+g[f+(O<<2)>>2]- +g[f+(O-2<<2)>>2]))<.08){N=-1;P=22;break}else{O=O+1|0}}if((P|0)==22){return N|0}}else{if(n>.66&n<.985){R=4}else{N=-1;return N|0}while(1){if((R|0)>=10){N=0;P=22;break}if(+Q(+(+g[f+(R<<2)>>2]- +g[f+(R-4<<2)>>2]))<.0931){N=-1;P=22;break}else{R=R+1|0}}if((P|0)==22){return N|0}}return 0}function oTa(b,e){b=b|0;e=e|0;var f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0;f=c[b+20>>2]|0;h=(f|0)>2;do{if(!(h|(f|0)==0)){if((f|0)==-1){if((c[b+4016>>2]|0)>2){break}}i=e+68|0;UGb(b+180|0,i|0,572)|0;UGb(b+1392|0,i|0,572)|0;TGb(b+4020|0,0,20)|0;return}}while(0);if(h){h=a[b+72|0]|0;if(h<<24>>24==0){j=0.0}else{j=+((d[b+80|0]|0)+1|0)*.25}g[b+4020>>2]=j;a[b+4036|0]=h+16;h=a[b+73|0]|0;if(h<<24>>24==0){k=0.0}else{k=+((d[b+81|0]|0)+1|0)*.25}g[b+4024>>2]=k;a[b+4037|0]=h+16;h=a[b+74|0]|0;if(h<<24>>24==0){l=0.0}else{l=+((d[b+82|0]|0)+1|0)*.25}g[b+4028>>2]=l;a[b+4038|0]=h+16;h=a[b+75|0]|0;if(h<<24>>24==0){m=0.0}else{m=+((d[b+83|0]|0)+1|0)*.25}g[b+4032>>2]=m;a[b+4039|0]=h+16;n=j}else{do{if((f|0)==-1){h=a[b+95|0]|0;if(!((h&255)>>>0<3>>>0)){o=0.0;break}o=.9- +((h&255)-1|0)*.3}else{o=1.0}}while(0);f=b+4020|0;j=+g[f>>2];m=j>o?o:j;g[f>>2]=m;f=b+4024|0;j=+g[f>>2];g[f>>2]=j>o?o:j;f=b+4028|0;j=+g[f>>2];g[f>>2]=j>o?o:j;f=b+4032|0;j=+g[f>>2];g[f>>2]=j>o?o:j;f=b+76|0;x=0;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;n=m}f=b+752|0;h=0;i=f;p=e;m=n;while(1){q=b+4020+(h<<2)|0;if(m!=0.0){r=p+160|0;s=b+76+h|0;t=b+180+((h*40|0)+143-(d[b+4036+h|0]|0)<<2)|0;u=i;v=p;while(1){if((a[s]|0)==0){n=+g[t>>2];g[u>>2]=n;w=n;y=t+4|0}else{g[u>>2]=0.0;n=(+g[t-16>>2]+ +g[t+12>>2])*-.006821999792009592+0.0;g[u>>2]=n;j=n+(+g[t-12>>2]+ +g[t+8>>2])*.041248999536037445;g[u>>2]=j;z=t+4|0;n=j+(+g[t-8>>2]+ +g[z>>2])*-.1434590071439743;g[u>>2]=n;j=n+(+g[t-4>>2]+ +g[t>>2])*.5888630151748657;g[u>>2]=j;w=j;y=z}g[u>>2]=+g[v>>2]+w*+g[q>>2];z=u+4|0;A=v+4|0;if(A>>>0<r>>>0){t=y;u=z;v=A}else{B=A;C=z;break}}}else{UGb(i|0,p|0,160)|0;B=p+160|0;C=i+160|0}v=h+1|0;if((v|0)>=4){break}h=v;i=C;p=B;m=+g[b+4020+(v<<2)>>2]}UGb(b+180|0,b+820|0,572)|0;B=b+4020|0;m=+g[B>>2];if(m>1.0){D=.5}else{D=m*.5}g[B>>2]=D;B=b+4024|0;m=+g[B>>2];if(m>1.0){E=.5}else{E=m*.5}g[B>>2]=E;B=b+4028|0;E=+g[B>>2];if(E>1.0){F=.5}else{F=E*.5}g[B>>2]=F;B=b+4032|0;F=+g[B>>2];if(F>1.0){G=.5}else{G=F*.5}g[B>>2]=G;B=b+1964|0;p=0;C=B;i=f;G=D;while(1){h=b+4020+(p<<2)|0;if(G!=0.0){y=i+160|0;v=b+76+p|0;u=b+1392+((p*40|0)+143-(d[b+4036+p|0]|0)<<2)|0;t=C;r=i;while(1){if((a[v]|0)==0){D=+g[u>>2];g[t>>2]=D;H=D;I=u+4|0}else{g[t>>2]=0.0;D=(+g[u-16>>2]+ +g[u+12>>2])*-.006821999792009592+0.0;g[t>>2]=D;F=D+(+g[u-12>>2]+ +g[u+8>>2])*.041248999536037445;g[t>>2]=F;q=u+4|0;D=F+(+g[u-8>>2]+ +g[q>>2])*-.1434590071439743;g[t>>2]=D;F=D+(+g[u-4>>2]+ +g[u>>2])*.5888630151748657;g[t>>2]=F;H=F;I=q}g[t>>2]=+g[r>>2]+H*+g[h>>2];q=t+4|0;s=r+4|0;if(s>>>0<y>>>0){u=I;t=q;r=s}else{J=s;K=q;break}}}else{UGb(C|0,i|0,160)|0;J=i+160|0;K=C+160|0}r=p+1|0;if((r|0)>=4){break}p=r;C=K;i=J;G=+g[b+4020+(r<<2)>>2]}UGb(b+1392|0,b+2032|0,572)|0;Ogb(e,B,+eCb(f,f,40),40);f=b+912|0;Ogb(e+160|0,b+2124|0,+eCb(f,f,40),40);f=b+1072|0;Ogb(e+320|0,b+2284|0,+eCb(f,f,40),40);f=b+1232|0;Ogb(e+480|0,b+2444|0,+eCb(f,f,40),40);return}function pTa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;i=i+80|0;d=c|0;e=d|0;h[e>>3]=+T(+g[a>>2]*3.141592653589793);h[d+8>>3]=+T(+g[a+4>>2]*3.141592653589793);h[d+16>>3]=+T(+g[a+8>>2]*3.141592653589793);h[d+24>>3]=+T(+g[a+12>>2]*3.141592653589793);h[d+32>>3]=+T(+g[a+16>>2]*3.141592653589793);h[d+40>>3]=+T(+g[a+20>>2]*3.141592653589793);h[d+48>>3]=+T(+g[a+24>>2]*3.141592653589793);h[d+56>>3]=+T(+g[a+28>>2]*3.141592653589793);h[d+64>>3]=+T(+g[a+32>>2]*3.141592653589793);h[d+72>>3]=+T(+g[a+36>>2]*3.141592653589793);QKa(e,b,5);g[b>>2]=+g[b>>2]*.9883;e=b+4|0;g[e>>2]=+g[e>>2]*.97673689;e=b+8|0;g[e>>2]=+g[e>>2]*.9653090683869999;e=b+12|0;g[e>>2]=+g[e>>2]*.9540149522868719;e=b+16|0;g[e>>2]=+g[e>>2]*.9428529773451155;e=b+20|0;g[e>>2]=+g[e>>2]*.9318215975101777;e=b+24|0;g[e>>2]=+g[e>>2]*.9209192848193085;e=b+28|0;g[e>>2]=+g[e>>2]*.9101445291869226;e=b+32|0;g[e>>2]=+g[e>>2]*.8994958381954355;e=b+36|0;g[e>>2]=+g[e>>2]*.8889717368885489;i=c;return}function qTa(e){e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;h=c[e+60>>2]|0;if(!(a[556472]|0)){c[646327]=4602008;c[646329]=260;N_(2585304,8,24,134072,1,1,134024,2,2,0,0,0,6)|0;c[646359]=4603048;c[646361]=306;N_(2585432,8,37,134664,1,1,134584,2,2,0,0,0,6)|0;c[646321]=4604272;c[646323]=32;N_(2585280,5,6,134016,1,1,134008,1,1,0,0,0,6)|0;c[1313595]=4604400;c[1313597]=296;N_(5254376,8,28,1074984,1,1,1074928,2,2,0,0,0,6)|0;c[1313589]=4605584;c[1313591]=272;N_(5254352,8,20,1074904,1,1,1074864,2,2,0,0,0,6)|0;c[1313583]=4606672;c[1313585]=64;N_(5254328,6,7,1074344,1,1,1074336,1,1,0,0,0,6)|0;c[1313577]=4606928;c[1313579]=64;N_(5254304,6,9,1074320,1,1,1074304,1,1,0,0,0,6)|0;c[646315]=4607184;c[646317]=384;N_(2585256,8,20,133984,1,1,133944,2,2,0,0,0,6)|0;c[646303]=4608720;c[646305]=272;N_(2585208,8,24,133848,1,1,133800,2,2,0,0,0,6)|0;c[646309]=4609808;c[646311]=264;N_(2585232,8,24,133920,1,1,133872,2,2,0,0,0,6)|0;c[646297]=4610864;c[646299]=64;N_(2585184,6,9,133784,1,1,133768,1,1,0,0,0,6)|0;c[646291]=4611120;c[646293]=32;N_(2585160,5,10,133752,1,1,133736,1,1,0,0,0,6)|0;c[646333]=4611248;c[646335]=260;N_(2585328,8,23,134560,1,1,134512,2,2,0,0,0,6)|0;c[646338]=4612288;c[646340]=264;N_(2585348,8,28,134480,1,1,134424,2,2,0,0,0,6)|0;c[646343]=4613344;c[646345]=290;N_(2585368,8,32,134392,1,1,134328,2,2,0,0,0,6)|0;c[646348]=4614504;c[646350]=324;N_(2585388,8,35,134288,1,1,134216,2,2,0,0,0,6)|0;c[646353]=4615800;c[646355]=390;N_(2585408,8,38,134176,1,1,134096,2,2,0,0,0,6)|0;jOa(6867408);j=0;while(1){b[4286728+(j<<1)>>1]=27600-~~(+U(+(j|0)*.00019353590323589742)*-5167.0);k=j+1|0;if((k|0)<8117){j=k}else{l=0;m=0;n=0;break}}while(1){j=gHb(m,l,214013,0)|0;k=YGb(j,F,2531011,0)|0;g[4654760+(n<<2)>>2]=(+(k>>>16&32767|0)*6103515625.0e-14+-1.0)*1.3;j=n+1|0;if((j|0)<4096){l=F;m=k;n=j}else{o=0;break}}while(1){a[4599704+(o*5|0)|0]=(o>>>0)/81|0;n=(o>>>0)%81|0;a[4599705+(o*5|0)|0]=(n>>>0)/27|0;m=(n>>>0)%27|0;a[4599706+(o*5|0)|0]=(m>>>0)/9|0;n=(m>>>0)%9|0;a[4599707+(o*5|0)|0]=(n>>>0)/3|0;a[4599708+(o*5|0)|0]=(n>>>0)%3|0;n=o+1|0;if((n|0)<256){o=n}else{p=0;break}}while(1){a[4599320+(p*3|0)|0]=(p>>>0)/25|0;o=(p>>>0)%25|0;a[4599321+(p*3|0)|0]=(o>>>0)/5|0;a[4599322+(p*3|0)|0]=(o>>>0)%5|0;o=p+1|0;if((o|0)<128){p=o}else{q=0;r=0;break}}do{q=(q*214013|0)+2531011|0;g[4671224+(r<<2)>>2]=+((q>>>16&32767)>>>0>>>0)*6103515625.0e-14+-1.0;r=r+1|0;}while((r|0)<128);a[556472]=1}r=c[e+96>>2]|0;do{if((r|0)!=0){q=c[e+100>>2]|0;if((q|0)<48){break}else{s=r;t=q}while(1){if((PGb(s,2191616,7)|0)==0){u=14;break}q=t-1|0;if((q|0)>7){s=s+1|0;t=q}else{v=q;break}}do{if((u|0)==14){if((t|0)<12){v=t;break}if((a[s+7|0]|0)==67){yDb(e,16,2158064,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=f;return x|0}q=t-8|0;p=s+8|0;o=fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if((o|0)>(q|0)){yDb(e,16,2151120,(w=i,i=i+16|0,c[w>>2]=q,c[w+8>>2]=o,w)|0);i=w;x=-1;i=f;return x|0}q=e;yDb(q,48,2144152,(w=i,i=i+8|0,c[w>>2]=o,w)|0);i=w;o=s+12|0;if((d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)!=1094927441){yDb(q,16,2138520,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=f;return x|0}o=s+20|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=fe(p|0)|0;n=h+4|0;c[n>>2]=o;c[h>>2]=o;c[e+416>>2]=o;if(((c[n>>2]|0)-1|0)>>>0>1>>>0){yDb(q,16,2131960,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1094995529;i=f;return x|0}o=(p|0)==33554432;p=e+448|0;c[p>>2]=o?3:4;c[p+4>>2]=o?0:0;o=s+24|0;c[e+412>>2]=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=s+28|0;p=e+72|0;c[p>>2]=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=s+32|0;m=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;c[h+8>>2]=m;o=s+36|0;l=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;c[h+12>>2]=l;o=s+40|0;j=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;c[h+16>>2]=j;if(j>>>0>268435455>>>0){yDb(q,16,2125664,(w=i,i=i+8|0,c[w>>2]=j,w)|0);i=w;x=-1094995529;i=f;return x|0}j=l>>>0>65535>>>0;o=j?l>>>16:l;k=j?16:0;if((o&65280|0)==0){y=k;z=o}else{y=k|8;z=o>>>8}o=d[1191992+z|0]|0;k=y+1+o|0;c[h+24>>2]=k;j=m>>>0>65535>>>0;A=j?m>>>16:m;B=j?16:0;if((A&65280|0)==0){C=B;D=A}else{C=B|8;D=A>>>8}c[h+20>>2]=C+1+(d[1191992+D|0]|0);c[h+28>>2]=(m|0)/16|0;if((m|0)>8207){x=-1094995529;i=f;return x|0}m=k-7|0;c[h+36>>2]=m;c[h+32>>2]=255>>>((9-k|0)>>>0);switch((m<<1)+(c[n>>2]|0)|0){case 6:{E=100;break};case 2:{E=48;break};case 1:{E=40;break};case 4:{E=72;break};case 3:{E=56;break};case 5:{E=80;break};default:{E=m}}n=c[p>>2]|0;c[h+44>>2]=(E*2240|0|0)<(n|0)?4:(E*1760|0|0)<(n|0)?3:(E*1440|0|0)<(n|0)?2:(E*1e3|0|0)<(n|0)|0;n=c[p>>2]|0;do{if((n|0)<8001){c[h+40>>2]=0}else{p=h+40|0;if((n|0)<16e3){c[p>>2]=1;break}else{c[p>>2]=2;break}}}while(0);if(m>>>0>2>>>0){yDb(q,16,2119920,(w=i,i=i+8|0,c[w>>2]=k,w)|0);i=w;x=-1;i=f;return x|0}if((l|0)==(1<<y+o|0)){BUa(h+38832|0,k,1)|0;bOa(h+51240|0);c[e+420>>2]=1;x=0;i=f;return x|0}else{yDb(q,16,2113880,(w=i,i=i+8|0,c[w>>2]=l,w)|0);i=w;x=-1094995529;i=f;return x|0}}}while(0);yDb(e,16,2175096,(w=i,i=i+8|0,c[w>>2]=v,w)|0);i=w;x=-1;i=f;return x|0}}while(0);yDb(e,16,2200216,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=f;return x|0}function rTa(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0.0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0.0,Dc=0.0,Ec=0.0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0.0,Kc=0,Lc=0.0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0;k=i;i=i+200|0;l=k|0;m=k+8|0;n=k+40|0;o=k+64|0;p=k+88|0;q=k+112|0;r=k+136|0;s=k+160|0;t=k+184|0;u=c[j+24>>2]|0;v=c[e+60>>2]|0;w=v;if((u|0)==0){y=0;i=k;return y|0}z=v+16|0;if((c[j+28>>2]|0)<(c[z>>2]|0)){y=-1;i=k;return y|0}j=v+28|0;c[f+76>>2]=c[j>>2]<<4;A=_$a(e,f,0)|0;if((A|0)<0){y=A;i=k;return y|0}A=v+4|0;e=v+43040|0;B=v+43044|0;C=v+43048|0;D=v+129856|0;E=v+129844|0;F=v+121312|0;G=v+496|0;H=v+36|0;I=v+40|0;J=v;K=s|0;L=s+12|0;M=s+16|0;N=s+4|0;O=s+8|0;P=t|0;Q=v+129848|0;R=t+8|0;S=t+4|0;V=v+368|0;W=v+628|0;X=W;Y=v+38808|0;Z=v+38812|0;_=v+38816|0;$=v+38820|0;aa=v+38824|0;ca=v+38828|0;da=W;ea=v+129852|0;fa=v+129860|0;ga=(W|0)==0;W=r|0;ha=r+12|0;ia=r+16|0;ja=r+4|0;ka=r+8|0;la=p|0;ma=p+12|0;na=p+16|0;oa=p+4|0;pa=p+8|0;qa=v+44|0;ra=o|0;sa=o+12|0;ta=o+16|0;ua=o+4|0;va=o+8|0;wa=q|0;xa=q+12|0;ya=q+16|0;za=q+4|0;Aa=q+8|0;Ba=v+38764|0;Ca=v+38768|0;Da=Ca;Ea=n|0;Fa=n+12|0;Ga=n+16|0;Ha=n+4|0;Ia=n+8|0;Ja=v+38772|0;Ka=v+38776|0;La=v+38780|0;Ma=v+38784|0;Na=v+12|0;Oa=v+38804|0;Pa=v+28760|0;Qa=v+28756|0;Ra=v+32|0;Sa=m+26|0;Ta=m|0;Ua=m+4|0;Va=m+8|0;Wa=m+12|0;Xa=m+16|0;Ya=m+20|0;Za=m+24|0;_a=v+38832|0;$a=v+38916|0;ab=v+500|0;bb=v+51240|0;v=c[f>>2]|0;f=0;cb=c[j>>2]|0;db=c[A>>2]|0;a:while(1){eb=ba(db,cb)|0;if(eb>>>0>1024>>>0){y=-1;fb=290;break}c[e>>2]=u;c[B>>2]=c[z>>2];gb=w+43048+(eb<<2)|0;hb=eb<<2;VGb(C|0,gb|0,hb|0)|0;TGb(gb|0,0,hb|0)|0;b:do{if((c[D>>2]|0)==0){c[E>>2]=0;yDb(0,48,2183176,(ib=i,i=i+1|0,i=i+7&-8,c[ib>>2]=0,ib)|0);i=ib;c[G>>2]=0;TGb(F|0,0,852)|0;hb=c[H>>2]|0;if((hb|0)>1){jb=29}else{jb=(8<<hb)-1|0}hb=(d[1429496+((c[I>>2]|0)*30|0)+jb|0]|0)+1|0;if((c[J>>2]|0)>0){gb=0;do{kb=0;do{lb=w+120672+(gb*80|0)+(kb<<3)|0;mb=(a[w+120672+(gb*80|0)+(kb<<3)+1|0]|0)+(a[lb]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+2|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+3|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+4|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+5|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+6|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+7|0]|0)|0;nb=(mb|0)/8|0;if((mb|0)>7){ob=nb+255&255}else{ob=nb&255}TGb(lb|0,ob|0,8)|0;kb=kb+1|0;}while((kb|0)<(hb|0));gb=gb+1|0;}while((gb|0)<(c[J>>2]|0))}gb=c[e>>2]|0;hb=c[B>>2]<<3;kb=hb>>>0>2147483639>>>0|(gb|0)==0;lb=kb?0:gb;gb=kb?0:hb;c[K>>2]=lb;c[L>>2]=gb;c[M>>2]=gb+8;c[N>>2]=lb+(gb>>3);c[O>>2]=0;wTa(s,t);gb=c[P>>2]|0;if((gb-2|0)>>>0>5>>>0){c[E>>2]=1;yDb(0,16,1937832,(ib=i,i=i+1|0,i=i+7&-8,c[ib>>2]=0,ib)|0);i=ib;break}if((gb|0)==2){pb=1}else{pb=(gb|0)==3|0}c[Q>>2]=pb;lb=(c[B>>2]|0)-((c[O>>2]|0)/8|0)|0;hb=c[R>>2]|0;kb=c[S>>2]|0;nb=kb<<3;mb=nb>>>0>2147483639>>>0|(hb|0)==0;qb=mb?0:hb;hb=mb?0:nb;c[K>>2]=qb;c[L>>2]=hb;nb=hb+8|0;c[M>>2]=nb;mb=qb+(hb>>3)|0;c[N>>2]=mb;c[O>>2]=0;do{if((gb|0)==2|(gb|0)==4|(gb|0)==5){rb=qb;sb=nb>>>0>8>>>0?8:nb;tb=((d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24)&255)*257|0;rb=qb+(sb>>>3)|0;ub=d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0;rb=sb+8|0;c[O>>2]=nb>>>0>rb>>>0?rb:nb;rb=(ub<<1&510)+tb|0;tb=c[e>>2]|0;ub=c[z>>2]|0;sb=rb&65535;if((ub|0)>0){vb=rb;rb=0;do{vb=vb-(d[tb+rb|0]|0)|0;rb=rb+1|0;}while((rb|0)<(ub|0));wb=vb&65535}else{wb=sb}if(wb<<16>>16==0){break}c[E>>2]=1;yDb(0,16,1913840,(ib=i,i=i+1|0,i=i+7&-8,c[ib>>2]=0,ib)|0);i=ib;break b}}while(0);c[V>>2]=0;c[X>>2]=0;gb=(c[Y>>2]|0)-1|0;c[Y>>2]=(gb|0)<0?0:gb;gb=(c[Z>>2]|0)-1|0;c[Z>>2]=(gb|0)<0?0:gb;gb=(c[_>>2]|0)-1|0;c[_>>2]=(gb|0)<0?0:gb;gb=(c[$>>2]|0)-1|0;c[$>>2]=(gb|0)<0?0:gb;gb=(c[aa>>2]|0)-1|0;c[aa>>2]=(gb|0)<0?0:gb;gb=(c[ca>>2]|0)-1|0;c[ca>>2]=(gb|0)<0?0:gb;do{if((lb|0)>0){gb=lb;ub=0;rb=0;tb=0;c:while(1){if(tb>>>0>15>>>0){fb=27;break}xb=w+240+(tb<<3)|0;c[w+240+(tb<<3)+4>>2]=0;if((tb|0)>0){c[w+240+(tb-1<<3)+4>>2]=xb;c[K>>2]=qb;c[L>>2]=hb;c[M>>2]=nb;c[N>>2]=mb;yb=rb<<3;c[O>>2]=nb>>>0>yb>>>0?yb:nb;if(!(rb>>>0<kb>>>0)){fb=50;break}}yb=w+48+(tb*12|0)|0;wTa(s,yb);zb=w+48+(tb*12|0)+4|0;Ab=c[zb>>2]|0;Bb=c[O>>2]|0;Cb=((Bb|0)/8|0)+Ab|0;Db=Ab+2+(Ab>>>0>255>>>0)|0;Eb=yb|0;Fb=c[Eb>>2]|0;if((Fb|0)==0){fb=50;break}if((Db|0)>(gb|0)){if(!((Fb-10|0)>>>0<3>>>0)){fb=50;break}c[zb>>2]=Ab+gb-Db}Ab=gb-Db|0;c[xb>>2]=yb;xb=c[Eb>>2]|0;if((xb|0)==8){fb=35;break}do{if((xb-9|0)>>>0<4>>>0){if((ub|0)>0){c[w+628+(ub-1<<3)+4>>2]=w+628+(ub<<3)}c[w+628+(ub<<3)>>2]=yb;c[w+628+(ub<<3)+4>>2]=0;Gb=ub+1|0}else{if((xb|0)==14){c[Y>>2]=vTa(s,c[1313588]|0,c[1313589]|0,0,2)|0;c[Z>>2]=vTa(s,c[1313588]|0,c[1313589]|0,0,2)|0;c[_>>2]=vTa(s,c[1313588]|0,c[1313589]|0,0,2)|0;c[$>>2]=vTa(s,c[1313588]|0,c[1313589]|0,0,2)|0;c[aa>>2]=vTa(s,c[1313588]|0,c[1313589]|0,0,2)|0;c[ca>>2]=vTa(s,c[1313588]|0,c[1313589]|0,0,2)|0;Gb=ub;break}else if((xb|0)==15){fb=43;break c}else if((xb|0)==13){Eb=c[M>>2]|0;Db=c[K>>2]|0;zb=Db+(Bb>>>3)|0;Fb=Bb+6|0;Hb=Eb>>>0>Fb>>>0?Fb:Eb;c[Y>>2]=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((Bb&7)>>>0)&63;zb=Db+(Hb>>>3)|0;Fb=Hb+6|0;Ib=Eb>>>0>Fb>>>0?Fb:Eb;c[Z>>2]=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((Hb&7)>>>0)&63;Hb=Db+(Ib>>>3)|0;zb=Ib+6|0;Fb=Eb>>>0>zb>>>0?zb:Eb;c[_>>2]=(d[Hb]|d[Hb+1|0]<<8|d[Hb+2|0]<<16|d[Hb+3|0]<<24|0)>>>((Ib&7)>>>0)&63;Ib=Db+(Fb>>>3)|0;Hb=Fb+6|0;zb=Eb>>>0>Hb>>>0?Hb:Eb;c[$>>2]=(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)>>>((Fb&7)>>>0)&63;Fb=Db+(zb>>>3)|0;Ib=zb+6|0;Hb=Eb>>>0>Ib>>>0?Ib:Eb;c[aa>>2]=(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)>>>((zb&7)>>>0)&63;zb=Db+(Hb>>>3)|0;Db=Hb+6|0;c[ca>>2]=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((Hb&7)>>>0)&63;c[O>>2]=Eb>>>0>Db>>>0?Db:Eb;Gb=ub;break}else{Eb=xb-16|0;if(!(Eb>>>0<32>>>0)){Gb=ub;break}if((1056997120>>>(Eb>>>0)&1|0)!=0){Gb=ub;break}Eb=c[G>>2]|0;if((Eb|0)>0){c[w+368+(Eb-1<<3)+4>>2]=w+368+(Eb<<3)}c[w+368+(Eb<<3)>>2]=yb;Eb=c[G>>2]|0;c[w+368+(Eb<<3)+4>>2]=0;c[G>>2]=Eb+1;Gb=ub;break}}}while(0);if((Ab|0)>0){gb=Ab;ub=Gb;rb=Cb;tb=tb+1|0}else{fb=50;break}}if((fb|0)==27){fb=0;yDb(0,32,2106080,(ib=i,i=i+8|0,c[ib>>2]=1893264,ib)|0);i=ib;break b}else if((fb|0)==35){fb=0;yDb(0,32,2106080,(ib=i,i=i+8|0,c[ib>>2]=2350888,ib)|0);i=ib;break b}else if((fb|0)==43){fb=0;yDb(0,32,2106080,(ib=i,i=i+8|0,c[ib>>2]=2330544,ib)|0);i=ib;break b}else if((fb|0)==50){fb=0;if((c[X>>2]|0)==0){break}d:do{if(ga){Jb=0;fb=133}else{tb=da;while(1){Kb=c[tb>>2]|0;if((Kb|0)==0){Lb=0;break}if((c[Kb>>2]|0)==9){fb=55;break}rb=c[tb+4>>2]|0;if((rb|0)==0){Lb=0;break}else{tb=rb}}e:do{if((fb|0)==55){fb=0;if((tb|0)==0){Lb=0;break}Cb=c[Kb+8>>2]|0;Ab=c[Kb+4>>2]<<3;rb=Ab>>>0>2147483639>>>0|(Cb|0)==0;ub=rb?0:Cb;Cb=rb?0:Ab;c[wa>>2]=ub;c[xa>>2]=Cb;c[ya>>2]=Cb+8;c[za>>2]=ub+(Cb>>3);c[Aa>>2]=0;Cb=c[H>>2]|0;if((Cb|0)>1){Mb=29}else{Mb=(8<<Cb)-1|0}Cb=(d[1429496+((c[I>>2]|0)*30|0)+Mb|0]|0)+1|0;ub=c[J>>2]|0;if(Cb>>>0>1>>>0){Ab=1;rb=ub;while(1){if((rb|0)>0){gb=0;while(1){sb=vTa(q,c[646326]|0,c[646327]|0,0,2)|0;a[w+120672+(gb*80|0)+(Ab<<3)|0]=sb;vb=0;yb=sb;while(1){sb=c[646321]|0;xb=c[Aa>>2]|0;Bb=c[ya>>2]|0;Eb=c[wa>>2]|0;Db=Eb+(xb>>>3)|0;Hb=32-(c[646320]|0)|0;zb=(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)>>>((xb&7)>>>0)<<Hb>>>(Hb>>>0);Hb=b[sb+(zb<<2)>>1]|0;Db=(b[sb+(zb<<2)+2>>1]|0)+xb|0;xb=Bb>>>0>Db>>>0?Db:Bb;c[Aa>>2]=xb;if(Hb<<16>>16==0){Db=Eb+(xb>>>3)|0;zb=(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)>>>((xb&7)>>>0)&7;Db=xb+3|0;xb=Bb>>>0>Db>>>0?Db:Bb;Db=Eb+(xb>>>3)|0;Eb=zb^31;sb=(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)>>>((xb&7)>>>0)<<Eb>>>(Eb>>>0);Eb=xb+1+zb|0;c[Aa>>2]=Bb>>>0>Eb>>>0?Eb:Bb;Nb=sb}else{Nb=(Hb<<16>>16)-1|0}Hb=Nb+1|0;sb=vTa(q,c[646358]|0,c[646359]|0,0,2)|0;if((sb&1|0)==0){Ob=-(sb>>1)|0}else{Ob=sb+1>>1}sb=Hb+vb|0;if((sb|0)>7){Lb=1;break e}if((Nb|0)>=0){Bb=1;do{a[Bb+vb+(w+120672+(gb*80|0)+(Ab<<3))|0]=((ba(Bb,Ob)|0)/(Hb|0)|0)+yb;Bb=Bb+1|0;}while((Bb|0)<=(Hb|0))}if((sb|0)<7){vb=sb;yb=Ob+yb|0}else{break}}yb=gb+1|0;vb=c[J>>2]|0;if((yb|0)<(vb|0)){gb=yb}else{Pb=vb;break}}}else{Pb=rb}gb=Ab+1|0;if((gb|0)<(Cb|0)){Ab=gb;rb=Pb}else{Qb=Pb;break}}}else{Qb=ub}if((Qb|0)>0){Rb=0}else{Lb=1;break}while(1){rb=w+120672+(Rb*80|0)|0;Ab=rb|0;x=0;a[Ab]=x;x=x>>8;a[Ab+1|0]=x;x=x>>8;a[Ab+2|0]=x;x=x>>8;a[Ab+3|0]=x;Ab=rb+4|0;x=0;a[Ab]=x;x=x>>8;a[Ab+1|0]=x;x=x>>8;a[Ab+2|0]=x;x=x>>8;a[Ab+3|0]=x;Ab=Rb+1|0;if((Ab|0)<(c[J>>2]|0)){Rb=Ab}else{Lb=1;break}}}}while(0);tb=da;while(1){Sb=c[tb>>2]|0;if((Sb|0)==0){Jb=Lb;fb=133;break d}if((c[Sb>>2]|0)==10){break}ub=c[tb+4>>2]|0;if((ub|0)==0){Jb=Lb;fb=133;break d}else{tb=ub}}if((tb|0)==0){Jb=Lb;fb=133;break}ub=c[Sb+8>>2]|0;Ab=c[Sb+4>>2]<<3;rb=Ab>>>0>2147483639>>>0|(ub|0)==0;Cb=rb?0:ub;ub=rb?0:Ab;c[ra>>2]=Cb;c[sa>>2]=ub;c[ta>>2]=ub+8;c[ua>>2]=Cb+(ub>>3);c[va>>2]=0;Cb=0;Ab=0;rb=ub;while(1){if((Cb|0)>=(c[J>>2]|0)){break}Tb=w+120672+(Cb*80|0)|0;f:do{if((rb-Ab|0)<16){Ub=Ab;Vb=rb}else{ub=vTa(o,c[646326]|0,c[646327]|0,0,2)|0;a[Tb|0]=ub;gb=0;vb=ub;while(1){ub=c[va>>2]|0;yb=c[sa>>2]|0;if((yb-ub|0)<16){Ub=ub;Vb=yb;break f}Hb=c[646321]|0;Bb=c[ta>>2]|0;Eb=c[ra>>2]|0;zb=Eb+(ub>>>3)|0;xb=32-(c[646320]|0)|0;Db=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((ub&7)>>>0)<<xb>>>(xb>>>0);xb=b[Hb+(Db<<2)>>1]|0;zb=(b[Hb+(Db<<2)+2>>1]|0)+ub|0;ub=Bb>>>0>zb>>>0?zb:Bb;c[va>>2]=ub;if(xb<<16>>16==0){zb=Eb+(ub>>>3)|0;Db=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((ub&7)>>>0)&7;zb=ub+3|0;Hb=Bb>>>0>zb>>>0?zb:Bb;zb=Eb+(Hb>>>3)|0;Eb=Db^31;Fb=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((Hb&7)>>>0)<<Eb>>>(Eb>>>0);Eb=Hb+1+Db|0;Db=Bb>>>0>Eb>>>0?Eb:Bb;c[va>>2]=Db;Wb=Fb;Xb=Db}else{Wb=(xb<<16>>16)-1|0;Xb=ub}ub=Wb+1|0;xb=ub+gb|0;if((xb|0)>7){Ub=Xb;Vb=yb;break f}if((yb-Xb|0)<16){Ub=Xb;Vb=yb;break f}yb=vTa(o,c[646358]|0,c[646359]|0,0,2)|0;if((yb&1|0)==0){Yb=-(yb>>1)|0}else{Yb=yb+1>>1}if((Wb|0)>=0){yb=1;do{a[yb+gb+(w+120672+(Cb*80|0))|0]=((ba(yb,Yb)|0)/(ub|0)|0)+vb;yb=yb+1|0;}while((yb|0)<=(ub|0))}if((xb|0)<7){gb=xb;vb=Yb+vb|0}else{break}}Ub=c[va>>2]|0;Vb=c[sa>>2]|0}}while(0);if((Vb-Ub|0)<16){fb=97;break}Cb=Cb+1|0;Ab=Ub;rb=Vb}if((fb|0)==97){fb=0;rb=Tb;Ab=rb|0;x=0;a[Ab]=x;x=x>>8;a[Ab+1|0]=x;x=x>>8;a[Ab+2|0]=x;x=x>>8;a[Ab+3|0]=x;Ab=rb+4|0;x=0;a[Ab]=x;x=x>>8;a[Ab+1|0]=x;x=x>>8;a[Ab+2|0]=x;x=x>>8;a[Ab+3|0]=x}Ab=c[H>>2]|0;rb=Ab+1|0;if((rb|0)>0){Cb=0;tb=c[J>>2]|0;while(1){if((tb|0)>0){vb=0;while(1){gb=0;do{ub=c[va>>2]|0;yb=c[sa>>2]|0;if((yb-ub|0)<1){break}Db=d[(c[ra>>2]|0)+(ub>>>3)|0]|0;Fb=((ub|0)<(c[ta>>2]|0))+ub|0;c[va>>2]=Fb;g:do{if((Db&1<<(ub&7)|0)==0){Bb=w+121312+(vb*192|0)+(Cb<<6)+(gb<<3)|0;Eb=Bb|0;x=0;a[Eb]=x;x=x>>8;a[Eb+1|0]=x;x=x>>8;a[Eb+2|0]=x;x=x>>8;a[Eb+3|0]=x;Eb=Bb+4|0;x=0;a[Eb]=x;x=x>>8;a[Eb+1|0]=x;x=x>>8;a[Eb+2|0]=x;x=x>>8;a[Eb+3|0]=x}else{if((yb-Fb|0)<16){break}else{Zb=0}do{a[w+121312+(vb*192|0)+(Cb<<6)+(gb<<3)+Zb|0]=vTa(o,c[646314]|0,c[646315]|0,0,2)|0;Zb=Zb+1|0;if((Zb|0)>=8){break g}}while(((c[sa>>2]|0)-(c[va>>2]|0)|0)>=16)}}while(0);gb=gb+1|0;}while((gb|0)<8);gb=vb+1|0;Fb=c[J>>2]|0;if((gb|0)<(Fb|0)){vb=gb}else{_b=Fb;break}}}else{_b=tb}vb=Cb+1|0;if((vb|0)<(rb|0)){Cb=vb;tb=_b}else{break}}$b=c[H>>2]|0}else{$b=Ab}if(($b|0)>1){ac=26;fb=114}else{tb=(8<<$b)-4|0;if((tb|0)>0){ac=tb;fb=114}else{bc=$b}}if((fb|0)==114){fb=0;tb=0;Cb=c[J>>2]|0;while(1){h:do{if((Cb|0)>0){if((tb|0)>19){rb=0;vb=Cb;while(1){if(((c[sa>>2]|0)-(c[va>>2]|0)|0)<16){cc=vb;break h}a[w+122112+(rb*26|0)+tb|0]=((vTa(o,c[646308]|0,c[646309]|0,0,2)|0)&255)-16;Fb=rb+1|0;gb=c[J>>2]|0;if((Fb|0)<(gb|0)){rb=Fb;vb=gb}else{cc=gb;break}}}else{vb=0;rb=Cb;while(1){if(((c[sa>>2]|0)-(c[va>>2]|0)|0)<16){cc=rb;break h}a[w+122112+(vb*26|0)+tb|0]=vTa(o,c[646308]|0,c[646309]|0,0,2)|0;gb=w+121696+(vb*208|0)+(tb<<3)|0;Fb=gb|0;x=-252645136;a[Fb]=x;x=x>>8;a[Fb+1|0]=x;x=x>>8;a[Fb+2|0]=x;x=x>>8;a[Fb+3|0]=x;Fb=gb+4|0;x=-252645136;a[Fb]=x;x=x>>8;a[Fb+1|0]=x;x=x>>8;a[Fb+2|0]=x;x=x>>8;a[Fb+3|0]=x;Fb=vb+1|0;gb=c[J>>2]|0;if((Fb|0)<(gb|0)){vb=Fb;rb=gb}else{cc=gb;break}}}}else{cc=Cb}}while(0);rb=tb+1|0;if((rb|0)<(ac|0)){tb=rb;Cb=cc}else{break}}bc=c[H>>2]|0}if((bc|0)>1){dc=25;fb=125}else{Cb=(8<<bc)-5|0;if((Cb|0)>0){dc=Cb;fb=125}}if((fb|0)==125){fb=0;Cb=0;tb=c[J>>2]|0;while(1){if((tb|0)>0){Ab=0;while(1){rb=0;do{if(((c[sa>>2]|0)-(c[va>>2]|0)|0)<16){break}a[w+121696+(Ab*208|0)+(Cb<<3)+rb|0]=(vTa(o,c[646302]|0,c[646303]|0,0,2)|0)+224;rb=rb+1|0;}while((rb|0)<8);rb=Ab+1|0;vb=c[J>>2]|0;if((rb|0)<(vb|0)){Ab=rb}else{ec=vb;break}}}else{ec=tb}Ab=Cb+1|0;if((Ab|0)<(dc|0)){Cb=Ab;tb=ec}else{break}}}yTa(w,1);fc=0;gc=Lb}}while(0);if((fb|0)==133){fb=0;yTa(w,0);fc=1;gc=Jb}i:do{if(ga){fb=138}else{tb=da;while(1){hc=c[tb>>2]|0;if((hc|0)==0){fb=138;break i}if((c[hc>>2]|0)==11){break}Cb=c[tb+4>>2]|0;if((Cb|0)==0){fb=138;break i}else{tb=Cb}}Cb=fc|gc^1;if(Cb|(tb|0)==0){ic=Cb;fb=149;break}Cb=c[hc+4>>2]<<3;Ab=c[hc+8>>2]|0;vb=Cb>>>0>2147483639>>>0|(Ab|0)==0;rb=vb?0:Ab;Ab=vb?0:Cb;c[la>>2]=rb;c[ma>>2]=Ab;vb=Ab+8|0;c[na>>2]=vb;c[oa>>2]=rb+(Ab>>3);c[pa>>2]=0;do{if((Cb|0)>31){Ab=rb;gb=(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24)&8188;c[pa>>2]=vb>>>0>13>>>0?13:vb;if(!(gb>>>0>3>>>0)){break}gb=c[J>>2]|0;Ab=c[qa>>2]|0;if((c[Q>>2]|0)==0){DDb(0,2218016,(ib=i,i=i+1|0,i=i+7&-8,c[ib>>2]=0,ib)|0);i=ib;break}if((gb|0)>0){jc=0}else{break}do{Fb=0;do{TGb(w+116832+(jc*1920|0)+(Fb<<6)|0,a[1458536+(Ab*30|0)+Fb|0]|0,64)|0;Fb=Fb+1|0;}while((Fb|0)<30);jc=jc+1|0;}while((jc|0)<(gb|0))}}while(0);xTa(w,p,Cb,0,8);kc=0}}while(0);if((fb|0)==138){fb=0;ic=fc|gc^1;fb=149}if((fb|0)==149){fb=0;vb=0;while(1){rb=c[fa>>2]|0;if((rb|0)>3839){c[fa>>2]=rb-3840}if((c[J>>2]|0)>0){lc=+g[482968+(vb<<2)>>2];rb=0;do{tb=0;do{gb=c[fa>>2]|0;c[fa>>2]=gb+1;Ab=w+101472+(rb*7680|0)+(vb<<8)+(tb<<2)|0;Fb=tb<<1;g[w+59488+(rb<<14)+(Fb<<7)+(vb<<2)>>2]=lc*+g[4654760+(gb<<2)>>2]*+g[Ab>>2];gb=c[fa>>2]|0;c[fa>>2]=gb+1;g[w+59488+(rb<<14)+((Fb|1)<<7)+(vb<<2)>>2]=lc*+g[4654760+(gb<<2)>>2]*+g[Ab>>2];tb=tb+1|0;}while((tb|0)<64);rb=rb+1|0;}while((rb|0)<(c[J>>2]|0))}rb=vb+1|0;if((rb|0)<8){vb=rb}else{kc=ic;break}}}j:do{if(ga){fb=164}else{vb=da;while(1){mc=c[vb>>2]|0;if((mc|0)==0){fb=164;break j}if((c[mc>>2]|0)==12){break}rb=c[vb+4>>2]|0;if((rb|0)==0){fb=164;break j}else{vb=rb}}if(kc|(vb|0)==0){fb=164;break}rb=c[mc+4>>2]<<3;Cb=c[mc+8>>2]|0;tb=rb>>>0>2147483639>>>0|(Cb|0)==0;Ab=tb?0:Cb;Cb=tb?0:rb;c[W>>2]=Ab;c[ha>>2]=Cb;c[ia>>2]=Cb+8;c[ja>>2]=Ab+(Cb>>3);c[ka>>2]=0;Cb=c[H>>2]|0;xTa(w,r,rb,8,(Cb|0)>1?30:8<<Cb)}}while(0);do{if((fb|0)==164){fb=0;Cb=c[H>>2]|0;rb=(Cb|0)>1?30:8<<Cb;if((rb|0)>8){nc=8}else{break}do{Cb=c[fa>>2]|0;if((Cb|0)>3839){c[fa>>2]=Cb-3840}if((c[J>>2]|0)>0){lc=+g[482968+(nc<<2)>>2];Cb=0;do{Ab=0;do{tb=c[fa>>2]|0;c[fa>>2]=tb+1;gb=w+101472+(Cb*7680|0)+(nc<<8)+(Ab<<2)|0;Fb=Ab<<1;g[w+59488+(Cb<<14)+(Fb<<7)+(nc<<2)>>2]=lc*+g[4654760+(tb<<2)>>2]*+g[gb>>2];tb=c[fa>>2]|0;c[fa>>2]=tb+1;g[w+59488+(Cb<<14)+((Fb|1)<<7)+(nc<<2)>>2]=lc*+g[4654760+(tb<<2)>>2]*+g[gb>>2];Ab=Ab+1|0;}while((Ab|0)<64);Cb=Cb+1|0;}while((Cb|0)<(c[J>>2]|0))}nc=nc+1|0;}while((nc|0)<(rb|0))}}while(0);c[ea>>2]=1;break b}}}while(0);if((c[ea>>2]|0)==0){break}yTa(w,0);kb=0;do{nb=c[fa>>2]|0;if((nb|0)>3839){c[fa>>2]=nb-3840}nb=c[J>>2]|0;if((nb|0)>0){lc=+g[482968+(kb<<2)>>2];mb=0;while(1){hb=0;do{qb=c[fa>>2]|0;c[fa>>2]=qb+1;lb=w+101472+(mb*7680|0)+(kb<<8)+(hb<<2)|0;rb=hb<<1;g[w+59488+(mb<<14)+(rb<<7)+(kb<<2)>>2]=lc*+g[4654760+(qb<<2)>>2]*+g[lb>>2];qb=c[fa>>2]|0;c[fa>>2]=qb+1;g[w+59488+(mb<<14)+((rb|1)<<7)+(kb<<2)>>2]=lc*+g[4654760+(qb<<2)>>2]*+g[lb>>2];hb=hb+1|0;}while((hb|0)<64);hb=mb+1|0;lb=c[J>>2]|0;if((hb|0)<(lb|0)){mb=hb}else{oc=lb;break}}}else{oc=nb}kb=kb+1|0;}while((kb|0)<8);kb=c[H>>2]|0;mb=(kb|0)>1?30:8<<kb;if((mb|0)>8){pc=8;qc=oc}else{break}while(1){kb=c[fa>>2]|0;if((kb|0)>3839){c[fa>>2]=kb-3840}if((qc|0)>0){lc=+g[482968+(pc<<2)>>2];kb=0;while(1){lb=0;do{hb=c[fa>>2]|0;c[fa>>2]=hb+1;qb=w+101472+(kb*7680|0)+(pc<<8)+(lb<<2)|0;rb=lb<<1;g[w+59488+(kb<<14)+(rb<<7)+(pc<<2)>>2]=lc*+g[4654760+(hb<<2)>>2]*+g[qb>>2];hb=c[fa>>2]|0;c[fa>>2]=hb+1;g[w+59488+(kb<<14)+((rb|1)<<7)+(pc<<2)>>2]=lc*+g[4654760+(hb<<2)>>2]*+g[qb>>2];lb=lb+1|0;}while((lb|0)<64);lb=kb+1|0;qb=c[J>>2]|0;if((lb|0)<(qb|0)){kb=lb}else{rc=qb;break}}}else{rc=qc}kb=pc+1|0;if((kb|0)<(mb|0)){pc=kb;qc=rc}else{break}}}}while(0);if((c[E>>2]|0)==0){k:do{if((c[D>>2]|0)==2){if((c[V>>2]|0)==0){break}c[Ba>>2]=0;TGb(Ca|0,-1|0,20)|0;mb=c[G>>2]|0;do{if((mb|0)>0){kb=256;nb=0;qb=mb;while(1){if((qb|0)>0){sc=0;tc=0;uc=0}else{break k}do{lb=c[w+368+(tc<<3)>>2]|0;hb=c[lb>>2]|0;rb=(hb|0)>(sc|0)&(hb|0)<(kb|0);sc=rb?hb:sc;uc=rb?lb:uc;tc=tc+1|0;}while((tc|0)<(qb|0));if((uc|0)==0){break k}lb=uc|0;if((nb|0)==0){rb=(c[lb>>2]|0)-16|0;if(rb>>>0>31>>>0){break k}if((1056997120>>>(rb>>>0)&1|0)!=0){break k}}rb=c[uc+8>>2]|0;hb=c[uc+4>>2]<<3;vb=hb>>>0>2147483639>>>0|(rb|0)==0;Cb=vb?0:rb;rb=vb?0:hb;c[Ea>>2]=Cb;c[Fa>>2]=rb;hb=rb+8|0;c[Ga>>2]=hb;c[Ha>>2]=Cb+(rb>>3);c[Ia>>2]=0;rb=c[lb>>2]|0;if((rb-32|0)>>>0<16>>>0){if((1056997120>>>((rb-16|0)>>>0)&1|0)==0){vc=1}else{fb=205}}else{fb=205}if((fb|0)==205){fb=0;vc=0}do{if((rb-17|0)>>>0<7>>>0|(rb-33|0)>>>0<7>>>0){lb=(c[H>>2]|0)+(5-(rb&15))|0;if(!(lb>>>0<4>>>0)){break}uTa(w,lb,n,vc)}else{if((rb|0)==31){uTa(w,0,n,vc);uTa(w,1,n,vc);uTa(w,2,n,vc);uTa(w,3,n,vc);break}else if((rb|0)==46){lb=Cb;vb=(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24)&63;lb=hb>>>0>6>>>0?6:hb;c[Ia>>2]=lb;c[Y>>2]=vb;vb=Cb+(lb>>>3)|0;Ab=(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((lb&6)>>>0)&63;vb=lb+6|0;lb=hb>>>0>vb>>>0?vb:hb;c[Ia>>2]=lb;c[Z>>2]=Ab;Ab=Cb+(lb>>>3)|0;vb=(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)>>>((lb&7)>>>0)&63;Ab=lb+6|0;lb=hb>>>0>Ab>>>0?Ab:hb;c[Ia>>2]=lb;c[_>>2]=vb;vb=Cb+(lb>>>3)|0;Ab=(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((lb&7)>>>0)&63;vb=lb+6|0;lb=hb>>>0>vb>>>0?vb:hb;c[Ia>>2]=lb;c[$>>2]=Ab;Ab=Cb+(lb>>>3)|0;vb=(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)>>>((lb&7)>>>0)&63;Ab=lb+6|0;lb=hb>>>0>Ab>>>0?Ab:hb;c[Ia>>2]=lb;c[aa>>2]=vb;vb=Cb+(lb>>>3)|0;Ab=(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((lb&7)>>>0)&63;vb=lb+6|0;c[Ia>>2]=hb>>>0>vb>>>0?vb:hb;c[ca>>2]=Ab;uTa(w,0,n,vc);uTa(w,1,n,vc);uTa(w,2,n,vc);uTa(w,3,n,vc);break}else{break}}}while(0);hb=nb+1|0;Cb=c[G>>2]|0;if((hb|0)<(Cb|0)){kb=sc;nb=hb;qb=Cb}else{break}}qb=c[Da>>2]>>31;nb=c[Ja>>2]|0;if(!((nb|0)>-1)){wc=qb;break}if(!((qb|0)>-1)){wc=1;break}c[w+38788+(qb<<2)>>2]=nb;wc=1}else{wc=-1}}while(0);mb=c[Ka>>2]|0;do{if((mb|0)>-1){if(!((wc|0)>-1)){xc=2;break}c[w+38788+(wc<<2)>>2]=mb;xc=2}else{xc=wc}}while(0);mb=c[La>>2]|0;do{if((mb|0)>-1){if(!((xc|0)>-1)){yc=3;break}c[w+38788+(xc<<2)>>2]=mb;yc=3}else{yc=xc}}while(0);mb=c[Ma>>2]|0;nb=(yc|0)>-1;do{if((mb|0)>-1){if(!nb){zc=4;break}c[w+38788+(yc<<2)>>2]=mb;zc=4}else{if(nb){zc=yc}else{break k}}}while(0);c[w+38788+(zc<<2)>>2]=c[Ba>>2]}}while(0);nb=c[D>>2]|0;if((c[A>>2]|0)>0){mb=0;do{TGb(w+38944+(mb<<11)|0,0,c[Na>>2]<<3|0)|0;mb=mb+1|0;}while((mb|0)<(c[A>>2]|0))}mb=c[Ma>>2]|0;l:do{if((mb|0)>-1){if((mb|0)<(c[Oa>>2]|0)){Ac=mb}else{break}do{if((b[w+28764+(Ac*10|0)>>1]|0)!=(nb|0)){break l}if((c[A>>2]|0)==1){Bc=0}else{Bc=d[w+28764+(Ac*10|0)+2|0]|0}qb=b[w+28764+(Ac*10|0)+6>>1]|0;if(qb<<16>>16<0){Cc=0.0}else{Cc=+g[1073296+(((c[Q>>2]|0)==0)<<8)+((qb&63)<<2)>>2]}lc=+(d[w+28764+(Ac*10|0)+8|0]|0)*.7853981633974483;Dc=Cc*+T(lc);Ec=Cc*+U(lc);qb=w+28764+(Ac*10|0)+4|0;kb=w+38944+(Bc<<11)+(b[qb>>1]<<3)|0;g[kb>>2]=Dc+ +g[kb>>2];kb=w+38944+(Bc<<11)+(b[qb>>1]<<3)+4|0;g[kb>>2]=Ec+ +g[kb>>2];kb=w+38944+(Bc<<11)+((b[qb>>1]|0)+1<<3)|0;g[kb>>2]=+g[kb>>2]-Dc;kb=w+38944+(Bc<<11)+((b[qb>>1]|0)+1<<3)+4|0;g[kb>>2]=+g[kb>>2]-Ec;Ac=Ac+1|0;}while((Ac|0)<(c[Oa>>2]|0))}}while(0);mb=c[Pa>>2]|0;kb=c[Qa>>2]|0;if((mb|0)==(kb|0)){Fc=0}else{qb=kb;while(1){tTa(w,w+756+(qb*28|0)|0);kb=((c[Qa>>2]|0)+1|0)%1e3|0;c[Qa>>2]=kb;if((mb|0)==(kb|0)){Fc=0;break}else{qb=kb}}}do{qb=w+38768+(Fc<<2)|0;mb=c[qb>>2]|0;if((mb|0)>-1){kb=w+38788+(Fc<<2)|0;Cb=c[kb>>2]|0;m:do{if((mb|0)<(Cb|0)){hb=4-Fc|0;rb=7-hb|0;Ab=mb;vb=Cb;while(1){if((b[w+28764+(Ab*10|0)>>1]|0)!=(nb|0)){Gc=Ab;break m}lb=b[w+28764+(Ab*10|0)+4>>1]|0;gb=lb>>hb;if((c[A>>2]|0)==1){Hc=0}else{Hc=d[w+28764+(Ab*10|0)+2|0]|0}if((gb|0)<(c[Ra>>2]|0)){if((gb|0)<2){Ic=gb&65535}else{Ic=(gb|0)>59?3:2}b[Sa>>1]=Ic;tb=b[w+28764+(Ab*10|0)+6>>1]|0;if(tb<<16>>16<0){Jc=0.0}else{Jc=+g[1073296+(((c[Q>>2]|0)==0)<<8)+((tb&63)<<2)>>2]}g[Ta>>2]=Jc;c[Ua>>2]=w+38944+(Hc<<11)+(gb<<3);c[Va>>2]=1072016+(Fc*320|0)+((lb-(gb<<hb)|0)*20|0);c[Wa>>2]=-128-(gb<<8)+(d[w+28764+(Ab*10|0)+8|0]<<6);c[Xa>>2]=(lb<<1|1)<<rb;c[Ya>>2]=Fc;b[Za>>1]=0;tTa(w,m);Kc=c[kb>>2]|0}else{Kc=vb}lb=Ab+1|0;if((lb|0)<(Kc|0)){Ab=lb;vb=Kc}else{Gc=lb;break}}}else{Gc=mb}}while(0);c[qb>>2]=Gc}Fc=Fc+1|0;}while((Fc|0)<4)}nb=c[A>>2]|0;if((nb|0)>0){mb=0;kb=nb;while(1){if((kb|0)==1){Lc=(c[J>>2]|0)==2?.5:1.0}else{Lc=1.0}Cb=w+38944+(mb<<11)|0;g[Cb>>2]=+g[Cb>>2]*2.0;g[w+38944+(mb<<11)+4>>2]=0.0;ne[c[$a>>2]&1023](_a,Cb);Cb=(c[Na>>2]|0)+7&-8;if((Cb|0)>0){vb=c[A>>2]|0;Ab=vb<<1;rb=w+43048+(mb<<2)|0;hb=0;while(1){g[rb>>2]=+g[rb>>2]+Lc*+g[w+38944+(mb<<11)+(hb<<3)>>2];lb=rb+(vb<<2)|0;g[lb>>2]=Lc*+g[w+38944+(mb<<11)+(hb<<3)+4>>2]+ +g[lb>>2];lb=hb+1|0;if((lb|0)<(Cb|0)){rb=rb+(Ab<<2)|0;hb=lb}else{break}}}hb=c[E>>2]|0;if((hb|0)==0){if((c[ab>>2]|0)!=0){fb=264;break a}}Ab=mb+1|0;rb=c[A>>2]|0;if((Ab|0)<(rb|0)){mb=Ab;kb=rb}else{Mc=rb;Nc=hb;break}}}else{Mc=nb;Nc=c[E>>2]|0}do{if((Nc|0)==0){if((c[ea>>2]|0)==0){break}kb=c[D>>2]|0;c[l>>2]=0;mb=c[H>>2]|0;hb=(mb|0)>1?30:8<<mb;if((Mc|0)>0&(hb|0)<32){mb=kb<<3;rb=128-(hb<<2)|0;Ab=mb|1;Cb=mb|2;vb=mb|3;qb=mb|4;lb=mb|5;gb=mb|6;tb=mb|7;Fb=0;while(1){TGb(w+59488+(Fb<<14)+(mb<<7)+(hb<<2)|0,0,rb|0)|0;TGb(w+59488+(Fb<<14)+(Ab<<7)+(hb<<2)|0,0,rb|0)|0;TGb(w+59488+(Fb<<14)+(Cb<<7)+(hb<<2)|0,0,rb|0)|0;TGb(w+59488+(Fb<<14)+(vb<<7)+(hb<<2)|0,0,rb|0)|0;TGb(w+59488+(Fb<<14)+(qb<<7)+(hb<<2)|0,0,rb|0)|0;TGb(w+59488+(Fb<<14)+(lb<<7)+(hb<<2)|0,0,rb|0)|0;TGb(w+59488+(Fb<<14)+(gb<<7)+(hb<<2)|0,0,rb|0)|0;TGb(w+59488+(Fb<<14)+(tb<<7)+(hb<<2)|0,0,rb|0)|0;yb=c[A>>2]|0;ub=Fb+1|0;if((ub|0)<(yb|0)){Fb=ub}else{Oc=yb;break}}}else{Oc=Mc}Fb=c[J>>2]|0;if((Fb|0)>0){rb=kb<<3;hb=rb|1;tb=rb|2;gb=rb|3;lb=rb|4;qb=rb|5;vb=rb|6;Cb=rb|7;Ab=0;mb=Fb;do{Fb=w+51264+(Ab<<12)|0;yb=w+59456+(Ab<<2)|0;iOa(bb,Fb,yb,6867408,l,w+92256+(Ab<<2)|0,mb,w+59488+(Ab<<14)+(rb<<7)|0);ub=c[J>>2]|0;Db=(ub<<5)+Ab|0;iOa(bb,Fb,yb,6867408,l,w+92256+(Db<<2)|0,ub,w+59488+(Ab<<14)+(hb<<7)|0);ub=c[J>>2]|0;xb=(ub<<5)+Db|0;iOa(bb,Fb,yb,6867408,l,w+92256+(xb<<2)|0,ub,w+59488+(Ab<<14)+(tb<<7)|0);ub=c[J>>2]|0;Db=(ub<<5)+xb|0;iOa(bb,Fb,yb,6867408,l,w+92256+(Db<<2)|0,ub,w+59488+(Ab<<14)+(gb<<7)|0);ub=c[J>>2]|0;xb=(ub<<5)+Db|0;iOa(bb,Fb,yb,6867408,l,w+92256+(xb<<2)|0,ub,w+59488+(Ab<<14)+(lb<<7)|0);ub=c[J>>2]|0;Db=(ub<<5)+xb|0;iOa(bb,Fb,yb,6867408,l,w+92256+(Db<<2)|0,ub,w+59488+(Ab<<14)+(qb<<7)|0);ub=c[J>>2]|0;xb=(ub<<5)+Db|0;iOa(bb,Fb,yb,6867408,l,w+92256+(xb<<2)|0,ub,w+59488+(Ab<<14)+(vb<<7)|0);ub=c[J>>2]|0;iOa(bb,Fb,yb,6867408,l,w+92256+((ub<<5)+xb<<2)|0,ub,w+59488+(Ab<<14)+(Cb<<7)|0);mb=c[J>>2]|0;Ab=Ab+1|0;}while((Ab|0)<(mb|0));Pc=c[A>>2]|0}else{Pc=Oc}mb=4>>>((c[H>>2]|0)>>>0);if((Pc|0)<=0){break}Ab=0;Cb=c[j>>2]|0;vb=Pc;while(1){if((Cb|0)>0){qb=0;lb=vb;while(1){Ec=+g[w+92256+((ba(ba(qb,mb)|0,c[J>>2]|0)|0)+Ab<<2)>>2]*8388608.0;gb=w+43048+((ba(qb,lb)|0)+Ab<<2)|0;g[gb>>2]=Ec+ +g[gb>>2];gb=qb+1|0;tb=c[j>>2]|0;hb=c[A>>2]|0;if((gb|0)<(tb|0)){qb=gb;lb=hb}else{Qc=tb;Rc=hb;break}}}else{Qc=Cb;Rc=vb}lb=Ab+1|0;if((lb|0)<(Rc|0)){Ab=lb;Cb=Qc;vb=Rc}else{break}}}}while(0);c[D>>2]=((c[D>>2]|0)+1|0)%16|0;if((eb|0)>0){nb=0;do{vb=~~+g[w+43048+(nb<<2)>>2];do{if((vb|0)>27600){if((vb|0)>35716){Sc=32767;break}Sc=b[4286728+(vb-27600<<1)>>1]|0}else{if(!((vb|0)<-27600)){Sc=vb&65535;break}if((vb|0)<-35716){Sc=-32767;break}Sc=-(b[4286728+(-27600-vb<<1)>>1]|0)&65535}}while(0);b[v+(nb<<1)>>1]=Sc;nb=nb+1|0;}while((nb|0)<(eb|0))}eb=c[A>>2]|0;nb=c[j>>2]|0;vb=v+((ba(nb,eb)|0)<<1)|0;Cb=f+1|0;if((Cb|0)<16){v=vb;f=Cb;cb=nb;db=eb}else{fb=289;break}}if((fb|0)==264){yDb(0,32,2106080,(ib=i,i=i+8|0,c[ib>>2]=2048936,ib)|0);i=ib;y=-1;i=k;return y|0}else if((fb|0)==289){c[h>>2]=1;y=c[z>>2]|0;i=k;return y|0}else if((fb|0)==290){i=k;return y|0}return 0}function sTa(a){a=a|0;DUa((c[a+60>>2]|0)+38832|0);return 0}function tTa(a,d){a=a|0;d=d|0;var e=0,f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0,x=0,y=0,z=0.0;e=d+12|0;f=(c[e>>2]|0)+(c[d+16>>2]|0)|0;c[e>>2]=f;e=d+24|0;h=b[e>>1]|0;i=c[d+20>>2]|0;j=+g[1073808+(i*124|0)+(h<<16>>16<<2)>>2]*+g[d>>2];k=+(f|0)*.01227184630308513;l=+U(k)*j;m=j*+T(k);do{if((i|0)>2){n=3}else{f=b[d+26>>1]|0;if(f<<16>>16>2){n=3;break}o=c[d+8>>2]|0;k=+g[o+16>>2];j=-0.0-k;p=+g[o+12>>2];q=+g[o>>2];r=p-q;s=+g[o+8>>2];t=1.0-s-p;p=+g[o+4>>2];u=p+k+-1.0;v=q-p;o=f<<16>>16;w=c[d+4>>2]|0;x=c[1075144+(o<<3)>>2]|0;y=w+(x<<3)|0;g[y>>2]=m*r+ +g[y>>2];if(f<<16>>16>0){z=r}else{z=-0.0-r}y=w+(x<<3)+4|0;g[y>>2]=l*z+ +g[y>>2];y=c[1075148+(o<<3)>>2]|0;o=w+(y<<3)|0;g[o>>2]=m*j+ +g[o>>2];o=w+(y<<3)+4|0;g[o>>2]=l*(f<<16>>16>1?j:k)+ +g[o>>2];o=w|0;g[o>>2]=m*t+ +g[o>>2];o=w+4|0;g[o>>2]=l*t+ +g[o>>2];o=w+8|0;g[o>>2]=m*u+ +g[o>>2];o=w+12|0;g[o>>2]=l*u+ +g[o>>2];o=w+16|0;g[o>>2]=m*v+ +g[o>>2];o=w+20|0;g[o>>2]=l*v+ +g[o>>2];o=w+24|0;g[o>>2]=m*s+ +g[o>>2];o=w+28|0;g[o>>2]=l*s+ +g[o>>2]}}while(0);if((n|0)==3){n=c[d+4>>2]|0;o=n+4|0;g[o>>2]=l+ +g[o>>2];o=n|0;g[o>>2]=m+ +g[o>>2];o=n+12|0;g[o>>2]=+g[o>>2]-l;o=n+8|0;g[o>>2]=+g[o>>2]-m}o=h+1&65535;b[e>>1]=o;if((o<<16>>16|0)>=((1<<5-i)-1|0)){return}i=a+28760|0;o=a+756+((c[i>>2]|0)*28|0)|0;a=d;c[o>>2]=c[a>>2];c[o+4>>2]=c[a+4>>2];c[o+8>>2]=c[a+8>>2];c[o+12>>2]=c[a+12>>2];c[o+16>>2]=c[a+16>>2];c[o+20>>2]=c[a+20>>2];c[o+24>>2]=c[a+24>>2];c[i>>2]=((c[i>>2]|0)+1|0)%1e3|0;return}function uTa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;j=i;k=4-f|0;l=1<<(c[e+20>>2]|0)+~f;m=g+8|0;n=g+12|0;if(((c[n>>2]|0)-(c[m>>2]|0)|0)<=0){i=j;return}o=e+129848|0;p=2585328+(k*20|0)|0;q=2585332+(k*20|0)|0;r=l-1|0;s=2-l|0;t=1<<k;u=e+8|0;v=e|0;w=g|0;x=g+16|0;y=(h|0)!=0?5254352:5254376;h=y|0;z=y+4|0;y=e+32|0;A=e+38768+(f<<2)|0;f=e+38764|0;B=l<<3;C=0;D=0;E=1;a:while(1){F=(c[o>>2]|0)==0;G=vTa(g,c[p>>2]|0,c[q>>2]|0,1,2)|0;do{if(F){H=G+E|0;if((H|0)<(r|0)){I=H;J=D;K=C;break}else{L=C;M=D;N=H}while(1){H=s+N|0;O=L+l|0;P=M+t|0;if((H|0)<(r|0)){I=H;J=P;K=O;break}else{L=O;M=P;N=H}}}else{if((G|0)<2){Q=C;H=D;P=G;while(1){if(((c[n>>2]|0)-(c[m>>2]|0)|0)<0){R=6;break a}O=(P|0)==0;S=H+((O?1:8)<<k)|0;T=Q+(O?l:B)|0;O=vTa(g,c[p>>2]|0,c[q>>2]|0,1,2)|0;if((O|0)<2){Q=T;H=S;P=O}else{U=T;V=S;W=1;X=O;break}}}else{U=C;V=D;W=E;X=G}I=W-2+X|0;J=V;K=U}}while(0);if((K|0)>=(c[u>>2]|0)){R=30;break}G=I>>k;if(G>>>0>255>>>0){R=30;break}if((c[v>>2]|0)>1){F=c[m>>2]|0;P=c[w>>2]|0;H=(d[P+(F>>>3)|0]|0)>>>((F&7)>>>0);O=c[x>>2]|0;S=((F|0)<(O|0))+F|0;c[m>>2]=S;F=d[P+(S>>>3)|0]|0;c[m>>2]=((S|0)<(O|0))+S;Y=H&1;Z=(1<<(S&7)&F|0)!=0}else{Y=0;Z=0}F=vTa(g,c[h>>2]|0,c[z>>2]|0,0,2)|0;S=(c[e+38808+(b[1074352+(G<<1)>>1]<<2)>>2]|0)+F|0;F=(S|0)<0?0:S;S=c[m>>2]|0;H=c[x>>2]|0;O=c[w>>2]|0;P=O+(S>>>3)|0;T=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((S&7)>>>0)&7;P=S+3|0;S=H>>>0>P>>>0?P:H;c[m>>2]=S;if(Z){P=c[1313583]|0;_=O+(S>>>3)|0;$=32-(c[1313582]|0)|0;aa=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((S&7)>>>0)<<$>>>($>>>0);$=b[P+(aa<<2)>>1]|0;_=(b[P+(aa<<2)+2>>1]|0)+S|0;S=H>>>0>_>>>0?_:H;c[m>>2]=S;if($<<16>>16==0){_=O+(S>>>3)|0;aa=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((S&7)>>>0)&7;_=S+3|0;P=H>>>0>_>>>0?_:H;c[m>>2]=P;_=O+(P>>>3)|0;ba=aa^31;ca=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((P&7)>>>0)<<ba>>>(ba>>>0);ba=P+1+aa|0;aa=H>>>0>ba>>>0?ba:H;c[m>>2]=aa;da=ca;ea=aa}else{da=($<<16>>16)-1|0;ea=S}S=c[1313577]|0;$=O+(ea>>>3)|0;aa=32-(c[1313576]|0)|0;ca=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((ea&7)>>>0)<<aa>>>(aa>>>0);aa=b[S+(ca<<2)>>1]|0;$=(b[S+(ca<<2)+2>>1]|0)+ea|0;ca=H>>>0>$>>>0?$:H;c[m>>2]=ca;if(aa<<16>>16==0){$=O+(ca>>>3)|0;S=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((ca&7)>>>0)&7;$=ca+3|0;ca=H>>>0>$>>>0?$:H;c[m>>2]=ca;$=O+(ca>>>3)|0;O=S^31;ba=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((ca&7)>>>0)<<O>>>(O>>>0);O=ca+1+S|0;c[m>>2]=H>>>0>O>>>0?O:H;fa=ba}else{fa=(aa<<16>>16)-1|0}aa=T-fa|0;ga=F-da&65535;ha=((aa|0)<0?aa+8|0:aa)&255}else{ga=0;ha=0}do{if((c[y>>2]|0)>(G+1|0)){aa=J+2|0;if((c[A>>2]|0)<0){c[A>>2]=c[f>>2]}ba=((aa|0)>15?J+65522|0:aa)&65535;b[e+28764+((c[f>>2]|0)*10|0)>>1]=ba;a[e+28764+((c[f>>2]|0)*10|0)+2|0]=Y;aa=I&65535;b[e+28764+((c[f>>2]|0)*10|0)+4>>1]=aa;b[e+28764+((c[f>>2]|0)*10|0)+6>>1]=F;a[e+28764+((c[f>>2]|0)*10|0)+8|0]=T;H=(c[f>>2]|0)+1|0;c[f>>2]=H;if(!Z){break}if((c[A>>2]|0)<0){c[A>>2]=H;ia=c[f>>2]|0}else{ia=H}b[e+28764+(ia*10|0)>>1]=ba;a[e+28764+((c[f>>2]|0)*10|0)+2|0]=Y^1;b[e+28764+((c[f>>2]|0)*10|0)+4>>1]=aa;b[e+28764+((c[f>>2]|0)*10|0)+6>>1]=ga;a[e+28764+((c[f>>2]|0)*10|0)+8|0]=ha;c[f>>2]=(c[f>>2]|0)+1}}while(0);if(((c[n>>2]|0)-(c[m>>2]|0)|0)>0){C=K;D=J;E=I+1|0}else{R=30;break}}if((R|0)==6){if((Q|0)>=(c[u>>2]|0)){i=j;return}yDb(0,16,2003352,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;i=j;return}else if((R|0)==30){i=j;return}}function vTa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;k=a+8|0;l=c[k>>2]|0;m=c[a+16>>2]|0;n=c[a>>2]|0;a=n+(l>>>3)|0;o=32-e|0;p=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>((l&7)>>>0)<<o>>>(o>>>0);o=b[f+(p<<2)>>1]|0;a=b[f+(p<<2)+2>>1]|0;p=a<<16>>16;do{if((h|0)>1&a<<16>>16<0){q=l+e|0;r=m>>>0>q>>>0?q:m;q=n+(r>>>3)|0;s=p+32|0;t=((d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((r&7)>>>0)<<s>>>(s>>>0))+o|0;s=b[f+(t<<2)>>1]|0;q=b[f+(t<<2)+2>>1]|0;t=q<<16>>16;if(!((h|0)>2&q<<16>>16<0)){u=t;v=s;w=r;break}q=r-p|0;r=m>>>0>q>>>0?q:m;q=n+(r>>>3)|0;x=t+32|0;t=((d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((r&7)>>>0)<<x>>>(x>>>0))+s|0;u=b[f+(t<<2)+2>>1]|0;v=b[f+(t<<2)>>1]|0;w=r}else{u=p;v=o;w=l}}while(0);l=u+w|0;w=m>>>0>l>>>0?l:m;c[k>>2]=w;if((v|0)==0){l=n+(w>>>3)|0;u=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)>>>((w&7)>>>0)&7;l=w+3|0;o=m>>>0>l>>>0?l:m;c[k>>2]=o;l=n+(o>>>3)|0;p=u^31;f=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)>>>((o&7)>>>0)<<p>>>(p>>>0);p=o+1+u|0;u=m>>>0>p>>>0?p:m;c[k>>2]=u;y=f;z=u}else{y=v-1|0;z=w}if((g|0)==0){A=y;i=j;return A|0}if((y|0)>59){yDb(0,16,1965848,(g=i,i=i+8|0,c[g>>2]=y,g)|0);i=g;A=0;i=j;return A|0}g=c[134704+(y<<2)>>2]|0;if((y&-4|0)<=0){A=g;i=j;return A|0}w=y>>2;y=n+(z>>>3)|0;n=32-w|0;v=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((z&7)>>>0)<<n>>>(n>>>0);n=z+w|0;c[k>>2]=m>>>0>n>>>0?n:m;A=v+g|0;i=j;return A|0}function wTa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;f=a+8|0;g=c[f>>2]|0;h=a+16|0;j=c[h>>2]|0;k=c[a>>2]|0;a=k+(g>>>3)|0;l=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>((g&7)>>>0)&255;a=g+8|0;c[f>>2]=j>>>0>a>>>0?a:j;j=b|0;c[j>>2]=l;if((l|0)==0){c[b+4>>2]=0;c[b+8>>2]=0;m=0;n=0;o=c[f>>2]|0;p=(o|0)/8|0;yDb(0,48,2208656,(q=i,i=i+24|0,c[q>>2]=m,c[q+8>>2]=n,c[q+16>>2]=p,q)|0);i=q;i=e;return}l=c[f>>2]|0;a=c[h>>2]|0;g=k+(l>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((l&7)>>>0)&255;g=l+8|0;c[f>>2]=a>>>0>g>>>0?g:a;a=b+4|0;c[a>>2]=r;g=c[j>>2]|0;if((g&128|0)==0){s=g;t=r}else{c[a>>2]=r<<8;r=c[f>>2]|0;g=c[h>>2]|0;l=k+(r>>>3)|0;u=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)>>>((r&7)>>>0)&255;l=r+8|0;c[f>>2]=g>>>0>l>>>0?l:g;g=u|c[a>>2];c[a>>2]=g;u=c[j>>2]&127;c[j>>2]=u;s=u;t=g}if((s|0)==127){g=c[f>>2]|0;u=c[h>>2]|0;h=k+(g>>>3)|0;l=(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>((g&7)>>>0);h=g+8|0;c[f>>2]=u>>>0>h>>>0?h:u;u=l<<8&65280|c[j>>2];c[j>>2]=u;v=u;w=c[a>>2]|0}else{v=s;w=t}t=c[f>>2]|0;c[b+8>>2]=k+((t|0)/8|0);m=v;n=w;o=t;p=(o|0)/8|0;yDb(0,48,2208656,(q=i,i=i+24|0,c[q>>2]=m,c[q+8>>2]=n,c[q+16>>2]=p,q)|0);i=q;i=e;return}function xTa(e,f,h,j,k){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0.0,O=0,P=0.0,Q=0.0,R=0,S=0.0,T=0,U=0.0,V=0.0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0.0,ea=0,fa=0,ga=0,ha=0.0,ia=0,ja=0,ka=0,la=0.0;l=i;i=i+104|0;m=l|0;n=l+40|0;TGb(n|0,0,64)|0;o=(j|0)<(k|0);if((h|0)==0){if(!o){i=l;return}h=e+129860|0;p=e|0;q=j;do{r=c[h>>2]|0;if((r|0)>3839){c[h>>2]=r-3840}if((c[p>>2]|0)>0){s=+g[482968+(q<<2)>>2];r=0;do{t=0;do{u=c[h>>2]|0;c[h>>2]=u+1;v=e+101472+(r*7680|0)+(q<<8)+(t<<2)|0;w=t<<1;g[e+59488+(r<<14)+(w<<7)+(q<<2)>>2]=s*+g[4654760+(u<<2)>>2]*+g[v>>2];u=c[h>>2]|0;c[h>>2]=u+1;g[e+59488+(r<<14)+((w|1)<<7)+(q<<2)>>2]=s*+g[4654760+(u<<2)>>2]*+g[v>>2];t=t+1|0;}while((t|0)<64);r=r+1|0;}while((r|0)<(c[p>>2]|0))}q=q+1|0;}while((q|0)<(k|0));i=l;return}if(!o){i=l;return}o=e|0;q=e+129860|0;p=f+8|0;h=f+12|0;r=f|0;t=f+16|0;f=m|0;s=0.0;v=j;a:while(1){j=c[o>>2]|0;b:do{if((j|0)<2|(v|0)<12){x=49}else{u=c[p>>2]|0;w=c[h>>2]|0;if((v|0)>23){y=1;z=u}else{if((w-u|0)<=0){x=49;break}A=(d[(c[r>>2]|0)+(u>>>3)|0]|0)>>>((u&7)>>>0);B=((u|0)<(c[t>>2]|0))+u|0;c[p>>2]=B;u=A&1;if((u|0)==0){x=49;break}else{y=u;z=B}}if((w-z|0)>15){w=c[r>>2]|0;B=c[t>>2]|0;u=0;A=z;while(1){C=(d[w+(A>>>3)|0]|0)>>>((A&7)>>>0);D=((A|0)<(B|0))+A|0;c[p>>2]=D;c[n+(u<<2)>>2]=C&1;C=u+1|0;if((C|0)<16){u=C;A=D}else{E=0;break}}}else{E=0}do{A=a[e+118752+(v<<6)+E|0]|0;u=e+116832+(v<<6)+E|0;if(A<<24>>24>(a[u]|0)){a[u]=A}E=E+1|0;}while((E|0)<64);A=c[o>>2]|0;if((A|0)>0){F=0}else{G=1;H=y;I=1;x=50;break}c:while(1){u=0;do{B=e+116832+(F*1920|0)+(v<<6)+u|0;w=a[B]|0;if(w<<24>>24<8){break c}D=(w<<24>>24)-8|0;d:do{if((D|0)>22){J=8;K=1}else{w=c[402704+(D<<2)>>2]|0;switch(w|0){case 1:{J=16;K=w;break d;break};case 2:{J=24;K=5;break d;break};case 3:{J=30;K=w;break d;break};case 4:{J=30;K=1;break d;break};case 5:{J=8;K=1;break d;break};case 0:{J=10;K=10;break d;break};default:{J=8;K=1;break d}}}}while(0);D=0;do{w=D+u|0;do{if((w|0)<128){if(!((a[((w|0)%64|0)+(e+116832+(F*1920|0)+(((w|0)/64|0)+v<<6))|0]|0)>(a[B]|0)&(D|0)>0)){break}yDb(0,32,2229848,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;C=e+116832+(F*1920|0)+(v<<6)+w|0;TGb(C|0,J|0,D|0)|0;TGb(C|0,J|0,3)|0}}while(0);D=D+1|0;}while((D|0)<(K|0));u=K+u|0;}while((u|0)<64);u=F+1|0;if((u|0)<(A|0)){F=u}else{G=1;H=y;I=1;x=50;break b}}yDb(0,16,2306352,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;A=c[q>>2]|0;if((A|0)>3839){c[q>>2]=A-3840}if((c[o>>2]|0)<=0){M=s;break}N=+g[482968+(v<<2)>>2];A=0;while(1){u=0;do{D=c[q>>2]|0;c[q>>2]=D+1;B=e+101472+(A*7680|0)+(v<<8)+(u<<2)|0;w=u<<1;g[e+59488+(A<<14)+(w<<7)+(v<<2)>>2]=N*+g[4654760+(D<<2)>>2]*+g[B>>2];D=c[q>>2]|0;c[q>>2]=D+1;g[e+59488+(A<<14)+((w|1)<<7)+(v<<2)>>2]=N*+g[4654760+(D<<2)>>2]*+g[B>>2];u=u+1|0;}while((u|0)<64);u=A+1|0;if((u|0)<(c[o>>2]|0)){A=u}else{M=s;break}}}}while(0);if((x|0)==49){x=0;if((j|0)>0){G=0;H=0;I=j;x=50}else{M=s}}if((x|0)==50){x=0;A=482968+(v<<2)|0;u=v+1|0;B=0;N=s;while(1){D=c[q>>2]|0;if((D|0)>3839){c[q>>2]=D-3840}D=c[p>>2]|0;if(((c[h>>2]|0)-D|0)>0){w=d[(c[r>>2]|0)+(D>>>3)|0]|0;c[p>>2]=((D|0)<(c[t>>2]|0))+D;O=(w&1<<(D&7)|0)==0}else{O=1}D=(B*5|0)+1|0;w=0;C=1;P=N;Q=0.0;while(1){e:do{switch(a[((w|0)/2|0)+(e+116832+(B*1920|0)+(v<<6))|0]|0){case 8:{R=c[p>>2]|0;if(((c[h>>2]|0)-R|0)<=9){S=+g[A>>2];T=c[q>>2]|0;g[f>>2]=+g[4654760+(T<<2)>>2]*S;g[m+4>>2]=+g[4654760+(T+1<<2)>>2]*S;g[m+8>>2]=+g[4654760+(T+2<<2)>>2]*S;g[m+12>>2]=+g[4654760+(T+3<<2)>>2]*S;g[m+16>>2]=+g[4654760+(T+4<<2)>>2]*S;g[m+20>>2]=+g[4654760+(T+5<<2)>>2]*S;g[m+24>>2]=+g[4654760+(T+6<<2)>>2]*S;g[m+28>>2]=+g[4654760+(T+7<<2)>>2]*S;g[m+32>>2]=+g[4654760+(T+8<<2)>>2]*S;g[m+36>>2]=+g[4654760+(T+9<<2)>>2]*S;c[q>>2]=T+10;U=Q;V=P;W=C;X=10;break e}f:do{if(O){T=c[t>>2]|0;Y=(c[r>>2]|0)+(R>>>3)|0;Z=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&255;Y=R+8|0;c[p>>2]=T>>>0>Y>>>0?Y:T;if(Z>>>0>242>>>0){x=66;break a}g[f>>2]=+g[1381400+(H*12|0)+(d[4599704+(Z*5|0)|0]<<2)>>2];g[m+8>>2]=+g[1381400+(H*12|0)+(d[4599705+(Z*5|0)|0]<<2)>>2];g[m+16>>2]=+g[1381400+(H*12|0)+(d[4599706+(Z*5|0)|0]<<2)>>2];g[m+24>>2]=+g[1381400+(H*12|0)+(d[4599707+(Z*5|0)|0]<<2)>>2];g[m+32>>2]=+g[1381400+(H*12|0)+(d[4599708+(Z*5|0)|0]<<2)>>2]}else{Z=0;T=R;while(1){Y=Z<<1;if((Y+w|0)>127){break f}_=c[r>>2]|0;$=d[_+(T>>>3)|0]|0;aa=c[t>>2]|0;ca=((T|0)<(aa|0))+T|0;c[p>>2]=ca;if(($&1<<(T&7)|0)==0){da=0.0;ea=ca}else{$=(d[_+(ca>>>3)|0]|0)>>>((ca&7)>>>0);_=((ca|0)<(aa|0))+ca|0;c[p>>2]=_;da=+g[1381400+(H*12|0)+(($<<1&2)<<2)>>2];ea=_}g[m+(Y<<2)>>2]=da;Y=Z+1|0;if((Y|0)<5){Z=Y;T=ea}else{break}}}}while(0);S=+g[A>>2];R=c[q>>2]|0;g[m+4>>2]=+g[4654760+(R<<2)>>2]*S;g[m+12>>2]=+g[4654760+(R+1<<2)>>2]*S;g[m+20>>2]=+g[4654760+(R+2<<2)>>2]*S;g[m+28>>2]=+g[4654760+(R+3<<2)>>2]*S;g[m+36>>2]=+g[4654760+(R+4<<2)>>2]*S;c[q>>2]=R+5;U=Q;V=P;W=C;X=10;break};case 10:{R=c[p>>2]|0;if(((c[h>>2]|0)-R|0)>0){T=d[(c[r>>2]|0)+(R>>>3)|0]|0;c[p>>2]=((R|0)<(c[t>>2]|0))+R;g[f>>2]=((T&1<<(R&7)|0)==0?.8100000023841858:-.8100000023841858)- +g[4671224+(((ba(D+w|0,u)|0)&127)<<2)>>2]*9.0/40.0;U=Q;V=P;W=C;X=1;break e}else{R=c[q>>2]|0;c[q>>2]=R+1;g[f>>2]=+g[4654760+(R<<2)>>2]*+g[A>>2];U=Q;V=P;W=C;X=1;break e}break};case 16:{R=c[p>>2]|0;if(((c[h>>2]|0)-R|0)<=9){S=+g[A>>2];T=c[q>>2]|0;g[f>>2]=+g[4654760+(T<<2)>>2]*S;g[m+4>>2]=+g[4654760+(T+1<<2)>>2]*S;g[m+8>>2]=+g[4654760+(T+2<<2)>>2]*S;g[m+12>>2]=+g[4654760+(T+3<<2)>>2]*S;g[m+16>>2]=+g[4654760+(T+4<<2)>>2]*S;c[q>>2]=T+5;U=Q;V=P;W=C;X=5;break e}if(O){T=c[t>>2]|0;Z=(c[r>>2]|0)+(R>>>3)|0;Y=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>((R&7)>>>0)&255;Z=R+8|0;c[p>>2]=T>>>0>Z>>>0?Z:T;if(Y>>>0>242>>>0){x=80;break a}g[f>>2]=+g[1381400+(H*12|0)+(d[4599704+(Y*5|0)|0]<<2)>>2];g[m+4>>2]=+g[1381400+(H*12|0)+(d[4599705+(Y*5|0)|0]<<2)>>2];g[m+8>>2]=+g[1381400+(H*12|0)+(d[4599706+(Y*5|0)|0]<<2)>>2];g[m+12>>2]=+g[1381400+(H*12|0)+(d[4599707+(Y*5|0)|0]<<2)>>2];g[m+16>>2]=+g[1381400+(H*12|0)+(d[4599708+(Y*5|0)|0]<<2)>>2];U=Q;V=P;W=C;X=5;break e}else{fa=0;ga=R}while(1){if((fa+w|0)>127){U=Q;V=P;W=C;X=5;break e}R=c[r>>2]|0;Y=d[R+(ga>>>3)|0]|0;T=c[t>>2]|0;Z=((ga|0)<(T|0))+ga|0;c[p>>2]=Z;if((Y&1<<(ga&7)|0)==0){ha=0.0;ia=Z}else{Y=(d[R+(Z>>>3)|0]|0)>>>((Z&7)>>>0);R=((Z|0)<(T|0))+Z|0;c[p>>2]=R;ha=+g[1381400+(H*12|0)+((Y<<1&2)<<2)>>2];ia=R}g[m+(fa<<2)>>2]=ha;R=fa+1|0;if((R|0)<5){fa=R;ga=ia}else{U=Q;V=P;W=C;X=5;break}}break};case 24:{R=c[p>>2]|0;if(((c[h>>2]|0)-R|0)<=6){S=+g[A>>2];Y=c[q>>2]|0;g[f>>2]=+g[4654760+(Y<<2)>>2]*S;g[m+4>>2]=+g[4654760+(Y+1<<2)>>2]*S;g[m+8>>2]=+g[4654760+(Y+2<<2)>>2]*S;c[q>>2]=Y+3;U=Q;V=P;W=C;X=3;break e}Y=c[t>>2]|0;Z=(c[r>>2]|0)+(R>>>3)|0;T=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>((R&7)>>>0)&127;Z=R+7|0;c[p>>2]=Y>>>0>Z>>>0?Z:Y;if(T>>>0>124>>>0){x=85;break a}g[f>>2]=+((d[4599320+(T*3|0)|0]|0)-2|0)*.5;g[m+4>>2]=+((d[4599321+(T*3|0)|0]|0)-2|0)*.5;g[m+8>>2]=+((d[4599322+(T*3|0)|0]|0)-2|0)*.5;U=Q;V=P;W=C;X=3;break};case 30:{T=c[p>>2]|0;if(((c[h>>2]|0)-T|0)<=3){Y=c[q>>2]|0;c[q>>2]=Y+1;g[f>>2]=+g[4654760+(Y<<2)>>2]*+g[A>>2];U=Q;V=P;W=C;X=1;break e}Y=c[646297]|0;Z=c[t>>2]|0;R=c[r>>2]|0;_=R+(T>>>3)|0;$=32-(c[646296]|0)|0;ca=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((T&7)>>>0)<<$>>>($>>>0);$=b[Y+(ca<<2)>>1]|0;_=(b[Y+(ca<<2)+2>>1]|0)+T|0;T=Z>>>0>_>>>0?_:Z;c[p>>2]=T;if($<<16>>16==0){_=R+(T>>>3)|0;ca=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((T&7)>>>0)&7;_=T+3|0;T=Z>>>0>_>>>0?_:Z;c[p>>2]=T;_=R+(T>>>3)|0;R=ca^31;Y=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((T&7)>>>0)<<R>>>(R>>>0);R=T+1+ca|0;c[p>>2]=Z>>>0>R>>>0?R:Z;ja=Y}else{ja=($<<16>>16)-1|0}if(ja>>>0>7>>>0){x=90;break a}g[f>>2]=+g[180184+(ja<<2)>>2];U=Q;V=P;W=C;X=1;break};case 34:{$=c[p>>2]|0;if(((c[h>>2]|0)-$|0)<=6){Y=c[q>>2]|0;c[q>>2]=Y+1;g[f>>2]=+g[4654760+(Y<<2)>>2]*+g[A>>2];U=Q;V=P;W=C;X=1;break e}if((C|0)!=0){Y=c[t>>2]|0;Z=c[r>>2]|0;R=Z+($>>>3)|0;ca=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>(($&7)>>>0)&3;R=$+2|0;T=Y>>>0>R>>>0?R:Y;c[p>>2]=T;R=Z+(T>>>3)|0;Z=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((T&7)>>>0)&31;R=T+5|0;c[p>>2]=Y>>>0>R>>>0?R:Y;S=(+(Z>>>0>>>0)+-16.0)/15.0;g[f>>2]=S;U=S;V=+(1<<ca|0);W=0;X=1;break e}ca=c[646291]|0;Z=c[t>>2]|0;Y=c[r>>2]|0;R=Y+($>>>3)|0;T=32-(c[646290]|0)|0;_=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>(($&7)>>>0)<<T>>>(T>>>0);T=b[ca+(_<<2)>>1]|0;R=(b[ca+(_<<2)+2>>1]|0)+$|0;$=Z>>>0>R>>>0?R:Z;c[p>>2]=$;if(T<<16>>16==0){R=Y+($>>>3)|0;_=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>(($&7)>>>0)&7;R=$+3|0;$=Z>>>0>R>>>0?R:Z;c[p>>2]=$;R=Y+($>>>3)|0;Y=_^31;ca=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>(($&7)>>>0)<<Y>>>(Y>>>0);Y=$+1+_|0;c[p>>2]=Z>>>0>Y>>>0?Y:Z;ka=ca}else{ka=(T<<16>>16)-1|0}if(ka>>>0>9>>>0){x=99;break a}S=Q+ +g[180144+(ka<<2)>>2]/P;g[f>>2]=S;U=S;V=P;W=0;X=1;break};default:{T=c[q>>2]|0;c[q>>2]=T+1;g[f>>2]=+g[4654760+(T<<2)>>2]*+g[A>>2];U=Q;V=P;W=C;X=1}}}while(0);g:do{if(G){T=0;do{ca=T+w|0;if((ca|0)>=128){break g}Z=(ca|0)/2|0;S=+g[m+(T<<2)>>2];g[e+59488+(ca<<7)+(v<<2)>>2]=+g[e+101472+(v<<8)+(Z<<2)>>2]*S;do{if((c[o>>2]|0)==2){la=+g[e+109152+(v<<8)+(Z<<2)>>2];if((c[n+(((ca|0)/8|0)<<2)>>2]|0)==0){g[e+75872+(ca<<7)+(v<<2)>>2]=la*S;break}else{g[e+75872+(ca<<7)+(v<<2)>>2]=la*(-0.0-S);break}}}while(0);T=T+1|0;}while((T|0)<(X|0))}else{T=0;do{ca=T+w|0;if((ca|0)<128){g[e+59488+(B<<14)+(ca<<7)+(v<<2)>>2]=+g[e+101472+(B*7680|0)+(v<<8)+(((ca|0)/2|0)<<2)>>2]*+g[m+(T<<2)>>2]}T=T+1|0;}while((T|0)<(X|0))}}while(0);T=X+w|0;if((T|0)<128){w=T;C=W;P=V;Q=U}else{break}}C=B+1|0;if((C|0)<(I|0)){B=C;N=V}else{M=V;break}}}B=v+1|0;if((B|0)<(k|0)){s=M;v=B}else{x=116;break}}if((x|0)==66){yDb(0,16,2288200,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;i=l;return}else if((x|0)==80){yDb(0,16,2288200,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;i=l;return}else if((x|0)==85){yDb(0,16,2271992,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;i=l;return}else if((x|0)==90){yDb(0,16,2256664,(L=i,i=i+8|0,c[L>>2]=ja,L)|0);i=L;i=l;return}else if((x|0)==99){yDb(0,16,2242328,(L=i,i=i+8|0,c[L>>2]=ka,L)|0);i=L;i=l;return}else if((x|0)==116){i=l;return}}function yTa(b,e){b=b|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=b|0;h=c[f>>2]|0;if((h|0)>0){i=b+40|0;j=0;while(1){k=0;do{l=0;do{m=c[i>>2]|0;n=d[1429400+(m*30|0)+k|0]|0;if((n|0)<((d[858112+m|0]|0)-1|0)){o=n+1|0;p=ba(a[b+120672+(j*80|0)+(o<<3)+l|0]|0,c[1377536+(m*1200|0)+(o*120|0)+(k<<2)>>2]|0)|0;q=(ba(a[b+120672+(j*80|0)+(n<<3)+l|0]|0,c[1377536+(m*1200|0)+(n*120|0)+(k<<2)>>2]|0)|0)+p|0}else{q=ba(a[b+120672+(j*80|0)+(n<<3)+l|0]|0,c[1377536+(m*1200|0)+(n*120|0)+(k<<2)>>2]|0)|0}a[b+120832+(j*240|0)+(k<<3)+l|0]=(((q|0)<0?q+255|0:q)|0)/256|0;l=l+1|0;}while((l|0)<8);k=k+1|0;}while((k|0)<30);k=j+1|0;l=c[f>>2]|0;if((k|0)<(l|0)){j=k}else{r=l;break}}}else{r=h}h=c[b+36>>2]|0;j=(h|0)>1?30:8<<h;h=b+129848|0;q=c[h>>2]|0;if((q|0)!=0&(e|0)==0){if((j|0)>0){s=0;t=r}else{return}while(1){if((t|0)>0){e=0;while(1){i=0;do{l=a[((i|0)/8|0)+(b+120832+(e*240|0)+(s<<3))|0]|0;a[b+122164+(e*1920|0)+(s<<6)+i|0]=l;if(l<<24>>24<0){g[b+101472+(e*7680|0)+(s<<8)+(i<<2)>>2]=0.0}else{g[b+101472+(e*7680|0)+(s<<8)+(i<<2)>>2]=+g[1073296+((l&63)<<2)>>2]}i=i+1|0;}while((i|0)<64);i=e+1|0;l=c[f>>2]|0;if((i|0)<(l|0)){e=i}else{u=l;break}}}else{u=t}e=s+1|0;if((e|0)<(j|0)){s=e;t=u}else{break}}return}u=(q|0)==0|0;if((j|0)>0){v=0;w=r}else{return}while(1){r=v-4|0;do{if(r>>>0<20>>>0){if((w|0)<=0){x=w;break}q=(v|0)/8|0;t=0;while(1){s=b+122112+(t*26|0)+r|0;e=0;do{l=(e|0)/8|0;i=(a[b+120832+(t*240|0)+(v<<3)+l|0]|0)-(a[((e|0)%8|0)+(b+121312+(t*192|0)+(q<<6)+(l<<3))|0]|0)-(a[b+121696+(t*208|0)+(r<<3)+l|0]|0)|0;l=a[s]|0;k=i-l|0;a[b+122164+(t*1920|0)+(v<<6)+e|0]=k;do{if((k|0)<0){y=28}else{if((c[h>>2]|0)==0&(i|0)==(l|0)){y=28;break}g[b+101472+(t*7680|0)+(v<<8)+(e<<2)>>2]=+g[1073296+(u<<8)+((k&63)<<2)>>2]}}while(0);if((y|0)==28){y=0;g[b+101472+(t*7680|0)+(v<<8)+(e<<2)>>2]=0.0}e=e+1|0;}while((e|0)<64);e=t+1|0;s=c[f>>2]|0;if((e|0)<(s|0)){t=e}else{x=s;break}}}else{t=(w|0)>0;if((v|0)>4){if(t){z=0}else{x=w;break}while(1){q=b+122112+(z*26|0)+r|0;s=0;do{e=(s|0)/8|0;k=(a[b+120832+(z*240|0)+(v<<3)+e|0]|0)-(a[((s|0)%8|0)+(b+121312+(z*192|0)+128+(e<<3))|0]|0)|0;e=a[q]|0;l=k-e|0;a[b+122164+(z*1920|0)+(v<<6)+s|0]=l;do{if((l|0)<0){y=38}else{if((c[h>>2]|0)==0&(k|0)==(e|0)){y=38;break}g[b+101472+(z*7680|0)+(v<<8)+(s<<2)>>2]=+g[1073296+(u<<8)+((l&63)<<2)>>2]}}while(0);if((y|0)==38){y=0;g[b+101472+(z*7680|0)+(v<<8)+(s<<2)>>2]=0.0}s=s+1|0;}while((s|0)<64);s=z+1|0;q=c[f>>2]|0;if((s|0)<(q|0)){z=s}else{x=q;break}}}else{if(t){A=0}else{x=w;break}while(1){q=0;do{s=a[((q|0)/8|0)+(b+120832+(A*240|0)+(v<<3))|0]|0;a[b+122164+(A*1920|0)+(v<<6)+q|0]=s;l=s&255;do{if(s<<24>>24<0){y=45}else{if((c[h>>2]|0)==0&s<<24>>24==0){y=45;break}g[b+101472+(A*7680|0)+(v<<8)+(q<<2)>>2]=+g[1073296+(u<<8)+((l&63)<<2)>>2]}}while(0);if((y|0)==45){y=0;g[b+101472+(A*7680|0)+(v<<8)+(q<<2)>>2]=0.0}q=q+1|0;}while((q|0)<64);q=A+1|0;l=c[f>>2]|0;if((q|0)<(l|0)){A=q}else{x=l;break}}}}}while(0);r=v+1|0;if((r|0)<(j|0)){v=r;w=x}else{break}}return}function zTa(a){a=a|0;c[a+140>>2]=11;return 0}function ATa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=_$a(b,e,0)|0;if((g|0)<0){l=g;i=h;return l|0}c[e+88>>2]=1;c[e+84>>2]=1;g=c[e>>2]|0;m=j+k|0;if((k|0)<108){l=-1094995529;i=h;return l|0}n=j+104|0;o=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;if(o>>>0>256>>>0){yDb(b,16,2183128,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=o,p)|0);i=p;l=-1094995529;i=h;return l|0}if((k-108|0)<((o<<3)+8|0)){l=-1094995529;i=h;return l|0}n=c[e+4>>2]|0;q=b;r=o<<3;s=0;t=j+108|0;while(1){u=t;v=de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=v&65535;if((v&65535)>>>0>255>>>0){yDb(q,16,2106032,(p=i,i=i+8|0,c[p>>2]=u,p)|0);i=p}else{c[n+(u<<2)>>2]=(d[t+2|0]|0)<<16|(d[t+4|0]|0)<<8|(d[t+6|0]|0)|-16777216}u=s+1|0;if((u|0)>(o|0)){break}else{s=u;t=t+8|0}}c[e+304>>2]=1;if((k-(r+116)|0)<18){l=-1094995529;i=h;return l|0}t=b+124|0;a:do{if((c[t>>2]|0)>0){b=e+32|0;s=0;o=g;n=j+(r+134)|0;b:while(1){p=n;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=(de(q|0)|0)&65535;u=n+2|0;if((m-u|0)<(p|0)){l=-1094995529;w=25;break}v=n+(p+2)|0;c:do{if(!(q<<16>>16==0)){x=p;y=u;z=o;while(1){A=y+1|0;B=d[y]|0;if((B&128|0)==0){if((z+B|0)>>>0>(o+(c[b>>2]|0)|0)>>>0){break c}C=B+1|0;if((m-A|0)<(C|0)){l=-1094995529;w=25;break b}UGb(z|0,A|0,C)|0;D=z+C|0;E=y+(B+2)|0;F=x-2-B|0}else{C=257-B|0;B=z+C|0;if(B>>>0>(o+(c[b>>2]|0)|0)>>>0){break c}TGb(z|0,a[A]|0,C|0)|0;D=B;E=y+2|0;F=x-2|0}if((F|0)>0){x=F;y=E;z=D}else{break}}}}while(0);u=s+1|0;if((u|0)<(c[t>>2]|0)){s=u;o=o+(c[b>>2]|0)|0;n=v}else{break a}}if((w|0)==25){i=h;return l|0}}}while(0);c[f>>2]=1;l=k;i=h;return l|0}function BTa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+60|0;e=c[b>>2]|0;c[e>>2]=a;c[a+140>>2]=11;f=c[a+100>>2]|0;g=f>>>0<1024>>>0?f:1024;h=c[a+96>>2]|0;a=f-g|0;f=(g|0)/4|0;if((g|0)>3){g=(c[b>>2]|0)+12|0;i=0;do{j=h+(a+(i<<2))|0;c[g+(i<<2)>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|-16777216;i=i+1|0;}while((i|0)<(f|0))}f=e+4|0;c[f>>2]=ICb()|0;i=ICb()|0;c[e+8>>2]=i;if(!((c[f>>2]|0)==0|(i|0)==0)){k=0;return k|0}i=c[b>>2]|0;JCb(i+4|0);JCb(i+8|0);k=-12;return k|0}function CTa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;h=i;i=i+128|0;j=c[b+60>>2]|0;k=j;l=c[j+4>>2]|0;m=c[j+8>>2]|0;n=HZ(g,0,0)|0;o=g+28|0;p=c[o>>2]|0;if((p|0)<134){yDb(b,16,2183104,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}q=c[g+24>>2]|0;g=j+1036|0;c[g>>2]=q;c[j+1044>>2]=q;s=j+1040|0;c[s>>2]=q+p;KCb(m);QCb(m,l);p=_$a(b,l,1)|0;if((p|0)<0){r=p;i=h;return r|0}p=c[l>>2]|0;q=c[s>>2]|0;t=c[g>>2]|0;u=q;v=u-t|0;w=v>>>0>4>>>0?4:v;v=t+w|0;c[g>>2]=v;x=h|0;y=u-v|0;z=y>>>0>128>>>0?128:y;UGb(x|0,v|0,z)|0;v=u-(t+(w+z))|0;y=(v>>>0>1>>>0?1:v)+z|0;z=t+(w+y)|0;c[g>>2]=z;if((u-z|0)<1){A=0;B=z}else{u=t+(w+(y+1))|0;c[g>>2]=u;A=d[z]|0;B=u}u=c[l+32>>2]|0;z=c[b+120>>2]|0;y=c[b+124>>2]|0;a:do{if((A|0)==16){if(!((q|0)!=(B|0)&(y|0)>0)){break}b=-u|0;w=0;t=y;v=p+(ba(y-1|0,u)|0)|0;C=q;D=B;while(1){E=C;b:do{if((E-D|0)<1){F=D;G=1;H=35}else{I=D+1|0;c[g>>2]=I;J=a[D]|0;K=J&255;if(J<<24>>24==-4){break a}do{if((J&255)>>>0>247>>>0){if((E-I|0)<1){L=0;M=I}else{N=D+2|0;c[g>>2]=N;L=(d[I]|0)<<8;M=N}if((E-M|0)<1){O=0;P=M}else{N=M+1|0;c[g>>2]=N;O=d[M]|0;P=N}Q=O|L+(K<<16&458752);R=P}else{if((J&255)>>>0>239>>>0){if((E-I|0)<1){S=0;T=I}else{N=D+2|0;c[g>>2]=N;S=d[I]|0;T=N}Q=S|K<<8&3840;R=T;break}if((J&255)>>>0>223>>>0){Q=K&31;R=I;break}do{if((J&255)>>>0>191>>>0){if((E-I|0)<1){U=0;V=I}else{N=D+2|0;c[g>>2]=N;U=(d[I]|0)<<8;V=N}if((E-V|0)<1){W=0;X=V}else{N=V+1|0;c[g>>2]=N;W=d[V]|0;X=N}Y=W|U+(K<<16&4128768);Z=X}else{if(!(J<<24>>24<0)){Y=K;Z=I;break}if((E-I|0)<1){_=0;$=I}else{N=D+2|0;c[g>>2]=N;_=d[I]|0;$=N}Y=_|K<<8&32512;Z=$}}while(0);N=Y+1|0;if((N|0)>0){F=Z;G=N;H=35;break b}else{aa=v;ca=t;da=w;break b}}}while(0);K=Q+2|0;if((E-R|0)<1){ea=0}else{c[g>>2]=R+1;ea=a[R]|0}if((K|0)>0){fa=0;ga=w;ha=t;ia=v}else{aa=v;ca=t;da=w;break}while(1){I=ga+1|0;a[ia+ga|0]=ea;if((I|0)<(z|0)){ja=ia;ka=ha;la=I}else{I=ha-1|0;if((I|0)<1){break a}else{ja=ia+b|0;ka=I;la=0}}I=fa+1|0;if((I|0)<(K|0)){fa=I;ga=la;ha=ka;ia=ja}else{aa=ja;ca=ka;da=la;break}}}}while(0);c:do{if((H|0)==35){H=0;E=1;K=w;I=t;J=v;N=C;ma=F;while(1){if((N-ma|0)<1){na=0}else{c[g>>2]=ma+1;na=a[ma]|0}oa=K+1|0;a[J+K|0]=na;if((oa|0)<(z|0)){pa=J;qa=I;ra=oa}else{oa=I-1|0;if((oa|0)<1){break a}else{pa=J+b|0;qa=oa;ra=0}}if((E|0)>=(G|0)){aa=pa;ca=qa;da=ra;break c}E=E+1|0;K=ra;I=qa;J=pa;N=c[s>>2]|0;ma=c[g>>2]|0}}}while(0);ma=c[g>>2]|0;N=c[s>>2]|0;if((N|0)!=(ma|0)&(ca|0)>0){w=da;t=ca;v=aa;C=N;D=ma}else{break}}}else{FTa(k,p,u,z,y,A,x,c[m>>2]|0)}}while(0);if((n|0)==0){sa=j+12|0}else{c[l+304>>2]=1;m=j+12|0;UGb(m|0,n|0,1024)|0;sa=m}UGb(c[l+4>>2]|0,sa|0,1024)|0;sa=MCb(e,l)|0;if((sa|0)<0){r=sa;i=h;return r|0}c[f>>2]=1;r=c[o>>2]|0;i=h;return r|0}function DTa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);JCb(b+8|0);return 0}function ETa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[a+100>>2]|0;e=b>>>0<1024>>>0?b:1024;f=c[a+96>>2]|0;g=b-e|0;b=(e|0)/4|0;if((e|0)<=3){return}e=(c[a+60>>2]|0)+12|0;a=0;do{h=f+(g+(a<<2))|0;c[e+(a<<2)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|-16777216;a=a+1|0;}while((a|0)<(b|0));return}function FTa(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0;m=i;n=(l|0)==0?e:l;if((h|0)>0){l=0;do{o=ba(l,f)|0;UGb(e+o|0,n+o|0,g)|0;l=l+1|0;}while((l|0)<(h|0))}l=h-1|0;o=b+1036|0;p=b+1040|0;b=(j|0)==0;q=(j|0)==1;j=-f|0;r=e+(ba(l,f)|0)|0;e=l;l=0;a:while(1){s=(e|0)>-1;t=l;while(1){u=c[o>>2]|0;v=c[p>>2]|0;if(!((v|0)!=(u|0)&s)){w=56;break a}if((v-u|0)<1){x=0;y=u}else{z=u+1|0;c[o>>2]=z;x=d[u]|0;y=z}b:do{if(b){A=x;B=v;C=y}else{if((v|0)==(y|0)){A=x;B=v;C=v;break}else{D=x;E=v;F=y}while(1){if((D&240|0)!=240){A=D;B=E;C=F;break b}c:do{if(q){z=D&15;u=c[555632+(z<<2)>>2]|0;G=c[555696+(z<<2)>>2]|0;if((E-F|0)<1){H=0}else{c[o>>2]=F+1;H=d[F]|0}I=H>>>4;J=H>>>0>127>>>0?I|-16:I;I=H&15;K=I>>>0>7>>>0?H|-16:I;I=J+t|0;do{if((I|0)>=0){L=u+t|0;if((L+J|0)>(g|0)){break}M=e-K|0;if((M-G|0)<0|(M|0)>(h|0)|(L|0)>(g|0)){break}if((e-G|0)<0){break}if((z|0)==0){break c}L=(ba(M,f)|0)+I|0;M=0;while(1){N=ba(M,f)|0;O=L-N|0;P=t-N|0;N=0;do{a[r+(P+N)|0]=a[n+(O+N)|0]|0;N=N+1|0;}while((N|0)<(u|0));M=M+1|0;if((M|0)>=(G|0)){break c}}}}while(0);yDb(0,16,2105976,(I=i,i=i+48|0,c[I>>2]=J,c[I+8>>2]=K,c[I+16>>2]=u,c[I+24>>2]=G,c[I+32>>2]=t,c[I+40>>2]=e,I)|0);i=I}}while(0);I=c[p>>2]|0;z=c[o>>2]|0;if((I-z|0)<1){Q=0;R=z}else{M=z+1|0;c[o>>2]=M;Q=d[z]|0;R=M}if((I|0)==(R|0)){A=Q;B=I;C=I;break}else{D=Q;E=I;F=R}}}}while(0);if((A|0)==224){w=56;break a}if((A|0)>224){w=29;break}if((A|0)>191){w=36;break}if((A|0)>127){w=44;break}if((A|0)!=0){a[r+t|0]=a[k+(A&127)|0]|0}v=t+1|0;if((v|0)<(g|0)){t=v}else{w=55;break}}if((w|0)==29){w=0;s=A&31;if((B-C|0)<1){S=0}else{c[o>>2]=C+1;S=a[C]|0}v=t;I=0;M=e;z=r;while(1){L=v+1|0;a[z+v|0]=S;if((L|0)<(g|0)){T=z;U=M;V=L}else{L=z+j|0;N=M-1|0;if((N|0)<0){r=L;e=N;l=0;continue a}else{T=L;U=N;V=0}}N=I+1|0;if((N|0)>(s|0)){r=T;e=U;l=V;continue a}else{v=V;I=N;M=U;z=T}}}else if((w|0)==36){w=0;z=A&31;if((z+1|0)>>>0>(B-C|0)>>>0){w=56;break}else{W=t;X=1;Y=e;Z=r;_=B;$=C}while(1){if((_-$|0)<1){aa=0}else{c[o>>2]=$+1;aa=a[$]|0}M=W+1|0;a[Z+W|0]=aa;if((M|0)<(g|0)){ca=Z;da=Y;ea=M}else{M=Z+j|0;I=Y-1|0;if((I|0)<0){r=M;e=I;l=0;continue a}else{ca=M;da=I;ea=0}}if((X|0)>(z|0)){r=ca;e=da;l=ea;continue a}W=ea;X=X+1|0;Y=da;Z=ca;_=c[p>>2]|0;$=c[o>>2]|0}}else if((w|0)==44){w=0;z=A&63;do{if((z|0)==0){if((B-C|0)<1){fa=64;break}c[o>>2]=C+1;fa=(d[C]|0)+64|0}else if((z|0)==1){if((B-C|0)<1){fa=320;break}c[o>>2]=C+1;fa=(d[C]|0)+320|0}else{fa=z}}while(0);z=r;I=e;M=fa+t|0;while(1){if((M|0)<(g|0)){r=z;e=I;l=M;continue a}v=M-g|0;s=z+j|0;N=I-1|0;if((N|0)<0){r=s;e=N;l=v;continue a}else{z=s;I=N;M=v}}}else if((w|0)==55){w=0;r=r+j|0;e=e-1|0;l=0;continue}}if((w|0)==56){i=m;return}}function GTa(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;e=c[a+792>>2]|0;switch(e|0){case 32:{c[a+140>>2]=30;break};case 24:{c[a+140>>2]=2;break};case 16:{c[a+140>>2]=46;break};case 1:case 33:{c[a+140>>2]=9;break};case 2:case 4:case 8:case 34:case 36:case 40:{c[a+140>>2]=11;break};default:{yDb(a,16,2183056,(a=i,i=i+8|0,c[a>>2]=e,a)|0);i=a;f=-1094995529;i=b;return f|0}}a=ICb()|0;c[d+4>>2]=a;f=(a|0)==0?-12:0;i=b;return f|0}function HTa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0;j=i;k=c[e+60>>2]|0;l=k;m=c[h+24>>2]|0;n=h+28|0;o=c[n>>2]|0;if(!((o|0)>-1)){yDb(0,0,2048888,(p=i,i=i+24|0,c[p>>2]=2003336,c[p+8>>2]=1965816,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}q=k+8|0;c[q>>2]=m;r=k+16|0;c[r>>2]=m;s=k+12|0;c[s>>2]=m+o;o=k+4|0;m=$$a(e,c[o>>2]|0)|0;if((m|0)<0){t=m;i=j;return t|0}m=c[n>>2]|0;a:do{if((m|0)>=8){u=c[s>>2]|0;v=c[r>>2]|0;w=u;x=w-v|0;y=(x|0)<4?x:4;x=v+y|0;c[q>>2]=x;do{if((w-x|0)<2){z=x;A=13}else{B=v+(y+2)|0;c[q>>2]=B;C=x;if(((d[C]|d[C+1|0]<<8)<<16>>16&2048)==0){z=B;A=13;break}if((m|0)<14){break a}if((w-B|0)<2){D=0;E=B}else{C=v+(y+4)|0;c[q>>2]=C;F=B;D=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;E=C}C=w-E|0;F=C>>>0>2>>>0?2:C;C=E+F|0;c[q>>2]=C;if((w-C|0)<2){G=0;H=C}else{B=E+(F+2)|0;c[q>>2]=B;F=C;G=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;H=B}B=w-H|0;F=H+(B>>>0>2>>>0?2:B)|0;c[q>>2]=F;B=c[k>>2]|0;C=c[B+124>>2]|0;if((G|0)>(C-D|0)){break a}else{I=D;J=G;K=B;L=C;M=F}}}while(0);if((A|0)==13){y=c[k>>2]|0;v=c[y+124>>2]|0;I=0;J=v;K=y;L=v;M=z}v=c[o>>2]|0;y=c[v+32>>2]|0;x=ba(y,I)|0;F=c[e+792>>2]|0;b:do{switch(F|0){case 8:case 40:{C=c[v>>2]|0;B=k;N=ba(L,y)|0;if((J|0)==0){break b}else{O=x;P=J;Q=u;R=M}c:while(1){S=P-1|0;if((Q-R|0)<1){T=-4;U=R}else{V=R+1|0;c[q>>2]=V;T=((d[R]|0)<<2)-4|0;U=V}W=T+O|0;if((W|0)>(N|0)|(W|0)<0){A=46;break}else{X=W;Y=Q;Z=U}d:while(1){V=Y;do{if((V-Z|0)<1){_=Z;A=50}else{$=Z+1|0;c[q>>2]=$;aa=a[Z]|0;ca=(aa&255)<<24;da=aa<<24>>24;if((da|0)==(-1|0)){break d}else if((da|0)==0){_=$;A=50;break}if((ca|0)>=0){ea=ca>>22;fa=ea+X|0;if((fa|0)>(N|0)|(fa|0)<0){A=68;break c}ca=V-$|0;ga=ca>>>0>ea>>>0?ea:ca;UGb(C+X|0,$|0,ga)|0;ca=(c[q>>2]|0)+ga|0;c[q>>2]=ca;ha=fa;ia=ca;break}ca=-da|0;if((V-$|0)<1){ja=0;ka=$}else{ga=Z+2|0;c[q>>2]=ga;ja=a[$]|0;ka=ga}if((V-ka|0)<1){la=0;ma=ka}else{ga=ka+1|0;c[q>>2]=ga;la=a[ka]|0;ma=ga}if((V-ma|0)<1){na=0;oa=ma}else{ga=ma+1|0;c[q>>2]=ga;na=a[ma]|0;oa=ga}if((V-oa|0)<1){pa=0;qa=oa}else{ga=oa+1|0;c[q>>2]=ga;pa=a[oa]|0;qa=ga}ra=(ca<<2)+X|0;if((ra|0)>(N|0)|(ra|0)<0){A=65;break c}if(aa<<24>>24==0){ha=X;ia=qa;break}else{sa=X;ta=ca}while(1){ca=ta-1|0;a[C+sa|0]=ja;a[C+(sa+1)|0]=la;a[C+(sa+2)|0]=na;a[C+(sa+3)|0]=pa;if((ca|0)==0){break}else{sa=sa+4|0;ta=ca}}ha=X-(da<<2)|0;ia=c[q>>2]|0}}while(0);if((A|0)==50){A=0;if((V-_|0)<1){ua=-4;va=_}else{ca=_+1|0;c[q>>2]=ca;ua=((d[_]|0)<<2)-4|0;va=ca}wa=ua+X|0;if((wa|0)>(N|0)|(wa|0)<0){A=53;break c}else{ha=wa;ia=va}}X=ha;Y=c[s>>2]|0;Z=ia}if((S|0)==0){break b}else{O=O+y|0;P=S;Q=Y;R=$}}if((A|0)==46){yDb(c[B>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=W,c[p+8>>2]=N,p)|0);i=p;break b}else if((A|0)==53){yDb(c[B>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=wa,c[p+8>>2]=N,p)|0);i=p;break b}else if((A|0)==65){yDb(c[B>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=ra,c[p+8>>2]=N,p)|0);i=p;break b}else if((A|0)==68){yDb(c[B>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=fa,c[p+8>>2]=N,p)|0);i=p;break b}break};case 32:{C=c[v>>2]|0;ca=k;aa=ba(L,y)|0;if((J|0)==0){break a}else{xa=x;ya=J;za=u;Aa=M}e:while(1){ga=ya-1|0;if((za-Aa|0)<1){Ba=-4;Ca=Aa}else{ea=Aa+1|0;c[q>>2]=ea;Ba=((d[Aa]|0)<<2)-4|0;Ca=ea}Da=Ba+xa|0;if((Da|0)>(aa|0)|(Da|0)<0){A=140;break}else{Ea=Da;Fa=za;Ga=Ca}f:while(1){ea=Fa;do{if((ea-Ga|0)<1){Ha=Ga;A=145}else{Ia=Ga+1|0;c[q>>2]=Ia;Ja=a[Ga]|0;Ka=(Ja&255)<<24;La=Ja<<24>>24;if((La|0)==0){Ha=Ia;A=145;break}else if((La|0)==(-1|0)){break f}if((Ka|0)<0){Ma=-La|0;if((ea-Ia|0)<4){Na=0}else{c[q>>2]=Ga+5;Oa=Ia;Na=fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0}Pa=(Ma<<2)+Ea|0;if((Pa|0)>(aa|0)|(Pa|0)<0){A=155;break e}if(Ja<<24>>24==0){Qa=Ea;break}else{Ra=Ea;Sa=Ma}while(1){Ma=Sa-1|0;c[C+Ra>>2]=Na;if((Ma|0)==0){break}else{Ra=Ra+4|0;Sa=Ma}}Qa=Ea-(La<<2)|0;break}Ta=(Ka>>22)+Ea|0;if((Ta|0)>(aa|0)|(Ta|0)<0){A=159;break e}if(Ja<<24>>24==0){Qa=Ea;break}else{Ua=Ea;Va=La;Wa=Fa;Xa=Ia}while(1){da=Va-1|0;if((Wa-Xa|0)<4){Ya=0}else{c[q>>2]=Xa+4;Ma=Xa;Ya=fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0}c[C+Ua>>2]=Ya;if((da|0)==0){break}Ua=Ua+4|0;Va=da;Wa=c[s>>2]|0;Xa=c[q>>2]|0}Qa=(La<<2)+Ea|0}}while(0);if((A|0)==145){A=0;if((ea-Ha|0)<1){Za=-4}else{c[q>>2]=Ha+1;Za=((d[Ha]|0)<<2)-4|0}_a=Za+Ea|0;if((_a|0)>(aa|0)|(_a|0)<0){A=149;break e}else{Qa=_a}}Ea=Qa;Fa=c[s>>2]|0;Ga=c[q>>2]|0}if((ga|0)==0){break a}else{xa=xa+y|0;ya=ga;za=Fa;Aa=Ia}}if((A|0)==140){yDb(c[ca>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=Da,c[p+8>>2]=aa,p)|0);i=p;break a}else if((A|0)==149){yDb(c[ca>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=_a,c[p+8>>2]=aa,p)|0);i=p;break a}else if((A|0)==155){yDb(c[ca>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=Pa,c[p+8>>2]=aa,p)|0);i=p;break a}else if((A|0)==159){yDb(c[ca>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=Ta,c[p+8>>2]=aa,p)|0);i=p;break a}break};case 16:{C=c[v>>2]|0;N=ba(L,y)|0;if((J|0)==0){break a}else{$a=x;ab=J;bb=M}g:while(1){B=ab-1|0;if((w-bb|0)<1){cb=-2;db=bb}else{S=bb+1|0;c[q>>2]=S;cb=((d[bb]|0)<<1)-2|0;db=S}eb=cb+$a|0;if((eb|0)>(N|0)|(eb|0)<0){A=76;break}else{fb=eb;gb=db}h:while(1){i:do{if((w-gb|0)<1){hb=gb}else{S=gb;while(1){ib=S+1|0;c[q>>2]=ib;V=a[S]|0;Ja=(V&255)<<24;jb=V<<24>>24;if((jb|0)==(-1|0)){break h}else if((jb|0)==0){hb=ib;break i}if((Ja|0)<0){Ka=-jb|0;if((w-ib|0)<2){kb=0;lb=ib}else{da=S+3|0;c[q>>2]=da;Ma=ib;kb=de((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0;lb=da}mb=(Ka<<1)+fb|0;if((mb|0)>(N|0)|(mb|0)<0){A=91;break g}if(V<<24>>24==0){nb=lb}else{ob=fb;pb=Ka;A=92;break}}else{qb=(Ja>>23)+fb|0;if((qb|0)>(N|0)|(qb|0)<0){A=95;break g}if(V<<24>>24==0){nb=ib}else{rb=fb;sb=jb;tb=ib;break}}if((w-nb|0)<1){hb=nb;break i}else{S=nb}}if((A|0)==92){while(1){A=0;S=pb-1|0;b[C+ob>>1]=kb;if((S|0)==0){break}else{ob=ob+2|0;pb=S;A=92}}fb=fb-(jb<<1)|0;gb=lb;continue h}while(1){S=sb-1|0;if((w-tb|0)<2){ub=0;vb=tb}else{La=tb+2|0;c[q>>2]=La;V=tb;ub=de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0;vb=La}b[C+rb>>1]=ub;if((S|0)==0){break}else{rb=rb+2|0;sb=S;tb=vb}}fb=(jb<<1)+fb|0;gb=vb;continue h}}while(0);if((w-hb|0)<1){wb=-2;xb=hb}else{ea=hb+1|0;c[q>>2]=ea;wb=((d[hb]|0)<<1)-2|0;xb=ea}yb=wb+fb|0;if((yb|0)>(N|0)|(yb|0)<0){A=84;break g}else{fb=yb;gb=xb}}if((B|0)==0){break a}else{$a=$a+y|0;ab=B;bb=ib}}if((A|0)==76){yDb(K,16,2105928,(p=i,i=i+16|0,c[p>>2]=eb,c[p+8>>2]=N,p)|0);i=p;break a}else if((A|0)==84){yDb(K,16,2105928,(p=i,i=i+16|0,c[p>>2]=yb,c[p+8>>2]=N,p)|0);i=p;break a}else if((A|0)==91){yDb(K,16,2105928,(p=i,i=i+16|0,c[p>>2]=mb,c[p+8>>2]=N,p)|0);i=p;break a}else if((A|0)==95){yDb(K,16,2105928,(p=i,i=i+16|0,c[p>>2]=qb,c[p+8>>2]=N,p)|0);i=p;break a}break};case 24:{C=c[v>>2]|0;aa=k;ca=ba(L,y)|0;if((J|0)==0){break a}else{zb=x;Ab=J;Bb=u;Cb=M}j:while(1){ga=Ab-1|0;if((Bb-Cb|0)<1){Db=-3;Eb=Cb}else{ea=Cb+1|0;c[q>>2]=ea;Db=((d[Cb]|0)*3|0)-3|0;Eb=ea}Fb=Db+zb|0;if((Fb|0)>(ca|0)|(Fb|0)<0){A=104;break}else{Gb=Fb;Hb=Bb;Ib=Eb}k:while(1){ea=Hb;l:do{if((ea-Ib|0)<1){Jb=Ib;A=107}else{Kb=Ib+1|0;c[q>>2]=Kb;S=a[Ib]|0;La=S<<24>>24;if((La|0)==(-1|0)){break k}else if((La|0)==0){Jb=Kb;A=107;break}if(S<<24>>24<0){if((ea-Kb|0)<1){Lb=0;Mb=Kb}else{V=Ib+2|0;c[q>>2]=V;Lb=a[Kb]|0;Mb=V}if((ea-Mb|0)<1){Nb=0;Ob=Mb}else{V=Mb+1|0;c[q>>2]=V;Nb=a[Mb]|0;Ob=V}if((ea-Ob|0)<1){Pb=0}else{c[q>>2]=Ob+1;Pb=a[Ob]|0}Qb=(La*-3|0)+Gb|0;if((Qb|0)>(ca|0)|(Qb|0)<0){A=122;break j}if(S<<24>>24==0){Rb=Gb;break}V=Gb;Ja=-La|0;while(1){Ka=Ja-1|0;a[C+V|0]=Lb;a[C+(V+1)|0]=Nb;a[C+(V+2)|0]=Pb;if((Ka|0)==0){Rb=Qb;break}else{V=V+3|0;Ja=Ka}}}else{Sb=(La*3|0)+Gb|0;if((Sb|0)>(ca|0)|(Sb|0)<0){A=126;break j}if(S<<24>>24==0){Rb=Gb;break}else{Tb=Gb;Ub=La;Vb=Hb;Wb=Kb}while(1){Ja=Ub-1|0;if((Vb-Wb|0)<1){Xb=0}else{c[q>>2]=Wb+1;Xb=a[Wb]|0}a[C+Tb|0]=Xb;V=c[q>>2]|0;if(((c[s>>2]|0)-V|0)<1){Yb=0}else{c[q>>2]=V+1;Yb=a[V]|0}a[C+(Tb+1)|0]=Yb;V=c[q>>2]|0;if(((c[s>>2]|0)-V|0)<1){Zb=0}else{c[q>>2]=V+1;Zb=a[V]|0}a[C+(Tb+2)|0]=Zb;if((Ja|0)==0){Rb=Sb;break l}Tb=Tb+3|0;Ub=Ja;Vb=c[s>>2]|0;Wb=c[q>>2]|0}}}}while(0);if((A|0)==107){A=0;if((ea-Jb|0)<1){_b=-3}else{c[q>>2]=Jb+1;_b=((d[Jb]|0)*3|0)-3|0}$b=_b+Gb|0;if(($b|0)>(ca|0)|($b|0)<0){A=111;break j}else{Rb=$b}}Gb=Rb;Hb=c[s>>2]|0;Ib=c[q>>2]|0}if((ga|0)==0){break a}else{zb=zb+y|0;Ab=ga;Bb=Hb;Cb=Kb}}if((A|0)==104){yDb(c[aa>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=Fb,c[p+8>>2]=ca,p)|0);i=p;break a}else if((A|0)==111){yDb(c[aa>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=$b,c[p+8>>2]=ca,p)|0);i=p;break a}else if((A|0)==122){yDb(c[aa>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=Qb,c[p+8>>2]=ca,p)|0);i=p;break a}else if((A|0)==126){yDb(c[aa>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=Sb,c[p+8>>2]=ca,p)|0);i=p;break a}break};case 1:case 33:{C=c[v>>2]|0;N=k;B=ba(L,y)|0;La=x-y|0;S=J+1|0;if((S|0)==0){break a}else{ac=La;bc=S;cc=La;dc=u;ec=M}m:while(1){La=dc;if((La-ec|0)<1){fc=0;gc=ec}else{S=ec+1|0;c[q>>2]=S;fc=d[ec]|0;gc=S}if((La-gc|0)<1){break a}S=gc+1|0;c[q>>2]=S;Ja=a[gc]|0;V=(Ja&255)<<24;Ka=Ja<<24>>24;if(Ja<<24>>24==0){break a}if((fc&128|0)==0){hc=cc;ic=bc;jc=(fc<<1)+ac|0}else{da=cc+y|0;hc=da;ic=bc-1|0;jc=(fc<<1&254)+da|0}if((jc|0)>(B|0)|(jc|0)<0){A=25;break}do{if(Ja<<24>>24==-1){kc=jc}else{if((V|0)>=0){da=V>>23;lc=jc+da|0;if((lc|0)>(B|0)|(lc|0)<0){A=38;break m}Ma=La-S|0;Oa=Ma>>>0>da>>>0?da:Ma;UGb(C+jc|0,S|0,Oa)|0;c[q>>2]=(c[q>>2]|0)+Oa;kc=lc;break}Oa=-Ka|0;if((La-S|0)<1){mc=0;nc=S}else{Ma=gc+2|0;c[q>>2]=Ma;mc=a[S]|0;nc=Ma}if((La-nc|0)<1){oc=0}else{c[q>>2]=nc+1;oc=a[nc]|0}pc=jc+(Oa<<1)|0;if((pc|0)>(B|0)|(pc|0)<0){A=35;break m}else{qc=jc;rc=Oa}while(1){Oa=rc-1|0;a[C+qc|0]=mc;a[C+(qc+1)|0]=oc;if((Oa|0)==0){break}else{qc=qc+2|0;rc=Oa}}kc=jc-(Ka<<1)|0}}while(0);if((ic|0)==0){break a}ac=kc;bc=ic;cc=hc;dc=c[s>>2]|0;ec=c[q>>2]|0}if((A|0)==25){yDb(c[N>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=jc,c[p+8>>2]=B,p)|0);i=p;break a}else if((A|0)==35){yDb(c[N>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=pc,c[p+8>>2]=B,p)|0);i=p;break a}else if((A|0)==38){yDb(c[N>>2]|0,16,2105928,(p=i,i=i+16|0,c[p>>2]=lc,c[p+8>>2]=B,p)|0);i=p;break a}break};case 2:case 34:{JTa(l,x,J,2);break};case 4:case 36:{JTa(l,x,J,4);break};default:{yDb(K,16,2183056,(p=i,i=i+8|0,c[p>>2]=F,p)|0);i=p;break a}}}while(0);F=HZ(h,0,0)|0;x=c[o>>2]|0;if((F|0)==0){sc=k+20|0}else{c[x+304>>2]=1;y=k+20|0;UGb(y|0,F|0,1024)|0;sc=y}UGb(c[x+4>>2]|0,sc|0,1024)|0}}while(0);sc=MCb(f,c[o>>2]|0)|0;if((sc|0)<0){t=sc;i=j;return t|0}c[g>>2]=1;t=c[n>>2]|0;i=j;return t|0}function ITa(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function JTa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;h=i;i=i+16|0;j=h|0;k=c[b+4>>2]|0;l=c[k+32>>2]|0;m=c[k>>2]|0;k=b|0;n=ba(c[(c[k>>2]|0)+124>>2]|0,l)|0;o=(g|0)==4;p=o?8:16;if((f|0)==0){i=h;return}q=b+12|0;r=b+8|0;b=p-1|0;s=(1<<g)+255|0;t=p>>>2;u=t-1|0;v=j|0;w=e;e=f;f=c[q>>2]|0;x=c[r>>2]|0;a:while(1){y=e-1|0;if((f-x|0)<1){z=-1;A=x}else{B=x+1|0;c[r>>2]=B;z=(d[x]|0)-1|0;A=B}C=(ba(z,p)|0)+w|0;if((C|0)>(n|0)|(C|0)<0){D=6;break}else{E=C;F=f;G=A}b:while(1){B=F;c:do{if((B-G|0)<1){H=G;D=10}else{I=G+1|0;c[r>>2]=I;J=a[G]|0;K=(J&255)<<24;L=J<<24>>24;if((L|0)==(-1|0)){break b}else if((L|0)==0){H=I;D=10;break}if((K|0)<0){M=b;N=I;while(1){O=B-N|0;if((O|0)<1){P=0}else{P=d[N]|0}a[j+(b-M)|0]=P>>>(((ba(M,g)|0)&7)>>>0)&s;Q=(M&u|0)==0|0;R=N+(O>>>0>Q>>>0?Q:O)|0;c[r>>2]=R;if((M|0)>0){M=M-1|0;N=R}else{break}}N=-L|0;S=(ba(p,N)|0)+E|0;if((S|0)>(n|0)|(S|0)<0){D=22;break a}if(J<<24>>24==0){T=E;break}M=ba(p,L)|0;R=E;O=N;while(1){N=O-1|0;UGb(m+R|0,v|0,p)|0;if((N|0)==0){break}else{R=R+p|0;O=N}}T=E-M|0;break}O=K>>22;U=(ba(O,t)|0)+E|0;if((U|0)>(n|0)|(U|0)<0){D=31;break a}R=O-1|0;if((O|0)==0){T=E;break}if(o){O=E;L=R;J=F;N=I;while(1){if((J-N|0)<1){V=0;W=0}else{c[r>>2]=N+1;Q=a[N]|0;V=(Q&255)>>>4;W=Q&15}a[m+O|0]=V;Q=O+2|0;a[m+(O+1)|0]=W;if((L|0)==0){T=Q;break c}O=Q;L=L-1|0;J=c[q>>2]|0;N=c[r>>2]|0}}else{N=E;J=R;L=F;O=I;while(1){if((L-O|0)<1){X=0;Y=0;Z=0;_=0}else{c[r>>2]=O+1;K=a[O]|0;X=(K&255)>>>6;Y=(K&255)>>>4&3;Z=(K&255)>>>2&3;_=K&3}a[m+N|0]=X;a[m+(N+1)|0]=Y;a[m+(N+2)|0]=Z;K=N+4|0;a[m+(N+3)|0]=_;if((J|0)==0){T=K;break c}N=K;J=J-1|0;L=c[q>>2]|0;O=c[r>>2]|0}}}}while(0);if((D|0)==10){D=0;if((B-H|0)<1){$=-1}else{c[r>>2]=H+1;$=(d[H]|0)-1|0}aa=(ba($,p)|0)+E|0;if((aa|0)>(n|0)|(aa|0)<0){D=14;break a}else{T=aa}}E=T;F=c[q>>2]|0;G=c[r>>2]|0}if((y|0)==0){D=37;break}else{w=w+l|0;e=y;f=F;x=I}}if((D|0)==6){yDb(c[k>>2]|0,16,2105928,(ca=i,i=i+16|0,c[ca>>2]=C,c[ca+8>>2]=n,ca)|0);i=ca;i=h;return}else if((D|0)==14){yDb(c[k>>2]|0,16,2105928,(ca=i,i=i+16|0,c[ca>>2]=aa,c[ca+8>>2]=n,ca)|0);i=ca;i=h;return}else if((D|0)==22){yDb(c[k>>2]|0,16,2105928,(ca=i,i=i+16|0,c[ca>>2]=S,c[ca+8>>2]=n,ca)|0);i=ca;i=h;return}else if((D|0)==31){yDb(c[k>>2]|0,16,2105928,(ca=i,i=i+16|0,c[ca>>2]=U,c[ca+8>>2]=n,ca)|0);i=ca;i=h;return}else if((D|0)==37){i=h;return}}function KTa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;d=a+60|0;e=c[d>>2]|0;f=a+120|0;g=a+124|0;h=a;if((hDb(c[f>>2]|0,c[g>>2]|0,0,h)|0)<0){j=-22;i=b;return j|0}k=e;c[k>>2]=a;l=e+76|0;c[l>>2]=c[f>>2];m=a+140|0;n=c[m>>2]|0;if((n|0)==2){c[e+4>>2]=3;o=8}else if((n|0)==45){c[e+4>>2]=2;o=8}else if((n|0)==27){c[e+4>>2]=4;o=8}else if((n|0)==8){c[l>>2]=(c[f>>2]|0)/4|0;c[e+4>>2]=4;p=40}else{yDb(h,16,2183024,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;if((c[m>>2]|0)==8){p=40}else{o=8}}if((o|0)==8){p=c[e+4>>2]<<3}c[a+792>>2]=p;p=e+80|0;c[p>>2]=cEb(c[l>>2]|0)|0;o=e+88|0;c[o>>2]=cEb(c[l>>2]|0)|0;n=cEb((c[l>>2]<<2)+4|0)|0;c[e+84>>2]=n;do{if(!((c[o>>2]|0)==0|(n|0)==0)){if((c[p>>2]|0)==0){break}r=RZ(e+8|0,c[m>>2]|0,c[f>>2]|0,c[g>>2]|0)|0;if((r|0)<0){yDb(h,16,2048856,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=r;i=b;return j|0}r=c[l>>2]|0;s=c[(c[k>>2]|0)+124>>2]|0;c[e+72>>2]=((r|0)/127|0)+16+((ba(ba(s,r)|0,c[e+4>>2]|0)|0)+s<<1);s=ICb()|0;r=a+804|0;c[r>>2]=s;if((s|0)!=0){j=0;i=b;return j|0}s=c[d>>2]|0;JCb(r);SZ(s+8|0);ZDb(c[s+80>>2]|0);ZDb(c[s+84>>2]|0);ZDb(c[s+88>>2]|0);j=-12;i=b;return j|0}}while(0);yDb(h,16,2105896,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=-12;i=b;return j|0}function LTa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;h=c[b+60>>2]|0;i=c[b+804>>2]|0;j=r0a(b,e,c[h+72>>2]|0,0)|0;if((j|0)<0){k=j;return k|0}j=c[b+136>>2]|0;l=c[h>>2]|0;do{if((j|0)==0){m=4}else{if(((c[l+428>>2]|0)%(j|0)|0|0)==0){m=4;break}c[i+88>>2]=2;c[i+84>>2]=0}}while(0);if((m|0)==4){c[i+88>>2]=1;c[i+84>>2]=1}j=c[e+24>>2]|0;n=h;do{if((c[(c[l+804>>2]|0)+84>>2]|0)==0){o=ba(c[h+4>>2]|0,c[h+76>>2]|0)|0;p=f|0;q=c[l+124>>2]|0;r=f+32|0;s=h+8|0;t=h+40|0;u=0;while(1){if((u|0)>=(q|0)){v=q;break}w=(c[p>>2]|0)+(ba(c[r>>2]|0,u)|0)|0;if((PGb(w,(c[s>>2]|0)+(ba(c[t>>2]|0,u)|0)|0,o)|0)==0){u=u+1|0}else{v=q;break}}while(1){if((v|0)<=(u|0)){break}q=v-1|0;w=(c[p>>2]|0)+(ba(c[r>>2]|0,q)|0)|0;if((PGb(w,(c[s>>2]|0)+(ba(c[t>>2]|0,q)|0)|0,o)|0)==0){v=q}else{break}}o=j;x=0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;t=j+4|0;if((u|0)==0){y=v;z=o;A=t;m=15;break}B=v;C=u;D=o;E=t;F=c[(c[n>>2]|0)+124>>2]|0;m=16}else{t=c[l+124>>2]|0;o=j;x=0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;y=t;z=o;A=j+4|0;m=15}}while(0);if((m|0)==15){l=c[(c[n>>2]|0)+124>>2]|0;if((y|0)==(l|0)){G=y;H=0;I=z;J=A;m=17}else{B=y;C=0;D=z;E=A;F=l;m=16}}do{if((m|0)==16){if((C|0)==(F|0)){G=B;H=F;I=D;J=E;m=17;break}l=E;x=2048;a[l]=x;x=x>>8;a[l+1|0]=x;l=E+2|0;x=de(C&65535|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;l=E+4|0;x=0;a[l]=x;x=x>>8;a[l+1|0]=x;l=E+6|0;x=de(B-C&65535|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;l=E+8|0;x=0;a[l]=x;x=x>>8;a[l+1|0]=x;K=C;L=E+10|0;M=B;N=D}}while(0);if((m|0)==17){D=J;x=0;a[D]=x;x=x>>8;a[D+1|0]=x;K=H;L=J+2|0;M=G;N=I}if((K|0)<(M|0)){I=h+76|0;G=f|0;J=f+32|0;H=h+4|0;D=h+8|0;B=D;E=h+40|0;C=h+84|0;F=h+88|0;l=h+80|0;A=L;z=K;while(1){K=c[I>>2]|0;y=c[G>>2]|0;v=c[J>>2]|0;o=K-1|0;t=ba(c[H>>2]|0,o)|0;s=c[B>>2]|0;r=c[E>>2]|0;c[(c[C>>2]|0)+(K<<2)>>2]=0;if((K|0)>0){p=ba(r,z)|0;r=ba(v,z)|0;v=c[H>>2]|0;q=0;w=0;O=v+1|0;P=1073741823;Q=K;R=1073741823;S=K;T=y+(t+r)|0;r=s+(p+t)|0;t=o;p=v;while(1){v=t+127|0;s=(((K|0)>(v|0)?v:K)|0)<(Q|0);v=s?R:P;U=s?S:Q;V=s?1073741823:R;W=s?K:S;s=(t|0)==0;if(s){X=V+1|0;Y=v+1|0;Z=O+1|0}else{X=V;Y=v;Z=O}v=t+1|0;V=c[C>>2]|0;_=(c[V+(v<<2)>>2]|0)+Z|0;if((_|0)>(X|0)){$=W;aa=X;ca=U;da=Y}else{ea=(_|0)>(Y|0);$=ea?v:W;aa=ea?_:1073741823;ca=ea?U:v;da=ea?Y:_}do{if((c[(c[(c[n>>2]|0)+804>>2]|0)+84>>2]|0)==0){if((PGb(T,r,p)|0)!=0){fa=0;break}_=q+1|0;fa=_>>>0>254>>>0?254:_}else{fa=0}}while(0);_=c[V+(fa+t<<2)>>2]|0;ea=_+2|0;a[(c[F>>2]|0)+t|0]=fa;v=c[H>>2]|0;do{if((t|0)<(o|0)){if((PGb(T,T+v|0,v)|0)!=0){ga=1;break}U=w+1|0;ga=U>>>0>128>>>0?128:U}else{ga=1}}while(0);V=c[C>>2]|0;U=v+1+(c[V+(ga+t<<2)>>2]|0)|0;if(s){ha=U+1|0;ia=_+1|0}else{ha=U;ia=ea}do{if(ga>>>0>1>>>0){if(!((fa|0)==0|(ha|0)<(ia|0))){m=39;break}c[V+(t<<2)>>2]=ha;a[(c[l>>2]|0)+t|0]=-ga}else{m=39}}while(0);do{if((m|0)==39){m=0;ea=V+(t<<2)|0;if((fa|0)==0){c[ea>>2]=da;a[(c[l>>2]|0)+t|0]=ca-t;break}else{c[ea>>2]=ia;a[(c[l>>2]|0)+t|0]=0;break}}}while(0);V=c[H>>2]|0;ea=-V|0;if((t|0)>0){q=fa;w=ga;O=Z;P=V+da|0;Q=ca;R=V+aa|0;S=$;T=T+ea|0;r=r+ea|0;t=t-1|0;p=V}else{break}}ja=c[G>>2]|0}else{ja=y}p=ba(c[J>>2]|0,z)|0;if((a[c[l>>2]|0]|0)==0){a[A]=(a[c[F>>2]|0]|0)+1;ka=d[c[F>>2]|0]|0}else{a[A]=1;ka=0}t=A+1|0;if((ka|0)<(K|0)){r=ka;T=t;while(1){S=a[(c[l>>2]|0)+r|0]|0;R=S<<24>>24;a[T]=S;Q=T+1|0;do{if(S<<24>>24==0){a[Q]=(a[(c[F>>2]|0)+r|0]|0)+1;la=(d[(c[F>>2]|0)+r|0]|0)+r|0;ma=T+2|0}else{P=(c[(c[n>>2]|0)+140>>2]|0)==8;O=c[H>>2]|0;if(S<<24>>24>0){do{if(P){if((ba(O,R)|0)>0){na=0;oa=O;pa=Q}else{qa=Q;break}while(1){a[pa]=~a[ja+(na+p+(ba(oa,r)|0))|0];w=pa+1|0;q=na+1|0;o=c[H>>2]|0;if((q|0)<(ba(o,R)|0)){na=q;oa=o;pa=w}else{qa=w;break}}}else{w=ba(O,R)|0;UGb(Q|0,ja+((ba(O,r)|0)+p)|0,w)|0;qa=T+(w+1)|0}}while(0);la=R+r|0;ma=qa;break}else{do{if(P){if((O|0)>0){ra=0;sa=O;ta=Q}else{ua=Q;break}while(1){a[ta]=~a[ja+(ra+p+(ba(sa,r)|0))|0];w=ta+1|0;o=ra+1|0;q=c[H>>2]|0;if((o|0)<(q|0)){ra=o;sa=q;ta=w}else{ua=w;break}}}else{UGb(Q|0,ja+((ba(O,r)|0)+p)|0,O)|0;ua=T+(O+1)|0}}while(0);la=r-R|0;ma=ua;break}}}while(0);if((la|0)<(K|0)){r=la;T=ma}else{va=ma;break}}}else{va=t}a[va]=-1;T=va+1|0;r=z+1|0;if((r|0)<(M|0)){A=T;z=r}else{wa=T;xa=D;break}}}else{wa=L;xa=h+8|0}a[wa]=0;h=wa+1-j|0;x=fe(h|0)|0;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[e+28>>2]=h;TZ(xa,f,c[b+140>>2]|0,c[b+120>>2]|0,c[b+124>>2]|0);if((c[i+84>>2]|0)!=0){i=e+36|0;c[i>>2]=c[i>>2]|1}c[g>>2]=1;k=0;return k|0}function MTa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(a+804|0);SZ(b+8|0);ZDb(c[b+80>>2]|0);ZDb(c[b+84>>2]|0);ZDb(c[b+88>>2]|0);return 0}function NTa(a){a=a|0;c[a+140>>2]=42;c[a+796>>2]=10;return 0}function OTa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;h=c[f+24>>2]|0;j=a+120|0;k=a+48|0;l=(c[k>>2]|0)==146?1:64;m=(c[j>>2]|0)-1+l&-l;l=f+28|0;f=a+124|0;if((c[l>>2]|0)<(ba(c[f>>2]<<2,m)|0)){yDb(a,16,1965792,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}n=_$a(a,d,0)|0;if((n|0)<0){o=n;i=g;return o|0}c[d+88>>2]=1;c[d+84>>2]=1;n=c[f>>2]|0;if((n|0)>0){f=c[j>>2]|0;j=(f|0)>0;a=c[d+32>>2]|0;p=0;q=h;h=c[d>>2]|0;while(1){d=h;if(j){r=c[k>>2]|0;s=(f|0)>1?f:1;if((r|0)==1096176208){t=0;u=q;v=d;while(1){w=c[u>>2]|0;b[v>>1]=w>>>16&65535&-64|w>>>26&65535;b[v+2>>1]=w>>>6&65535&-64|w>>>16&63;b[v+4>>1]=w>>>6&63|w<<4&65535;w=t+1|0;if((w|0)<(f|0)){t=w;u=u+4|0;v=v+6|0}else{break}}}else{v=0;u=q;t=d;w=r;while(1){x=fe(c[u>>2]|0)|0;if((w|0)==134){y=x<<6&65535;z=x>>>4&65535;A=134;B=x>>>14&65535}else{y=x<<4&65535;z=x>>>6&65535;A=w;B=x>>>16&65535}b[t>>1]=B&-64|(B&65535)>>>10;b[t+2>>1]=z&-64|(z&65535)>>>10;b[t+4>>1]=(y&65535)>>>10|y;x=v+1|0;if((x|0)<(f|0)){v=x;u=u+4|0;t=t+6|0;w=A}else{break}}}C=q+(s<<2)|0}else{C=q}w=p+1|0;if((w|0)<(n|0)){p=w;q=C+(m-f<<2)|0;h=h+a|0}else{break}}}c[e>>2]=1;o=c[l>>2]|0;i=g;return o|0}function PTa(a){a=a|0;var b=0;b=ICb()|0;c[a+804>>2]=b;return((b|0)==0?-12:0)|0}function QTa(b,d,f,g){b=b|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;h=b+120|0;i=c[h>>2]|0;j=b+48|0;k=(c[j>>2]|0)==146?1:64;l=i-1+k&-k;k=l-i<<2;i=b+124|0;m=ba(c[i>>2]<<2,l)|0;l=r0a(b,d,m,(m|0)<0|0?-1:0)|0;if((l|0)<0){n=l;return n|0}l=c[b+804>>2]|0;c[l+84>>2]=1;c[l+88>>2]=1;if((c[i>>2]|0)>0){l=f+32|0;b=c[d+24>>2]|0;m=c[f>>2]|0;f=0;while(1){if((c[h>>2]|0)>0){o=b;p=m;q=0;while(1){r=(e[p+2>>1]|0)>>>6;s=p+6|0;t=(e[p+4>>1]|0)>>>4;u=c[j>>2]|0;v=(e[p>>1]|0)>>>6&65535;do{if((u|0)==134){w=(r&65535)<<10|v<<20|(t&65535)>>>2;y=10}else{z=(r&65535)<<12|v<<22|t&65535;if((u|0)!=1096176208){w=z;y=10;break}A=o;x=z;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x}}while(0);if((y|0)==10){y=0;u=o;x=fe(w|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x}u=o+4|0;t=q+1|0;if((t|0)<(c[h>>2]|0)){o=u;p=s;q=t}else{B=u;break}}}else{B=b}TGb(B|0,0,k|0)|0;q=f+1|0;if((q|0)<(c[i>>2]|0)){b=B+k|0;m=m+(c[l>>2]|0)|0;f=q}else{break}}}f=d+36|0;c[f>>2]=c[f>>2]|1;c[g>>2]=1;n=0;return n|0}function RTa(a){a=a|0;$Db(a+804|0);return 0}function STa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;Z3(b+4|0,a);c[b+1388>>2]=b+1308;c[b+1392>>2]=b+1348;c[a+416>>2]=1;b=a+448|0;c[b>>2]=4;c[b+4>>2]=0;c[a+420>>2]=1;return 0}function TTa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=i;i=i+136|0;j=h|0;k=h+16|0;l=h+96|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[a+60>>2]|0;o=g;if((n|0)<20){yDb(a,16,2182888,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;c[f>>2]=0;q=-1094995529;i=h;return q|0}c[e+76>>2]=160;p=_$a(a,e,0)|0;if((p|0)<0){q=p;i=h;return q|0}p=c[e>>2]|0;e=(m|0)==0?8:168;a=0;n=0;do{r=d[549664+n|0]|0;s=m+(a>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(a&7)>>>((32-r|0)>>>0);s=r+a|0;a=e>>>0>s>>>0?s:e;c[l+(n<<2)>>2]=b[(c[1191952+(n<<2)>>2]|0)+(t<<1)>>1]|0;n=n+1|0;}while((n|0)<10);n=g+1388|0;t=l|0;dnb(c[n>>2]|0,t);l=g+1396|0;c[l>>2]=gnb(t)|0;t=m+(a>>>3)|0;s=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(a&7)>>>27;t=a+5|0;a=b[1222664+(s<<1)>>1]|0;s=g+1304|0;r=hnb(o,k|0,1,1,c[s>>2]|0)|0;c[j>>2]=r;u=c[s>>2]|0;c[j+4>>2]=hnb(o,k+20|0,2,a>>>0<=u>>>0|0,(fnb(ba(u,a)|0)|0)>>12)|0;c[j+8>>2]=hnb(o,k+40|0,3,0,a)|0;c[j+12>>2]=inb(c[l>>2]|0,a)|0;enb(k+60|0,c[n>>2]|0);u=g+1724|0;v=e>>>0>t>>>0?t:e;t=p;p=0;w=r;while(1){r=m+(v>>>3)|0;x=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(v&7)>>>25;r=v+7|0;y=e>>>0>r>>>0?r:e;r=m+(y>>>3)|0;z=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(y&7)>>>24;r=y+8|0;y=e>>>0>r>>>0?r:e;r=m+(y>>>3)|0;A=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(y&7)>>>25;r=y+7|0;y=e>>>0>r>>>0?r:e;r=m+(y>>>3)|0;B=y+7|0;C=e>>>0>B>>>0;knb(o,k+(p*20|0)|0,x,A,(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(y&7)>>>25,w,z);z=t;y=0;while(1){r=b[u+(y+10<<1)>>1]|0;A=r<<2;if((A+32768|0)>>>0>65535>>>0){D=(r>>29^32767)&65535}else{D=A&65535}b[z>>1]=D;A=y+1|0;if((A|0)<40){z=z+2|0;y=A}else{break}}y=p+1|0;if((y|0)>=4){break}v=C?B:e;t=t+80|0;p=y;w=c[j+(y<<2)>>2]|0}c[s>>2]=a;c[g+1400>>2]=c[l>>2];l=g+1392|0;g=c[l>>2]|0;c[l>>2]=c[n>>2];c[n>>2]=g;c[f>>2]=1;q=20;i=h;return q|0}function UTa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+416>>2]|0;if((d|0)!=1){yDb(a,16,2048744,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;f=-1;i=b;return f|0}e=a+424|0;c[e>>2]=160;c[a+116>>2]=160;c[a+72>>2]=8e3;d=a+60|0;g=c[d>>2]|0;c[g+1388>>2]=g+1308;c[g+1392>>2]=g+1348;c[g>>2]=a;Z3(g+4|0,a);h=FKa(g+1248|0,c[e>>2]|0,10,2)|0;if((h|0)<0){e=c[d>>2]|0;EKa(e+1248|0);Rhb(e+1276|0);f=h;i=b;return f|0}else{Qhb(a,g+1276|0);f=0;i=b;return f|0}return 0}function VTa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0.0,ta=0.0,ua=0.0,va=0,wa=0,xa=0,ya=0.0,za=0.0,Aa=0.0,Ba=0.0,Ca=0.0,Da=0,Ea=0.0,Fa=0.0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0.0,Qa=0.0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0;l=i;i=i+3640|0;m=l|0;n=l+8|0;o=l+168|0;p=l+328|0;q=l+488|0;r=l+648|0;s=l+848|0;t=l+888|0;u=l+1048|0;v=l+1208|0;w=l+1368|0;y=l+1528|0;z=l+1536|0;A=l+1544|0;B=l+2184|0;C=l+3464|0;D=l+3504|0;E=l+3584|0;F=l+3624|0;G=c[f+60>>2]|0;H=G;I=(j|0)!=0;if(I){J=c[j>>2]|0}else{J=0}K=G+1300|0;if((c[K>>2]|0)!=0){L=0;i=l;return L|0}M=r0a(f,h,20,0)|0;if((M|0)<0){L=M;i=l;return L|0}M=G+1404|0;N=M;O=0;P=0;do{Q=b[N+(O+60<<1)>>1]|0;c[A+(O<<2)>>2]=Q;P=((ba(Q,Q)|0)>>>4)+P|0;O=O+1|0;}while((O|0)<100);do{if(I){O=c[j+76>>2]|0;if((O|0)<=0){R=100;S=P;T=12;break}Q=(O|0)>1?-O|0:-1;U=Q>>>0>4294967236>>>0;V=100;W=P;X=0;do{Y=b[J+(X<<1)>>1]>>2;c[A+(V<<2)>>2]=Y;W=((ba(Y,Y)|0)>>>4)+W|0;V=V+1|0;X=X+1|0;}while((X|0)<(O|0)&(V|0)<160);V=U?100-Q|0:160;if((V|0)<160){R=V;S=W;T=12}else{Z=W}}else{R=100;S=P;T=12}}while(0);if((T|0)==12){TGb(A+(R<<2)|0,0,160-R<<2|0)|0;Z=S}S=(fnb(Z>>5)|0)>>10;Z=b[611347]|0;R=31;T=0;P=15;V=Z-S|0;do{O=(V|0)>0;R=O?P:R;T=O?T:P;P=(R+T|0)>>>1;V=(b[1222664+(P<<1)>>1]|0)-S|0;}while((P|0)!=(T|0));P=b[1222664+((((b[1222664+(R<<1)>>1]|0)+V|0)>(S|0)?T:R)<<1)>>1]|0;DKa(G+1248|0,A|0,160,10,10,16,B|0,C|0,2,0,0,12,0)|0;A=12-(c[C+36>>2]|0)|0;C=D+60|0;b[C>>1]=-(c[B+1152>>2]<<A);b[D+62>>1]=-(c[B+1156>>2]<<A);b[D+64>>1]=-(c[B+1160>>2]<<A);b[D+66>>1]=-(c[B+1164>>2]<<A);b[D+68>>1]=-(c[B+1168>>2]<<A);b[D+70>>1]=-(c[B+1172>>2]<<A);b[D+72>>1]=-(c[B+1176>>2]<<A);b[D+74>>1]=-(c[B+1180>>2]<<A);b[D+76>>1]=-(c[B+1184>>2]<<A);b[D+78>>1]=-(c[B+1188>>2]<<A);A=P<<16>>16;P=E|0;do{if((cnb(P,C,f)|0)!=0){enb(C,c[G+1392>>2]|0);if((cnb(P,C,f)|0)==0){break}TGb(E|0,0,40)|0}}while(0);B=h+28|0;R=0;T=(c[B>>2]|0)<0?0:c[h+24>>2]|0;S=32;V=0;O=0;while(1){X=E+(V<<2)|0;Y=c[X>>2]|0;_=c[1191952+(V<<2)>>2]|0;$=(d[549632+V|0]|0)-1|0;aa=$>>>1;ca=(b[_+(aa<<1)>>1]|0)-Y|0;if((aa|0)==0){da=$;ea=0;fa=ca}else{ga=$;$=0;ha=aa;aa=ca;while(1){ca=(aa|0)>0;ia=ca?ha:ga;ja=ca?$:ha;ca=(ia+ja|0)>>>1;ka=(b[_+(ca<<1)>>1]|0)-Y|0;if((ca|0)==(ja|0)){da=ia;ea=ja;fa=ka;break}else{ga=ia;$=ja;ha=ca;aa=ka}}}aa=((b[_+(da<<1)>>1]|0)+fa|0)>(Y|0)?ea:da;ha=d[549648+V|0]|0;if((S|0)>(ha|0)){la=S;ma=aa|O<<ha;na=T}else{$=T;x=fe(aa>>>((ha-S|0)>>>0)|O<<S|0)|0;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;la=S+32|0;ma=aa;na=T+4|0}oa=la-ha|0;R=ma;c[X>>2]=b[_+(aa<<1)>>1]|0;aa=V+1|0;if((aa|0)<10){T=na;S=oa;V=aa;O=ma}else{break}}O=G+1396|0;c[O>>2]=gnb(P)|0;V=G+1388|0;dnb(c[V>>2]|0,P);P=G+1304|0;c[F>>2]=hnb(H,D|0,1,1,c[P>>2]|0)|0;S=c[P>>2]|0;c[F+4>>2]=hnb(H,D+20|0,2,A>>>0<=S>>>0|0,(fnb(ba(S,A)|0)|0)>>12)|0;c[F+8>>2]=hnb(H,D+40|0,3,0,A)|0;c[F+12>>2]=inb(c[O>>2]|0,A)|0;enb(C,c[V>>2]|0);C=31;S=0;T=15;la=Z-A|0;do{Z=(la|0)>0;C=Z?T:C;S=Z?S:T;T=(C+S|0)>>>1;la=(b[1222664+(T<<1)>>1]|0)-A|0;}while((T|0)!=(S|0));T=((b[1222664+(C<<1)>>1]|0)+la|0)>(A|0)?S:C;if((oa|0)>5){pa=oa-5|0;qa=T|ma<<5;ra=na}else{C=na;x=fe(T>>>((5-oa|0)>>>0)|ma<<oa|0)|0;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;pa=oa+27|0;qa=T;ra=na+4|0}R=qa;na=M;M=q;T=r;oa=t;C=u;ma=v;S=w;la=r+40|0;Z=s|0;da=q|0;ea=la;fa=p;E=p|0;aa=G+1824|0;ha=G+2128|0;$=G+4|0;ga=n;W=n|0;n=v|0;Q=w|0;U=o|0;ka=ra;ra=pa;pa=0;ca=qa;while(1){qa=pa*40|0;ja=c[F+(pa<<2)>>2]|0;TGb(M|0,0,160)|0;ia=0;do{g[r+(ia<<2)>>2]=+(b[H+1724+(ia+40<<1)>>1]|0);g[s+(ia<<2)>>2]=+(b[D+(pa*20|0)+(ia<<1)>>1]|0)*.000244140625;ia=ia+1|0;}while((ia|0)<10);y$(la,Z,da,40,10);UGb(oa|0,ea|0,160)|0;ia=0;do{g[q+(ia<<2)>>2]=+(b[na+(ia+qa<<1)>>1]|0)- +g[r+(ia+10<<2)>>2];ia=ia+1|0;}while((ia|0)<40);TGb(T|0,0,40)|0;sa=0.0;ia=20;_=0;ta=0.0;ua=0.0;while(1){X=146-ia|0;Y=(ia|0)<40;va=Y?ia:40;if((va|0)>0){wa=0;do{g[p+(wa<<2)>>2]=+(b[H+1824+(wa+X<<1)>>1]|0);wa=wa+1|0;}while((wa|0)<(va|0))}do{if(Y){va=40-ia|0;if((va|0)>0){xa=0}else{break}do{g[p+(xa+ia<<2)>>2]=+(b[H+1824+(xa+X<<1)>>1]|0);xa=xa+1|0;}while((xa|0)<(va|0))}}while(0);y$(la,Z,E,40,10);ya=0.0;za=0.0;X=0;do{Aa=+g[r+(X+10<<2)>>2];za=za+Aa*Aa;ya=ya+Aa*+g[q+(X<<2)>>2];X=X+1|0;}while((X|0)<40);if(ya>0.0){Aa=ya/za;Ba=ya*Aa;Ca=Aa}else{Ba=0.0;Ca=sa}X=Ba>ta;Da=X?ia:_;Ea=X?Ba:ta;Fa=X?Ca:ua;X=ia+1|0;if((X|0)<147){sa=Ca;ia=X;_=Da;ta=Ea;ua=Fa}else{break}}_=D+(pa*20|0)|0;do{if(Ea!=0.0){ia=146-Da|0;X=(Da|0)<40;Y=X?Da:40;if((Y|0)>0){va=0;do{g[p+(va<<2)>>2]=+(b[H+1824+(va+ia<<1)>>1]|0);va=va+1|0;}while((va|0)<(Y|0))}do{if(X){Y=40-Da|0;if((Y|0)>0){Ga=0}else{break}do{g[p+(Ga+Da<<2)>>2]=+(b[H+1824+(Ga+ia<<1)>>1]|0);Ga=Ga+1|0;}while((Ga|0)<(Y|0))}}while(0);y$(la,Z,E,40,10);ia=0;do{X=q+(ia<<2)|0;g[X>>2]=+g[X>>2]-Fa*+g[r+(ia+10<<2)>>2];ia=ia+1|0;}while((ia|0)<40);ia=Da-19|0;if((ia|0)==0){Ha=0;Ia=0;Ja=0;break}UGb(C|0,ea|0,160)|0;bnb(ha,aa,Da);Ha=(ba(jnb($,ha)|0,ja)|0)>>>12;Ia=ia;Ja=1}else{Ha=0;Ia=0;Ja=0}}while(0);if(Ja){UGb(fa|0,ea|0,160)|0}ia=Ja?E:0;XTa(la,Z,1250008,ia,0,da,y,m);ya=+g[m>>2];X=c[y>>2]|0;if(ya!=0.0){Y=0;do{g[o+(Y<<2)>>2]=+(a[1250008+(X*40|0)+Y|0]|0);Y=Y+1|0;}while((Y|0)<40);y$(la,Z,U,40,10);if(Ja){Y=0;za=0.0;ua=0.0;do{ta=+g[p+(Y<<2)>>2];za=za+ +g[r+(Y+10<<2)>>2]*ta;ua=ua+ta*ta;Y=Y+1|0;}while((Y|0)<40);ta=za/ua;Y=0;while(1){va=r+(Y+10<<2)|0;g[va>>2]=+g[va>>2]-ta*+g[p+(Y<<2)>>2];va=Y+1|0;if((va|0)<40){Y=va}else{Ka=0;break}}}else{Ka=0}do{Y=q+(Ka<<2)|0;g[Y>>2]=+g[Y>>2]-ya*+g[r+(Ka+10<<2)>>2];Ka=Ka+1|0;}while((Ka|0)<40);UGb(ga|0,ea|0,160)|0;La=W}else{La=0}XTa(la,Z,1244632,ia,La,da,z,m);Y=c[z>>2]|0;va=0;do{g[v+(va<<2)>>2]=+(a[1250008+(X*40|0)+va|0]|0);g[w+(va<<2)>>2]=+(a[1244632+(Y*40|0)+va|0]|0);va=va+1|0;}while((va|0)<40);y$(la,Z,n,40,10);UGb(ma|0,ea|0,160)|0;va=(ba(e[1255128+(X<<1)>>1]|0,ja)|0)>>>8;y$(la,Z,Q,40,10);UGb(S|0,ea|0,160)|0;ia=(ba(e[1249752+(Y<<1)>>1]|0,ja)|0)>>>8;wa=0;Ma=0;ya=3.4028234663852886e+38;while(1){Na=ba(b[1215026+(wa*6|0)>>1]|0,va)|0;Oa=d[1216560+wa|0]|0;ta=+(Na>>>(Oa>>>0)>>>0>>>0)*.000244140625;ua=+((ba(b[1215028+(wa*6|0)>>1]|0,ia)|0)>>>(Oa>>>0)>>>0>>>0)*.000244140625;if(Ja){za=+((ba(b[1215024+(wa*6|0)>>1]|0,Ha)|0)>>>(Oa>>>0)>>>0>>>0)*.000244140625;Oa=0;sa=0.0;while(1){Aa=+g[t+(Oa<<2)>>2]+za*+g[u+(Oa<<2)>>2]+ta*+g[v+(Oa<<2)>>2]+ua*+g[w+(Oa<<2)>>2];g[q+(Oa<<2)>>2]=Aa;Pa=Aa- +(b[na+(Oa+qa<<1)>>1]|0);Aa=sa+Pa*Pa;Na=Oa+1|0;if((Na|0)<40){Oa=Na;sa=Aa}else{Qa=Aa;break}}}else{Oa=0;sa=0.0;while(1){za=+g[t+(Oa<<2)>>2]+ta*+g[v+(Oa<<2)>>2]+ua*+g[w+(Oa<<2)>>2];g[q+(Oa<<2)>>2]=za;Aa=za- +(b[na+(Oa+qa<<1)>>1]|0);za=sa+Aa*Aa;Na=Oa+1|0;if((Na|0)<40){Oa=Na;sa=za}else{Qa=za;break}}}Oa=Qa<ya;Ra=Oa?wa:Ma;Na=wa+1|0;if((Na|0)<256){wa=Na;Ma=Ra;ya=Oa?Qa:ya}else{break}}if((ra|0)>7){Sa=ra-7|0;Ta=ca<<7|Ia;Ua=ka}else{Ma=ka;x=fe(ca<<ra|Ia>>>((7-ra|0)>>>0)|0)|0;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;Sa=ra+25|0;Ta=Ia;Ua=ka+4|0}R=Ta;if((Sa|0)>8){Va=Sa-8|0;Wa=Ta<<8|Ra;Xa=Ua}else{Ma=Ua;x=fe(Ra>>>((8-Sa|0)>>>0)|Ta<<Sa|0)|0;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;Va=Sa+24|0;Wa=Ra;Xa=Ua+4|0}R=Wa;if((Va|0)>7){Ya=Va-7|0;Za=Wa<<7|X;_a=Xa}else{Ma=Xa;x=fe(X>>>((7-Va|0)>>>0)|Wa<<Va|0)|0;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;Ya=Va+25|0;Za=X;_a=Xa+4|0}R=Za;if((Ya|0)>7){$a=Ya-7|0;ab=Za<<7|Y;bb=_a}else{Ma=_a;x=fe(Y>>>((7-Ya|0)>>>0)|Za<<Ya|0)|0;a[Ma]=x;x=x>>8;a[Ma+1|0]=x;x=x>>8;a[Ma+2|0]=x;x=x>>8;a[Ma+3|0]=x;$a=Ya+25|0;ab=Y;bb=_a+4|0}R=ab;knb(H,_,Ia,X,Y,ja,Ra);Ma=pa+1|0;if((Ma|0)<4){ka=bb;ra=$a;pa=Ma;ca=ab}else{break}}if(($a|0)<32){ca=ab<<$a;R=ca;ab=ca>>>24&255;ca=$a;$a=bb;while(1){a[$a]=ab;bb=R;R=bb<<8;pa=ca+8|0;if((pa|0)<32){ab=bb>>>16&255;ca=pa;$a=$a+1|0}else{break}}}R=0;c[P>>2]=A;c[G+1400>>2]=c[O>>2];O=G+1392|0;A=c[O>>2]|0;c[O>>2]=c[V>>2];c[V>>2]=A;do{if(I){A=c[j+76>>2]|0;if((A|0)>0){V=(A|0)>1;O=0;do{b[N+(O<<1)>>1]=(b[J+(O<<1)>>1]|0)>>>2;O=O+1|0;}while((O|0)<(A|0));cb=V?A:1}else{cb=0}O=G+1276|0;ja=Shb(O,j)|0;if((ja|0)<0){L=ja}else{db=cb;eb=O;break}i=l;return L|0}else{c[K>>2]=1;db=0;eb=G+1276|0}}while(0);TGb(N+(db<<1)|0,0,160-db<<1|0)|0;Thb(eb,c[f+424>>2]|0,h+8|0,h+48|0);c[B>>2]=20;c[k>>2]=1;L=0;i=l;return L|0}function WTa(a){a=a|0;var b=0;b=c[a+60>>2]|0;EKa(b+1248|0);Rhb(b+1276|0);return 0}function XTa(b,d,e,f,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0,u=0.0,v=0.0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0.0,H=0.0,I=0.0,J=0,K=0.0,L=0.0,M=0.0;m=i;i=i+160|0;n=m|0;g[l>>2]=0.0;c[k>>2]=0;o=n|0;p=(h|0)==0;if((f|0)==0){q=0.0;r=0;s=0.0;while(1){t=0;do{g[n+(t<<2)>>2]=+(a[e+(r*40|0)+t|0]|0);t=t+1|0;}while((t|0)<40);y$(b,d,o,40,10);if(p){u=0.0;v=0.0;w=0}else{t=0;x=0.0;y=0.0;do{z=+g[h+(t<<2)>>2];x=x+ +g[b+(t<<2)>>2]*z;y=y+z*z;t=t+1|0;}while((t|0)<40);z=x/y;t=0;while(1){A=b+(t<<2)|0;g[A>>2]=+g[A>>2]-z*+g[h+(t<<2)>>2];A=t+1|0;if((A|0)<40){t=A}else{u=0.0;v=0.0;w=0;break}}}do{z=+g[b+(w<<2)>>2];v=v+z*z;u=u+z*+g[j+(w<<2)>>2];w=w+1|0;}while((w|0)<40);if(u>0.0){z=u/v;B=u*z;C=z}else{B=0.0;C=q}if(B>s){c[k>>2]=r;g[l>>2]=C;D=B}else{D=s}t=r+1|0;if((t|0)<128){q=C;r=t;s=D}else{break}}i=m;return}else{E=0.0;F=0;G=0.0}while(1){r=0;do{g[n+(r<<2)>>2]=+(a[e+(F*40|0)+r|0]|0);r=r+1|0;}while((r|0)<40);y$(b,d,o,40,10);r=0;D=0.0;s=0.0;do{C=+g[f+(r<<2)>>2];D=D+ +g[b+(r<<2)>>2]*C;s=s+C*C;r=r+1|0;}while((r|0)<40);C=D/s;r=0;do{w=b+(r<<2)|0;g[w>>2]=+g[w>>2]-C*+g[f+(r<<2)>>2];r=r+1|0;}while((r|0)<40);if(p){H=0.0;I=0.0;J=0}else{r=0;C=0.0;s=0.0;do{D=+g[h+(r<<2)>>2];C=C+ +g[b+(r<<2)>>2]*D;s=s+D*D;r=r+1|0;}while((r|0)<40);D=C/s;r=0;while(1){w=b+(r<<2)|0;g[w>>2]=+g[w>>2]-D*+g[h+(r<<2)>>2];w=r+1|0;if((w|0)<40){r=w}else{H=0.0;I=0.0;J=0;break}}}do{D=+g[b+(J<<2)>>2];I=I+D*D;H=H+D*+g[j+(J<<2)>>2];J=J+1|0;}while((J|0)<40);if(H>0.0){D=H/I;K=H*D;L=D}else{K=0.0;L=E}if(K>G){c[k>>2]=F;g[l>>2]=L;M=K}else{M=G}r=F+1|0;if((r|0)<128){E=L;F=r;G=M}else{break}}i=m;return}function YTa(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+60>>2]|0;c[a+416>>2]=1;e=a+448|0;c[e>>2]=4;c[e+4>>2]=0;c[a+420>>2]=3;if((c[a+432>>2]|0)<1){yDb(a,16,2105728,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1163346256;i=b;return f|0}else{fCb(d,c[a+88>>2]&8388608);f=0;i=b;return f|0}return 0}function ZTa(a,e,f,h){a=a|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ba=0.0,ca=0,da=0,ea=0.0,fa=0.0,ga=0.0;j=i;i=i+24|0;k=j|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;h=c[a+60>>2]|0;n=h;o=a+432|0;p=c[o>>2]|0;if((m|0)<(p|0)){yDb(a,16,2182840,(q=i,i=i+16|0,c[q>>2]=m,c[q+8>>2]=p,q)|0);i=q;r=-1094995529;i=j;return r|0}c[e+76>>2]=160;q=_$a(a,e,0)|0;if((q|0)<0){r=q;i=j;return r|0}q=c[o>>2]|0;a=q>>>0>268435455>>>0?-8:q<<3;q=a>>>0>2147483639>>>0|(l|0)==0;p=q?0:l;l=q?8:a+8|0;a=h+600|0;q=h+744|0;m=q;s=h+620|0;t=h+1060|0;u=h+256|0;v=h+1056|0;w=h+260|0;x=h+1052|0;y=h+264|0;z=h+1048|0;A=h+268|0;B=h+1044|0;C=h+272|0;D=h+1040|0;E=h+276|0;F=h+1036|0;G=h+280|0;H=h+1032|0;I=h+284|0;J=h+1028|0;K=J;L=h+288|0;M=h+1024|0;N=M;O=h+292|0;P=k|0;Q=k+4|0;R=k+8|0;S=k+12|0;T=k+16|0;k=h+64|0;U=h+320|0;V=h+764|0;W=h+912|0;X=h+1064|0;h=0;Y=0;Z=c[e>>2]|0;while(1){e=p+(h>>>3)|0;$=h+3|0;aa=l>>>0>$>>>0?$:l;ba=+g[1795992+(((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>((h&7)>>>0)&7)<<2)>>2];e=Y&1|6;$=p+(aa>>>3)|0;ca=32-e|0;da=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((aa&7)>>>0)<<ca>>>(ca>>>0);ca=aa+e|0;VGb(a|0,s|0,144)|0;ea=32.0- +g[t>>2]*+g[u>>2]- +g[v>>2]*+g[w>>2]- +g[x>>2]*+g[y>>2]- +g[z>>2]*+g[A>>2]- +g[B>>2]*+g[C>>2]- +g[D>>2]*+g[E>>2]- +g[F>>2]*+g[G>>2]- +g[H>>2]*+g[I>>2]- +g[K>>2]*+g[L>>2]- +g[N>>2]*+g[O>>2];if(ea<0.0){fa=0.0}else{fa=ea>60.0?6.907755278982:ea*.1151292546497}ea=ba*+_(fa)*1.1920928955078125e-7;g[P>>2]=ea*+(b[1458688+(da*10|0)>>1]|0);g[Q>>2]=ea*+(b[1458690+(da*10|0)>>1]|0);g[R>>2]=ea*+(b[1458692+(da*10|0)>>1]|0);g[S>>2]=ea*+(b[1458694+(da*10|0)>>1]|0);g[T>>2]=ea*+(b[1458696+(da*10|0)>>1]|0);ea=+eCb(P,P,5);if(ea>2.980232238769531e-7){ga=ea}else{ga=2.980232238769531e-7}VGb(M|0,J|0,36)|0;g[t>>2]=+ad(+ga)*10.0+33.2574989159953;y$(m,k,P,5,36);da=Z;c[da>>2]=c[q>>2];c[da+4>>2]=c[q+4>>2];c[da+8>>2]=c[q+8>>2];c[da+12>>2]=c[q+12>>2];c[da+16>>2]=c[q+16>>2];if((Y&7|0)==3){_Ta(n,U,V,399800,k,400248,36,40,35,70);_Ta(n,W,X,1038024,u,1039600,10,8,20,28)}da=Y+1|0;if((da|0)<32){h=l>>>0>ca>>>0?ca:l;Y=da;Z=Z+20|0}else{break}}c[f>>2]=1;r=c[o>>2]|0;i=j;return r|0}function _Ta(a,b,d,e,f,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0;n=i;i=i+936|0;o=n|0;p=n+152|0;q=n+784|0;r=q|0;s=a|0;a=n+335&-32;t=j+15|0;cf[c[s>>2]&1023](a,e,b,t+k+l&-16);e=a+(j<<2)|0;do{if((j|0)>-1){u=j;while(1){g[o+(u<<2)>>2]=+eCb(e,a+(j-u<<2)|0,k);if((u|0)>0){u=u-1|0}else{break}}u=k+j|0;v=a+(u<<2)|0;w=j;while(1){g[p+(w<<2)>>2]=+eCb(v,a+(u-w<<2)|0,l);if((w|0)>0){w=w-1|0}else{break}}if((j|0)<0){x=0.0*1.00390625;break}else{y=0}do{w=d+(y<<2)|0;z=+g[w>>2]*.5625+ +g[o+(y<<2)>>2];g[w>>2]=z;g[q+(y<<2)>>2]=+g[p+(y<<2)>>2]+z;y=y+1|0;}while((y|0)<=(j|0));x=+g[r>>2]*1.00390625}else{x=0.0*1.00390625}}while(0);g[r>>2]=x;if(+g[q+(j<<2)>>2]!=0.0&x>0.0){A=x;B=0}else{C=b;D=b+(k<<2)|0;E=D;F=m<<2;VGb(C|0,E|0,F|0)|0;i=n;return}while(1){if((B|0)>=(j|0)){break}r=B+1|0;x=-0.0- +g[q+(r<<2)>>2];if((B|0)>0){y=0;z=x;while(1){G=z- +g[f+(y<<2)>>2]*+g[q+(B-y<<2)>>2];p=y+1|0;if((p|0)<(B|0)){y=p;z=G}else{H=G;break}}}else{H=x}z=H/A;G=A*(1.0-z*z);g[f+(B<<2)>>2]=z;y=r>>1;if((y|0)>0){p=B-1|0;o=0;do{d=f+(o<<2)|0;I=+g[d>>2];l=f+(p-o<<2)|0;J=+g[l>>2];g[d>>2]=I+z*J;g[l>>2]=J+z*I;o=o+1|0;}while((o|0)<(y|0))}if(G<0.0){K=17;break}else{A=G;B=r}}if((K|0)==17){C=b;D=b+(k<<2)|0;E=D;F=m<<2;VGb(C|0,E|0,F|0)|0;i=n;return}cf[c[s>>2]&1023](f,f,h,t&-16);C=b;D=b+(k<<2)|0;E=D;F=m<<2;VGb(C|0,E|0,F|0)|0;i=n;return}function $Ta(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;e=c[a+60>>2]|0;do{if((c[a+100>>2]|0)>=24){f=c[a+96>>2]|0;if((PGb(f,1893248,4)|0)!=0){break}g=f+4|0;h=(d[g]|d[g+1|0]<<8)<<16>>16;g=(de(h|0)|0)&65535;c[e>>2]=g;if(!(h<<16>>16==769)){DDb(a,2330456,(j=i,i=i+8|0,c[j>>2]=g,j)|0);i=j;k=-1163346256;i=b;return k|0}g=f+8|0;h=(d[g]|d[g+1|0]<<8)<<16>>16;g=(de(h|0)|0)&65535;c[a+416>>2]=g;l=f+12|0;m=fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;l=a+412|0;c[l>>2]=m;if((g-1|0)>>>0>1>>>0|(m|0)<8e3|(m|0)>96e3){yDb(a,16,2306304,(j=i,i=i+16|0,c[j>>2]=m,c[j+8>>2]=g,j)|0);i=j;k=-1094995529;i=b;return k|0}c[a+420>>2]=6;g=h<<16>>16==512;h=a+448|0;c[h>>2]=g?3:4;c[h+4>>2]=g?0:0;g=f+16|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=fe(f|0)|0;h=e+4|0;c[h>>2]=g;if((g|0)>1048576|(f|0)==0){yDb(a,16,2288096,(j=i,i=i+8|0,c[j>>2]=g,j)|0);i=j;n=c[h>>2]|0}else{n=g}g=c[l>>2]|0;c[h>>2]=(n|0)>(g|0)?n:g;g=e+8|0;h=0;a:while(1){o=dUa(g+(h*5060|0)|0,1059120+(h*324|0)|0,643)|0;if((o|0)<0){p=12;break}q=dUa(g+(h*5060|0)+20|0,1732080+(h<<7)|0,255)|0;if((q|0)<0){p=14;break}r=dUa(g+(h*5060|0)+40|0,1458320+(h*72|0)|0,140)|0;if((r|0)<0){p=16;break}else{s=0}while(1){if((s|0)>=11){t=0;break}l=dUa(g+(h*5060|0)+60+(s*20|0)|0,1060240+(h*2640|0)+(s*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{s=s+1|0}}while(1){if((t|0)>=11){v=0;break}l=dUa(g+(h*5060|0)+280+(t*20|0)|0,1060504+(h*2640|0)+(t*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{t=t+1|0}}while(1){if((v|0)>=11){w=0;break}l=dUa(g+(h*5060|0)+500+(v*20|0)|0,1060768+(h*2640|0)+(v*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{v=v+1|0}}while(1){if((w|0)>=11){x=0;break}l=dUa(g+(h*5060|0)+720+(w*20|0)|0,1061032+(h*2640|0)+(w*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{w=w+1|0}}while(1){if((x|0)>=11){y=0;break}l=dUa(g+(h*5060|0)+940+(x*20|0)|0,1061296+(h*2640|0)+(x*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{x=x+1|0}}while(1){if((y|0)>=11){z=0;break}l=dUa(g+(h*5060|0)+1160+(y*20|0)|0,1061560+(h*2640|0)+(y*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{y=y+1|0}}while(1){if((z|0)>=11){A=0;break}l=dUa(g+(h*5060|0)+1380+(z*20|0)|0,1061824+(h*2640|0)+(z*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{z=z+1|0}}while(1){if((A|0)>=11){B=0;break}l=dUa(g+(h*5060|0)+1600+(A*20|0)|0,1062088+(h*2640|0)+(A*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{A=A+1|0}}while(1){if((B|0)>=11){C=0;break}l=dUa(g+(h*5060|0)+1820+(B*20|0)|0,1062352+(h*2640|0)+(B*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{B=B+1|0}}while(1){if((C|0)>=11){D=0;break}l=dUa(g+(h*5060|0)+2040+(C*20|0)|0,1062616+(h*2640|0)+(C*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{C=C+1|0}}while(1){if((D|0)>=15){E=0;break}F=dUa(g+(h*5060|0)+2260+(D*20|0)|0,439872+(h*1320|0)+(D*88|0)|0,169)|0;if((F|0)<0){p=22;break a}else{D=D+1|0}}while(1){if((E|0)>=125){break}G=dUa(g+(h*5060|0)+2560+(E*20|0)|0,767e3+(h*28e3|0)+(E*224|0)|0,441)|0;if((G|0)<0){p=25;break a}else{E=E+1|0}}l=h+1|0;if((l|0)<3){h=l}else{k=0;p=27;break}}if((p|0)==12){bUa(a)|0;k=o;i=b;return k|0}else if((p|0)==14){bUa(a)|0;k=q;i=b;return k|0}else if((p|0)==16){bUa(a)|0;k=r;i=b;return k|0}else if((p|0)==19){bUa(a)|0;k=u;i=b;return k|0}else if((p|0)==22){bUa(a)|0;k=F;i=b;return k|0}else if((p|0)==25){bUa(a)|0;k=G;i=b;return k|0}else if((p|0)==27){i=b;return k|0}}}while(0);yDb(a,16,2350848,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}function aUa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=a+60|0;m=c[l>>2]|0;n=e;o=m+97392|0;do{if((c[o>>2]|0)==0){p=g+28|0;q=c[p>>2]|0;if((q|0)!=8192){r=q;s=c[g+24>>2]|0;break}UGb(m+81008|0,c[g+24>>2]|0,8192)|0;c[o>>2]=1;c[f>>2]=0;t=c[p>>2]|0;i=h;return t|0}else{c[o>>2]=0;p=c[g+24>>2]|0;q=p;u=(((de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)+7|0)>>>3;q=c[g+28>>2]|0;if((u+3|0)>(q|0)|(q|0)>8192){yDb(a,16,2182792,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;t=-1094995529;i=h;return t|0}w=m+81008|0;x=u+2|0;if((PGb(w,p,x)|0)==0){UGb(m+89200|0,p+x|0,q-2-u|0)|0;r=q+8192|0;s=w;break}yDb(a,16,2105696,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;t=-1094995529;i=h;return t|0}}while(0);o=e+76|0;c[o>>2]=c[m+4>>2];w=_$a(a,n,0)|0;if((w|0)<0){t=w;i=h;return t|0}w=c[e>>2]|0;n=c[e+4>>2]|0;if((r|0)<5){yDb(a,16,2048704,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;t=-1094995529;i=h;return t|0}e=s;q=(de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535;e=(q+7|0)>>>3;if((r|0)<(e+3|0)){yDb(a,16,2003232,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;t=-1094995529;i=h;return t|0}u=(s+2|0)==0?0:q;q=u+8|0;x=m+48232|0;c[x>>2]=0;a:do{if((u|0)==0){p=m+48236|0;c[p>>2]=0;y=p}else{p=m+48240|0;z=m+64624|0;A=0;B=0;while(1){C=s+((A>>>3)+2)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(A&7)>>>17;C=A+15|0;E=q>>>0>C>>>0?C:q;c[p+(B<<2)>>2]=D;D=((E|0)<(q|0))+E|0;if((d[s+((E>>>3)+2)|0]&128>>>((E&7)>>>0)|0)==0){c[z+(c[x>>2]<<2)>>2]=0;F=D}else{E=s+((D>>>3)+2)|0;C=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>23;E=D+9|0;c[z+(c[x>>2]<<2)>>2]=C;F=q>>>0>E>>>0?E:q}G=(c[x>>2]|0)+1|0;c[x>>2]=G;if((u-F|0)>0){A=F;B=G}else{break}}B=m+48236|0;c[B>>2]=0;if((G|0)<=0){y=B;break}A=m+48240|0;z=a+416|0;p=j|0;E=j+4|0;C=k|0;D=k+4|0;H=0;I=s+(e+2)|0;J=r-2-e|0;b:while(1){K=A+(H<<2)|0;L=c[K>>2]|0;if((J|0)<(L|0)){M=25;break}N=L<<3;L=N>>>0>2147483639>>>0|(I|0)==0;O=L?0:I;P=L?0:N;N=P+8|0;L=c[B>>2]|0;Q=c[l>>2]|0;R=Q;S=0;T=0;while(1){if((S|0)>=6){U=T;break}V=((T|0)<(N|0))+T|0;if((d[O+(T>>>3)|0]&128>>>((T&7)>>>0)|0)==0){U=V;break}else{S=S+1|0;T=V}}T=12-S|0;V=1<<((T|0)<8^T);T=Q+48236|0;if(((c[T>>2]|0)+V|0)>(c[Q+4>>2]|0)){M=30;break}W=c[z>>2]|0;if((W|0)>1){X=O+(U>>>3)|0;Y=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(U&7)>>>30;X=U+2|0;Z=Y+1|0;_=N>>>0>X>>>0?X:N}else{Z=0;_=U}c[p>>2]=(Z|0)==4;X=(Z|0)>1;c[E>>2]=X?2:0;c[C>>2]=16;c[D>>2]=X?17:16;X=Q+47956|0;Y=Q+47964|0;$=Q+47960|0;aa=(V|0)>0;ca=(V|0)>1;da=V<<2;ea=0;fa=_;ga=W;while(1){if((ea|0)>=(ga|0)){break}W=c[j+(ea<<2)>>2]|0;ha=c[k+(ea<<2)>>2]|0;ia=R+15188+(ea<<14)|0;ja=c[R+8+(W*5060|0)+4>>2]|0;ka=O+(fa>>>3)|0;la=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(fa&7)>>>23;ka=b[ja+(la<<2)>>1]|0;ma=b[ja+(la<<2)+2>>1]|0;la=ma<<16>>16;if(ma<<16>>16<0){ma=fa+9|0;na=N>>>0>ma>>>0?ma:N;ma=O+(na>>>3)|0;oa=((fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(na&7)>>>((la+32|0)>>>0))+ka|0;pa=b[ja+(oa<<2)+2>>1]|0;qa=b[ja+(oa<<2)>>1]|0;ra=na}else{pa=la;qa=ka;ra=fa}ka=pa+ra|0;la=N>>>0>ka>>>0?ka:N;c[X>>2]=qa;ka=qa-2>>6;c[Y>>2]=ka;c[$>>2]=qa-1-(ka<<6);do{if((qa|0)==642){if(aa){ka=32-ha|0;na=0;oa=la;while(1){ja=O+(oa>>>3)|0;ma=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(oa&7)>>>(ka>>>0);ja=oa+ha|0;sa=N>>>0>ja>>>0?ja:N;c[R+15188+(ea<<14)+(na<<2)>>2]=ma;ma=na+1|0;if((ma|0)<(V|0)){na=ma;oa=sa}else{ta=sa;break}}}else{ta=la}c[R+48224+(ea<<2)>>2]=0;ua=ta}else{oa=c[R+8+(W*5060|0)+24>>2]|0;na=O+(la>>>3)|0;ka=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(la&7)>>>23;na=b[oa+(ka<<2)>>1]|0;sa=b[oa+(ka<<2)+2>>1]|0;ka=sa<<16>>16;if(sa<<16>>16<0){sa=la+9|0;ma=N>>>0>sa>>>0?sa:N;sa=O+(ma>>>3)|0;ja=((fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ma&7)>>>((ka+32|0)>>>0))+na|0;va=b[oa+(ja<<2)+2>>1]|0;wa=b[oa+(ja<<2)>>1]|0;xa=ma}else{va=ka;wa=na;xa=la}na=va+xa|0;ka=N>>>0>na>>>0?na:N;na=R+48224+(ea<<2)|0;c[na>>2]=wa;if((wa|0)==254){ma=O+(ka>>>3)|0;ja=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(ka&7);if(ja>>>0>134217727>>>0){ma=ja>>>23;oa=(d[1213744+ma|0]|0)+ka|0;ya=d[1108392+ma|0]|0;za=N>>>0>oa>>>0?oa:N}else{oa=ja>>>0>65535>>>0;ma=oa?ja>>>16:ja;sa=oa?16:0;if((ma&65280|0)==0){Aa=sa;Ba=ma}else{Aa=sa|8;Ba=ma>>>8}ma=(d[1191992+Ba|0]|0)+Aa<<1;sa=63-ma+ka|0;ya=(ja>>>((ma-31|0)>>>0))-1|0;za=N>>>0>sa>>>0?sa:N}Ca=ya+127|0;Da=za}else if((wa|0)==0){sa=O+(ka>>>3)|0;ma=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ka&7);if(ma>>>0>134217727>>>0){sa=ma>>>23;ja=(d[1213744+sa|0]|0)+ka|0;Ea=d[1108392+sa|0]|0;Fa=N>>>0>ja>>>0?ja:N}else{ja=ma>>>0>65535>>>0;sa=ja?ma>>>16:ma;oa=ja?16:0;if((sa&65280|0)==0){Ga=oa;Ha=sa}else{Ga=oa|8;Ha=sa>>>8}sa=(d[1191992+Ha|0]|0)+Ga<<1;oa=63-sa+ka|0;Ea=(ma>>>((sa-31|0)>>>0))-1|0;Fa=N>>>0>oa>>>0?oa:N}Ca=-127-Ea|0;Da=Fa}else{Ca=wa-127|0;Da=ka}ka=O+(Da>>>3)|0;oa=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(Da&7)>>>28;ka=Da+4|0;sa=N>>>0>ka>>>0?ka:N;c[na>>2]=oa|Ca<<4;oa=c[X>>2]|0;if((oa|0)==0){TGb(ia|0,0,da|0)|0;ua=sa;break}do{if((oa|0)>1){na=c[Y>>2]|0;if((c[$>>2]|0)<=0){Ia=sa;break}ka=(na|0)==0;ma=12<<na;ja=32-na|0;Ja=0;Ka=0;La=0;Ma=sa;while(1){Na=Ja+5|0;Oa=c[R+8+(W*5060|0)+60+(na*220|0)+(Na*20|0)+4>>2]|0;Pa=c[R+8+(W*5060|0)+60+(na*220|0)+(Na*20|0)>>2]|0;Na=O+(Ma>>>3)|0;Qa=(fe(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0)<<(Ma&7)>>>((32-Pa|0)>>>0);Na=b[Oa+(Qa<<2)>>1]|0;Ra=b[Oa+(Qa<<2)+2>>1]|0;Qa=Ra<<16>>16;if(Ra<<16>>16<0){Ra=Pa+Ma|0;Pa=N>>>0>Ra>>>0?Ra:N;Ra=O+(Pa>>>3)|0;Sa=((fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Pa&7)>>>((Qa+32|0)>>>0))+Na|0;Ta=b[Oa+(Sa<<2)+2>>1]|0;Ua=b[Oa+(Sa<<2)>>1]|0;Va=Pa}else{Ta=Qa;Ua=Na;Va=Ma}Na=Ta+Va|0;Qa=N>>>0>Na>>>0?Na:N;if((Ua|0)==0){Na=O+(Qa>>>3)|0;Pa=(fe(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0)<<(Qa&7);if(Pa>>>0>134217727>>>0){Na=Pa>>>23;Sa=(d[1213744+Na|0]|0)+Qa|0;Wa=d[1108392+Na|0]|0;Xa=N>>>0>Sa>>>0?Sa:N}else{Sa=Pa>>>0>65535>>>0;Na=Sa?Pa>>>16:Pa;Oa=Sa?16:0;if((Na&65280|0)==0){Ya=Oa;Za=Na}else{Ya=Oa|8;Za=Na>>>8}Na=(d[1191992+Za|0]|0)+Ya<<1;Oa=63-Na+Qa|0;Wa=(Pa>>>((Na-31|0)>>>0))-1|0;Xa=N>>>0>Oa>>>0?Oa:N}_a=-21-Wa|0;$a=Xa}else if((Ua|0)==42){Oa=O+(Qa>>>3)|0;Na=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Qa&7);if(Na>>>0>134217727>>>0){Oa=Na>>>23;Pa=(d[1213744+Oa|0]|0)+Qa|0;ab=d[1108392+Oa|0]|0;bb=N>>>0>Pa>>>0?Pa:N}else{Pa=Na>>>0>65535>>>0;Oa=Pa?Na>>>16:Na;Sa=Pa?16:0;if((Oa&65280|0)==0){cb=Sa;db=Oa}else{cb=Sa|8;db=Oa>>>8}Oa=(d[1191992+db|0]|0)+cb<<1;Sa=63-Oa+Qa|0;ab=(Na>>>((Oa-31|0)>>>0))-1|0;bb=N>>>0>Sa>>>0?Sa:N}_a=ab+21|0;$a=bb}else{_a=Ua-21|0;$a=Qa}if(ka){eb=_a;fb=$a}else{Qa=O+($a>>>3)|0;Sa=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<($a&7)>>>(ja>>>0);Qa=$a+na|0;eb=Sa|_a<<na;fb=N>>>0>Qa>>>0?Qa:N}Qa=eb+(((Ja|0)==0?ma:0)-Ka)|0;c[R+47968+(La<<2)>>2]=Qa;Sa=Qa>>na;do{if((Sa|0)<0){Oa=-Sa|0;Na=Oa>>>0>65535>>>0;Pa=Na?Oa>>>16:Oa;Oa=Na?16:0;if((Pa&65280|0)==0){gb=Oa;hb=Pa}else{gb=Oa|8;hb=Pa>>>8}Pa=(d[1191992+hb|0]|0)+gb|0;ib=(Pa|0)>4?-5:~Pa}else{if((Sa|0)<=0){ib=0;break}Pa=Sa>>>0>65535>>>0;Oa=Pa?Sa>>>16:Sa;Na=Pa?16:0;if((Oa&65280|0)==0){jb=Na;kb=Oa}else{jb=Na|8;kb=Oa>>>8}Oa=jb+1+(d[1191992+kb|0]|0)|0;ib=(Oa|0)>5?5:Oa}}while(0);Sa=La+1|0;if((Sa|0)<(c[$>>2]|0)){Ja=ib;Ka=Qa;La=Sa;Ma=fb}else{Ia=fb;break}}}else{Ia=sa}}while(0);sa=c[R+8+(W*5060|0)+44>>2]|0;oa=c[R+8+(W*5060|0)+40>>2]|0;Ma=O+(Ia>>>3)|0;La=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ia&7)>>>((32-oa|0)>>>0);Ma=b[sa+(La<<2)>>1]|0;Ka=b[sa+(La<<2)+2>>1]|0;La=Ka<<16>>16;if(Ka<<16>>16<0){Ka=oa+Ia|0;oa=N>>>0>Ka>>>0?Ka:N;Ka=O+(oa>>>3)|0;Ja=((fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(oa&7)>>>((La+32|0)>>>0))+Ma|0;lb=b[sa+(Ja<<2)+2>>1]|0;mb=b[sa+(Ja<<2)>>1]|0;nb=oa}else{lb=La;mb=Ma;nb=Ia}Ma=lb+nb|0;La=N>>>0>Ma>>>0?Ma:N;if((mb|0)>14){Ma=((mb|0)/5|0)-3|0;oa=(Ma|0)/2|0;do{if((Ma|0)<-1){ob=0}else{Ja=(oa|0)>10?10:oa;if((Ja|0)<=9){ob=Ja;break}ob=((((mb|0)%5|0|0)!=2)<<31>>31)+Ja|0}}while(0);pb=R+8+(W*5060|0)+2560+((mb-15|0)*20|0)|0;qb=ob;rb=21;sb=10}else{pb=R+8+(W*5060|0)+2260+(mb*20|0)|0;qb=0;rb=13;sb=6}if(!aa){ua=La;break}oa=pb|0;Ma=(qb|0)==0;Ja=32-qb|0;sa=sb<<1;Ka=c[pb+4>>2]|0;na=0;ma=La;while(1){ja=c[oa>>2]|0;ka=O+(ma>>>3)|0;Sa=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ma&7)>>>((32-ja|0)>>>0);ka=b[Ka+(Sa<<2)>>1]|0;Oa=b[Ka+(Sa<<2)+2>>1]|0;Sa=Oa<<16>>16;if(Oa<<16>>16<0){Oa=ja+ma|0;ja=N>>>0>Oa>>>0?Oa:N;Oa=O+(ja>>>3)|0;Na=((fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(ja&7)>>>((Sa+32|0)>>>0))+ka|0;tb=b[Ka+(Na<<2)+2>>1]|0;ub=b[Ka+(Na<<2)>>1]|0;vb=ja}else{tb=Sa;ub=ka;vb=ma}ka=tb+vb|0;Sa=N>>>0>ka>>>0?ka:N;ka=(ub|0)/(rb|0)|0;ja=(ub|0)%(rb|0)|0;do{if((ka|0)==0){Na=O+(Sa>>>3)|0;Oa=(fe(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0)<<(Sa&7);if(Oa>>>0>134217727>>>0){Na=Oa>>>23;Pa=(d[1213744+Na|0]|0)+Sa|0;wb=d[1108392+Na|0]|0;xb=N>>>0>Pa>>>0?Pa:N}else{Pa=Oa>>>0>65535>>>0;Na=Pa?Oa>>>16:Oa;Ra=Pa?16:0;if((Na&65280|0)==0){yb=Ra;zb=Na}else{yb=Ra|8;zb=Na>>>8}Na=(d[1191992+zb|0]|0)+yb<<1;Ra=63-Na+Sa|0;wb=(Oa>>>((Na-31|0)>>>0))-1|0;xb=N>>>0>Ra>>>0?Ra:N}Ab=-(wb+sb|0)|0;Bb=xb}else{if((sa|0)!=(ka|0)){Ab=ka-sb|0;Bb=Sa;break}Ra=O+(Sa>>>3)|0;Na=(fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Sa&7);if(Na>>>0>134217727>>>0){Ra=Na>>>23;Oa=(d[1213744+Ra|0]|0)+Sa|0;Cb=d[1108392+Ra|0]|0;Db=N>>>0>Oa>>>0?Oa:N}else{Oa=Na>>>0>65535>>>0;Ra=Oa?Na>>>16:Na;Pa=Oa?16:0;if((Ra&65280|0)==0){Eb=Pa;Fb=Ra}else{Eb=Pa|8;Fb=Ra>>>8}Ra=(d[1191992+Fb|0]|0)+Eb<<1;Pa=63-Ra+Sa|0;Cb=(Na>>>((Ra-31|0)>>>0))-1|0;Db=N>>>0>Pa>>>0?Pa:N}Ab=Cb+sb|0;Bb=Db}}while(0);Sa=Ab<<qb;ka=R+15188+(ea<<14)+(na<<2)|0;c[ka>>2]=Sa;do{if((ja|0)==0){Pa=O+(Bb>>>3)|0;Ra=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Bb&7);if(Ra>>>0>134217727>>>0){Pa=Ra>>>23;Na=(d[1213744+Pa|0]|0)+Bb|0;Gb=d[1108392+Pa|0]|0;Hb=N>>>0>Na>>>0?Na:N}else{Na=Ra>>>0>65535>>>0;Pa=Na?Ra>>>16:Ra;Oa=Na?16:0;if((Pa&65280|0)==0){Ib=Oa;Jb=Pa}else{Ib=Oa|8;Jb=Pa>>>8}Pa=(d[1191992+Jb|0]|0)+Ib<<1;Oa=63-Pa+Bb|0;Gb=(Ra>>>((Pa-31|0)>>>0))-1|0;Hb=N>>>0>Oa>>>0?Oa:N}Kb=-(Gb+sb|0)|0;Lb=Hb}else{if((sa|0)!=(ja|0)){Kb=ja-sb|0;Lb=Bb;break}Oa=O+(Bb>>>3)|0;Pa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Bb&7);if(Pa>>>0>134217727>>>0){Oa=Pa>>>23;Ra=(d[1213744+Oa|0]|0)+Bb|0;Mb=d[1108392+Oa|0]|0;Nb=N>>>0>Ra>>>0?Ra:N}else{Ra=Pa>>>0>65535>>>0;Oa=Ra?Pa>>>16:Pa;Na=Ra?16:0;if((Oa&65280|0)==0){Ob=Na;Pb=Oa}else{Ob=Na|8;Pb=Oa>>>8}Oa=(d[1191992+Pb|0]|0)+Ob<<1;Na=63-Oa+Bb|0;Mb=(Pa>>>((Oa-31|0)>>>0))-1|0;Nb=N>>>0>Na>>>0?Na:N}Kb=Mb+sb|0;Lb=Nb}}while(0);ja=Kb<<qb;Na=R+15188+(ea<<14)+((na|1)<<2)|0;c[Na>>2]=ja;if(Ma){Qb=Lb}else{Oa=O+(Lb>>>3)|0;Pa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Lb&7)>>>(Ja>>>0);Oa=Lb+qb|0;Ra=N>>>0>Oa>>>0?Oa:N;c[ka>>2]=Pa|Sa;Pa=O+(Ra>>>3)|0;Oa=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Ra&7)>>>(Ja>>>0);Pa=Ra+qb|0;c[Na>>2]=Oa|ja;Qb=N>>>0>Pa>>>0?Pa:N}Pa=na+2|0;if((Pa|0)<(V|0)){na=Pa;ma=Qb}else{ua=Qb;break}}}}while(0);W=c[X>>2]|0;do{if(!((W|0)<2|(W|0)==642)){ia=c[Y>>2]|0;c[Y>>2]=ia+3;la=1<<ia+2;ia=1<<ha;ma=ia-1|0;na=1-ia-1|0;if(ca){Rb=1}else{break}do{ia=c[$>>2]|0;Ja=(ia|0)>(Rb|0)?Rb:ia;do{if((Ja|0)>0){ia=Rb-1|0;Ma=0;sa=0;do{Ma=(ba(c[R+15188+(ea<<14)+(ia-sa<<2)>>2]|0,c[R+47968+(sa<<2)>>2]|0)|0)+Ma|0;sa=sa+1|0;}while((sa|0)<(Ja|0));sa=Ma+la|0;if((Ma|0)>=0){Sb=sa;M=142;break}ia=sa-1>>c[Y>>2];Tb=(ia|0)>(na|0)?ia:na}else{Sb=la;M=142}}while(0);if((M|0)==142){M=0;Ja=Sb>>c[Y>>2];Tb=(Ja|0)>(ma|0)?ma:Ja}Ja=R+15188+(ea<<14)+(Rb<<2)|0;c[Ja>>2]=(c[Ja>>2]|0)+Tb;Rb=Rb+1|0;}while((Rb|0)<(V|0))}}while(0);if((P-ua|0)<0){M=162;break b}ea=ea+1|0;fa=ua;ga=c[z>>2]|0}ga=Q+15188|0;fa=Q+31572|0;c:do{switch(Z|0){case 0:{if(!aa){break c}ea=c[Q+48224>>2]|0;P=0;do{b[w+(P+L<<1)>>1]=(c[ga+(P<<2)>>2]|0)+ea;P=P+1|0;}while((P|0)<(V|0));break};case 4:{if(!aa){break c}P=c[Q+48228>>2]|0;ea=c[Q+48224>>2]|0;R=0;do{Y=(c[fa+(R<<2)>>2]|0)+P|0;$=(c[ga+(R<<2)>>2]|0)+ea<<1|Y&1;ca=R+L|0;b[w+(ca<<1)>>1]=($+Y|0)/2|0;b[n+(ca<<1)>>1]=($-Y|0)/2|0;R=R+1|0;}while((R|0)<(V|0));break};case 3:{if(!aa){break c}R=c[Q+48224>>2]|0;ea=c[Q+48228>>2]|0;P=0;do{Y=(c[ga+(P<<2)>>2]|0)+R|0;$=P+L|0;b[w+($<<1)>>1]=(c[fa+(P<<2)>>2]|0)+ea+Y;b[n+($<<1)>>1]=Y;P=P+1|0;}while((P|0)<(V|0));break};case 2:{if(!aa){break c}P=Q+48224|0;ea=Q+48228|0;R=0;do{Y=ga+(R<<2)|0;$=(c[Y>>2]|0)+(c[P>>2]|0)|0;c[Y>>2]=$;Y=R+L|0;b[w+(Y<<1)>>1]=$;b[n+(Y<<1)>>1]=$-(c[fa+(R<<2)>>2]|0)-(c[ea>>2]|0);R=R+1|0;}while((R|0)<(V|0));break};case 1:{if(!aa){break c}R=c[Q+48224>>2]|0;ea=c[Q+48228>>2]|0;P=0;do{$=P+L|0;b[w+($<<1)>>1]=(c[ga+(P<<2)>>2]|0)+R;b[n+($<<1)>>1]=(c[fa+(P<<2)>>2]|0)+ea;P=P+1|0;}while((P|0)<(V|0));break};default:{}}}while(0);c[T>>2]=(c[T>>2]|0)+V;fa=c[K>>2]|0;ga=H+1|0;if((ga|0)<(c[x>>2]|0)){H=ga;I=I+fa|0;J=J-fa|0}else{y=B;break a}}if((M|0)==25){yDb(a,16,1965720,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;y=B;break}else if((M|0)==30){J=a;yDb(J,16,1913704,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;Ub=J}else if((M|0)==162){Ub=a}yDb(Ub,16,1937696,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;y=B}}while(0);c[o>>2]=c[y>>2];c[f>>2]=(c[y>>2]|0)>0;t=c[g+28>>2]|0;i=h;return t|0}function bUa(a){a=a|0;var b=0,d=0;b=(c[a+60>>2]|0)+8|0;a=0;do{Q_(b+(a*5060|0)|0);Q_(b+(a*5060|0)+20|0);Q_(b+(a*5060|0)+40|0);d=0;do{Q_(b+(a*5060|0)+60+(d*220|0)|0);Q_(b+(a*5060|0)+60+(d*220|0)+20|0);Q_(b+(a*5060|0)+60+(d*220|0)+40|0);Q_(b+(a*5060|0)+60+(d*220|0)+60|0);Q_(b+(a*5060|0)+60+(d*220|0)+80|0);Q_(b+(a*5060|0)+60+(d*220|0)+100|0);Q_(b+(a*5060|0)+60+(d*220|0)+120|0);Q_(b+(a*5060|0)+60+(d*220|0)+140|0);Q_(b+(a*5060|0)+60+(d*220|0)+160|0);Q_(b+(a*5060|0)+60+(d*220|0)+180|0);Q_(b+(a*5060|0)+60+(d*220|0)+200|0);d=d+1|0;}while((d|0)<10);Q_(b+(a*5060|0)+2260|0);Q_(b+(a*5060|0)+2280|0);Q_(b+(a*5060|0)+2300|0);Q_(b+(a*5060|0)+2320|0);Q_(b+(a*5060|0)+2340|0);Q_(b+(a*5060|0)+2360|0);Q_(b+(a*5060|0)+2380|0);Q_(b+(a*5060|0)+2400|0);Q_(b+(a*5060|0)+2420|0);Q_(b+(a*5060|0)+2440|0);Q_(b+(a*5060|0)+2460|0);Q_(b+(a*5060|0)+2480|0);Q_(b+(a*5060|0)+2500|0);Q_(b+(a*5060|0)+2520|0);Q_(b+(a*5060|0)+2540|0);d=0;do{Q_(b+(a*5060|0)+2560+(d*20|0)|0);d=d+1|0;}while((d|0)<125);a=a+1|0;}while((a|0)<3);return 0}function cUa(a){a=a|0;c[(c[a+60>>2]|0)+97392>>2]=0;return}function dUa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+2008|0;j=h|0;k=h+648|0;l=h+1936|0;m=i;i=i+72|0;TGb(l|0,0,68)|0;n=(g|0)>0;if(n){o=0;p=f;f=0;q=0;while(1){r=d[p]|0;s=((q|0)!=0?r&15:r>>>4)+1|0;r=l+(s<<2)|0;c[r>>2]=(c[r>>2]|0)+1;r=(f|0)>(s|0)?f:s;a[j+o|0]=s;s=o+1|0;if((s|0)<(g|0)){o=s;p=p+q|0;f=r;q=q^1}else{t=r;break}}}else{t=0}c[m+4>>2]=0;q=1;f=0;do{f=(c[l+(q<<2)>>2]|0)+f<<1;q=q+1|0;c[m+(q<<2)>>2]=f;}while((q|0)<17);if(n){u=0}else{v=(t|0)>9;w=v?9:t;x=j|0;y=k;z=N_(e,w,g,x,1,1,y,2,2,0,0,0,0)|0;i=h;return z|0}do{n=m+((d[j+u|0]|0)<<2)|0;q=c[n>>2]|0;c[n>>2]=q+1;b[k+(u<<1)>>1]=q;u=u+1|0;}while((u|0)<(g|0));v=(t|0)>9;w=v?9:t;x=j|0;y=k;z=N_(e,w,g,x,1,1,y,2,2,0,0,0,0)|0;i=h;return z|0}function eUa(a,b,d){a=a|0;b=b|0;d=d|0;c[a+532>>2]=b;c[a+528>>2]=b;c[a+536>>2]=b+d;c[a>>2]=0;c[a+4>>2]=65280;c[a+8>>2]=0;c[a+12>>2]=-1;return}function fUa(a,b,e){a=a|0;b=b|0;e=e|0;c[a+528>>2]=b;c[a+536>>2]=b+e;e=a|0;c[e>>2]=0;c[a+4>>2]=65280;c[a+8>>2]=0;c[a+12>>2]=-1;c[a+532>>2]=b+2;a=b;c[e>>2]=(de((d[a]|d[a+1|0]<<8)<<16>>16|0)|0)&65535;return}function gUa(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c;f=(c|0)<0|0?-1:0;TGb(b+16|0,0,512)|0;c=0;g=-2147483648;h=0;i=0;while(1){YGb(g<<8|0>>>24,c<<8|g>>>24,-2147483648,0)|0;j=F;k=(j|0)>(h|0)?j:h+1|0;if(!((h|0)>255|(h|0)==0|(k|0)>(d|0))){a[b+272+h|0]=k}j=ZGb(0,1,g,c)|0;l=gHb(j,F,e,f)|0;YGb(l,F,-2147483648,0)|0;l=F;j=YGb(l,(l|0)<0|0?-1:0,g,c)|0;l=i+1|0;if((l|0)<128){c=F;g=j;h=k;i=l}else{break}}i=256-d|0;if((i|0)>(d|0)){m=1}else{h=i;while(1){i=b+272+h|0;if((a[i]|0)==0){g=h;c=g<<24|0>>>8;l=((h|0)<0|0?-1:0)<<24|g>>>8;g=ZGb(0,1,c,l)|0;k=gHb(g,F,e,f)|0;YGb(k,F,-2147483648,0)|0;k=F;g=YGb(k,(k|0)<0|0?-1:0,c,l)|0;YGb(g<<8|0>>>24,F<<8|g>>>24,-2147483648,0)|0;g=F;l=h+1|0;c=(g|0)>(h|0)?g:l;a[i]=(c|0)>(d|0)?d:c;n=l}else{n=h+1|0}if((n|0)>(d|0)){m=1;break}else{h=n}}}do{a[b+16+m|0]=-(a[256-m+(b+272)|0]|0);m=m+1|0;}while((m|0)<255);return}function hUa(a){a=a|0;var b=0,d=0;b=a+4|0;c[b>>2]=255;d=a|0;c[d>>2]=(c[d>>2]|0)+255;iUa(a);c[b>>2]=255;iUa(a);return(c[a+532>>2]|0)-(c[a+528>>2]|0)|0}function iUa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b+4|0;if((c[d>>2]|0)>=256){return}e=b+12|0;f=b|0;g=b+532|0;h=b+8|0;b=c[e>>2]|0;i=c[f>>2]|0;while(1){do{if((b|0)<0){j=i>>8;c[e>>2]=j;k=j;l=i}else{if((i|0)<65281){j=c[g>>2]|0;c[g>>2]=j+1;a[j]=b;if((c[h>>2]|0)!=0){do{j=c[g>>2]|0;c[g>>2]=j+1;a[j]=-1;j=(c[h>>2]|0)-1|0;c[h>>2]=j;}while((j|0)!=0)}j=c[f>>2]|0;m=j>>8;c[e>>2]=m;k=m;l=j;break}if((i|0)<=65535){c[h>>2]=(c[h>>2]|0)+1;k=b;l=i;break}j=c[g>>2]|0;c[g>>2]=j+1;a[j]=b+1;if((c[h>>2]|0)!=0){do{j=c[g>>2]|0;c[g>>2]=j+1;a[j]=0;j=(c[h>>2]|0)-1|0;c[h>>2]=j;}while((j|0)!=0)}j=c[f>>2]|0;m=j>>>8&255;c[e>>2]=m;k=m;l=j}}while(0);j=l<<8&65280;c[f>>2]=j;m=c[d>>2]<<8;c[d>>2]=m;if((m|0)<256){b=k;i=j}else{break}}return}function jUa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;d=c[a+9856>>2]|0;e=c[d+160>>2]|0;f=c[a+9992>>2]|0;g=c[a+7792>>2]|0;h=c[a+13672>>2]|0;j=c[a+13676>>2]|0;k=c[a+13664>>2]|0;l=c[a+13696>>2]|0;m=c[a+11556>>2]|0;n=c[a+11560>>2]|0;o=a+9800|0;p=c[o>>2]|0;q=c[o+4>>2]|0;o=a+9792|0;r=c[o>>2]|0;s=c[o+4>>2]|0;o=c[a+13680>>2]|0;t=c[a+13692>>2]|0;u=c[a+13668>>2]|0;Lb(c[(c[a+4>>2]|0)+668>>2]|0,256,2224896,(a=i,i=i+136|0,c[a>>2]=c[d+164>>2],c[a+8>>2]=e,c[a+16>>2]=f,c[a+24>>2]=g,c[a+32>>2]=h,c[a+40>>2]=j,c[a+48>>2]=k,c[a+56>>2]=l,c[a+64>>2]=m,c[a+72>>2]=n,c[a+80>>2]=p,c[a+88>>2]=q,c[a+96>>2]=r,c[a+104>>2]=s,c[a+112>>2]=o,c[a+120>>2]=t,c[a+128>>2]=u,a)|0)|0;i=a;i=b;return}function kUa(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0.0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0.0,ja=0.0,ka=0,la=0,ma=0,na=0.0,oa=0,pa=0,qa=0.0,ra=0,sa=0,ta=0.0,ua=0,va=0.0,wa=0.0,xa=0.0,ya=0.0,za=0.0,Aa=0.0,Ba=0.0,Ca=0.0,Da=0.0,Ea=0,Fa=0,Ga=0,Ha=0.0,Ia=0,Ja=0.0,Ka=0,La=0.0,Ma=0.0,Na=0,Oa=0,Pa=0,Qa=0.0;d=i;i=i+168|0;e=d|0;f=d+40|0;j=d+80|0;k=d+88|0;l=b+4|0;m=c[l>>2]|0;n=m+556|0;do{if(!(+g[n>>2]!=0.0)){o=c[m+524>>2]|0;if((o|0)==0){break}p=c[m+540>>2]|0;if((p|0)==0){g[n>>2]=1.0;break}r=c[m+112>>2]|0;if((r|0)>1){s=+(r|0)}else{s=1.0}t=+(p|0)/(+(o|0)*(1.0/(+(c[m+104>>2]|0)/+(c[m+108>>2]|0))/s));if(t<.3333333432674408){u=.3333333432674408}else{u=t>1.0?1.0:t}g[n>>2]=u}}while(0);n=c[m+536>>2]|0;o=JBb(b+13660|0,(n|0)==0?2164808:n,1151320,1151288,1151304,0,0,0,m)|0;if((o|0)<0){m=c[l>>2]|0;yDb(m,16,2158032,(v=i,i=i+8|0,c[v>>2]=c[m+536>>2],v)|0);i=v;w=o;i=d;return w|0}h[b+13248>>3]=826.0;h[b+13256>>3]=1.0;h[b+13264>>3]=.4;c[b+13624>>2]=1;o=b+13584|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13544|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13504|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13464|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13408>>3]=590.0;h[b+13272>>3]=826.0;h[b+13280>>3]=1.0;h[b+13288>>3]=.4;c[b+13628>>2]=1;o=b+13592|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13552|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13512|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13472|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13416>>3]=590.0;h[b+13296>>3]=826.0;h[b+13304>>3]=1.0;h[b+13312>>3]=.4;c[b+13632>>2]=1;o=b+13600|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13560|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13520|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13480|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13424>>3]=590.0;h[b+13320>>3]=826.0;h[b+13328>>3]=1.0;h[b+13336>>3]=.4;c[b+13636>>2]=1;o=b+13608|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13568|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13528|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13488|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13432>>3]=590.0;h[b+13344>>3]=826.0;h[b+13352>>3]=1.0;h[b+13360>>3]=.4;c[b+13640>>2]=1;o=b+13616|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13576|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13536|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13496|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13440>>3]=590.0;o=c[l>>2]|0;m=c[o+564>>2]|0;n=b+13240|0;h[n>>3]=+(m|0);if((m|0)==0){h[n>>3]=+(((c[o+524>>2]|0)*3|0|0)/4|0|0)}m=b+60|0;p=c[m>>2]|0;do{if((p&1024|0)==0){x=p}else{r=c[o+672>>2]|0;if((r|0)==0){y=-1}else{z=r;r=-1;while(1){A=Vb(z+1|0,59)|0;B=r+1|0;if((A|0)==0){y=B;break}else{z=A;r=B}}}r=b+68|0;z=(c[r>>2]|0)+y|0;if((z|0)<1|z>>>0>26843544>>>0){w=-1;i=d;return w|0}B=cEb(z*80|0)|0;A=b+13236|0;c[A>>2]=B;C=b+13232|0;c[C>>2]=z;if((z|0)>0){D=c[b+144>>2]|0;G=0;do{c[B+(G*80|0)+40>>2]=2;c[B+(G*80|0)>>2]=2;g[B+(G*80|0)+44>>2]=236.0;g[B+(G*80|0)+4>>2]=236.0;c[B+(G*80|0)+20>>2]=D+10;H=D*100|0;I=B+(G*80|0)+56|0;c[I>>2]=H;c[I+4>>2]=(H|0)<0|0?-1:0;G=G+1|0;}while((G|0)<(z|0))}G=0;B=c[(c[l>>2]|0)+672>>2]|0;D=z;while(1){if((G|0)>=(D-(c[r>>2]|0)|0)){J=32;break}H=Vb(B|0,59)|0;if((H|0)==0){K=0}else{a[H]=0;K=H+1|0}H=xd(B|0,2151112,(v=i,i=i+8|0,c[v>>2]=j,v)|0)|0;i=v;I=c[j>>2]|0;if(!((I|0)>-1)){J=26;break}if((I|0)>=(c[C>>2]|0)){J=28;break}L=c[A>>2]|0;M=xd(B|0,2125528,(v=i,i=i+104|0,c[v>>2]=L+(I*80|0),c[v+8>>2]=L+(I*80|0)+4,c[v+16>>2]=L+(I*80|0)+12,c[v+24>>2]=L+(I*80|0)+16,c[v+32>>2]=L+(I*80|0)+8,c[v+40>>2]=L+(I*80|0)+20,c[v+48>>2]=L+(I*80|0)+72,c[v+56>>2]=L+(I*80|0)+76,c[v+64>>2]=L+(I*80|0)+48,c[v+72>>2]=L+(I*80|0)+56,c[v+80>>2]=L+(I*80|0)+64,c[v+88>>2]=L+(I*80|0)+68,c[v+96>>2]=L+(I*80|0)+24,v)|0)|0;i=v;N=M+H|0;if((N|0)!=14){J=31;break}G=G+1|0;B=K;D=c[C>>2]|0}if((J|0)==26){yd(2144112,2138488,205,236e4);return 0}else if((J|0)==28){yd(2131920,2138488,206,236e4);return 0}else if((J|0)==31){yDb(c[l>>2]|0,16,2119864,(v=i,i=i+16|0,c[v>>2]=G,c[v+8>>2]=N,v)|0);i=v;w=-1;i=d;return w|0}else if((J|0)==32){B=c[l>>2]|0;r=c[B+112>>2]|0;if((r|0)>1){O=+(r|0)}else{O=1.0}u=1.0/(+(c[B+104>>2]|0)/+(c[B+108>>2]|0))/O;TGb(e|0,0,40)|0;TGb(f|0,0,40)|0;r=b+24|0;s=+(c[r>>2]|0)*+(D|0)/u;z=~~+s>>>0;H=(E=+s,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);M=B+496|0;B=~~(+g[M>>2]*4.0)|1;if((D|0)>0){I=0;do{L=c[A>>2]|0;R=c[L+(I*80|0)>>2]|0;S=L+(I*80|0)+40|0;c[S>>2]=R;T=L+(I*80|0)+12|0;s=+g[L+(I*80|0)+4>>2];U=b+13464+(R<<3)|0;u=+(c[T>>2]|0)*s+(+((c[U>>2]|0)>>>0)+ +((c[U+4>>2]|0)>>>0)*4294967296.0);V=(E=+u,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[U>>2]=~~+u>>>0;c[U+4>>2]=V;V=L+(I*80|0)+16|0;U=b+13504+(R<<3)|0;u=s*+(c[V>>2]|0)+(+((c[U>>2]|0)>>>0)+ +((c[U+4>>2]|0)>>>0)*4294967296.0);W=(E=+u,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[U>>2]=~~+u>>>0;c[U+4>>2]=W;W=L+(I*80|0)+8|0;U=c[W>>2]|0;X=b+13544+(R<<3)|0;Y=YGb(c[X>>2]|0,c[X+4>>2]|0,U,(U|0)<0|0?-1:0)|0;c[X>>2]=Y;c[X+4>>2]=F;X=b+13624+(R<<2)|0;c[X>>2]=(c[X>>2]|0)+1;X=c[S>>2]|0;S=e+(X<<3)|0;h[S>>3]=+h[S>>3]+s*+((c[V>>2]|0)+(c[T>>2]|0)|0);T=(c[L+(I*80|0)+20>>2]|0)+(c[W>>2]|0)|0;W=f+(X<<3)|0;X=YGb(T,(T|0)<0|0?-1:0,c[W>>2]|0,c[W+4>>2]|0)|0;c[W>>2]=X;c[W+4>>2]=F;I=I+1|0;Z=c[C>>2]|0;}while((I|0)<(Z|0));I=f+8|0;G=f+16|0;W=f+24|0;$=Z;ba=c[I+4>>2]|0;ca=c[I>>2]|0;da=c[G+4>>2]|0;ea=c[G>>2]|0;fa=c[W+4>>2]|0;ha=c[W>>2]|0}else{$=D;ba=0;ca=0;da=0;ea=0;fa=0;ha=0}W=YGb(ea,da,ha,fa)|0;G=YGb(W,F,ca,ba)|0;W=F;if(H>>>0<W>>>0|H>>>0==W>>>0&z>>>0<G>>>0){yDb(c[l>>2]|0,16,2059992,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}G=WDb($<<3)|0;W=G;I=WDb(c[C>>2]<<3)|0;X=I;T=((B|0)%2|0|0)==1;s=+(z>>>0)+ +(H>>>0)*4294967296.0;L=(B|0)>0;V=(B|0)/-2|0;u=65536.0;t=0.0;S=0;R=c[C>>2]|0;while(1){ia=t+u;h[n>>3]=+((c[(c[l>>2]|0)+524>>2]|0)/2|0|0);if((R|0)>0){Y=0;while(1){U=(c[A>>2]|0)+(Y*80|0)|0;ja=+nUa(b,U,ia,Y);h[W+(Y<<3)>>3]=ja;h[b+13408+(c[U>>2]<<3)>>3]=ja;U=Y+1|0;ka=c[C>>2]|0;if((U|0)<(ka|0)){Y=U}else{la=ka;break}}}else{la=R}if(!T){J=43;break}Y=la-300|0;ka=(Y|0)<0?0:Y;if((ka|0)<(la|0)){Y=ka;while(1){ka=W+(Y<<3)|0;h[ka>>3]=+tUa(b,c[(c[A>>2]|0)+(Y*80|0)+40>>2]|0,+h[ka>>3]);ka=Y+1|0;U=c[C>>2]|0;if((ka|0)<(U|0)){Y=ka}else{ma=U;break}}}else{ma=la}a:do{if((ma|0)>0){Y=ma;do{Y=Y-1|0;U=W+(Y<<3)|0;h[U>>3]=+tUa(b,c[(c[A>>2]|0)+(Y*80|0)+40>>2]|0,+h[U>>3]);}while((Y|0)>0);Y=c[C>>2]|0;if((Y|0)<=0){na=0.0;oa=Y;break}U=c[A>>2]|0;if(L){ka=0;while(1){pa=c[U+(ka*80|0)+40>>2]|0;ja=+g[M>>2];qa=ja*ja;ra=ka+V|0;if(ja==0.0){sa=0;ja=0.0;ta=0.0;while(1){ua=ra+sa|0;do{if((ua|0)>-1&(ua|0)<(Y|0)){if((pa|0)!=(c[U+(ua*80|0)+40>>2]|0)){va=ta;wa=ja;break}va=ta+1.0;wa=ja+ +h[W+(ua<<3)>>3]}else{va=ta;wa=ja}}while(0);ua=sa+1|0;if((ua|0)<(B|0)){sa=ua;ja=wa;ta=va}else{xa=wa;ya=va;break}}}else{sa=0;ta=0.0;ja=0.0;while(1){ua=ra+sa|0;za=+(ua-ka|0);Aa=+_(za*(-0.0-za)/qa);do{if((ua|0)>-1&(ua|0)<(Y|0)){if((pa|0)!=(c[U+(ua*80|0)+40>>2]|0)){Ba=ja;Ca=ta;break}Ba=ja+Aa;Ca=ta+Aa*+h[W+(ua<<3)>>3]}else{Ba=ja;Ca=ta}}while(0);ua=sa+1|0;if((ua|0)<(B|0)){sa=ua;ta=Ca;ja=Ba}else{xa=Ca;ya=Ba;break}}}h[X+(ka<<3)>>3]=xa/ya;sa=ka+1|0;if((sa|0)<(Y|0)){ka=sa}else{Da=0.0;Ea=0;Fa=U;break}}}else{ka=0;while(1){h[X+(ka<<3)>>3]=+q;sa=ka+1|0;if((sa|0)<(Y|0)){ka=sa}else{Da=0.0;Ea=0;Fa=U;break}}}while(1){ja=+uUa(b,Fa+(Ea*80|0)|0,+h[X+(Ea<<3)>>3],Ea);g[Fa+(Ea*80|0)+44>>2]=ja;if(!(ja>0.0)){yDb(0,16,2009232,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v}ta=+g[Fa+(Ea*80|0)+4>>2]*+((c[Fa+(Ea*80|0)+12>>2]|0)+1+(c[Fa+(Ea*80|0)+16>>2]|0)|0)/ja+ +(c[Fa+(Ea*80|0)+8>>2]|0)+ +(c[Fa+(Ea*80|0)+20>>2]|0);ja=ta+ +((pUa(b,~~ta)|0)<<3|0);U=(E=+Da,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);ka=Fa+(Ea*80|0)+32|0;c[ka>>2]=~~+Da>>>0;c[ka+4>>2]=U;ta=Da+ja;U=Ea+1|0;ka=c[C>>2]|0;if((U|0)>=(ka|0)){na=ta;oa=ka;break a}Da=ta;Ea=U;Fa=c[A>>2]|0}}else{na=0.0;oa=ma}}while(0);if(na>s){Ga=S+1|0;Ha=ia-u}else{Ga=S;Ha=ia}ta=u*.5;if(ta>1.0e-7){u=ta;t=Ha;S=Ga;R=oa}else{break}}if((J|0)==43){yd(2055168,2138488,971,2359912);return 0}ZDb(G);ZDb(I);R=c[C>>2]|0;if((R|0)>0){S=c[A>>2]|0;X=c[l>>2]|0;B=c[X+500>>2]|0;W=c[X+504>>2]|0;t=0.0;X=0;do{V=~~(+g[S+(X*80|0)+44>>2]/118.0);if((V|0)<(B|0)){Ia=B}else{Ia=(V|0)>(W|0)?W:V}t=t+ +(Ia|0);X=X+1|0;}while((X|0)<(R|0));Ja=t}else{Ja=0.0}if((Ga|0)>=41){yd(2044288,2138488,1043,2359912);return 0}R=c[r>>2]|0;yDb(c[l>>2]|0,48,2039216,(v=i,i=i+16|0,c[v>>2]=R,c[v+8>>2]=~~(na/(s/+(R|0))),v)|0);i=v;yDb(c[l>>2]|0,48,2036112,(v=i,i=i+8|0,h[v>>3]=Ja/+(c[C>>2]|0),v)|0);i=v;do{if((Ga|0)==0){yDb(c[l>>2]|0,32,2032264,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v}else if((Ga|0)==40){yDb(c[l>>2]|0,16,2028232,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}else{if(!(+Q(+(na/s+-1.0))>.01)){break}yDb(c[l>>2]|0,16,2024592,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}}while(0);C=c[m>>2]|0;if((C&1024|0)==0){x=C;break}r=c[l>>2]|0;if((c[r+164>>2]|0)!=1){x=C;break}yDb(r,16,2113808,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}}}while(0);if((x&1024|0)!=0){w=0;i=d;return w|0}h[b+13368>>3]=.001;h[b+13376>>3]=.001;x=b+13384|0;h[x>>3]=.001;m=b+13392|0;h[m>>3]=.001;Ga=c[l>>2]|0;if(+g[Ga+496>>2]>1.0){yDb(Ga,16,2099560,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}na=+g[Ga+552>>2];if(!(na!=0.0)){w=0;i=d;return w|0}Ga=b+144|0;v=b+16|0;Ia=k|0;J=k+40|0;oa=k+48|0;ma=k+56|0;Fa=k+4|0;Ea=k+72|0;la=k+76|0;n=k+20|0;$=b+9992|0;ba=k+64|0;ca=k+12|0;fa=k+16|0;ha=k+8|0;da=b+24|0;ea=b+68|0;Z=0;Ja=na;while(1){f=c[Ga>>2]|0;na=+(f|0);Ha=Ja*(+(Z|0)/1.0e4+1.0)*na;do{if(((Z|0)%(((c[v>>2]|0)+3|0)/4|0|0)|0|0)==0){c[Ia>>2]=1;Ka=1}else{if(((Z|0)%((c[ea>>2]|0)+1|0)|0|0)==0){c[Ia>>2]=2;Ka=2;break}else{c[Ia>>2]=3;Ka=3;break}}}while(0);c[J>>2]=Ka;Da=Ha*na/1.0e5;e=(E=+Da,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[oa>>2]=~~+Da>>>0;c[oa+4>>2]=e;c[ma>>2]=f;c[ma+4>>2]=(f|0)<0|0?-1:0;g[Fa>>2]=236.0;c[Ea>>2]=2;c[la>>2]=1;c[n>>2]=1;if((c[$>>2]|0)==1){c[ba>>2]=f;e=~~Ha;c[ca>>2]=e;c[fa>>2]=0;La=+(e|0)*236.0;Ma=0.0;Na=0;Oa=0;Pa=0}else{c[ba>>2]=0;c[ca>>2]=0;e=~~(Ha*.9);c[fa>>2]=e;N=~~(Ha*.1);La=0.0;Ma=+(e|0)*236.0;Na=(N|0)<0|0?-1:0;Oa=N;Pa=N}c[ha>>2]=Pa;N=b+13464+(Ka<<3)|0;Da=La+(+((c[N>>2]|0)>>>0)+ +((c[N+4>>2]|0)>>>0)*4294967296.0);e=(E=+Da,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[N>>2]=~~+Da>>>0;c[N+4>>2]=e;e=b+13504+(Ka<<3)|0;Da=Ma+(+((c[e>>2]|0)>>>0)+ +((c[e+4>>2]|0)>>>0)*4294967296.0);N=(E=+Da,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[e>>2]=~~+Da>>>0;c[e+4>>2]=N;N=b+13544+(Ka<<3)|0;e=YGb(c[N>>2]|0,c[N+4>>2]|0,Oa,Na)|0;c[N>>2]=e;c[N+4>>2]=F;N=b+13624+(Ka<<2)|0;c[N>>2]=(c[N>>2]|0)+1;+nUa(b,k,+h[m>>3]/+h[x>>3],Z);N=c[l>>2]|0;e=c[N+112>>2]|0;if((e|0)>1){Qa=+(e|0)}else{Qa=1.0}h[m>>3]=+(c[da>>2]|0)/(1.0/(+(c[N+104>>2]|0)/+(c[N+108>>2]|0))/Qa)+ +h[m>>3];e=Z+1|0;if((e|0)>=1800){w=0;break}Z=e;Ja=+g[N+552>>2]}i=d;return w|0}function lUa(a,b){a=a|0;b=+b;var d=0,e=0;d=i;if(b<.9){yDb(0,16,1998832,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}i=d;return+(+g[a+4>>2]*+((c[a+12>>2]|0)+1+(c[a+16>>2]|0)|0)/b)}function mUa(a,b){a=a|0;b=+b;var d=0,e=0;d=i;if(!(b>0.0)){yDb(0,16,2009232,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}i=d;return+(+g[a+4>>2]*+((c[a+12>>2]|0)+1+(c[a+16>>2]|0)|0)/b)}function nUa(a,b,d,e){a=a|0;b=b|0;d=+d;e=e|0;var f=0,j=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0.0,y=0,z=0.0,A=0.0,B=0,C=0,D=0.0,E=0.0;f=i;i=i+168|0;j=f|0;l=a+4|0;m=c[l>>2]|0;n=c[b+40>>2]|0;o=+(c[a+144>>2]|0);p=j|0;h[p>>3]=3.141592653589793;h[j+8>>3]=2.718281828459045;q=b+12|0;r=c[q>>2]|0;s=b+4|0;t=+g[s>>2];h[j+16>>3]=+(r|0)*t;u=b+16|0;v=c[u>>2]|0;h[j+24>>3]=+(v|0)*t;h[j+32>>3]=+(v+r|0)*t;h[j+40>>3]=+(c[b+8>>2]|0)/o;r=c[b>>2]|0;v=(r|0)==3;w=c[b+72>>2]|0;if(v){x=+((c[b+76>>2]|0)+w|0)*.5}else{x=+(w|0)}h[j+48>>3]=x;h[j+56>>3]=+(c[b+64>>2]|0)/o;w=b+48|0;h[j+64>>3]=(+((c[w>>2]|0)>>>0)+ +(c[w+4>>2]|0)*4294967296.0)/o;w=b+56|0;h[j+72>>3]=(+((c[w>>2]|0)>>>0)+ +(c[w+4>>2]|0)*4294967296.0)/o;h[j+80>>3]=+((r|0)==1|0);h[j+88>>3]=+((r|0)==2|0);h[j+96>>3]=+(v&1|0);v=a+13584+(n<<3)|0;o=+(c[a+13624+(n<<2)>>2]|0);h[j+104>>3]=(+((c[v>>2]|0)>>>0)+ +((c[v+4>>2]|0)>>>0)*4294967296.0)/o;h[j+112>>3]=+g[m+492>>2];m=a+13472|0;h[j+120>>3]=(+((c[m>>2]|0)>>>0)+ +((c[m+4>>2]|0)>>>0)*4294967296.0)/+(c[a+13628>>2]|0);m=a+13480|0;x=+(c[a+13632>>2]|0);h[j+128>>3]=(+((c[m>>2]|0)>>>0)+ +((c[m+4>>2]|0)>>>0)*4294967296.0)/x;m=a+13520|0;h[j+136>>3]=(+((c[m>>2]|0)>>>0)+ +((c[m+4>>2]|0)>>>0)*4294967296.0)/x;m=a+13528|0;h[j+144>>3]=(+((c[m>>2]|0)>>>0)+ +((c[m+4>>2]|0)>>>0)*4294967296.0)/+(c[a+13636>>2]|0);m=a+13464+(n<<3)|0;v=a+13504+(n<<3)|0;r=YGb(c[v>>2]|0,c[v+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;h[j+152>>3]=(+(r>>>0)+ +(F>>>0)*4294967296.0)/o;h[j+160>>3]=0.0;o=+MBb(c[a+13660>>2]|0,p,b);h[k>>3]=o;b=c[k+4>>2]&2147483647;p=2146435072;if(b>>>0>p>>>0|b>>>0==p>>>0&(c[k>>2]|0)>>>0>0>>>0){p=c[l>>2]|0;yDb(p,16,2013456,(y=i,i=i+8|0,c[y>>2]=c[p+536>>2],y)|0);i=y;z=-1.0;i=f;return+z}p=a+13384|0;h[p>>3]=o+ +h[p>>3];x=o*d;d=(x<0.0?0.0:x)+1.0;p=c[l>>2]|0;if((c[p+528>>2]|0)>0){x=d;a=0;b=p;while(1){p=c[b+532>>2]|0;do{if((c[p+(a<<4)>>2]|0)>(e|0)){A=x;B=b}else{if((c[p+(a<<4)+4>>2]|0)<(e|0)){A=x;B=b;break}j=c[p+(a<<4)+8>>2]|0;if((j|0)==0){A=x*+g[p+(a<<4)+12>>2];B=b;break}if((j|0)>0){C=b}else{yDb(0,16,2009232,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;C=c[l>>2]|0}A=+g[s>>2]*+((c[q>>2]|0)+1+(c[u>>2]|0)|0)/+(j|0);B=C}}while(0);p=a+1|0;if((p|0)<(c[B+528>>2]|0)){x=A;a=p;b=B}else{D=A;break}}}else{D=d}if(D<.9){yDb(0,16,1998832,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}d=+g[s>>2]*+((c[q>>2]|0)+1+(c[u>>2]|0)|0)/D;do{if((n|0)==1){u=c[l>>2]|0;D=+g[u+184>>2];if(!(D<0.0)){E=d;break}E=D*(-0.0-d)+ +g[u+188>>2]}else if((n|0)==3){u=c[l>>2]|0;D=+g[u+160>>2];if(!(D<0.0)){E=d;break}E=D*(-0.0-d)+ +g[u+172>>2]}else{E=d}}while(0);z=E<1.0?1.0:E;i=f;return+z}function oUa(a){a=a|0;IBb(c[a+13660>>2]|0);$Db(a+13236|0);return}function pUa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0.0,k=0.0,l=0.0,m=0,n=0.0,o=0,p=0.0,q=0,r=0,s=0;d=i;e=a+4|0;f=c[e>>2]|0;g=c[f+112>>2]|0;if((g|0)>1){j=+(g|0)}else{j=1.0}k=1.0/(+(c[f+104>>2]|0)/+(c[f+108>>2]|0))/j;g=c[f+524>>2]|0;j=+(c[f+544>>2]|0)/k;l=+(c[f+540>>2]|0)/k;if((g|0)==0){m=0;i=d;return m|0}k=+(b|0);b=a+13240|0;n=+h[b>>3]-k;h[b>>3]=n;if(n<0.0){yDb(f,16,2093144,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;do{if(k>l){f=c[e>>2]|0;if((c[a+9960>>2]|0)!=(c[f+504>>2]|0)){break}yDb(f,16,2087776,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);h[b>>3]=0.0;p=0.0}else{p=n}n=+(g|0);g=~~(n-p+-1.0);f=~~j;q=~~l;if((g|0)<(f|0)){r=f}else{r=(g|0)>(q|0)?q:g}l=p+ +(r|0);h[b>>3]=l;if(!(l>n)){m=0;i=d;return m|0}r=~~+aa((l-n)*.125);if((r|0)<4){s=(c[a+48>>2]|0)==13?4:r}else{s=r}h[b>>3]=l- +(s<<3|0);b=c[e>>2]|0;if((c[b+688>>2]&2|0)==0){m=s;i=d;return m|0}yDb(b,48,2083216,(o=i,i=i+8|0,c[o>>2]=s,o)|0);i=o;m=s;i=d;return m|0}function qUa(a){a=a|0;var b=0,d=0;b=c[a+108>>2]|0;d=c[a+13236>>2]|0;c[a+11556>>2]=c[d+(b*80|0)+72>>2];c[a+11560>>2]=c[d+(b*80|0)+76>>2];return}function rUa(d,f){d=d|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0.0,N=0.0,O=0,T=0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0,$=0.0,ca=0.0,da=0.0,ea=0,fa=0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0.0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0.0,ta=0.0,ua=0.0,va=0.0,wa=0.0,xa=0;j=i;i=i+96|0;k=j|0;l=j+8|0;m=j+16|0;n=c[d+108>>2]|0;o=d+4|0;p=c[o>>2]|0;q=d+9992|0;r=c[q>>2]|0;sUa(k,l,p,r);s=c[o>>2]|0;t=c[s+112>>2]|0;if((t|0)>1){u=+(t|0)}else{u=1.0}v=1.0/(+(c[s+104>>2]|0)/+(c[s+108>>2]|0))/u;s=(f|0)==0;do{if((n|0)>2&s){f=c[d+1e4>>2]|0;t=(f|0)==1?d+13456|0:d+13448|0;u=+R(+((c[t>>2]|0)>>>0)+ +(c[t+4>>2]|0)*4294967296.0);if(u<10.0){break}w=+h[d+13400>>3]*+((c[d+13216>>2]|0)-(c[d+13220>>2]|0)|0)/(u+1.0);u=+h[d+13248+(f*24|0)+16>>3];t=d+13248+(f*24|0)+8|0;x=d+13248+(f*24|0)|0;y=u*+h[x>>3];h[t>>3]=u*+h[t>>3]+1.0;h[x>>3]=w+y}}while(0);x=d+60|0;t=(c[x>>2]&1024|0)==0;a:do{if(t){do{if((c[q>>2]|0)==3){z=14}else{if((c[d+13944>>2]|0)!=0){z=14;break}A=d+9848|0}}while(0);if((z|0)==14){A=d+9856|0}f=c[A>>2]|0;do{if((f|0)!=0){B=f+136|0;C=c[B>>2]|0;D=c[B+4>>2]|0;if((C|0)==0&(D|0)==(-2147483648|0)){break}y=(+(C>>>0)+ +(D|0)*4294967296.0)*+(c[d+24>>2]|0)/v;G=(E=+y,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);H=~~+y>>>0;I=m;break a}}while(0);y=+(n|0)*+(c[d+24>>2]|0)/v;G=(E=+y,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);H=~~+y>>>0;I=m}else{if(!((n|0)>-1)){yd(2144112,2138488,783,2359976);return 0.0}if((n|0)<(c[d+13232>>2]|0)){f=c[d+13236>>2]|0;D=f+(n*80|0)+32|0;G=c[D+4>>2]|0;H=c[D>>2]|0;I=f+(n*80|0)|0;break}yDb(d,16,2077560,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1.0;i=j;return+K}}while(0);m=d+13208|0;A=ZGb(c[m>>2]|0,c[m+4>>2]|0,H,G)|0;y=+(c[p+76>>2]|0);w=(y-(+(A>>>0)+ +(F|0)*4294967296.0))/y;y=w>0.0?w:.0010000000474974513;A=(r|0)==1;G=d+9792|0;q=d+9800|0;do{if(t){f=A?G:q;D=c[f>>2]|0;C=c[f+4>>2]|0;f=I+40|0;c[f>>2]=r;c[I>>2]=r;B=c[q+4>>2]|0;L=I+48|0;c[L>>2]=c[q>>2];c[L+4>>2]=B;B=c[G+4>>2]|0;L=I+56|0;c[L>>2]=c[G>>2];c[L+4>>2]=B;g[I+4>>2]=236.0;c[I+72>>2]=c[d+11556>>2];c[I+76>>2]=c[d+11560>>2];c[I+20>>2]=1;w=+R(+(D>>>0)+ +(C|0)*4294967296.0);u=w*+h[d+13248+(r*24|0)>>3]/(+h[d+13248+(r*24|0)+8>>3]*236.0);if(A){c[I+64>>2]=c[d+144>>2];C=~~u;c[I+12>>2]=C;c[I+16>>2]=0;c[I+8>>2]=0;M=+(C|0)*236.0;N=0.0;O=0;T=0}else{c[I+64>>2]=0;c[I+12>>2]=0;C=~~(u*.9);c[I+16>>2]=C;D=~~(u*.1);c[I+8>>2]=D;M=0.0;N=+(C|0)*236.0;O=(D|0)<0|0?-1:0;T=D}D=d+13464+(r<<3)|0;u=M+(+((c[D>>2]|0)>>>0)+ +((c[D+4>>2]|0)>>>0)*4294967296.0);C=(E=+u,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[D>>2]=~~+u>>>0;c[D+4>>2]=C;C=d+13504+(r<<3)|0;u=N+(+((c[C>>2]|0)>>>0)+ +((c[C+4>>2]|0)>>>0)*4294967296.0);D=(E=+u,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[C>>2]=~~+u>>>0;c[C+4>>2]=D;D=d+13544+(r<<3)|0;C=YGb(c[D>>2]|0,c[D+4>>2]|0,T,O)|0;c[D>>2]=C;c[D+4>>2]=F;D=d+13624+(r<<2)|0;c[D>>2]=(c[D>>2]|0)+1;D=d+13392|0;u=+nUa(d,I,y*(+h[D>>3]/+h[d+13384>>3]),n);if(u<0.0){K=-1.0;i=j;return+K}if(!(u>0.0)){yd(2068176,2138488,858,2359976);return 0.0}w=+tUa(d,c[f>>2]|0,u);u=w;if(!(w>0.0)){yd(2068176,2138488,860,2359976);return 0.0}if((r|0)==2){z=35}else{if((c[d+20>>2]|0)==0){U=w;V=0.0}else{z=35}}if((z|0)==35){w=+g[p+496>>2];f=d+13368|0;C=d+13376|0;W=+h[C>>3]*w;X=u+ +h[f>>3]*w;h[f>>3]=X;w=W+1.0;h[C>>3]=w;W=X/w;U=W;V=W}if(!(U>0.0)){yd(2068176,2138488,871,2359976);return 0.0}W=+uUa(d,I,U,n);h[D>>3]=+(c[d+24>>2]|0)/v+ +h[D>>3];if(W>0.0){Y=W;Z=V;break}yd(2068176,2138488,877,2359976);return 0.0}else{do{if(!A){if((r|0)==(c[I+40>>2]|0)){break}yd(2072808,2138488,818,2359976);return 0.0}}while(0);Y=+g[I+44>>2]/y;Z=0.0}}while(0);I=c[o>>2]|0;if((c[I+688>>2]&2|0)==0){_=c[k>>2]|0}else{A=(mGb(r)|0)<<24>>24;r=c[k>>2]|0;k=c[l>>2]|0;p=(c[m>>2]|0)/1e3|0;m=c[d+13216>>2]|0;z=c[G>>2]|0;O=c[G+4>>2]|0;T=c[q>>2]|0;t=c[q+4>>2]|0;D=(c[d+24>>2]|0)/1e3|0;yDb(I,48,2063752,(J=i,i=i+128|0,c[J>>2]=A,c[J+8>>2]=r,h[J+16>>3]=Y,c[J+24>>2]=k,c[J+32>>2]=n,c[J+40>>2]=(H|0)/1e3|0,c[J+48>>2]=p,h[J+56>>3]=y,h[J+64>>3]=Z,c[J+72>>2]=m,c[J+80>>2]=z,c[J+88>>2]=O,c[J+96>>2]=T,c[J+104>>2]=t,c[J+112>>2]=D,c[J+120>>2]=~~v,J)|0);i=J;_=r}v=+(_|0);do{if(Y<v){$=v}else{Z=+(c[l>>2]|0);if(!(Y>Z)){$=Y;break}$=Z}}while(0);Y=$;b:do{if((c[d+9980>>2]|0)==0){ca=+(~~(Y+.5)|0)}else{l=c[o>>2]|0;v=+g[l+192>>2]*6103515625.0e-14;Z=+g[l+208>>2]*6103515625.0e-14;y=+g[l+336>>2];_=c[d+14412>>2]|0;r=c[d+14416>>2]|0;J=c[l+340>>2]|0;D=c[l+344>>2]|0;t=c[d+116>>2]|0;T=c[d+120>>2]|0;O=d+144|0;z=c[O>>2]|0;m=(z|0)>0;if(m){V=-0.0- +g[l+196>>2];U=-0.0- +g[l+200>>2];p=(t|0)/5|0;N=+(p|0);H=(T|0)/5|0;M=+(H|0);n=(T<<2|0)/5|0;T=(t<<2|0)/5|0;W=+g[l+204>>2]+1.0;l=c[d+12556>>2]|0;t=c[d+9200>>2]|0;k=c[d+9192>>2]|0;A=c[d+9216>>2]|0;I=c[d+124>>2]|0;C=c[d+12492>>2]|0;w=0.0;X=0.0;f=0;while(1){B=c[l+(f<<2)>>2]|0;u=+R(+((e[t+(B<<1)>>1]|0)>>>0));da=+R(+((e[k+(B<<1)>>1]|0)>>>0));L=a[A+B|0]|0;ea=(B|0)%(I|0)|0;fa=(B|0)/(I|0)|0;ha=da<4.0?4.0:da;da=u<4.0?4.0:u;if((b[C+(B<<1)>>1]&1)==0){ia=+S(+da,+V);ja=da}else{ia=W;ja=ha}da=+S(+ha,+U)*ia;B=(L&255)-128|0;ha=+(ba(B,B)|0);if(L<<24>>24<0){ka=(1.0-v*ha)*da}else{ka=(1.0-Z*ha)*da}da=ka;do{if((ea|0)<(p|0)){la=+(p-ea|0)/N}else{if((ea|0)<=(T|0)){la=0.0;break}la=+(ea-T|0)/N}}while(0);do{if((fa|0)<(H|0)){ha=+(H-fa|0)/M;ma=la>ha?la:ha}else{if((fa|0)<=(n|0)){ma=la;break}ha=+(fa-n|0)/M;ma=la>ha?la:ha}}while(0);ha=da*(1.0-y*ma);u=ja*(ha<1.0e-5?9999999747378752.0e-21:ha);ha=w+ja;na=X+u;g[_+(f<<2)>>2]=ja;g[r+(f<<2)>>2]=u;fa=f+1|0;if((fa|0)<(z|0)){w=ha;X=na;f=fa}else{oa=ha;pa=na;break}}}else{oa=0.0;pa=0.0}f=c[x>>2]|0;do{if((f&131072|0)==0){qa=pa;ra=oa}else{X=pa/oa;if(m){w=+(D|0);y=+(D|0);M=+(J|0);N=+(J|0);Z=oa;v=pa;n=0;while(1){U=Y*+g[_+(n<<2)>>2];W=+g[r+(n<<2)>>2];V=X*(U/W);do{if(V>w){sa=v-W;ta=Z-U/y}else{if(!(V<M)){sa=v;ta=Z;break}sa=v-W;ta=Z-U/N}}while(0);H=n+1|0;if((H|0)<(z|0)){Z=ta;v=sa;n=H}else{ua=ta;va=sa;break}}}else{ua=oa;va=pa}v=va<.001?.0010000000474974513:va;if(!(ua<.001)){qa=v;ra=ua;break}qa=v;ra=.0010000000474974513}}while(0);if(!m){ca=$;break}z=c[d+12556>>2]|0;n=c[d+9976>>2]|0;v=qa/ra;H=0;T=f;while(1){Z=Y*+g[_+(H<<2)>>2]/+g[r+(H<<2)>>2];if((T&131072|0)==0){wa=Z}else{wa=v*Z}p=~~(wa+.5);if((p|0)>(D|0)){xa=D}else{xa=(p|0)<(J|0)?J:p}c[n+(c[z+(H<<2)>>2]<<2)>>2]=xa;p=H+1|0;if((p|0)>=(c[O>>2]|0)){ca=$;break b}H=p;T=c[x>>2]|0}}}while(0);if(!s){K=ca;i=j;return+K}h[d+13400>>3]=ca;s=c[q+4>>2]|0;x=d+13448|0;c[x>>2]=c[q>>2];c[x+4>>2]=s;s=c[G+4>>2]|0;x=d+13456|0;c[x>>2]=c[G>>2];c[x+4>>2]=s;K=ca;i=j;return+K}function sUa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0.0,j=0,k=0.0,l=0.0,m=0.0,n=0,o=0,p=0.0,q=0.0,r=0,s=0,t=0,u=0;f=c[d+576>>2]|0;h=c[d+580>>2]|0;if((f|0)>(h|0)){yd(2017400,2138488,482,2359928)}if((e|0)==3){i=+g[d+160>>2];j=i<0.0;if(j){k=-0.0-i}else{k=i}l=+g[d+172>>2];if(j){m=-0.0-i}else{m=i}n=~~(+(h|0)*m+l+.5);o=~~(+(f|0)*k+l+.5)}else if((e|0)==1){l=+g[d+184>>2];e=l<0.0;if(e){p=-0.0-l}else{p=l}k=+g[d+188>>2];if(e){q=-0.0-l}else{q=l}n=~~(+(h|0)*q+k+.5);o=~~(+(f|0)*p+k+.5)}else{n=h;o=f}if((o|0)<1){r=1}else{r=(o|0)>32767?32767:o}if((n|0)<1){s=1;t=(s|0)<(r|0);u=t?r:s;c[a>>2]=r;c[b>>2]=u;return}s=(n|0)>32767?32767:n;t=(s|0)<(r|0);u=t?r:s;c[a>>2]=r;c[b>>2]=u;return}function tUa(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0.0,i=0,j=0,k=0.0,l=0.0,m=0.0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0;e=c[a+4>>2]|0;f=+h[a+13424>>3];i=a+13644|0;j=c[i>>2]|0;k=+h[a+13408+(j<<3)>>3];do{if((b|0)==3){l=+g[e+160>>2];if(l>0.0){m=k*l+ +g[e+172>>2]}else{m=d}n=m<1.0?1.0:m;o=11}else if((b|0)==1){l=+g[e+184>>2];if(!(l>0.0|(j|0)==2)){p=d;o=9;break}if(l<0.0){q=-0.0-l}else{q=l}p=f*q+ +g[e+188>>2];o=9}else{p=d;o=9}}while(0);do{if((o|0)==9){d=p<1.0?1.0:p;if((j|0)==(b|0)|(b|0)!=1){n=d;o=11;break}r=d;s=a+13408+(b<<3)|0}}while(0);do{if((o|0)==11){j=a+13408+(b<<3)|0;p=+h[j>>3];d=+((c[e+508>>2]|0)*118|0|0);q=p+d;if(n>q){r=q;s=j;break}q=p-d;if(!(n<q)){r=n;s=j;break}r=q;s=j}}while(0);h[s>>3]=r;if((b|0)==3){return+r}c[i>>2]=b;return+r}function uUa(a,b,d,e){a=a|0;b=b|0;d=+d;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0.0,r=0.0,s=0.0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0.0;f=i;i=i+16|0;j=f|0;k=f+8|0;l=a+4|0;m=c[l>>2]|0;n=c[m+524>>2]|0;o=+(n|0);p=c[m+112>>2]|0;if((p|0)>1){q=+(p|0)}else{q=1.0}r=1.0/(+(c[m+104>>2]|0)/+(c[m+108>>2]|0))/q;q=+(c[m+544>>2]|0)/r;s=+(c[m+540>>2]|0)/r;p=c[b+40>>2]|0;sUa(j,k,m,p);m=c[l>>2]|0;t=c[m+520>>2]|0;do{if((t|0)==0){u=d}else{if(!(((e|0)%(t|0)|0|0)==0&(p|0)==2)){u=d;break}u=+g[m+516>>2]*d}}while(0);do{if((n|0)==0){v=u}else{p=a+13240|0;d=+h[p>>3];do{if(q!=0.0){r=(o-d)*2.0/o;do{if(r>1.0){w=1.0}else{if(!(r<1.0e-4)){w=r;break}w=1.0e-4}}while(0);r=u*+S(+w,+(1.0/+g[m+548>>2]));x=(q-o+d)*+g[m+560>>2];y=x>1.0?x:1.0;if(y<.9){yDb(0,16,1998832,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}x=+g[b+4>>2]*+((c[b+12>>2]|0)+1+(c[b+16>>2]|0)|0)/y;if(!(r>x)){A=r;break}t=c[l>>2]|0;if((c[t+688>>2]&2|0)==0){A=x;break}yDb(t,48,2021376,(z=i,i=i+16|0,h[z>>3]=r,h[z+8>>3]=x,z)|0);i=z;A=x}else{A=u}}while(0);if(!(s!=0.0)){v=A;break}x=d*2.0/o;do{if(x>1.0){B=1.0}else{if(!(x<1.0e-4)){B=x;break}B=1.0e-4}}while(0);t=c[l>>2]|0;x=A/+S(+B,+(1.0/+g[t+548>>2]));d=+h[p>>3]*+g[t+556>>2];r=d>1.0?d:1.0;if(r<.9){yDb(0,16,1998832,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}d=+g[b+4>>2]*+((c[b+12>>2]|0)+1+(c[b+16>>2]|0)|0)/r;if(!(x<d)){v=x;break}t=c[l>>2]|0;if((c[t+688>>2]&2|0)==0){v=d;break}yDb(t,48,2021376,(z=i,i=i+16|0,h[z>>3]=x,h[z+8>>3]=d,z)|0);i=z;v=d}}while(0);z=c[j>>2]|0;do{if(!(+g[(c[l>>2]|0)+512>>2]==0.0)){j=c[k>>2]|0;if((z|0)==(j|0)){break}B=+$(+(z|0));A=+$(+(j|0))-B;C=+_(B+A*(1.0/(+_(((+$(v)-B)/A+-.5)*-4.0)+1.0)));i=f;return+C}}while(0);A=+(z|0);if(v<A){C=A;i=f;return+C}A=+(c[k>>2]|0);if(!(v>A)){C=v;i=f;return+C}C=A;i=f;return+C}function vUa(a){a=a|0;var b=0,d=0,e=0,f=0;b=1149856;while(1){d=c[b>>2]|0;if(!((d|0)>-1)){e=0;f=5;break}if((d|0)==(a|0)){break}else{b=b+8|0}}if((f|0)==5){return e|0}e=c[b+4>>2]|0;return e|0}function wUa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=c[b+60>>2]|0;f=b+52|0;g=c[f>>2]|0;do{if((g|0)==1463898711){h=c0a(588576,c[b+792>>2]|0)|0;c[b+140>>2]=h;j=h}else if((g|0)==0){h=b+140|0;k=c[h>>2]|0;if(!((k|0)==-1)){j=k;break}k=c[b+792>>2]|0;if((k|0)==0){j=-1;break}l=c0a(588576,k)|0;c[h>>2]=l;j=l}else if((g|0)==544694642|(g|0)==909201230){l=c0a(588504,c[b+792>>2]|0)|0;c[b+140>>2]=l;j=l}else{l=c0a(1149856,g)|0;c[b+140>>2]=l;j=l}}while(0);g=b+140|0;l=bFb(j)|0;if((l|0)==0){yDb(b,16,1893216,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;m=-22;i=d;return m|0}j=l+7|0;do{if(!((a[j]&66)==0)){h=UAb(1024)|0;c[e+4>>2]=h;if((h|0)==0){m=-12;i=d;return m|0}k=c[h+4>>2]|0;if((a[j]&64)==0){TGb(k|0,0,1024)|0;break}else{fDb(k,c[g>>2]|0)|0;break}}}while(0);j=b+792|0;k=c[j>>2]|0;do{if((k|0)==4|(k|0)==2){if((c[g>>2]|0)!=11){n=19;break}h=c[f>>2]|0;if(!((h|0)==0|(h|0)==544694642)){n=19;break}c[e+16>>2]=1;c[e+8>>2]=QZ(11,(c[b+120>>2]|0)+15&-16,c[b+124>>2]|0)|0}else{n=19}}while(0);if((n|0)==19){do{if(($Eb(l)|0)==16){k=c[j>>2]|0;if((k|0)==0){o=0;break}o=(k|0)<16|0}else{o=0}}while(0);c[e+24>>2]=o;c[e+8>>2]=QZ(c[g>>2]|0,c[b+120>>2]|0,c[b+124>>2]|0)|0}o=c[b+100>>2]|0;if((o|0)>8){if((PGb((c[b+96>>2]|0)+(o-9)|0,2350816,9)|0)==0){n=26}else{n=25}}else{n=25}if((n|0)==25){o=c[f>>2]|0;if((o|0)==1987410275|(o|0)==3|(o|0)==1463898711){n=26}else{p=o}}if((n|0)==26){c[e+12>>2]=1;p=c[f>>2]|0}if((p|0)!=846624121){m=0;i=d;return m|0}if((c[g>>2]|0)!=1){m=0;i=d;return m|0}c[e+20>>2]=1;m=0;i=d;return m|0}function xUa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;j=b+140|0;k=bFb(c[j>>2]|0)|0;l=c[b+60>>2]|0;m=c[g+24>>2]|0;n=g+28|0;o=c[n>>2]|0;p=g|0;do{if((c[p>>2]|0)==0){q=1}else{if((c[l+16>>2]|0)!=0){q=1;break}if((c[l+20>>2]|0)!=0){q=1;break}q=(c[l+24>>2]|0)!=0}}while(0);r=e;s=e;c[e+88>>2]=1;c[e+84>>2]=1;t=b+704|0;u=c[t+4>>2]|0;v=e+320|0;c[v>>2]=c[t>>2];c[v+4>>2]=u;u=b+64|0;v=c[(c[u>>2]|0)+32>>2]|0;t=v+8|0;w=c[t+4>>2]|0;y=e+144|0;c[y>>2]=c[t>>2];c[y+4>>2]=w;w=v+64|0;tCb(r,c[w>>2]|0,c[w+4>>2]|0);w=c[(c[(c[u>>2]|0)+32>>2]|0)+48>>2]|0;rCb(r,w,(w|0)<0|0?-1:0);w=l+28|0;if((c[w>>2]|0)>-1){c[e+296>>2]=1;c[e+300>>2]=c[w>>2]}w=b+120|0;r=b+124|0;u=b;v=hDb(c[w>>2]|0,c[r>>2]|0,0,u)|0;if((v|0)<0){z=v;i=h;return z|0}if(q){v=c[l+8>>2]|0;y=UAb((v|0)>(o|0)?v:o)|0;c[e+360>>2]=y;A=y}else{y=WAb(c[p>>2]|0)|0;c[e+360>>2]=y;A=y}y=e+360|0;if((A|0)==0){z=-12;i=h;return z|0}a:do{if((c[l+16>>2]|0)==0){if((c[l+24>>2]|0)==0){if(!q){B=m;C=o;D=4;break}UGb(c[A+4>>2]|0,m|0,o)|0;B=c[(c[y>>2]|0)+4>>2]|0;C=o;D=4;break}p=c[A+4>>2]|0;v=(o|0)>1;if((a[k+7|0]&1)==0){if(!v){B=p;C=o;D=4;break}t=b+792|0;E=0;while(1){F=m+E|0;G=p+E|0;x=((d[F]|d[F+1|0]<<8)<<16>>16&65535)<<16-(c[t>>2]|0)&65535;a[G]=x;x=x>>8;a[G+1|0]=x;G=E+2|0;if((G|1|0)<(o|0)){E=G}else{B=p;C=o;D=4;break}}}else{if(!v){B=p;C=o;D=4;break}E=b+792|0;t=0;while(1){G=m+t|0;F=(de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=p+t|0;x=de(F<<16-(c[E>>2]|0)&65535|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x;G=t+2|0;if((G|1|0)<(o|0)){t=G}else{B=p;C=o;D=4;break}}}}else{p=c[A+4>>2]|0;t=(c[l+8>>2]|0)-1024|0;E=c[b+792>>2]|0;if((E|0)==2){if((t|0)>3){H=0;I=0;J=3}else{B=p;C=t;D=16;break}while(1){if((H|0)>=(c[n>>2]|0)){B=p;C=t;D=16;break a}v=m+H|0;a[p+I|0]=(d[v]|0)>>>6;a[p+(I|1)|0]=(d[v]|0)>>>4&3;a[p+(I|2)|0]=(d[v]|0)>>>2&3;a[p+J|0]=a[v]&3;v=H+1|0;G=v<<2;F=G|3;if((F|0)<(t|0)){H=v;I=G;J=F}else{B=p;C=t;D=16;break}}}else if((E|0)==4){if((t|0)>1){K=0;L=0;M=1}else{B=p;C=t;D=8;break}while(1){if((K|0)>=(c[n>>2]|0)){B=p;C=t;D=8;break a}F=m+K|0;a[p+L|0]=(d[F]|0)>>>4;a[p+M|0]=a[F]&15;F=K+1|0;G=F<<1;v=G|1;if((v|0)<(t|0)){K=F;L=G;M=v}else{B=p;C=t;D=8;break}}}else{yDb(0,0,2182648,(N=i,i=i+24|0,c[N>>2]=2105648,c[N+8>>2]=2048672,c[N+16>>2]=208,N)|0);i=N;Cd();return 0}}}while(0);M=b+52|0;L=c[M>>2]|0;if((L|0)==2016499265|(L|0)==1886737985){L=c[l+8>>2]|0;O=B+(C-L)|0;P=L}else{O=B;P=c[l+8>>2]|0}B=l+8|0;L=c[j>>2]|0;K=P-((L|0)==11?1024:0)|0;if((C|0)<(K|0)){yDb(u,16,2003160,(N=i,i=i+16|0,c[N>>2]=C,c[N+8>>2]=K,N)|0);i=N;XAb(y);z=-22;i=h;return z|0}N=OZ(s,O,L,c[w>>2]|0,c[r>>2]|0)|0;if((N|0)<0){XAb(y);z=N;i=h;return z|0}N=c[j>>2]|0;if((N|0)==11){L=HZ(g,0,0)|0;do{if((L|0)!=0){g=l+4|0;XAb(g);O=UAb(1024)|0;c[g>>2]=O;if((O|0)!=0){UGb(c[O+4>>2]|0,L|0,1024)|0;c[e+304>>2]=1;break}XAb(y);z=-12;i=h;return z|0}}while(0);Q=c[j>>2]|0}else{Q=N}switch(Q|0){case 25:{R=48;break};case 3:case 8:case 46:case 45:case 44:case 9:case 11:{N=e+32|0;L=D-1+(c[N>>2]|0)&-D;if((ba(L,c[r>>2]|0)|0)<=(C|0)){c[N>>2]=L}if((Q|0)==11){R=52}else if((Q|0)==25){R=48}else{R=53}break};default:{R=53}}do{if((R|0)==48){if((c[M>>2]|0)!=842094158){R=53;break}L=e+32|0;N=c[L>>2]|0;O=D-1|0;g=-D|0;s=O+N&g;K=c[r>>2]|0;u=ba(s,K)|0;P=e+36|0;m=O+(c[P>>2]|0)&g;if(((ba(m,(K+1|0)/2|0)|0)+u|0)<=(C|0)){u=ba(s-N|0,K)|0;K=e+4|0;c[K>>2]=(c[K>>2]|0)+u;c[L>>2]=s;c[P>>2]=m}if((Q|0)==11){R=52}else{R=53}}}while(0);if((R|0)==52){if((C|0)<(c[B>>2]|0)){R=54}else{R=53}}if((R|0)==53){if((a[k+7|0]&64)==0){S=Q}else{R=54}}do{if((R|0)==54){Q=WAb(c[l+4>>2]|0)|0;c[e+364>>2]=Q;if((Q|0)!=0){c[e+4>>2]=c[Q+4>>2];S=c[j>>2]|0;break}XAb(y);z=-12;i=h;return z|0}}while(0);do{if((S|0)==3){y=e+32|0;Q=(c[y>>2]|0)+3&-4;if((ba(Q,c[r>>2]|0)|0)>(C|0)){break}c[y>>2]=Q}}while(0);if((c[l+12>>2]|0)!=0){l=e+32|0;Q=c[l>>2]|0;y=ba(Q,(c[r>>2]|0)-1|0)|0;k=e;c[k>>2]=(c[k>>2]|0)+y;c[l>>2]=-Q}Q=c[M>>2]|0;do{if((Q|0)==842094169|(Q|0)==909203033|(Q|0)==875714137|(Q|0)==961893977){l=e+8|0;y=c[l>>2]|0;k=e+4|0;c[l>>2]=c[k>>2];c[k>>2]=y;R=66}else if((Q|0)==808596553){y=c[w>>2]|0;k=c[r>>2]|0;l=ba(k+1|0,y+1|0)|0;if(((l*3|0|0)/2|0|0)!=(C|0)){break}B=e+4|0;D=l-(ba(k,y)|0)|0;c[B>>2]=(c[B>>2]|0)+D;B=e+8|0;c[B>>2]=(c[B>>2]|0)+((D*5|0|0)/4|0);R=66}else if((Q|0)==846624121){R=67}else{T=Q;R=75}}while(0);if((R|0)==66){if((Q|0)==846624121){R=67}else{T=Q;R=75}}do{if((R|0)==67){if((S|0)!=1){break}Q=c[r>>2]|0;if((Q|0)<=0){break}D=e+32|0;B=0;y=c[e>>2]|0;k=c[w>>2]|0;l=Q;while(1){if((k|0)>0){Q=0;do{m=y+(Q<<1|1)|0;a[m]=a[m]^-128;Q=Q+1|0;U=c[w>>2]|0;}while((Q|0)<(U|0));V=U;W=c[r>>2]|0}else{V=k;W=l}Q=B+1|0;if((Q|0)<(W|0)){B=Q;y=y+(c[D>>2]|0)|0;k=V;l=W}else{break}}T=c[M>>2]|0;R=75}}while(0);do{if((R|0)==75){if((T|0)!=1431918169){break}if((c[j>>2]|0)!=1){break}M=c[r>>2]|0;if((M|0)<=0){break}W=e+32|0;V=0;U=c[e>>2]|0;S=c[w>>2]|0;l=M;while(1){if((S-1|0)>0){M=0;do{k=M<<1;D=U+(k|3)|0;y=a[D]|0;B=U+(k|1)|0;a[D]=a[B]|0;a[B]=y;M=M+2|0;X=c[w>>2]|0;}while((M|0)<(X-1|0));Y=X;Z=c[r>>2]|0}else{Y=S;Z=l}M=V+1|0;if((M|0)<(Z|0)){V=M;U=U+(c[W>>2]|0)|0;S=Y;l=Z}else{break}}}}while(0);Z=c[b+408>>2]|0;do{if(Z>>>0>1>>>0){c[e+296>>2]=1;if(!((Z|0)==2|(Z|0)==4)){break}c[e+300>>2]=1}}while(0);c[f>>2]=1;z=C;i=h;return z|0}function yUa(a){a=a|0;XAb((c[a+60>>2]|0)+4|0);return 0}function zUa(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+140|0;d=bFb(c[b>>2]|0)|0;e=c[a+60>>2]|0;f=a+804|0;c[f>>2]=e;e0a(e);c[(c[f>>2]|0)+88>>2]=1;c[a+792>>2]=$Eb(d)|0;d=a+52|0;if((c[d>>2]|0)!=0){return 0}c[d>>2]=vUa(c[b>>2]|0)|0;return 0}function AUa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=b+140|0;h=b+120|0;i=b+124|0;j=QZ(c[g>>2]|0,c[h>>2]|0,c[i>>2]|0)|0;if((j|0)<0){k=j;return k|0}l=r0a(b,d,j,(j|0)<0|0?-1:0)|0;if((l|0)<0){k=l;return k|0}l=d+24|0;j=PZ(e,c[g>>2]|0,c[h>>2]|0,c[i>>2]|0,c[l>>2]|0,c[d+28>>2]|0)|0;if((j|0)<0){k=j;return k|0}do{if((c[b+52>>2]|0)==846624121&(j|0)>0){if((c[g>>2]|0)!=1){break}if((ba(c[i>>2]<<1,c[h>>2]|0)|0)>1){m=1}else{break}do{e=(c[l>>2]|0)+m|0;a[e]=a[e]^-128;m=m+2|0;}while((m|0)<(ba(c[i>>2]<<1,c[h>>2]|0)|0))}}while(0);h=d+36|0;c[h>>2]=c[h>>2]|1;c[f>>2]=1;k=0;return k|0}function BUa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0.0,j=0,k=0,l=0.0,m=0,n=0,o=0.0,p=0,q=0,r=0;e=1<<b;f=(d|0)==0;do{if(f){c[a>>2]=b;c[a+4>>2]=0;h=0;i=-6.283185307179586/+(e|0);j=6}else{k=(d|0)==3;l=(k?-6.283185307179586:6.283185307179586)/+(e|0);c[a>>2]=b;if((d|0)==1){c[a+4>>2]=1;h=1;i=l;j=6;break}else{c[a+4>>2]=k&1;if((d|0)==2){m=1;n=0;o=l;p=1;break}else{h=0;i=l;j=6;break}}}}while(0);if((j|0)==6){m=(d|0)==3?1:-1;n=h;o=i;p=0}c[a+8>>2]=m;if((b-4|0)>>>0>12>>>0){q=-1;return q|0}if(($8(a+20|0,b-1|0,n?1:p)|0)<0){q=-1;return q|0}_8(b);c[a+12>>2]=c[1237600+(b<<2)>>2];p=c[1138280+(b<<2)>>2]|0;if(f){r=1}else{r=(d|0)==3|0}d=e>>2;e=d&-r;c[a+16>>2]=p+(e<<2);if((d|0)>0){r=0;do{g[p+(e+r<<2)>>2]=+U(o*+(r|0));r=r+1|0;}while((r|0)<(d|0))}c[a+84>>2]=28;q=0;return q|0}function CUa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0,v=0,w=0.0,x=0.0,y=0,z=0;d=1<<c[a>>2];e=a+4|0;f=c[e>>2]|0;h=.5- +(f|0);i=c[a+12>>2]|0;j=c[a+16>>2]|0;if((f|0)==0){f=a+20|0;k=b;ne[c[a+52>>2]&1023](f,k);ne[c[a+56>>2]&1023](f,k)}l=+g[b>>2];k=b+4|0;m=+g[k>>2];g[b>>2]=l+m;g[k>>2]=l-m;f=d>>2;if((f|0)>1){m=-0.0-h;n=1;do{o=n<<1;p=d-o|0;q=b+(o<<2)|0;l=+g[q>>2];r=b+(p<<2)|0;s=+g[r>>2];t=(l+s)*.5;u=(l-s)*m;v=b+((o|1)<<2)|0;s=+g[v>>2];o=b+(p+1<<2)|0;l=+g[o>>2];w=(s-l)*.5;x=h*(s+l);p=i+(n<<2)|0;y=j+(n<<2)|0;g[q>>2]=t+ +g[p>>2]*x-u*+g[y>>2];g[v>>2]=w+u*+g[p>>2]+x*+g[y>>2];g[r>>2]=t-x*+g[p>>2]+u*+g[y>>2];g[o>>2]=u*+g[p>>2]-w+x*+g[y>>2];n=n+1|0;}while((n|0)<(f|0));z=f<<1|1}else{z=3}f=b+(z<<2)|0;g[f>>2]=+(c[a+8>>2]|0)*+g[f>>2];if((c[e>>2]|0)==0){return}g[b>>2]=+g[b>>2]*.5;g[k>>2]=+g[k>>2]*.5;k=a+20|0;e=b;ne[c[a+52>>2]&1023](k,e);ne[c[a+56>>2]&1023](k,e);return}function DUa(a){a=a|0;d9(a+20|0);return}function EUa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+1024|0;g=b|0;h=d;j=c[f+24>>2]|0;IAb(g,0,4096);k=f+28|0;do{if((j|0)!=0){if((c[k>>2]|0)>0){l=j;m=1}else{break}a:while(1){n=a[l]|0;do{if((n<<24>>24|0)==60){o=Vb(l|0,62)|0;if((o|0)==0){break a}if((zAb(l,2182624,5)|0)!=0){if((zAb(l,2105608,4)|0)!=0){p=o;q=m;break}}KAb(g,2048664,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=o;q=m}else if((n<<24>>24|0)==0){break a}else{do{if((EAb(n<<24>>24)|0)==0){MAb(g,a[l]|0,1)}else{if((m|0)!=0){break}MAb(g,32,1)}}while(0);p=l;q=EAb(a[l]|0)|0}}while(0);l=p+1|0;m=q}KAb(g,2003152,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;shb(h,c[g>>2]|0,c[f+8>>2]|0,c[f+48>>2]|0,0)|0}}while(0);c[e>>2]=(c[d+12>>2]|0)!=0;QAb(g,0)|0;i=b;return c[k>>2]|0}function FUa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=c[a+60>>2]|0;g=f;c[f>>2]=a;c[a+140>>2]=11;h=a+96|0;j=c[h>>2]|0;do{if((j|0)!=0){k=a+100|0;if((c[k>>2]|0)<774){break}l=j;m=(d[l]|d[l+1|0]<<8)<<16>>16;b[f+4>>1]=m;l=j+2|0;c[f+8>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=a+120|0;n=a+124|0;if((m&65535|0)>=(ba(c[n>>2]|0,c[l>>2]|0)|0)){yDb(a,16,2105584,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=e;return p|0}m=f+16|0;q=0;do{r=q*3|0;c[m+(q<<2)>>2]=(d[j+(r+6)|0]|0)<<16|(d[j+(r+7)|0]|0)<<8|(d[j+(r+8)|0]|0)|-16777216;q=q+1|0;}while((q|0)<256);q=(c[k>>2]|0)-774|0;if((q|0)<=0){p=0;i=e;return p|0}m=cEb(ba(c[n>>2]|0,c[l>>2]|0)|0)|0;if((m|0)==0){p=-12;i=e;return p|0}IUa(g,(c[h>>2]|0)+774|0,q,m,c[l>>2]|0,0);c[f+12>>2]=m;p=0;i=e;return p|0}}while(0);yDb(a,16,2182600,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=e;return p|0}function GUa(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[f+24>>2]|0;h=c[f+28>>2]|0;f=c[a+60>>2]|0;i=_$a(a,b,0)|0;if((i|0)<0){j=i;return j|0}IUa(f,g,h,c[b>>2]|0,c[b+32>>2]|0,e[f+4>>1]|0);UGb(c[b+4>>2]|0,f+16|0,1024)|0;c[d>>2]=1;j=h;return j|0}function HUa(a){a=a|0;ZDb(c[(c[a+60>>2]|0)+12>>2]|0);return 0}function IUa(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=b|0;j=c[i>>2]|0;k=c[j+120>>2]|0;l=(h|0)%(k|0)|0;m=(h|0)/(k|0)|0;h=g-k|0;n=b+12|0;b=c[n>>2]|0;o=d+e|0;p=f+(ba(c[j+124>>2]|0,g)|0)|0;if((m|0)<0){q=b;r=f;s=k}else{j=ba(m+1|0,g)|0;t=1;u=b;v=f;w=k;k=b;while(1){if((k|0)==0){x=w}else{UGb(v|0,u|0,w)|0;x=c[(c[i>>2]|0)+120>>2]|0}y=u+x|0;if((t|0)>(m|0)){break}t=t+1|0;u=y;v=v+g|0;w=x;k=c[n>>2]|0}q=y;r=f+j|0;s=x}x=q+(l-s)|0;s=r+(-h|0)|0;q=r+(l-g)|0;a:do{if((e|0)>0){l=p;r=h+1|0;j=x;f=q;y=d;k=s;while(1){w=y+1|0;v=a[y]|0;if(v<<24>>24<0){if(!(w>>>0<o>>>0)){z=j;A=f;B=k;break a}u=a[w]|0;if(u<<24>>24==0){z=j;A=f;B=k;break a}else{C=u&255;D=y+2|0}}else{C=1;D=w}if((C|0)>=(l-f|0)){z=j;A=f;B=k;break a}b:do{if((c[n>>2]|0)==0){E=v&127;F=18}else{w=v|-128;if(w<<24>>24==-128){G=C;H=k;I=f;J=j}else{E=w;F=18;break}while(1){w=G;u=I;t=J;while(1){K=w-1|0;if((w|0)==0){L=H;M=u;N=t;break b}m=u+1|0;a[u]=a[t]|0;O=t+1|0;if((m|0)==(H|0)){break}else{w=K;u=m;t=O}}t=u+r|0;w=H+g|0;if((K|0)<(l-t|0)){G=K;H=w;I=t;J=O}else{L=w;M=t;N=O;break}}}}while(0);c:do{if((F|0)==18){F=0;v=C;t=k;w=f;m=j;while(1){i=v;b=w;P=m;while(1){Q=i-1|0;if((i|0)==0){L=t;M=b;N=P;break c}R=b+1|0;a[b]=E;S=P+1|0;if((R|0)==(t|0)){break}else{i=Q;b=R;P=S}}P=b+r|0;i=t+g|0;if((Q|0)<(l-P|0)){v=Q;t=i;w=P;m=S}else{L=i;M=P;N=S;break}}}}while(0);if(D>>>0<o>>>0){j=N;f=M;y=D;k=L}else{z=N;A=M;B=L;break}}}else{z=x;A=q;B=s}}while(0);if((c[n>>2]|0)!=0&A>>>0<p>>>0){T=z;U=A;V=B}else{return}while(1){B=V-U|0;UGb(U|0,T|0,B)|0;A=V+h|0;if(A>>>0<p>>>0){T=T+B|0;U=A;V=V+g|0}else{break}}return}function JUa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a+60|0;f=c[e>>2]|0;g=c[a+416>>2]|0;if((g|0)>2){yDb(a,16,2182568,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=d;return j|0}if((c[a+412>>2]|0)!=22050){yDb(a,16,2105560,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=d;return j|0}c[a+424>>2]=735;c[a+72>>2]=(g*176400|0)+1920;a=WDb(g*11760|0)|0;c[f+12>>2]=a;if((a|0)==0){$Db((c[e>>2]|0)+12|0);j=-12;i=d;return j|0}else{b[f+2>>1]=0;b[f>>1]=0;j=0;i=d;return j|0}return 0}function KUa(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;a:do{if((h|0)==0){j=f+416|0;k=c[f+60>>2]|0;l=j;m=(c[j>>2]|0)==2;n=4}else{j=c[h>>2]|0;o=j;p=c[f+60>>2]|0;q=f+416|0;r=c[q>>2]|0;s=(r|0)==2;if((j|0)==0){k=p;l=q;m=s;n=4;break}t=p+4|0;u=c[t>>2]|0;if((u|0)>=8){v=p+4|0;if(s){w=v;y=p;z=q;A=u;B=o;n=16;break}C=o;D=0;E=q;G=p;H=v;I=c[q>>2]|0;n=19;break}v=p+8|0;u=ba(r,c[v>>2]|0)|0;J=f+424|0;UGb((c[p+12>>2]|0)+(u<<1)|0,j|0,ba(r<<1,c[J>>2]|0)|0)|0;c[v>>2]=(c[v>>2]|0)+(c[J>>2]|0);J=c[t>>2]|0;do{if((J|0)==0){v=h+136|0;r=c[v+4>>2]|0;j=p+16|0;c[j>>2]=c[v>>2];c[j+4>>2]=r}else{if((J|0)<7){break}r=p+4|0;if((J|0)<8){j=c[p+12>>2]|0;if(s){w=r;y=p;z=q;A=7;B=j;n=16;break a}else{K=r;L=p;M=q;N=0;O=7;P=j;n=17;break a}}else{if(s){w=r;y=p;z=q;A=J;B=o;n=16;break a}else{K=r;L=p;M=q;N=0;O=J;P=o;n=17;break a}}}}while(0);c[t>>2]=J+1;Q=0;return Q|0}}while(0);do{if((n|0)==4){o=c[k+4>>2]|0;if((o|0)>7){Q=0;return Q|0}else{q=k+4|0;p=c[k+12>>2]|0;if(m){w=q;y=k;z=l;A=o;B=p;n=16;break}else{K=q;L=k;M=l;N=0;O=o;P=p;n=17;break}}}}while(0);if((n|0)==16){l=y;b[l>>1]=b[l>>1]&-256;l=y+2|0;b[l>>1]=b[l>>1]&-256;K=w;L=y;M=z;N=1;O=A;P=B;n=17}do{if((n|0)==17){B=c[M>>2]|0;if((O|0)!=7){C=P;D=N;E=M;G=L;H=K;I=B;n=19;break}R=L+8|0;S=P;T=N;U=M;V=L;W=K;X=B}}while(0);if((n|0)==19){R=f+424|0;S=C;T=D;U=E;V=G;W=H;X=I}I=ba(c[R>>2]|0,X)|0;X=I+8|0;R=r0a(f,g,X,(X|0)<0|0?-1:0)|0;if((R|0)<0){Q=R;return Q|0}R=c[g+24>>2]|0;a[R]=T?33:32;a[R+1|0]=16;X=R+2|0;x=I;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=R+6|0;f=V;if(T){a[X]=(e[V+2>>1]|0)>>>8;a[R+7|0]=(e[V>>1]|0)>>>8}else{T=X;x=b[V>>1]|0;a[T]=x;x=x>>8;a[T+1|0]=x}if((I|0)>0){T=R+8|0;R=0;X=S;while(1){H=f+((R&1)<<1)|0;G=X+2|0;E=b[H>>1]|0;D=(b[X>>1]|0)-E|0;C=(D|0)<0;n=D>>>31;K=(D|0)>-1?D:-D|0;if((K|0)>16128){Y=127}else{if(K>>>0<255>>>0){Z=(d[K+1135649|0]|0)-1>>4}else{do{if(K>>>0<4096>>>0){_=(d[1135648+(K>>>4)|0]|0)>>>2}else{if(K>>>0<16384>>>0){_=(d[1135648+(K>>>6)|0]|0)>>>1;break}else{D=K>>>16;L=(D&65280|0)==0;M=((d[1191992+(L?D:K>>>24)|0]|0)+(L?0:8)|0)>>>1;L=K>>>((M+2|0)>>>0);D=d[1135648+(L>>>((M+8|0)>>>0))|0]|0;gHb(L,0,c[1199552+(D<<2)>>2]|0,0)|0;_=F+(D<<M)|0;break}}}while(0);Z=_-((ba(_,_)|0)>>>0>K>>>0)|0}Y=((K|0)>((ba(Z,Z)|0)+Z|0))+Z|0}if(C){J=Y;while(1){t=E-(ba(J,J)|0)|0;if((t+32768|0)>>>0>65535>>>0){J=J-1|0}else{$=J;aa=t&65535;break}}}else{J=Y;while(1){C=(ba(J,J)|0)+E|0;if((C+32768|0)>>>0>65535>>>0){J=J-1|0}else{$=J;aa=C&65535;break}}}b[H>>1]=aa;a[T]=$|n<<7;J=R+1|0;if((J|0)<(I|0)){T=T+1|0;R=J;X=G}else{break}}ca=S+(I<<1)|0}else{ca=S}if((c[W>>2]|0)<8){da=V+16|0}else{da=h+136|0}h=c[da+4>>2]|0;V=g+8|0;c[V>>2]=c[da>>2];c[V+4>>2]=h;c[g+48>>2]=(I|0)/(c[U>>2]|0)|0;U=(c[W>>2]|0)+1|0;if((ca|0)==0){ea=(U|0)>8?U:8}else{ea=U}c[W>>2]=ea;c[i>>2]=1;Q=0;return Q|0}function LUa(a){a=a|0;$Db((c[a+60>>2]|0)+12|0);return 0}function MUa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+60>>2]|0;c[d+4>>2]=a;e=c[a+120>>2]|0;do{if((e&15|0)==0){f=a+124|0;if((c[f>>2]&15|0)!=0){break}c[d+5664>>2]=e;c[d+5668>>2]=c[f>>2];f=d+8|0;c[f>>2]=ICb()|0;g=ICb()|0;h=d+12|0;c[h>>2]=g;do{if((g|0)!=0){if((c[f>>2]|0)==0){break}c[a+140>>2]=5;j=0;i=b;return j|0}}while(0);JCb(h);JCb(f);j=-12;i=b;return j|0}}while(0);yDb(a,16,1937648,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-1163346256;i=b;return j|0}function NUa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;h=i;i=i+32|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=g;n=g+12|0;o=c[n>>2]|0;p=c[o>>2]|0;q=$$a(b,o)|0;if((q|0)<0){r=q;i=h;return r|0}if((p|0)==0){TZ(c[n>>2]|0,c[g+8>>2]|0,c[b+140>>2]|0,c[b+120>>2]|0,c[b+124>>2]|0)}if(!((l|0)>-1)){yDb(0,0,2048616,(s=i,i=i+24|0,c[s>>2]=2003104,c[s+8>>2]=1965688,c[s+16>>2]=135,s)|0);i=s;Cd();return 0}b=g+5652|0;c[b>>2]=k;p=g+5660|0;c[p>>2]=k;q=k+l|0;o=g+5656|0;c[o>>2]=q;TGb(j|0,0,32)|0;if(l>>>0>7>>>0){t=q;u=k;a:while(1){v=t;if((v-u|0)<2){w=0;x=u}else{y=u+2|0;c[b>>2]=y;z=u;w=(d[z]|d[z+1|0]<<8)<<16>>16&65535;x=y}if((v-x|0)<4){A=0;B=x}else{y=x+4|0;c[b>>2]=y;z=x;A=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;B=y}if((v-B|0)<2){C=0;D=B}else{v=B+2|0;c[b>>2]=v;y=B;C=(d[y]|d[y+1|0]<<8)<<16>>16&65535;D=v}E=C>>>8;do{if((w|0)==4098){v=(E|0)==0?256:E;y=C&255;if((y|0)==0){G=(v*6|0)>>>0<A>>>0?256:0}else{G=y}y=0;z=t;H=D;while(1){if((z-H|0)<1){I=0}else{c[b>>2]=H+1;I=a[H]|0}a[m+20+(y*6|0)|0]=I;J=c[b>>2]|0;if(((c[o>>2]|0)-J|0)<1){K=0}else{c[b>>2]=J+1;K=a[J]|0}a[m+20+(y*6|0)+1|0]=K;J=c[b>>2]|0;if(((c[o>>2]|0)-J|0)<1){L=0}else{c[b>>2]=J+1;L=a[J]|0}a[m+20+(y*6|0)+2|0]=L;J=c[b>>2]|0;if(((c[o>>2]|0)-J|0)<1){M=0}else{c[b>>2]=J+1;M=a[J]|0}a[m+20+(y*6|0)+3|0]=M;J=c[b>>2]|0;if(((c[o>>2]|0)-J|0)<1){N=0}else{c[b>>2]=J+1;N=a[J]|0}a[m+20+(y*6|0)+4|0]=N;J=c[b>>2]|0;if(((c[o>>2]|0)-J|0)<1){O=0}else{c[b>>2]=J+1;O=a[J]|0}a[m+20+(y*6|0)+5|0]=O;J=y+1|0;if((J|0)>=(v|0)){break}y=J;z=c[o>>2]|0;H=c[b>>2]|0}if((G|0)==0){P=c[b>>2]|0;Q=c[o>>2]|0;break}H=0;z=c[o>>2]|0;y=c[b>>2]|0;while(1){v=z;if((v-y|0)<1){R=0}else{c[b>>2]=y+1;R=d[y]|0}c[m+1556+(H<<4)>>2]=R;J=c[b>>2]|0;if((v-J|0)<1){S=0;T=J}else{v=J+1|0;c[b>>2]=v;S=d[J]|0;T=v}c[m+1556+(H<<4)+4>>2]=S;v=c[o>>2]|0;J=v;if((J-T|0)<1){U=0;V=T}else{W=T+1|0;c[b>>2]=W;U=d[T]|0;V=W}c[m+1556+(H<<4)+8>>2]=U;if((J-V|0)<1){X=0;Y=V}else{J=V+1|0;c[b>>2]=J;X=d[V]|0;Y=J}c[m+1556+(H<<4)+12>>2]=X;J=H+1|0;if((J|0)<(G|0)){H=J;z=v;y=Y}else{P=Y;Q=v;break}}}else if((w|0)==4113){Z=D;_=t;break a}else{P=D;Q=t}}while(0);if((Q-P|0)>>>0>7>>>0){t=Q;u=P}else{Z=P;_=Q;break}}$=E<<24>>24;aa=C<<24>>24;ba=A;ca=Z;da=_;ea=c[p>>2]|0}else{$=0;aa=0;ba=0;ca=k;da=q;ea=k}k=ca;q=k-ea|0;if(ba>>>0>(da-k|0)>>>0){yDb(c[g+4>>2]|0,16,2182528,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;k=c[b>>2]|0;fa=(c[o>>2]|0)-k|0;ga=k;ha=c[p>>2]|0}else{fa=ba;ga=ca;ha=ea}ea=YGb(fa,0,q,(q|0)<0|0?-1:0)|0;q=F;fa=8-$|0;$=8-aa|0;aa=g+5664|0;ca=g+5668|0;ba=ga-ha|0;ha=(ba|0)<0|0?-1:0;b:do{if((ha|0)<(q|0)|(ha|0)==(q|0)&ba>>>0<ea>>>0){ga=0;k=-1;da=0;_=0;c:while(1){Z=_+16|0;A=da+16|0;C=ga;E=k;Q=_;while(1){P=Q+4|0;u=C;t=E;D=da;while(1){w=c[b>>2]|0;Y=w;G=c[p>>2]|0;X=Y-G|0;V=(X|0)<0|0?-1:0;if(!((V|0)<(q|0)|(V|0)==(q|0)&X>>>0<ea>>>0)){ia=45;break c}do{if((t|0)<0){if(((c[o>>2]|0)-Y|0)<2){ja=7;ka=0;la=w;break}X=w+2|0;c[b>>2]=X;V=w;ja=7;ka=(d[V]|d[V+1|0]<<8)<<16>>16&65535;la=X}else{ja=t;ka=u;la=w}}while(0);w=ka>>(ja<<1)&3;Y=j+(w<<2)|0;c[Y>>2]=(c[Y>>2]|0)+1;Y=ja-1|0;d:do{if((w|0)==1){if(((c[o>>2]|0)-la|0)<1){ma=0}else{c[b>>2]=la+1;ma=d[la]|0}qnb(m,D,Q,fa-(ma>>>4)|0,$-(ma&15)|0);na=Y;oa=ka}else if((w|0)==3){X=D+4|0;V=la;U=V-G|0;T=(U|0)<0|0?-1:0;if((T|0)<(q|0)|(T|0)==(q|0)&U>>>0<ea>>>0){pa=la;qa=Y;ra=ka;sa=0;ta=D;ua=Q;va=V}else{ia=57;break c}while(1){do{if((qa|0)<0){if(((c[o>>2]|0)-va|0)<2){wa=7;xa=0;ya=pa;break}V=pa+2|0;c[b>>2]=V;U=pa;wa=7;xa=(d[U]|d[U+1|0]<<8)<<16>>16&65535;ya=V}else{wa=qa;xa=ra;ya=pa}}while(0);V=xa>>(wa<<1)&3;U=j+16+(V<<2)|0;c[U>>2]=(c[U>>2]|0)+1;U=wa-1|0;if((V|0)==2){if(((c[o>>2]|0)-ya|0)<1){za=0}else{c[b>>2]=ya+1;za=d[ya]|0}mnb(m,ta,ua,m+20+((c[m+1556+(za<<4)>>2]|0)*6|0)|0);T=ta+2|0;mnb(m,T,ua,m+20+((c[m+1556+(za<<4)+4>>2]|0)*6|0)|0);S=ua+2|0;mnb(m,ta,S,m+20+((c[m+1556+(za<<4)+8>>2]|0)*6|0)|0);mnb(m,T,S,m+20+((c[m+1556+(za<<4)+12>>2]|0)*6|0)|0)}else if((V|0)==3){if(((c[o>>2]|0)-ya|0)<1){Aa=0}else{c[b>>2]=ya+1;Aa=d[ya]|0}mnb(m,ta,ua,m+20+(Aa*6|0)|0);S=ta+2|0;T=c[b>>2]|0;if(((c[o>>2]|0)-T|0)<1){Ba=0}else{c[b>>2]=T+1;Ba=d[T]|0}mnb(m,S,ua,m+20+(Ba*6|0)|0);T=ua+2|0;R=c[b>>2]|0;if(((c[o>>2]|0)-R|0)<1){Ca=0}else{c[b>>2]=R+1;Ca=d[R]|0}mnb(m,ta,T,m+20+(Ca*6|0)|0);R=c[b>>2]|0;if(((c[o>>2]|0)-R|0)<1){Da=0}else{c[b>>2]=R+1;Da=d[R]|0}mnb(m,S,T,m+20+(Da*6|0)|0)}else if((V|0)==1){if(((c[o>>2]|0)-ya|0)<1){Ea=0}else{c[b>>2]=ya+1;Ea=d[ya]|0}onb(m,ta,ua,fa-(Ea>>>4)|0,$-(Ea&15)|0)}V=sa+1|0;if((V|0)>=4){na=U;oa=xa;break d}T=c[b>>2]|0;S=T;R=S-(c[p>>2]|0)|0;O=(R|0)<0|0?-1:0;if((O|0)<(q|0)|(O|0)==(q|0)&R>>>0<ea>>>0){pa=T;qa=U;ra=xa;sa=V;ta=(V&1|0)==0?D:X;ua=(V&2|0)==0?Q:P;va=S}else{ia=57;break c}}}else if((w|0)==2){if(((c[o>>2]|0)-la|0)<1){Fa=0}else{c[b>>2]=la+1;Fa=d[la]|0}nnb(m,D,Q,m+20+((c[m+1556+(Fa<<4)>>2]|0)*6|0)|0);X=D+4|0;nnb(m,X,Q,m+20+((c[m+1556+(Fa<<4)+4>>2]|0)*6|0)|0);nnb(m,D,P,m+20+((c[m+1556+(Fa<<4)+8>>2]|0)*6|0)|0);nnb(m,X,P,m+20+((c[m+1556+(Fa<<4)+12>>2]|0)*6|0)|0);na=Y;oa=ka}else{na=Y;oa=ka}}while(0);Y=D+8|0;if((Y|0)<(A|0)){u=oa;t=na;D=Y}else{break}}D=Q+8|0;if((D|0)<(Z|0)){C=oa;E=na;Q=D}else{break}}Q=c[aa>>2]|0;E=(A|0)<(Q|0);C=E?_:Z;if((C|0)>=(c[ca>>2]|0)){break b}D=(c[b>>2]|0)-(c[p>>2]|0)|0;t=(D|0)<0|0?-1:0;if((t|0)<(q|0)|(t|0)==(q|0)&D>>>0<ea>>>0){ga=oa;k=na;da=A-(E?0:Q)|0;_=C}else{break b}}if((ia|0)==45){yDb(c[g+4>>2]|0,40,2105536,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;break}else if((ia|0)==57){yDb(c[g+4>>2]|0,40,2105536,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;break}}}while(0);s=MCb(e,c[n>>2]|0)|0;if((s|0)<0){r=s;i=h;return r|0}c[f>>2]=1;f=g+8|0;g=c[f>>2]|0;c[f>>2]=c[n>>2];c[n>>2]=g;r=l;i=h;return r|0}function OUa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+12|0);JCb(b+8|0);return 0}function PUa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=a+60|0;e=c[d>>2]|0;oDb(e+5672|0,1);f=e+5960|0;c[f>>2]=0;g=a+120|0;h=c[g>>2]|0;do{if((h&15|0)==0){j=a+124|0;k=c[j>>2]|0;if((k&15|0)!=0){break}if((h-1&h|0)==0){if((k-1&k|0)==0){l=h}else{m=6}}else{m=6}if((m|0)==6){yDb(a,16,2048576,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=c[g>>2]|0}k=e+5664|0;c[k>>2]=l;o=e+5668|0;c[o>>2]=c[j>>2];c[f>>2]=0;c[e+16>>2]=1;j=e+8|0;c[j>>2]=ICb()|0;p=ICb()|0;c[e+12>>2]=p;if((c[j>>2]|0)==0|(p|0)==0){p=c[d>>2]|0;JCb(p+12|0);JCb(p+8|0);ZDb(c[p+5972>>2]|0);ZDb(c[p+5944>>2]|0);ZDb(c[p+5948>>2]|0);ZDb(c[p+5952>>2]|0);ZDb(c[p+5956>>2]|0);q=-12;i=b;return q|0}else{c[e+5972>>2]=WDb(70700)|0;c[e+5944>>2]=cEb(((ba(c[o>>2]|0,c[k>>2]|0)|0)/16|0)<<3)|0;c[e+5948>>2]=WDb(((ba(c[o>>2]|0,c[k>>2]|0)|0)/16|0)<<3)|0;c[e+5952>>2]=cEb(((ba(c[o>>2]|0,c[k>>2]|0)|0)/64|0)<<3)|0;c[e+5956>>2]=WDb(((ba(c[o>>2]|0,c[k>>2]|0)|0)/64|0)<<3)|0;q=0;i=b;return q|0}}}while(0);yDb(a,16,2105496,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=-22;i=b;return q|0}function QUa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;h=i;i=i+288|0;j=h|0;k=h+80|0;l=h+272|0;m=c[b+60>>2]|0;n=m;o=m+4|0;c[o>>2]=b;p=m+5964|0;c[p>>2]=f;q=c[f+168>>2]|0;if((q|0)==0){f=m+5936|0;c[f>>2]=256;c[f+4>>2]=0}else{f=q-1|0;q=m+5936|0;c[q>>2]=f;c[q+4>>2]=(f|0)<0|0?-1:0}f=m+5664|0;q=m+5668|0;r=(((((ba(c[q>>2]|0,c[f>>2]|0)|0)/64|0)*138|0)+7|0)/8|0)+2568|0;s=r0a(b,e,r,(r|0)<0|0?-1:0)|0;if((s|0)<0){t=s;i=h;return t|0}s=e+24|0;r=m+5968|0;c[r>>2]=c[s>>2];u=m+5960|0;if((c[u>>2]|0)==(c[b+136>>2]|0)){c[u>>2]=0}v=m+16|0;do{if((c[v>>2]|0)!=0){w=_$a(b,c[m+12>>2]|0,0)|0;if((w|0)<0){t=w;i=h;return t|0}w=_$a(b,c[m+8>>2]|0,0)|0;if((w|0)<0){t=w;i=h;return t|0}else{w=c[r>>2]|0;x=4097;a[w]=x;x=x>>8;a[w+1|0]=x;w=(c[r>>2]|0)+2|0;c[r>>2]=w;y=w;x=8;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;y=(c[r>>2]|0)+4|0;c[r>>2]=y;a[y]=0;y=(c[r>>2]|0)+1|0;c[r>>2]=y;a[y]=0;y=(c[r>>2]|0)+1|0;c[r>>2]=y;w=y;x=c[f>>2]&65535;a[w]=x;x=x>>8;a[w+1|0]=x;w=(c[r>>2]|0)+2|0;c[r>>2]=w;y=w;x=c[q>>2]&65535;a[y]=x;x=x>>8;a[y+1|0]=x;y=(c[r>>2]|0)+2|0;c[r>>2]=y;a[y]=8;y=(c[r>>2]|0)+1|0;c[r>>2]=y;a[y]=0;y=(c[r>>2]|0)+1|0;c[r>>2]=y;a[y]=4;y=(c[r>>2]|0)+1|0;c[r>>2]=y;a[y]=0;c[r>>2]=(c[r>>2]|0)+1;c[v>>2]=0;break}}}while(0);v=c[m+5972>>2]|0;TGb(v|0,0,70700)|0;b=WDb(((ba(c[q>>2]|0,c[f>>2]|0)|0)/64|0)*248|0)|0;y=v|0;c[y>>2]=b;w=c[q>>2]|0;z=c[f>>2]|0;if((w|0)>0){A=(z|0)>0;B=0;C=0;while(1){if(A){D=C|8;G=B;H=0;while(1){c[b+(G*248|0)+240>>2]=H;I=G+1|0;c[b+(G*248|0)+244>>2]=C;J=H|8;c[b+(I*248|0)+240>>2]=J;K=G+2|0;c[b+(I*248|0)+244>>2]=C;c[b+(K*248|0)+240>>2]=H;I=G+3|0;c[b+(K*248|0)+244>>2]=D;c[b+(I*248|0)+240>>2]=J;c[b+(I*248|0)+244>>2]=D;I=G+4|0;J=H+16|0;if((J|0)<(z|0)){G=I;H=J}else{L=I;break}}}else{L=B}H=C+16|0;if((H|0)<(w|0)){B=L;C=H}else{break}}}C=(ba(z,w)|0)/16|0;w=WDb(6144)|0;z=w;L=C*96|0;B=WDb(L)|0;b=WDb(L)|0;L=b;A=c[p>>2]|0;H=c[f>>2]|0;G=c[q>>2]|0;a:do{if((G|0)>0){D=A|0;I=A+32|0;J=A+36|0;K=A+4|0;M=A+8|0;if((H|0)>0){N=B;O=0}else{R=0;while(1){R=R+4|0;if((R|0)>=(G|0)){break a}}}while(1){R=N;S=0;do{T=0;do{U=T<<1;V=U+O|0;W=V|1;X=0;do{Y=(X+U|0)*6|0;Z=(X<<1)+S|0;_=(ba(c[I>>2]|0,V)|0)+Z|0;a[R+Y|0]=a[(c[D>>2]|0)+_|0]|0;_=(ba(c[J>>2]|0,V)|0)+Z|0;$=d[(c[K>>2]|0)+_|0]|0;ca=d[(c[M>>2]|0)+_|0]|0;_=Z|1;da=(ba(c[I>>2]|0,V)|0)+_|0;a[R+(Y|1)|0]=a[(c[D>>2]|0)+da|0]|0;da=(ba(c[J>>2]|0,V)|0)+_|0;ea=d[(c[K>>2]|0)+da|0]|0;fa=d[(c[M>>2]|0)+da|0]|0;da=(ba(c[I>>2]|0,W)|0)+Z|0;a[R+(Y+2)|0]=a[(c[D>>2]|0)+da|0]|0;da=(ba(c[J>>2]|0,W)|0)+Z|0;Z=d[(c[K>>2]|0)+da|0]|0;ha=d[(c[M>>2]|0)+da|0]|0;da=(ba(c[I>>2]|0,W)|0)+_|0;a[R+(Y+3)|0]=a[(c[D>>2]|0)+da|0]|0;da=(ba(c[J>>2]|0,W)|0)+_|0;_=d[(c[M>>2]|0)+da|0]|0;a[R+(Y+4)|0]=($+2+ea+Z+(d[(c[K>>2]|0)+da|0]|0)|0)>>>2;a[R+(Y+5)|0]=(ca+2+fa+ha+_|0)>>>2;X=X+1|0;}while((X|0)<2);T=T+1|0;}while((T|0)<2);R=R+24|0;S=S+4|0;}while((S|0)<(H|0));S=O+4|0;if((S|0)<(G|0)){N=R;O=S}else{break}}}}while(0);O=C*24|0;if((O|0)>0){N=0;do{c[L+(N<<2)>>2]=d[B+N|0]|0;N=N+1|0;}while((N|0)<(O|0))}O=m+5976|0;VUa(n,v,L,C,z,4,(c[O>>2]|0)!=0?255:256);N=v+4112|0;c[N>>2]=(c[O>>2]|0)!=0?255:256;G=v+70680|0;c[G>>2]=WDb(C<<4)|0;VUa(n,v,L,C<<2,m+20|0,2,256);C=v+4116|0;c[C>>2]=256;L=0;do{H=L*12|0;A=n+20+(L*6|0)|0;K=v+6168+H|0;x=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;TGb(H+4+(v+6168)|0,a[n+20+(L*6|0)+4|0]|0,4)|0;TGb(H+8+(v+6168)|0,a[n+20+(L*6|0)+5|0]|0,4)|0;L=L+1|0;}while((L|0)<(c[C>>2]|0));if((c[N>>2]|0)>0){L=0;do{H=L<<2;K=0;do{A=K+H|0;M=z+(A*6|0)|0;J=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;M=c[C>>2]|0;D=n+1556+(L<<4)+(K<<2)|0;I=J>>>24;if((M|0)>0){S=J&255;T=J>>>8&255;X=J>>>16&255;J=d[z+(A*6|0)+4|0]|0;W=d[z+(A*6|0)+5|0]|0;A=2147483647;V=0;U=0;while(1){_=U*12|0;ha=_|1;fa=(d[v+6168+_|0]|0)-S|0;ca=(d[v+6168+ha|0]|0)-T|0;Y=ba(ca,ca)|0;ca=(d[ha+1+(v+6168)|0]|0)-X|0;ha=ba(ca,ca)|0;ca=(d[(_|3)+(v+6168)|0]|0)-I|0;da=ba(ca,ca)|0;ca=(d[_+4+(v+6168)|0]|0)-J|0;Z=(d[_+5+(v+6168)|0]|0)-J|0;ea=ba(Z,Z)|0;Z=(d[_+6+(v+6168)|0]|0)-J|0;$=ba(Z,Z)|0;Z=(d[_+7+(v+6168)|0]|0)-J|0;ia=ba(Z,Z)|0;Z=Y+(ba(fa,fa)|0)+ha+da|0;da=(d[_+8+(v+6168)|0]|0)-W|0;ha=ba(da,da)|0;da=(d[_+9+(v+6168)|0]|0)-W|0;fa=ba(da,da)|0;da=(d[_+10+(v+6168)|0]|0)-W|0;Y=ba(da,da)|0;da=(d[_+11+(v+6168)|0]|0)-W|0;_=ea+(ba(ca,ca)|0)+(Z<<2)+$+ia+ha+fa+Y+(ba(da,da)|0)|0;da=(_|0)<(A|0);Y=da?U:V;fa=U+1|0;if((fa|0)<(M|0)){A=da?_:A;V=Y;U=fa}else{ja=Y;break}}}else{ja=0}c[D>>2]=ja;K=K+1|0;}while((K|0)<4);K=L*48|0;H=0;do{U=H<<2;V=H<<4;A=V+K|0;M=(V|1)+K|0;W=(V|4)+K|0;J=(V|5)+K|0;V=0;do{I=n+1556+(L<<4)+(V<<2)|0;X=c[163112+(V<<2)>>2]|0;a[A+X+(v+9240)|0]=a[((c[I>>2]|0)*12|0)+U+(v+6168)|0]|0;a[M+X+(v+9240)|0]=a[(((c[I>>2]|0)*12|0)+U|1)+(v+6168)|0]|0;a[W+X+(v+9240)|0]=a[(((c[I>>2]|0)*12|0)+U|2)+(v+6168)|0]|0;a[J+X+(v+9240)|0]=a[(((c[I>>2]|0)*12|0)+U|3)+(v+6168)|0]|0;V=V+1|0;}while((V|0)<4);H=H+1|0;}while((H|0)<3);H=L*192|0;V=v+21528+H|0;U=0;while(1){J=((U|0)/2|0)<<2;W=J+K+(v+9240)|0;a[V]=a[W]|0;a[V+1|0]=a[W]|0;W=(J|1)+K+(v+9240)|0;a[V+2|0]=a[W]|0;a[V+3|0]=a[W]|0;W=(J|2)+K+(v+9240)|0;a[V+4|0]=a[W]|0;a[V+5|0]=a[W]|0;W=(J|3)+K+(v+9240)|0;a[V+6|0]=a[W]|0;a[V+7|0]=a[W]|0;W=U+1|0;if((W|0)<8){V=V+8|0;U=W}else{break}}U=K+16|0;V=K+17|0;W=K+18|0;J=K+19|0;M=H+64+(v+21528)|0;A=0;while(1){D=((A|0)/2|0)<<2;I=U+D+(v+9240)|0;a[M]=a[I]|0;a[M+1|0]=a[I]|0;I=V+D+(v+9240)|0;a[M+2|0]=a[I]|0;a[M+3|0]=a[I]|0;I=W+D+(v+9240)|0;a[M+4|0]=a[I]|0;a[M+5|0]=a[I]|0;I=J+D+(v+9240)|0;a[M+6|0]=a[I]|0;a[M+7|0]=a[I]|0;I=A+1|0;if((I|0)<8){M=M+8|0;A=I}else{break}}A=K+32|0;M=K+33|0;J=K+34|0;W=K+35|0;V=H+128+(v+21528)|0;U=0;while(1){I=((U|0)/2|0)<<2;D=A+I+(v+9240)|0;a[V]=a[D]|0;a[V+1|0]=a[D]|0;D=M+I+(v+9240)|0;a[V+2|0]=a[D]|0;a[V+3|0]=a[D]|0;D=J+I+(v+9240)|0;a[V+4|0]=a[D]|0;a[V+5|0]=a[D]|0;D=W+I+(v+9240)|0;a[V+6|0]=a[D]|0;a[V+7|0]=a[D]|0;D=U+1|0;if((D|0)<8){V=V+8|0;U=D}else{break}}L=L+1|0;}while((L|0)<(c[N>>2]|0))}ZDb(B);ZDb(b);ZDb(w);if((c[u>>2]|0)!=0){SUa(n,8);SUa(n,4)}w=v+4100|0;b=k|0;B=l;L=m+12|0;ja=k+64|0;z=k+128|0;k=l+12|0;C=m+5936|0;U=l|0;V=l+4|0;W=l+8|0;J=m+5952|0;M=m+8|0;A=v+70684|0;H=v+4120|0;K=0;while(1){D=c[f>>2]|0;if((K|0)>=((ba(c[q>>2]|0,D)|0)/64|0|0)){I=c[w>>2]|0;if((I|0)<=524287){ka=0;la=0;break}if((c[O>>2]|0)==0){ka=0;la=0;break}yDb(c[o>>2]|0,16,2182424,(X=i,i=i+8|0,c[X>>2]=(I|0)/8|0,X)|0);i=X;ma=(+((c[C>>2]|0)>>>0)+ +((c[C+4>>2]|0)>>>0)*4294967296.0)*1.5;X=(E=+ma,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[C>>2]=~~+ma>>>0;c[C+4>>2]=X;c[w>>2]=0;TGb(A|0,0,16)|0;TGb(H|0,0,2048)|0;K=0;continue}X=c[y>>2]|0;I=X+(K*248|0)|0;T=X+(K*248|0)+244|0;S=c[T>>2]|0;R=(ba(S,D)|0)/64|0;D=X+(K*248|0)+240|0;Y=c[D>>2]|0;fa=((Y|0)/8|0)+R|0;c[B>>2]=c[258734];c[B+4>>2]=c[258735];c[B+8>>2]=c[258736];c[B+12>>2]=c[258737];if((c[u>>2]|0)==0){c[X+(K*248|0)+4>>2]=2147483647}else{R=(c[J>>2]|0)+(fa<<3)|0;_=X+(K*248|0)+228|0;da=c[R+4>>2]|0;c[_>>2]=c[R>>2];c[_+4>>2]=da;da=c[J>>2]|0;_=c[da+(fa<<3)>>2]|0;R=c[da+(fa<<3)+4>>2]|0;do{if((_+7|0)>>>0>14>>>0){na=2147483647}else{if((R+7|0)>>>0>14>>>0){na=2147483647;break}fa=_+Y|0;da=R+S|0;if(fa>>>0>((c[f>>2]|0)-8|0)>>>0){na=2147483647;break}if(da>>>0>((c[q>>2]|0)-8|0)>>>0){na=2147483647;break}ha=c[p>>2]|0;ia=c[M>>2]|0;na=TUa(ha|0,ia|0,Y,S,fa,da,ha+32|0,ia+32|0,8)|0}}while(0);c[X+(K*248|0)+4>>2]=na}if((c[u>>2]|0)>>>0>1>>>0){R=c[p>>2]|0;_=c[L>>2]|0;c[I>>2]=TUa(R|0,_|0,Y,S,Y,S,R+32|0,_+32|0,8)|0;oa=R}else{c[I>>2]=2147483647;oa=c[p>>2]|0}R=c[oa+32>>2]|0;_=oa|0;ia=0;ha=b;while(1){da=(ba(ia+S|0,R)|0)+Y|0;a[ha]=a[(c[_>>2]|0)+da|0]|0;a[ha+1|0]=a[(c[_>>2]|0)+(da+1)|0]|0;a[ha+2|0]=a[(c[_>>2]|0)+(da+2)|0]|0;a[ha+3|0]=a[(c[_>>2]|0)+(da+3)|0]|0;a[ha+4|0]=a[(c[_>>2]|0)+(da+4)|0]|0;a[ha+5|0]=a[(c[_>>2]|0)+(da+5)|0]|0;a[ha+6|0]=a[(c[_>>2]|0)+(da+6)|0]|0;a[ha+7|0]=a[(c[_>>2]|0)+(da+7)|0]|0;da=ia+1|0;if((da|0)<8){ia=da;ha=ha+8|0}else{break}}ha=c[oa+36>>2]|0;ia=oa+4|0;_=0;R=ja;while(1){da=(ba(_+S|0,ha)|0)+Y|0;a[R]=a[(c[ia>>2]|0)+da|0]|0;a[R+1|0]=a[(c[ia>>2]|0)+(da+1)|0]|0;a[R+2|0]=a[(c[ia>>2]|0)+(da+2)|0]|0;a[R+3|0]=a[(c[ia>>2]|0)+(da+3)|0]|0;a[R+4|0]=a[(c[ia>>2]|0)+(da+4)|0]|0;a[R+5|0]=a[(c[ia>>2]|0)+(da+5)|0]|0;a[R+6|0]=a[(c[ia>>2]|0)+(da+6)|0]|0;a[R+7|0]=a[(c[ia>>2]|0)+(da+7)|0]|0;da=_+1|0;if((da|0)<8){_=da;R=R+8|0}else{break}}R=c[oa+40>>2]|0;_=oa+8|0;ia=0;ha=z;while(1){da=(ba(ia+S|0,R)|0)+Y|0;a[ha]=a[(c[_>>2]|0)+da|0]|0;a[ha+1|0]=a[(c[_>>2]|0)+(da+1)|0]|0;a[ha+2|0]=a[(c[_>>2]|0)+(da+2)|0]|0;a[ha+3|0]=a[(c[_>>2]|0)+(da+3)|0]|0;a[ha+4|0]=a[(c[_>>2]|0)+(da+4)|0]|0;a[ha+5|0]=a[(c[_>>2]|0)+(da+5)|0]|0;a[ha+6|0]=a[(c[_>>2]|0)+(da+6)|0]|0;a[ha+7|0]=a[(c[_>>2]|0)+(da+7)|0]|0;da=ia+1|0;if((da|0)<8){ia=da;ha=ha+8|0}else{break}}ha=c[N>>2]|0;ia=X+(K*248|0)+236|0;if((ha|0)>0){_=2147483647;Y=0;R=0;while(1){S=R*192|0;da=b;fa=v+21528+S|0;$=64;Z=0;while(1){ca=$-1|0;ea=(d[fa]|0)-(d[da]|0)|0;pa=(ba(ea,ea)|0)+Z|0;if((ca|0)==0){break}else{da=da+1|0;fa=fa+1|0;$=ca;Z=pa}}Z=ja;$=S+64+(v+21528)|0;fa=64;da=0;while(1){ca=fa-1|0;ea=(d[$]|0)-(d[Z]|0)|0;qa=(ba(ea,ea)|0)+da|0;if((ca|0)==0){break}else{Z=Z+1|0;$=$+1|0;fa=ca;da=qa}}da=z;fa=S+128+(v+21528)|0;$=64;Z=0;while(1){ca=$-1|0;ea=(d[fa]|0)-(d[da]|0)|0;ra=(ba(ea,ea)|0)+Z|0;if((ca|0)==0){break}else{da=da+1|0;fa=fa+1|0;$=ca;Z=ra}}Z=qa+(pa<<2)+ra|0;$=(Z|0)<(_|0);fa=$?Z:_;Z=$?R:Y;$=R+1|0;if(($|0)<(ha|0)){_=fa;Y=Z;R=$}else{sa=fa;ta=Z;break}}}else{sa=2147483647;ta=0}c[ia>>2]=ta;R=X+(K*248|0)+8|0;c[R>>2]=sa;UUa(X+(K*248|0)+20|0,c[D>>2]|0,c[T>>2]|0,n,v);UUa(X+(K*248|0)+72|0,(c[D>>2]|0)+4|0,c[T>>2]|0,n,v);UUa(X+(K*248|0)+124|0,c[D>>2]|0,(c[T>>2]|0)+4|0,n,v);UUa(X+(K*248|0)+176|0,(c[D>>2]|0)+4|0,(c[T>>2]|0)+4|0,n,v);Y=X+(K*248|0)+12|0;c[Y>>2]=0;_=c[X+(K*248|0)+20+(c[X+(K*248|0)+40>>2]<<2)>>2]|0;c[Y>>2]=_;ha=c[X+(K*248|0)+36>>2]|0;Z=(c[X+(K*248|0)+72+(c[X+(K*248|0)+92>>2]<<2)>>2]|0)+_|0;c[Y>>2]=Z;_=c[X+(K*248|0)+88>>2]|0;fa=(c[X+(K*248|0)+124+(c[X+(K*248|0)+144>>2]<<2)>>2]|0)+Z|0;c[Y>>2]=fa;Z=c[X+(K*248|0)+140>>2]|0;$=(c[X+(K*248|0)+176+(c[X+(K*248|0)+196>>2]<<2)>>2]|0)+fa|0;c[Y>>2]=$;Y=ha+2+_+Z+(c[X+(K*248|0)+192>>2]|0)|0;c[k>>2]=Y;Z=c[C>>2]|0;_=c[C+4>>2]|0;ha=X+(K*248|0)+16|0;fa=c[I>>2]|0;da=fa;S=c[U>>2]|0;ca=gHb(S,(S|0)<0|0?-1:0,Z,_)|0;S=YGb(ca,F,da<<7|0>>>25,((fa|0)<0|0?-1:0)<<7|da>>>25)|0;da=F;fa=0;if(da>>>0<fa>>>0|da>>>0==fa>>>0&S>>>0<2147483647>>>0){c[ha>>2]=0;ua=S}else{ua=2147483647}S=c[X+(K*248|0)+4>>2]|0;fa=S;da=c[V>>2]|0;ca=gHb(da,(da|0)<0|0?-1:0,Z,_)|0;da=YGb(ca,F,fa<<7|0>>>25,((S|0)<0|0?-1:0)<<7|fa>>>25)|0;fa=F;S=(ua|0)<0|0?-1:0;if(fa>>>0<S>>>0|fa>>>0==S>>>0&da>>>0<ua>>>0){c[ha>>2]=1;va=da}else{va=ua}da=c[R>>2]|0;R=da;S=c[W>>2]|0;fa=gHb(S,(S|0)<0|0?-1:0,Z,_)|0;S=YGb(fa,F,R<<7|0>>>25,((da|0)<0|0?-1:0)<<7|R>>>25)|0;R=F;da=(va|0)<0|0?-1:0;if(R>>>0<da>>>0|R>>>0==da>>>0&S>>>0<va>>>0){c[ha>>2]=2;wa=S}else{wa=va}S=$;da=gHb(Y,(Y|0)<0|0?-1:0,Z,_)|0;_=YGb(da,F,S<<7|0>>>25,(($|0)<0|0?-1:0)<<7|S>>>25)|0;S=F;$=(wa|0)<0|0?-1:0;if(S>>>0<$>>>0|S>>>0==$>>>0&_>>>0<wa>>>0){c[ha>>2]=3;xa=3}else{xa=c[ha>>2]|0}_=v+70684+(xa<<2)|0;c[_>>2]=(c[_>>2]|0)+1;c[w>>2]=(c[w>>2]|0)+(c[l+(c[ha>>2]<<2)>>2]|0);_=c[ha>>2]|0;if((_|0)==2){$=v+5144+(c[ia>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1;ya=c[ha>>2]|0}else{ya=_}if((ya|0)==3){_=0;do{ha=c[X+(K*248|0)+20+(_*52|0)+20>>2]|0;if((ha|0)==3){$=v+4120+(c[X+(K*248|0)+20+(_*52|0)+24>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1;$=v+4120+(c[X+(K*248|0)+20+(_*52|0)+28>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1;$=v+4120+(c[X+(K*248|0)+20+(_*52|0)+32>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1;$=v+4120+(c[X+(K*248|0)+20+(_*52|0)+36>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1}else if((ha|0)==2){ha=v+5144+(c[X+(K*248|0)+20+(_*52|0)+48>>2]<<2)|0;c[ha>>2]=(c[ha>>2]|0)+1}_=_+1|0;}while((_|0)<4)}K=K+1|0}while(1){if((c[v+5144+(ka<<2)>>2]|0)==0){za=la}else{c[v+1028+(ka<<2)>>2]=la;c[v+4+(la<<2)>>2]=ka;K=v+4120+(c[n+1556+(ka<<4)>>2]<<2)|0;c[K>>2]=(c[K>>2]|0)+1;K=v+4120+(c[n+1556+(ka<<4)+4>>2]<<2)|0;c[K>>2]=(c[K>>2]|0)+1;K=v+4120+(c[n+1556+(ka<<4)+8>>2]<<2)|0;c[K>>2]=(c[K>>2]|0)+1;K=v+4120+(c[n+1556+(ka<<4)+12>>2]<<2)|0;c[K>>2]=(c[K>>2]|0)+1;za=la+1|0}K=ka+1|0;if((K|0)<(((c[O>>2]|0)!=0?255:256)|0)){ka=K;la=za}else{break}}la=v+4104|0;c[la>>2]=za;za=0;ka=0;while(1){if((c[v+4120+(za<<2)>>2]|0)==0){Aa=ka}else{c[v+3076+(za<<2)>>2]=ka;c[v+2052+(ka<<2)>>2]=za;Aa=ka+1|0}O=za+1|0;if((O|0)<256){za=O;ka=Aa}else{break}}ka=v+4108|0;c[ka>>2]=Aa;do{if((Aa|0)!=0){za=c[r>>2]|0;x=4098;a[za]=x;x=x>>8;a[za+1|0]=x;za=(c[r>>2]|0)+2|0;c[r>>2]=za;O=za;x=(c[la>>2]<<2)+((c[ka>>2]|0)*6|0)|0;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;O=(c[r>>2]|0)+4|0;c[r>>2]=O;a[O]=c[la>>2];O=(c[r>>2]|0)+1|0;c[r>>2]=O;a[O]=c[ka>>2];O=(c[r>>2]|0)+1|0;c[r>>2]=O;if((c[ka>>2]|0)>0){za=0;K=O;while(1){ya=v+2052+(za<<2)|0;l=n+20+((c[ya>>2]|0)*6|0)|0;xa=K;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;xa=(c[r>>2]|0)+4|0;c[r>>2]=xa;a[xa]=a[n+20+((c[ya>>2]|0)*6|0)+4|0]|0;xa=(c[r>>2]|0)+1|0;c[r>>2]=xa;a[xa]=a[n+20+((c[ya>>2]|0)*6|0)+5|0]|0;ya=(c[r>>2]|0)+1|0;c[r>>2]=ya;xa=za+1|0;if((xa|0)<(c[ka>>2]|0)){za=xa;K=ya}else{Ba=ya;break}}}else{Ba=O}if((c[la>>2]|0)>0){Ca=0;Da=Ba}else{break}do{K=v+4+(Ca<<2)|0;a[Da]=c[v+3076+(c[n+1556+(c[K>>2]<<4)>>2]<<2)>>2];za=(c[r>>2]|0)+1|0;c[r>>2]=za;a[za]=c[v+3076+(c[n+1556+(c[K>>2]<<4)+4>>2]<<2)>>2];za=(c[r>>2]|0)+1|0;c[r>>2]=za;a[za]=c[v+3076+(c[n+1556+(c[K>>2]<<4)+8>>2]<<2)>>2];za=(c[r>>2]|0)+1|0;c[r>>2]=za;a[za]=c[v+3076+(c[n+1556+(c[K>>2]<<4)+12>>2]<<2)>>2];Da=(c[r>>2]|0)+1|0;c[r>>2]=Da;Ca=Ca+1|0;}while((Ca|0)<(c[la>>2]|0))}}while(0);la=ba(c[q>>2]|0,c[f>>2]|0)|0;f=(la|0)/64|0;q=j|0;c[q>>2]=0;Ca=j+4|0;c[Ca>>2]=0;Da=j+8|0;Ba=j+72|0;c[Ba>>2]=Da;ka=j+76|0;c[ka>>2]=r;if((c[v+70696>>2]&1|0)!=0){c[w>>2]=(c[w>>2]|0)+8}j=c[r>>2]|0;x=4113;a[j]=x;x=x>>8;a[j+1|0]=x;j=(c[r>>2]|0)+2|0;c[r>>2]=j;Aa=j;x=(c[w>>2]|0)/8|0;a[Aa]=x;x=x>>8;a[Aa+1|0]=x;x=x>>8;a[Aa+2|0]=x;x=x>>8;a[Aa+3|0]=x;Aa=(c[r>>2]|0)+4|0;c[r>>2]=Aa;a[Aa]=0;Aa=(c[r>>2]|0)+1|0;c[r>>2]=Aa;a[Aa]=0;c[r>>2]=(c[r>>2]|0)+1;Aa=Da;if((la|0)>63){la=0;do{w=c[y>>2]|0;j=c[w+(la*248|0)+240>>2]|0;O=c[w+(la*248|0)+244>>2]|0;K=c[w+(la*248|0)+16>>2]|0;do{if((K|0)==3){za=c[Ca>>2]|0;ya=3<<14-za|c[q>>2];c[q>>2]=ya;xa=za+2|0;c[Ca>>2]=xa;if((xa|0)==16){xa=c[ka>>2]|0;za=c[xa>>2]|0;x=ya&65535;a[za]=x;x=x>>8;a[za+1|0]=x;c[xa>>2]=(c[xa>>2]|0)+2;xa=c[ka>>2]|0;za=(c[Ba>>2]|0)-Aa|0;UGb(c[xa>>2]|0,Da|0,za)|0;c[xa>>2]=(c[xa>>2]|0)+za;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da;Ea=0}else{Ea=0}do{za=(Ea<<2&4)+j|0;xa=(Ea<<1&4)+O|0;ya=w+(la*248|0)+20+(Ea*52|0)+20|0;l=c[ya>>2]|0;if((l|0)==3){wa=c[w+(la*248|0)+20+(Ea*52|0)+24>>2]|0;a[c[Ba>>2]|0]=c[v+3076+(wa<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;mnb(n,za,xa,n+20+(wa*6|0)|0);wa=c[w+(la*248|0)+20+(Ea*52|0)+28>>2]|0;a[c[Ba>>2]|0]=c[v+3076+(wa<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;va=za+2|0;mnb(n,va,xa,n+20+(wa*6|0)|0);wa=c[w+(la*248|0)+20+(Ea*52|0)+32>>2]|0;a[c[Ba>>2]|0]=c[v+3076+(wa<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;W=xa+2|0;mnb(n,za,W,n+20+(wa*6|0)|0);wa=c[w+(la*248|0)+20+(Ea*52|0)+36>>2]|0;a[c[Ba>>2]|0]=c[v+3076+(wa<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;mnb(n,va,W,n+20+(wa*6|0)|0)}else if((l|0)==1){wa=w+(la*248|0)+20+(Ea*52|0)+40|0;W=w+(la*248|0)+20+(Ea*52|0)+44|0;a[c[Ba>>2]|0]=8-(c[W>>2]|0)&15|8-(c[wa>>2]|0)<<4;c[Ba>>2]=(c[Ba>>2]|0)+1;onb(n,za,xa,c[wa>>2]|0,c[W>>2]|0)}else if((l|0)==2){l=w+(la*248|0)+20+(Ea*52|0)+48|0;a[c[Ba>>2]|0]=c[v+1028+(c[l>>2]<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;W=c[l>>2]|0;mnb(n,za,xa,n+20+((c[n+1556+(W<<4)>>2]|0)*6|0)|0);l=za+2|0;mnb(n,l,xa,n+20+((c[n+1556+(W<<4)+4>>2]|0)*6|0)|0);wa=xa+2|0;mnb(n,za,wa,n+20+((c[n+1556+(W<<4)+8>>2]|0)*6|0)|0);mnb(n,l,wa,n+20+((c[n+1556+(W<<4)+12>>2]|0)*6|0)|0)}W=c[Ca>>2]|0;wa=(c[ya>>2]&3)<<14-W|c[q>>2];c[q>>2]=wa;ya=W+2|0;c[Ca>>2]=ya;if((ya|0)==16){ya=c[ka>>2]|0;W=c[ya>>2]|0;x=wa&65535;a[W]=x;x=x>>8;a[W+1|0]=x;c[ya>>2]=(c[ya>>2]|0)+2;ya=c[ka>>2]|0;W=(c[Ba>>2]|0)-Aa|0;UGb(c[ya>>2]|0,Da|0,W)|0;c[ya>>2]=(c[ya>>2]|0)+W;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da}Ea=Ea+1|0;}while((Ea|0)<4)}else if((K|0)==2){W=w+(la*248|0)+236|0;a[c[Ba>>2]|0]=c[v+1028+(c[W>>2]<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;ya=c[Ca>>2]|0;wa=2<<14-ya|c[q>>2];c[q>>2]=wa;l=ya+2|0;c[Ca>>2]=l;if((l|0)==16){l=c[ka>>2]|0;ya=c[l>>2]|0;x=wa&65535;a[ya]=x;x=x>>8;a[ya+1|0]=x;c[l>>2]=(c[l>>2]|0)+2;l=c[ka>>2]|0;ya=(c[Ba>>2]|0)-Aa|0;UGb(c[l>>2]|0,Da|0,ya)|0;c[l>>2]=(c[l>>2]|0)+ya;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da}ya=c[W>>2]|0;nnb(n,j,O,n+20+((c[n+1556+(ya<<4)>>2]|0)*6|0)|0);W=j+4|0;nnb(n,W,O,n+20+((c[n+1556+(ya<<4)+4>>2]|0)*6|0)|0);l=O+4|0;nnb(n,j,l,n+20+((c[n+1556+(ya<<4)+8>>2]|0)*6|0)|0);nnb(n,W,l,n+20+((c[n+1556+(ya<<4)+12>>2]|0)*6|0)|0)}else if((K|0)==1){ya=w+(la*248|0)+228|0;l=w+(la*248|0)+232|0;a[c[Ba>>2]|0]=8-(c[l>>2]|0)&15|8-(c[ya>>2]|0)<<4;c[Ba>>2]=(c[Ba>>2]|0)+1;W=c[Ca>>2]|0;wa=1<<14-W|c[q>>2];c[q>>2]=wa;za=W+2|0;c[Ca>>2]=za;if((za|0)==16){za=c[ka>>2]|0;W=c[za>>2]|0;x=wa&65535;a[W]=x;x=x>>8;a[W+1|0]=x;c[za>>2]=(c[za>>2]|0)+2;za=c[ka>>2]|0;W=(c[Ba>>2]|0)-Aa|0;UGb(c[za>>2]|0,Da|0,W)|0;c[za>>2]=(c[za>>2]|0)+W;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da}qnb(n,j,O,c[ya>>2]|0,c[l>>2]|0)}else if((K|0)==0){l=c[q>>2]|0;ya=(c[Ca>>2]|0)+2|0;c[Ca>>2]=ya;if((ya|0)!=16){break}ya=c[ka>>2]|0;W=c[ya>>2]|0;x=l&65535;a[W]=x;x=x>>8;a[W+1|0]=x;c[ya>>2]=(c[ya>>2]|0)+2;ya=c[ka>>2]|0;W=(c[Ba>>2]|0)-Aa|0;UGb(c[ya>>2]|0,Da|0,W)|0;c[ya>>2]=(c[ya>>2]|0)+W;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da}}while(0);la=la+1|0;}while((la|0)<(f|0))}f=c[Ca>>2]|0;la=c[q>>2]&65535;b:while(1){n=f;do{if((n|0)==0){break b}n=n+2|0;c[Ca>>2]=n;}while((n|0)!=16);n=c[ka>>2]|0;v=c[n>>2]|0;x=la;a[v]=x;x=x>>8;a[v+1|0]=x;c[n>>2]=(c[n>>2]|0)+2;n=c[ka>>2]|0;v=(c[Ba>>2]|0)-Aa|0;UGb(c[n>>2]|0,Da|0,v)|0;c[n>>2]=(c[n>>2]|0)+v;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da;f=0;la=0}c[(c[o>>2]|0)+804>>2]=c[L>>2];o=c[M>>2]|0;c[M>>2]=c[L>>2];c[L>>2]=o;o=m+5944|0;L=c[o>>2]|0;M=m+5948|0;c[o>>2]=c[M>>2];c[M>>2]=L;L=c[J>>2]|0;M=m+5956|0;c[J>>2]=c[M>>2];c[M>>2]=L;ZDb(c[y>>2]|0);ZDb(c[G>>2]|0);c[u>>2]=(c[u>>2]|0)+1;c[e+28>>2]=(c[r>>2]|0)-(c[s>>2]|0);if((c[u>>2]|0)==1){u=e+36|0;c[u>>2]=c[u>>2]|1}c[g>>2]=1;t=0;i=h;return t|0}function RUa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+12|0);JCb(b+8|0);ZDb(c[b+5972>>2]|0);ZDb(c[b+5944>>2]|0);ZDb(c[b+5948>>2]|0);ZDb(c[b+5952>>2]|0);ZDb(c[b+5956>>2]|0);return 0}function SUa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;d=i;i=i+8|0;e=d|0;f=a+5664|0;g=c[f>>2]|0;h=a+5668|0;j=c[h>>2]|0;k=(ba(j,(g|0)/(b|0)|0)|0)/(b|0)|0;l=(b|0)==4;if(l){m=a+5944|0;n=a+5948|0}else{m=a+5952|0;n=a+5956|0}o=c[m>>2]|0;m=c[n>>2]|0;if((j|0)<=0){i=d;return}n=a+5952|0;p=a+5964|0;q=a+8|0;a=e;r=e+4|0;s=e;t=0;u=g;g=j;while(1){if((u|0)>0){j=(t|0)/8|0;v=(t|0)/(b|0)|0;w=v+1|0;x=(t|0)==0;y=0;z=u;do{A=z-b|0;do{if(y>>>0>A>>>0){B=2147483647}else{if(t>>>0>((c[h>>2]|0)-b|0)>>>0){B=2147483647;break}C=c[p>>2]|0;D=c[q>>2]|0;B=TUa(C|0,D|0,y,t,y,t,C+32|0,D+32|0,b)|0}}while(0);do{if(l){D=(ba((z|0)/8|0,j)|0)+((y|0)/8|0)|0;C=c[n>>2]|0;E=c[C+(D<<3)>>2]|0;F=c[C+(D<<3)+4>>2]|0;if((E+7|0)>>>0>14>>>0){G=0;H=0;I=B;break}if((F+7|0)>>>0>14>>>0){G=0;H=0;I=B;break}D=E+y|0;C=F+t|0;if(D>>>0>(z-4|0)>>>0){G=0;H=0;I=B;break}if(C>>>0>((c[h>>2]|0)-4|0)>>>0){G=0;H=0;I=B;break}J=c[p>>2]|0;K=c[q>>2]|0;L=TUa(J|0,K|0,y,t,D,C,J+32|0,K+32|0,4)|0;K=(L|0)<(B|0);G=K?E:0;H=K?F:0;I=K?L:B}else{G=0;H=0;I=B}}while(0);L=(ba(z,v)|0)/(b|0)|0;K=(y|0)/(b|0)|0;F=K+L|0;do{if((F|0)<(k|0)&(F|0)>-1){E=c[m+(F<<3)>>2]|0;J=c[m+(F<<3)+4>>2]|0;if((E+7|0)>>>0>14>>>0){M=G;N=H;O=I;break}if((J+7|0)>>>0>14>>>0){M=G;N=H;O=I;break}C=E+y|0;D=J+t|0;if(C>>>0>A>>>0){M=G;N=H;O=I;break}if(D>>>0>((c[h>>2]|0)-b|0)>>>0){M=G;N=H;O=I;break}P=c[p>>2]|0;Q=c[q>>2]|0;R=TUa(P|0,Q|0,y,t,C,D,P+32|0,Q+32|0,b)|0;Q=(R|0)<(I|0);M=Q?E:G;N=Q?J:H;O=Q?R:I}else{M=G;N=H;O=I}}while(0);R=F+1|0;do{if((R|0)<(k|0)&(R|0)>-1){Q=c[m+(R<<3)>>2]|0;J=c[m+(R<<3)+4>>2]|0;if((Q+7|0)>>>0>14>>>0){S=M;T=N;U=O;break}if((J+7|0)>>>0>14>>>0){S=M;T=N;U=O;break}E=Q+y|0;P=J+t|0;if(E>>>0>A>>>0){S=M;T=N;U=O;break}if(P>>>0>((c[h>>2]|0)-b|0)>>>0){S=M;T=N;U=O;break}D=c[p>>2]|0;C=c[q>>2]|0;V=TUa(D|0,C|0,y,t,E,P,D+32|0,C+32|0,b)|0;C=(V|0)<(O|0);S=C?Q:M;T=C?J:N;U=C?V:O}else{S=M;T=N;U=O}}while(0);R=((ba(z,w)|0)/(b|0)|0)+K|0;do{if((R|0)<(k|0)&(R|0)>-1){V=c[m+(R<<3)>>2]|0;C=c[m+(R<<3)+4>>2]|0;if((V+7|0)>>>0>14>>>0){W=S;X=T;Y=U;break}if((C+7|0)>>>0>14>>>0){W=S;X=T;Y=U;break}J=V+y|0;Q=C+t|0;if(J>>>0>A>>>0){W=S;X=T;Y=U;break}if(Q>>>0>((c[h>>2]|0)-b|0)>>>0){W=S;X=T;Y=U;break}D=c[p>>2]|0;P=c[q>>2]|0;E=TUa(D|0,P|0,y,t,J,Q,D+32|0,P+32|0,b)|0;P=(E|0)<(U|0);W=P?V:S;X=P?C:T;Y=P?E:U}else{W=S;X=T;Y=U}}while(0);R=K-1+L|0;E=R-((z|0)/(b|0)|0)|0;P=E+1|0;C=E+2|0;do{if(x){if((y|0)==0){Z=W;_=X;$=Y;break}E=c[o+(R<<3)>>2]|0;V=c[o+(R<<3)+4>>2]|0;if((E+7|0)>>>0>14>>>0){Z=W;_=X;$=Y;break}if((V+7|0)>>>0>14>>>0){Z=W;_=X;$=Y;break}D=E+y|0;if(D>>>0>A>>>0){Z=W;_=X;$=Y;break}if(V>>>0>((c[h>>2]|0)-b|0)>>>0){Z=W;_=X;$=Y;break}Q=c[p>>2]|0;J=c[q>>2]|0;aa=TUa(Q|0,J|0,y,0,D,V,Q+32|0,J+32|0,b)|0;J=(aa|0)<(Y|0);Z=J?E:W;_=J?V:X;$=J?aa:Y}else{aa=c[o+(R<<3)>>2]|0;J=c[o+(P<<3)>>2]|0;V=c[o+(C<<3)>>2]|0;do{if((aa|0)>(J|0)){if((V|0)<=(J|0)){ca=J;break}ca=(V|0)>(aa|0)?aa:V}else{if((J|0)<=(V|0)){ca=J;break}ca=(V|0)>(aa|0)?V:aa}}while(0);c[e>>2]=ca;E=c[o+(R<<3)+4>>2]|0;Q=c[o+(P<<3)+4>>2]|0;D=c[o+(C<<3)+4>>2]|0;do{if((E|0)>(Q|0)){if((D|0)<=(Q|0)){da=Q;break}da=(D|0)>(E|0)?E:D}else{if((Q|0)<=(D|0)){da=Q;break}da=(D|0)>(E|0)?D:E}}while(0);c[s+4>>2]=da;do{if((ca+7|0)>>>0>14>>>0){ea=W;fa=X;ga=Y}else{if((da+7|0)>>>0>14>>>0){ea=W;fa=X;ga=Y;break}ha=ca+y|0;ia=da+t|0;if(ha>>>0>A>>>0){ea=W;fa=X;ga=Y;break}if(ia>>>0>((c[h>>2]|0)-b|0)>>>0){ea=W;fa=X;ga=Y;break}ja=c[p>>2]|0;ka=c[q>>2]|0;la=TUa(ja|0,ka|0,y,t,ha,ia,ja+32|0,ka+32|0,b)|0;ka=(la|0)<(Y|0);ea=ka?ca:W;fa=ka?da:X;ga=ka?la:Y}}while(0);do{if((aa+7|0)>>>0>14>>>0){ma=ea;na=fa;oa=ga}else{if((E+7|0)>>>0>14>>>0){ma=ea;na=fa;oa=ga;break}la=aa+y|0;ka=E+t|0;if(la>>>0>A>>>0){ma=ea;na=fa;oa=ga;break}if(ka>>>0>((c[h>>2]|0)-b|0)>>>0){ma=ea;na=fa;oa=ga;break}ja=c[p>>2]|0;ia=c[q>>2]|0;ha=TUa(ja|0,ia|0,y,t,la,ka,ja+32|0,ia+32|0,b)|0;ia=(ha|0)<(ga|0);ma=ia?aa:ea;na=ia?E:fa;oa=ia?ha:ga}}while(0);do{if((J+7|0)>>>0>14>>>0){pa=ma;qa=na;ra=oa}else{if((Q+7|0)>>>0>14>>>0){pa=ma;qa=na;ra=oa;break}E=J+y|0;aa=Q+t|0;if(E>>>0>A>>>0){pa=ma;qa=na;ra=oa;break}if(aa>>>0>((c[h>>2]|0)-b|0)>>>0){pa=ma;qa=na;ra=oa;break}ha=c[p>>2]|0;ia=c[q>>2]|0;ja=TUa(ha|0,ia|0,y,t,E,aa,ha+32|0,ia+32|0,b)|0;ia=(ja|0)<(oa|0);pa=ia?J:ma;qa=ia?Q:na;ra=ia?ja:oa}}while(0);if((V+7|0)>>>0>14>>>0){Z=pa;_=qa;$=ra;break}if((D+7|0)>>>0>14>>>0){Z=pa;_=qa;$=ra;break}Q=V+y|0;J=D+t|0;if(Q>>>0>A>>>0){Z=pa;_=qa;$=ra;break}if(J>>>0>((c[h>>2]|0)-b|0)>>>0){Z=pa;_=qa;$=ra;break}ja=c[p>>2]|0;ia=c[q>>2]|0;ha=TUa(ja|0,ia|0,y,t,Q,J,ja+32|0,ia+32|0,b)|0;ia=(ha|0)<(ra|0);Z=ia?V:pa;_=ia?D:qa;$=ia?ha:ra}}while(0);c[a>>2]=Z;c[r>>2]=_;if(($|0)==-1){sa=_;ta=Z}else{C=_;P=$;R=Z;while(1){L=c[e>>2]|0;K=c[e+4>>2]|0;ha=P;ia=C;ja=R;J=0;while(1){Q=L+(c[676512+(J<<3)>>2]|0)|0;aa=K+(c[676516+(J<<3)>>2]|0)|0;do{if((Q+7|0)>>>0>14>>>0){ua=ja;va=ia;wa=ha}else{if((aa+7|0)>>>0>14>>>0){ua=ja;va=ia;wa=ha;break}E=Q+y|0;ka=aa+t|0;if(E>>>0>A>>>0){ua=ja;va=ia;wa=ha;break}if(ka>>>0>((c[h>>2]|0)-b|0)>>>0){ua=ja;va=ia;wa=ha;break}la=c[p>>2]|0;xa=c[q>>2]|0;ya=TUa(la|0,xa|0,y,t,E,ka,la+32|0,xa+32|0,b)|0;xa=(ya|0)<(ha|0);ua=xa?Q:ja;va=xa?aa:ia;wa=xa?ya:ha}}while(0);aa=J+1|0;if((aa|0)<8){ha=wa;ia=va;ja=ua;J=aa}else{break}}c[a>>2]=ua;c[r>>2]=va;if((P|0)==(wa|0)){sa=va;ta=ua;break}else{C=va;P=wa;R=ua}}}c[o+(F<<3)>>2]=ta;c[o+(F<<3)+4>>2]=sa;y=y+b|0;z=c[f>>2]|0;}while((y|0)<(z|0));za=z;Aa=c[h>>2]|0}else{za=u;Aa=g}y=t+b|0;if((y|0)<(Aa|0)){t=y;u=za;g=Aa}else{break}}i=d;return}function TUa(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;l=(k|0)>0;m=(k|0)==0;if(!l){n=0;return n|0}o=c[a>>2]|0;p=c[i>>2]|0;q=c[b>>2]|0;r=c[j>>2]|0;s=0;t=0;do{if(m){u=0}else{v=o+((ba(p,t+f|0)|0)+e)|0;w=q+((ba(r,t+h|0)|0)+g)|0;x=k;y=0;while(1){z=x-1|0;A=(d[w]|0)-(d[v]|0)|0;B=(ba(A,A)|0)+y|0;if((z|0)==0){break}else{v=v+1|0;w=w+1|0;x=z;y=B}}u=B<<2}s=u+s|0;t=t+1|0;}while((t|0)<(k|0));if(!l){n=s;return n|0}t=c[a+4>>2]|0;u=c[i+4>>2]|0;B=c[b+4>>2]|0;r=c[j+4>>2]|0;q=s;s=0;do{if(m){C=0}else{p=t+((ba(u,s+f|0)|0)+e)|0;o=B+((ba(r,s+h|0)|0)+g)|0;y=k;x=0;while(1){w=y-1|0;v=(d[o]|0)-(d[p]|0)|0;z=(ba(v,v)|0)+x|0;if((w|0)==0){C=z;break}else{p=p+1|0;o=o+1|0;y=w;x=z}}}q=C+q|0;s=s+1|0;}while((s|0)<(k|0));if(!l){n=q;return n|0}l=c[a+8>>2]|0;a=c[i+8>>2]|0;i=c[b+8>>2]|0;b=c[j+8>>2]|0;j=q;q=0;while(1){if(m){D=0}else{s=l+((ba(a,q+f|0)|0)+e)|0;C=i+((ba(b,q+h|0)|0)+g)|0;r=k;B=0;while(1){u=r-1|0;t=(d[C]|0)-(d[s]|0)|0;x=(ba(t,t)|0)+B|0;if((u|0)==0){D=x;break}else{s=s+1|0;C=C+1|0;r=u;B=x}}}B=D+j|0;r=q+1|0;if((r|0)<(k|0)){j=B;q=r}else{n=B;break}}return n|0}function UUa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;j=i;i=i+48|0;k=j|0;l=g+5960|0;if((c[l>>2]|0)==0){c[b+4>>2]=2147483647}else{m=g+5664|0;n=(e|0)/4|0;o=n+((ba(c[m>>2]|0,f)|0)/16|0)|0;p=g+5944|0;q=(c[p>>2]|0)+(o<<3)|0;o=b+40|0;r=c[q+4>>2]|0;c[o>>2]=c[q>>2];c[o+4>>2]=r;r=c[m>>2]|0;m=((ba(r,f)|0)/16|0)+n|0;n=c[p>>2]|0;p=c[n+(m<<3)>>2]|0;o=c[n+(m<<3)+4>>2]|0;do{if((p+7|0)>>>0>14>>>0){s=2147483647}else{if((o+7|0)>>>0>14>>>0){s=2147483647;break}m=p+e|0;n=o+f|0;if(m>>>0>(r-4|0)>>>0){s=2147483647;break}if(n>>>0>((c[g+5668>>2]|0)-4|0)>>>0){s=2147483647;break}q=c[g+5964>>2]|0;t=c[g+8>>2]|0;s=TUa(q|0,t|0,e,f,m,n,q+32|0,t+32|0,4)|0}}while(0);c[b+4>>2]=s}if((c[l>>2]|0)>>>0>1>>>0){l=c[g+5964>>2]|0;s=c[g+12>>2]|0;c[b>>2]=TUa(l|0,s|0,e,f,e,f,l+32|0,s+32|0,4)|0;u=l}else{c[b>>2]=2147483647;u=c[g+5964>>2]|0}l=ba(c[g+5664>>2]|0,f)|0;s=k|0;r=u+32|0;o=c[r>>2]|0;p=(ba(o,f)|0)+e|0;t=c[u>>2]|0;a[s]=a[t+p|0]|0;a[k+1|0]=a[t+(p+1)|0]|0;a[k+2|0]=a[t+(p+2)|0]|0;a[k+3|0]=a[t+(p+3)|0]|0;p=f+1|0;q=(ba(p,o)|0)+e|0;a[k+4|0]=a[t+q|0]|0;a[k+5|0]=a[t+(q+1)|0]|0;a[k+6|0]=a[t+(q+2)|0]|0;a[k+7|0]=a[t+(q+3)|0]|0;q=f+2|0;n=(ba(q,o)|0)+e|0;a[k+8|0]=a[t+n|0]|0;a[k+9|0]=a[t+(n+1)|0]|0;a[k+10|0]=a[t+(n+2)|0]|0;a[k+11|0]=a[t+(n+3)|0]|0;n=f+3|0;m=(ba(n,o)|0)+e|0;a[k+12|0]=a[t+m|0]|0;a[k+13|0]=a[t+(m+1)|0]|0;a[k+14|0]=a[t+(m+2)|0]|0;a[k+15|0]=a[t+(m+3)|0]|0;m=((e|0)/4|0)+((l|0)/16|0)|0;l=k+16|0;o=u+36|0;v=c[o>>2]|0;w=(ba(v,f)|0)+e|0;x=c[u+4>>2]|0;a[l]=a[x+w|0]|0;a[k+17|0]=a[x+(w+1)|0]|0;a[k+18|0]=a[x+(w+2)|0]|0;a[k+19|0]=a[x+(w+3)|0]|0;w=(ba(p,v)|0)+e|0;a[k+20|0]=a[x+w|0]|0;a[k+21|0]=a[x+(w+1)|0]|0;a[k+22|0]=a[x+(w+2)|0]|0;a[k+23|0]=a[x+(w+3)|0]|0;w=(ba(q,v)|0)+e|0;a[k+24|0]=a[x+w|0]|0;a[k+25|0]=a[x+(w+1)|0]|0;a[k+26|0]=a[x+(w+2)|0]|0;a[k+27|0]=a[x+(w+3)|0]|0;w=(ba(n,v)|0)+e|0;a[k+28|0]=a[x+w|0]|0;a[k+29|0]=a[x+(w+1)|0]|0;a[k+30|0]=a[x+(w+2)|0]|0;a[k+31|0]=a[x+(w+3)|0]|0;w=k+32|0;v=u+40|0;y=c[v>>2]|0;z=(ba(y,f)|0)+e|0;A=c[u+8>>2]|0;a[w]=a[A+z|0]|0;a[k+33|0]=a[A+(z+1)|0]|0;a[k+34|0]=a[A+(z+2)|0]|0;a[k+35|0]=a[A+(z+3)|0]|0;z=(ba(p,y)|0)+e|0;a[k+36|0]=a[A+z|0]|0;a[k+37|0]=a[A+(z+1)|0]|0;a[k+38|0]=a[A+(z+2)|0]|0;a[k+39|0]=a[A+(z+3)|0]|0;z=(ba(q,y)|0)+e|0;a[k+40|0]=a[A+z|0]|0;a[k+41|0]=a[A+(z+1)|0]|0;a[k+42|0]=a[A+(z+2)|0]|0;a[k+43|0]=a[A+(z+3)|0]|0;z=(ba(n,y)|0)+e|0;a[k+44|0]=a[A+z|0]|0;a[k+45|0]=a[A+(z+1)|0]|0;a[k+46|0]=a[A+(z+2)|0]|0;a[k+47|0]=a[A+(z+3)|0]|0;z=c[h+4112>>2]|0;k=b+48|0;if((z|0)>0){y=2147483647;n=0;q=0;while(1){p=q*48|0;u=s;B=h+9240+p|0;C=15;D=0;while(1){E=(d[B]|0)-(d[u]|0)|0;G=(ba(E,E)|0)+D|0;if((C|0)==0){break}u=u+1|0;B=B+1|0;C=C-1|0;D=G}D=l;C=p+16+(h+9240)|0;B=16;u=0;while(1){E=B-1|0;H=(d[C]|0)-(d[D]|0)|0;I=(ba(H,H)|0)+u|0;if((E|0)==0){break}else{D=D+1|0;C=C+1|0;B=E;u=I}}u=w;B=p+32+(h+9240)|0;C=16;D=0;while(1){E=C-1|0;H=(d[B]|0)-(d[u]|0)|0;J=(ba(H,H)|0)+D|0;if((E|0)==0){break}else{u=u+1|0;B=B+1|0;C=E;D=J}}D=I+(G<<2)+J|0;C=(D|0)<(y|0);B=C?D:y;D=C?q:n;C=q+1|0;if((C|0)<(z|0)){y=B;n=D;q=C}else{K=B;L=D;break}}}else{K=2147483647;L=0}c[k>>2]=L;L=b+8|0;c[L>>2]=K;K=b+12|0;c[K>>2]=0;k=m<<2;m=c[h+70680>>2]|0;q=0;do{n=c[m+(q+k<<2)>>2]|0;c[b+24+(q<<2)>>2]=n;y=(q<<1&2)+e|0;z=(q&2)+f|0;J=c[r>>2]|0;G=(ba(z,J)|0)+y|0;I=z+1|0;w=(ba(I,J)|0)+y|0;J=c[o>>2]|0;l=(ba(z,J)|0)+y|0;s=(ba(I,J)|0)+y|0;J=c[v>>2]|0;D=(ba(z,J)|0)+y|0;z=(ba(I,J)|0)+y|0;y=n*12|0;n=y|1;J=(d[t+G|0]|0)-(d[h+6168+y|0]|0)|0;I=ba(J,J)|0;J=(d[t+(G+1)|0]|0)-(d[h+6168+n|0]|0)|0;G=(ba(J,J)|0)+I|0;I=(d[t+w|0]|0)-(d[n+1+(h+6168)|0]|0)|0;n=(ba(I,I)|0)+G|0;G=(d[t+(w+1)|0]|0)-(d[(y|3)+(h+6168)|0]|0)|0;w=(ba(G,G)|0)+n|0;n=(d[x+l|0]|0)-(d[y+4+(h+6168)|0]|0)|0;G=(d[x+(l+1)|0]|0)-(d[y+5+(h+6168)|0]|0)|0;l=ba(G,G)|0;G=(d[x+s|0]|0)-(d[y+6+(h+6168)|0]|0)|0;I=ba(G,G)|0;G=(d[x+(s+1)|0]|0)-(d[y+7+(h+6168)|0]|0)|0;s=ba(G,G)|0;G=(d[A+D|0]|0)-(d[y+8+(h+6168)|0]|0)|0;J=ba(G,G)|0;G=(d[A+(D+1)|0]|0)-(d[y+9+(h+6168)|0]|0)|0;D=(ba(G,G)|0)+J|0;J=(d[A+z|0]|0)-(d[y+10+(h+6168)|0]|0)|0;G=(ba(J,J)|0)+D|0;D=(d[A+(z+1)|0]|0)-(d[y+11+(h+6168)|0]|0)|0;y=s+(I+(l+(ba(n,n)|0)))+(w<<2)+((ba(D,D)|0)+G)|0;M=y+(c[K>>2]|0)|0;c[K>>2]=M;q=q+1|0;}while((q|0)<4);q=g+5936|0;g=c[q>>2]|0;K=c[q+4>>2]|0;q=b+20|0;h=b+16|0;A=c[b>>2]|0;x=A;t=YGb(g<<1|0>>>31,K<<1|g>>>31,x<<7|0>>>25,((A|0)<0|0?-1:0)<<7|x>>>25)|0;x=F;A=0;if(x>>>0<A>>>0|x>>>0==A>>>0&t>>>0<2147483647>>>0){c[q>>2]=0;c[h>>2]=2;N=t}else{N=2147483647}t=c[b+4>>2]|0;b=t;A=gHb(g,K,10,0)|0;x=F;v=YGb(A,x,b<<7|0>>>25,((t|0)<0|0?-1:0)<<7|b>>>25)|0;b=F;t=(N|0)<0|0?-1:0;if(b>>>0<t>>>0|b>>>0==t>>>0&v>>>0<N>>>0){c[q>>2]=1;c[h>>2]=10;O=v}else{O=N}N=c[L>>2]|0;L=N;v=YGb(A,x,L<<7|0>>>25,((N|0)<0|0?-1:0)<<7|L>>>25)|0;L=F;N=(O|0)<0|0?-1:0;if(L>>>0<N>>>0|L>>>0==N>>>0&v>>>0<O>>>0){c[q>>2]=2;c[h>>2]=10;P=v}else{P=O}O=M;v=gHb(g,K,34,0)|0;K=YGb(v,F,O<<7|0>>>25,((M|0)<0|0?-1:0)<<7|O>>>25)|0;O=F;M=(P|0)<0|0?-1:0;if(!(O>>>0<M>>>0|O>>>0==M>>>0&K>>>0<P>>>0)){i=j;return}c[q>>2]=3;c[h>>2]=34;i=j;return}function VUa(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=(ba(h,h)|0)>>>2;k=j*6|0;l=WDb(ba(i<<2,k)|0)|0;m=l;n=(h|0)==4;if(n){o=WDb(ba(f<<2,k)|0)|0}else{o=c[d+70680>>2]|0}d=b+5672|0;D8(e,k,f,m,i,1,o,d);E8(e,k,f,m,i,1,o,d);if(n){ZDb(o)}if((i|0)<1|(j|0)==0){ZDb(l);return}o=j>>>0>1>>>0?j:1;n=o*6|0;d=0;f=m;m=g;while(1){g=m+(o*6|0)|0;k=0;e=f;b=m;while(1){a[b|0]=c[e>>2];a[b+1|0]=c[e+4>>2];a[b+2|0]=c[e+8>>2];a[b+3|0]=c[e+12>>2];a[b+4|0]=c[e+16>>2];a[b+5|0]=c[e+20>>2];h=k+1|0;if((h|0)<(j|0)){k=h;e=e+24|0;b=b+6|0}else{break}}b=d+1|0;if((b|0)<(i|0)){d=b;f=f+(n<<2)|0;m=g}else{break}}ZDb(l);return}function WUa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=46;a=ICb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function XUa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;j=i;i=i+8|0;k=j|0;l=c[e+60>>2]|0;m=c[h+24>>2]|0;n=h+28|0;h=c[n>>2]|0;if(!((h|0)>-1)){yDb(0,0,1965608,(o=i,i=i+24|0,c[o>>2]=1937536,c[o+8>>2]=1913648,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}p=l+8|0;c[p>>2]=m;c[l+16>>2]=m;q=l+12|0;c[q>>2]=m+h;h=l+4|0;m=$$a(e,c[h>>2]|0)|0;if((m|0)<0){r=m;i=j;return r|0}m=l;l=c[m>>2]|0;e=c[l+120>>2]|0;s=c[h>>2]|0;t=(c[s+32>>2]|0)/2|0;u=c[s>>2]|0;s=c[p>>2]|0;v=c[q>>2]|0;do{if((v-s|0)<1){w=0;x=7}else{y=a[s]|0;if(y<<24>>24==-31){z=v;A=s;break}w=y&255;x=7}}while(0);if((x|0)==7){yDb(l,16,2182376,(o=i,i=i+8|0,c[o>>2]=w,o)|0);i=o;z=c[q>>2]|0;A=c[p>>2]|0}w=z;if((w-A|0)<4){B=0;C=A}else{l=A+4|0;c[p>>2]=l;s=A;B=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)&16777215;C=l}if((B|0)==(w-4-C|0)){D=C;E=z}else{yDb(c[m>>2]|0,24,2105456,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;D=c[p>>2]|0;E=c[q>>2]|0}q=c[m>>2]|0;a:do{if((E|0)!=(D|0)){m=t<<2;z=k|0;C=k+2|0;w=k+4|0;B=k+6|0;l=E;s=-4;A=ba(((c[q+120>>2]|0)+3|0)/4|0,((c[q+124>>2]|0)+3|0)/4|0)|0;v=0;y=0;F=D;b:while(1){if((l-F|0)<1){G=0;H=1;I=F;x=17}else{J=F+1|0;c[p>>2]=J;K=a[F]|0;L=K&255;M=(L&31)+1|0;if((L&128|0)==0){G=L;H=M;I=J;x=17}else{N=y;O=M;P=K;Q=J}}if((x|0)==17){x=0;if((l-I|0)<1){R=0;S=I}else{J=I+1|0;c[p>>2]=J;R=d[I]|0;S=J}if((l-S|0)<1){T=1}else{T=(a[S]|0)>-1}N=(R|G<<8)&65535;O=T?H:1;P=T?0:32;Q=S}J=(O|0)>(A|0)?A:O;U=P&255;c:do{switch(U&224|0){case 32:{V=N;W=Q;x=34;break};case 128:{K=v;M=J;L=A;X=s;while(1){if((M|0)==0){Y=N;Z=K;_=L;$=X;aa=Q;break c}ca=X+4|0;da=(ca|0)<(e|0);ea=L-1|0;if((ea|0)<0){x=25;break b}else{K=K+(da?0:m)|0;M=M-1|0;L=ea;X=da?ca:0}}break};case 0:{if((l-Q|0)>>>0<30>>>0){break a}X=s+4|0;L=(X|0)<(e|0);M=L?X:0;X=(L?0:m)+v|0;L=A-1|0;if((L|0)<0){x=43;break b}K=X+M|0;b[u+(K<<1)>>1]=N;ca=Q+2|0;c[p>>2]=ca;da=Q;b[u+(K+1<<1)>>1]=de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0;da=Q+4|0;c[p>>2]=da;ea=ca;b[u+(K+2<<1)>>1]=de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0;ea=Q+6|0;c[p>>2]=ea;ca=da;b[u+(K+3<<1)>>1]=de((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0;ca=K+t|0;K=Q+8|0;c[p>>2]=K;da=ea;b[u+(ca<<1)>>1]=de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0;da=Q+10|0;c[p>>2]=da;ea=K;b[u+(ca+1<<1)>>1]=de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0;ea=Q+12|0;c[p>>2]=ea;K=da;b[u+(ca+2<<1)>>1]=de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0;K=Q+14|0;c[p>>2]=K;da=ea;b[u+(ca+3<<1)>>1]=de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0;da=ca+t|0;ca=Q+16|0;c[p>>2]=ca;ea=K;b[u+(da<<1)>>1]=de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0;ea=Q+18|0;c[p>>2]=ea;K=ca;b[u+(da+1<<1)>>1]=de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0;K=Q+20|0;c[p>>2]=K;ca=ea;b[u+(da+2<<1)>>1]=de((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0;ca=Q+22|0;c[p>>2]=ca;ea=K;b[u+(da+3<<1)>>1]=de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0;ea=da+t|0;da=Q+24|0;c[p>>2]=da;K=ca;b[u+(ea<<1)>>1]=de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0;K=Q+26|0;c[p>>2]=K;ca=da;b[u+(ea+1<<1)>>1]=de((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0;ca=Q+28|0;c[p>>2]=ca;da=K;b[u+(ea+2<<1)>>1]=de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0;da=Q+30|0;c[p>>2]=da;K=ca;ca=de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0;b[u+(ea+3<<1)>>1]=ca;Y=ca;Z=X;_=L;$=M;aa=da;break};case 192:{if((l-Q|0)<2){V=0;W=Q;x=34;break c}da=Q+2|0;c[p>>2]=da;M=Q;V=de((d[M]|d[M+1|0]<<8)<<16>>16|0)|0;W=da;x=34;break};case 160:{if((l-Q|0)<2){fa=0;ga=Q}else{da=Q+2|0;c[p>>2]=da;M=Q;fa=de((d[M]|d[M+1|0]<<8)<<16>>16|0)|0;ga=da}if((J|0)==0){Y=fa;Z=v;_=A;$=s;aa=ga;break c}else{ha=s;ia=A;ja=v;ka=J}while(1){da=ka-1|0;M=ha+4|0;L=(M|0)<(e|0);X=L?M:0;M=(L?0:m)+ja|0;L=ia-1|0;if((L|0)<0){x=30;break b}ca=M+X|0;b[u+(ca<<1)>>1]=fa;b[u+(ca+1<<1)>>1]=fa;b[u+(ca+2<<1)>>1]=fa;b[u+(ca+3<<1)>>1]=fa;ea=ca+t|0;b[u+(ea<<1)>>1]=fa;b[u+(ea+1<<1)>>1]=fa;b[u+(ea+2<<1)>>1]=fa;b[u+(ea+3<<1)>>1]=fa;ca=ea+t|0;b[u+(ca<<1)>>1]=fa;b[u+(ca+1<<1)>>1]=fa;b[u+(ca+2<<1)>>1]=fa;b[u+(ca+3<<1)>>1]=fa;ea=ca+t|0;b[u+(ea<<1)>>1]=fa;b[u+(ea+1<<1)>>1]=fa;b[u+(ea+2<<1)>>1]=fa;b[u+(ea+3<<1)>>1]=fa;if((da|0)==0){Y=fa;Z=M;_=L;$=X;aa=ga;break}else{ha=X;ia=L;ja=M;ka=da}}break};default:{x=44;break b}}}while(0);do{if((x|0)==34){x=0;if((l-W|0)<2){la=0;ma=W}else{da=W+2|0;c[p>>2]=da;M=W;la=(de((d[M]|d[M+1|0]<<8)<<16>>16|0)|0)&65535;ma=da}b[z>>1]=la;b[B>>1]=V;da=(V&65535)>>>10&31;M=la>>>10&31;L=(V&65535)>>>5&31;X=la>>>5&31;ea=V&31;ca=la&31;b[C>>1]=(X*21|0)+(L*11|0)&65504|((ca*21|0)+(ea*11|0)|0)>>>5|((M*21|0)+(da*11|0)|0)>>>5<<10;b[w>>1]=(X*11|0)+(L*21|0)&65504|((ca*11|0)+(ea*21|0)|0)>>>5|((M*11|0)+(da*21|0)|0)>>>5<<10;if((l-ma|0)>>>0<J<<2>>>0){break a}if((J|0)==0){Y=V;Z=v;_=A;$=s;aa=ma;break}else{na=s;oa=A;pa=v;qa=J;ra=ma}while(1){da=qa-1|0;M=na+4|0;ea=(M|0)<(e|0);ca=ea?M:0;M=(ea?0:m)+pa|0;ea=oa-1|0;if((ea|0)<0){x=39;break b}L=M+ca|0;X=ra+1|0;c[p>>2]=X;K=d[ra]|0;b[u+(L<<1)>>1]=b[k+(K>>>6<<1)>>1]|0;b[u+(L+1<<1)>>1]=b[k+((K>>>4&3)<<1)>>1]|0;b[u+(L+2<<1)>>1]=b[k+((K>>>2&3)<<1)>>1]|0;b[u+(L+3<<1)>>1]=b[k+((K&3)<<1)>>1]|0;K=L+t|0;L=ra+2|0;c[p>>2]=L;sa=d[X]|0;b[u+(K<<1)>>1]=b[k+(sa>>>6<<1)>>1]|0;b[u+(K+1<<1)>>1]=b[k+((sa>>>4&3)<<1)>>1]|0;b[u+(K+2<<1)>>1]=b[k+((sa>>>2&3)<<1)>>1]|0;b[u+(K+3<<1)>>1]=b[k+((sa&3)<<1)>>1]|0;sa=K+t|0;K=ra+3|0;c[p>>2]=K;X=d[L]|0;b[u+(sa<<1)>>1]=b[k+(X>>>6<<1)>>1]|0;b[u+(sa+1<<1)>>1]=b[k+((X>>>4&3)<<1)>>1]|0;b[u+(sa+2<<1)>>1]=b[k+((X>>>2&3)<<1)>>1]|0;b[u+(sa+3<<1)>>1]=b[k+((X&3)<<1)>>1]|0;X=sa+t|0;sa=ra+4|0;c[p>>2]=sa;L=d[K]|0;b[u+(X<<1)>>1]=b[k+(L>>>6<<1)>>1]|0;b[u+(X+1<<1)>>1]=b[k+((L>>>4&3)<<1)>>1]|0;b[u+(X+2<<1)>>1]=b[k+((L>>>2&3)<<1)>>1]|0;b[u+(X+3<<1)>>1]=b[k+((L&3)<<1)>>1]|0;if((da|0)==0){Y=V;Z=M;_=ea;$=ca;aa=sa;break}else{na=ca;oa=ea;pa=M;qa=da;ra=sa}}}}while(0);if((E|0)==(aa|0)){break a}else{s=$;A=_;v=Z;y=Y;F=aa}}if((x|0)==25){yDb(q,16,2048504,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((x|0)==30){yDb(q,16,2048504,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((x|0)==39){yDb(q,16,2048504,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((x|0)==43){yDb(q,16,2048504,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((x|0)==44){yDb(q,16,2003016,(o=i,i=i+16|0,c[o>>2]=U,c[o+8>>2]=l-Q,o)|0);i=o;break}}}while(0);o=MCb(f,c[h>>2]|0)|0;if((o|0)<0){r=o;i=j;return r|0}c[g>>2]=1;r=c[n>>2]|0;i=j;return r|0}function YUa(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function ZUa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;i=i+24|0;g=f|0;h=c[a>>2]|0;j=(h|0)/16|0;k=c[a+4>>2]|0;l=(k|0)/16|0;m=c[b>>2]|0;n=b+32|0;o=c[n>>2]|0;p=c[b+4>>2]|0;q=c[b+8>>2]|0;r=e>>>0>268435455>>>0?-8:e<<3;e=r>>>0>2147483639>>>0|(d|0)==0;s=e?0:d;d=e?0:r;c[g>>2]=s;c[g+12>>2]=d;c[g+16>>2]=d+8;c[g+4>>2]=s+(d>>3);d=g+8|0;c[d>>2]=0;if(e){t=e?-1094995529:0;i=f;return t|0}if((k|0)<=15){t=0;i=f;return t|0}k=(h|0)>15;h=b+36|0;e=b+40|0;b=a+592|0;s=a+12|0;r=a+76|0;u=a+8|0;v=a+332|0;a=q;q=p;p=m+(o<<3)|0;w=m;m=0;x=o;a:while(1){if(k){o=a;y=q;z=p;A=w;B=0;do{C=_Ua(g,b,s,r)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){Xe[c[(c[u>>2]|0)+1120>>2]&4095](A,c[n>>2]|0,b)}C=_Ua(g,b,s,r)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){Xe[c[(c[u>>2]|0)+1120>>2]&4095](A+8|0,c[n>>2]|0,b)}A=A+16|0;C=_Ua(g,b,s,r)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){Xe[c[(c[u>>2]|0)+1120>>2]&4095](z,c[n>>2]|0,b)}C=_Ua(g,b,s,r)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){Xe[c[(c[u>>2]|0)+1120>>2]&4095](z+8|0,c[n>>2]|0,b)}z=z+16|0;C=_Ua(g,b,s,v)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){Xe[c[(c[u>>2]|0)+1120>>2]&4095](y,c[h>>2]|0,b)}y=y+8|0;C=_Ua(g,b,s,v)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){Xe[c[(c[u>>2]|0)+1120>>2]&4095](o,c[e>>2]|0,b)}o=o+8|0;B=B+1|0;}while((B|0)<(j|0));E=o;F=y;G=z;H=A;I=c[n>>2]|0}else{E=a;F=q;G=p;H=w;I=x}B=I-j<<4;C=m+1|0;if((C|0)<(l|0)){a=E+((c[e>>2]|0)-j<<3)|0;q=F+((c[h>>2]|0)-j<<3)|0;p=G+B|0;w=H+B|0;m=C;x=I}else{D=26;break}}if((D|0)==26){t=(c[d>>2]|0)/8|0;i=f;return t|0}else if((D|0)==27){i=f;return t|0}return 0}function _Ua(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=a+8|0;i=c[h>>2]|0;j=a+16|0;k=c[j>>2]|0;l=a|0;m=c[l>>2]|0;n=m+(i>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(i&7)>>>24;n=i+8|0;i=k>>>0>n>>>0?n:k;c[h>>2]=i;if((o|0)==255){p=0;return p|0}n=m+(i>>>3)|0;m=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(i&7)>>>26;n=i+6|0;i=k>>>0>n>>>0?n:k;c[h>>2]=i;k=a+12|0;if(((c[k>>2]|0)-i|0)<(m<<1|0)){p=-1094995529;return p|0}TGb(e|0,0,128)|0;i=c[h>>2]|0;a:do{if((m|0)==0){q=0;r=i}else{a=c[j>>2]|0;n=c[l>>2]|0;s=m;t=i;while(1){u=n+(t>>>3)|0;v=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7)>>30;u=t+2|0;w=a>>>0>u>>>0?u:a;c[h>>2]=w;if((v|0)==-2){q=s;r=w;break a}u=s-1|0;x=d[f+s|0]|0;b[e+(x<<1)>>1]=ba(c[g+(x<<2)>>2]|0,v)|0;if((u|0)==0){q=0;r=w;break}else{s=u;t=w}}}}while(0);i=-r&3;if((i|0)==0){y=r}else{m=c[j>>2]|0;t=r+i|0;i=m>>>0>t>>>0?t:m;c[h>>2]=i;y=i}i=c[k>>2]|0;if((i-y|0)<(q<<2|0)){p=-1094995529;return p|0}b:do{if((q|0)==0){z=0;A=y}else{k=c[j>>2]|0;m=c[l>>2]|0;t=q;r=y;while(1){s=m+(r>>>3)|0;a=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>28;s=r+4|0;n=k>>>0>s>>>0?s:k;c[h>>2]=n;if((a|0)==-8){z=t;A=n;break b}s=t-1|0;w=d[f+t|0]|0;b[e+(w<<1)>>1]=ba(c[g+(w<<2)>>2]|0,a)|0;if((s|0)==0){z=0;A=n;break}else{t=s;r=n}}}}while(0);y=-A&7;if((y|0)==0){B=A}else{q=c[j>>2]|0;r=A+y|0;y=q>>>0>r>>>0?r:q;c[h>>2]=y;B=y}if((i-B|0)<(z<<3|0)){p=-1094995529;return p|0}if((z|0)!=0){i=c[j>>2]|0;j=c[l>>2]|0;l=z;z=B;while(1){B=j+(z>>>3)|0;y=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7);B=z+8|0;q=i>>>0>B>>>0?B:i;c[h>>2]=q;B=l-1|0;r=d[f+l|0]|0;b[e+(r<<1)>>1]=ba(y>>24,c[g+(r<<2)>>2]|0)|0;if((B|0)==0){break}else{l=B;z=q}}}z=d[f]|0;b[e+(z<<1)>>1]=ba(c[g+(z<<2)>>2]|0,o)|0;p=1;return p|0}function $Ua(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;j=b+8|0;c[j>>2]=e;k=0;l=e;while(1){e=d[1075976+k|0]|0;m=d[l+1128+k|0]|0;a[b+12+k|0]=a[(e<<3&56|e>>>3)+(l+1128)|0]|0;c[b+76+(m<<2)>>2]=c[h+(k<<2)>>2];c[b+332+(m<<2)>>2]=c[i+(k<<2)>>2];m=k+1|0;if((m|0)>=64){break}k=m;l=c[j>>2]|0}c[b>>2]=f;c[b+4>>2]=g;return}function aVa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;g=a+14120|0;do{if((e|0)<4){h=c[1078693]|0;j=a+14128|0;k=c[j>>2]|0;l=c[a+14136>>2]|0;m=c[g>>2]|0;n=m+(k>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7)>>>18;n=b[h+(o<<2)>>1]|0;p=b[h+(o<<2)+2>>1]|0;o=p<<16>>16;if(p<<16>>16<0){p=k+14|0;q=l>>>0>p>>>0?p:l;p=m+(q>>>3)|0;r=((fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(q&7)>>>((o+32|0)>>>0))+n|0;s=b[h+(r<<2)+2>>1]|0;t=b[h+(r<<2)>>1]|0;u=q}else{s=o;t=n;u=k}k=s+u|0;n=l>>>0>k>>>0?k:l;c[j>>2]=n;if((t|0)>=0){v=t-128|0;break}k=m+(n>>>3)|0;o=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(n&7)>>>25;k=n+7|0;n=l>>>0>k>>>0?k:l;c[j>>2]=n;if((o|0)==124){k=m+(n>>>3)|0;q=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(n&7)>>>25;k=n+7|0;c[j>>2]=l>>>0>k>>>0?k:l;v=(q<<24)+16777216>>24;break}else if((o|0)==125){q=m+(n>>>3)|0;k=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(n&7)>>>25;q=n+7|0;c[j>>2]=l>>>0>q>>>0?q:l;v=k|-128;break}else if((o|0)==126){k=d[m+(n>>>3)|0]|0;q=((n|0)<(l|0))+n|0;c[j>>2]=q;r=m+(q>>>3)|0;m=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)&-16777216;r=q+8|0;c[j>>2]=l>>>0>r>>>0?r:l;if((k&128>>>((n&7)>>>0)|0)==0){v=m+16777216>>24;break}else{v=m>>24;break}}else if((o|0)==127){m=n+11|0;c[j>>2]=l>>>0>m>>>0?m:l;v=1;break}else{v=o;break}}else{o=c[1078699]|0;l=a+14128|0;m=c[l>>2]|0;j=c[a+14136>>2]|0;n=c[g>>2]|0;k=n+(m>>>3)|0;r=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(m&7)>>>18;k=b[o+(r<<2)>>1]|0;q=b[o+(r<<2)+2>>1]|0;r=q<<16>>16;if(q<<16>>16<0){q=m+14|0;h=j>>>0>q>>>0?q:j;q=n+(h>>>3)|0;p=((fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(h&7)>>>((r+32|0)>>>0))+k|0;w=b[o+(p<<2)+2>>1]|0;x=b[o+(p<<2)>>1]|0;y=h}else{w=r;x=k;y=m}m=w+y|0;k=j>>>0>m>>>0?m:j;c[l>>2]=k;if((x|0)>=0){v=x-128|0;break}m=n+(k>>>3)|0;r=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(k&7)>>>23;m=k+9|0;k=j>>>0>m>>>0?m:j;c[l>>2]=k;if((r|0)==508){m=n+(k>>>3)|0;h=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(k&7)>>>25;m=k+7|0;c[l>>2]=j>>>0>m>>>0?m:j;v=(h<<24)+16777216>>24;break}else if((r|0)==510){h=k+9|0;c[l>>2]=j>>>0>h>>>0?h:j;v=1;break}else if((r|0)==509){r=n+(k>>>3)|0;n=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(k&7)>>>25;r=k+7|0;c[l>>2]=j>>>0>r>>>0?r:j;v=n|-128;break}else{yDb(c[a+4>>2]|0,16,2223416,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;z=65535;i=f;return z|0}}}while(0);z=-v|0;i=f;return z|0}function bVa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;f=c[b+60>>2]|0;g=f;if((c[b+100>>2]|0)<8){yDb(b,16,2138456,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1094995529;i=e;return j|0}k=b+128|0;l=b+132|0;m=b;n=hDb(c[k>>2]|0,c[l>>2]|0,0,m)|0;if((n|0)<0){j=n;i=e;return j|0}IOa(g);c[f+4>>2]=b;c[f+28>>2]=2;c[f+48>>2]=c[b+48>>2];n=c[k>>2]|0;c[f+8>>2]=n;c[f+14044>>2]=n;n=c[l>>2]|0;c[f+12>>2]=n;c[f+14048>>2]=n;n=c[b+96>>2]|0;c[f+10052>>2]=a[n+3|0]&1;l=n+4|0;k=fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;l=f+14672|0;c[l>>2]=k;o=k>>28;p=k>>>12&255;q=f+13944|0;c[q>>2]=1;do{if((o|0)==1){c[f+14028>>2]=(p|0)!=0?3:1;c[f+13788>>2]=(p|0)==2}else if((o|0)==2){if(!((k&266338304)>>>0>1048576>>>0)){break}c[q>>2]=0;c[b+176>>2]=1}else{yDb(m,16,2131872,(h=i,i=i+8|0,c[h>>2]=k,h)|0);i=h;DDb(m,2125512,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=e;return j|0}}while(0);if((c[b+688>>2]&1|0)!=0){k=c[n>>2]|0;yDb(m,48,2119848,(h=i,i=i+16|0,c[h>>2]=c[l>>2],c[h+8>>2]=k,h)|0);i=h}c[b+140>>2]=0;b=FOa(g)|0;if((b|0)<0){j=b;i=e;return j|0}Jca(f+11548|0);gIa();if(a[545416]|0){j=0;i=e;return j|0}c[1078693]=4479848;c[1078695]=16384;N_(4314768,14,256,484312,1,1,483800,2,2,0,0,0,4)|0;c[1078699]=4414296;c[1078701]=16388;N_(4314792,14,256,485080,1,1,484568,2,2,0,0,0,4)|0;a[545416]=1;j=0;i=e;return j|0}function cVa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0;j=i;i=i+40|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=c[h+24>>2]|0;q=h+28|0;h=c[q>>2]|0;r=e+60|0;s=c[r>>2]|0;t=s;u=f;c[s+60>>2]=c[e+88>>2];c[s+64>>2]=c[e+92>>2];if((h|0)==0){v=0;i=j;return v|0}f=e+212|0;w=c[f>>2]|0;do{if((w|0)==0){x=(d[p]|0)+1|0;y=h-1|0;z=x<<3;if((y|0)>(z|0)){A=y-z|0;B=p+(z|1)|0;C=x;D=p+5|0;E=7;break}yDb(e,16,2002984,(G=i,i=i+8|0,c[G>>2]=x,G)|0);i=G;v=-1094995529;i=j;return v|0}else{if((w|0)>0){A=h;B=p;C=w;D=0;E=7}}}while(0);a:do{if((E|0)==7){p=e+220|0;h=e;x=k;z=m;y=o;H=k;I=x+4|0;J=l|0;K=l+4|0;L=n|0;M=n+4|0;N=0;O=w;b:while(1){P=(O|0)==0;if(P){Q=D+(N<<3)|0}else{Q=(c[p>>2]|0)+(N<<2)|0}R=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;if(!(R>>>0<A>>>0)){v=-1094995529;E=166;break}S=N+1|0;if((S|0)==(C|0)){T=A}else{if(P){U=D+(S<<3)|0}else{U=(c[p>>2]|0)+(S<<2)|0}T=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0}V=T-R|0;W=N+2|0;if((W|0)<(C|0)){if(P){X=D+(W<<3)|0}else{X=(c[p>>2]|0)+(W<<2)|0}Y=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0}else{Y=A}W=Y-R|0;if((V|0)<1|(W|0)<1){v=-1094995529;E=166;break}P=(V|0)>(W|0)?V:W;if((P+R|0)>>>0>A>>>0){v=-1094995529;E=166;break}Z=B+R|0;_=c[r>>2]|0;R=_;$=V<<3;V=P<<3;P=V>>>0>2147483639>>>0|(Z|0)==0;aa=P?0:Z;Z=P?0:V;V=_+14120|0;c[V>>2]=aa;c[_+14132>>2]=Z;P=Z+8|0;ca=_+14136|0;c[ca>>2]=P;c[_+14124>>2]=aa+(Z>>3);Z=_+14128|0;c[Z>>2]=0;da=_+48|0;if((c[da>>2]|0)==6){ea=a[aa]|0;fa=(P|0)>0|0;c[Z>>2]=fa;ga=(d[aa]|0)<<fa;ha=((fa|0)<(P|0))+fa|0;c[Z>>2]=ha;fa=_+9992|0;c[fa>>2]=(ga>>>7&1)+1;if(ea<<24>>24>-1){yDb(c[_+4>>2]|0,16,2151088,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;ia=c[Z>>2]|0;ja=c[V>>2]|0;ka=c[ca>>2]|0}else{ia=ha;ja=aa;ka=P}ha=d[ja+(ia>>>3)|0]|0;ea=((ia|0)<(ka|0))+ia|0;c[Z>>2]=ea;if((ha&128>>>((ia&7)>>>0)|0)!=0){E=28;break}ha=ja+(ea>>>3)|0;ga=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ea&7)>>>27;ha=ea+5|0;ea=ka>>>0>ha>>>0?ha:ka;c[Z>>2]=ea;c[_+9960>>2]=ga;if((ga|0)==0){E=30;break}ga=c[fa>>2]|0;do{if((ga|0)==1){if((c[_+14028>>2]|0)!=3){la=ea;break}fa=ja+(ea>>>3)|0;ha=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ea&7)>>>24;fa=ea+8|0;ma=ka>>>0>fa>>>0?fa:ka;c[Z>>2]=ma;c[_+9860>>2]=ha;ha=ja+(ma>>>3)|0;fa=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ma&7)>>>24;ha=ma+8|0;ma=ka>>>0>ha>>>0?ha:ka;c[Z>>2]=ma;c[_+9864>>2]=fa;fa=ja+(ma>>>3)|0;ha=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ma&7)>>>24;fa=ma+8|0;ma=ka>>>0>fa>>>0?fa:ka;c[Z>>2]=ma;c[_+9868>>2]=ha;la=ma}else{la=ea}}while(0);ea=_+12476|0;ma=_+12480|0;ha=c[_+116>>2]|0;fa=(ba(ha,c[ma>>2]|0)|0)+(c[ea>>2]|0)|0;na=ja+(la>>>3)|0;oa=fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0;na=la&7;do{if((oa&-1048576>>>(na>>>0)|0)==0){E=37}else{if((fa|0)!=0){if((fa|0)<(c[_+144>>2]|0)){E=37;break}}c[ea>>2]=0;c[ma>>2]=0;pa=ba(c[_+120>>2]|0,ha)|0;qa=la}}while(0);if((E|0)==37){E=0;fa=la+6|0;ra=ka>>>0>fa>>>0?fa:ka;c[Z>>2]=ra;c[ea>>2]=oa<<na>>>26;fa=ja+(ra>>>3)|0;sa=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ra&7)>>>26;fa=ra+6|0;ra=ka>>>0>fa>>>0?fa:ka;c[Z>>2]=ra;c[ma>>2]=sa;sa=ja+(ra>>>3)|0;fa=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ra&7)>>>20;sa=ra+12|0;ra=ka>>>0>sa>>>0?sa:ka;c[Z>>2]=ra;pa=fa;qa=ra}ra=qa+3|0;c[Z>>2]=ka>>>0>ra>>>0?ra:ka;c[_+11556>>2]=1;c[_+10048>>2]=1;ta=pa;ua=ha;va=ga}else{ra=aa;fa=(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)>>>6&3;ra=P>>>0>2>>>0?2:P;c[Z>>2]=ra;if((fa|0)==2){c[_+9992>>2]=2;E=45}else if((fa|0)==0){c[_+9992>>2]=1;E=45}else if((fa|0)==1){c[_+9992>>2]=1;E=45}else if((fa|0)==3){c[_+9992>>2]=3;fa=_+13944|0;if((c[fa>>2]|0)!=0){E=47;break}if((c[_+9848>>2]|0)==0){E=49;break}else{wa=fa}}else{E=44;break}if((E|0)==45){E=0;wa=_+13944|0}fa=aa+(ra>>>3)|0;sa=d[fa]|0;xa=(ra|0)<(P|0)|ra;c[Z>>2]=xa;if((sa&128>>>((ra&2)>>>0)|0)!=0){E=51;break}ra=fa;fa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(xa&3)>>>27;ra=xa+5|0;xa=P>>>0>ra>>>0?ra:P;c[Z>>2]=xa;ra=_+9960|0;c[ra>>2]=fa;if((fa|0)==0){E=53;break}fa=_+14672|0;sa=c[fa>>2]&266338304;if(sa>>>0>1048576>>>0){ya=d[aa+(xa>>>3)|0]|0;za=((xa|0)<(P|0))+xa|0;c[Z>>2]=za;if((ya&128>>>((xa&7)>>>0)|0)==0){Aa=0}else{Aa=(c[(c[_+4>>2]|0)+800>>2]|0)==0|0}c[_+13836>>2]=Aa;Ba=za}else{Ba=xa}xa=aa+(Ba>>>3)|0;za=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ba&7);if(sa>>>0<2097152>>>0){sa=Ba+8|0;xa=P>>>0>sa>>>0?sa:P;c[Z>>2]=xa;Ca=za>>>24<<7;Da=xa}else{xa=Ba+13|0;sa=P>>>0>xa>>>0?xa:P;c[Z>>2]=sa;Ca=za>>>19<<2;Da=sa}Ea=_+4|0;Fa=c[Ea>>2]|0;sa=c[Fa+96>>2]|0;za=a[sa+1|0]&7;do{if((za|0)==0){Ga=Fa;Ha=_+8|0}else{xa=d[1191992+za|0]|0;ya=xa+1|0;Ia=aa+(Da>>>3)|0;Ja=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Da&7)>>>((31-xa|0)>>>0);xa=ya+Da|0;c[Z>>2]=P>>>0>xa>>>0?xa:P;if((Ja|0)==0){Ka=c[_+14048>>2]|0;La=c[_+14044>>2]|0}else{xa=Ja<<1;if((c[Fa+100>>2]|0)<(xa+8|0)){E=65;break b}Ka=(d[sa+(xa+7)|0]|0)<<2;La=(d[sa+(xa+6)|0]|0)<<2}xa=_+8|0;if((La|0)==(c[xa>>2]|0)){if((Ka|0)==(c[_+12>>2]|0)){Ma=Fa}else{E=70}}else{E=70}if((E|0)==70){E=0;Ia=Fa+224|0;Na=c[Ia>>2]|0;Oa=c[Ia+4>>2]|0;c[k>>2]=Na;c[k+4>>2]=Oa;yDb(Fa,48,2217944,(G=i,i=i+16|0,c[G>>2]=La,c[G+8>>2]=Ka,G)|0);i=G;if((hDb(La,Ka,0,c[Ea>>2]|0)|0)<0){Pa=Ea;break b}LOa(R);if((Na|0)==0){c[H>>2]=1;c[I>>2]=1}Na=_+12|0;Oa=c[Na>>2]|0;Ia=ba(La<<1,Oa)|0;Qa=c[xa>>2]|0;if((Ia|0)==(ba(Qa,Ka)|0)){Ia=(c[Ea>>2]|0)+224|0;c[J>>2]=2;c[K>>2]=1;jFb(z,x,l);Ra=Ia;Ia=c[m+4>>2]|0;c[Ra>>2]=c[m>>2];c[Ra+4>>2]=Ia;Sa=c[Na>>2]|0;Ta=c[xa>>2]|0}else{Sa=Oa;Ta=Qa}if((ba(Sa,La)|0)==(ba(Ka<<1,Ta)|0)){Qa=(c[Ea>>2]|0)+224|0;c[L>>2]=1;c[M>>2]=2;jFb(y,x,n);Oa=Qa;Qa=c[o+4>>2]|0;c[Oa>>2]=c[o>>2];c[Oa+4>>2]=Qa}Qa=V$a(c[Ea>>2]|0,La,Ka)|0;if((Qa|0)<0){Ua=Qa;E=103;break b}c[xa>>2]=La;c[Na>>2]=Ka;Na=FOa(R)|0;if((Na|0)<0){Ua=Na;E=103;break b}Ma=c[Ea>>2]|0}if((c[Ma+688>>2]&1|0)==0){Ga=Ma;Ha=xa;break}yDb(Ma,48,2208616,(G=i,i=i+24|0,c[G>>2]=Ja,c[G+8>>2]=ya,c[G+16>>2]=za,G)|0);i=G;Ga=c[Ea>>2]|0;Ha=xa}}while(0);if((hDb(c[Ha>>2]|0,c[_+12>>2]|0,0,Ga)|0)<0){Pa=Ea;break}za=hIa(R)|0;sa=_+13856|0;P=c[sa>>2]|0;aa=c[sa+4>>2]|0;ga=P&-32768|Ca;ha=ZGb(ga,(ga|0)<0|0?-1:0,P,aa)|0;ma=F;na=0;oa=(ma|0)>(na|0)|(ma|0)==(na|0)&ha>>>0>16384>>>0?ga-32768|0:ga;ga=ZGb(oa,(oa|0)<0|0?-1:0,P,aa)|0;ha=F;na=-1;ma=(ha|0)<(na|0)|(ha|0)==(na|0)&ga>>>0<-16384>>>0?oa+32768|0:oa;oa=ma;ga=(ma|0)<0|0?-1:0;na=_+9992|0;ha=c[na>>2]|0;ea=(ha|0)==3;do{if((oa|0)==(P|0)&(ga|0)==(aa|0)){if(!ea){Va=ha;break}Wa=b[_+13872>>1]|0;Xa=b[_+13874>>1]|0;E=89}else{c[sa>>2]=oa;c[sa+4>>2]=ga;if(ea){xa=b[_+13872>>1]|0;ya=_+13864|0;Ja=ZGb(oa,ga,c[ya>>2]|0,c[ya+4>>2]|0)|0;ya=YGb(Ja,F,xa&65535,0)|0;Ja=ya&65535;b[_+13874>>1]=Ja;Wa=xa;Xa=Ja;E=89;break}else{Ja=_+13864|0;xa=ZGb(oa,ga,c[Ja>>2]|0,c[Ja+4>>2]|0)|0;b[_+13872>>1]=xa;c[Ja>>2]=oa;c[Ja+4>>2]=ga;Va=ha;break}}}while(0);if((E|0)==89){E=0;if((Wa&65535)>>>0<=(Xa&65535)>>>0|Xa<<16>>16==0|Wa<<16>>16==0){E=90;break}UMa(R);Va=c[na>>2]|0}ha=c[Z>>2]|0;ga=(d[(c[V>>2]|0)+(ha>>>3)|0]|0)<<(ha&7)>>>7;oa=c[ca>>2]|0;ea=((ha|0)<(oa|0))+ha|0;c[Z>>2]=ea;ha=ga&1;c[_+12472>>2]=ha;if((c[fa>>2]&266338304)>>>0<2097152>>>0&(Va|0)==3){ga=ea+5|0;c[Z>>2]=oa>>>0>ga>>>0?ga:oa;Ya=3}else{Ya=Va}c[_+11556>>2]=1;c[_+10048>>2]=1;c[_+228>>2]=(Ya|0)==1;c[_+13832>>2]=1;oa=c[Ea>>2]|0;if((c[oa+800>>2]|0)==0){c[_+13836>>2]=1}if((c[oa+688>>2]&1|0)==0){Za=Ya;_a=Va}else{ga=c[_+12476>>2]|0;ea=c[_+12480>>2]|0;sa=c[ra>>2]|0;yDb(oa,32,2191552,(G=i,i=i+48|0,c[G>>2]=ma,c[G+8>>2]=ga,c[G+16>>2]=ea,c[G+24>>2]=Ya,c[G+32>>2]=sa,c[G+40>>2]=ha,G)|0);i=G;ha=c[na>>2]|0;Za=ha;_a=ha}if((Za|0)==3){if((c[wa>>2]|0)!=0){E=100;break}}ha=c[_+116>>2]|0;ta=(ba(c[_+120>>2]|0,ha)|0)-za|0;ua=ha;va=_a}if((ta|0)<0){Ua=ta;E=103;break}$a=_+12476|0;ab=c[$a>>2]|0;ha=_+116|0;bb=_+12480|0;cb=c[bb>>2]|0;if((ab|0)>=(ua|0)){E=108;break}sa=c[_+120>>2]|0;if((cb|0)>=(sa|0)){E=108;break}if((ta|0)>((ba(sa,ua)|0)-((ba(cb,ua)|0)+ab)|0)){E=110;break}sa=c[_+9856>>2]|0;ea=(sa|0)==0;do{if((cb|ab|0)==0){if(ea){E=115;break}Mkb(_+14424|0);SOa(R);c[_+13708>>2]=0;c[_+13704>>2]=0;c[bb>>2]=0;c[$a>>2]=0;E=115}else{if(ea){E=115;break}if((c[sa+88>>2]|0)!=(va|0)){E=118;break b}}}while(0);if((E|0)==115){E=0;sa=ROa(R,e)|0;if((sa|0)<0){v=sa;E=166;break}ePa(R)}do{if((c[da>>2]|0)==6){sa=c[bb>>2]|0;if((sa|0)!=0){db=sa;break}c[_+14084>>2]=1;db=0}else{c[_+14084>>2]=1;c[_+13704>>2]=c[$a>>2];db=c[bb>>2]|0}}while(0);da=c[$a>>2]|0;sa=_+13708|0;c[sa>>2]=db;ea=_+9892|0;if((c[_+228>>2]|0)==0){c[ea>>2]=1179688;c[_+9888>>2]=1179688}else{c[ea>>2]=1265888;c[_+9888>>2]=1265888}if((c[_+13832>>2]|0)!=0){c[_+9896>>2]=1211152}cPa(R,c[_+9960>>2]|0);c[_+14032>>2]=0;c[_+14036>>2]=0;c[_+14040>>2]=0;ea=c[_+128>>2]|0;c[_+12532>>2]=ea;c[_+12528>>2]=ea;c[_+12524>>2]=ea;c[_+12520>>2]=ea;ea=c[_+124>>2]|0;c[_+12540>>2]=ea;c[_+12536>>2]=ea;$Oa(R);ea=_+13732|0;c[ea>>2]=ta;c:do{if((ta|0)>0){eb=_+4|0;za=_+12496|0;na=_+12500|0;ma=_+12504|0;ra=_+12508|0;fa=_+12512|0;ca=_+12516|0;ga=_+12544|0;oa=_+12548|0;aa=_+12552|0;P=_+11736|0;Ja=_+11740|0;xa=_+14340|0;ya=W<<3;Na=_+9992|0;Qa=_+13836|0;Oa=_+13704|0;Ia=_+14084|0;Ra=$;while(1){fb=8>>>((c[(c[eb>>2]|0)+800>>2]|0)>>>0);c[za>>2]=(c[za>>2]|0)+2;c[na>>2]=(c[na>>2]|0)+2;c[ma>>2]=(c[ma>>2]|0)+2;c[ra>>2]=(c[ra>>2]|0)+2;c[fa>>2]=(c[fa>>2]|0)+1;c[ca>>2]=(c[ca>>2]|0)+1;c[ga>>2]=(c[ga>>2]|0)+(fb<<1);c[oa>>2]=(c[oa>>2]|0)+fb;c[aa>>2]=(c[aa>>2]|0)+fb;c[P>>2]=1;c[Ja>>2]=0;fb=mIa(R,c[xa>>2]|0)|0;if((fb|0)==-1){E=138;break b}gb=c[Z>>2]|0;hb=(c[V>>2]|0)+(gb>>>3)|0;ib=(fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(gb&7)>>>16;hb=gb+16|0;if((hb|0)>(Ra|0)){jb=ib>>>((hb-Ra|0)>>>0)}else{jb=ib}ib=(jb|0)==0?-2:fb;if((ib|0)==-1){E=138;break b}if((Ra|0)>=(gb|0)|(ya|0)<(gb|0)){kb=Ra;lb=ib;mb=gb}else{yDb(h,48,2350784,(G=i,i=i+16|0,c[G>>2]=$,c[G+8>>2]=ya,G)|0);i=G;kb=ya;lb=0;mb=c[Z>>2]|0}if((kb|0)<(mb|0)){E=138;break b}if((c[Na>>2]|0)!=3){xca(R)}YOa(R,c[xa>>2]|0);if((c[Qa>>2]|0)!=0){zca(R)}gb=(c[$a>>2]|0)+1|0;c[$a>>2]=gb;if((gb|0)==(c[ha>>2]|0)){c[$a>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;$Oa(R);nb=c[$a>>2]|0}else{nb=gb}if((nb|0)==(c[Oa>>2]|0)){c[Ia>>2]=0}if((lb|0)==-2){ob=kb;pb=nb;break c}gb=(c[ea>>2]|0)-1|0;c[ea>>2]=gb;if((gb|0)>0){Ra=kb}else{ob=kb;pb=nb;break}}}else{ob=$;pb=c[$a>>2]|0}}while(0);Lkb(_+14424|0,da,c[sa>>2]|0,pb-1|0,c[bb>>2]|0,112);if((ob|0)<0){v=ob;E=166;break}ea=((ob|0)>($|0)?S:N)+1|0;if((ea|0)>=(C|0)){break a}N=ea;O=c[f>>2]|0}do{if((E|0)==28){O=_+4|0;DDb(c[O>>2]|0,2144040,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Pa=O}else if((E|0)==30){O=_+4|0;yDb(c[O>>2]|0,16,2242152,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Pa=O}else if((E|0)==44){O=_+4|0;yDb(c[O>>2]|0,16,2306240,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Pa=O}else if((E|0)==47){O=_+4|0;yDb(c[O>>2]|0,16,2288056,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Pa=O}else if((E|0)==49){O=_+4|0;yDb(c[O>>2]|0,16,2271848,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Pa=O}else if((E|0)==51){O=_+4|0;yDb(c[O>>2]|0,16,2256544,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Pa=O}else if((E|0)==53){O=_+4|0;yDb(c[O>>2]|0,16,2242152,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Pa=O}else if((E|0)==65){yDb(Fa,16,2229792,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Pa=Ea}else if((E|0)==90){yDb(c[Ea>>2]|0,48,2200128,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;v=-1094995529;i=j;return v|0}else if((E|0)==100){yDb(0,0,2174960,(G=i,i=i+24|0,c[G>>2]=2164712,c[G+8>>2]=2157976,c[G+16>>2]=441,G)|0);i=G;Cd();return 0}else if((E|0)==103){if((Ua|0)==-123){v=-1094995529;i=j;return v|0}else{Pa=_+4|0;break}}else if((E|0)==108){yDb(c[_+4>>2]|0,16,1937512,(G=i,i=i+16|0,c[G>>2]=ab,c[G+8>>2]=cb,G)|0);i=G;v=-1094995529;i=j;return v|0}else if((E|0)==110){yDb(c[_+4>>2]|0,16,1913632,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;v=-1094995529;i=j;return v|0}else if((E|0)==118){yDb(c[_+4>>2]|0,16,1893192,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;v=-1094995529;i=j;return v|0}else if((E|0)==138){O=c[bb>>2]|0;yDb(c[eb>>2]|0,16,2330416,(G=i,i=i+16|0,c[G>>2]=c[$a>>2],c[G+8>>2]=O,G)|0);i=G;v=-1094995529;i=j;return v|0}else if((E|0)==166){i=j;return v|0}}while(0);yDb(c[Pa>>2]|0,16,1965592,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;v=-1094995529;i=j;return v|0}}while(0);G=s+9856|0;do{if((c[G>>2]|0)!=0){if((c[s+12480>>2]|0)<(c[s+120>>2]|0)){break}Mkb(s+14424|0);SOa(t);do{if((c[s+9992>>2]|0)==3){E=156}else{if((c[s+13944>>2]|0)!=0){E=156;break}Pa=s+9848|0;$a=c[Pa>>2]|0;if(($a|0)==0){qb=Pa;break}eb=MCb(u,$a|0)|0;if((eb|0)<0){v=eb;i=j;return v|0}else{VOa(t,c[Pa>>2]|0,u);WOa(t,u,c[Pa>>2]|0,0)|0;qb=Pa;break}}}while(0);do{if((E|0)==156){Pa=MCb(u,c[G>>2]|0)|0;if((Pa|0)<0){v=Pa;i=j;return v|0}else{VOa(t,c[G>>2]|0,u);WOa(t,u,c[G>>2]|0,0)|0;qb=s+9848|0;break}}}while(0);if((c[qb>>2]|0)==0){if((c[s+13944>>2]|0)!=0){E=163}}else{E=163}if((E|0)==163){c[g>>2]=1}c[G>>2]=0}}while(0);v=c[q>>2]|0;i=j;return v|0}function dVa(a){a=a|0;LOa(c[a+60>>2]|0);return 0}function eVa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;d=b+784|0;K_(d);e=d|0;d=c[e>>2]|0;f=b+788|0;g=c[f>>2]|0;if((g|0)>1){h=g-1|0;i=d<<1|1}else{j=fe(1>>>((1-g|0)>>>0)|d<<g|0)|0;d=b+796|0;k=c[d>>2]|0;x=j;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[d>>2]=(c[d>>2]|0)+4;h=g+31|0;i=1}c[e>>2]=i;c[f>>2]=h;g=(c[b+9992>>2]|0)==2|0;if((h|0)>1){l=h-1|0;m=i<<1|g}else{d=fe(g>>>((1-h|0)>>>0)|i<<h|0)|0;i=b+796|0;k=c[i>>2]|0;x=d;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;l=h+31|0;m=g}c[e>>2]=m;c[f>>2]=l;if((l|0)>1){n=l-1|0;o=m<<1}else{g=fe(m<<l|0)|0;m=b+796|0;h=c[m>>2]|0;x=g;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;n=l+31|0;o=0}c[e>>2]=o;c[f>>2]=n;l=c[b+9960>>2]|0;if((n|0)>5){p=n-5|0;q=o<<5|l}else{m=fe(o<<n|l>>>((5-n|0)>>>0)|0)|0;o=b+796|0;h=c[o>>2]|0;x=m;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;p=n+27|0;q=l}c[e>>2]=q;c[f>>2]=p;if((p|0)>6){r=p-6|0;s=q<<6}else{l=fe(q<<p|0)|0;q=b+796|0;n=c[q>>2]|0;x=l;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;r=p+26|0;s=0}c[e>>2]=s;c[f>>2]=r;if((r|0)>6){t=r-6|0;u=s<<6}else{p=fe(s<<r|0)|0;s=b+796|0;q=c[s>>2]|0;x=p;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;t=r+26|0;u=0}c[e>>2]=u;c[f>>2]=t;r=ba(c[b+120>>2]|0,c[b+116>>2]|0)|0;if((t|0)>12){v=t-12|0;w=u<<12|r}else{s=fe(r>>>((12-t|0)>>>0)|u<<t|0)|0;u=b+796|0;q=c[u>>2]|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=t+20|0;w=r}c[e>>2]=w;c[f>>2]=v;if((v|0)>3){y=v-3|0;z=w<<3;c[e>>2]=z;c[f>>2]=y;return}else{r=fe(w<<v|0)|0;w=b+796|0;b=c[w>>2]|0;x=r;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;y=v+29|0;z=0;c[e>>2]=z;c[f>>2]=y;return}}function fVa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;e=i;f=b+9992|0;g=c[f>>2]|0;h=b+784|0;j=c[h>>2]|0;k=b+788|0;l=c[k>>2]|0;if((l|0)>2){m=l-2|0;n=j<<2|g}else{o=fe(g>>>((2-l|0)>>>0)|j<<l|0)|0;j=b+796|0;p=c[j>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;m=l+30|0;n=g}c[h>>2]=n;c[k>>2]=m;if((m|0)>1){q=m-1|0;r=n<<1}else{g=fe(n<<m|0)|0;n=b+796|0;l=c[n>>2]|0;x=g;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;q=m+31|0;r=0}c[h>>2]=r;c[k>>2]=q;m=c[b+9960>>2]|0;if((q|0)>5){s=q-5|0;t=r<<5|m}else{n=fe(r<<q|m>>>((5-q|0)>>>0)|0)|0;r=b+796|0;l=c[r>>2]|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;s=q+27|0;t=m}c[h>>2]=t;c[k>>2]=s;m=d&255;if((s|0)>8){u=s-8|0;v=t<<8|m}else{d=fe(m>>>((8-s|0)>>>0)|t<<s|0)|0;t=b+796|0;q=c[t>>2]|0;x=d;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;u=s+24|0;v=m}c[h>>2]=v;c[k>>2]=u;c[b+12480>>2]=0;c[b+12476>>2]=0;Ilb(b);u=c[b+12472>>2]|0;v=c[h>>2]|0;m=c[k>>2]|0;if((m|0)>1){w=m-1|0;y=v<<1|u}else{s=fe(u>>>((1-m|0)>>>0)|v<<m|0)|0;v=b+796|0;t=c[v>>2]|0;x=s;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;w=m+31|0;y=u}c[h>>2]=y;c[k>>2]=w;if((c[b+11556>>2]|0)!=1){yDb(0,0,2223e3,(z=i,i=i+24|0,c[z>>2]=2316456,c[z+8>>2]=2182304,c[z+16>>2]=43,z)|0);i=z;Cd()}if((c[b+10048>>2]|0)!=0){yDb(0,0,2223e3,(z=i,i=i+24|0,c[z>>2]=2105344,c[z+8>>2]=2182304,c[z+16>>2]=44,z)|0);i=z;Cd()}if((c[b+13828>>2]|0)!=0){yDb(0,0,2223e3,(z=i,i=i+24|0,c[z>>2]=2048456,c[z+8>>2]=2182304,c[z+16>>2]=45,z)|0);i=z;Cd()}if((c[b+13816>>2]|0)!=0){yDb(0,0,2223e3,(z=i,i=i+24|0,c[z>>2]=2002936,c[z+8>>2]=2182304,c[z+16>>2]=46,z)|0);i=z;Cd()}if((c[b+13832>>2]|0)!=1){yDb(0,0,2223e3,(z=i,i=i+24|0,c[z>>2]=1965568,c[z+8>>2]=2182304,c[z+16>>2]=47,z)|0);i=z;Cd()}if((c[b+13836>>2]|0)!=1){yDb(0,0,2223e3,(z=i,i=i+24|0,c[z>>2]=1937488,c[z+8>>2]=2182304,c[z+16>>2]=48,z)|0);i=z;Cd()}z=(c[f>>2]|0)==1;c[b+228>>2]=z&1;f=b+9892|0;if(z){c[f>>2]=1265888;c[b+9888>>2]=1265888;i=e;return}else{c[f>>2]=1179688;c[b+9888>>2]=1179688;i=e;return}}function gVa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[b+60>>2]|0;c[e+15600>>2]=1;f=nVa(b)|0;if((f|0)<0){g=f;i=d;return g|0}f=b+100|0;if((c[f>>2]|0)<2){yDb(b,16,2182272,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1;i=d;return g|0}j=a[(c[b+96>>2]|0)+1|0]&7;c[e+15604>>2]=j;k=c[f>>2]|0;f=(j<<1)+8|0;if((k|0)<(f|0)){yDb(b,24,2105264,(h=i,i=i+16|0,c[h>>2]=f,c[h+8>>2]=k,h)|0);i=h}c[e+15732>>2]=272;c[e+15740>>2]=122;c[e+15736>>2]=662;c[e+15744>>2]=94;c[e+15276>>2]=544184;c[e+15280>>2]=544184;g=0;i=d;return g|0}function hVa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;g=a+4|0;h=c[g>>2]|0;j=c[a+8>>2]|0;k=c[a+12>>2]|0;TGb(e|0,0,32)|0;l=b+8|0;m=c[l>>2]|0;n=b+16|0;o=c[n>>2]|0;p=b|0;q=c[p>>2]|0;r=q+(m>>>3)|0;s=fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;r=m+3|0;t=o>>>0>r>>>0?r:o;c[l>>2]=t;if((s&-536870912>>>((m&7)>>>0)|0)!=0){u=-1;i=f;return u|0}m=q+(t>>>3)|0;q=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(t&7)>>>30;m=t+2|0;c[l>>2]=o>>>0>m>>>0?m:o;c[e>>2]=(q|0)==1?0:q;q=c[l>>2]|0;o=c[p>>2]|0;m=d[o+(q>>>3)|0]|0;t=c[n>>2]|0;s=((q|0)<(t|0))+q|0;c[l>>2]=s;if((m&128>>>((q&7)>>>0)|0)!=0){u=-1;i=f;return u|0}q=o+(s>>>3)|0;m=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(s&7)>>>27;q=s+5|0;c[l>>2]=t>>>0>q>>>0?q:t;c[e+4>>2]=m;m=c[n>>2]|0;t=(c[l>>2]|0)+1|0;q=m>>>0>t>>>0?t:m;c[l>>2]=q;t=o+(q>>>3)|0;s=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(q&7)>>>19;t=q+13|0;c[l>>2]=m>>>0>t>>>0?t:m;c[e+28>>2]=s;s=a+15604|0;a=c[s>>2]|0;m=a>>>0>65535>>>0;t=m?a>>>16:a;a=m?16:0;if((t&65280|0)==0){v=a;w=t}else{v=a|8;w=t>>>8}t=(d[1191992+w|0]|0)+v|0;v=c[l>>2]|0;w=c[n>>2]|0;a=o+(v>>>3)|0;o=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(v&7)>>>((31-t|0)>>>0);a=v+1+t|0;c[l>>2]=w>>>0>a>>>0?a:w;do{if((o|0)==0){x=j;y=k}else{if((o|0)>(c[s>>2]|0)){yDb(h,16,1913608,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;u=-1094995529;i=f;return u|0}w=c[h+100>>2]|0;a=o<<1;t=a+8|0;if((w|0)>=(t|0)){v=c[(c[g>>2]|0)+96>>2]|0;x=(d[v+(a+6)|0]|0)<<2;y=(d[v+(a+7)|0]|0)<<2;break}yDb(h,16,2105264,(z=i,i=i+16|0,c[z>>2]=t,c[z+8>>2]=w,z)|0);i=z;u=-22;i=f;return u|0}}while(0);c[e+20>>2]=x;c[e+24>>2]=y;z=mVa(b,ba(x+15>>4,y+15>>4)|0)|0;y=c[l>>2]|0;x=c[n>>2]|0;b=(c[p>>2]|0)+(y>>>3)|0;p=(fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(y&7)>>>((32-z|0)>>>0);b=y+z|0;c[l>>2]=x>>>0>b>>>0?b:x;c[e+12>>2]=p;p=c[n>>2]|0;n=(c[l>>2]|0)+1|0;c[l>>2]=p>>>0>n>>>0?n:p;u=0;i=f;return u|0}function iVa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;h=e+8|0;j=e+16|0;k=e|0;e=b+15272|0;l=0;m=f;a:while(1){f=0;n=m;while(1){o=c[h>>2]|0;p=c[j>>2]|0;q=c[k>>2]|0;r=q+(o>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(o&7);if((s&-1434451968|0)==0){r=1;t=o;u=s;while(1){v=u>>>24;w=a[1201432+v|0]|0;x=w&255;y=((w&255)>>>0>8>>>0?8:x)+t|0;z=p>>>0>y>>>0;A=z?y:p;if(!(w<<24>>24==9)){B=6;break}w=d[1201688+v|0]|r<<4;if(!(w>>>0<134217728>>>0)){C=w;break}y=q+(A>>>3)|0;D=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(A&7);if(z){r=w;t=A;u=D}else{C=w;break}}if((B|0)==6){B=0;C=d[1201688+v|0]|r<<(x-1>>1)}c[h>>2]=A;E=C-1|0}else{u=s>>>24;t=(d[1201432+u|0]|0)+o|0;c[h>>2]=p>>>0>t>>>0?t:p;E=d[1200920+u|0]|0}u=E<<1;if(u>>>0>160>>>0){B=12;break a}t=a[544248+(((a[n+(-(c[e>>2]|0)|0)|0]|0)*90|0)+99+((a[n-1|0]|0)*9|0)+(d[545152+u|0]|0))|0]|0;a[n]=t;if(t<<24>>24==9){B=13;break a}q=a[544248+(((a[n+(1-(c[e>>2]|0))|0]|0)*90|0)+99+((t<<24>>24)*9|0)+(d[545152+(u|1)|0]|0))|0]|0;a[n+1|0]=q;if(q<<24>>24==9){B=13;break a}q=f+2|0;if((q|0)<4){f=q;n=n+2|0}else{break}}f=l+1|0;if((f|0)<4){l=f;m=n+((c[e>>2]|0)-2)|0}else{F=0;B=16;break}}if((B|0)==12){yDb(c[b+4>>2]|0,16,1965520,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;F=-1;i=g;return F|0}else if((B|0)==13){yDb(c[b+4>>2]|0,16,1937432,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;F=-1;i=g;return F|0}else if((B|0)==16){i=g;return F|0}return 0}function jVa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;f=b+14128|0;g=c[f>>2]|0;h=c[b+14136>>2]|0;j=c[b+14120>>2]|0;k=j+(g>>>3)|0;l=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(g&7);if((l&-1434451968|0)==0){k=1;m=g;n=l;while(1){o=n>>>24;p=a[1201432+o|0]|0;q=p&255;r=((p&255)>>>0>8>>>0?8:q)+m|0;s=h>>>0>r>>>0;t=s?r:h;if(!(p<<24>>24==9)){u=4;break}p=d[1201688+o|0]|0|k<<4;if(!(p>>>0<134217728>>>0)){v=p;break}r=j+(t>>>3)|0;w=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7);if(s){k=p;m=t;n=w}else{v=p;break}}if((u|0)==4){v=d[1201688+o|0]|0|k<<(q-1>>1)}c[f>>2]=t;x=v-1|0}else{v=l>>>24;l=(d[1201432+v|0]|0)+g|0;c[f>>2]=h>>>0>l>>>0?l:h;x=d[1200920+v|0]|0}if(x>>>0>11>>>0){yDb(c[b+4>>2]|0,16,2048432,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;z=-1;i=e;return z|0}if(x>>>0>5>>>0){yDb(c[b+4>>2]|0,16,2002920,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;A=x-6|0}else{A=x}if((c[b+9992>>2]|0)==3){z=c[545344+(A<<2)>>2]|0;i=e;return z|0}else{z=c[545320+(A<<2)>>2]|0;i=e;return z|0}return 0}function kVa(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0;h=f+124|0;i=f+116|0;j=c[i>>2]|0;if((j|0)<=0){return}k=f+9856|0;l=f+15644|0;m=f+15648|0;n=1;o=ba(c[h>>2]|0,g)|0;p=j;while(1){j=c[(c[(c[k>>2]|0)+1536>>2]|0)+(o<<2)>>2]|0;q=(j&7|0)!=0;if(!((j&16777216|0)==0&(q^1))){b[(c[m>>2]|0)+(o<<1)>>1]=-1}if(q){a[(c[l>>2]|0)+o|0]=-1;r=c[i>>2]|0}else{r=p}if((n|0)>=(r|0)){break}n=n+1|0;o=o+1|0;p=r}if((r|0)<=0){return}r=f+9856|0;p=g<<4;o=f+148|0;n=f+15648|0;l=f+15644|0;m=g<<3;k=f+152|0;q=0;j=0;s=ba(c[h>>2]|0,g)|0;while(1){t=c[(c[r>>2]|0)+1512>>2]|0;u=d[544216+(a[t+s|0]|0)|0]|0;v=(j|0)!=0;w=s-1|0;if(v){x=d[544216+(a[t+w|0]|0)|0]|0}else{x=q}t=v&1^1;y=t<<2;z=y|j<<4;A=0;do{B=z+(ba(c[o>>2]|0,A+p|0)|0)|0;C=(c[c[r>>2]>>2]|0)+B|0;B=t;while(1){D=B+A|0;E=c[n>>2]|0;F=e[E+(s<<1)>>1]|0;do{if((F&1<<D|0)==0){if((B|0)==0){G=(e[E+(w<<1)>>1]&1<<D+3|0)!=0?x:0;break}else{G=(F&1<<D-1|0)==0?0:u;break}}else{G=u}}while(0);if((G|0)!=0){lVa(C,1,c[o>>2]|0,G)}D=B+1|0;if((D|0)>=4){break}C=C+4|0;B=D}A=A+4|0;}while((A|0)<16);A=y|j<<3;z=0;do{B=c[l>>2]|0;C=z<<2;D=(d[B+s|0]|0)>>>(C>>>0)&15;if(v){H=(d[B+w|0]|0)>>>(C>>>0)&15}else{H=0}z=z+1|0;C=A+(ba(c[k>>2]|0,m)|0)|0;B=(c[(c[r>>2]|0)+(z<<2)>>2]|0)+C|0;C=t;while(1){do{if((1<<C&D|0)==0){if((C|0)==0){I=(H&2|0)!=0?x:0;break}else{I=(1<<C-1&D|0)==0?0:u;break}}else{I=u}}while(0);if((I|0)!=0){lVa(B,1,c[k>>2]|0,I)}F=C+1|0;if((F|0)<2){B=B+4|0;C=F}else{break}}C=A+(ba(c[k>>2]|0,m|4)|0)|0;B=(c[(c[r>>2]|0)+(z<<2)>>2]|0)+C|0;C=t;while(1){do{if((1<<C+2&D|0)==0){if((C|0)==0){J=(1<<C+3&H|0)!=0?x:0;break}else{J=(1<<C+1&D|0)==0?0:u;break}}else{J=u}}while(0);if((J|0)!=0){lVa(B,1,c[k>>2]|0,J)}F=C+1|0;if((F|0)<2){B=B+4|0;C=F}else{break}}}while((z|0)<2);z=j+1|0;K=c[i>>2]|0;if((z|0)>=(K|0)){break}q=x;j=z;s=s+1|0}if((K|0)<=0){return}K=f+9856|0;s=(g|0)!=0;j=(s&1)<<2^4;x=f+15644|0;q=g<<3;J=f+152|0;k=g<<4;H=f+148|0;r=f+15648|0;f=0;m=0;I=ba(c[h>>2]|0,g)|0;while(1){g=c[K>>2]|0;l=c[g+1512>>2]|0;G=d[544216+(a[l+I|0]|0)|0]|0;if(s){L=d[544216+(a[l+(I-(c[h>>2]|0))|0]|0)|0]|0}else{L=f}l=m<<4;o=j;n=g;while(1){g=c[n>>2]|0;p=c[H>>2]|0;z=(ba(p,o+k|0)|0)+l|0;u=g+z|0;t=c[r>>2]|0;A=b[t+(I<<1)>>1]|0;do{if((o|0)==0){if((A&1)==0){M=(b[t+(I-(c[h>>2]|0)<<1)>>1]&4096)!=0?L:0}else{M=G}if((M|0)==0){N=t;O=A}else{lVa(u,p,1,M);w=c[r>>2]|0;N=w;O=b[w+(I<<1)>>1]|0}if((O&2)==0){P=(b[N+(I-(c[h>>2]|0)<<1)>>1]&8192)!=0?L:0}else{P=G}if((P|0)==0){Q=N;R=O}else{lVa(g+(z+4)|0,c[H>>2]|0,1,P);w=c[r>>2]|0;Q=w;R=b[w+(I<<1)>>1]|0}if((R&4)==0){S=(b[Q+(I-(c[h>>2]|0)<<1)>>1]&16384)!=0?L:0}else{S=G}if((S|0)==0){T=Q;U=R}else{lVa(g+(z+8)|0,c[H>>2]|0,1,S);w=c[r>>2]|0;T=w;U=b[w+(I<<1)>>1]|0}if((U&8)==0){V=(b[T+(I-(c[h>>2]|0)<<1)>>1]|0)<0?L:0}else{V=G}if((V|0)==0){break}lVa(g+(z+12)|0,c[H>>2]|0,1,V)}else{w=A&65535;if((w&1<<o|0)==0){W=(w&1<<o-4|0)==0?0:G}else{W=G}if((W|0)==0){X=A}else{lVa(u,p,1,W);X=b[(c[r>>2]|0)+(I<<1)>>1]|0}w=o|1;v=X&65535;if((v&1<<w|0)==0){Y=(v&1<<w-4|0)==0?0:G}else{Y=G}if((Y|0)==0){Z=X}else{lVa(g+(z+4)|0,c[H>>2]|0,1,Y);Z=b[(c[r>>2]|0)+(I<<1)>>1]|0}w=o|2;v=Z&65535;if((v&1<<w|0)==0){_=(v&1<<w-4|0)==0?0:G}else{_=G}if((_|0)==0){$=Z}else{lVa(g+(z+8)|0,c[H>>2]|0,1,_);$=b[(c[r>>2]|0)+(I<<1)>>1]|0}w=o|3;v=$&65535;if((v&1<<w|0)==0){aa=(v&1<<w-4|0)==0?0:G}else{aa=G}if((aa|0)==0){break}lVa(g+(z+12)|0,c[H>>2]|0,1,aa)}}while(0);z=o+4|0;if((z|0)>=16){break}o=z;n=c[K>>2]|0}n=m<<3;o=0;do{l=c[x>>2]|0;z=a[l+I|0]|0;g=o<<2;p=(z&255)>>>(g>>>0)&15;if(s){ca=(d[l+(I-(c[h>>2]|0))|0]|0)>>>(g>>>0)&15}else{ca=0}o=o+1|0;g=j;l=z;while(1){z=c[(c[K>>2]|0)+(o<<2)>>2]|0;u=c[J>>2]|0;A=(ba(u,g+q|0)|0)+n|0;t=z+A|0;w=g>>1;v=(g|0)!=0;y=v^1;do{if((l&255&1<<w|0)==0){if(!v){C=(1<<w+2&ca|0)!=0;if(C|y){da=C?L:0;break}}da=(p&1<<w-2|0)==0?0:G}else{da=G}}while(0);if((da|0)==0){ea=l}else{lVa(t,u,1,da);ea=a[(c[x>>2]|0)+I|0]|0}C=z+(A+4)|0;B=w|1;do{if((ea&255&1<<B|0)==0){if(!v){D=(1<<B+2&ca|0)!=0;if(D|y){fa=D?L:0;break}}fa=(p&1<<B-2|0)==0?0:G}else{fa=G}}while(0);if((fa|0)!=0){lVa(C,c[J>>2]|0,1,fa)}B=g+4|0;if((B|0)>=8){break}g=B;l=a[(c[x>>2]|0)+I|0]|0}}while((o|0)<2);o=m+1|0;if((o|0)>=(c[i>>2]|0)){break}f=L;m=o;I=I+1|0}return}function lVa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=c*-2|0;h=-f|0;i=b+(-c|0)|0;j=d[i]|0;k=(d[b+g|0]|0)-(d[b+c|0]|0)-(j-(d[b]|0)<<2)>>3;if((k|0)<(h|0)){l=h}else{l=(k|0)>(f|0)?f:k}a[i]=a[1235032+((j|1024)+l)|0]|0;a[b]=a[1235032+(1024-l+(d[b]|0))|0]|0;l=b+e|0;j=b+(e-c)|0;i=d[j]|0;k=(d[b+(g+e)|0]|0)-(d[b+(e+c)|0]|0)-(i-(d[l]|0)<<2)>>3;if((k|0)<(h|0)){m=h}else{m=(k|0)>(f|0)?f:k}a[j]=a[1235032+((i|1024)+m)|0]|0;a[l]=a[1235032+(1024-m+(d[l]|0))|0]|0;l=e<<1;m=b+l|0;i=b+(l-c)|0;j=d[i]|0;k=(d[b+(l+g)|0]|0)-(d[b+(l+c)|0]|0)-(j-(d[m]|0)<<2)>>3;if((k|0)<(h|0)){n=h}else{n=(k|0)>(f|0)?f:k}a[i]=a[1235032+((j|1024)+n)|0]|0;a[m]=a[1235032+(1024-n+(d[m]|0))|0]|0;m=l+e|0;e=b+m|0;l=b+(m-c)|0;n=d[l]|0;j=(d[b+(m+g)|0]|0)-(d[b+(m+c)|0]|0)-(n-(d[e]|0)<<2)>>3;if((j|0)<(h|0)){o=h;p=n|1024;q=p+o|0;r=1235032+q|0;s=a[r]|0;a[l]=s;t=a[e]|0;u=t&255;v=1024-o|0;w=v+u|0;x=1235032+w|0;y=a[x]|0;a[e]=y;return}o=(j|0)>(f|0)?f:j;p=n|1024;q=p+o|0;r=1235032+q|0;s=a[r]|0;a[l]=s;t=a[e]|0;u=t&255;v=1024-o|0;w=v+u|0;x=1235032+w|0;y=a[x]|0;a[e]=y;return}function mVa(a,b){a=a|0;b=b|0;a=b-1|0;b=0;while(1){if((b|0)>=5){break}if((e[534144+(b<<1)>>1]|0|0)<(a|0)){b=b+1|0}else{break}}return d[534160+b|0]|0|0}function nVa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+60>>2]|0;d=b;IOa(d);c[b+28>>2]=2;e=a+48|0;c[b+48>>2]=c[e>>2];c[b+8>>2]=c[a+120>>2];c[b+12>>2]=c[a+124>>2];c[b+4>>2]=a;c[a+140>>2]=0;c[a+176>>2]=1;c[b+13944>>2]=0;f=FOa(d)|0;if((f|0)<0){g=f;return g|0}cia(b+15288|0,70,8,1);f=c[e>>2]|0;if((f|0)==69){rnb(b+14672|0);h=c[e>>2]|0}else{h=f}if((h|0)==70){GVa(b+14672|0)}h=oVa(b)|0;if((h|0)<0){LOa(d);g=h;return g|0}if((c[1270540]|0)==0){h=0;while(1){d=h*19|0;AVa(505248+(h*2592|0)|0,1296,5082160+(h*380|0)|0,0,d);AVa(486888+(h*216|0)|0,108,5082440+(h*380|0)|0,0,d+2|0);AVa(485808+(h*216|0)|0,108,5082480+(h*380|0)|0,0,d+4|0);AVa(518208+(h<<7)|0,16,5082200+(h*380|0)|0,544168,d+6|0);AVa(518240+(h<<7)|0,16,5082220+(h*380|0)|0,544168,d+7|0);AVa(518272+(h<<7)|0,16,5082240+(h*380|0)|0,544168,d+8|0);AVa(518304+(h<<7)|0,16,5082260+(h*380|0)|0,544168,d+9|0);AVa(506544+(h*2592|0)|0,1296,5082180+(h*380|0)|0,0,d+1|0);AVa(486996+(h*216|0)|0,108,5082460+(h*380|0)|0,0,d+3|0);AVa(485916+(h*216|0)|0,108,5082500+(h*380|0)|0,0,d+5|0);AVa(518224+(h<<7)|0,16,5082280+(h*380|0)|0,544168,d+10|0);AVa(518256+(h<<7)|0,16,5082300+(h*380|0)|0,544168,d+11|0);AVa(518288+(h<<7)|0,16,5082320+(h*380|0)|0,544168,d+12|0);AVa(518320+(h<<7)|0,16,5082340+(h*380|0)|0,544168,d+13|0);AVa(487968+(h*3456|0)|0,864,5082360+(h*380|0)|0,0,d+14|0);AVa(488832+(h*3456|0)|0,864,5082380+(h*380|0)|0,0,d+15|0);AVa(489696+(h*3456|0)|0,864,5082400+(h*380|0)|0,0,d+16|0);AVa(490560+(h*3456|0)|0,864,5082420+(h*380|0)|0,0,d+17|0);AVa(534168+(h<<5)|0,32,5082520+(h*380|0)|0,0,d+18|0);d=h+1|0;if((d|0)<5){h=d}else{i=0;break}}do{h=i*12|0;AVa(534552+(i*1296|0)|0,1296,5084080+(i*380|0)|0,0,h+95|0);AVa(543624+(i<<6)|0,16,5084120+(i*380|0)|0,544168,h+96|0);AVa(543640+(i<<6)|0,16,5084140+(i*380|0)|0,544168,h+97|0);AVa(543656+(i<<6)|0,16,5084160+(i*380|0)|0,544168,h+98|0);AVa(543672+(i<<6)|0,16,5084180+(i*380|0)|0,544168,h+99|0);AVa(521872+(i*1728|0)|0,864,5084280+(i*380|0)|0,0,h+100|0);AVa(520360+(i*216|0)|0,108,5084360+(i*380|0)|0,0,h+102|0);AVa(518848+(i*216|0)|0,108,5084400+(i*380|0)|0,0,h+104|0);AVa(522736+(i*1728|0)|0,864,5084300+(i*380|0)|0,0,h+101|0);AVa(520468+(i*216|0)|0,108,5084380+(i*380|0)|0,0,h+103|0);AVa(518956+(i*216|0)|0,108,5084420+(i*380|0)|0,0,h+105|0);AVa(534328+(i<<5)|0,32,5084440+(i*380|0)|0,0,h+106|0);i=i+1|0;}while((i|0)<7)}c[(c[a+64>>2]|0)+4>>2]=1;g=0;return g|0}function oVa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+15272|0;c[b>>2]=(c[a+116>>2]<<2)+4;d=a+124|0;e=a+120|0;f=a+15644|0;c[f>>2]=cEb(ba(c[e>>2]|0,c[d>>2]|0)|0)|0;g=a+15640|0;c[g>>2]=cEb(ba(c[d>>2]<<1,c[e>>2]|0)|0)|0;h=a+15648|0;c[h>>2]=cEb(ba(c[d>>2]<<1,c[e>>2]|0)|0)|0;i=a+15264|0;c[i>>2]=WDb(c[b>>2]<<3)|0;j=cEb(ba(c[d>>2]<<2,c[e>>2]|0)|0)|0;e=a+15548|0;c[e>>2]=j;do{if((c[f>>2]|0)!=0){if((c[g>>2]|0)==0){break}if((c[h>>2]|0)==0){break}d=c[i>>2]|0;if((d|0)==0|(j|0)==0){break}c[a+15268>>2]=d+(c[b>>2]<<2);k=0;return k|0}}while(0);$Db(i);c[a+15268>>2]=0;$Db(a+15728|0);$Db(e);$Db(g);$Db(f);$Db(h);k=-12;return k|0}function pVa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0;k=i;i=i+88|0;l=k|0;m=k+32|0;n=k+40|0;o=k+48|0;p=k+56|0;q=c[j+24>>2]|0;r=j+28|0;j=c[r>>2]|0;s=f+60|0;t=c[s>>2]|0;u=t;v=t;w=g;if((j|0)==0){if((c[t+13944>>2]|0)!=0){x=0;i=k;return x|0}g=t+9852|0;y=c[g>>2]|0;if((y|0)==0){x=0;i=k;return x|0}z=MCb(w,y|0)|0;if((z|0)<0){x=z;i=k;return x|0}c[g>>2]=0;c[h>>2]=1;x=0;i=k;return x|0}g=f+212|0;z=c[g>>2]|0;y=(z|0)==0;do{if(y){A=(d[q]|0)+1|0;B=q+5|0;C=A<<3|1;D=q+C|0;E=j-C|0;C=q+1|0;F=B;G=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;if((d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)==1){H=G;I=A;J=B;K=E;L=D;break}H=fe(G|0)|0;I=A;J=B;K=E;L=D}else{H=c[c[f+220>>2]>>2]|0;I=z;J=0;K=j;L=q}}while(0);do{if((H|0)>=0){do{if(y){q=J-4|0;j=J;z=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;if((d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)==1){M=z;break}M=fe(z|0)|0}else{M=c[c[f+220>>2]>>2]|0}}while(0);if((M|0)>(K|0)){break}z=t+14120|0;q=z;do{if(y){j=J-4|0;D=J;E=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;if((d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)==1){N=E}else{N=fe(E|0)|0}E=L+N|0;j=J-4|0;D=J;B=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;if((d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)==1){O=B;P=E;break}O=fe(B|0)|0;P=E}else{E=c[c[f+220>>2]>>2]|0;O=E;P=L+E|0}}while(0);E=K-O<<3;B=E>>>0>2147483639>>>0|(P|0)==0;j=B?0:P;D=B?0:E;E=z;c[E>>2]=j;B=t+14132|0;c[B>>2]=D;A=t+14136|0;c[A>>2]=D+8;G=t+14124|0;c[G>>2]=j+(D>>3);D=t+14128|0;c[D>>2]=0;j=t+15732|0;do{if((ze[c[j>>2]&511](u,q,p)|0)>=0){C=p+12|0;if((c[C>>2]|0)!=0){break}F=c[t+9848>>2]|0;if((F|0)==0){Q=28}else{if((c[F>>2]|0)==0){Q=28}}do{if((Q|0)==28){if((c[p>>2]|0)!=3){break}yDb(f,16,2182200,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;x=-1094995529;i=k;return x|0}}while(0);F=c[f+856>>2]|0;do{if((F|0)>7){S=c[p>>2]|0;if((S|0)!=3){if((F|0)<=31){break}if(!((S|0)!=1|(F|0)>47)){break}}x=c[r>>2]|0;i=k;return x|0}}while(0);F=t+13732|0;S=c[F>>2]|0;if((S|0)>0){yDb(f,16,2105224,(R=i,i=i+8|0,c[R>>2]=S,R)|0);i=R;Mkb(t+14424|0);SOa(v)}S=t+8|0;T=p+20|0;U=c[T>>2]|0;do{if((c[S>>2]|0)==(U|0)){V=c[p+24>>2]|0;if((c[t+12>>2]|0)!=(V|0)){W=V;Q=41;break}X=t+4|0}else{W=c[p+24>>2]|0;Q=41}}while(0);do{if((Q|0)==41){V=t+4|0;Y=p+24|0;yDb(c[V>>2]|0,24,2048400,(R=i,i=i+16|0,c[R>>2]=U,c[R+8>>2]=W,R)|0);i=R;if((hDb(c[T>>2]|0,c[Y>>2]|0,0,c[V>>2]|0)|0)!=0){x=-1094995529;i=k;return x|0}Z=c[V>>2]|0;_=Z+224|0;$=c[S>>2]|0;aa=t+12|0;ca=c[aa>>2]|0;da=c[T>>2]|0;ea=c[Y>>2]|0;fa=c[_>>2]|0;ga=c[Z+228>>2]|0;Z=m;ha=m;c[ha>>2]=fa;ia=Z+4|0;c[ia>>2]=ga;if((fa|0)==0){c[ha>>2]=1;c[ia>>2]=1}c[n>>2]=ba(ea,$)|0;c[n+4>>2]=ba(da,ca)|0;jFb(o,Z,n);Z=c[o+4>>2]|0;ca=_;c[ca>>2]=c[o>>2];c[ca+4>>2]=Z;Z=c[T>>2]|0;c[S>>2]=Z;ca=c[Y>>2]|0;c[aa>>2]=ca;aa=V$a(c[V>>2]|0,Z,ca)|0;if((aa|0)<0){x=aa;i=k;return x|0}aa=GOa(v)|0;if((aa|0)<0){x=aa;i=k;return x|0}$Db(t+15264|0);c[t+15268>>2]=0;$Db(t+15728|0);$Db(t+15548|0);$Db(t+15640|0);$Db(t+15644|0);$Db(t+15648|0);aa=oVa(u)|0;if((aa|0)<0){x=aa}else{X=V;break}i=k;return x|0}}while(0);T=c[p>>2]|0;U=t+9992|0;c[U>>2]=(T|0)==0?1:T;if((ROa(v,c[X>>2]|0)|0)<0){x=-1;i=k;return x|0}ePa(v);T=t+15728|0;if((c[T>>2]|0)==0){V=t+148|0;aa=WDb((c[V>>2]|0)*48|0)|0;c[T>>2]=aa;c[t+15704>>2]=aa;T=c[V>>2]|0;c[t+15708>>2]=aa+(T<<4);V=T<<5;c[t+15712>>2]=aa+V;T=V|16;c[t+15716>>2]=aa+T;ca=c[t+152>>2]<<3;c[t+15720>>2]=aa+(V+ca);c[t+15724>>2]=aa+(T+ca)}ca=c[p+28>>2]|0;c[t+15608>>2]=ca;T=t+15616|0;aa=c[T>>2]|0;V=t+15612|0;do{if((c[U>>2]|0)==3){Z=c[V>>2]|0;Y=aa-Z&8191;if((Y|0)==0){c[t+15628>>2]=8192;c[t+15624>>2]=8192;c[t+15636>>2]=8192;c[t+15632>>2]=8192;c[t+15620>>2]=0;break}_=((ca-Z<<14&134201344)>>>0)/(Y>>>0)|0;c[t+15632>>2]=_;Z=((aa-ca<<14&134201344)>>>0)/(Y>>>0)|0;c[t+15636>>2]=Z;if(((_|Z)&511|0)==0){c[t+15624>>2]=_>>>9;c[t+15628>>2]=Z>>>9;c[t+15620>>2]=1;break}else{c[t+15624>>2]=_;c[t+15628>>2]=Z;c[t+15620>>2]=0;break}}else{c[V>>2]=aa;c[T>>2]=ca}}while(0);ca=t+12480|0;c[ca>>2]=0;T=t+12476|0;c[T>>2]=0;X0a(c[X>>2]|0);aa=t+116|0;V=t+120|0;Z=t+15532|0;_=t+15528|0;Y=f+220|0;da=t+15516|0;$=da;ea=da;da=t+15536|0;ia=t+12|0;ha=t+15540|0;fa=t+15520|0;ga=t+9960|0;ja=t+12484|0;ka=t+15264|0;la=t+15272|0;ma=t+14084|0;na=t+13704|0;oa=t+13708|0;pa=t+12496|0;qa=t+12500|0;ra=t+12504|0;sa=t+12508|0;ta=t+12512|0;ua=t+12516|0;va=t+12544|0;wa=t+12548|0;xa=t+12552|0;ya=t+15268|0;za=t+124|0;Aa=t+15656|0;Ba=t+15680|0;Ca=t+15684|0;Da=t+15696|0;Ea=t+15700|0;Fa=t+9856|0;Ga=t+15660|0;Ha=t+15564|0;Ia=t+15600|0;Ja=t+15552|0;Ka=t+15740|0;La=t+15556|0;Ma=t+15640|0;Na=t+15644|0;Oa=t+15648|0;Pa=t+15560|0;Qa=t+15524|0;Ra=t+15284|0;Sa=t+15672|0;Ta=t+15668|0;Ua=t+15664|0;Va=t+15692|0;Wa=t+15676|0;Xa=t+15744|0;Ya=l;Za=t+14340|0;_a=t+15736|0;$a=t+128|0;ab=l|0;bb=t+15280|0;cb=t+15228|0;db=t+15236|0;eb=t+148|0;fb=t+15232|0;gb=t+15224|0;hb=t+152|0;ib=t+15548|0;jb=t+15568|0;kb=t+14672|0;lb=kb;mb=t+15184|0;nb=mb;ob=t+9852|0;pb=t+15632|0;qb=t+15636|0;rb=t+15624|0;sb=t+14928|0;tb=t+15196|0;ub=t+15620|0;vb=t+15704|0;wb=t+15708|0;xb=t+15628|0;yb=t+15712|0;zb=t+15720|0;Ab=t+15716|0;Bb=t+15724|0;Cb=jb;Db=t+15576|0;Eb=t+15572|0;Fb=t+15580|0;Gb=t+14424|0;Hb=0;a:while(1){if((Hb|0)>=(I|0)){break}Ib=(c[g>>2]|0)==0;do{if(Ib){Jb=Hb<<3;Kb=J+(Jb-4)|0;Lb=J+Jb|0;Jb=d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0;if((d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)==1){Mb=Jb;break}Mb=fe(Jb|0)|0}else{Mb=c[(c[Y>>2]|0)+(Hb<<2)>>2]|0}}while(0);Jb=Hb+1|0;do{if((Jb|0)==(I|0)){Nb=K}else{if(!Ib){Nb=c[(c[Y>>2]|0)+(Jb<<2)>>2]|0;break}Kb=Jb<<3;Lb=J+(Kb-4)|0;Ob=J+Kb|0;Kb=d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0;if((d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)==1){Nb=Kb;break}Nb=fe(Kb|0)|0}}while(0);Ib=Nb-Mb|0;if((Mb|0)<0|(Mb|0)>(K|0)){Q=69;break}Kb=c[aa>>2]|0;c[Z>>2]=ba(c[V>>2]|0,Kb)|0;Lb=(ba(Kb,c[ca>>2]|0)|0)+(c[T>>2]|0)|0;c[F>>2]=Lb-(c[_>>2]|0);do{if((Jb|0)<(I|0)){Lb=(c[g>>2]|0)==0;do{if(Lb){Kb=Jb<<3;Ob=J+(Kb-4)|0;Pb=J+Kb|0;Kb=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;if((d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)==1){Qb=Kb;break}Qb=fe(Kb|0)|0}else{Qb=c[(c[Y>>2]|0)+(Jb<<2)>>2]|0}}while(0);if((Qb|0)<0){Q=81;break a}do{if(Lb){Kb=Jb<<3;Ob=J+(Kb-4)|0;Pb=J+Kb|0;Kb=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;if((d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)==1){Rb=Kb;break}Rb=fe(Kb|0)|0}else{Rb=c[(c[Y>>2]|0)+(Jb<<2)>>2]|0}}while(0);if((Rb|0)>(K|0)){Q=81;break a}do{if(Lb){Kb=Jb<<3;Ob=J+(Kb-4)|0;Pb=J+Kb|0;Kb=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;if((d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)==1){Sb=Kb}else{Sb=fe(Kb|0)|0}Kb=L+Sb|0;Ob=Jb<<3;Pb=J+(Ob-4)|0;Tb=J+Ob|0;Ob=d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0;if((d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)==1){Ub=Ob;Vb=Kb;break}Ub=fe(Ob|0)|0;Vb=Kb}else{Kb=c[(c[Y>>2]|0)+(Jb<<2)>>2]|0;Ub=Kb;Vb=L+Kb|0}}while(0);Lb=K-Ub<<3;Kb=Lb>>>0>2147483639>>>0|(Vb|0)==0;Ob=Kb?0:Vb;Pb=Kb?0:Lb;c[E>>2]=Ob;c[B>>2]=Pb;c[A>>2]=Pb+8;c[G>>2]=Ob+(Pb>>3);c[D>>2]=0;if((ze[c[j>>2]&511](u,q,p)|0)>=0){c[Z>>2]=c[C>>2];Wb=Ib;break}Pb=Hb+2|0;if((Pb|0)>=(I|0)){Wb=K-Mb|0;break}do{if((c[g>>2]|0)==0){Ob=Pb<<3;Lb=J+(Ob-4)|0;Kb=J+Ob|0;Ob=d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0;if((d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)==1){Xb=Ob;break}Xb=fe(Ob|0)|0}else{Xb=c[(c[Y>>2]|0)+(Pb<<2)>>2]|0}}while(0);Wb=Xb-Mb|0}else{Wb=Ib}}while(0);if((Wb|0)<0|(Wb|0)>(K-Mb|0)){Q=98;break}Ib=c[Z>>2]|0;Pb=L+Mb|0;Ob=Wb<<3;Lb=Ob>>>0>2147483639>>>0|(Pb|0)==0;Kb=Lb?0:Pb;Pb=Lb?0:Ob;c[E>>2]=Kb;c[B>>2]=Pb;c[A>>2]=Pb+8;c[G>>2]=Kb+(Pb>>3);c[D>>2]=0;if((ze[c[j>>2]&511](u,q,$)|0)<0){Q=100;break}Pb=c[ea>>2]|0;if((((Pb|0)==0?1:Pb)|0)!=(c[U>>2]|0)){Q=102;break}if((c[S>>2]|0)!=(c[da>>2]|0)){Q=105;break}if((c[ia>>2]|0)!=(c[ha>>2]|0)){Q=105;break}c[Z>>2]=Ib;c[ga>>2]=c[fa>>2];Pb=c[_>>2]|0;c[F>>2]=Ib-Pb;c[ja>>2]=0;Ib=(ba(c[aa>>2]|0,c[ca>>2]|0)|0)+(c[T>>2]|0)|0;if((Pb|0)!=(Ib|0)){yDb(c[X>>2]|0,16,1893136,(R=i,i=i+16|0,c[R>>2]=Pb,c[R+8>>2]=Ib,R)|0);i=R;Ib=c[_>>2]|0;Pb=c[aa>>2]|0;c[T>>2]=(Ib|0)%(Pb|0)|0;c[ca>>2]=(Ib|0)/(Pb|0)|0}TGb(c[ka>>2]|0,-1|0,c[la>>2]<<3|0)|0;c[ma>>2]=1;c[na>>2]=c[T>>2];c[oa>>2]=c[ca>>2];$Oa(v);Pb=c[ca>>2]|0;b:do{if((Pb|0)<(c[V>>2]|0)){Ib=Pb;Kb=c[F>>2]|0;while(1){if((Kb|0)==0){Yb=Ib;break b}do{if((c[ja>>2]|0)<=1){Ob=c[D>>2]|0;Lb=(c[B>>2]|0)-Ob|0;if((Lb|0)<1){Yb=Ib;break b}if((Lb|0)>=8){break}Tb=(c[E>>2]|0)+(Ob>>>3)|0;if(((fe(d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0)|0)<<(Ob&7)>>>((32-Lb|0)>>>0)|0)==0){Yb=Ib;break b}}}while(0);Lb=c[X>>2]|0;Ob=8>>>((c[Lb+800>>2]|0)>>>0);c[pa>>2]=(c[pa>>2]|0)+2;c[qa>>2]=(c[qa>>2]|0)+2;c[ra>>2]=(c[ra>>2]|0)+2;c[sa>>2]=(c[sa>>2]|0)+2;c[ta>>2]=(c[ta>>2]|0)+1;c[ua>>2]=(c[ua>>2]|0)+1;Tb=(c[va>>2]|0)+(Ob<<1)|0;c[va>>2]=Tb;c[wa>>2]=(c[wa>>2]|0)+Ob;c[xa>>2]=(c[xa>>2]|0)+Ob;Ob=c[ya>>2]|0;Zb=c[T>>2]|0;_b=(Zb<<2)+4|0;$b=Ob+_b|0;do{if((c[ea>>2]|0)==0){ac=c[za>>2]|0;bc=(ba(ac,Ib)|0)+Zb|0;TGb(Aa|0,0,48)|0;c[Ba>>2]=1;c[Ca>>2]=1;c[Da>>2]=1;c[Ea>>2]=1;cc=c[aa>>2]|0;dc=(ba(Ib-(c[oa>>2]|0)|0,cc)|0)+(Zb-(c[na>>2]|0))|0;ec=(Zb|0)==0;if(!(ec|(dc|0)==0)){fc=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc-1<<2)>>2]|0;c[Va>>2]=fc;c[Wa>>2]=fc}if((dc|0)>=(cc|0)){fc=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc-ac<<2)>>2]|0;c[Ta>>2]=fc;c[Ua>>2]=fc}if(!((Zb+1|0)>=(cc|0)|(dc|0)<(cc-1|0))){c[Sa>>2]=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(1-ac+bc<<2)>>2]}if((dc|0)>(cc|0)&(ec^1)){c[Ga>>2]=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc+~ac<<2)>>2]}c[ga>>2]=c[fa>>2];ac=c[D>>2]|0;ec=c[E>>2]|0;cc=d[ec+(ac>>>3)|0]<<(ac&7)>>>7;dc=c[A>>2]|0;fc=((ac|0)<(dc|0))+ac|0;c[D>>2]=fc;ac=cc&1;c[Ha>>2]=ac;if((ac|0)==0){do{if((c[Ia>>2]|0)==0){ac=d[ec+(fc>>>3)|0]|0;c[D>>2]=((fc|0)<(dc|0))+fc;if((ac&128>>>((fc&7)>>>0)|0)!=0){break}yDb(Lb,16,2350752,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R}}while(0);c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc<<2)>>2]=1;c[Ja>>2]=0;if((ze[c[Ka>>2]&511](u,q,$b)|0)<0){gc=-1}else{hc=1;Q=304}}else{c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc<<2)>>2]=2;c[Ja>>2]=1;fc=c[D>>2]|0;dc=c[A>>2]|0;ac=ec+(fc>>>3)|0;cc=(fe(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(fc&7)>>>30;ac=fc+2|0;c[D>>2]=dc>>>0>ac>>>0?ac:dc;dc=c[la>>2]|0;ac=ba(cc,16843009)|0;c[$b>>2]=ac;c[Ob+(dc+_b)>>2]=ac;c[Ob+((dc<<1)+_b)>>2]=ac;c[Ob+((dc*3|0)+_b)>>2]=ac;hc=2;Q=304}if((Q|0)==304){Q=0;c[La>>2]=hc;c[Pa>>2]=0;ac=c[fa>>2]|0;dc=c[Qa>>2]|0;if((dc|0)==2&(ac|0)<19){ic=ac+10|0}else{ic=(dc|0)!=0&(ac|0)<26?ac+5|0:ac}if((ic|0)<0){jc=0}else{jc=(ic|0)>30?30:ic}ac=5082160+((d[533968+jc|0]|0)*380|0)|0;c[Ra>>2]=ac;gc=vVa(q,ac,c[Ha>>2]|0)|0}b[(c[Ma>>2]|0)+(bc<<1)>>1]=gc;a[(c[Na>>2]|0)+bc|0]=gc>>>16;b[(c[Oa>>2]|0)+(bc<<1)>>1]=-1;a[(c[(c[Fa>>2]|0)+1512>>2]|0)+bc|0]=c[ga>>2];if((gc|0)==-1){Q=314;break a}if((c[Ha>>2]|0)==0){sVa(u,$b,gc);break}else{rVa(u,$b,gc);break}}else{ac=c[Za>>2]|0;dc=c[za>>2]|0;cc=(ba(dc,Ib)|0)+Zb|0;TGb(Aa|0,0,48)|0;c[Ba>>2]=1;c[Ca>>2]=1;c[Da>>2]=1;c[Ea>>2]=1;fc=c[aa>>2]|0;kc=(ba(Ib-(c[oa>>2]|0)|0,fc)|0)+(Zb-(c[na>>2]|0))|0;lc=(Zb|0)==0;if(!(lc|(kc|0)==0)){mc=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc-1<<2)>>2]|0;c[Va>>2]=mc;c[Wa>>2]=mc}if((kc|0)>=(fc|0)){mc=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc-dc<<2)>>2]|0;c[Ta>>2]=mc;c[Ua>>2]=mc}if(!((Zb+1|0)>=(fc|0)|(kc|0)<(fc-1|0))){c[Sa>>2]=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(1-dc+cc<<2)>>2]}if((kc|0)>(fc|0)&(lc^1)){c[Ga>>2]=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc+~dc<<2)>>2]}c[ga>>2]=c[fa>>2];dc=re[c[_a>>2]&4095](u)|0;c[Ja>>2]=dc;c:do{if((dc|0)==-1){nc=-1}else{lc=(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc<<2)|0;c[lc>>2]=c[534096+(dc<<2)>>2];fc=(c[ib>>2]|0)+(cc<<2)|0;c[fc>>2]=c[Ja>>2];do{if((c[Ja>>2]|0)==6){kc=c[U>>2]|0;if((kc|0)==2){c[fc>>2]=2;oc=c[U>>2]|0}else{oc=kc}if((oc|0)!=3){break}c[fc>>2]=7}}while(0);c[Ha>>2]=(c[lc>>2]|0)>>>1&1;fc=c[Ja>>2]|0;kc=c[T>>2]|0;mc=ba(c[$a>>2]|0,c[ca>>2]|0)|0;TGb(jb|0,0,32)|0;if((3900>>>(fc>>>0)&1|0)!=0){pc=c[630032+(fc<<2)>>2]|0;qc=0;rc=c[D>>2]|0;sc=c[A>>2]|0;tc=c[E>>2]|0;while(1){uc=tc+(rc>>>3)|0;vc=(fe(d[uc]|d[uc+1|0]<<8|d[uc+2|0]<<16|d[uc+3|0]<<24|0)|0)<<(rc&7);do{if((vc&-1434451968|0)==0){uc=rc+8|0;wc=sc>>>0>uc>>>0?uc:sc;uc=tc+(wc>>>3)|0;xc=(fe(d[uc]|d[uc+1|0]<<8|d[uc+2|0]<<16|d[uc+3|0]<<24|0)|0)<<(wc&7)>>>8|vc;uc=xc|1;if((xc&-1431655766|0)==0){yc=-2147483648;break}if((uc|0)>-1){xc=uc;zc=31;while(1){Ac=zc-1|0;Bc=(xc>>>30|xc<<2)-(xc<<zc>>>(Ac>>>0))|0;if((Bc|0)>-1){xc=Bc;zc=Ac}else{Cc=Bc;Dc=Ac;break}}}else{Cc=uc;Dc=31}zc=wc+55-(Dc<<1)|0;c[D>>2]=sc>>>0>zc>>>0?zc:sc;yc=((Cc<<Dc>>>(Dc>>>0))-1^-(Cc&1))+1>>1}else{zc=vc>>>24;xc=(d[1201432+zc|0]|0)+rc|0;c[D>>2]=sc>>>0>xc>>>0?xc:sc;yc=a[1201176+zc|0]|0}}while(0);c[u+15568+(qc<<3)>>2]=yc;vc=c[D>>2]|0;zc=c[A>>2]|0;xc=c[E>>2]|0;Ac=xc+(vc>>>3)|0;Bc=(fe(d[Ac]|d[Ac+1|0]<<8|d[Ac+2|0]<<16|d[Ac+3|0]<<24|0)|0)<<(vc&7);do{if((Bc&-1434451968|0)==0){Ac=vc+8|0;Ec=zc>>>0>Ac>>>0?Ac:zc;Ac=xc+(Ec>>>3)|0;Fc=(fe(d[Ac]|d[Ac+1|0]<<8|d[Ac+2|0]<<16|d[Ac+3|0]<<24|0)|0)<<(Ec&7)>>>8|Bc;Ac=Fc|1;if((Fc&-1431655766|0)==0){Gc=-2147483648;Hc=vc;break}if((Ac|0)>-1){Fc=Ac;Ic=31;while(1){Jc=Ic-1|0;Kc=(Fc>>>30|Fc<<2)-(Fc<<Ic>>>(Jc>>>0))|0;if((Kc|0)>-1){Fc=Kc;Ic=Jc}else{Lc=Kc;Mc=Jc;break}}}else{Lc=Ac;Mc=31}Ic=Ec+55-(Mc<<1)|0;Fc=zc>>>0>Ic>>>0?Ic:zc;c[D>>2]=Fc;Gc=((Lc<<Mc>>>(Mc>>>0))-1^-(Lc&1))+1>>1;Hc=Fc}else{Fc=Bc>>>24;Ic=(d[1201432+Fc|0]|0)+vc|0;wc=zc>>>0>Ic>>>0?Ic:zc;c[D>>2]=wc;Gc=a[1201176+Fc|0]|0;Hc=wc}}while(0);c[u+15568+(qc<<3)+4>>2]=Gc;vc=qc+1|0;if((vc|0)<(pc|0)){qc=vc;rc=Hc;sc=zc;tc=xc}else{break}}}d:do{switch(fc|0){case 3:{xVa(u,3,0,0);zVa(u,3,0,0,0,1,1,0,c[Ia>>2]|0,0,lb,nb);xVa(u,3,1,1);zVa(u,3,8,0,1,1,1,0,c[Ia>>2]|0,0,lb,nb);xVa(u,3,2,2);zVa(u,3,0,8,c[$a>>2]|0,1,1,0,c[Ia>>2]|0,0,lb,nb);xVa(u,3,3,3);zVa(u,3,8,8,(c[$a>>2]|0)+1|0,1,1,0,c[Ia>>2]|0,0,lb,nb);break};case 0:case 1:{tc=c[$a>>2]|0;sc=(ba(c[ca>>2]<<1,tc)|0)+(c[T>>2]<<1)|0;rc=c[(c[Fa>>2]|0)+1524>>2]|0;qc=rc+(sc<<2)|0;pc=qc;lc=tc<<2;c[qc>>2]=0;c[pc+lc>>2]=0;c[rc+(sc<<2)+4>>2]=0;c[pc+(lc+4)>>2]=0;break};case 6:{if((c[U>>2]|0)!=2){Q=150;break d}lc=c[$a>>2]|0;pc=(ba(c[ca>>2]<<1,lc)|0)+(c[T>>2]<<1)|0;sc=c[(c[Fa>>2]|0)+1524>>2]|0;rc=sc+(pc<<2)|0;qc=rc;tc=lc<<2;c[rc>>2]=0;c[qc+tc>>2]=0;c[sc+(pc<<2)+4>>2]=0;c[qc+(tc+4)>>2]=0;zVa(u,6,0,0,0,2,2,0,c[Ia>>2]|0,0,lb,nb);break};case 7:{Q=150;break};case 10:{yVa(u,10,0);yVa(u,10,1);wVa(u,10);break};case 2:case 11:{xVa(u,fc,0,0);zVa(u,fc,0,0,0,2,2,0,c[Ia>>2]|0,0,lb,nb);break};case 8:case 9:{xVa(u,fc,0,0);tc=(fc|0)==8;xVa(u,fc,tc?2:1,1);qc=c[Ia>>2]|0;if(tc){zVa(u,8,0,0,0,2,1,0,qc,0,lb,nb);zVa(u,8,0,8,c[$a>>2]|0,2,1,0,c[Ia>>2]|0,0,lb,nb);break d}else{zVa(u,fc,0,0,0,1,2,0,qc,0,lb,nb);zVa(u,fc,8,0,1,1,2,0,c[Ia>>2]|0,0,lb,nb);break d}break};case 4:case 5:{qc=c[Cb>>2]|0;c[Db>>2]=qc;tc=c[Eb>>2]|0;c[Fb>>2]=tc;pc=c[Ia>>2]|0;sc=(fc|0)==5|0;if((pc|0)==0){yVa(u,fc,sc);Nc=c[Ia>>2]|0}else{rc=c[$a>>2]|0;lc=(ba(c[ca>>2]<<1,rc)|0)+(c[T>>2]<<1)|0;vc=(c[Wa>>2]|0)==0;if(vc){Oc=0;Pc=0}else{Bc=lc-1|0;wc=c[(c[Fa>>2]|0)+1524>>2]|0;Oc=b[wc+(Bc<<2)+2>>1]|0;Pc=b[wc+(Bc<<2)>>1]|0}Bc=(c[Ua>>2]|0)==0;if(Bc){Qc=Pc;Rc=Oc}else{wc=lc-rc|0;Fc=c[(c[Fa>>2]|0)+1524>>2]|0;Qc=b[Fc+(wc<<2)>>1]|0;Rc=b[Fc+(wc<<2)+2>>1]|0}do{if((c[Sa>>2]|0)==0){if(Bc|vc){Sc=Pc;Tc=Oc;break}wc=lc-rc-1|0;Fc=c[(c[Fa>>2]|0)+1524>>2]|0;Sc=b[Fc+(wc<<2)>>1]|0;Tc=b[Fc+(wc<<2)+2>>1]|0}else{wc=lc-rc+2|0;Fc=c[(c[Fa>>2]|0)+1524>>2]|0;Sc=b[Fc+(wc<<2)>>1]|0;Tc=b[Fc+(wc<<2)+2>>1]|0}}while(0);do{if((Pc|0)>(Qc|0)){if((Sc|0)<=(Qc|0)){Uc=Qc;break}Uc=(Sc|0)>(Pc|0)?Pc:Sc}else{if((Qc|0)<=(Sc|0)){Uc=Qc;break}Uc=(Sc|0)>(Pc|0)?Sc:Pc}}while(0);do{if((Oc|0)>(Rc|0)){if((Tc|0)<=(Rc|0)){Vc=Rc;break}Vc=(Tc|0)>(Oc|0)?Oc:Tc}else{if((Rc|0)<=(Tc|0)){Vc=Rc;break}Vc=(Tc|0)>(Oc|0)?Tc:Oc}}while(0);vc=Uc+qc&65535;Bc=c[Fa>>2]|0;xc=Vc+tc&65535;zc=c[Bc+1524>>2]|0;b[zc+(lc<<2)>>1]=vc;b[zc+(lc<<2)+2>>1]=xc;wc=c[Bc+1528>>2]|0;b[wc+(lc<<2)>>1]=vc;b[wc+(lc<<2)+2>>1]=xc;Bc=lc|1;b[zc+(Bc<<2)>>1]=vc;b[zc+(Bc<<2)+2>>1]=xc;b[wc+(Bc<<2)>>1]=vc;b[wc+(Bc<<2)+2>>1]=xc;Fc=lc+rc|0;b[zc+(Fc<<2)>>1]=vc;b[zc+(Fc<<2)+2>>1]=xc;b[wc+(Fc<<2)>>1]=vc;b[wc+(Fc<<2)+2>>1]=xc;Fc=Bc+rc|0;b[zc+(Fc<<2)>>1]=vc;b[zc+(Fc<<2)+2>>1]=xc;b[wc+(Fc<<2)>>1]=vc;b[wc+(Fc<<2)+2>>1]=xc;Nc=pc}zVa(u,fc,0,0,0,2,2,sc,Nc,0,lb,nb);break};default:{}}}while(0);if((Q|0)==150){Q=0;xc=c[T>>2]|0;Fc=c[ca>>2]|0;wc=(ba(c[za>>2]|0,Fc)|0)+xc|0;vc=c[ob>>2]|0;zc=c[(c[vc+1536>>2]|0)+(wc<<2)>>2]|0;if((zc&2055|0)==0){wc=mc+kc<<1;Bc=c[$a>>2]|0;Ic=c[vc+1524>>2]|0;vc=c[Fa>>2]|0;uc=c[pb>>2]|0;Jc=c[vc+1524>>2]|0;Kc=c[qb>>2]|0;Wc=c[vc+1528>>2]|0;vc=wc|1;Xc=Ic+(wc<<2)|0;b[Jc+(wc<<2)>>1]=((ba(b[Xc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(wc<<2)>>1]=(8192-(ba(b[Xc>>1]|0,Kc)|0)|0)>>>14;Xc=Ic+(wc<<2)+2|0;b[Jc+(wc<<2)+2>>1]=((ba(b[Xc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(wc<<2)+2>>1]=(8192-(ba(b[Xc>>1]|0,Kc)|0)|0)>>>14;Xc=Ic+(vc<<2)|0;b[Jc+(vc<<2)>>1]=((ba(b[Xc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(vc<<2)>>1]=(8192-(ba(b[Xc>>1]|0,Kc)|0)|0)>>>14;Xc=Ic+(vc<<2)+2|0;b[Jc+(vc<<2)+2>>1]=((ba(b[Xc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(vc<<2)+2>>1]=(8192-(ba(b[Xc>>1]|0,Kc)|0)|0)>>>14;Xc=Bc+wc|0;wc=Ic+(Xc<<2)|0;b[Jc+(Xc<<2)>>1]=((ba(b[wc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(Xc<<2)>>1]=(8192-(ba(b[wc>>1]|0,Kc)|0)|0)>>>14;wc=Ic+(Xc<<2)+2|0;b[Jc+(Xc<<2)+2>>1]=((ba(b[wc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(Xc<<2)+2>>1]=(8192-(ba(b[wc>>1]|0,Kc)|0)|0)>>>14;wc=Bc+vc|0;vc=Ic+(wc<<2)|0;b[Jc+(wc<<2)>>1]=((ba(b[vc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(wc<<2)>>1]=(8192-(ba(b[vc>>1]|0,Kc)|0)|0)>>>14;vc=Ic+(wc<<2)+2|0;b[Jc+(wc<<2)+2>>1]=((ba(b[vc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(wc<<2)+2>>1]=(8192-(ba(b[vc>>1]|0,Kc)|0)|0)>>>14}else{Kc=c[$a>>2]|0;vc=(ba(Fc<<1,Kc)|0)+(xc<<1)|0;xc=c[Fa>>2]|0;Fc=c[xc+1524>>2]|0;wc=Fc+(vc<<2)|0;Wc=wc;uc=Kc<<2;c[wc>>2]=0;c[Wc+uc>>2]=0;c[Fc+(vc<<2)+4>>2]=0;c[Wc+(uc+4)>>2]=0;uc=c[$a>>2]|0;Wc=(ba(c[ca>>2]<<1,uc)|0)+(c[T>>2]<<1)|0;vc=c[xc+1528>>2]|0;xc=vc+(Wc<<2)|0;Fc=xc;wc=uc<<2;c[xc>>2]=0;c[Fc+wc>>2]=0;c[vc+(Wc<<2)+4>>2]=0;c[Fc+(wc+4)>>2]=0}do{if((zc&112|0)==0){wVa(u,fc)}else{wc=c[Ia>>2]|0;if((wc|0)==0){Yc=(c[rb>>2]|0)!=8192}else{Yc=0}Fc=Yc&1;Wc=Yc?kb:sb;vc=Yc?mb:tb;zVa(u,3,0,0,0,1,1,0,wc,Fc,lb,nb);zVa(u,3,0,0,0,1,1,1,c[Ia>>2]|0,Fc,Wc,vc);zVa(u,3,8,0,1,1,1,0,c[Ia>>2]|0,Fc,lb,nb);zVa(u,3,8,0,1,1,1,1,c[Ia>>2]|0,Fc,Wc,vc);zVa(u,3,0,8,c[$a>>2]|0,1,1,0,c[Ia>>2]|0,Fc,lb,nb);zVa(u,3,0,8,c[$a>>2]|0,1,1,1,c[Ia>>2]|0,Fc,Wc,vc);zVa(u,3,8,8,(c[$a>>2]|0)+1|0,1,1,0,c[Ia>>2]|0,Fc,lb,nb);zVa(u,3,8,8,(c[$a>>2]|0)+1|0,1,1,1,c[Ia>>2]|0,Fc,Wc,vc);if(!Yc){break}Se[c[u+15208+(c[ub>>2]<<3)>>2]&511](c[va>>2]|0,c[vb>>2]|0,c[wb>>2]|0,c[rb>>2]|0,c[xb>>2]|0,c[eb>>2]|0);Se[c[u+15208+(c[ub>>2]<<3)+4>>2]&511](c[wa>>2]|0,c[yb>>2]|0,c[zb>>2]|0,c[rb>>2]|0,c[xb>>2]|0,c[hb>>2]|0);Se[c[u+15208+(c[ub>>2]<<3)+4>>2]&511](c[xa>>2]|0,c[Ab>>2]|0,c[Bb>>2]|0,c[rb>>2]|0,c[xb>>2]|0,c[hb>>2]|0)}}while(0);fc=c[$a>>2]|0;zc=(ba(c[ca>>2]<<1,fc)|0)+(c[T>>2]<<1)|0;kc=c[(c[Fa>>2]|0)+1524>>2]|0;mc=kc+(zc<<2)|0;vc=mc;Wc=fc<<2;c[mc>>2]=0;c[vc+Wc>>2]=0;c[kc+(zc<<2)+4>>2]=0;c[vc+(Wc+4)>>2]=0}if((c[Ja>>2]|0)==6){Wc=c[la>>2]|0;c[$b>>2]=0;c[Ob+(Wc+_b)>>2]=0;c[Ob+((Wc<<1)+_b)>>2]=0;c[Ob+((Wc*3|0)+_b)>>2]=0;nc=0;break}c[Pa>>2]=1;c[La>>2]=0;do{if((c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc<<2)>>2]&7|0)==0){Wc=0;do{a[Ob+((Wc&3|_b)+(ba(c[la>>2]|0,Wc>>2)|0))|0]=0;Wc=Wc+1|0;}while((Wc|0)<16);Wc=c[fa>>2]|0;sc=c[Qa>>2]|0;pc=(sc|0)==2&(Wc|0)<19;if(pc){Zc=Wc+10|0}else{Zc=(sc|0)!=0&(Wc|0)<26?Wc+5|0:Wc}if((Zc|0)<0){_c=0}else{_c=(Zc|0)>30?30:Zc}rc=5084080+((d[533999+_c|0]|0)*380|0)|0;c[Ra>>2]=rc;if((c[(c[ib>>2]|0)+(cc<<2)>>2]|0)!=11){$c=rc;break}c[Ha>>2]=1;c[Pa>>2]=1;c[La>>2]=2;if(pc){ad=Wc+10|0}else{ad=(sc|0)!=0&(Wc|0)<26?Wc+5|0:Wc}if((ad|0)<0){bd=0}else{bd=(ad|0)>30?30:ad}Wc=5082160+((d[533968+bd|0]|0)*380|0)|0;c[Ra>>2]=Wc;$c=Wc}else{if((c[Ha>>2]|0)==0){if((ze[c[Ka>>2]&511](u,q,$b)|0)<0){nc=-1;break c}else{cd=1}}else{Wc=c[D>>2]|0;sc=c[A>>2]|0;pc=(c[E>>2]|0)+(Wc>>>3)|0;rc=(fe(d[pc]|d[pc+1|0]<<8|d[pc+2|0]<<16|d[pc+3|0]<<24|0)|0)<<(Wc&7)>>>30;pc=Wc+2|0;c[D>>2]=sc>>>0>pc>>>0?pc:sc;sc=c[la>>2]|0;pc=ba(rc,16843009)|0;c[$b>>2]=pc;c[Ob+(sc+_b)>>2]=pc;c[Ob+((sc<<1)+_b)>>2]=pc;c[Ob+((sc*3|0)+_b)>>2]=pc;cd=2}c[La>>2]=cd;c[Pa>>2]=0;pc=c[fa>>2]|0;sc=c[Qa>>2]|0;if((sc|0)==2&(pc|0)<19){dd=pc+10|0}else{dd=(sc|0)!=0&(pc|0)<26?pc+5|0:pc}if((dd|0)<0){ed=0}else{ed=(dd|0)>30?30:dd}pc=5082160+((d[533968+ed|0]|0)*380|0)|0;c[Ra>>2]=pc;$c=pc}}while(0);nc=vVa(q,$c,c[Ha>>2]|0)|0}}while(0);b[(c[Ma>>2]|0)+(cc<<1)>>1]=nc;a[(c[Na>>2]|0)+cc|0]=nc>>>16;dc=c[T>>2]|0;bc=c[ca>>2]|0;ec=c[$a>>2]|0;pc=(ba(ec,bc)|0)+dc<<1;sc=c[Fa>>2]|0;rc=1-ec|0;Wc=-ec|0;lc=0;tc=0;qc=0;vc=(c[sc+1524>>2]|0)+(pc<<2)|0;pc=bc;zc=bc;while(1){kc=b[vc>>1]|0;mc=kc+3|0;fc=(mc-(b[vc-4>>1]|0)|0)>>>0>6>>>0;do{if((tc|0)==0){if(fc){Q=218}else{if(((b[vc+2>>1]|0)+3-(b[vc-4+2>>1]|0)|0)>>>0>6>>>0){Q=218}else{fd=lc}}if((Q|0)==218){Q=0;fd=lc|17}do{if((pc|0)==0){gd=qc}else{if(!((mc-(b[vc+(Wc<<2)>>1]|0)|0)>>>0>6>>>0)){if(!(((b[vc+2>>1]|0)+3-(b[vc+(Wc<<2)+2>>1]|0)|0)>>>0>6>>>0)){gd=qc;break}}gd=qc|3}}while(0);Fc=(b[vc+4>>1]|0)+3|0;if((Fc-kc|0)>>>0>6>>>0){Q=242}else{if(((b[vc+6>>1]|0)+3-(b[vc+2>>1]|0)|0)>>>0>6>>>0){Q=242}else{hd=fd}}if((Q|0)==242){Q=0;hd=fd|68}if((zc|0)==0){id=hd;jd=gd;kd=0;ld=0;break}if(!((Fc-(b[vc+(rc<<2)>>1]|0)|0)>>>0>6>>>0)){if(!(((b[vc+6>>1]|0)+3-(b[vc+(rc<<2)+2>>1]|0)|0)>>>0>6>>>0)){id=hd;jd=gd;kd=zc;ld=zc;break}}id=hd;jd=gd|12;kd=zc;ld=zc}else{if(fc){Q=225}else{if(((b[vc+2>>1]|0)+3-(b[vc-4+2>>1]|0)|0)>>>0>6>>>0){Q=225}else{md=lc}}if((Q|0)==225){Q=0;md=17<<tc|lc}if((mc-(b[vc+(Wc<<2)>>1]|0)|0)>>>0>6>>>0){Q=228}else{if(((b[vc+2>>1]|0)+3-(b[vc+(Wc<<2)+2>>1]|0)|0)>>>0>6>>>0){Q=228}else{nd=qc}}if((Q|0)==228){Q=0;nd=3<<tc|qc}Fc=(b[vc+4>>1]|0)+3|0;if((Fc-kc|0)>>>0>6>>>0){Q=237}else{if(((b[vc+6>>1]|0)+3-(b[vc+2>>1]|0)|0)>>>0>6>>>0){Q=237}else{od=md}}if((Q|0)==237){Q=0;od=md|17<<(tc|2)}if(!((Fc-(b[vc+(rc<<2)>>1]|0)|0)>>>0>6>>>0)){if(!(((b[vc+6>>1]|0)+3-(b[vc+(rc<<2)+2>>1]|0)|0)>>>0>6>>>0)){id=od;jd=nd;kd=pc;ld=zc;break}}id=od;jd=nd|3<<(tc|2);kd=pc;ld=zc}}while(0);kc=tc+8|0;if((kc|0)<16){lc=id;tc=kc;qc=jd;vc=vc+(ec<<2)|0;pc=kd;zc=ld}else{break}}zc=(c[ma>>2]|0)==0;pc=zc?jd:jd&-16;ec=(dc|0)==0;vc=ec?id&-4370:id;do{if((c[Ia>>2]|0)==0){pd=pc;qd=vc}else{qc=vc>>>1&8738|vc;tc=pc>>>4&240|pc;if(!ec){lc=dc-1+(ba(c[za>>2]|0,bc)|0)|0;rc=(c[Oa>>2]|0)+(lc<<1)|0;b[rc>>1]=e[rc>>1]|vc<<3&34952}if(!zc){pd=tc;qd=qc;break}rc=(ba(c[za>>2]|0,bc-1|0)|0)+dc|0;lc=(c[Oa>>2]|0)+(rc<<1)|0;b[lc>>1]=e[lc>>1]|pc<<12;pd=tc;qd=qc}}while(0);b[(c[Oa>>2]|0)+(cc<<1)>>1]=pd|qd|e[(c[Ma>>2]|0)+(cc<<1)>>1];a[(c[sc+1512>>2]|0)+cc|0]=c[ga>>2];if((nc|0)==-1){Q=314;break a}pc=(c[Ha>>2]|0)!=0;if((c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc<<2)>>2]&7|0)!=0){if(pc){rVa(u,$b,nc);break}else{sVa(u,$b,nc);break}}if(pc){TGb(Ya|0,0,32)|0;pc=c[ga>>2]|0;dc=e[534032+(d[(c[bb>>2]|0)+pc|0]<<1)>>1]|0;if((tVa(ab,q,c[Ra>>2]|0,3,0,dc,dc,e[534032+(pc<<1)>>1]|0)|0)==0){me[c[cb>>2]&511](ab)}else{me[c[gb>>2]&511](ab)}pc=e[534032+(c[ga>>2]<<1)>>1]|0;dc=0;bc=nc;zc=Tb;while(1){vc=dc<<2;ec=0;rd=bc;do{qc=b[l+(ec+vc<<1)>>1]|0;tc=qc<<16>>16;do{if((rd&1|0)==0){Q=261}else{if((tVa(ac,q,c[Ra>>2]|0,c[La>>2]|0,0,pc,pc,pc)|0)==0){Q=261;break}b[ac>>1]=qc;Xe[c[fb>>2]&4095](zc+(ec<<2)|0,c[eb>>2]|0,ac)}}while(0);if((Q|0)==261){Q=0;Xe[c[db>>2]&4095](zc+(ec<<2)|0,c[eb>>2]|0,tc)}ec=ec+1|0;rd=rd>>1;}while((ec|0)<4);ec=dc+1|0;if((ec|0)<4){dc=ec;bc=rd;zc=zc+(c[eb>>2]<<2)|0}else{break}}zc=c[fa>>2]|0;bc=c[Qa>>2]|0;if((bc|0)==2&(zc|0)<19){sd=zc+10|0}else{sd=(bc|0)!=0&(zc|0)<26?zc+5|0:zc}if((sd|0)<0){td=0}else{td=(sd|0)>30?30:sd}c[Ra>>2]=5084080+((d[533999+td|0]|0)*380|0);ud=rd}else{zc=e[534032+(c[ga>>2]<<1)>>1]|0;bc=0;dc=nc;ac=Tb;while(1){pc=0;cc=dc;do{do{if((cc&1|0)!=0){sc=ac+(pc<<2)|0;ec=c[eb>>2]|0;vc=c[Za>>2]|0;if((tVa(vc,q,c[Ra>>2]|0,c[La>>2]|0,0,zc,zc,zc)|0)==0){Xe[c[db>>2]&4095](sc,ec,b[vc>>1]|0);b[vc>>1]=0;break}else{Xe[c[fb>>2]&4095](sc,ec,vc);break}}}while(0);pc=pc+1|0;cc=cc>>1;}while((pc|0)<4);pc=bc+1|0;if((pc|0)<4){bc=pc;dc=cc;ac=ac+(c[eb>>2]<<2)|0}else{ud=cc;break}}}ac=c[ga>>2]|0;dc=e[534032+(d[544136+ac|0]<<1)>>1]|0;bc=e[534032+(d[544104+ac|0]<<1)>>1]|0;ac=c[wa>>2]|0;zc=0;pc=ud;do{do{if((pc&1|0)!=0){tc=c[hb>>2]|0;vc=ac+((ba(tc,zc<<1&4)|0)+(zc<<2&4))|0;ec=c[Za>>2]|0;if((tVa(ec,q,c[Ra>>2]|0,c[Pa>>2]|0,1,dc,bc,bc)|0)==0){Xe[c[db>>2]&4095](vc,tc,b[ec>>1]|0);b[ec>>1]=0;break}else{Xe[c[fb>>2]&4095](vc,tc,ec);break}}}while(0);zc=zc+1|0;pc=pc>>1;}while((zc|0)<4);zc=c[xa>>2]|0;ac=0;cc=pc;while(1){do{if((cc&1|0)!=0){ec=c[hb>>2]|0;tc=zc+((ba(ec,ac<<1&4)|0)+(ac<<2&4))|0;vc=c[Za>>2]|0;if((tVa(vc,q,c[Ra>>2]|0,c[Pa>>2]|0,1,dc,bc,bc)|0)==0){Xe[c[db>>2]&4095](tc,ec,b[vc>>1]|0);b[vc>>1]=0;break}else{Xe[c[fb>>2]&4095](tc,ec,vc);break}}}while(0);vc=ac+1|0;if((vc|0)<4){ac=vc;cc=cc>>1}else{break}}}}while(0);Tb=(c[T>>2]|0)+1|0;c[T>>2]=Tb;do{if((Tb|0)==(c[aa>>2]|0)){c[T>>2]=0;c[ca>>2]=(c[ca>>2]|0)+1;$Oa(v);VGb(c[ka>>2]|0,c[ya>>2]|0,c[la>>2]<<2|0)|0;TGb(c[ya>>2]|0,-1|0,c[la>>2]<<2|0)|0;$b=c[Xa>>2]|0;if(($b|0)==0){break}_b=c[ca>>2]|0;if((_b|0)<=1){break}ne[$b&1023](u,_b-2|0)}}while(0);if((c[T>>2]|0)==(c[na>>2]|0)){c[ma>>2]=0}Tb=(c[F>>2]|0)-1|0;c[F>>2]=Tb;_b=c[ca>>2]|0;if((_b|0)<(c[V>>2]|0)){Ib=_b;Kb=Tb}else{Yb=_b;break}}}else{Yb=Pb}}while(0);Lkb(Gb,c[na>>2]|0,c[oa>>2]|0,(c[T>>2]|0)-1|0,Yb,112);if((c[ca>>2]|0)==(c[V>>2]|0)){Q=323;break}else{Hb=Jb}}if((Q|0)==69){yDb(f,16,2222832,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R}else if((Q|0)==81){yDb(f,16,2222832,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R}else if((Q|0)==98){yDb(f,16,2002896,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R}else if((Q|0)==100){yDb(c[X>>2]|0,16,1965480,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;Q=323}else if((Q|0)==102){yDb(c[X>>2]|0,16,1937408,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;Q=323}else if((Q|0)==105){yDb(c[X>>2]|0,16,1913576,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;Q=323}else if((Q|0)==314){Lkb(Gb,c[na>>2]|0,c[oa>>2]|0,(c[T>>2]|0)-1|0,c[ca>>2]|0,14);Q=323}do{if((Q|0)==323){if((c[Fa>>2]|0)==0){break}Hb=c[Xa>>2]|0;if((Hb|0)!=0){ne[Hb&1023](u,(c[V>>2]|0)-1|0)}Hb=c[s>>2]|0;F=Hb;Mkb(Hb+14424|0);SOa(F);c[Hb+13732>>2]=0;do{if((c[Hb+9992>>2]|0)==3){Q=328}else{if((c[Hb+13944>>2]|0)!=0){Q=328;break}ma=Hb+9848|0;la=c[ma>>2]|0;if((la|0)==0){vd=0;break}ya=MCb(w,la|0)|0;if((ya|0)<0){x=ya;i=k;return x|0}else{VOa(F,c[ma>>2]|0,w);WOa(F,w,c[ma>>2]|0,0)|0;vd=1;break}}}while(0);do{if((Q|0)==328){Jb=Hb+9856|0;ma=MCb(w,c[Jb>>2]|0)|0;if((ma|0)<0){x=ma;i=k;return x|0}else{VOa(F,c[Jb>>2]|0,w);WOa(F,w,c[Jb>>2]|0,0)|0;vd=1;break}}}while(0);c[h>>2]=vd}}while(0);x=c[r>>2]|0;i=k;return x|0}}while(0);yDb(f,16,2316336,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;x=-1094995529;i=k;return x|0}}while(0);yDb(f,16,2222832,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;x=-1094995529;i=k;return x|0}function qVa(a){a=a|0;var b=0;b=c[a+60>>2]|0;LOa(b);$Db(b+15264|0);c[b+15268>>2]=0;$Db(b+15728|0);$Db(b+15548|0);$Db(b+15640|0);$Db(b+15644|0);$Db(b+15648|0);return 0}function rVa(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;j=i;i=i+32|0;k=j|0;l=k|0;m=f+14120|0;n=f+9960|0;o=c[n>>2]|0;p=e[534032+(d[(c[f+15276>>2]|0)+o|0]<<1)>>1]|0;q=e[534032+(o<<1)>>1]|0;o=c[f+12544>>2]|0;r=f+14340|0;s=c[r>>2]|0;TGb(k|0,0,32)|0;t=f+15284|0;if((tVa(l,m,c[t>>2]|0,3,0,p,p,q)|0)==0){me[c[f+15228>>2]&511](l)}else{me[c[f+15224>>2]&511](l)}l=a[g]|0;p=c[900912+(l<<24>>24<<2)>>2]|0;u=f+15664|0;v=f+15676|0;w=(c[u>>2]|0)!=0;x=(c[v>>2]|0)==0;do{if(x&(w^1)){y=6}else{if(!w){z=l<<24>>24==3?1:p;A=(z|0)==2?1:z;y=(A|0)==0?4:A;break}if(!x){y=p;break}A=l<<24>>24==3?2:p;z=(A|0)==1?2:A;y=(z|0)==0?5:z}}while(0);p=f+148|0;ne[c[f+15440+(y<<2)>>2]&1023](o,c[p>>2]|0);y=f+15236|0;l=f+15556|0;x=f+15232|0;w=o;o=0;z=h;while(1){h=o<<2;A=0;B=z;do{C=b[k+(A+h<<1)>>1]|0;D=C<<16>>16;do{if((B&1|0)==0){E=14}else{if((tVa(s,m,c[t>>2]|0,c[l>>2]|0,0,q,q,q)|0)==0){E=14;break}b[s>>1]=C;Xe[c[x>>2]&4095](w+(A<<2)|0,c[p>>2]|0,s)}}while(0);if((E|0)==14){E=0;Xe[c[y>>2]&4095](w+(A<<2)|0,c[p>>2]|0,D)}A=A+1|0;B=B>>1;}while((A|0)<4);A=o+1|0;if((A|0)<4){w=w+(c[p>>2]<<2)|0;o=A;z=B}else{break}}z=a[g]|0;g=z<<24>>24==3?0:c[900912+(z<<24>>24<<2)>>2]|0;z=(c[u>>2]|0)!=0;u=(c[v>>2]|0)==0;do{if(u&(z^1)){F=6}else{if(!z){v=(g|0)==3?1:g;o=(v|0)==2?1:v;F=(o|0)==0?4:o;break}if(!u){F=g;break}o=(g|0)==3?2:g;v=(o|0)==1?2:o;F=(v|0)==0?5:v}}while(0);g=c[n>>2]|0;n=e[534032+(d[544136+g|0]<<1)>>1]|0;u=e[534032+(d[544104+g|0]<<1)>>1]|0;g=f+15396+(F<<2)|0;F=f+152|0;z=f+15560|0;v=c[f+12548>>2]|0;ne[c[g>>2]&1023](v,c[F>>2]|0);o=0;p=B;do{do{if((p&1|0)!=0){B=c[F>>2]|0;w=v+((ba(B,o<<1&4)|0)+(o<<2&4))|0;E=c[r>>2]|0;if((tVa(E,m,c[t>>2]|0,c[z>>2]|0,1,n,u,u)|0)==0){Xe[c[y>>2]&4095](w,B,b[E>>1]|0);b[E>>1]=0;break}else{Xe[c[x>>2]&4095](w,B,E);break}}}while(0);o=o+1|0;p=p>>1;}while((o|0)<4);o=c[f+12552>>2]|0;ne[c[g>>2]&1023](o,c[F>>2]|0);g=0;f=p;while(1){do{if((f&1|0)!=0){p=c[F>>2]|0;v=o+((ba(p,g<<1&4)|0)+(g<<2&4))|0;E=c[r>>2]|0;if((tVa(E,m,c[t>>2]|0,c[z>>2]|0,1,n,u,u)|0)==0){Xe[c[y>>2]&4095](v,p,b[E>>1]|0);b[E>>1]=0;break}else{Xe[c[x>>2]&4095](v,p,E);break}}}while(0);E=g+1|0;if((E|0)<4){g=E;f=f>>1}else{break}}i=j;return}function sVa(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+208|0;k=j|0;l=j+8|0;m=j+16|0;n=c[f+12544>>2]|0;TGb(m|0,0,192)|0;if((c[f+15660>>2]|0)!=0){c[m>>2]=1}if((c[f+15664>>2]|0)!=0){c[m+8>>2]=1;c[m+4>>2]=1}if((c[f+15668>>2]|0)!=0){c[m+16>>2]=1;c[m+12>>2]=1}if((c[f+15672>>2]|0)!=0){c[m+20>>2]=1}if((c[f+15676>>2]|0)!=0){c[m+64>>2]=1;c[m+32>>2]=1}if((c[f+15692>>2]|0)!=0){c[m+128>>2]=1;c[m+96>>2]=1}o=f+9960|0;p=e[534032+(c[o>>2]<<1)>>1]|0;q=f+148|0;r=l;s=f+15556|0;t=f+14340|0;u=f+14120|0;v=f+15284|0;w=f+15236|0;x=f+15232|0;y=f+15272|0;z=n;n=0;A=h;h=g;g=c[q>>2]|0;while(1){B=z;C=0;D=(n<<3)+9|0;E=A;F=g;while(1){G=a[h+C|0]|0;H=c[900928+(G<<24>>24<<2)>>2]|0;I=c[m+(D+7<<2)>>2]|0;J=c[m+(D-7<<2)>>2]|0;K=B+(4-F)|0;L=(c[m+(D-8<<2)>>2]|0)!=0;M=L^1;N=(c[m+(D-1<<2)>>2]|0)==0;do{if(N&M){O=11}else{if(!L){P=G<<24>>24==1?1:H;O=(P|0)==2?9:P;break}if(!N){O=H;break}P=G<<24>>24==2?0:H;Q=(P|0)==2?10:P;O=(Q|0)==3?12:Q}}while(0);if((I|0)==0){H=(O|0)==3?12:O;G=(H|0)==8?13:H;R=(G|0)==7?14:G}else{R=O}if((J|0)!=0|M){S=K}else{c[l>>2]=ba(d[B+(3-F)|0]|0,16843009)|0;S=r}Xe[c[f+15288+(R<<2)>>2]&4095](B,S,F);c[m+(D<<2)>>2]=1;do{if((E&1|0)!=0){G=c[q>>2]|0;H=c[t>>2]|0;if((tVa(H,u,c[v>>2]|0,c[s>>2]|0,0,p,p,p)|0)==0){Xe[c[w>>2]&4095](B,G,b[H>>1]|0);b[H>>1]=0;break}else{Xe[c[x>>2]&4095](B,G,H);break}}}while(0);K=C+1|0;T=E>>1;U=c[q>>2]|0;if((K|0)<4){B=B+4|0;C=K;D=D+1|0;E=T;F=U}else{break}}V=c[y>>2]|0;F=n+1|0;if((F|0)<4){z=z+(U<<2)|0;n=F;A=T;h=h+V|0;g=U}else{break}}U=V<<2;g=c[o>>2]|0;o=e[534032+(d[544136+g|0]<<1)>>1]|0;A=e[534032+(d[544104+g|0]<<1)>>1]|0;g=f+15680|0;n=f+15684|0;z=f+15696|0;q=f+15700|0;p=f+152|0;s=k;m=f+15560|0;S=0;R=T;while(1){T=S+1|0;r=c[f+12544+(T<<2)>>2]|0;c[g>>2]=0;c[n>>2]=0;c[z>>2]=0;c[q>>2]=0;l=r;r=0;O=R;while(1){F=0;E=O;D=f+15656+((r<<2)+6<<2)|0;while(1){C=a[h+(V+(((ba(c[y>>2]|0,r)|0)+F<<1)-U))|0]|0;B=c[900928+(C<<24>>24<<2)>>2]|0;K=F<<2;M=l+K|0;J=c[p>>2]|0;I=c[D-12>>2]|0;H=l+(K+4-J)|0;G=(c[D-16>>2]|0)!=0;N=G^1;L=(c[D-4>>2]|0)==0;do{if(L&N){W=11}else{if(!G){Q=C<<24>>24==1?1:B;W=(Q|0)==2?9:Q;break}if(!L){W=B;break}Q=C<<24>>24==2?0:B;P=(Q|0)==2?10:Q;W=(P|0)==3?12:P}}while(0);if((F|r|0)==0){X=W}else{B=(W|0)==3?12:W;C=(B|0)==8?13:B;X=(C|0)==7?14:C}if((I|0)!=0|N){Y=H}else{c[k>>2]=ba(d[l+((K|3)-J)|0]|0,16843009)|0;Y=s}Xe[c[f+15288+(X<<2)>>2]&4095](M,Y,J);c[D>>2]=1;do{if((E&1|0)!=0){C=c[p>>2]|0;B=c[t>>2]|0;if((tVa(B,u,c[v>>2]|0,c[m>>2]|0,1,o,A,A)|0)==0){Xe[c[w>>2]&4095](M,C,b[B>>1]|0);b[B>>1]=0;break}else{Xe[c[x>>2]&4095](M,C,B);break}}}while(0);M=F+1|0;Z=E>>1;if((M|0)>=2){break}F=M;E=Z;D=D+4|0}D=r+1|0;if((D|0)<2){l=l+(c[p>>2]<<2)|0;r=D;O=Z}else{break}}if((T|0)<2){S=T;R=Z}else{break}}i=j;return}function tVa(e,f,g,h,i,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;m=c[g+200+(h*20|0)+4>>2]|0;h=f+8|0;n=c[h>>2]|0;o=f+16|0;p=c[o>>2]|0;q=f|0;r=c[q>>2]|0;s=r+(n>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(n&7)>>>23;s=b[m+(t<<2)>>1]|0;u=b[m+(t<<2)+2>>1]|0;t=u<<16>>16;if(u<<16>>16<0){u=n+9|0;v=p>>>0>u>>>0?u:p;u=r+(v>>>3)|0;r=((fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(v&7)>>>((t+32|0)>>>0))+s|0;w=b[m+(r<<2)+2>>1]|0;x=b[m+(r<<2)>>1]|0;y=v}else{w=t;x=s;y=n}n=w+y|0;c[h>>2]=p>>>0>n>>>0?n:p;p=x&7;n=a[676696+(x>>3)|0]|0;y=g+360|0;w=n&255;uVa(e,w>>>6,3,f,y,j);do{if((n&63)==0){if((p|0)==0){z=0}else{A=0;break}return z|0}else{uVa(e+2|0,w>>>4&3,2,f,y,k);uVa(e+8|0,w>>>2&3,2,f,y,k);uVa(e+10|0,w&3,2,f,y,l);A=1}}while(0);if((x&4|0)!=0){w=c[g+280+(i*20|0)+4>>2]|0;k=c[h>>2]|0;n=c[o>>2]|0;j=c[q>>2]|0;s=j+(k>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(k&7)>>>23;s=b[w+(t<<2)>>1]|0;v=b[w+(t<<2)+2>>1]|0;t=v<<16>>16;if(v<<16>>16<0){v=k+9|0;r=n>>>0>v>>>0?v:n;v=j+(r>>>3)|0;j=((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(r&7)>>>((t+32|0)>>>0))+s|0;B=b[w+(j<<2)+2>>1]|0;C=b[w+(j<<2)>>1]|0;D=r}else{B=t;C=s;D=k}k=B+D|0;c[h>>2]=n>>>0>k>>>0?k:n;n=d[676696+C|0]|0;uVa(e+4|0,n>>>6,3,f,y,l);uVa(e+6|0,n>>>4&3,2,f,y,l);uVa(e+12|0,n>>>2&3,2,f,y,l);uVa(e+14|0,n&3,2,f,y,l)}if((x&2|0)!=0){n=c[g+280+(i*20|0)+4>>2]|0;C=c[h>>2]|0;k=c[o>>2]|0;D=c[q>>2]|0;B=D+(C>>>3)|0;s=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>23;B=b[n+(s<<2)>>1]|0;t=b[n+(s<<2)+2>>1]|0;s=t<<16>>16;if(t<<16>>16<0){t=C+9|0;r=k>>>0>t>>>0?t:k;t=D+(r>>>3)|0;D=((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(r&7)>>>((s+32|0)>>>0))+B|0;E=b[n+(D<<2)+2>>1]|0;F=b[n+(D<<2)>>1]|0;G=r}else{E=s;F=B;G=C}C=E+G|0;c[h>>2]=k>>>0>C>>>0?C:k;k=d[676696+F|0]|0;uVa(e+16|0,k>>>6,3,f,y,l);uVa(e+24|0,k>>>4&3,2,f,y,l);uVa(e+18|0,k>>>2&3,2,f,y,l);uVa(e+26|0,k&3,2,f,y,l)}if((x&1|0)!=0){x=c[g+320+(i*20|0)+4>>2]|0;i=c[h>>2]|0;g=c[o>>2]|0;o=c[q>>2]|0;q=o+(i>>>3)|0;k=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(i&7)>>>23;q=b[x+(k<<2)>>1]|0;F=b[x+(k<<2)+2>>1]|0;k=F<<16>>16;if(F<<16>>16<0){F=i+9|0;C=g>>>0>F>>>0?F:g;F=o+(C>>>3)|0;o=((fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(C&7)>>>((k+32|0)>>>0))+q|0;H=b[x+(o<<2)+2>>1]|0;I=b[x+(o<<2)>>1]|0;J=C}else{H=k;I=q;J=i}i=H+J|0;c[h>>2]=g>>>0>i>>>0?i:g;g=d[676696+I|0]|0;uVa(e+20|0,g>>>6,3,f,y,l);uVa(e+22|0,g>>>4&3,2,f,y,l);uVa(e+28|0,g>>>2&3,2,f,y,l);uVa(e+30|0,g&3,2,f,y,l)}z=A|p;return z|0}function uVa(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((e|0)==0){return}if((e|0)==(f|0)){f=c[h+4>>2]|0;h=g+8|0;j=c[h>>2]|0;k=c[g+16>>2]|0;l=c[g>>2]|0;m=l+(j>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>23;m=b[f+(n<<2)>>1]|0;o=b[f+(n<<2)+2>>1]|0;n=o<<16>>16;if(o<<16>>16<0){o=j+9|0;p=k>>>0>o>>>0?o:k;o=l+(p>>>3)|0;q=((fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(p&7)>>>((n+32|0)>>>0))+m|0;r=b[f+(q<<2)+2>>1]|0;s=b[f+(q<<2)>>1]|0;t=p}else{r=n;s=m;t=j}j=r+t|0;t=k>>>0>j>>>0?j:k;c[h>>2]=t;if((s|0)>23){j=s-23|0;r=l+(t>>>3)|0;m=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7)>>>((55-s|0)>>>0);r=t+j|0;n=k>>>0>r>>>0?r:k;c[h>>2]=n;u=(m|1<<j)+22|0;v=n}else{u=s;v=t}w=u+e|0;x=v;y=l;z=k}else{w=e;x=c[g+8>>2]|0;y=c[g>>2]|0;z=c[g+16>>2]|0}e=d[y+(x>>>3)|0]|0;c[g+8>>2]=((x|0)<(z|0))+x;b[a>>1]=((ba((e&128>>>((x&7)>>>0)|0)==0?w:-w|0,i)|0)+8|0)>>>4;return}function vVa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=c[e+(f*20|0)+4>>2]|0;h=a+8|0;i=c[h>>2]|0;j=c[a+16>>2]|0;k=c[a>>2]|0;a=k+(i>>>3)|0;l=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>23;a=b[g+(l<<2)>>1]|0;m=b[g+(l<<2)+2>>1]|0;l=m<<16>>16;if(m<<16>>16<0){m=i+9|0;n=j>>>0>m>>>0?m:j;m=k+(n>>>3)|0;o=((fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(n&7)>>>((l+32|0)>>>0))+a|0;p=b[g+(o<<2)+2>>1]|0;q=b[g+(o<<2)>>1]|0;r=n}else{p=l;q=a;r=i}i=p+r|0;r=j>>>0>i>>>0?i:j;c[h>>2]=r;i=d[544088+(q&15)|0]|0;p=e+40+(f*80|0)+(i*20|0)+4|0;a=e+40+(f*80|0)+(i*20|0)|0;if((q&8|0)==0){s=0;t=r}else{i=c[p>>2]|0;f=c[a>>2]|0;e=k+(r>>>3)|0;l=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(r&7)>>>((32-f|0)>>>0);f=b[i+(l<<2)>>1]|0;e=(b[i+(l<<2)+2>>1]|0)+r|0;r=j>>>0>e>>>0?e:j;c[h>>2]=r;s=f;t=r}if((q&4|0)==0){u=s;v=t}else{r=c[p>>2]|0;f=c[a>>2]|0;e=k+(t>>>3)|0;l=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(t&7)>>>((32-f|0)>>>0);f=b[r+(l<<2)>>1]|0;e=(b[r+(l<<2)+2>>1]|0)+t|0;t=j>>>0>e>>>0?e:j;c[h>>2]=t;u=f<<2|s;v=t}if((q&2|0)==0){w=u;x=v}else{t=c[p>>2]|0;s=c[a>>2]|0;f=k+(v>>>3)|0;e=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(v&7)>>>((32-s|0)>>>0);s=b[t+(e<<2)>>1]|0;f=(b[t+(e<<2)+2>>1]|0)+v|0;v=j>>>0>f>>>0?f:j;c[h>>2]=v;w=s<<8|u;x=v}if((q&1|0)==0){y=w;z=x}else{v=c[p>>2]|0;p=c[a>>2]|0;a=k+(x>>>3)|0;u=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(x&7)>>>((32-p|0)>>>0);p=b[v+(u<<2)>>1]|0;a=(b[v+(u<<2)+2>>1]|0)+x|0;x=j>>>0>a>>>0?a:j;c[h>>2]=x;y=p<<10|w;z=x}x=d[676696+(q>>4)|0]|0;q=x>>>6;if((q|0)==2){A=y|1114112;B=z}else if((q|0)==1){q=d[k+(z>>>3)|0]<<(z&7)>>>7;w=((z|0)<(j|0))+z|0;c[h>>2]=w;A=c[544072+((q&1)<<2)>>2]|y;B=w}else{A=y;B=z}z=x>>>4&3;if((z|0)==2){C=A|2228224;D=B}else if((z|0)==1){z=d[k+(B>>>3)|0]<<(B&7)>>>7;y=((B|0)<(j|0))+B|0;c[h>>2]=y;C=c[544072+((z&1)<<2)>>2]<<1|A;D=y}else{C=A;D=B}B=x>>>2&3;if((B|0)==1){A=d[k+(D>>>3)|0]<<(D&7)>>>7;y=((D|0)<(j|0))+D|0;c[h>>2]=y;E=c[544072+((A&1)<<2)>>2]<<2|C;F=y}else if((B|0)==2){E=C|4456448;F=D}else{E=C;F=D}D=x&3;if((D|0)==1){x=d[k+(F>>>3)|0]<<(F&7)>>>7;c[h>>2]=((F|0)<(j|0))+F;G=c[544072+((x&1)<<2)>>2]<<3|E;return G|0}else if((D|0)==2){G=E|8912896;return G|0}else{G=E;return G|0}return 0}function wVa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+15600|0;e=c[d>>2]|0;if((e|0)!=0|(b|0)==10){f=0}else{f=(c[a+15624>>2]|0)!=8192}g=a+14672|0;h=a+15184|0;zVa(a,b,0,0,0,2,2,0,e,f&1,g,h);e=c[d>>2]|0;if(f){zVa(a,b,0,0,0,2,2,1,e,1,g,h);h=a+15620|0;g=a+15624|0;f=a+15628|0;Se[c[a+15208+(c[h>>2]<<3)>>2]&511](c[a+12544>>2]|0,c[a+15704>>2]|0,c[a+15708>>2]|0,c[g>>2]|0,c[f>>2]|0,c[a+148>>2]|0);d=a+152|0;Se[c[a+15208+(c[h>>2]<<3)+4>>2]&511](c[a+12548>>2]|0,c[a+15712>>2]|0,c[a+15720>>2]|0,c[g>>2]|0,c[f>>2]|0,c[d>>2]|0);Se[c[a+15208+(c[h>>2]<<3)+4>>2]&511](c[a+12552>>2]|0,c[a+15716>>2]|0,c[a+15724>>2]|0,c[g>>2]|0,c[f>>2]|0,c[d>>2]|0);return}else{zVa(a,b,0,0,0,2,2,1,e,0,a+14928|0,a+15196|0);return}}function xVa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=c[a+128>>2]|0;i=d[1775416+f|0]|0;j=d[592616+e|0]|0;k=(c[a+12476>>2]<<1|f&1)+(ba((c[a+12480>>2]<<1)+(f>>1)|0,h)|0)|0;l=(f|0)==3?-1:j;f=(c[a+15656+(i-1<<2)>>2]|0)==0;if(f){m=0;n=0}else{o=k-1|0;p=c[(c[a+9856>>2]|0)+1524>>2]|0;m=b[p+(o<<2)>>1]|0;n=b[p+(o<<2)+2>>1]|0}o=i-4|0;i=(c[a+15656+(o<<2)>>2]|0)==0;if(i){q=m;r=n}else{p=k-h|0;s=c[(c[a+9856>>2]|0)+1524>>2]|0;q=b[s+(p<<2)>>1]|0;r=b[s+(p<<2)+2>>1]|0}do{if((c[a+15656+(o+l<<2)>>2]|0)==0){if(i){t=m;u=n;break}if(f){if((c[a+15600>>2]|0)==0){t=m;u=n;break}}p=k-h-1|0;s=c[(c[a+9856>>2]|0)+1524>>2]|0;t=b[s+(p<<2)>>1]|0;u=b[s+(p<<2)+2>>1]|0}else{p=k-h+l|0;s=c[(c[a+9856>>2]|0)+1524>>2]|0;t=b[s+(p<<2)>>1]|0;u=b[s+(p<<2)+2>>1]|0}}while(0);do{if((m|0)>(q|0)){if((t|0)<=(q|0)){v=q;break}v=(t|0)>(m|0)?m:t}else{if((q|0)<=(t|0)){v=q;break}v=(t|0)>(m|0)?t:m}}while(0);do{if((n|0)>(r|0)){if((u|0)<=(r|0)){w=r;break}w=(u|0)>(n|0)?n:u}else{if((r|0)<=(u|0)){w=r;break}w=(u|0)>(n|0)?u:n}}while(0);n=d[592632+e|0]|0;e=(c[a+15568+(g<<3)>>2]|0)+v&65535;v=a+9856|0;u=(c[a+15568+(g<<3)+4>>2]|0)+w&65535;w=0;do{g=ba(h,w)|0;a=c[(c[v>>2]|0)+1524>>2]|0;r=0;do{m=g+(r+k)|0;b[a+(m<<2)>>1]=e;b[a+(m<<2)+2>>1]=u;r=r+1|0;}while((r|0)<(j|0));w=w+1|0;}while((w|0)<(n|0));return}function yVa(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=c[a+12476>>2]|0;g=c[a+12480>>2]|0;h=(ba(c[a+124>>2]|0,g)|0)+f|0;i=c[a+128>>2]|0;j=(ba(g<<1,i)|0)+(f<<1)|0;g=c[a+9856>>2]|0;k=(e|0)!=0;l=c[(c[g+1536>>2]|0)+(h<<2)>>2]&(k?49152:12288);if((l&c[a+15676>>2]|0)==0){m=0;n=0;o=0}else{h=j-1|0;p=c[g+1524+(e<<2)>>2]|0;m=1;n=b[p+(h<<2)>>1]|0;o=b[p+(h<<2)+2>>1]|0}h=c[a+15664>>2]|0;if((l&h|0)==0){q=0;r=0;s=0}else{p=j-i|0;t=c[g+1524+(e<<2)>>2]|0;q=1;r=b[t+(p<<2)>>1]|0;s=b[t+(p<<2)+2>>1]|0}do{if((h|0)==0){u=8}else{if((l&c[a+15672>>2]|0)==0){u=8;break}p=j-i+2|0;t=c[g+1524+(e<<2)>>2]|0;v=1;w=b[t+(p<<2)>>1]|0;x=b[t+(p<<2)+2>>1]|0}}while(0);do{if((u|0)==8){if((f+1|0)!=(c[a+116>>2]|0)){v=0;w=0;x=0;break}if((l&c[a+15660>>2]|0)==0){v=0;w=0;x=0;break}h=j-i-1|0;p=c[g+1524+(e<<2)>>2]|0;v=1;w=b[p+(h<<2)>>1]|0;x=b[p+(h<<2)+2>>1]|0}}while(0);l=q+m+v|0;do{if((l|0)==3){do{if((n|0)>(r|0)){if((w|0)<=(r|0)){y=r;break}y=(w|0)>(n|0)?n:w}else{if((r|0)<=(w|0)){y=r;break}y=(w|0)>(n|0)?w:n}}while(0);if((o|0)>(s|0)){if((x|0)<=(s|0)){z=s;A=y;break}z=(x|0)>(o|0)?o:x;A=y;break}else{if((s|0)<=(x|0)){z=s;A=y;break}z=(x|0)>(o|0)?x:o;A=y;break}}else{v=r+n+w|0;m=s+o+x|0;if((l|0)!=2){z=m;A=v;break}z=(m|0)/2|0;A=(v|0)/2|0}}while(0);l=(c[a+15568+(e<<3)>>2]|0)+A&65535;A=c[g+1524+(e<<2)>>2]|0;x=(c[a+15568+(e<<3)+4>>2]|0)+z&65535;b[A+(j<<2)>>1]=l;b[A+(j<<2)+2>>1]=x;z=j|1;b[A+(z<<2)>>1]=l;b[A+(z<<2)+2>>1]=x;e=i+j|0;b[A+(e<<2)>>1]=l;b[A+(e<<2)+2>>1]=x;e=i+z|0;b[A+(e<<2)>>1]=l;b[A+(e<<2)+2>>1]=x;if(!((d-4|0)>>>0<2>>>0)){return}d=c[g+1524+((k&1^1)<<2)>>2]|0;k=d+(j<<2)|0;g=k;x=i<<2;c[k>>2]=0;c[g+x>>2]=0;c[d+(j<<2)+4>>2]=0;c[g+(x+4)>>2]=0;return}function zVa(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;o=c[a+12476>>2]|0;p=c[a+12480>>2]|0;q=((ba(c[a+128>>2]|0,p)|0)+o<<1)+g|0;g=c[(c[a+9856>>2]|0)+1524+(j<<2)>>2]|0;r=b[g+(q<<2)>>1]|0;if((k|0)==0){k=b[g+(q<<2)+2>>1]|0;s=(r|0)/2|0;t=(k|0)/2|0;u=s<<1&6;v=t<<1;w=(u&v|0)==6;x=r>>2;y=k>>2;z=s>>2;A=t>>2;B=w?4:v&6;C=w?4:u;D=k&3;E=r&3}else{k=r+50331648|0;u=b[g+(q<<2)+2>>1]|0;q=u+50331648|0;g=((r|0)/2|0)+50331648|0;r=((u|0)/2|0)+50331648|0;x=((k|0)/3|0)-16777216|0;y=((q|0)/3|0)-16777216|0;z=((g|0)/3|0)-16777216|0;A=((r|0)/3|0)-16777216|0;B=c[1487256+(((r|0)%3|0)<<2)>>2]|0;C=c[1487256+(((g|0)%3|0)<<2)>>2]|0;D=(q|0)%3|0;E=(k|0)%3|0}k=(D<<2)+E|0;q=c[((j|0)!=0?a+9852|0:a+9848|0)>>2]|0;g=c[q>>2]|0;r=x+e+(o<<4)|0;x=y+f+(p<<4)|0;y=e>>1;u=z+y+(o<<3)|0;o=f>>1;z=A+o+(p<<3)|0;p=a+148|0;A=c[p>>2]|0;w=(ba(x,A)|0)+r|0;v=g+w|0;t=a+152|0;s=(ba(z,c[t>>2]|0)|0)+u|0;F=(c[q+4>>2]|0)+s|0;G=(c[q+8>>2]|0)+s|0;s=a+136|0;q=c[s>>2]|0;H=h<<3;I=c[a+140>>2]|0;J=i<<3;do{if((q-H|0)<6){K=8}else{if((I-J|0)<6){K=8;break}L=((E|0)!=0)<<1;if((r-L|0)>>>0>(-4-H-L+q|0)>>>0){K=8;break}L=((D|0)!=0)<<1;if((x-L|0)>>>0>(-4-J-L+I|0)>>>0){K=8}else{M=v;N=F;O=G}}}while(0);if((K|0)==8){K=a+9944|0;v=c[K>>2]|0;D=A*22|0;E=v+D|0;L=a+11540|0;P=a+140|0;Ne[c[L>>2]&127](v,g+(w-2-(A<<1))|0,A,A,H|6,J|6,r-2|0,x-2|0,q,I);I=(c[K>>2]|0)+((c[p>>2]<<1)+2)|0;K=c[t>>2]|0;q=h<<2|1;x=i<<2|1;Ne[c[L>>2]&127](E,F,K,K,q,x,u,z,c[s>>2]>>1,c[P>>2]>>1);K=v+(D+16)|0;D=c[t>>2]|0;Ne[c[L>>2]&127](K,G,D,D,q,x,u,z,c[s>>2]>>1,c[P>>2]>>1);M=I;N=E;O=K}if((l|0)==0){l=c[p>>2]|0;K=(c[a+12544>>2]|0)+((ba(l,f)|0)+e)|0;E=(ba(c[t>>2]|0,o)|0)+y|0;Q=K;R=(c[a+12548>>2]|0)+E|0;S=(c[a+12552>>2]|0)+E|0;T=l}else{l=c[p>>2]|0;E=(c[a+15704+(j<<2)>>2]|0)+((ba(l,f)|0)+e)|0;e=j<<1;j=(ba(c[t>>2]|0,o)|0)+y|0;Q=E;R=(c[a+15712+(e<<2)>>2]|0)+j|0;S=(c[a+15712+((e|1)<<2)>>2]|0)+j|0;T=l}if((d|0)==9){Xe[c[m+64+(k<<2)>>2]&4095](Q,M,T);l=c[p>>2]|0;j=l<<3;U=M+j|0;V=Q+j|0;W=l}else if((d|0)==3){X=1;Y=M;Z=Q;_=T;$=m+(X<<6)+(k<<2)|0;aa=c[$>>2]|0;Xe[aa&4095](Z,Y,_);ca=2-h|0;da=n+(ca<<2)|0;ea=c[da>>2]|0;fa=c[t>>2]|0;ga=i<<2;Se[ea&511](R,N,fa,ga,C,B);ha=c[da>>2]|0;ia=c[t>>2]|0;Se[ha&511](S,O,ia,ga,C,B);return}else if((d|0)==8){Xe[c[m+64+(k<<2)>>2]&4095](Q,M,T);X=1;Y=M+8|0;Z=Q+8|0;_=c[p>>2]|0;$=m+(X<<6)+(k<<2)|0;aa=c[$>>2]|0;Xe[aa&4095](Z,Y,_);ca=2-h|0;da=n+(ca<<2)|0;ea=c[da>>2]|0;fa=c[t>>2]|0;ga=i<<2;Se[ea&511](R,N,fa,ga,C,B);ha=c[da>>2]|0;ia=c[t>>2]|0;Se[ha&511](S,O,ia,ga,C,B);return}else{U=M;V=Q;W=T}X=(d|0)==9|0;Y=U;Z=V;_=W;$=m+(X<<6)+(k<<2)|0;aa=c[$>>2]|0;Xe[aa&4095](Z,Y,_);ca=2-h|0;da=n+(ca<<2)|0;ea=c[da>>2]|0;fa=c[t>>2]|0;ga=i<<2;Se[ea&511](R,N,fa,ga,C,B);ha=c[da>>2]|0;ia=c[t>>2]|0;Se[ha&511](S,O,ia,ga,C,B);return}function AVa(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=i;i=i+6624|0;l=k|0;m=k+72|0;n=k+144|0;o=k+2736|0;p=k+5328|0;TGb(l|0,0,68)|0;if((f|0)>0){if((h|0)==0){q=0;r=0;s=0;while(1){t=a[e+q|0]|0;if(t<<24>>24==0){u=s;v=r}else{a[p+s|0]=t;b[o+(s<<1)>>1]=q;w=t&255;t=l+(w<<2)|0;c[t>>2]=(c[t>>2]|0)+1;u=s+1|0;v=(r|0)>(w|0)?r:w}w=q+1|0;if((w|0)<(f|0)){q=w;r=v;s=u}else{x=v;y=u;break}}}else{u=0;v=0;s=0;while(1){r=a[e+u|0]|0;if(r<<24>>24==0){z=s;A=v}else{a[p+s|0]=r;b[o+(s<<1)>>1]=d[h+u|0]|0;q=r&255;r=l+(q<<2)|0;c[r>>2]=(c[r>>2]|0)+1;z=s+1|0;A=(v|0)>(q|0)?v:q}q=u+1|0;if((q|0)<(f|0)){u=q;v=A;s=z}else{x=A;y=z;break}}}}else{x=0;y=0}c[m>>2]=0;z=0;A=0;do{A=(c[l+(z<<2)>>2]|0)+A<<1;z=z+1|0;c[m+(z<<2)>>2]=A;}while((z|0)<16);if((y|0)>0){z=0;do{A=m+((d[p+z|0]|0)<<2)|0;l=c[A>>2]|0;c[A>>2]=l+1;b[n+(z<<1)>>1]=l;z=z+1|0;}while((z|0)<(y|0))}z=c[194232+(j<<2)>>2]|0;c[g+4>>2]=3475632+(z<<2);c[g+12>>2]=(c[194232+(j+1<<2)>>2]|0)-z;N_(g,(x|0)>9?9:x,y,p|0,1,1,n,2,2,o,2,2,4)|0;i=k;return}function BVa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+60>>2]|0;c[d+15600>>2]=0;e=nVa(a)|0;if((e|0)<0){f=e;return f|0}if((c[2295880]|0)==0){c[2295881]=4319936;c[2295883]=256;N_(9183520,8,16,485752,1,1,485736,1,1,0,0,0,4)|0;e=0;while(1){if(((e|0)%10|0|0)!=9){c[9183948+(e*20|0)>>2]=4368216+(e<<7<<2);c[9183956+(e*20|0)>>2]=128;N_(9183944+(e*20|0)|0,7,9,1805128+(e*9|0)|0,1,1,1804312+(e*9|0)|0,1,1,0,0,0,4)|0}a=e+1|0;if((a|0)<90){e=a}else{g=0;h=0;break}}while(1){e=h<<16>>16;c[9183548+(g*20|0)>>2]=4320960+(e<<2);a=g+1|0;i=b[678064+(a<<1)>>1]|0;c[9183556+(g*20|0)>>2]=(i<<16>>16)-e;N_(9183544+(g*20|0)|0,9,81,1802688+(g*81|0)|0,1,1,1799448+(g*162|0)|0,2,2,0,0,0,4)|0;if((a|0)<20){g=a;h=i}else{j=0;break}}while(1){c[4617492+(j*20|0)>>2]=4314816+(j<<7<<2);c[4617500+(j*20|0)>>2]=128;N_(4617488+(j*20|0)|0,7,8,559800+(j<<3)|0,1,1,559744+(j<<3)|0,1,1,559736,1,1,4)|0;h=j+1|0;if((h|0)<7){j=h}else{k=0;break}}do{c[8857060+(k*20|0)>>2]=4318400+(k<<6<<2);c[8857068+(k*20|0)>>2]=64;N_(8857056+(k*20|0)|0,6,7,1679872+(k<<3)|0,1,1,1679824+(k*7|0)|0,1,1,1679816,1,1,4)|0;k=k+1|0;}while((k|0)<6)}c[d+15732>>2]=164;c[d+15740>>2]=124;c[d+15736>>2]=638;c[d+15744>>2]=508;c[d+15276>>2]=485416;c[d+15280>>2]=485448;f=0;return f|0}function CVa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=c[a+8>>2]|0;g=c[a+12>>2]|0;TGb(e|0,0,32)|0;h=b+8|0;i=c[h>>2]|0;j=b|0;k=c[j>>2]|0;l=d[k+(i>>>3)|0]|0;m=b+16|0;n=c[m>>2]|0;o=((i|0)<(n|0))+i|0;c[h>>2]=o;if((l&128>>>((i&7)>>>0)|0)!=0){p=-1;return p|0}i=k+(o>>>3)|0;k=(fe(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(o&7)>>>30;i=o+2|0;c[h>>2]=n>>>0>i>>>0?i:n;n=e|0;c[n>>2]=(k|0)==1?0:k;k=c[h>>2]|0;i=c[m>>2]|0;o=c[j>>2]|0;l=o+(k>>>3)|0;q=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(k&7)>>>27;l=k+5|0;c[h>>2]=i>>>0>l>>>0?l:i;c[e+4>>2]=q;q=c[h>>2]|0;i=c[m>>2]|0;l=o+(q>>>3)|0;k=fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;l=q+2|0;r=i>>>0>l>>>0?l:i;c[h>>2]=r;if((k&-1073741824>>>((q&7)>>>0)|0)!=0){p=-1;return p|0}q=o+(r>>>3)|0;k=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>30;q=r+2|0;c[h>>2]=i>>>0>q>>>0?q:i;c[e+8>>2]=k;k=c[m>>2]|0;i=(c[h>>2]|0)+1|0;q=k>>>0>i>>>0?i:k;c[h>>2]=q;i=o+(q>>>3)|0;r=(fe(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(q&7)>>>19;i=q+13|0;c[h>>2]=k>>>0>i>>>0?i:k;c[e+28>>2]=r;r=c[h>>2]|0;if((c[n>>2]|0)==0){s=r;t=c[m>>2]|0;u=6}else{n=d[o+(r>>>3)|0]|0;k=c[m>>2]|0;i=((r|0)<(k|0))+r|0;c[h>>2]=i;if((n&128>>>((r&7)>>>0)|0)==0){s=i;t=k;u=6}else{v=g;w=f}}do{if((u|0)==6){f=o+(s>>>3)|0;g=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(s&7)>>>29;f=s+3|0;k=t>>>0>f>>>0?f:t;c[h>>2]=k;f=c[485336+(g<<2)>>2]|0;if((g|0)==7){g=0;i=k;while(1){r=o+(i>>>3)|0;n=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(i&7)>>>24;r=i+8|0;q=t>>>0>r>>>0?r:t;c[h>>2]=q;r=(n<<2)+g|0;if((n|0)==255){g=r;i=q}else{x=r;y=q;break}}}else{x=f;y=k}i=o+(y>>>3)|0;g=(fe(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(y&7)>>>29;i=y+3|0;q=t>>>0>i>>>0?i:t;c[h>>2]=q;i=c[485368+(g<<2)>>2]|0;if((g-6|0)>>>0<2>>>0){g=(d[o+(q>>>3)|0]|0)<<(q&7)>>>7;r=((q|0)<(t|0))+q|0;c[h>>2]=r;z=c[485368+((g&1)-i<<2)>>2]|0;A=r}else{z=i;A=q}if((z|0)==0){B=0;C=A}else{v=z;w=x;break}while(1){q=o+(C>>>3)|0;i=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(C&7)>>>24;q=C+8|0;r=t>>>0>q>>>0?q:t;c[h>>2]=r;q=(i<<2)+B|0;if((i|0)==255){B=q;C=r}else{v=q;w=x;break}}}}while(0);if((hDb(w,v,0,c[a+4>>2]|0)|0)<0){p=-1;return p|0}c[e+20>>2]=w;c[e+24>>2]=v;a=mVa(b,ba(v+15>>4,w+15>>4)|0)|0;w=c[h>>2]|0;v=c[m>>2]|0;m=(c[j>>2]|0)+(w>>>3)|0;j=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(w&7)>>>((32-a|0)>>>0);m=w+a|0;c[h>>2]=v>>>0>m>>>0?m:v;c[e+12>>2]=j;p=0;return p|0}function DVa(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;i=f+14084|0;j=g+8|0;k=g+16|0;l=g|0;g=f+15272|0;f=0;m=h;while(1){do{if((f|0)==0){if((c[i>>2]|0)==0){n=0;o=m;p=5;break}h=c[2295881]|0;q=c[j>>2]|0;r=c[k>>2]|0;s=(c[l>>2]|0)+(q>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(q&7)>>>24;s=b[h+(t<<2)>>1]|0;u=s<<16>>16;v=(b[h+(t<<2)+2>>1]|0)+q|0;c[j>>2]=r>>>0>v>>>0?v:r;a[m]=u>>>2&2;a[m+1|0]=u>>>1&2;a[m+2|0]=s&2;a[m+3|0]=u<<1&2}else{n=0;o=m;p=5}}while(0);a:do{if((p|0)==5){while(1){p=0;u=c[g>>2]|0;s=a[o+(-u|0)|0]|0;r=s<<24>>24;v=a[o-1|0]|0;q=v<<24>>24;t=(r<<4)+(a[o+(1-u)|0]|0)+(q<<8)|0;u=0;while(1){if((u|0)>=20){p=12;break}if((t|0)==(e[485768+(u<<1)>>1]|0)){p=8;break}else{u=u+1|0}}do{if((p|0)==8){p=0;if((n|0)>2){p=12;break}t=c[9183548+(u*20|0)>>2]|0;h=c[j>>2]|0;w=c[k>>2]|0;x=c[l>>2]|0;y=x+(h>>>3)|0;z=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(h&7)>>>23;y=b[t+(z<<2)>>1]|0;A=b[t+(z<<2)+2>>1]|0;z=A<<16>>16;if(A<<16>>16<0){A=h+9|0;B=w>>>0>A>>>0?A:w;A=x+(B>>>3)|0;x=((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(B&7)>>>((z+32|0)>>>0))+y|0;C=b[t+(x<<2)+2>>1]|0;D=b[t+(x<<2)>>1]|0;E=B}else{C=z;D=y;E=h}h=C+E|0;c[j>>2]=w>>>0>h>>>0?h:w;w=o+1|0;a[o]=(D|0)/9|0;a[w]=(D|0)%9|0;F=w;G=n+1|0}}while(0);if((p|0)==12){p=0;do{if(s<<24>>24==-1|v<<24>>24==-1){if((q|0)==0|(q|0)==2){u=c[j>>2]|0;w=d[(c[l>>2]|0)+(u>>>3)|0]<<(u&7)>>>7;c[j>>2]=((u|0)<(c[k>>2]|0))+u;H=(w<<1&2^2)&255;break}else if((q|0)!=(-1|0)){H=0;break}if(!(s<<24>>24<2)){H=0;break}w=c[j>>2]|0;u=d[(c[l>>2]|0)+(w>>>3)|0]<<(w&7)>>>7;c[j>>2]=((w|0)<(c[k>>2]|0))+w;H=(u&1^1)&255}else{u=c[9183948+(((q*10|0)+r|0)*20|0)>>2]|0;w=c[j>>2]|0;h=c[k>>2]|0;y=(c[l>>2]|0)+(w>>>3)|0;z=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>25;y=b[u+(z<<2)>>1]|0;B=(b[u+(z<<2)+2>>1]|0)+w|0;c[j>>2]=h>>>0>B>>>0?B:h;H=y&255}}while(0);a[o]=H;F=o;G=n}r=G+1|0;if((r|0)>=4){break a}n=r;o=F+1|0;p=5}}}while(0);r=f+1|0;if((r|0)<4){f=r;m=m+(c[g>>2]|0)|0}else{break}}return 0}function EVa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;f=i;i=i+48|0;g=f|0;h=e+14120|0;j=c[e+124>>2]|0;k=(ba(j,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;l=e+12484|0;m=c[l>>2]|0;do{if((m|0)==0){n=e+14128|0;o=c[n>>2]|0;p=c[e+14136>>2]|0;q=c[h>>2]|0;r=q+(o>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(o&7);if((s&-1434451968|0)==0){r=1;t=o;u=s;while(1){v=u>>>24;w=a[1201432+v|0]|0;x=w&255;y=((w&255)>>>0>8>>>0?8:x)+t|0;z=p>>>0>y>>>0;A=z?y:p;if(!(w<<24>>24==9)){B=5;break}w=d[1201688+v|0]|r<<4;if(!(w>>>0<134217728>>>0)){C=w;break}y=q+(A>>>3)|0;D=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(A&7);if(z){r=w;t=A;u=D}else{C=w;break}}if((B|0)==5){C=d[1201688+v|0]|r<<(x-1>>1)}c[n>>2]=A;E=C-1|0}else{u=s>>>24;t=(d[1201432+u|0]|0)+o|0;c[n>>2]=p>>>0>t>>>0?t:p;E=d[1200920+u|0]|0}u=E+1|0;c[l>>2]=u;if(u>>>0>(c[e+144>>2]|0)>>>0){F=-1}else{G=u;break}i=f;return F|0}else{G=m}}while(0);m=G-1|0;c[l>>2]=m;if((m|0)!=0){F=6;i=f;return F|0}do{if((c[e+15664>>2]|0)==0){if((c[e+15676>>2]|0)==0){H=0;break}H=c[(c[e+15548>>2]|0)+(k-1<<2)>>2]|0}else{TGb(g|0,0,48)|0;if((c[e+15676>>2]|0)==0){I=c[e+15548>>2]|0}else{m=c[e+15548>>2]|0;l=g+(c[m+(k-1<<2)>>2]<<2)|0;c[l>>2]=(c[l>>2]|0)+1;I=m}m=g+(c[I+(k-j<<2)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)+1;if((c[e+15672>>2]|0)!=0){m=g+(c[I+(k+1-j<<2)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)+1}if((c[e+15660>>2]|0)!=0){m=g+(c[I+(k-1-j<<2)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)+1}m=c[g>>2]|0;if((m|0)>0){if((m|0)>1){H=0;break}else{J=1}}else{J=0}m=c[g+4>>2]|0;if((m|0)>(J|0)){if((m|0)>1){H=1;break}else{K=m;L=1}}else{K=J;L=0}m=c[g+8>>2]|0;if((m|0)>(K|0)){if((m|0)>1){H=2;break}else{M=m;N=2}}else{M=K;N=L}m=c[g+12>>2]|0;if((m|0)>(M|0)){if((m|0)>1){H=3;break}else{O=m;P=3}}else{O=M;P=N}m=c[g+16>>2]|0;if((m|0)>(O|0)){if((m|0)>1){H=4;break}else{Q=m;R=4}}else{Q=O;R=P}m=c[g+20>>2]|0;if((m|0)>(Q|0)){if((m|0)>1){H=5;break}else{S=m;T=5}}else{S=Q;T=R}m=c[g+24>>2]|0;if((m|0)>(S|0)){if((m|0)>1){H=6;break}else{U=m;V=6}}else{U=S;V=T}m=c[g+28>>2]|0;if((m|0)>(U|0)){if((m|0)>1){H=7;break}else{W=m;X=7}}else{W=U;X=V}m=c[g+32>>2]|0;if((m|0)>(W|0)){if((m|0)>1){H=8;break}else{Y=m;Z=8}}else{Y=W;Z=X}m=c[g+36>>2]|0;if((m|0)>(Y|0)){if((m|0)>1){H=9;break}else{_=m;$=9}}else{_=Y;$=Z}m=c[g+40>>2]|0;if((m|0)>(_|0)){if((m|0)>1){H=10;break}else{aa=m;ca=10}}else{aa=_;ca=$}H=(c[g+44>>2]|0)>(aa|0)?11:ca}}while(0);if((c[e+9992>>2]|0)==2){ca=c[4617492+((d[1680712+H|0]|0)*20|0)>>2]|0;aa=e+14128|0;g=c[aa>>2]|0;$=c[e+14136>>2]|0;_=c[h>>2]|0;Z=_+(g>>>3)|0;Y=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(g&7)>>>25;Z=b[ca+(Y<<2)>>1]|0;X=(b[ca+(Y<<2)+2>>1]|0)+g|0;g=$>>>0>X>>>0?X:$;c[aa>>2]=g;if(Z<<16>>16<255){F=Z<<16>>16;i=f;return F|0}Z=_+(g>>>3)|0;_=(b[ca+((fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(g&7)>>>25<<2)+2>>1]|0)+g|0;c[aa>>2]=$>>>0>_>>>0?_:$;yDb(c[e+4>>2]|0,16,2182152,(da=i,i=i+1|0,i=i+7&-8,c[da>>2]=0,da)|0);i=da;F=0;i=f;return F|0}else{$=c[8857060+((d[1680728+H|0]|0)*20|0)>>2]|0;H=e+14128|0;_=c[H>>2]|0;aa=c[e+14136>>2]|0;g=c[h>>2]|0;h=g+(_>>>3)|0;Z=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(_&7)>>>26;h=b[$+(Z<<2)>>1]|0;ca=(b[$+(Z<<2)+2>>1]|0)+_|0;_=aa>>>0>ca>>>0?ca:aa;c[H>>2]=_;if(h<<16>>16<255){F=h<<16>>16;i=f;return F|0}h=g+(_>>>3)|0;g=(b[$+((fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(_&7)>>>26<<2)+2>>1]|0)+_|0;c[H>>2]=aa>>>0>g>>>0?g:aa;yDb(c[e+4>>2]|0,16,2105200,(da=i,i=i+1|0,i=i+7&-8,c[da>>2]=0,da)|0);i=da;F=0;i=f;return F|0}return 0}function FVa(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0;h=i;i=i+280|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;r=h+64|0;s=h+72|0;t=h+80|0;u=h+88|0;v=h+96|0;w=h+104|0;x=h+112|0;y=h+120|0;z=h+128|0;A=h+144|0;B=h+160|0;C=h+176|0;D=h+192|0;E=h+224|0;F=h+240|0;G=h+248|0;H=h+256|0;I=h+272|0;J=f+124|0;K=f+116|0;L=c[K>>2]|0;if((L|0)<=0){i=h;return}M=f+9856|0;N=f+15644|0;O=f+15648|0;P=f+15640|0;Q=1;R=ba(c[J>>2]|0,g)|0;S=L;while(1){L=c[(c[(c[M>>2]|0)+1536>>2]|0)+(R<<2)>>2]|0;T=(L&7|0)!=0;if(!((L&16777216|0)==0&(T^1))){b[(c[O>>2]|0)+(R<<1)>>1]=-1;b[(c[P>>2]|0)+(R<<1)>>1]=-1}if(T){a[(c[N>>2]|0)+R|0]=-1;U=c[K>>2]|0}else{U=S}if((Q|0)>=(U|0)){break}Q=Q+1|0;R=R+1|0;S=U}if((U|0)<=0){i=h;return}U=ba(c[J>>2]|0,g)|0;S=f+9856|0;R=f+8|0;Q=f+12|0;N=H|0;P=H+4|0;O=H+8|0;M=f+120|0;T=H+12|0;L=z|0;V=f+15648|0;W=f+15640|0;X=f+15644|0;Y=E|0;Z=E+12|0;_=C|0;$=C+4|0;aa=C+8|0;ca=(g|0)!=0;da=A|0;ea=A+12|0;fa=g<<4;ga=f+148|0;ha=A+8|0;ia=E+8|0;ja=B+8|0;ka=f+15260|0;la=f+15244|0;ma=f+15252|0;na=B|0;oa=A+4|0;pa=E+4|0;qa=f+15256|0;ra=f+15240|0;sa=f+15248|0;ta=B+4|0;ua=g<<3;va=f+152|0;f=0;wa=U;while(1){U=c[S>>2]|0;xa=a[(c[U+1512>>2]|0)+wa|0]|0;ya=a[485704+xa|0]|0;za=d[485672+xa|0]|0;Aa=(ba(c[Q>>2]|0,c[R>>2]|0)|0)<25345;Ba=Aa?za:0;c[N>>2]=1;c[P>>2]=g;c[O>>2]=f;Aa=(c[M>>2]|0)-1|0;c[T>>2]=(Aa|0)>(g|0);Ca=0;Da=0;while(1){if(Da){c[E+(Ca<<2)>>2]=0;Ea=c[L>>2]|0;c[z+(Ca<<2)>>2]=Ea;c[C+(Ca<<2)>>2]=0;c[D+(Ca<<3)+4>>2]=0;c[D+(Ca<<3)>>2]=0;Fa=Ea}else{Ea=(c[637488+(Ca<<2)>>2]|0)+wa+(ba(c[J>>2]|0,c[637472+(Ca<<2)>>2]|0)|0)|0;c[E+(Ca<<2)>>2]=e[(c[V>>2]|0)+(Ea<<1)>>1]|0;Ga=c[(c[U+1536>>2]|0)+(Ea<<2)>>2]|0;c[z+(Ca<<2)>>2]=Ga;c[C+(Ca<<2)>>2]=e[(c[W>>2]|0)+(Ea<<1)>>1]|0;Ha=(c[X>>2]|0)+Ea|0;c[D+(Ca<<3)>>2]=a[Ha]&15;c[D+(Ca<<3)+4>>2]=(d[Ha]|0)>>>4;Fa=Ga}if((Fa&7|0)==0){Ia=Fa>>>24&1}else{Ia=1}c[A+(Ca<<2)>>2]=Ia;c[B+(Ca<<2)>>2]=d[485480+(Ia+1<<5)+xa|0]|0;Ga=Ca+1|0;if((Ga|0)>=4){break}Ca=Ga;Da=(c[H+(Ga<<2)>>2]|0)==0}Da=ya&255;Ca=za*3|0;xa=Ba+Ca|0;Ga=c[Z>>2]<<16|c[Y>>2];Ha=c[_>>2]|0;Ea=Ga|Ha<<4;Ja=Ha<<1&-4370|Ga;Ha=(f|0)!=0;Ka=Ha?(c[aa>>2]|0)>>>3&4369|Ja:Ja&-4370;Ja=ca?(c[$>>2]|0)>>>12&15|Ea:Ea&-16;Ea=(Aa|0)==(g|0);La=c[da>>2]|0;Ma=c[ea>>2]|0;if(Ea){Na=21}else{if((Ma|La|0)==0){Oa=Ja}else{Na=21}}if((Na|0)==21){Na=0;Oa=Ja&-983041}Ja=(Ma|La|0)==0;Ma=c[D>>2]|0;Pa=c[D+24>>2]<<4|Ma;c[I>>2]=Pa;Qa=Ma<<1&-6|Pa;do{if(Ha){Ra=Qa|(c[D+16>>2]|0)>>>1&5;c[F>>2]=Ra;Sa=(c[D+8>>2]|0)>>>2&3|Pa|Ma<<2;if(ca){Ta=Sa;Ua=Sa}else{Va=Sa&-4;Ta=Va;Ua=Va}if(Ea|Ja^1){Va=Ta&-49;Wa=Va;Xa=Va}else{Wa=Ta;Xa=Ua}c[G>>2]=Xa;Va=c[D+4>>2]|0;Sa=c[D+28>>2]<<4|Va;c[I+4>>2]=Sa;c[F+4>>2]=Va<<1&-6|Sa|(c[D+20>>2]|0)>>>1&5;Ya=(c[D+12>>2]|0)>>>2&3|Sa|Va<<2;Va=G+4|0;if(ca){Za=Ya;_a=Ya}else{Sa=Ya&-4;Za=Sa;_a=Sa}c[Va>>2]=_a;if(!(Ea|Ja^1)){$a=Wa;ab=Ra;break}c[Va>>2]=Za&-49;$a=Wa;ab=Ra}else{Ra=F|0;Va=(c[D+8>>2]|0)>>>2&3|Pa|Ma<<2;Sa=G|0;if(ca){c[Sa>>2]=Va;Ya=Qa&-6;c[Ra>>2]=Ya;if(Ea|Ja^1){bb=Va&-49;c[Sa>>2]=bb;cb=bb}else{cb=Va}bb=c[D+4>>2]|0;db=c[D+28>>2]<<4|bb;c[I+4>>2]=db;eb=(c[D+12>>2]|0)>>>2&3|db|bb<<2;fb=G+4|0;c[fb>>2]=eb;c[F+4>>2]=(bb<<1|db)&-6;if(!(Ea|Ja^1)){$a=cb;ab=Ya;break}c[fb>>2]=eb&-49;$a=cb;ab=Ya;break}else{Ya=Qa&-6;c[Ra>>2]=Ya;Ra=Va&-4;if(Ea|Ja^1){eb=Va&-52;gb=eb;hb=eb}else{gb=Ra;hb=Ra}c[Sa>>2]=hb;Sa=c[D+4>>2]|0;Ra=c[D+28>>2]<<4|Sa;c[I+4>>2]=Ra;eb=G+4|0;c[F+4>>2]=(Sa<<1|Ra)&-6;Va=Ra&-4|Sa<<2;c[eb>>2]=Va;if(!(Ea|Ja^1)){$a=gb;ab=Ya;break}c[eb>>2]=Va&-52;$a=gb;ab=Ya;break}}}while(0);Ja=f<<4;Ea=(c[ha>>2]|La|0)==0;Qa=c[ia>>2]|0;Ma=c[ja>>2]|0;Ha=c[na>>2]|0;Aa=(c[oa>>2]|La|0)==0;Ba=c[pa>>2]|0;ya=c[ta>>2]|0;Ya=0;Va=U;while(1){eb=(Ya|0)!=0;Sa=(Qa&8<<Ya|0)==0;Ra=(c[Va>>2]|0)+((ba(c[ga>>2]|0,Ya+fa|0)|0)+Ja)|0;fb=0;while(1){db=fb+Ya|0;bb=1<<db;ib=(bb&Ga|0)==0?0:Ha;jb=eb?db:fb<<2;kb=16<<db;do{if((kb&Oa|0)!=0){lb=c[ga>>2]|0;mb=Ra+(lb<<2)|0;nb=(kb&Ga|0)==0?0:Ha;ob=je[c[qa>>2]&127](mb,lb,za,xa,0,x,y)|0;pb=c[x>>2]|0;qb=c[y>>2]|0;rb=(nb+ib>>1)+1+pb+qb|0;if((ob|0)!=0){Se[c[sa>>2]&511](mb,lb,Da,rb,jb,0);break}if((qb&pb|0)!=0){Le[c[ra>>2]&255](mb,lb,1,1,Da,za,rb,nb,ib);break}if((qb|pb|0)==0){break}Le[c[ra>>2]&255](mb,lb,pb,qb,Da,za,rb>>1,nb>>1,ib>>1)}}while(0);kb=(bb&Ka|0)!=0;do{if(kb){if((fb|0)==0){if(!Ea){break}sb=Sa?0:Ma}else{sb=(1<<db-1&Ga|0)==0?0:Ha}nb=c[ga>>2]|0;rb=je[c[ka>>2]&127](Ra,nb,za,xa,0,v,w)|0;qb=c[v>>2]|0;pb=c[w>>2]|0;lb=(sb+ib>>1)+1+qb+pb|0;if((rb|0)!=0){Se[c[ma>>2]&511](Ra,nb,Da,lb,jb,0);break}if((pb&qb|0)!=0){Le[c[la>>2]&255](Ra,nb,1,1,Da,za,lb,ib,sb);break}if((pb|qb|0)==0){break}Le[c[la>>2]&255](Ra,nb,qb,pb,Da,za,lb>>1,ib>>1,sb>>1)}}while(0);do{if(!eb){if((1<<fb&Oa|0)==0|Aa){break}db=c[ga>>2]|0;bb=(Ba&4096<<fb|0)==0?0:ya;lb=je[c[qa>>2]&127](Ra,db,za,xa,1,t,u)|0;pb=c[t>>2]|0;qb=c[u>>2]|0;nb=(bb+ib>>1)+1+pb+qb|0;if((lb|0)!=0){Se[c[sa>>2]&511](Ra,db,Da,nb,jb,0);break}if((qb&pb|0)!=0){Le[c[ra>>2]&255](Ra,db,1,1,Da,za,nb,ib,bb);break}if((qb|pb|0)==0){break}Le[c[ra>>2]&255](Ra,db,pb,qb,Da,za,nb>>1,ib>>1,bb>>1)}}while(0);do{if(!(Ea|kb&(fb|0)==0^1)){bb=Sa?0:Ma;nb=c[ga>>2]|0;qb=je[c[ka>>2]&127](Ra,nb,za,xa,1,r,s)|0;pb=c[r>>2]|0;db=c[s>>2]|0;lb=(bb+ib>>1)+1+pb+db|0;if((qb|0)!=0){Se[c[ma>>2]&511](Ra,nb,Da,lb,jb,0);break}if((db&pb|0)!=0){Le[c[la>>2]&255](Ra,nb,1,1,Da,za,lb,ib,bb);break}if((db|pb|0)==0){break}Le[c[la>>2]&255](Ra,nb,pb,db,Da,za,lb>>1,ib>>1,bb>>1)}}while(0);ib=fb+1|0;if((ib|0)<4){Ra=Ra+4|0;fb=ib}else{break}}fb=Ya+4|0;if((fb|0)>=16){break}Ya=fb;Va=c[S>>2]|0}Va=f<<3;Ya=0;xa=Pa;Ba=$a;Ga=ab;while(1){Ka=Ya+1|0;Ja=D+8+(Ya<<2)|0;Qa=D+16+(Ya<<2)|0;U=0;La=xa;while(1){fb=U<<1;Ra=(U|0)==0;Sa=1<<(fb|1);eb=U<<3;ib=(c[(c[S>>2]|0)+(Ka<<2)>>2]|0)+((ba(c[va>>2]|0,(U<<2)+ua|0)|0)+Va)|0;jb=0;kb=La;while(1){bb=jb+fb|0;lb=1<<bb;db=(xa&lb|0)==0?0:Ha;pb=1<<bb+2;do{if((Ba&pb|0)==0){tb=kb}else{nb=(xa&pb|0)==0?0:Ha;qb=c[va>>2]|0;rb=ib+(qb<<2)|0;mb=je[c[qa>>2]&127](rb,qb,za,Ca,0,p,q)|0;ob=c[p>>2]|0;ub=c[q>>2]|0;vb=(nb+db>>1)+1+ob+ub|0;if((mb|0)!=0){Se[c[sa>>2]&511](rb,qb,Da,vb,jb<<3,1);tb=xa;break}if((ub&ob|0)!=0){Le[c[ra>>2]&255](rb,qb,1,1,Da,za,vb,nb,db);tb=xa;break}if((ub|ob|0)==0){tb=xa;break}Le[c[ra>>2]&255](rb,qb,ob,ub,Da,za,vb>>1,nb>>1,db>>1);tb=xa}}while(0);nb=Ga&lb;do{if((nb|0)!=0){if((jb|0)==0){if(!Ea){break}wb=(c[Qa>>2]&Sa|0)==0?0:Ma}else{wb=(tb&1<<bb-1|0)==0?0:Ha}vb=c[va>>2]|0;ub=je[c[ka>>2]&127](ib,vb,za,Ca,0,n,o)|0;ob=c[n>>2]|0;qb=c[o>>2]|0;rb=(wb+db>>1)+1+ob+qb|0;if((ub|0)!=0){Se[c[ma>>2]&511](ib,vb,Da,rb,eb,1);break}if((qb&ob|0)!=0){Le[c[la>>2]&255](ib,vb,1,1,Da,za,rb,db,wb);break}if((qb|ob|0)==0){break}Le[c[la>>2]&255](ib,vb,ob,qb,Da,za,rb>>1,db>>1,wb>>1)}}while(0);do{if(Ra){if((Ba&lb|0)==0|Aa){break}bb=(c[Ja>>2]&pb|0)==0?0:ya;rb=c[va>>2]|0;qb=je[c[qa>>2]&127](ib,rb,za,Ca,1,l,m)|0;ob=c[l>>2]|0;vb=c[m>>2]|0;ub=(bb+db>>1)+1+ob+vb|0;if((qb|0)!=0){Se[c[sa>>2]&511](ib,rb,Da,ub,jb<<3,1);break}if((vb&ob|0)!=0){Le[c[ra>>2]&255](ib,rb,1,1,Da,za,ub,db,bb);break}if((vb|ob|0)==0){break}Le[c[ra>>2]&255](ib,rb,ob,vb,Da,za,ub>>1,db>>1,bb>>1)}}while(0);do{if(!((jb|0)!=0|(nb|0)==0|Ea)){pb=(c[Qa>>2]&Sa|0)==0?0:Ma;lb=c[va>>2]|0;bb=je[c[ka>>2]&127](ib,lb,za,Ca,1,j,k)|0;ub=c[j>>2]|0;vb=c[k>>2]|0;ob=(pb+db>>1)+1+ub+vb|0;if((bb|0)!=0){Se[c[ma>>2]&511](ib,lb,Da,ob,eb,1);break}if((vb&ub|0)!=0){Le[c[la>>2]&255](ib,lb,1,1,Da,za,ob,db,pb);break}if((vb|ub|0)==0){break}Le[c[la>>2]&255](ib,lb,ub,vb,Da,za,ob>>1,db>>1,pb>>1)}}while(0);db=jb+1|0;if((db|0)<2){ib=ib+4|0;jb=db;kb=tb}else{break}}kb=U+1|0;if((kb|0)<2){U=kb;La=tb}else{break}}if((Ka|0)>=2){break}Ya=Ka;xa=c[I+(Ka<<2)>>2]|0;Ba=c[G+(Ka<<2)>>2]|0;Ga=c[F+(Ka<<2)>>2]|0}Ga=f+1|0;if((Ga|0)>=(c[K>>2]|0)){break}f=Ga;wa=wa+1|0}i=h;return}function GVa(a){a=a|0;var b=0,d=0;b=i;i=i+512|0;d=b|0;iob(a);Soa(d,8);c[a>>2]=c[d>>2];c[a+4>>2]=1834;c[a+8>>2]=c[d+8>>2];c[a+12>>2]=796;c[a+16>>2]=890;c[a+20>>2]=1064;c[a+24>>2]=2238;c[a+28>>2]=1110;c[a+32>>2]=c[d+32>>2];c[a+36>>2]=1216;c[a+40>>2]=732;c[a+44>>2]=1692;c[a+48>>2]=1478;c[a+52>>2]=1564;c[a+56>>2]=1632;c[a+60>>2]=344;c[a+256>>2]=c[d+256>>2];c[a+260>>2]=2064;c[a+264>>2]=c[d+264>>2];c[a+268>>2]=398;c[a+272>>2]=614;c[a+276>>2]=1732;c[a+280>>2]=1342;c[a+284>>2]=98;c[a+288>>2]=c[d+288>>2];c[a+292>>2]=1154;c[a+296>>2]=1660;c[a+300>>2]=1006;c[a+304>>2]=2224;c[a+308>>2]=2332;c[a+312>>2]=754;c[a+316>>2]=1956;c[a+64>>2]=c[d+64>>2];c[a+68>>2]=2188;c[a+72>>2]=c[d+72>>2];c[a+76>>2]=2286;c[a+80>>2]=746;c[a+84>>2]=1840;c[a+88>>2]=2102;c[a+92>>2]=812;c[a+96>>2]=c[d+96>>2];c[a+100>>2]=368;c[a+104>>2]=2356;c[a+108>>2]=1676;c[a+112>>2]=1764;c[a+116>>2]=56;c[a+120>>2]=330;c[a+124>>2]=216;c[a+320>>2]=c[d+320>>2];c[a+324>>2]=666;c[a+328>>2]=c[d+328>>2];c[a+332>>2]=584;c[a+336>>2]=822;c[a+340>>2]=1018;c[a+344>>2]=2264;c[a+348>>2]=1534;c[a+352>>2]=c[d+352>>2];c[a+356>>2]=130;c[a+360>>2]=1966;c[a+364>>2]=1156;c[a+368>>2]=340;c[a+372>>2]=408;c[a+376>>2]=468;c[a+380>>2]=2078;c[a+512>>2]=296;c[a+516>>2]=162;c[a+524>>2]=12;c[a+528>>2]=144;c[a+536>>2]=256;c[a+540>>2]=100;c[a+544>>2]=176;c[a+548>>2]=20;c[a+568>>2]=124;c[a+572>>2]=14;c[a+576>>2]=84;c[a+580>>2]=234;c[a+584>>2]=46;c[a+588>>2]=2;i=b;return}function HVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;PWa(a,b,c,c,8,52,20,6);PWa(a+8|0,b+8|0,c,c,8,52,20,6);d=c<<3;PWa(a+d|0,b+d|0,c,c,8,52,20,6);e=d+8|0;PWa(a+e|0,b+e|0,c,c,8,52,20,6);return}function IVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;PWa(a,b,c,c,8,20,52,6);PWa(a+8|0,b+8|0,c,c,8,20,52,6);d=c<<3;PWa(a+d|0,b+d|0,c,c,8,20,52,6);e=d+8|0;PWa(a+e|0,b+e|0,c,c,8,20,52,6);return}function JVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;SWa(a,b,c,c,52,20,6);SWa(a+8|0,b+8|0,c,c,52,20,6);d=c<<3;SWa(a+d|0,b+d|0,c,c,52,20,6);e=d+8|0;SWa(a+e|0,b+e|0,c,c,52,20,6);return}function KVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,52,20,6);PWa(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,52,20,6);SWa(a,e+32|0,c,16,52,20,6);SWa(a+8|0,e+40|0,c,16,52,20,6);SWa(a+g|0,e+160|0,c,16,52,20,6);SWa(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function LVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,20,5);PWa(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,20,5);SWa(a,e+32|0,c,16,52,20,6);SWa(a+8|0,e+40|0,c,16,52,20,6);SWa(a+g|0,e+160|0,c,16,52,20,6);SWa(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function MVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,52,6);PWa(e+8|0,b+(8-f)|0,16,c,8,20,52,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,52,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,52,6);SWa(a,e+32|0,c,16,52,20,6);SWa(a+8|0,e+40|0,c,16,52,20,6);SWa(a+g|0,e+160|0,c,16,52,20,6);SWa(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function NVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,52,20,6);PWa(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,52,20,6);SWa(a,e+32|0,c,16,20,20,5);SWa(a+8|0,e+40|0,c,16,20,20,5);SWa(a+g|0,e+160|0,c,16,20,20,5);SWa(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function OVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,20,5);PWa(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,20,5);SWa(a,e+32|0,c,16,20,20,5);SWa(a+8|0,e+40|0,c,16,20,20,5);SWa(a+g|0,e+160|0,c,16,20,20,5);SWa(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function PVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,52,6);PWa(e+8|0,b+(8-f)|0,16,c,8,20,52,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,52,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,52,6);SWa(a,e+32|0,c,16,20,20,5);SWa(a+8|0,e+40|0,c,16,20,20,5);SWa(a+g|0,e+160|0,c,16,20,20,5);SWa(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function QVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;SWa(a,b,c,c,20,52,6);SWa(a+8|0,b+8|0,c,c,20,52,6);d=c<<3;SWa(a+d|0,b+d|0,c,c,20,52,6);e=d+8|0;SWa(a+e|0,b+e|0,c,c,20,52,6);return}function RVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,52,20,6);PWa(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,52,20,6);SWa(a,e+32|0,c,16,20,52,6);SWa(a+8|0,e+40|0,c,16,20,52,6);SWa(a+g|0,e+160|0,c,16,20,52,6);SWa(a+h|0,e+168|0,c,16,20,52,6);i=d;return}function SVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,20,5);PWa(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,20,5);SWa(a,e+32|0,c,16,20,52,6);SWa(a+8|0,e+40|0,c,16,20,52,6);SWa(a+g|0,e+160|0,c,16,20,52,6);SWa(a+h|0,e+168|0,c,16,20,52,6);i=d;return}function TVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;RWa(a,b,c,c,52,20);RWa(a+8|0,b+8|0,c,c,52,20);d=c<<3;RWa(a+d|0,b+d|0,c,c,52,20);e=d+8|0;RWa(a+e|0,b+e|0,c,c,52,20);return}function UVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;RWa(a,b,c,c,20,52);RWa(a+8|0,b+8|0,c,c,20,52);d=c<<3;RWa(a+d|0,b+d|0,c,c,20,52);e=d+8|0;RWa(a+e|0,b+e|0,c,c,20,52);return}function VVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;QWa(a,b,c,c,52,20,6);QWa(a+8|0,b+8|0,c,c,52,20,6);d=c<<3;QWa(a+d|0,b+d|0,c,c,52,20,6);e=d+8|0;QWa(a+e|0,b+e|0,c,c,52,20,6);return}function WVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,52,20,6);PWa(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,52,20,6);QWa(a,e+32|0,c,16,52,20,6);QWa(a+8|0,e+40|0,c,16,52,20,6);QWa(a+g|0,e+160|0,c,16,52,20,6);QWa(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function XVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,20,5);PWa(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,20,5);QWa(a,e+32|0,c,16,52,20,6);QWa(a+8|0,e+40|0,c,16,52,20,6);QWa(a+g|0,e+160|0,c,16,52,20,6);QWa(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function YVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,52,6);PWa(e+8|0,b+(8-f)|0,16,c,8,20,52,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,52,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,52,6);QWa(a,e+32|0,c,16,52,20,6);QWa(a+8|0,e+40|0,c,16,52,20,6);QWa(a+g|0,e+160|0,c,16,52,20,6);QWa(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function ZVa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,52,20,6);PWa(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,52,20,6);QWa(a,e+32|0,c,16,20,20,5);QWa(a+8|0,e+40|0,c,16,20,20,5);QWa(a+g|0,e+160|0,c,16,20,20,5);QWa(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function _Va(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,20,5);PWa(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,20,5);QWa(a,e+32|0,c,16,20,20,5);QWa(a+8|0,e+40|0,c,16,20,20,5);QWa(a+g|0,e+160|0,c,16,20,20,5);QWa(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function $Va(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,52,6);PWa(e+8|0,b+(8-f)|0,16,c,8,20,52,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,52,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,52,6);QWa(a,e+32|0,c,16,20,20,5);QWa(a+8|0,e+40|0,c,16,20,20,5);QWa(a+g|0,e+160|0,c,16,20,20,5);QWa(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function aWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;QWa(a,b,c,c,20,52,6);QWa(a+8|0,b+8|0,c,c,20,52,6);d=c<<3;QWa(a+d|0,b+d|0,c,c,20,52,6);e=d+8|0;QWa(a+e|0,b+e|0,c,c,20,52,6);return}function bWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,52,20,6);PWa(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,52,20,6);QWa(a,e+32|0,c,16,20,52,6);QWa(a+8|0,e+40|0,c,16,20,52,6);QWa(a+g|0,e+160|0,c,16,20,52,6);QWa(a+h|0,e+168|0,c,16,20,52,6);i=d;return}function cWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;PWa(e|0,b+(-f|0)|0,16,c,8,20,20,5);PWa(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;PWa(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;PWa(e+136|0,b+(h-f)|0,16,c,13,20,20,5);QWa(a,e+32|0,c,16,20,52,6);QWa(a+8|0,e+40|0,c,16,20,52,6);QWa(a+g|0,e+160|0,c,16,20,52,6);QWa(a+h|0,e+168|0,c,16,20,52,6);i=d;return}function dWa(a,b,c){a=a|0;b=b|0;c=c|0;PWa(a,b,c,c,8,52,20,6);return}function eWa(a,b,c){a=a|0;b=b|0;c=c|0;PWa(a,b,c,c,8,20,52,6);return}function fWa(a,b,c){a=a|0;b=b|0;c=c|0;SWa(a,b,c,c,52,20,6);return}function gWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);SWa(a,e+16|0,c,8,52,20,6);i=d;return}function hWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);SWa(a,e+16|0,c,8,52,20,6);i=d;return}function iWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,52,6);SWa(a,e+16|0,c,8,52,20,6);i=d;return}function jWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);SWa(a,e+16|0,c,8,20,20,5);i=d;return}function kWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);SWa(a,e+16|0,c,8,20,20,5);i=d;return}function lWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,52,6);SWa(a,e+16|0,c,8,20,20,5);i=d;return}function mWa(a,b,c){a=a|0;b=b|0;c=c|0;SWa(a,b,c,c,20,52,6);return}function nWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);SWa(a,e+16|0,c,8,20,52,6);i=d;return}function oWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);SWa(a,e+16|0,c,8,20,52,6);i=d;return}function pWa(a,b,c){a=a|0;b=b|0;c=c|0;RWa(a,b,c,c,52,20);return}function qWa(a,b,c){a=a|0;b=b|0;c=c|0;RWa(a,b,c,c,20,52);return}function rWa(a,b,c){a=a|0;b=b|0;c=c|0;QWa(a,b,c,c,52,20,6);return}function sWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);QWa(a,e+16|0,c,8,52,20,6);i=d;return}function tWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);QWa(a,e+16|0,c,8,52,20,6);i=d;return}function uWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,52,6);QWa(a,e+16|0,c,8,52,20,6);i=d;return}function vWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);QWa(a,e+16|0,c,8,20,20,5);i=d;return}function wWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);QWa(a,e+16|0,c,8,20,20,5);i=d;return}function xWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,52,6);QWa(a,e+16|0,c,8,20,20,5);i=d;return}function yWa(a,b,c){a=a|0;b=b|0;c=c|0;QWa(a,b,c,c,20,52,6);return}function zWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);QWa(a,e+16|0,c,8,20,52,6);i=d;return}function AWa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;PWa(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);QWa(a,e+16|0,c,8,20,52,6);i=d;return}function BWa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=8-h|0;k=8-i|0;l=ba(k,j)|0;m=ba(k,h)|0;k=ba(j,i)|0;j=ba(i,h)|0;n=c[485608+(i>>1<<4)+(h>>1<<2)>>2]|0;if((j|0)==0){h=m+k|0;i=(k|0)!=0?f:1;if((g|0)<=0){return}o=i+1|0;p=i+2|0;q=i+3|0;r=i+4|0;s=i+5|0;t=i+6|0;u=i+7|0;v=0;w=e;x=b;while(1){y=ba(d[w]|0,l)|0;a[x]=(y+n+(ba(d[w+i|0]|0,h)|0)|0)>>>6;y=ba(d[w+1|0]|0,l)|0;a[x+1|0]=(y+n+(ba(d[w+o|0]|0,h)|0)|0)>>>6;y=ba(d[w+2|0]|0,l)|0;a[x+2|0]=(y+n+(ba(d[w+p|0]|0,h)|0)|0)>>>6;y=ba(d[w+3|0]|0,l)|0;a[x+3|0]=(y+n+(ba(d[w+q|0]|0,h)|0)|0)>>>6;y=ba(d[w+4|0]|0,l)|0;a[x+4|0]=(y+n+(ba(d[w+r|0]|0,h)|0)|0)>>>6;y=ba(d[w+5|0]|0,l)|0;a[x+5|0]=(y+n+(ba(d[w+s|0]|0,h)|0)|0)>>>6;y=ba(d[w+6|0]|0,l)|0;a[x+6|0]=(y+n+(ba(d[w+t|0]|0,h)|0)|0)>>>6;y=ba(d[w+7|0]|0,l)|0;a[x+7|0]=(y+n+(ba(d[w+u|0]|0,h)|0)|0)>>>6;y=v+1|0;if((y|0)<(g|0)){v=y;w=w+f|0;x=x+f|0}else{break}}return}else{if((g|0)<=0){return}x=f+1|0;w=f+2|0;v=f+3|0;h=f+4|0;u=f+5|0;t=f+6|0;s=f+7|0;r=f+8|0;q=0;p=e;e=b;while(1){b=ba(d[p]|0,l)|0;o=p+1|0;i=ba(d[o]|0,m)|0;y=p+f|0;z=ba(d[y]|0,k)|0;A=p+x|0;a[e]=(b+n+i+z+(ba(d[A]|0,j)|0)|0)>>>6;z=ba(d[o]|0,l)|0;o=p+2|0;i=ba(d[o]|0,m)|0;b=ba(d[A]|0,k)|0;A=p+w|0;a[e+1|0]=(z+n+i+b+(ba(d[A]|0,j)|0)|0)>>>6;b=ba(d[o]|0,l)|0;o=p+3|0;i=ba(d[o]|0,m)|0;z=ba(d[A]|0,k)|0;A=p+v|0;a[e+2|0]=(b+n+i+z+(ba(d[A]|0,j)|0)|0)>>>6;z=ba(d[o]|0,l)|0;o=p+4|0;i=ba(d[o]|0,m)|0;b=ba(d[A]|0,k)|0;A=p+h|0;a[e+3|0]=(z+n+i+b+(ba(d[A]|0,j)|0)|0)>>>6;b=ba(d[o]|0,l)|0;o=p+5|0;i=ba(d[o]|0,m)|0;z=ba(d[A]|0,k)|0;A=p+u|0;a[e+4|0]=(b+n+i+z+(ba(d[A]|0,j)|0)|0)>>>6;z=ba(d[o]|0,l)|0;o=p+6|0;i=ba(d[o]|0,m)|0;b=ba(d[A]|0,k)|0;A=p+t|0;a[e+5|0]=(z+n+i+b+(ba(d[A]|0,j)|0)|0)>>>6;b=ba(d[o]|0,l)|0;o=p+7|0;i=ba(d[o]|0,m)|0;z=ba(d[A]|0,k)|0;A=p+s|0;a[e+6|0]=(b+n+i+z+(ba(d[A]|0,j)|0)|0)>>>6;z=ba(d[o]|0,l)|0;o=ba(d[p+8|0]|0,m)|0;i=ba(d[A]|0,k)|0;a[e+7|0]=(z+n+o+i+(ba(d[p+r|0]|0,j)|0)|0)>>>6;i=q+1|0;if((i|0)<(g|0)){q=i;p=y;e=e+f|0}else{break}}return}}function CWa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=8-h|0;k=8-i|0;l=ba(k,j)|0;m=ba(k,h)|0;k=ba(j,i)|0;j=ba(i,h)|0;n=c[485608+(i>>1<<4)+(h>>1<<2)>>2]|0;if((j|0)==0){h=m+k|0;i=(k|0)!=0?f:1;if((g|0)<=0){return}o=i+1|0;p=i+2|0;q=i+3|0;r=0;s=e;t=b;while(1){u=ba(d[s]|0,l)|0;a[t]=(u+n+(ba(d[s+i|0]|0,h)|0)|0)>>>6;u=ba(d[s+1|0]|0,l)|0;a[t+1|0]=(u+n+(ba(d[s+o|0]|0,h)|0)|0)>>>6;u=ba(d[s+2|0]|0,l)|0;a[t+2|0]=(u+n+(ba(d[s+p|0]|0,h)|0)|0)>>>6;u=ba(d[s+3|0]|0,l)|0;a[t+3|0]=(u+n+(ba(d[s+q|0]|0,h)|0)|0)>>>6;u=r+1|0;if((u|0)<(g|0)){r=u;s=s+f|0;t=t+f|0}else{break}}return}else{if((g|0)<=0){return}t=f+1|0;s=f+2|0;r=f+3|0;h=f+4|0;q=0;p=e;e=b;while(1){b=ba(d[p]|0,l)|0;o=p+1|0;i=ba(d[o]|0,m)|0;u=p+f|0;v=ba(d[u]|0,k)|0;w=p+t|0;a[e]=(b+n+i+v+(ba(d[w]|0,j)|0)|0)>>>6;v=ba(d[o]|0,l)|0;o=p+2|0;i=ba(d[o]|0,m)|0;b=ba(d[w]|0,k)|0;w=p+s|0;a[e+1|0]=(v+n+i+b+(ba(d[w]|0,j)|0)|0)>>>6;b=ba(d[o]|0,l)|0;o=p+3|0;i=ba(d[o]|0,m)|0;v=ba(d[w]|0,k)|0;w=p+r|0;a[e+2|0]=(b+n+i+v+(ba(d[w]|0,j)|0)|0)>>>6;v=ba(d[o]|0,l)|0;o=ba(d[p+4|0]|0,m)|0;i=ba(d[w]|0,k)|0;a[e+3|0]=(v+n+o+i+(ba(d[p+h|0]|0,j)|0)|0)>>>6;i=q+1|0;if((i|0)<(g|0)){q=i;p=u;e=e+f|0}else{break}}return}}function DWa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=8-h|0;k=8-i|0;l=ba(k,j)|0;m=ba(k,h)|0;k=ba(j,i)|0;j=ba(i,h)|0;n=c[485608+(i>>1<<4)+(h>>1<<2)>>2]|0;if((j|0)==0){h=m+k|0;i=(k|0)!=0?f:1;if((g|0)<=0){return}o=i+1|0;p=i+2|0;q=i+3|0;r=i+4|0;s=i+5|0;t=i+6|0;u=i+7|0;v=0;w=e;x=b;while(1){y=ba(d[w]|0,l)|0;a[x]=((d[x]|0)+1+((y+n+(ba(d[w+i|0]|0,h)|0)|0)>>>6)|0)>>>1;y=x+1|0;z=ba(d[w+1|0]|0,l)|0;a[y]=((d[y]|0)+1+((z+n+(ba(d[w+o|0]|0,h)|0)|0)>>>6)|0)>>>1;z=x+2|0;y=ba(d[w+2|0]|0,l)|0;a[z]=((d[z]|0)+1+((y+n+(ba(d[w+p|0]|0,h)|0)|0)>>>6)|0)>>>1;y=x+3|0;z=ba(d[w+3|0]|0,l)|0;a[y]=((d[y]|0)+1+((z+n+(ba(d[w+q|0]|0,h)|0)|0)>>>6)|0)>>>1;z=x+4|0;y=ba(d[w+4|0]|0,l)|0;a[z]=((d[z]|0)+1+((y+n+(ba(d[w+r|0]|0,h)|0)|0)>>>6)|0)>>>1;y=x+5|0;z=ba(d[w+5|0]|0,l)|0;a[y]=((d[y]|0)+1+((z+n+(ba(d[w+s|0]|0,h)|0)|0)>>>6)|0)>>>1;z=x+6|0;y=ba(d[w+6|0]|0,l)|0;a[z]=((d[z]|0)+1+((y+n+(ba(d[w+t|0]|0,h)|0)|0)>>>6)|0)>>>1;y=x+7|0;z=ba(d[w+7|0]|0,l)|0;a[y]=((d[y]|0)+1+((z+n+(ba(d[w+u|0]|0,h)|0)|0)>>>6)|0)>>>1;z=v+1|0;if((z|0)<(g|0)){v=z;w=w+f|0;x=x+f|0}else{break}}return}else{if((g|0)<=0){return}x=f+1|0;w=f+2|0;v=f+3|0;h=f+4|0;u=f+5|0;t=f+6|0;s=f+7|0;r=f+8|0;q=0;p=e;e=b;while(1){b=ba(d[p]|0,l)|0;o=p+1|0;i=ba(d[o]|0,m)|0;z=p+f|0;y=ba(d[z]|0,k)|0;A=p+x|0;a[e]=((d[e]|0)+1+((b+n+i+y+(ba(d[A]|0,j)|0)|0)>>>6)|0)>>>1;y=e+1|0;i=ba(d[o]|0,l)|0;o=p+2|0;b=ba(d[o]|0,m)|0;B=ba(d[A]|0,k)|0;A=p+w|0;a[y]=((d[y]|0)+1+((i+n+b+B+(ba(d[A]|0,j)|0)|0)>>>6)|0)>>>1;B=e+2|0;b=ba(d[o]|0,l)|0;o=p+3|0;i=ba(d[o]|0,m)|0;y=ba(d[A]|0,k)|0;A=p+v|0;a[B]=((d[B]|0)+1+((b+n+i+y+(ba(d[A]|0,j)|0)|0)>>>6)|0)>>>1;y=e+3|0;i=ba(d[o]|0,l)|0;o=p+4|0;b=ba(d[o]|0,m)|0;B=ba(d[A]|0,k)|0;A=p+h|0;a[y]=((d[y]|0)+1+((i+n+b+B+(ba(d[A]|0,j)|0)|0)>>>6)|0)>>>1;B=e+4|0;b=ba(d[o]|0,l)|0;o=p+5|0;i=ba(d[o]|0,m)|0;y=ba(d[A]|0,k)|0;A=p+u|0;a[B]=((d[B]|0)+1+((b+n+i+y+(ba(d[A]|0,j)|0)|0)>>>6)|0)>>>1;y=e+5|0;i=ba(d[o]|0,l)|0;o=p+6|0;b=ba(d[o]|0,m)|0;B=ba(d[A]|0,k)|0;A=p+t|0;a[y]=((d[y]|0)+1+((i+n+b+B+(ba(d[A]|0,j)|0)|0)>>>6)|0)>>>1;B=e+6|0;b=ba(d[o]|0,l)|0;o=p+7|0;i=ba(d[o]|0,m)|0;y=ba(d[A]|0,k)|0;A=p+s|0;a[B]=((d[B]|0)+1+((b+n+i+y+(ba(d[A]|0,j)|0)|0)>>>6)|0)>>>1;y=e+7|0;i=ba(d[o]|0,l)|0;o=ba(d[p+8|0]|0,m)|0;b=ba(d[A]|0,k)|0;a[y]=((d[y]|0)+1+((i+n+o+b+(ba(d[p+r|0]|0,j)|0)|0)>>>6)|0)>>>1;b=q+1|0;if((b|0)<(g|0)){q=b;p=z;e=e+f|0}else{break}}return}}function EWa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=8-h|0;k=8-i|0;l=ba(k,j)|0;m=ba(k,h)|0;k=ba(j,i)|0;j=ba(i,h)|0;n=c[485608+(i>>1<<4)+(h>>1<<2)>>2]|0;if((j|0)==0){h=m+k|0;i=(k|0)!=0?f:1;if((g|0)<=0){return}o=i+1|0;p=i+2|0;q=i+3|0;r=0;s=e;t=b;while(1){u=ba(d[s]|0,l)|0;a[t]=((d[t]|0)+1+((u+n+(ba(d[s+i|0]|0,h)|0)|0)>>>6)|0)>>>1;u=t+1|0;v=ba(d[s+1|0]|0,l)|0;a[u]=((d[u]|0)+1+((v+n+(ba(d[s+o|0]|0,h)|0)|0)>>>6)|0)>>>1;v=t+2|0;u=ba(d[s+2|0]|0,l)|0;a[v]=((d[v]|0)+1+((u+n+(ba(d[s+p|0]|0,h)|0)|0)>>>6)|0)>>>1;u=t+3|0;v=ba(d[s+3|0]|0,l)|0;a[u]=((d[u]|0)+1+((v+n+(ba(d[s+q|0]|0,h)|0)|0)>>>6)|0)>>>1;v=r+1|0;if((v|0)<(g|0)){r=v;s=s+f|0;t=t+f|0}else{break}}return}else{if((g|0)<=0){return}t=f+1|0;s=f+2|0;r=f+3|0;h=f+4|0;q=0;p=e;e=b;while(1){b=ba(d[p]|0,l)|0;o=p+1|0;i=ba(d[o]|0,m)|0;v=p+f|0;u=ba(d[v]|0,k)|0;w=p+t|0;a[e]=((d[e]|0)+1+((b+n+i+u+(ba(d[w]|0,j)|0)|0)>>>6)|0)>>>1;u=e+1|0;i=ba(d[o]|0,l)|0;o=p+2|0;b=ba(d[o]|0,m)|0;x=ba(d[w]|0,k)|0;w=p+s|0;a[u]=((d[u]|0)+1+((i+n+b+x+(ba(d[w]|0,j)|0)|0)>>>6)|0)>>>1;x=e+2|0;b=ba(d[o]|0,l)|0;o=p+3|0;i=ba(d[o]|0,m)|0;u=ba(d[w]|0,k)|0;w=p+r|0;a[x]=((d[x]|0)+1+((b+n+i+u+(ba(d[w]|0,j)|0)|0)>>>6)|0)>>>1;u=e+3|0;i=ba(d[o]|0,l)|0;o=ba(d[p+4|0]|0,m)|0;b=ba(d[w]|0,k)|0;a[u]=((d[u]|0)+1+((i+n+o+b+(ba(d[p+h|0]|0,j)|0)|0)>>>6)|0)>>>1;b=q+1|0;if((b|0)<(g|0)){q=b;p=v;e=e+f|0}else{break}}return}}function FWa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=e;e=c;c=b;b=0;while(1){j=0;do{k=(ba(d[e+j|0]|0,g)|0)>>>9;a[c+j|0]=(k+16+((ba(d[i+j|0]|0,f)|0)>>>9)|0)>>>5;j=j+1|0;}while((j|0)<16);j=b+1|0;if((j|0)<16){i=i+h|0;e=e+h|0;c=c+h|0;b=j}else{break}}return}function GWa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=e;e=c;c=b;b=0;while(1){j=0;do{k=(ba(d[e+j|0]|0,g)|0)>>>9;a[c+j|0]=(k+16+((ba(d[i+j|0]|0,f)|0)>>>9)|0)>>>5;j=j+1|0;}while((j|0)<8);j=b+1|0;if((j|0)<8){i=i+h|0;e=e+h|0;c=c+h|0;b=j}else{break}}return}function HWa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=e;e=c;c=b;b=0;while(1){j=0;do{k=ba(d[e+j|0]|0,g)|0;a[c+j|0]=(k+16+(ba(d[i+j|0]|0,f)|0)|0)>>>5;j=j+1|0;}while((j|0)<16);j=b+1|0;if((j|0)<16){i=i+h|0;e=e+h|0;c=c+h|0;b=j}else{break}}return}function IWa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=e;e=c;c=b;b=0;while(1){j=ba(d[e]|0,g)|0;a[c]=(j+16+(ba(d[i]|0,f)|0)|0)>>>5;j=ba(d[e+1|0]|0,g)|0;a[c+1|0]=(j+16+(ba(d[i+1|0]|0,f)|0)|0)>>>5;j=ba(d[e+2|0]|0,g)|0;a[c+2|0]=(j+16+(ba(d[i+2|0]|0,f)|0)|0)>>>5;j=ba(d[e+3|0]|0,g)|0;a[c+3|0]=(j+16+(ba(d[i+3|0]|0,f)|0)|0)>>>5;j=ba(d[e+4|0]|0,g)|0;a[c+4|0]=(j+16+(ba(d[i+4|0]|0,f)|0)|0)>>>5;j=ba(d[e+5|0]|0,g)|0;a[c+5|0]=(j+16+(ba(d[i+5|0]|0,f)|0)|0)>>>5;j=ba(d[e+6|0]|0,g)|0;a[c+6|0]=(j+16+(ba(d[i+6|0]|0,f)|0)|0)>>>5;j=ba(d[e+7|0]|0,g)|0;a[c+7|0]=(j+16+(ba(d[i+7|0]|0,f)|0)|0)>>>5;j=b+1|0;if((j|0)<8){i=i+h|0;e=e+h|0;c=c+h|0;b=j}else{break}}return}function JWa(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=c*-2|0;m=-c|0;n=c*-3|0;o=c<<1;p=(e|0)!=0;e=(f|0)!=0^3;q=(f|0)==0;f=q|p^1;r=-i|0;s=-k|0;t=-j|0;if(p){u=0;v=b}else{p=0;w=b;while(1){b=w+l|0;x=w+m|0;y=a[x]|0;z=y&255;A=w+c|0;B=d[A]|0;C=a[w]|0;D=C&255;E=B-D|0;F=B-(d[w+o|0]|0)|0;G=D-z|0;do{if(!(C<<24>>24==y<<24>>24)){if(((ba((G|0)>-1?G:-G|0,g)|0)>>7|0)>3){break}D=G<<2;if(f){H=D}else{H=D-B+(d[b]|0)|0}D=H+4>>3;if((D|0)<(r|0)){I=r}else{I=(D|0)>(i|0)?i:D}a[x]=a[1235032+((z|1024)+I)|0]|0;a[w]=a[1235032+(1024-I+(d[w]|0))|0]|0;if(q){break}if((((F|0)>-1?F:-F|0)|0)>(h|0)){break}D=E+F+I>>1;if((D|0)<(t|0)){J=t}else{J=(D|0)>(j|0)?j:D}a[A]=a[1235032+((d[A]|0|1024)-J)|0]|0}}while(0);A=p+1|0;if((A|0)<4){p=A;w=w+1|0}else{break}}return}while(1){w=v+l|0;p=d[w]|0;J=v+m|0;I=a[J]|0;H=I&255;A=p-H|0;F=v+c|0;E=d[F]|0;z=a[v]|0;x=z&255;b=E-x|0;B=p-(d[v+n|0]|0)|0;G=E-(d[v+o|0]|0)|0;y=x-H|0;do{if(!(z<<24>>24==I<<24>>24)){if(((ba((y|0)>-1?y:-y|0,g)|0)>>7|0)>(e|0)){break}x=y<<2;if(f){K=x}else{K=p-E+x|0}x=K+4>>3;if((x|0)<(r|0)){L=r}else{L=(x|0)>(i|0)?i:x}a[J]=a[1235032+((H|1024)+L)|0]|0;a[v]=a[1235032+(1024-L+(d[v]|0))|0]|0;if((((B|0)>-1?B:-B|0)|0)<=(h|0)){x=A+B-L>>1;if((x|0)<(s|0)){M=s}else{M=(x|0)>(k|0)?k:x}a[w]=a[1235032+((d[w]|0|1024)-M)|0]|0}if(q){break}if((((G|0)>-1?G:-G|0)|0)>(h|0)){break}x=b+G+L>>1;if((x|0)<(t|0)){N=t}else{N=(x|0)>(j|0)?j:x}a[F]=a[1235032+((d[F]|0|1024)-N)|0]|0}}while(0);F=u+1|0;if((F|0)<4){u=F;v=v+1|0}else{break}}return}function KWa(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;l=(e|0)!=0;e=(f|0)!=0^3;m=(f|0)==0;f=m|l^1;n=-i|0;o=-k|0;p=-j|0;if(l){q=0;r=b}else{l=0;s=b;while(1){b=s-2|0;t=s-1|0;u=a[t]|0;v=u&255;w=s+1|0;x=d[w]|0;y=a[s]|0;z=y&255;A=x-z|0;B=x-(d[s+2|0]|0)|0;C=z-v|0;do{if(!(y<<24>>24==u<<24>>24)){if(((ba((C|0)>-1?C:-C|0,g)|0)>>7|0)>3){break}D=C<<2;if(f){E=D}else{E=D-x+(d[b]|0)|0}D=E+4>>3;if((D|0)<(n|0)){F=n}else{F=(D|0)>(i|0)?i:D}a[t]=a[1235032+((v|1024)+F)|0]|0;a[s]=a[1235032+(1024-F+z)|0]|0;if(m){break}if((((B|0)>-1?B:-B|0)|0)>(h|0)){break}D=A+B+F>>1;if((D|0)<(p|0)){G=p}else{G=(D|0)>(j|0)?j:D}a[w]=a[1235032+((x|1024)-G)|0]|0}}while(0);x=l+1|0;if((x|0)<4){l=x;s=s+c|0}else{break}}return}while(1){s=r-2|0;l=d[s]|0;G=r-1|0;F=a[G]|0;E=F&255;x=l-E|0;w=r+1|0;B=d[w]|0;A=a[r]|0;z=A&255;v=B-z|0;t=l-(d[r-3|0]|0)|0;b=B-(d[r+2|0]|0)|0;C=z-E|0;do{if(!(A<<24>>24==F<<24>>24)){if(((ba((C|0)>-1?C:-C|0,g)|0)>>7|0)>(e|0)){break}u=C<<2;if(f){H=u}else{H=l-B+u|0}u=H+4>>3;if((u|0)<(n|0)){I=n}else{I=(u|0)>(i|0)?i:u}a[G]=a[1235032+((E|1024)+I)|0]|0;a[r]=a[1235032+(1024-I+z)|0]|0;if((((t|0)>-1?t:-t|0)|0)<=(h|0)){u=x+t-I>>1;if((u|0)<(o|0)){J=o}else{J=(u|0)>(k|0)?k:u}a[s]=a[1235032+((l|1024)-J)|0]|0}if(m){break}if((((b|0)>-1?b:-b|0)|0)>(h|0)){break}u=v+b+I>>1;if((u|0)<(p|0)){K=p}else{K=(u|0)>(j|0)?j:u}a[w]=a[1235032+((B|1024)-K)|0]|0}}while(0);B=q+1|0;if((B|0)<4){q=B;r=r+c|0}else{break}}return}function LWa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;i=-c|0;j=c*-3|0;k=c*-2|0;l=c<<1;m=c*-4|0;n=c*3|0;o=(h|0)==0;h=0;p=b;while(1){b=a[p]|0;q=b&255;r=p+i|0;s=a[r]|0;t=s&255;u=q-t|0;do{if(!(b<<24>>24==s<<24>>24)){v=(ba((u|0)>-1?u:-u|0,e)|0)>>7;if((v|0)>1){break}w=p+j|0;x=d[w]|0;y=p+k|0;z=d[y]|0;A=p+c|0;B=d[A]|0;C=h+g|0;D=d[485592+C|0]|0;E=t+q|0;F=((z+E|0)*26|0)+D+((B+x|0)*25|0)>>7;G=p+l|0;H=d[G]|0;I=d[485576+C|0]|0;C=I+((B+E|0)*26|0)+((H+z|0)*25|0)>>7;E=(v|0)!=0;do{if(E){v=t-f|0;J=t+f|0;if((F|0)<(v|0)){K=v}else{K=(F|0)>(J|0)?J:F}J=q-f|0;v=q+f|0;if((C|0)<(J|0)){L=J;M=K;break}L=(C|0)>(v|0)?v:C;M=K}else{L=C;M=F}}while(0);F=p+m|0;C=((z+x+M|0)*26|0)+D+(((d[F]|0)+q|0)*25|0)>>7;v=p+n|0;J=((H+B+L|0)*26|0)+I+(((d[v]|0)+t|0)*25|0)>>7;N=C&255;O=J&255;do{if(E){P=z-f|0;Q=z+f|0;if((C|0)<(P|0)){R=P&255}else{R=((C|0)>(Q|0)?Q:C)&255}Q=B-f|0;P=B+f|0;if((J|0)<(Q|0)){S=Q&255;T=R;break}S=((J|0)>(P|0)?P:J)&255;T=R}else{S=O;T=N}}while(0);a[y]=T;a[r]=M;a[p]=L;a[A]=S;if(!o){break}a[w]=(((d[r]|0)*25|0)+64+((d[w]|0)*51|0)+(((d[F]|0)+(d[y]|0)|0)*26|0)|0)>>>7;a[G]=(((d[p]|0)*25|0)+64+((d[G]|0)*51|0)+(((d[v]|0)+(d[A]|0)|0)*26|0)|0)>>>7}}while(0);r=h+1|0;if((r|0)<4){h=r;p=p+1|0}else{break}}return}function MWa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=(h|0)==0;h=0;j=b;while(1){b=a[j]|0;k=b&255;l=j-1|0;m=a[l]|0;n=m&255;o=k-n|0;do{if(!(b<<24>>24==m<<24>>24)){p=(ba((o|0)>-1?o:-o|0,e)|0)>>7;if((p|0)>1){break}q=j-3|0;r=d[q]|0;s=j-2|0;t=d[s]|0;u=j+1|0;v=d[u]|0;w=h+g|0;x=d[485592+w|0]|0;y=n+k|0;z=((t+y|0)*26|0)+x+((v+r|0)*25|0)>>7;A=j+2|0;B=d[A]|0;C=d[485576+w|0]|0;w=C+((v+y|0)*26|0)+((B+t|0)*25|0)>>7;y=(p|0)!=0;do{if(y){p=n-f|0;D=n+f|0;if((z|0)<(p|0)){E=p}else{E=(z|0)>(D|0)?D:z}D=k-f|0;p=k+f|0;if((w|0)<(D|0)){F=D;G=E;break}F=(w|0)>(p|0)?p:w;G=E}else{F=w;G=z}}while(0);z=d[j-4|0]|0;w=((t+r+G|0)*26|0)+x+((z+k|0)*25|0)>>7;p=d[j+3|0]|0;D=((B+v+F|0)*26|0)+C+((p+n|0)*25|0)>>7;H=w&255;I=D&255;do{if(y){J=t-f|0;K=t+f|0;if((w|0)<(J|0)){L=J&255}else{L=((w|0)>(K|0)?K:w)&255}K=v-f|0;J=v+f|0;if((D|0)<(K|0)){M=K&255;N=L;break}M=((D|0)>(J|0)?J:D)&255;N=L}else{M=I;N=H}}while(0);a[s]=N;a[l]=G;a[j]=F;a[u]=M;if(!i){break}a[q]=(((G&255)*25|0)+64+(r*51|0)+((z+(N&255)|0)*26|0)|0)>>>7;a[A]=(((F&255)*25|0)+64+(B*51|0)+((p+(M&255)|0)*26|0)|0)>>>7}}while(0);l=h+1|0;if((l|0)<4){h=l;j=j+c|0}else{break}}return}function NWa(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=b*-2|0;k=a+j|0;l=a+b|0;m=a+(j|1)|0;n=a+(b+1)|0;o=a+(j+2)|0;p=a+(b+2)|0;q=a+(j+3)|0;j=(d[k]|0)-(d[a+(-b|0)|0]|0)+(d[m]|0)-(d[a+(1-b)|0]|0)+(d[o]|0)-(d[a+(2-b)|0]|0)+(d[q]|0)-(d[a+(3-b)|0]|0)|0;r=a+(b+3)|0;s=(d[l]|0)-(d[a]|0)+(d[n]|0)-(d[a+1|0]|0)+(d[p]|0)-(d[a+2|0]|0)+(d[r]|0)-(d[a+3|0]|0)|0;t=e<<2;c[h>>2]=(((j|0)>-1?j:-j|0)|0)<(t|0);j=(((s|0)>-1?s:-s|0)|0)<(t|0);c[i>>2]=j&1;i=c[h>>2]|0;if((g|0)==0|((i|0)!=0|j)^1){u=0;return u|0}g=b*-3|0;h=b<<1;b=(d[k]|0)-(d[a+g|0]|0)+(d[m]|0)-(d[a+(g+1)|0]|0)+(d[o]|0)-(d[a+(g+2)|0]|0)+(d[q]|0)-(d[a+(g+3)|0]|0)|0;g=(d[l]|0)-(d[a+h|0]|0)+(d[n]|0)-(d[a+(h|1)|0]|0)+(d[p]|0)-(d[a+(h+2)|0]|0)+(d[r]|0)-(d[a+(h+3)|0]|0)|0;if((i|0)==0){v=0}else{v=(((b|0)>-1?b:-b|0)|0)<(f|0)}if(j){w=(((g|0)>-1?g:-g|0)|0)<(f|0)}else{w=0}u=v&w&1;return u|0}function OWa(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=a-2|0;k=a+1|0;l=a+(b-2)|0;m=a+(b+1)|0;n=b<<1;o=a+(n-2)|0;p=a+(n|1)|0;q=n+b|0;r=a+(q-2)|0;s=(d[j]|0)-(d[a-1|0]|0)+(d[l]|0)-(d[a+(b-1)|0]|0)+(d[o]|0)-(d[a+(n-1)|0]|0)+(d[r]|0)-(d[a+(q-1)|0]|0)|0;t=a+(q+1)|0;u=(d[k]|0)-(d[a]|0)+(d[m]|0)-(d[a+b|0]|0)+(d[p]|0)-(d[a+n|0]|0)+(d[t]|0)-(d[a+q|0]|0)|0;v=e<<2;c[h>>2]=(((s|0)>-1?s:-s|0)|0)<(v|0);s=(((u|0)>-1?u:-u|0)|0)<(v|0);c[i>>2]=s&1;i=c[h>>2]|0;if((g|0)==0|((i|0)!=0|s)^1){w=0;return w|0}g=(d[j]|0)-(d[a-3|0]|0)+(d[l]|0)-(d[a+(b-3)|0]|0)+(d[o]|0)-(d[a+(n-3)|0]|0)+(d[r]|0)-(d[a+(q-3)|0]|0)|0;r=(d[k]|0)-(d[a+2|0]|0)+(d[m]|0)-(d[a+(b+2)|0]|0)+(d[p]|0)-(d[a+(n+2)|0]|0)+(d[t]|0)-(d[a+(q+2)|0]|0)|0;if((i|0)==0){x=0}else{x=(((g|0)>-1?g:-g|0)|0)<(f|0)}if(s){y=(((r|0)>-1?r:-r|0)|0)<(f|0)}else{y=0}w=x&y&1;return w|0}function PWa(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((g|0)<=0){return}k=1<<j-1;l=c;c=b;b=0;while(1){m=l+3|0;n=l-1|0;o=l+2|0;p=ba(d[l]|0,h)|0;q=l+1|0;a[c]=a[((d[l-2|0]|0)+k+(d[m]|0)+(((d[o]|0)+(d[n]|0)|0)*-5|0)+p+(ba(d[q]|0,i)|0)>>j)+1236056|0]|0;p=l+4|0;r=ba(d[q]|0,h)|0;a[c+1|0]=a[((d[n]|0)+k+(d[p]|0)+(((d[m]|0)+(d[l]|0)|0)*-5|0)+r+(ba(d[o]|0,i)|0)>>j)+1236056|0]|0;r=l+5|0;n=ba(d[o]|0,h)|0;a[c+2|0]=a[((d[l]|0)+k+(d[r]|0)+(((d[p]|0)+(d[q]|0)|0)*-5|0)+n+(ba(d[m]|0,i)|0)>>j)+1236056|0]|0;n=l+6|0;s=ba(d[m]|0,h)|0;a[c+3|0]=a[((d[q]|0)+k+(d[n]|0)+(((d[r]|0)+(d[o]|0)|0)*-5|0)+s+(ba(d[p]|0,i)|0)>>j)+1236056|0]|0;s=l+7|0;q=ba(d[p]|0,h)|0;a[c+4|0]=a[((d[o]|0)+k+(d[s]|0)+(((d[n]|0)+(d[m]|0)|0)*-5|0)+q+(ba(d[r]|0,i)|0)>>j)+1236056|0]|0;q=l+8|0;o=ba(d[r]|0,h)|0;a[c+5|0]=a[((d[m]|0)+k+(d[q]|0)+(((d[s]|0)+(d[p]|0)|0)*-5|0)+o+(ba(d[n]|0,i)|0)>>j)+1236056|0]|0;o=l+9|0;m=ba(d[n]|0,h)|0;a[c+6|0]=a[((d[p]|0)+k+(d[o]|0)+(((d[q]|0)+(d[r]|0)|0)*-5|0)+m+(ba(d[s]|0,i)|0)>>j)+1236056|0]|0;m=ba(d[s]|0,h)|0;a[c+7|0]=a[((d[r]|0)+k+(d[l+10|0]|0)+(((d[o]|0)+(d[n]|0)|0)*-5|0)+m+(ba(d[q]|0,i)|0)>>j)+1236056|0]|0;q=b+1|0;if((q|0)<(g|0)){l=l+f|0;c=c+e|0;b=q}else{break}}return}function QWa(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=f*-2|0;k=-f|0;l=f<<1;m=f*3|0;n=f<<2;o=f*5|0;p=f*6|0;q=f*7|0;r=f<<3;s=f*9|0;t=f*10|0;u=1<<i-1;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=0;C=c;c=b;while(1){b=d[C+k|0]|0;D=d[C]|0;E=d[C+f|0]|0;F=d[C+l|0]|0;G=d[C+m|0]|0;H=d[C+n|0]|0;I=d[C+o|0]|0;J=d[C+p|0]|0;K=d[C+q|0]|0;L=d[C+r|0]|0;M=d[C+s|0]|0;N=d[C+t|0]|0;a[c]=((d[c]|0)+1+(d[((d[C+j|0]|0)+u+(ba(D,g)|0)+(ba(E,h)|0)+G+((F+b|0)*-5|0)>>i)+1236056|0]|0)|0)>>>1;O=c+e|0;a[O]=((d[O]|0)+1+(d[(b+u+(ba(E,g)|0)+(ba(F,h)|0)+H+((G+D|0)*-5|0)>>i)+1236056|0]|0)|0)>>>1;b=c+v|0;a[b]=((d[b]|0)+1+(d[(D+u+(ba(F,g)|0)+(ba(G,h)|0)+I+((H+E|0)*-5|0)>>i)+1236056|0]|0)|0)>>>1;D=c+w|0;a[D]=((d[D]|0)+1+(d[(E+u+(ba(G,g)|0)+(ba(H,h)|0)+J+((I+F|0)*-5|0)>>i)+1236056|0]|0)|0)>>>1;E=c+x|0;a[E]=((d[E]|0)+1+(d[(F+u+(ba(H,g)|0)+(ba(I,h)|0)+K+((J+G|0)*-5|0)>>i)+1236056|0]|0)|0)>>>1;F=c+y|0;a[F]=((d[F]|0)+1+(d[(G+u+(ba(I,g)|0)+(ba(J,h)|0)+L+((K+H|0)*-5|0)>>i)+1236056|0]|0)|0)>>>1;G=c+z|0;a[G]=((d[G]|0)+1+(d[(H+u+(ba(J,g)|0)+(ba(K,h)|0)+M+((L+I|0)*-5|0)>>i)+1236056|0]|0)|0)>>>1;H=c+A|0;a[H]=((d[H]|0)+1+(d[(I+u+(ba(K,g)|0)+(ba(L,h)|0)+N+((M+J|0)*-5|0)>>i)+1236056|0]|0)|0)>>>1;J=B+1|0;if((J|0)<8){B=J;C=C+1|0;c=c+1|0}else{break}}return}function RWa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=c;c=b;b=0;while(1){j=i+3|0;k=i-1|0;l=i+2|0;m=ba(d[i]|0,g)|0;n=i+1|0;a[c]=((d[c]|0)+1+(d[((d[i-2|0]|0)+32+(d[j]|0)+(((d[l]|0)+(d[k]|0)|0)*-5|0)+m+(ba(d[n]|0,h)|0)>>6)+1236056|0]|0)|0)>>>1;m=c+1|0;o=i+4|0;p=ba(d[n]|0,g)|0;a[m]=((d[m]|0)+1+(d[((d[k]|0)+32+(d[o]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+p+(ba(d[l]|0,h)|0)>>6)+1236056|0]|0)|0)>>>1;p=c+2|0;k=i+5|0;m=ba(d[l]|0,g)|0;a[p]=((d[p]|0)+1+(d[((d[i]|0)+32+(d[k]|0)+(((d[o]|0)+(d[n]|0)|0)*-5|0)+m+(ba(d[j]|0,h)|0)>>6)+1236056|0]|0)|0)>>>1;m=c+3|0;p=i+6|0;q=ba(d[j]|0,g)|0;a[m]=((d[m]|0)+1+(d[((d[n]|0)+32+(d[p]|0)+(((d[k]|0)+(d[l]|0)|0)*-5|0)+q+(ba(d[o]|0,h)|0)>>6)+1236056|0]|0)|0)>>>1;q=c+4|0;n=i+7|0;m=ba(d[o]|0,g)|0;a[q]=((d[q]|0)+1+(d[((d[l]|0)+32+(d[n]|0)+(((d[p]|0)+(d[j]|0)|0)*-5|0)+m+(ba(d[k]|0,h)|0)>>6)+1236056|0]|0)|0)>>>1;m=c+5|0;l=i+8|0;q=ba(d[k]|0,g)|0;a[m]=((d[m]|0)+1+(d[((d[j]|0)+32+(d[l]|0)+(((d[n]|0)+(d[o]|0)|0)*-5|0)+q+(ba(d[p]|0,h)|0)>>6)+1236056|0]|0)|0)>>>1;q=c+6|0;j=i+9|0;m=ba(d[p]|0,g)|0;a[q]=((d[q]|0)+1+(d[((d[o]|0)+32+(d[j]|0)+(((d[l]|0)+(d[k]|0)|0)*-5|0)+m+(ba(d[n]|0,h)|0)>>6)+1236056|0]|0)|0)>>>1;m=c+7|0;o=ba(d[n]|0,g)|0;a[m]=((d[m]|0)+1+(d[((d[k]|0)+32+(d[i+10|0]|0)+(((d[j]|0)+(d[p]|0)|0)*-5|0)+o+(ba(d[l]|0,h)|0)>>6)+1236056|0]|0)|0)>>>1;l=b+1|0;if((l|0)<8){i=i+f|0;c=c+e|0;b=l}else{break}}return}function SWa(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;j=f*-2|0;k=-f|0;l=f<<1;m=f*3|0;n=f<<2;o=f*5|0;p=f*6|0;q=f*7|0;r=f<<3;s=f*9|0;t=f*10|0;u=1<<i-1;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=0;C=c;c=b;while(1){b=d[C+k|0]|0;D=d[C]|0;E=d[C+f|0]|0;F=d[C+l|0]|0;G=d[C+m|0]|0;H=d[C+n|0]|0;I=d[C+o|0]|0;J=d[C+p|0]|0;K=d[C+q|0]|0;L=d[C+r|0]|0;M=d[C+s|0]|0;N=d[C+t|0]|0;a[c]=a[((d[C+j|0]|0)+u+(ba(D,g)|0)+(ba(E,h)|0)+G+((F+b|0)*-5|0)>>i)+1236056|0]|0;a[c+e|0]=a[(b+u+(ba(E,g)|0)+(ba(F,h)|0)+H+((G+D|0)*-5|0)>>i)+1236056|0]|0;a[c+v|0]=a[(D+u+(ba(F,g)|0)+(ba(G,h)|0)+I+((H+E|0)*-5|0)>>i)+1236056|0]|0;a[c+w|0]=a[(E+u+(ba(G,g)|0)+(ba(H,h)|0)+J+((I+F|0)*-5|0)>>i)+1236056|0]|0;a[c+x|0]=a[(F+u+(ba(H,g)|0)+(ba(I,h)|0)+K+((J+G|0)*-5|0)>>i)+1236056|0]|0;a[c+y|0]=a[(G+u+(ba(I,g)|0)+(ba(J,h)|0)+L+((K+H|0)*-5|0)>>i)+1236056|0]|0;a[c+z|0]=a[(H+u+(ba(J,g)|0)+(ba(K,h)|0)+M+((L+I|0)*-5|0)>>i)+1236056|0]|0;a[c+A|0]=a[(I+u+(ba(K,g)|0)+(ba(L,h)|0)+N+((M+J|0)*-5|0)>>i)+1236056|0]|0;J=B+1|0;if((J|0)<8){B=J;C=C+1|0;c=c+1|0}else{break}}return}function TWa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=i;k=c[h+24>>2]|0;l=h+28|0;h=c[l>>2]|0;if((h|0)<5){yDb(e,16,2182128,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=j;return n|0}o=k;p=fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=p>>>14<<1&6;q=p>>>4<<2&12|16;if(((p>>>16)+4|0)!=(h|0)|q>>>0>24>>>0){yDb(e,16,2105168,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=j;return n|0}m=o+2|0;p=e+796|0;c[p>>2]=q;c[e+420>>2]=(q|0)==16?1:2;r=e+416|0;c[r>>2]=m;if((o|0)==0){s=e+448|0;c[s>>2]=3;c[s+4>>2]=0}else if((o|0)==6){s=e+448|0;c[s>>2]=1610612799;c[s+4>>2]=0}else if((o|0)==4){s=e+448|0;c[s>>2]=63;c[s+4>>2]=0}else if((o|0)==2){o=e+448|0;c[o>>2]=51;c[o+4>>2]=0}c[e+412>>2]=48e3;o=q+4|0;c[e+72>>2]=((48e3/((h<<3|0)/(ba(o,m)|0)|0|0)|0)<<5)+(ba(m*48e3|0,o)|0);q=k+4|0;k=o>>>2;o=f+76|0;c[o>>2]=(((h-4|0)/(k|0)|0)<<1|0)/(m|0)|0;m=_$a(e,f,0)|0;if((m|0)<0){n=m;i=j;return n|0}m=ba((ba(c[r>>2]|0,c[o>>2]|0)|0)/2|0,k)|0;k=c[p>>2]|0;do{if((k|0)==24){if((m|0)<=6){break}p=m;o=q;r=c[f>>2]|0;while(1){c[r>>2]=(d[1148864+(d[o+1|0]|0)|0]|0)<<16|(d[1148864+(d[o+2|0]|0)|0]|0)<<24|(d[1148864+(d[o]|0)|0]|0)<<8;c[r+4>>2]=(d[1148864+(d[o+5|0]|0)|0]|0)<<20|(d[1148864+(a[o+6|0]&240)|0]|0)<<28|(d[1148864+(d[o+4|0]|0)|0]|0)<<12|(d[1148864+(a[o+3|0]&15)|0]|0)<<4;e=p-7|0;if((e|0)>6){p=e;o=o+7|0;r=r+8|0}else{break}}}else{r=c[f>>2]|0;if((k|0)==20){if((m|0)<=5){break}o=m;p=q;e=r;while(1){c[e>>2]=(d[1148864+(d[p+1|0]|0)|0]|0)<<20|(d[1148864+(a[p+2|0]&240)|0]|0)<<28|(d[1148864+(d[p]|0)|0]|0)<<12;c[e+4>>2]=(d[1148864+(d[p+4|0]|0)|0]|0)<<20|(d[1148864+(a[p+5|0]&240)|0]|0)<<28|(d[1148864+(d[p+3|0]|0)|0]|0)<<12;h=o-6|0;if((h|0)>5){o=h;p=p+6|0;e=e+8|0}else{break}}}else{if((m|0)<=4){break}e=m;p=q;o=r;while(1){b[o>>1]=d[1148864+(d[p]|0)|0]|0|(d[1148864+(d[p+1|0]|0)|0]|0)<<8;b[o+2>>1]=(d[1148864+(d[p+3|0]|0)|0]|0)<<4|(d[1148864+(a[p+4|0]&240)|0]|0)<<12|(a[1148864+(d[p+2|0]|0)|0]&255)>>>4;h=e-5|0;if((h|0)>4){e=h;p=p+5|0;o=o+4|0}else{break}}}}}while(0);c[g>>2]=1;n=c[l>>2]|0;i=j;return n|0}function UWa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=c[b+60>>2]|0;f=b+416|0;g=c[f>>2]|0;if((g&1|0)!=0|(g|0)>8){yDb(b,16,2105080,(h=i,i=i+8|0,c[h>>2]=g,h)|0);i=h;j=-22;i=d;return j|0}k=c[b+420>>2]|0;do{if((k|0)==2){l=b+796|0;m=c[l>>2]|0;if((m|0)>20){if((m|0)>24){yDb(b,24,2048368,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;n=c[f>>2]|0}else{n=g}c[l>>2]=24;o=n;p=28;break}else{if((m|0)==0){c[l>>2]=24;o=g;p=28;break}else{c[l>>2]=20;o=g;p=24;break}}}else if((k|0)==1){c[b+796>>2]=16;o=g;p=20}else{o=g;p=(c[b+796>>2]|0)+4|0}}while(0);c[b+424>>2]=0;c[b+72>>2]=ba(o*48e3|0,p)|0;a[e]=0;j=0;i=d;return j|0}function VWa(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0;i=c[d+60>>2]|0;j=g+76|0;k=d+416|0;l=ba(c[k>>2]|0,c[j>>2]|0)|0;m=d+796|0;n=(ba(l,(c[m>>2]|0)+4|0)|0)/8|0;l=n+4|0;o=r0a(d,f,l,(l|0)<0|0?-1:0)|0;if((o|0)<0){p=o;return p|0}o=c[f+24>>2]|0;f=fe(((((c[k>>2]|0)+524286|0)>>>1|n<<2)<<10|(((c[m>>2]|0)-16|0)/4|0))<<4|0)|0;n=(l&268435456|0)!=0?0:o;x=f;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;o=c[m>>2]|0;a:do{if((o|0)==24){if((c[j>>2]|0)<=0){break}m=n;f=c[g>>2]|0;l=1;while(1){if((c[k>>2]|0)>0){d=(a[i]|0)==0?16:0;q=m;r=f;s=0;while(1){a[q]=a[1148864+((c[r>>2]|0)>>>8&255)|0]|0;a[q+1|0]=a[1148864+((c[r>>2]|0)>>>16&255)|0]|0;a[q+2|0]=a[1148864+((c[r>>2]|0)>>>24)|0]|0;t=r+4|0;a[q+3|0]=a[1148864+((c[t>>2]|0)>>>4&240)|0]|d;a[q+4|0]=a[1148864+((c[t>>2]|0)>>>12&255)|0]|0;a[q+5|0]=a[1148864+((c[t>>2]|0)>>>20&255)|0]|0;a[q+6|0]=a[1148864+((c[t>>2]|0)>>>28)|0]|0;t=q+7|0;u=r+8|0;v=s+2|0;if((v|0)<(c[k>>2]|0)){q=t;r=u;s=v}else{w=t;y=u;break}}}else{w=m;y=f}s=(a[i]|0)+1&255;a[i]=(s&255)>>>0>191>>>0?0:s;if((l|0)>=(c[j>>2]|0)){break a}m=w;f=y;l=l+1|0}}else if((o|0)==20){if((c[j>>2]|0)<=0){break}l=n;f=c[g>>2]|0;m=1;while(1){if((c[k>>2]|0)>0){s=(a[i]|0)==0?128:0;r=l;q=0;d=f;while(1){a[r]=a[1148864+((c[d>>2]|0)>>>12&255)|0]|0;a[r+1|0]=a[1148864+((c[d>>2]|0)>>>20&255)|0]|0;a[r+2|0]=a[1148864+((c[d>>2]|0)>>>28|s)|0]|0;u=d+4|0;a[r+3|0]=a[1148864+((c[u>>2]|0)>>>12&255)|0]|0;a[r+4|0]=a[1148864+((c[u>>2]|0)>>>20&255)|0]|0;a[r+5|0]=a[1148864+((c[u>>2]|0)>>>28)|0]|0;u=r+6|0;t=d+8|0;v=q+2|0;if((v|0)<(c[k>>2]|0)){r=u;q=v;d=t}else{z=u;A=t;break}}}else{z=l;A=f}d=(a[i]|0)+1&255;a[i]=(d&255)>>>0>191>>>0?0:d;if((m|0)>=(c[j>>2]|0)){break a}l=z;f=A;m=m+1|0}}else if((o|0)==16){if((c[j>>2]|0)<=0){break}m=n;f=1;l=c[g>>2]|0;while(1){if((c[k>>2]|0)>0){d=(a[i]|0)==0?16:0;q=m;r=0;s=l;while(1){a[q]=a[1148864+(b[s>>1]&255)|0]|0;a[q+1|0]=a[1148864+((e[s>>1]|0)>>>8)|0]|0;t=s+2|0;a[q+2|0]=a[1148864+(e[t>>1]<<4&240)|0]|d;a[q+3|0]=a[1148864+((e[t>>1]|0)>>>4&255)|0]|0;a[q+4|0]=a[1148864+((e[t>>1]|0)>>>12)|0]|0;t=q+5|0;u=s+4|0;v=r+2|0;if((v|0)<(c[k>>2]|0)){q=t;r=v;s=u}else{B=t;C=u;break}}}else{B=m;C=l}s=(a[i]|0)+1&255;a[i]=(s&255)>>>0>191>>>0?0:s;if((f|0)>=(c[j>>2]|0)){break a}m=B;f=f+1|0;l=C}}}while(0);c[h>>2]=1;p=0;return p|0}function WWa(a){a=a|0;var b=0;b=c[a+60>>2]|0;IAb(b,0,2048);IAb(b+1024|0,0,2048);IAb(b+2048|0,0,2048);return qhb(a)|0}function XWa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=d;m=c[f+24>>2]|0;n=c[b+60>>2]|0;o=f+28|0;if((m|0)==0){p=d+12|0;q=p;r=c[q>>2]|0;s=(r|0)!=0;t=s&1;c[e>>2]=t;u=c[o>>2]|0;i=g;return u|0}if((c[o>>2]|0)<=0){p=d+12|0;q=p;r=c[q>>2]|0;s=(r|0)!=0;t=s&1;c[e>>2]=t;u=c[o>>2]|0;i=g;return u|0}v=eEb(m)|0;m=n+1024|0;w=m;PAb(w);c[h>>2]=0;x=rAb(v,2182120)|0;a:do{if((x|0)!=0){y=n+1028|0;z=n;A=x;b:while(1){B=a[A+2|0]|0;do{if(B<<24>>24==62){C=9}else{if((EAb(B<<24>>24)|0)!=0){C=9;break}D=A+1|0}}while(0);c:do{if((C|0)==9){C=0;if((c[y>>2]|0)!=0){KAb(w,2105072,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E}B=xAb(A,2048360,h)|0;if((B|0)==0){break a}F=c[h>>2]|0;if((F|0)==0){break a}if((rAb(B,2002880)|0)==0){if((rAb(B,1965464)|0)==0){G=w}else{C=15}}else{C=15}if((C|0)==15){C=0;PAb(z);G=z}B=F;while(1){if((EAb(a[B]|0)|0)==0){break}else{B=B+1|0}}if((RGb(B,1937400,6)|0)==0){break b}else{H=0;I=B}while(1){F=a[I]|0;if((F<<24>>24|0)==0){D=I;break c}else if((F<<24>>24|0)==60){if((zAb(I,2182120,2)|0)==0){J=a[I+2|0]|0;if(J<<24>>24==62){D=I;break c}if((EAb(J<<24>>24)|0)!=0){D=I;break c}}if((zAb(I,1913568,3)|0)==0){KAb(G,2105072,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;K=I}else{K=I}while(1){J=K+1|0;L=a[J]|0;if((L<<24>>24|0)==62){break}else if((L<<24>>24|0)==0){D=J;break c}else{K=J}}J=K+2|0;M=J;N=a[J]|0}else{M=I;N=F}do{if((EAb(N<<24>>24)|0)==0){MAb(G,a[M]|0,1)}else{if((H|0)!=0){break}MAb(G,32,1)}}while(0);H=EAb(a[M]|0)|0;I=M+1|0}}}while(0);c[h>>2]=0;A=rAb(D,2182120)|0;if((A|0)==0){break a}}ZDb(v);p=d+12|0;q=p;r=c[q>>2]|0;s=(r|0)!=0;t=s&1;c[e>>2]=t;u=c[o>>2]|0;i=g;return u|0}}while(0);D=n+2048|0;h=D;PAb(h);if((c[n+4>>2]|0)!=0){KAb(h,1893104,(E=i,i=i+8|0,c[E>>2]=c[n>>2],E)|0);i=E}KAb(h,2350728,(E=i,i=i+8|0,c[E>>2]=c[m>>2],E)|0);i=E;ZDb(v);v=f+8|0;E=c[v>>2]|0;m=c[v+4>>2]|0;v=b+104|0;c[j>>2]=1;c[j+4>>2]=100;b=KDb(E,m,v,j)|0;j=c[f+48>>2]|0;if((j|0)==-1){O=-1}else{c[k>>2]=1;c[k+4>>2]=100;f=KDb(j,(j|0)<0|0?-1:0,v,k)|0;O=f}shb(l,c[D>>2]|0,b,O,0)|0;p=d+12|0;q=p;r=c[q>>2]|0;s=(r|0)!=0;t=s&1;c[e>>2]=t;u=c[o>>2]|0;i=g;return u|0}function YWa(a){a=a|0;var b=0;b=c[a+60>>2]|0;QAb(b,0)|0;QAb(b+1024|0,0)|0;QAb(b+2048|0,0)|0;return 0}function ZWa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=a+100|0;g=(c[f>>2]|0)==0;h=e+16|0;c[h>>2]=g&1;c[a+140>>2]=g?44:11;g=c[a+120>>2]|0;j=c[a+124>>2]|0;c[e+2588>>2]=g;c[e+2592>>2]=j;c[e+2656>>2]=ba(j,g)|0;k=g+7&-8;c[e+2596>>2]=k;l=j+7&-8;c[e+2600>>2]=l;c[e+2660>>2]=ba(k<<1,l)|0;c[e+2584>>2]=g;if((lXa(e)|0)!=0){yDb(a,16,2138424,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-12;i=b;return n|0}nXa(e+3184|0,986648,986632,4);nXa(e+7280|0,986616,986600,8);if((c[h>>2]|0)!=0){n=0;i=b;return n|0}if((c[f>>2]|0)<1026){yDb(a,16,2131848,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=b;return n|0}m=c[a+96>>2]|0;a=m;c[e+20>>2]=(d[a]|d[a+1|0]<<8)<<16>>16&65535;a=e+24|0;e=0;while(1){f=m+(e<<2|2)|0;c[a+(e<<2)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|-16777216;f=e+1|0;if((f|0)<256){e=f}else{n=0;break}}i=b;return n|0}function _Wa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0;j=i;k=c[e+60>>2]|0;l=k;m=k+2608|0;c[m>>2]=f;f=c[h+24>>2]|0;n=h+28|0;h=c[n>>2]|0;if(!((h|0)>-1)){yDb(0,0,2157944,(o=i,i=i+24|0,c[o>>2]=2151072,c[o+8>>2]=2144016,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}p=k+4|0;c[p>>2]=f;q=k+12|0;c[q>>2]=f;r=f+h|0;s=k+8|0;c[s>>2]=r;a:do{if((c[k+16>>2]|0)==0){do{if(h>>>0>7>>>0){t=e;u=k+24|0;v=u;w=k+2588|0;y=k+2592|0;z=k;A=k+2656|0;B=k+2596|0;C=k+2600|0;D=k+2660|0;E=k+2584|0;F=k+2612|0;G=k+2652|0;H=k+2620|0;I=k+2616|0;J=k+2632|0;K=k+2636|0;L=k+2604|0;M=k+1048|0;N=k+2624|0;O=0;P=f;Q=f;R=r;b:while(1){S=P+4|0;c[p>>2]=S;T=P;U=fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0;T=P+8|0;c[p>>2]=T;V=S;S=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;W=fe(S|0)|0;V=T;X=V-Q|0;Y=R-V|0;if(Y>>>0<W>>>0){Z=7;break}c:do{if((U|0)==1481654604){if((W|0)==6|(W|0)==4){V=0;while(1){_=v+(V<<2)|0;$=c[_>>2]|0;aa=V*3|0;ca=(($>>>16&255)*129|0)+(b[M+(aa<<1)>>1]|0)>>7;if(ca>>>0>255>>>0){da=-ca>>31&255}else{da=ca&255}ca=(($>>>8&255)*129|0)+(b[M+(aa+1<<1)>>1]|0)>>7;if(ca>>>0>255>>>0){ea=-ca>>31&255}else{ea=ca&255}ca=(($&255)*129|0)+(b[M+(aa+2<<1)>>1]|0)>>7;if(ca>>>0>255>>>0){fa=-ca>>31&255}else{fa=ca&255}c[_>>2]=(da&255)<<16|(ea&255)<<8|fa&255|-16777216;_=V+1|0;if((_|0)<256){V=_}else{ga=O;break}}}else{if(W>>>0<1540>>>0){Z=187;break b}V=P+12|0;c[p>>2]=V;_=0;ca=V;while(1){c[p>>2]=ca+2;V=ca;b[M+(_<<1)>>1]=(d[V]|d[V+1|0]<<8)<<16>>16;V=_+1|0;if((V|0)>=768){break}_=V;ca=c[p>>2]|0}if(W>>>0>3843>>>0){ca=0;while(1){_=c[p>>2]|0;c[p>>2]=_+3;c[v+(ca<<2)>>2]=d[_]<<16|d[_+1|0]<<8|d[_+2|0]|-16777216;_=ca+1|0;if((_|0)<256){ca=_}else{ga=O;break}}}else{TGb(u|0,0,1024)|0;ga=O;break}}}else if((U|0)==1179927368){UGb(c[F>>2]|0,c[N>>2]|0,c[D>>2]|0)|0;ga=O}else if((U|0)==1398034258){ga=1}else if((U|0)==1179599434){if(W>>>0<16>>>0){ha=-1094995529;Z=238;break b}ca=P+10|0;c[p>>2]=ca;_=T;ia=(d[_]|d[_+1|0]<<8)<<16>>16&65535;_=P+12|0;c[p>>2]=_;V=ca;ca=(d[V]|d[V+1|0]<<8)<<16>>16&65535;V=P+14|0;c[p>>2]=V;aa=_;_=(d[aa]|d[aa+1|0]<<8)<<16>>16&65535;aa=P+16|0;c[p>>2]=aa;$=V;V=(d[$]|d[$+1|0]<<8)<<16>>16;$=V&65535;ja=P+18|0;c[p>>2]=ja;ka=aa;aa=(d[ka]|d[ka+1|0]<<8)<<16>>16;ka=aa&65535;if(V<<16>>16==0|aa<<16>>16==0){Z=15;break b}V=c[w>>2]|0;la=$+ca|0;ma=(V|0)<(la|0);na=c[y>>2]|0;oa=ka+_|0;pa=(na|0)<(oa|0);if(ma|pa){qa=V$a(c[z>>2]|0,ma?la:V,pa?oa:na)|0;if((qa|0)<0){ha=qa;Z=238;break b}qa=c[w>>2]|0;na=(la|0)>(qa|0)?la:qa;qa=c[y>>2]|0;la=(oa|0)>(qa|0)?oa:qa;c[w>>2]=na;c[y>>2]=la;c[A>>2]=ba(la,na)|0;qa=na+7&-8;c[B>>2]=qa;oa=la+7&-8;c[C>>2]=oa;c[D>>2]=ba(qa<<1,oa)|0;c[E>>2]=na;if((lXa(l)|0)!=0){Z=20;break b}ra=c[p>>2]|0;sa=c[s>>2]|0}else{ra=ja;sa=R}ja=sa;na=ja-ra|0;oa=na>>>0>4>>>0?4:na;na=ra+oa|0;c[p>>2]=na;if((ia|0)==37){qa=c[E>>2]|0;if((ja-na|0)<1){ta=0;ua=na}else{la=ra+(oa+1)|0;c[p>>2]=la;ta=d[na]|0;ua=la}if((ja-ua|0)<1){va=0;wa=ua}else{la=ua+1|0;c[p>>2]=la;va=d[ua]|0;wa=la}if((ja-wa|0)<2){xa=0;ya=wa}else{la=wa+2|0;c[p>>2]=la;pa=wa;xa=(d[pa]|d[pa+1|0]<<8)<<16>>16&1;ya=la}if((ja-ya|0)<4){za=0;Aa=ya}else{la=ya+4|0;c[p>>2]=la;pa=ya;za=d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0;Aa=la}la=ja-Aa|0;pa=la>>>0>4>>>0?4:la;la=Aa+pa|0;c[p>>2]=la;if((ja-la|0)<1){Ba=0;Ca=la}else{V=Aa+(pa+1)|0;c[p>>2]=V;Ba=d[la]|0;Ca=V}V=ja-Ca|0;c[p>>2]=Ca+(V>>>0>3>>>0?3:V);V=ba(qa,_)|0;la=(ba(c[y>>2]|0,qa)|0)-ca-V|0;if(za>>>0>la>>>0){yDb(c[z>>2]|0,24,2208584,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;Da=la}else{Da=za}c[G>>2]=0;if((xa|0)==0){if((Ba&1|0)==0){Z=56}}else{Z=56}do{if((Z|0)==56){Z=0;if((ta|0)==2|(ta|0)==0){break}la=c[F>>2]|0;c[F>>2]=c[H>>2];c[H>>2]=la}}while(0);la=V+ca|0;pa=(c[F>>2]|0)+la|0;ma=(c[H>>2]|0)+la|0;if(va>>>0>2>>>0){Z=59;break b}if((ta|0)==0){la=c[p>>2]|0;Ea=(c[s>>2]|0)-la|0;Fa=Ea>>>0>$>>>0?$:Ea;UGb(pa|0,la|0,Fa)|0;la=(c[p>>2]|0)+Fa|0;c[p>>2]=la;if((aa&65535)>>>0>1>>>0){Fa=1;Ea=pa;Ga=la;do{Ea=Ea+qa|0;Fa=Fa+1|0;la=(c[s>>2]|0)-Ga|0;Ha=la>>>0>$>>>0?$:la;UGb(Ea|0,Ga|0,Ha)|0;Ga=(c[p>>2]|0)+Ha|0;c[p>>2]=Ga;}while((Fa|0)<(ka|0))}TGb(c[I>>2]|0,0,ba(c[y>>2]|0,qa)|0)|0;TGb(c[H>>2]|0,0,ba(c[y>>2]|0,qa)|0)|0;ga=O;break}else if((ta|0)==2){d:do{if((Da|0)>0){Fa=pa;Ga=Da;while(1){Ea=c[s>>2]|0;aa=c[p>>2]|0;V=Ea;if((V-aa|0)<1){Ia=0;Ja=aa}else{Ha=aa+1|0;c[p>>2]=Ha;Ia=d[aa]|0;Ja=Ha}Ha=(Ia>>>1)+1|0;if((Ha|0)>(Ga|0)){ha=-1094995529;Z=238;break b}aa=V-Ja|0;if((Ea|0)==(Ja|0)){ha=-1094995529;Z=238;break b}if((Ia&1|0)==0){if(aa>>>0<Ha>>>0){ha=-1094995529;Z=238;break b}UGb(Fa|0,Ja|0,Ha)|0;c[p>>2]=(c[p>>2]|0)+Ha}else{if((aa|0)<1){Ka=0}else{c[p>>2]=Ja+1;Ka=a[Ja]|0}TGb(Fa|0,Ka|0,Ha|0)|0}aa=Ga-Ha|0;if((aa|0)<=0){break d}Fa=Fa+Ha|0;Ga=aa}}}while(0);TGb(c[I>>2]|0,0,c[J>>2]|0)|0;TGb(c[H>>2]|0,0,c[K>>2]|0)|0;ga=O;break}else if((ta|0)==3|(ta|0)==4){Ga=qa<<2;Fa=(ta|0)==4;aa=va*255|0;Ha=qa<<1;Ea=qa*3|0;if((Ba&4|0)==0){V=pa;la=ma;La=0;Ma=0;while(1){Na=La;Oa=0;while(1){e:do{if((Na|0)==0){Pa=c[s>>2]|0;Qa=c[p>>2]|0;Ra=Pa;do{if((Ra-Qa|0)<1){Sa=0;Ta=Qa}else{Ua=Qa+1|0;c[p>>2]=Ua;Va=a[Qa]|0;if(!(Va<<24>>24==-1)){Sa=Va&255;Ta=Ua;break}if((Ra-Ua|0)>>>0<16>>>0){ha=-1094995529;Z=238;break b}Va=Ua;Ua=V+Oa|0;x=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[p>>2]|0)+4|0;c[p>>2]=Ua;Va=Ua;Ua=V+(Oa+qa)|0;x=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[p>>2]|0)+4|0;c[p>>2]=Ua;Va=Ua;Ua=V+(Oa+Ha)|0;x=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[p>>2]|0)+4|0;c[p>>2]=Ua;Va=Ua;Ua=V+(Oa+Ea)|0;x=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;Wa=Oa;Xa=0;break e}}while(0);if(Fa&(Sa|0)==0){if((Pa|0)==(Ta|0)){ha=-1094995529;Z=238;break b}c[p>>2]=Ta+1;Wa=Oa-4|0;Xa=(d[Ta]|0)+1|0;break}Ra=Sa+aa<<1;Qa=a[1677312+(Ra|1)|0]|0;Ua=(a[1677312+Ra|0]|0)+Oa|0;Ra=la+((ba(Qa,qa)|0)+Ua)|0;Va=ba(c[y>>2]|0,qa)|0;Ya=Ra;Ra=V+Oa|0;Za=(ba(Qa+Ma|0,qa)|0)+Ua|0;Ua=0;while(1){if((Za|0)>-1&(Za|0)<(Va|0)){_a=a[Ya]|0}else{_a=0}a[Ra]=_a;Qa=Za+1|0;if((Qa|0)>-1&(Qa|0)<(Va|0)){a[Ra+1|0]=a[Ya+1|0]|0}else{a[Ra+1|0]=0}Qa=Za+2|0;if((Qa|0)>-1&(Qa|0)<(Va|0)){a[Ra+2|0]=a[Ya+2|0]|0}else{a[Ra+2|0]=0}Qa=Za+3|0;if((Qa|0)>-1&(Qa|0)<(Va|0)){a[Ra+3|0]=a[Ya+3|0]|0}else{a[Ra+3|0]=0}Qa=Ua+1|0;if((Qa|0)<4){Ya=Ya+qa|0;Ra=Ra+qa|0;Za=Za+qa|0;Ua=Qa}else{Wa=Oa;Xa=0;break}}}else{Ua=la+Oa|0;Za=V+Oa|0;x=d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;Za=Oa+qa|0;Ua=la+Za|0;Ra=V+Za|0;x=d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0;a[Ra]=x;x=x>>8;a[Ra+1|0]=x;x=x>>8;a[Ra+2|0]=x;x=x>>8;a[Ra+3|0]=x;Ra=Za+qa|0;Za=la+Ra|0;Ua=V+Ra|0;x=d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=Ra+qa|0;Ra=la+Ua|0;Za=V+Ua|0;x=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;Wa=Oa;Xa=Na-1|0}}while(0);Za=Wa+4|0;if((Za|0)<($|0)){Na=Xa;Oa=Za}else{break}}Oa=Ma+4|0;if((Oa|0)<(ka|0)){V=V+Ga|0;la=la+Ga|0;La=Xa;Ma=Oa}else{ga=O;break c}}}else{$a=pa;ab=ma;bb=0;cb=0}while(1){Ma=bb;La=0;while(1){do{if((Ma|0)==0){la=c[p>>2]|0;V=c[s>>2]|0;if((V|0)==(la|0)){ha=-1094995529;Z=238;break b}Oa=la+1|0;c[p>>2]=Oa;Na=a[la]|0;Za=Na&255;if((Za|0)==255){if((V-Oa|0)>>>0<16>>>0){ha=-1094995529;Z=238;break b}Ra=Oa;Ua=$a+La|0;x=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[p>>2]|0)+4|0;c[p>>2]=Ua;Ra=Ua;Ua=$a+(La+qa)|0;x=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[p>>2]|0)+4|0;c[p>>2]=Ua;Ra=Ua;Ua=$a+(La+Ha)|0;x=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=(c[p>>2]|0)+4|0;c[p>>2]=Ua;Ra=Ua;Ua=$a+(La+Ea)|0;x=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;db=La;eb=0;break}else if((Za|0)==254){if((V-Oa|0)>>>0<4>>>0){ha=-1094995529;Z=238;break b}c[p>>2]=la+2;TGb($a+La|0,a[Oa]|0,4)|0;Ua=c[p>>2]|0;c[p>>2]=Ua+1;TGb($a+(La+qa)|0,a[Ua]|0,4)|0;Ua=c[p>>2]|0;c[p>>2]=Ua+1;TGb($a+(La+Ha)|0,a[Ua]|0,4)|0;Ua=c[p>>2]|0;c[p>>2]=Ua+1;TGb($a+(La+Ea)|0,a[Ua]|0,4)|0;db=La;eb=0;break}else if((Za|0)==253){if((V|0)==(Oa|0)){ha=-1094995529;Z=238;break b}c[p>>2]=la+2;Ua=a[Oa]|0;TGb($a+La|0,Ua|0,4)|0;TGb($a+(La+qa)|0,Ua|0,4)|0;TGb($a+(La+Ha)|0,Ua|0,4)|0;TGb($a+(La+Ea)|0,Ua|0,4)|0;db=La;eb=0;break}else{if(Fa&Na<<24>>24==0){if((V|0)==(Oa|0)){ha=-1094995529;Z=238;break b}c[p>>2]=la+2;db=La-4|0;eb=(d[Oa]|0)+1|0;break}Oa=Za+aa<<1;Za=a[1677312+(Oa|1)|0]|0;la=(a[1677312+Oa|0]|0)+La|0;Oa=ab+((ba(Za,qa)|0)+la)|0;V=ba(c[y>>2]|0,qa)|0;Na=Oa;Oa=$a+La|0;Ua=(ba(Za+cb|0,qa)|0)+la|0;la=0;while(1){if((Ua|0)>-1&(Ua|0)<(V|0)){fb=a[Na]|0}else{fb=0}a[Oa]=fb;Za=Ua+1|0;if((Za|0)>-1&(Za|0)<(V|0)){a[Oa+1|0]=a[Na+1|0]|0}else{a[Oa+1|0]=0}Za=Ua+2|0;if((Za|0)>-1&(Za|0)<(V|0)){a[Oa+2|0]=a[Na+2|0]|0}else{a[Oa+2|0]=0}Za=Ua+3|0;if((Za|0)>-1&(Za|0)<(V|0)){a[Oa+3|0]=a[Na+3|0]|0}else{a[Oa+3|0]=0}Za=la+1|0;if((Za|0)<4){Na=Na+qa|0;Oa=Oa+qa|0;Ua=Ua+qa|0;la=Za}else{db=La;eb=0;break}}}}else{la=ab+La|0;Ua=$a+La|0;x=d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;Ua=La+qa|0;la=ab+Ua|0;Oa=$a+Ua|0;x=d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0;a[Oa]=x;x=x>>8;a[Oa+1|0]=x;x=x>>8;a[Oa+2|0]=x;x=x>>8;a[Oa+3|0]=x;Oa=Ua+qa|0;Ua=ab+Oa|0;la=$a+Oa|0;x=d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;la=Oa+qa|0;Oa=ab+la|0;Ua=$a+la|0;x=d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0;a[Ua]=x;x=x>>8;a[Ua+1|0]=x;x=x>>8;a[Ua+2|0]=x;x=x>>8;a[Ua+3|0]=x;db=La;eb=Ma-1|0}}while(0);Ua=db+4|0;if((Ua|0)<($|0)){Ma=eb;La=Ua}else{break}}La=cb+4|0;if((La|0)<(ka|0)){$a=$a+Ga|0;ab=ab+Ga|0;bb=eb;cb=La}else{ga=O;break}}}else{Z=133;break b}}else if((ia|0)==47){Ga=c[E>>2]|0;qa=ba(Ga,_)|0;aa=(c[F>>2]|0)+(qa+ca)|0;Fa=c[I>>2]|0;Ea=c[H>>2]|0;Ha=na;ma=c[q>>2]|0;if((ja-Ha|0)<2){gb=0;hb=na}else{pa=ra+(oa+2)|0;c[p>>2]=pa;La=na;gb=(d[La]|d[La+1|0]<<8)<<16>>16&65535;hb=pa}if((ja-hb|0)<1){ib=0;jb=hb}else{pa=hb+1|0;c[p>>2]=pa;ib=d[hb]|0;jb=pa}if((ja-jb|0)<1){kb=0;lb=jb}else{pa=jb+1|0;c[p>>2]=pa;kb=d[jb]|0;lb=pa}if((ja-lb|0)<1){mb=0;nb=lb}else{pa=lb+1|0;c[p>>2]=pa;mb=a[lb]&1;nb=pa}pa=ja-nb|0;La=pa>>>0>9>>>0?9:pa;pa=nb+La|0;c[p>>2]=pa;if((ja-pa|0)<4){ob=0;pb=pa}else{Ma=nb+(La+4)|0;c[p>>2]=Ma;La=pa;ob=d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0;pb=Ma}Ma=ja-pb|0;c[p>>2]=pb+(Ma>>>0>8>>>0?8:Ma);Ma=(ba(c[y>>2]|0,Ga)|0)-ca-qa|0;if(ob>>>0>Ma>>>0){yDb(c[z>>2]|0,24,2208584,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;qb=Ma}else{qb=ob}if((mb|0)!=0){Ma=c[p>>2]|0;qa=(c[s>>2]|0)-Ma|0;c[p>>2]=Ma+(qa>>>0>32896>>>0?32896:qa)}if((gb|0)==0){c[L>>2]=-1;TGb(Fa|0,0,ba(c[y>>2]|0,Ga)|0)|0;TGb(Ea|0,0,ba(c[y>>2]|0,Ga)|0)|0}f:do{switch(ib|0){case 0:{qa=c[p>>2]|0;if(((c[s>>2]|0)-qa|0)>>>0<(ba(ka,$)|0)>>>0){ha=-1094995529;Z=238;break b}else{rb=0;sb=aa;tb=qa}while(1){UGb(sb|0,tb|0,$)|0;qa=(c[p>>2]|0)+$|0;c[p>>2]=qa;Ma=rb+1|0;if((Ma|0)<(ka|0)){rb=Ma;sb=sb+Ga|0;tb=qa}else{break}}break};case 1:{if(((c[s>>2]|0)-(c[p>>2]|0)|0)>>>0<(ba((ka+1|0)>>>1,($+1|0)>>>1)|0)>>>0){ha=-1094995529;Z=238;break b}qa=Ga<<1;Ma=0;La=aa;while(1){pa=0;do{Ua=c[p>>2]|0;c[p>>2]=Ua+1;Oa=a[Ua]|0;Ua=pa+Ga|0;a[La+(Ua+1)|0]=Oa;a[La+Ua|0]=Oa;a[La+(pa|1)|0]=Oa;a[La+pa|0]=Oa;pa=pa+2|0;}while((pa|0)<($|0));pa=Ma+2|0;if((pa|0)<(ka|0)){Ma=pa;La=La+qa|0}else{break}}break};case 2:{if((gb|0)!=((c[L>>2]|0)+1|0)){break f}qa=Ha+8-ma|0;La=Ga<<3;Ma=0;pa=aa;Oa=Fa;Ua=Ea;while(1){la=0;while(1){if((la|0)>=($|0)){break}if((mXa(l,pa+la|0,Oa+la|0,Ua+la|0,Ga,qa,8)|0)==0){la=la+8|0}else{ha=-1094995529;Z=238;break b}}la=Ma+8|0;if((la|0)<(ka|0)){Ma=la;pa=pa+La|0;Oa=Oa+La|0;Ua=Ua+La|0}else{break}}break};case 3:{UGb(c[F>>2]|0,c[H>>2]|0,ba(c[y>>2]|0,c[E>>2]|0)|0)|0;break};case 4:{UGb(c[F>>2]|0,c[I>>2]|0,ba(c[y>>2]|0,c[E>>2]|0)|0)|0;break};case 5:{if((qb|0)>0){ub=aa;vb=qb}else{break f}while(1){La=c[s>>2]|0;Ua=c[p>>2]|0;Oa=La;if((Oa-Ua|0)<1){wb=0;xb=Ua}else{pa=Ua+1|0;c[p>>2]=pa;wb=d[Ua]|0;xb=pa}pa=(wb>>>1)+1|0;if((pa|0)>(vb|0)){ha=-1094995529;Z=238;break b}Ua=Oa-xb|0;if((La|0)==(xb|0)){ha=-1094995529;Z=238;break b}if((wb&1|0)==0){if(Ua>>>0<pa>>>0){ha=-1094995529;Z=238;break b}UGb(ub|0,xb|0,pa)|0;c[p>>2]=(c[p>>2]|0)+pa}else{if((Ua|0)<1){yb=0}else{c[p>>2]=xb+1;yb=a[xb]|0}TGb(ub|0,yb|0,pa|0)|0}Ua=vb-pa|0;if((Ua|0)<=0){break f}ub=ub+pa|0;vb=Ua}break};default:{Z=179;break b}}}while(0);c[G>>2]=(gb|0)==((c[L>>2]|0)+1|0)?kb:0;c[L>>2]=gb;ga=O;break}else if((ia|0)==1|(ia|0)==3){aa=c[E>>2]|0;if((ja-na|0)>>>0<2>>>0){ha=-1094995529;Z=238;break b}Ga=(c[F>>2]|0)+((ba(aa,_)|0)+ca)|0;Ea=aa;aa=na;Fa=Ga;Ga=1;ma=sa;Ha=c[q>>2]|0;while(1){oa=aa+2|0;c[p>>2]=oa;Ua=aa;pa=oa;La=pa-Ha|0;Oa=La+((d[Ua]|d[Ua+1|0]<<8)<<16>>16&65535)|0;if((La|0)<(Oa|0)){La=ma;if((La-pa|0)>>>0<2>>>0){ha=-1094995529;Z=238;break b}else{zb=oa;Ab=0;Bb=La}while(1){La=zb+1|0;c[p>>2]=La;pa=d[zb]|0;Ua=pa>>>1;Ma=Ua+1|0;qa=Ma+Ab|0;if((qa|0)>($|0)){ha=-1094995529;Z=238;break b}do{if((pa&1|0)==0){if((Bb-La|0)>>>0<Ma>>>0){ha=-1094995529;Z=238;break b}else{Cb=1;Db=Ab;Eb=La}while(1){c[p>>2]=Eb+1;la=a[Eb]|0;if(!(la<<24>>24==0)){a[Fa+Db|0]=la}if((Cb|0)>=(Ma|0)){break}Cb=Cb+1|0;Db=Db+1|0;Eb=c[p>>2]|0}Fb=Ab+1+Ua|0}else{c[p>>2]=zb+2;la=a[La]|0;if(la<<24>>24==0){Fb=qa;break}TGb(Fa+Ab|0,la|0,Ma|0)|0;Fb=qa}}while(0);Gb=c[p>>2]|0;Hb=c[q>>2]|0;qa=Gb;if((qa-Hb|0)>=(Oa|0)){break}Ma=c[s>>2]|0;if((Ma-qa|0)>>>0<2>>>0){ha=-1094995529;Z=238;break b}else{zb=Gb;Ab=Fb;Bb=Ma}}Ib=Gb;Jb=c[E>>2]|0;Kb=Hb}else{Ib=oa;Jb=Ea;Kb=Ha}if((Ga|0)>=(ka|0)){break}Oa=c[s>>2]|0;if((Oa-Ib|0)>>>0<2>>>0){ha=-1094995529;Z=238;break b}else{Ea=Jb;aa=Ib;Fa=Fa+Jb|0;Ga=Ga+1|0;ma=Oa;Ha=Kb}}c[G>>2]=0;ga=O;break}else{Z=181;break b}}else if((U|0)==1313882444){if((S|0)==196608){Lb=0;Mb=T}else{Z=10;break b}while(1){c[p>>2]=Mb+3;c[v+(Lb<<2)>>2]=d[Mb]<<16|d[Mb+1|0]<<8|d[Mb+2|0]|-16777216;Ha=Lb+1|0;if((Ha|0)>=256){ga=O;break c}Lb=Ha;Mb=c[p>>2]|0}}else{c[p>>2]=P+((Y>>>0>W>>>0?W:Y)+8);yDb(t,48,2002848,(o=i,i=i+8|0,c[o>>2]=U,o)|0);i=o;ga=O}}while(0);U=X+W|0;Y=c[s>>2]|0;T=c[q>>2]|0;S=Y;Ha=S-T|0;if((U|0)<0){Nb=0}else{Nb=(Ha|0)<(U|0)?Ha:U}U=T+Nb|0;if((W&1|0)==0){Ob=U}else{Ha=S-U|0;Ob=T+((Ha>>>0>1>>>0?1:Ha)+Nb)|0}c[p>>2]=Ob;if((S-Ob|0)>>>0>7>>>0){O=ga;P=Ob;Q=T;R=Y}else{Pb=ga;break}}if((Z|0)==7){yDb(t,16,2182072,(o=i,i=i+8|0,c[o>>2]=W,o)|0);i=o;Pb=O}else if((Z|0)==10){yDb(t,16,2105032,(o=i,i=i+8|0,c[o>>2]=W,o)|0);i=o;ha=-1094995529;i=j;return ha|0}else if((Z|0)==15){yDb(c[z>>2]|0,16,2242128,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ha=-1094995529;i=j;return ha|0}else if((Z|0)==20){yDb(c[z>>2]|0,16,2229736,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ha=-12;i=j;return ha|0}else if((Z|0)==59){yDb(c[z>>2]|0,16,2174896,(o=i,i=i+8|0,c[o>>2]=va,o)|0);i=o;ha=-1094995529;i=j;return ha|0}else if((Z|0)==133){yDb(c[z>>2]|0,16,2164664,(o=i,i=i+8|0,c[o>>2]=ta,o)|0);i=o;ha=-1163346256;i=j;return ha|0}else if((Z|0)==179){yDb(c[z>>2]|0,16,2200080,(o=i,i=i+8|0,c[o>>2]=ib,o)|0);i=o;ha=-1163346256;i=j;return ha|0}else if((Z|0)==181){DDb(c[z>>2]|0,2217920,(o=i,i=i+8|0,c[o>>2]=ia,o)|0);i=o;ha=-1163346256;i=j;return ha|0}else if((Z|0)==187){yDb(t,16,2048320,(o=i,i=i+8|0,c[o>>2]=W,o)|0);i=o;ha=-1094995529;i=j;return ha|0}else if((Z|0)==238){i=j;return ha|0}if((Pb|0)==0){Z=202;break}R=k+2612|0;UGb(c[k+2624>>2]|0,c[R>>2]|0,c[k+2660>>2]|0)|0;Qb=R}else{Z=202}}while(0);if((Z|0)==202){Qb=k+2612|0}R=c[Qb>>2]|0;Q=c[k+2592>>2]|0;P=c[k+2584>>2]|0;v=_$a(c[k>>2]|0,c[m>>2]|0,0)|0;if((v|0)<0){ha=v;i=j;return ha|0}v=c[m>>2]|0;G=c[v+32>>2]|0;if((Q|0)==0){Rb=v}else{E=R;R=c[v>>2]|0;v=Q;while(1){Q=v-1|0;UGb(R|0,E|0,P)|0;if((Q|0)==0){break}else{E=E+P|0;R=R+G|0;v=Q}}Rb=c[m>>2]|0}UGb(c[Rb+4>>2]|0,k+24|0,1024)|0;Sb=k+2652|0}else{v=r;if((h|0)<560){yDb(c[k>>2]|0,16,2271800,(o=i,i=i+8|0,c[o>>2]=h,o)|0);i=o;ha=-1094995529;i=j;return ha|0}G=f+12|0;c[p>>2]=G;R=f+8|0;P=d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0;R=f+16|0;c[p>>2]=R;do{if((P|0)==(c[k+2588>>2]|0)){E=G;Q=k+2592|0;if((d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)!=(c[Q>>2]|0)){break}E=f+18|0;c[p>>2]=E;F=R;L=(d[F]|d[F+1|0]<<8)<<16>>16;F=f+19|0;c[p>>2]=F;y=a[E]|0;E=f+20|0;c[p>>2]=E;I=a[F]|0;F=v-E|0;E=F>>>0>4>>>0?4:F;F=f+(E+22)|0;c[p>>2]=F;H=f+(E+20)|0;b[k+3176>>1]=(d[H]|d[H+1|0]<<8)<<16>>16;H=f+(E+24)|0;c[p>>2]=H;K=F;b[k+3178>>1]=(d[K]|d[K+1|0]<<8)<<16>>16;K=f+(E+26)|0;c[p>>2]=K;F=H;b[k+3180>>1]=(d[F]|d[F+1|0]<<8)<<16>>16;F=f+(E+28)|0;c[p>>2]=F;H=K;b[k+3182>>1]=(d[H]|d[H+1|0]<<8)<<16>>16;H=E+30|0;E=f+H|0;c[p>>2]=E;K=F;F=(d[K]|d[K+1|0]<<8)<<16>>16;K=v-E|0;E=(K>>>0>2>>>0?6:K+4|0)+H|0;H=f+(E+2)|0;c[p>>2]=H;K=f+E|0;b[k+2664>>1]=(d[K]|d[K+1|0]<<8)<<16>>16;K=1;E=H;while(1){c[p>>2]=E+2;H=E;b[l+2664+(K<<1)>>1]=(d[H]|d[H+1|0]<<8)<<16>>16;H=K+1|0;if((H|0)>=256){break}K=H;E=c[p>>2]|0}E=y&255;K=c[p>>2]|0;t=(c[s>>2]|0)-K|0;c[p>>2]=K+(t>>>0>8>>>0?8:t);t=k+2652|0;c[t>>2]=I&255;K=L<<16>>16==0;z=c[m>>2]|0;c[z+84>>2]=K&1;O=z+88|0;do{if(K){c[O>>2]=1;z=c[k+2656>>2]|0;if((z|0)==0){break}H=z;J=c[k+2616>>2]|0;while(1){D=H-1|0;b[J>>1]=F;if((D|0)==0){break}else{H=D;J=J+2|0}}J=z;H=c[k+2620>>2]|0;while(1){X=J-1|0;b[H>>1]=F;if((X|0)==0){break}else{J=X;H=H+2|0}}}else{c[O>>2]=2}}while(0);if(!((y&255)>>>0<9>>>0)){DDb(e,1937384,(o=i,i=i+8|0,c[o>>2]=E,o)|0);i=o;ha=-1163346256;i=j;return ha|0}O=re[c[160928+(E<<2)>>2]&4095](l)|0;if((O|0)!=0){yDb(e,16,1965424,(o=i,i=i+8|0,c[o>>2]=E,o)|0);i=o;ha=O;i=j;return ha|0}O=c[k+2612>>2]|0;F=c[Q>>2]|0;K=c[k+2584>>2]<<1;L=_$a(c[k>>2]|0,c[m>>2]|0,0)|0;if((L|0)<0){ha=L;i=j;return ha|0}L=c[m>>2]|0;I=c[L+32>>2]|0;if((F|0)==0){Sb=t;break a}H=O;O=c[L>>2]|0;L=F;while(1){F=L-1|0;UGb(O|0,H|0,K)|0;if((F|0)==0){Sb=t;break a}else{H=H+K|0;O=O+I|0;L=F}}}}while(0);yDb(c[k>>2]|0,16,2256496,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ha=-1163346256;i=j;return ha|0}}while(0);o=c[Sb>>2]|0;if((o|0)!=0){Sb=k+2620|0;m=c[Sb>>2]|0;if((o|0)==2){o=k+2616|0;e=c[o>>2]|0;c[Sb>>2]=e;c[o>>2]=m;Tb=e}else{Tb=m}m=k+2612|0;k=c[m>>2]|0;c[m>>2]=Tb;c[Sb>>2]=k}c[g>>2]=1;ha=c[n>>2]|0;i=j;return ha|0}function $Wa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+2612|0);$Db(b+2616|0);$Db(b+2620|0);$Db(b+2624|0);$Db(b+2644|0);c[b+2636>>2]=0;c[b+2632>>2]=0;c[b+2628>>2]=0;return 0}function aXa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=c[a+2612>>2]|0;g=a+4|0;h=c[g>>2]|0;j=c[a+2588>>2]|0;k=c[a+2592>>2]|0;if(((c[a+8>>2]|0)-h|0)>>>0<(ba(j<<1,k)|0)>>>0){yDb(c[a>>2]|0,16,2287944,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=e;return m|0}if((k|0)<=0){m=0;i=e;return m|0}l=a+2584|0;a=f;f=0;n=h;while(1){if((j|0)>0){h=0;o=n;while(1){p=o+2|0;c[g>>2]=p;q=o;b[a+(h<<1)>>1]=(d[q]|d[q+1|0]<<8)<<16>>16;q=h+1|0;if((q|0)<(j|0)){h=q;o=p}else{r=p;break}}}else{r=n}o=f+1|0;if((o|0)<(k|0)){a=a+(c[l>>2]<<1)|0;f=o;n=r}else{m=0;break}}i=e;return m|0}function bXa(a){a=a|0;var b=0;b=i;DDb(c[a>>2]|0,2306136,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return-1163346256|0}function cXa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a+2600|0;if((c[b>>2]|0)<=0){d=0;return d|0}e=a+2596|0;f=0;a:while(1){g=0;while(1){if((g|0)>=(c[e>>2]|0)){break}h=iXa(a,g,f,8)|0;if((h|0)!=0){d=h;i=8;break a}g=g+8|0}g=f+8|0;if((g|0)<(c[b>>2]|0)){f=g}else{d=0;i=8;break}}if((i|0)==8){return d|0}return 0}function dXa(a){a=a|0;UGb(c[a+2612>>2]|0,c[a+2620>>2]|0,c[a+2636>>2]|0)|0;return 0}function eXa(a){a=a|0;UGb(c[a+2612>>2]|0,c[a+2616>>2]|0,c[a+2632>>2]|0)|0;return 0}function fXa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[b+2660>>2]|0;f=b+4|0;if((e|0)<=0){g=0;return g|0}h=b+8|0;i=c[b+2612>>2]|0;b=e;while(1){e=c[h>>2]|0;j=c[f>>2]|0;k=e;if((k-j|0)<1){l=0;m=j}else{n=j+1|0;c[f>>2]=n;l=d[j]|0;m=n}n=(l>>>1)+1|0;if((n|0)>(b|0)){g=-1094995529;o=15;break}j=k-m|0;if((e|0)==(m|0)){g=-1094995529;o=15;break}if((l&1|0)==0){if(j>>>0<n>>>0){g=-1094995529;o=15;break}UGb(i|0,m|0,n)|0;c[f>>2]=(c[f>>2]|0)+n}else{if((j|0)<1){p=0}else{c[f>>2]=m+1;p=a[m]|0}TGb(i|0,p|0,n|0)|0}j=b-n|0;if((j|0)<=0){g=0;o=15;break}i=i+n|0;b=j}if((o|0)==15){return g|0}return 0}function gXa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[a+2656>>2]|0;g=a+4|0;h=c[g>>2]|0;if(((c[a+8>>2]|0)-h|0)>>>0<f>>>0){yDb(c[a>>2]|0,16,1893072,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=e;return k|0}if((f|0)==0){k=0;i=e;return k|0}else{l=f;m=c[a+2612>>2]|0;n=h}while(1){h=l-1|0;f=n+1|0;c[g>>2]=f;b[m>>1]=b[a+2664+((d[n]|0)<<1)>>1]|0;if((h|0)==0){k=0;break}else{l=h;m=m+2|0;n=f}}i=e;return k|0}function hXa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;g=c[e+2612>>2]|0;h=c[e+2656>>2]|0;j=e+2644|0;kEb(j,e+2648|0,h);k=c[j>>2]|0;if((k|0)==0){yDb(c[e>>2]|0,16,1913536,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;l=-12;i=f;return l|0}j=e+4|0;a:do{if((h|0)>0){m=e+8|0;n=k;o=h;while(1){p=c[m>>2]|0;q=c[j>>2]|0;r=p;if((r-q|0)<1){s=0;t=q}else{u=q+1|0;c[j>>2]=u;s=d[q]|0;t=u}u=(s>>>1)+1|0;if((u|0)>(o|0)){l=-1094995529;v=19;break}q=r-t|0;if((p|0)==(t|0)){l=-1094995529;v=19;break}if((s&1|0)==0){if(q>>>0<u>>>0){l=-1094995529;v=19;break}UGb(n|0,t|0,u)|0;c[j>>2]=(c[j>>2]|0)+u}else{if((q|0)<1){w=0}else{c[j>>2]=t+1;w=a[t]|0}TGb(n|0,w|0,u|0)|0}q=o-u|0;if((q|0)<=0){break a}n=n+u|0;o=q}if((v|0)==19){i=f;return l|0}}}while(0);if((h|0)==0){l=0;i=f;return l|0}else{x=g;y=k;z=h}while(1){h=z-1|0;b[x>>1]=b[e+2664+((d[y]|0)<<1)>>1]|0;if((h|0)==0){l=0;break}else{x=x+2|0;y=y+1|0;z=h}}i=f;return l|0}function iXa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;j=i;i=i+8|0;k=j|0;l=e+4|0;m=c[l>>2]|0;n=c[e+8>>2]|0;if((n|0)==(m|0)){o=-1094995529;i=j;return o|0}p=m+1|0;c[l>>2]=p;q=d[m]|0;a:do{switch(q|0){case 248:{kXa(e,f,g,h,c[e+2584>>2]|0);break};case 249:case 250:case 251:case 252:{r=c[e+2584>>2]|0;s=b[e+3176+(q-249<<1)>>1]|0;if((h|0)<=0){break a}t=(ba(r,g)|0)+f|0;u=(c[e+2612>>2]|0)+(t<<1)|0;t=0;while(1){v=u;w=0;while(1){b[v>>1]=s;x=w+1|0;if((x|0)<(h|0)){v=v+2|0;w=x}else{break}}w=t+1|0;if((w|0)<(h|0)){u=u+(r<<1)|0;t=w}else{break}}break};case 246:{t=c[e+2584>>2]|0;r=(ba(t,g)|0)+f|0;jXa((c[e+2612>>2]|0)+(r<<1)|0,(c[e+2616>>2]|0)+(r<<1)|0,h,t);break};case 245:{if((n-p|0)>>>0<2>>>0){o=-1094995529;i=j;return o|0}c[l>>2]=m+3;t=p;r=(d[t]|d[t+1|0]<<8)<<16>>16<<16>>16;t=c[e+2588>>2]|0;u=(((r|0)%(t|0)|0)<<16>>16)+f|0;s=(((r|0)/(t|0)|0)<<16>>16)+g|0;t=e+2584|0;r=c[t>>2]|0;w=(ba(s,r)|0)+u|0;if((w|0)>-1){v=w+(ba(r+1|0,h-1|0)|0)|0;r=(v|0)<(c[e+2660>>2]>>1|0);v=r&1;if(r){y=v}else{z=v;A=11}}else{z=0;A=11}if((A|0)==11){yDb(c[e>>2]|0,16,2330328,(B=i,i=i+40|0,c[B>>2]=u,c[B+8>>2]=s,c[B+16>>2]=f,c[B+24>>2]=g,c[B+32>>2]=h,B)|0);i=B;y=z}if((y|0)==0){break a}v=c[t>>2]|0;t=(c[e+2612>>2]|0)+((ba(v,g)|0)+f<<1)|0;jXa(t,(c[e+2620>>2]|0)+(u+(ba(v,s)|0)<<1)|0,h,v);break};case 253:{if((n|0)==(p|0)){o=-1094995529;i=j;return o|0}v=c[e+2612>>2]|0;s=c[e+2584>>2]|0;c[l>>2]=m+2;u=b[e+2664+(d[p]<<1)>>1]|0;if((h|0)<=0){break a}t=v+((ba(s,g)|0)+f<<1)|0;v=0;while(1){r=t;w=0;while(1){b[r>>1]=u;x=w+1|0;if((x|0)<(h|0)){r=r+2|0;w=x}else{break}}w=v+1|0;if((w|0)<(h|0)){t=t+(s<<1)|0;v=w}else{break}}break};case 254:{if((n-p|0)>>>0<2>>>0){o=-1094995529;i=j;return o|0}v=c[e+2612>>2]|0;s=c[e+2584>>2]|0;c[l>>2]=m+3;t=p;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((h|0)<=0){break a}t=v+((ba(s,g)|0)+f<<1)|0;v=0;while(1){w=t;r=0;while(1){b[w>>1]=u;x=r+1|0;if((x|0)<(h|0)){w=w+2|0;r=x}else{break}}r=v+1|0;if((r|0)<(h|0)){t=t+(s<<1)|0;v=r}else{break}}break};case 247:{v=c[e+2584>>2]|0;s=c[e+2612>>2]|0;t=(ba(v,g)|0)+f|0;u=s+(t<<1)|0;r=e+4|0;w=n-p|0;if((h|0)==2){if(w>>>0<4>>>0){break a}c[r>>2]=m+5;x=p;C=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;b[u>>1]=b[e+2664+((C&255)<<1)>>1]|0;b[s+(t+1<<1)>>1]=b[e+2664+((C>>>8&255)<<1)>>1]|0;b[s+(t+v<<1)>>1]=b[e+2664+((C>>>16&255)<<1)>>1]|0;b[s+(v+1+t<<1)>>1]=b[e+2664+(C>>>24<<1)>>1]|0;break a}if(w>>>0<3>>>0){break a}w=m+2|0;c[r>>2]=w;C=d[p]|0;t=m+3|0;c[r>>2]=t;s=b[e+2664+(d[w]<<1)>>1]|0;c[r>>2]=m+4;b[k>>1]=b[e+2664+(d[t]<<1)>>1]|0;b[k+2>>1]=s;if((h|0)==8){D=u;E=e+7280+(C<<6)|0;F=0}else{if((h|0)>0){D=u;E=e+3184+(C<<4)|0;F=0}else{break a}}while(1){C=D;u=E;s=0;while(1){b[C>>1]=b[k+(a[u]<<1)>>1]|0;t=s+1|0;if((t|0)<(h|0)){C=C+2|0;u=u+1|0;s=t}else{break}}s=F+1|0;if((s|0)<(h|0)){D=D+(v<<1)|0;E=E+h|0;F=s}else{break}}break};case 255:{if((h|0)==2){kXa(e,f,g,2,c[e+2584>>2]|0);break a}v=h>>1;if((iXa(e,f,g,v)|0)!=0){o=-1094995529;i=j;return o|0}s=v+f|0;if((iXa(e,s,g,v)|0)!=0){o=-1094995529;i=j;return o|0}u=v+g|0;if((iXa(e,f,u,v)|0)!=0){o=-1094995529;i=j;return o|0}if((iXa(e,s,u,v)|0)==0){break a}else{o=-1094995529}i=j;return o|0};default:{v=(a[675584+(q<<1)|0]|0)+f|0;u=(a[675585+(q<<1)|0]|0)+g|0;s=e+2584|0;C=c[s>>2]|0;t=(ba(u,C)|0)+v|0;if((t|0)>-1){r=t+(ba(C+1|0,h-1|0)|0)|0;C=(r|0)<(c[e+2660>>2]>>1|0);r=C&1;if(C){G=r}else{H=r;A=5}}else{H=0;A=5}if((A|0)==5){yDb(c[e>>2]|0,16,2330328,(B=i,i=i+40|0,c[B>>2]=v,c[B+8>>2]=u,c[B+16>>2]=f,c[B+24>>2]=g,c[B+32>>2]=h,B)|0);i=B;G=H}if((G|0)==0){break a}r=c[s>>2]|0;s=(c[e+2612>>2]|0)+((ba(r,g)|0)+f<<1)|0;jXa(s,(c[e+2620>>2]|0)+(v+(ba(r,u)|0)<<1)|0,h,r)}}}while(0);o=0;i=j;return o|0}function jXa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;h=c;i=f<<1;if((e|0)==4){j=c;k=j|0;l=j+4|0;j=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b;m=l|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+4|0;x=j;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=c+(f<<1)|0;j=m|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(f<<1)|0;k=l|0;x=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=l+4|0;x=m;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=f<<2;m=h+k|0;l=m|0;j=m+4|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+k|0;n=j|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+4|0;x=m;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+i|0;k=h+n|0;m=k|0;j=k+4|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+n|0;n=j|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;return}else if((e|0)==8){n=c;k=n|0;j=n+4|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b;m=j|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=j+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=c+8|0;n=m|0;j=m+4|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+8|0;k=j|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=j+4|0;x=m;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=c+(f<<1)|0;m=k|0;j=k+4|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(f<<1)|0;n=j|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=i+8|0;k=h+n|0;j=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+n|0;n=m|0;x=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=f<<2;k=h+n|0;m=k|0;j=k+4|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+n|0;l=j|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=j+4|0;x=k;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=n+8|0;k=h+l|0;j=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+l|0;l=m|0;x=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=k;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=n+i|0;n=h+l|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+l|0;j=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=m+4|0;x=n;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=l+8|0;n=h+j|0;m=n|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+j|0;j=k|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=k+4|0;x=n;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=l+i|0;l=h+j|0;n=l|0;k=l+4|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+j|0;m=k|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+4|0;x=l;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=j+8|0;l=h+m|0;k=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+m|0;m=n|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=n+4|0;x=l;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=j+i|0;j=h+m|0;l=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+m|0;k=n|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=n+4|0;x=j;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+8|0;j=h+k|0;n=j|0;l=j+4|0;j=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+k|0;k=l|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=l+4|0;x=j;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+i|0;m=h+k|0;j=m|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+k|0;n=l|0;x=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+4|0;x=m;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+8|0;m=h+n|0;l=m|0;j=m+4|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+n|0;n=j|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+4|0;x=m;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+i|0;i=h+n|0;k=i|0;m=i+4|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+n|0;j=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=m+4|0;x=i;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=n+8|0;n=h+j|0;h=n|0;i=n+4|0;n=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=g+j|0;j=i|0;x=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=i+4|0;x=n;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;return}else if((e|0)==2){e=c;j=b;x=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=c+(f<<1)|0;c=b+(f<<1)|0;x=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[c]=x;x=x>>8;a[c+1|0]=x;x=x>>8;a[c+2|0]=x;x=x>>8;a[c+3|0]=x;return}else{return}}function kXa(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+8|0;l=k|0;m=c[e+2612>>2]|0;n=(ba(c[e+2584>>2]|0,g)|0)+f|0;f=m+(n<<1)|0;g=e+4|0;o=c[g>>2]|0;p=(c[e+8>>2]|0)-o|0;if((h|0)==2){if(p>>>0<8>>>0){i=k;return}q=o+2|0;c[g>>2]=q;r=o;b[f>>1]=(d[r]|d[r+1|0]<<8)<<16>>16;r=o+4|0;c[g>>2]=r;s=q;b[m+(n+1<<1)>>1]=(d[s]|d[s+1|0]<<8)<<16>>16;s=o+6|0;c[g>>2]=s;q=r;b[m+(n+j<<1)>>1]=(d[q]|d[q+1|0]<<8)<<16>>16;c[g>>2]=o+8;q=s;b[m+(j+1+n<<1)>>1]=(d[q]|d[q+1|0]<<8)<<16>>16;i=k;return}if(p>>>0<5>>>0){i=k;return}p=o+1|0;c[g>>2]=p;q=d[o]|0;n=o+3|0;c[g>>2]=n;m=p;p=(d[m]|d[m+1|0]<<8)<<16>>16;c[g>>2]=o+5;o=n;b[l>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;b[l+2>>1]=p;do{if((h|0)==8){t=f;u=e+7280+(q<<6)|0;v=0}else{if((h|0)>0){t=f;u=e+3184+(q<<4)|0;v=0;break}i=k;return}}while(0);while(1){q=t;e=u;f=0;while(1){b[q>>1]=b[l+(a[e]<<1)>>1]|0;p=f+1|0;if((p|0)<(h|0)){q=q+2|0;e=e+1|0;f=p}else{break}}f=v+1|0;if((f|0)<(h|0)){t=t+(j<<1)|0;u=u+h|0;v=f}else{break}}i=k;return}function lXa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+2612|0;d=b;e=a+2628|0;f=a+2660|0;O$a(d,e,c[f>>2]|0);g=a+2616|0;h=g;i=a+2632|0;O$a(h,i,c[f>>2]|0);j=a+2620|0;k=j;l=a+2636|0;O$a(k,l,c[f>>2]|0);m=a+16|0;if((c[m>>2]|0)==0){O$a(a+2624|0,a+2640|0,c[f>>2]|0)}do{if((c[b>>2]|0)!=0){if((c[g>>2]|0)==0){break}if((c[j>>2]|0)==0){break}if((c[a+2624>>2]|0)!=0){n=0;return n|0}if((c[m>>2]|0)==0){break}else{n=0}return n|0}}while(0);$Db(d);$Db(h);$Db(k);$Db(a+2624|0);$Db(a+2644|0);c[l>>2]=0;c[i>>2]=0;c[e>>2]=0;n=-12;return n|0}function mXa(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;m=i;i=i+8|0;n=m|0;o=n;p=e+4|0;q=c[p>>2]|0;r=c[e+8>>2]|0;if((r|0)==(q|0)){s=-1094995529;i=m;return s|0}t=q+1|0;c[p>>2]=t;u=a[q]|0;v=u&255;a:do{if((u&255)>>>0>247>>>0){if((v|0)==253){if((r-t|0)>>>0<3>>>0){s=-1094995529;i=m;return s|0}w=q+2|0;c[p>>2]=w;x=d[t]|0;if((l|0)==8){y=w;b[n>>1]=(d[y]|d[y+1|0]<<8)<<16>>16;c[p>>2]=q+4;z=0;A=e+7280+(x<<6)|0}else{y=w;b[n>>1]=(d[y]|d[y+1|0]<<8)<<16>>16;c[p>>2]=q+4;if((l|0)>0){z=0;A=e+3184+(x<<4)|0}else{break}}while(1){x=ba(z,j)|0;y=0;w=A;while(1){a[f+(y+x)|0]=a[o+((a[w]|0)==0)|0]|0;B=y+1|0;if((B|0)<(l|0)){y=B;w=w+1|0}else{break}}w=z+1|0;if((w|0)<(l|0)){z=w;A=A+l|0}else{break}}}else if((v|0)==255){if((l|0)==2){if((r-t|0)>>>0<4>>>0){s=-1094995529;i=m;return s|0}else{c[p>>2]=q+2;a[f]=a[t]|0;w=c[p>>2]|0;c[p>>2]=w+1;a[f+1|0]=a[w]|0;w=c[p>>2]|0;c[p>>2]=w+1;a[f+j|0]=a[w]|0;w=c[p>>2]|0;c[p>>2]=w+1;a[f+(j+1)|0]=a[w]|0;break}}w=l>>1;if((mXa(e,f,g,h,j,k,w)|0)!=0){s=-1094995529;i=m;return s|0}if((mXa(e,f+w|0,g+w|0,h+w|0,j,k,w)|0)!=0){s=-1094995529;i=m;return s|0}y=ba(w,j)|0;if((mXa(e,f+y|0,g+y|0,h+y|0,j,k,w)|0)!=0){s=-1094995529;i=m;return s|0}x=y+w|0;if((mXa(e,f+x|0,g+x|0,h+x|0,j,k,w)|0)==0){break}else{s=-1094995529}i=m;return s|0}else if((v|0)==252){if((l|0)>0){C=0}else{break}do{w=ba(C,j)|0;UGb(f+w|0,g+w|0,l)|0;C=C+1|0;}while((C|0)<(l|0))}else if((v|0)==254){if((r|0)==(t|0)){s=-1094995529;i=m;return s|0}c[p>>2]=q+2;w=a[t]|0;if((l|0)>0){D=0}else{break}do{TGb(f+(ba(D,j)|0)|0,w|0,l|0)|0;D=D+1|0;}while((D|0)<(l|0))}else{w=c[e+12>>2]|0;x=w;y=t-x|0;B=(v&7)+k|0;E=r;F=E-x|0;if((B|0)<0){G=0}else{G=(F|0)<(B|0)?F:B}B=w+G|0;c[p>>2]=B;if((E-B|0)<1){H=0}else{c[p>>2]=w+(G+1);H=a[B]|0}if((y|0)<0){I=0}else{I=(F|0)<(y|0)?F:y}c[p>>2]=w+I;if((l|0)>0){J=0}else{break}do{TGb(f+(ba(J,j)|0)|0,H|0,l|0)|0;J=J+1|0;}while((J|0)<(l|0))}}else{w=a[675584+(v<<1)|0]|0;y=a[675585+(v<<1)|0]|0;F=h-(c[e+2620>>2]|0)|0;do{if((F|0)>=(-((ba(y,j)|0)+w|0)|0)){if(((c[e+2660>>2]>>1)-F|0)<(w+l+(ba(l-1+y|0,j)|0)|0)){break}if((l|0)>0){K=0}else{break a}while(1){UGb(f+(ba(K,j)|0)|0,h+((ba(K+y|0,j)|0)+w)|0,l)|0;K=K+1|0;if((K|0)>=(l|0)){break a}}}}while(0);yDb(c[e>>2]|0,16,2191536,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1094995529;i=m;return s|0}}while(0);s=0;i=m;return s|0}function nXa(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;f=ba(e,e)|0;g=e-1|0;h=f<<4;i=0;j=b;while(1){b=a[c+i|0]|0;k=b<<24>>24;l=a[d+i|0]|0;m=l<<24>>24;do{if(l<<24>>24==0){n=3}else{if((g|0)==(m|0)){n=1;break}if(b<<24>>24==0){n=0;break}n=(g|0)==(k|0)?2:4}}while(0);o=(n|0)==0;p=(n|0)==2;q=(n|0)==3;r=q^1;s=(n|0)==1;t=s^1;u=(n|0)!=2;v=ba(m,e)|0;w=v+k|0;x=e-k|0;y=0;z=j;while(1){A=ba(f,y)|0;B=j+(w+A)|0;C=a[c+y|0]|0;D=C<<24>>24;E=a[d+y|0]|0;F=E<<24>>24;do{if(E<<24>>24==0){G=0;H=3;I=0;J=13}else{if((g|0)==(F|0)){K=0;L=0;M=1;N=0;O=0;P=1;J=15;break}if(C<<24>>24==0){if(p){Q=1;break}else{G=0;H=0;I=1;J=13;break}}R=(g|0)==(D|0);if(o&R){Q=1;break}G=R;H=R?2:4;I=0;J=13}}while(0);do{if((J|0)==13){J=0;if(q){Q=1;break}C=(H|0)==3;E=C^1;if(s|E){K=1;L=G;M=H;N=I;O=C;P=E;J=15}else{Q=1}}}while(0);do{if((J|0)==15){J=0;if(!(O|t)){Q=3;break}if(!(q|K)){Q=3;break}if(!(L|o^1)){Q=0;break}if(!(p|N^1)){Q=0;break}if(!((P|t)&(K|r)&(u|N))){Q=2;break}Q=(M|0)!=2|o?4:2}}while(0);E=D-k|0;C=(E|0)>-1?E:-E|0;E=F-m|0;R=(E|0)>-1?E:-E|0;E=(C|0)>(R|0)?C:R;a:do{if((E|0)>=0){R=E>>1;if((E|0)==0){if((Q|0)==2){if((k|0)>=(e|0)){break}TGb(B|0,1,x|0)|0;break}else if((Q|0)==1){if(l<<24>>24>-1){S=m}else{break}while(1){a[z+((ba(S,e)|0)+k)|0]=1;if((S|0)>0){S=S-1|0}else{break a}}}else if((Q|0)==0){if(b<<24>>24>-1){T=k}else{break}while(1){a[z+(T+v)|0]=1;if((T|0)>0){T=T-1|0}else{break a}}}else if((Q|0)==3){if((m|0)<(e|0)){U=m}else{break}while(1){a[z+((ba(U,e)|0)+k)|0]=1;U=U+1|0;if((U|0)>=(e|0)){break a}}}else{break}}else{V=0}do{C=E-V|0;W=(((ba(V,k)|0)+R+(ba(C,D)|0)|0)/(E|0)|0)&255;X=(((ba(V,m)|0)+R+(ba(C,F)|0)|0)/(E|0)|0)&255;do{if((Q|0)==0){if(!(W<<24>>24>-1)){break}C=ba(X<<24>>24,e)|0;Y=W<<24>>24;while(1){a[z+(Y+C)|0]=1;if((Y|0)>0){Y=Y-1|0}else{break}}}else if((Q|0)==3){Y=X<<24>>24;if((Y|0)>=(e|0)){break}C=W<<24>>24;Z=Y;do{a[z+((ba(Z,e)|0)+C)|0]=1;Z=Z+1|0;}while((Z|0)<(e|0))}else if((Q|0)==1){if(!(X<<24>>24>-1)){break}Z=W<<24>>24;C=X<<24>>24;while(1){a[z+((ba(C,e)|0)+Z)|0]=1;if((C|0)>0){C=C-1|0}else{break}}}else if((Q|0)==2){C=W<<24>>24;if((C|0)>=(e|0)){break}TGb(j+(A+((ba(X<<24>>24,e)|0)+C))|0,1,e-C|0)|0}}while(0);V=V+1|0;}while((V|0)<=(E|0))}}while(0);E=y+1|0;if((E|0)<16){y=E;z=z+f|0}else{break}}z=i+1|0;if((z|0)<16){i=z;j=j+h|0}else{break}}return}function oXa(a){a=a|0;c[c[a+60>>2]>>2]=a;return 0}function pXa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0;j=i;i=i+48|0;k=j|0;l=c[e+60>>2]|0;m=f;n=l+24|0;o=c[h+24>>2]|0;p=h+28|0;h=c[p>>2]|0;if(!((h|0)>-1)){yDb(0,0,1913504,(q=i,i=i+24|0,c[q>>2]=1893056,c[q+8>>2]=2350704,c[q+16>>2]=135,q)|0);i=q;Cd();return 0}r=n;c[r>>2]=o;s=l+32|0;c[s>>2]=o;t=l+28|0;c[t>>2]=o+h;if(h>>>0<512>>>0){yDb(e,16,2182040,(q=i,i=i+8|0,c[q>>2]=h,q)|0);i=q;u=-1094995529;i=j;return u|0}h=o+2|0;c[r>>2]=h;v=o;if(!((d[v]|d[v+1|0]<<8)<<16>>16<<16>>16==-9727)){yDb(e,16,2105008,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=j;return u|0}v=o+3|0;c[r>>2]=v;w=a[h]|0;h=o+4|0;c[r>>2]=h;x=a[v]|0;v=x&255;y=l+16|0;c[y>>2]=v;z=o+6|0;c[r>>2]=z;A=h;h=(de((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535;A=o+8|0;c[r>>2]=A;B=z;z=(de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535;B=l+4|0;c[B>>2]=z;C=o+10|0;c[r>>2]=C;D=A;A=(de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;D=l+8|0;c[D>>2]=A;c[r>>2]=o+12;o=C;C=(de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;o=l+12|0;c[o>>2]=C;if((v|0)==2){if(!(w<<24>>24==0)){E=9}}else if((v|0)!=1){E=9}if((E|0)==9){yDb(e,16,2048296,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=j;return u|0}if((h-2|0)>>>0>1>>>0){yDb(e,16,2002824,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=j;return u|0}if((C|0)==4){c[e+140>>2]=x<<24>>24==2?291:28}else if((C|0)==1){c[e+140>>2]=x<<24>>24==2?31:8}else if((C|0)==3){c[e+140>>2]=x<<24>>24==2?41:2}else{yDb(e,16,1965400,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=j;return u|0}x=V$a(e,z,A)|0;if((x|0)<0){u=x;i=j;return u|0}x=_$a(e,m,0)|0;if((x|0)<0){u=x;i=j;return u|0}c[f+88>>2]=1;c[f+84>>2]=1;x=c[f>>2]|0;m=c[f+32>>2]|0;f=c[D>>2]|0;e=l+20|0;c[e>>2]=m;A=c[s>>2]|0;z=c[t>>2]|0;C=z-A|0;h=A+((C|0)<512?C:512)|0;c[r>>2]=h;a:do{if(w<<24>>24==0){C=c[B>>2]|0;A=ba(C,f)|0;v=c[y>>2]|0;F=ba(A,v)|0;A=c[o>>2]|0;if((ba(F,A)|0)>>>0>(z-h|0)>>>0){u=-1094995529;i=j;return u|0}if((A|0)==0){G=0}else{H=0;while(1){I=k+(H*12|0)|0;J=I;c[J>>2]=c[n>>2];c[J+4>>2]=c[n+4>>2];c[J+8>>2]=c[n+8>>2];J=ba(H,F)|0;K=I|0;I=c[K>>2]|0;L=(c[k+(H*12|0)+4>>2]|0)-I|0;c[K>>2]=I+(L>>>0>J>>>0?J:L);L=H+1|0;if(L>>>0<A>>>0){H=L}else{G=A;break}}}A=f-1|0;if((A|0)>-1){M=A;N=G;O=G;P=G;Q=v;R=m;S=C}else{break}while(1){A=x+(ba(R,M)|0)|0;H=(S|0)>0;do{if((Q|0)==1){if(H){T=S;U=A;V=N;W=O;X=P}else{Y=N;Z=O;_=P;break}while(1){if((V|0)==0){$=U;aa=0;ca=W;da=X}else{F=0;L=U;while(1){J=k+(F*12|0)|0;I=c[J>>2]|0;c[J>>2]=I+1;J=L+1|0;a[L]=a[I]|0;I=F+1|0;K=c[o>>2]|0;if(I>>>0<K>>>0){F=I;L=J}else{$=J;aa=K;ca=K;da=K;break}}}L=T-1|0;if((L|0)>0){T=L;U=$;V=aa;W=ca;X=da}else{Y=aa;Z=ca;_=da;break}}}else{if(!H){Y=N;Z=O;_=P;break}L=P>>>0>1>>>0?P:1;F=S;K=A;J=O;while(1){if((J|0)==0){ea=K;fa=0}else{I=0;ga=K;while(1){ha=k+(I*12|0)|0;ia=c[ha>>2]|0;c[ha>>2]=ia+2;ha=ia;b[ga>>1]=(d[ha]|d[ha+1|0]<<8)<<16>>16;ha=I+1|0;if(ha>>>0<P>>>0){I=ha;ga=ga+2|0}else{break}}ea=K+(L<<1)|0;fa=P}ga=F-1|0;if((ga|0)>0){F=ga;K=ea;J=fa}else{Y=fa;Z=fa;_=P;break}}}}while(0);A=M-1|0;if(!((A|0)>-1)){break a}M=A;N=Y;O=Z;P=_;Q=c[y>>2]|0;R=c[e>>2]|0;S=c[B>>2]|0}}else{C=x+(ba(f,m)|0)|0;v=c[o>>2]|0;if((ba(f<<3,v)|0)>>>0>(z-h|0)>>>0){u=-1094995529;i=j;return u|0}if((v|0)==0){break}A=l;H=h;J=0;K=f;F=v;b:while(1){if((K|0)==0){ja=H;ka=0;la=F}else{v=H;L=C;ga=1;while(1){I=c[e>>2]|0;if((z-v|0)<4){ha=c[t>>2]|0;ia=c[s>>2]|0;ma=v;na=0;oa=ha;pa=ia;qa=ha-ia|0;E=27}else{ia=v+4|0;ha=v;ra=fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0;ha=c[t>>2]|0;sa=c[s>>2]|0;if((ra|0)<0){ta=0;ua=ia;va=ha;wa=sa}else{ma=ia;na=ra;oa=ha;pa=sa;qa=ha-sa|0;E=27}}if((E|0)==27){E=0;ta=(qa|0)<(na|0)?qa:na;ua=ma;va=oa;wa=pa}sa=wa+ta|0;c[r>>2]=sa;ha=J-I|0;ra=L+ha|0;ia=c[o>>2]|0;xa=ba(ia,c[B>>2]|0)|0;ya=L+(xa+ha)|0;c:do{if((xa|0)>0){ha=ya;if((va|0)==(sa|0)){za=-1094995529;break}else{Aa=va;Ba=sa;Ca=ra}while(1){Da=Ba+1|0;c[r>>2]=Da;Ea=a[Ba]|0;Fa=Ea&127;if(Fa<<24>>24==0){Ga=Ca;E=44;break c}if((ha-Ca|0)<=(ba((Fa&255)-1|0,ia)|0)){break}d:do{if(Ea<<24>>24>-1){if((Aa-Da|0)<1){Ha=0}else{c[r>>2]=Ba+2;Ha=a[Da]|0}Ia=Fa;Ja=Ca;while(1){Ka=Ia-1&255;a[Ja]=Ha;if(Ka<<24>>24==0){break}else{Ia=Ka;Ja=Ja+ia|0}}}else{Ja=Fa;Ia=Ca;Ka=Aa;La=Da;while(1){Ma=Ja-1&255;if((Ka-La|0)<1){Na=0}else{c[r>>2]=La+1;Na=a[La]|0}a[Ia]=Na;if(Ma<<24>>24==0){break d}Ja=Ma;Ia=Ia+ia|0;Ka=c[t>>2]|0;La=c[r>>2]|0}}}while(0);Da=Ca+(ba((Fa-1&255)+1|0,ia)|0)|0;if(!(Da>>>0<ya>>>0)){Ga=Da;E=44;break c}Ea=c[r>>2]|0;La=c[t>>2]|0;if((La|0)==(Ea|0)){za=-1094995529;break c}else{Aa=La;Ba=Ea;Ca=Da}}yDb(c[A>>2]|0,16,1937360,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;za=-1094995529}else{Ga=ra;E=44}}while(0);if((E|0)==44){E=0;za=(Ga-ra|0)/(ia|0)|0}if((za|0)!=(c[B>>2]|0)){u=-1094995529;break b}Oa=c[D>>2]|0;if(!(ga>>>0<Oa>>>0)){break}v=ua;L=L+(-I|0)|0;ga=ga+1|0}ja=ua;ka=Oa;la=c[o>>2]|0}ga=J+1|0;if(ga>>>0<la>>>0){H=ja;J=ga;K=ka;F=la}else{break a}}i=j;return u|0}}while(0);c[g>>2]=1;u=c[p>>2]|0;i=j;return u|0}function qXa(a){a=a|0;var b=0,d=0,e=0;b=i;do{if((c[a+120>>2]|0)<=65535){if((c[a+124>>2]|0)>65535){break}d=ICb()|0;c[a+804>>2]=d;e=(d|0)==0?-12:0;i=b;return e|0}}while(0);yDb(a,16,2181984,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1;i=b;return e|0}function rXa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;h=c[d+804>>2]|0;c[h+88>>2]=1;c[h+84>>2]=1;h=c[d+120>>2]|0;i=c[d+124>>2]|0;switch(c[d+140>>2]|0){case 32:{j=1;k=5;break};case 28:{l=0;m=255;n=1;o=3;p=4;break};case 8:{l=0;m=255;n=1;o=2;p=1;break};case 292:{q=1;k=9;break};case 291:{q=0;k=9;break};case 42:{r=1;k=7;break};case 2:{l=0;m=255;n=1;o=3;p=3;break};case 41:{r=0;k=7;break};case 31:{j=0;k=5;break};default:{s=-1094995529;return s|0}}if((k|0)==5){c[d+568>>2]=2;l=j;m=65535;n=2;o=2;p=1}else if((k|0)==7){c[d+568>>2]=2;l=r;m=65535;n=2;o=3;p=3}else if((k|0)==9){c[d+568>>2]=2;l=q;m=65535;n=2;o=3;p=4}q=ba(p,i)|0;r=q<<2;j=d+568|0;if((c[j>>2]|0)==2){t=h}else{t=(h<<1|1)+8|0}u=r0a(d,e,ba((ba(q,t)|0)+512|0,n)|0,0)|0;if((u|0)<0){s=u;return s|0}u=e+24|0;t=c[u>>2]|0;d=e+28|0;v=t+(c[d>>2]|0)|0;w=t;x=-9727;a[w]=x;x=x>>8;a[w+1|0]=x;a[t+2|0]=(c[j>>2]|0)!=2|0;a[t+3|0]=n;w=t+4|0;x=de(o|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;w=t+6|0;x=de(h&65535|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;w=t+8|0;x=de(i&65535|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;w=t+10|0;x=de(p&65535|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;w=t+12|0;x=0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;w=t+16|0;x=fe(m|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;w=t+512|0;TGb(t+20|0,0,516)|0;do{if((c[j>>2]|0)==2){m=f|0;o=f+32|0;y=i-1|0;z=(i|0)==0;A=ba(p,h)|0;B=(A|0)==0;C=(n|0)==1;D=(l|0)==0;E=w;F=0;while(1){if(z){G=E}else{H=c[o>>2]|0;I=(ba(H,y)|0)+(ba(F,n)|0)|0;J=E;K=0;L=(c[m>>2]|0)+I|0;I=H;while(1){if(B){M=J;N=I}else{H=L;if(C){if(D){O=J;P=0;while(1){a[O]=a[L+P|0]|0;Q=O+1|0;R=P+p|0;if(R>>>0<A>>>0){O=Q;P=R}else{S=Q;break}}}else{P=J;O=0;while(1){a[P]=a[L+O|0]|0;Q=P+1|0;R=O+p|0;if(R>>>0<A>>>0){P=Q;O=R}else{S=Q;break}}}}else{if(D){O=J;P=0;while(1){Q=O;x=b[H+(P<<1)>>1]|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;Q=O+2|0;R=P+p|0;if(R>>>0<A>>>0){O=Q;P=R}else{S=Q;break}}}else{P=J;O=0;while(1){Q=P;x=de(b[H+(O<<1)>>1]|0)|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;Q=P+2|0;R=O+p|0;if(R>>>0<A>>>0){P=Q;O=R}else{S=Q;break}}}}M=S;N=c[o>>2]|0}O=K+1|0;if(O>>>0<i>>>0){J=M;K=O;L=L+(-N|0)|0;I=N}else{G=M;break}}}I=F+1|0;if(I>>>0<p>>>0){E=G;F=I}else{T=G;break}}}else{F=WDb(h)|0;if((F|0)==0){s=-1;return s|0}E=f|0;o=f+32|0;A=i-1|0;D=(i|0)==0;C=(h|0)==0;B=v-1|0;m=w;y=t+(r+512)|0;z=t+((q<<3)+512)|0;I=0;a:while(1){b:do{if(D){U=m;V=y;W=z}else{L=(ba(c[o>>2]|0,A)|0)+I|0;K=(c[E>>2]|0)+L|0;if(C){L=m;J=y;O=z;P=0;while(1){H=O;Q=L;x=fe(H-(c[u>>2]|0)|0)|0;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;Q=L+4|0;R=lnb(O,B-H|0,F,1,0,0,0,128,0)|0;if((R|0)<1){break a}a[O+R|0]=0;H=R+1|0;R=O+H|0;X=J;x=fe(H|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=J+4|0;H=P+1|0;if(H>>>0<i>>>0){L=Q;J=X;O=R;P=H}else{U=Q;V=X;W=R;break b}}}else{Y=m;Z=y;_=z;$=0;aa=K}while(1){P=_;O=Y;x=fe(P-(c[u>>2]|0)|0)|0;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;O=Y+4|0;J=0;do{a[F+J|0]=a[aa+(ba(J,p)|0)|0]|0;J=J+1|0;}while(J>>>0<h>>>0);J=lnb(_,B-P|0,F,1,h,0,0,128,0)|0;if((J|0)<1){break a}a[_+J|0]=0;L=J+1|0;J=_+L|0;R=Z;x=fe(L|0)|0;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;R=Z+4|0;L=$+1|0;if(L>>>0<i>>>0){Y=O;Z=R;_=J;$=L;aa=aa+(-(c[o>>2]|0)|0)|0}else{U=O;V=R;W=J;break}}}}while(0);K=I+1|0;if(K>>>0<p>>>0){m=U;y=V;z=W;I=K}else{k=27;break}}if((k|0)==27){ZDb(F);T=W;break}ZDb(F);s=-1;return s|0}}while(0);c[d>>2]=T-(c[u>>2]|0);u=e+36|0;c[u>>2]=c[u>>2]|1;c[g>>2]=1;s=0;return s|0}function sXa(a){a=a|0;JCb(a+804|0);return 0}function tXa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[a+140>>2]=19;a=ICb()|0;c[b>>2]=a;return((a|0)==0?-12:0)|0}function uXa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;h=c[b+60>>2]|0;j=$$a(b,c[h>>2]|0)|0;if((j|0)<0){k=j;i=g;return k|0}j=c[h>>2]|0;l=c[j>>2]|0;m=c[f+24>>2]|0;n=f+28|0;f=c[n>>2]|0;o=c[b+120>>2]|0;p=c[b+124>>2]|0;q=c[j+32>>2]|0;j=m+f|0;a:do{if((f|0)>1){r=0;s=0;t=m;b:while(1){u=t+1|0;v=a[t]|0;c:do{if(v<<24>>24!=0&(v&255)>>>0<192>>>0){w=v;x=s;y=r;while(1){z=w&255;A=o-y|0;B=(z|0)>(A|0)?A:z;if((B|0)<1){C=x;D=y;break}A=l+((ba(x,q)|0)+y)|0;E=a[u]|0;TGb(A|0,E<<3|(E&255)>>>5|0,B|0)|0;E=B+y|0;if((E|0)<(o|0)){F=x;G=E}else{E=x+1|0;if((E|0)<(p|0)){F=E;G=0}else{break a}}E=z-B|0;if((E&255|0)==0){C=F;D=G;break}else{w=E&255;x=F;y=G}}H=t+2|0;I=C;J=D}else{if(!((v&255)>>>0>192>>>0)){break b}y=u;x=v+64&255;w=s;E=r;while(1){B=x&255;z=o-E|0;A=(B|0)>(z|0)?z:B;z=j-y|0;K=(A|0)>(z|0)?z:A;if((K|0)<1){H=y;I=w;J=E;break c}A=(ba(w,q)|0)+E|0;z=0;do{L=a[y+z|0]|0;a[l+(A+z)|0]=L<<3|(L&255)>>>5;z=z+1|0;}while((z|0)<(K|0));z=K+E|0;if((z|0)<(o|0)){M=w;N=z}else{z=w+1|0;if((z|0)<(p|0)){M=z;N=0}else{break a}}z=y+K|0;A=B-K|0;if((A&255|0)==0){H=z;I=M;J=N;break}else{y=z;x=A&255;w=M;E=N}}}}while(0);if((j-H|0)>1){r=J;s=I;t=H}else{break a}}DDb(b,2181968,(t=i,i=i+8|0,c[t>>2]=v&255,t)|0);i=t;k=-1163346256;i=g;return k|0}}while(0);c[e>>2]=1;e=MCb(d,c[h>>2]|0)|0;if((e|0)<0){k=e;i=g;return k|0}k=c[n>>2]|0;i=g;return k|0}function vXa(a){a=a|0;JCb(c[a+60>>2]|0);return 0}function wXa(a){a=a|0;c[c[a+60>>2]>>2]=a;return 0}function xXa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;j=i;k=f;l=h+24|0;m=c[l>>2]|0;n=h+28|0;h=c[n>>2]|0;o=c[e+60>>2]|0;p=o;q=o+28|0;r=c[q>>2]|0;do{if((r|0)==0){c[q>>2]=8192;s=o+136|0;t=o+148|0;u=jEb(c[s>>2]|0,t,8208)|0;if((u|0)!=0){TGb(u|0,0,c[t>>2]|0)|0;c[s>>2]=u;u=c[q>>2]|0;if((u|0)==0){v=m;w=h;x=0;break}else{y=u;z=t;A=6;break}}yDb(e,16,2181928,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-12;i=j;return C|0}else{y=r;z=o+148|0;A=6}}while(0);do{if((A|0)==6){r=o+140|0;t=c[r>>2]|0;u=y-t|0;s=(h|0)>(u|0)?u:h;u=o+144|0;D=c[u>>2]|0;if((t+16+D+s|0)>>>0>(c[z>>2]|0)>>>0){E=c[o+136>>2]|0;VGb(E|0,E+D|0,t|0)|0;c[u>>2]=0;F=0}else{F=D}if((m|0)==0){G=F;H=o+136|0}else{D=o+136|0;UGb((c[D>>2]|0)+((c[r>>2]|0)+F)|0,m|0,s)|0;G=c[u>>2]|0;H=D}D=(c[H>>2]|0)+G|0;u=(c[r>>2]|0)+s|0;c[r>>2]=u;if((u|0)>=(c[q>>2]|0)){v=D;w=u;x=s;break}if((c[l>>2]|0)==0){v=D;w=u;x=s;break}c[g>>2]=0;C=s;i=j;return C|0}}while(0);l=o+4|0;q=l;G=w<<3;H=G>>>0>2147483639>>>0|(v|0)==0;m=H?0:v;v=H?0:G;c[l>>2]=m;l=o+16|0;c[l>>2]=v;G=v+8|0;H=o+20|0;c[H>>2]=G;c[o+8>>2]=m+(v>>3);F=o+12|0;z=o+16568|0;h=c[z>>2]|0;y=G>>>0>h>>>0?h:G;c[F>>2]=y;h=o+16576|0;a:do{if((c[h>>2]|0)==0){s=m+(y>>>3)|0;u=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(y&7)&-65536;s=y+16|0;D=G>>>0>s>>>0?s:G;c[F>>2]=D;s=m+(D>>>3)|0;r=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(D&7)>>>16;s=D+16|0;D=G>>>0>s>>>0?s:G;c[F>>2]=D;if((r|u|0)!=1634364263){yDb(c[o>>2]|0,16,1893024,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}u=o+16572|0;c[u>>2]=0;r=o+16564|0;c[r>>2]=256;s=o+16552|0;c[s>>2]=-1;t=m+(D>>>3)|0;E=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(D&7)>>>24;t=D+8|0;c[F>>2]=G>>>0>t>>>0?t:G;t=o+16540|0;c[t>>2]=E;if((E|0)==0){I=4}else{I=zXa(q,2)|0}E=o+16556|0;c[E>>2]=zXa(q,I)|0;if((c[t>>2]|0)==0){J=0}else{J=zXa(q,2)|0}D=zXa(q,J)|0;K=o+32|0;c[K>>2]=D;if((D|0)==0){yDb(c[o>>2]|0,16,2350680,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}L=o;M=c[L>>2]|0;if(D>>>0>8>>>0){yDb(M,16,2330304,(B=i,i=i+8|0,c[B>>2]=D,B)|0);i=B;c[K>>2]=0;C=-1094995529;i=j;return C|0}c[M+416>>2]=D;do{if((c[t>>2]|0)>0){D=zXa(q,zXa(q,2)|0)|0;if((D|0)==0|D>>>0>65535>>>0){yDb(c[L>>2]|0,16,2002784,(B=i,i=i+8|0,c[B>>2]=D,B)|0);i=B;C=-22;i=j;return C|0}c[r>>2]=D;if((c[t>>2]|0)==0){N=2}else{N=zXa(q,2)|0}D=zXa(q,N)|0;if((c[t>>2]|0)==0){O=0}else{O=zXa(q,2)|0}c[s>>2]=zXa(q,O)|0;if((c[t>>2]|0)==0){P=1}else{P=zXa(q,2)|0}M=zXa(q,P)|0;if((M|0)<=0){Q=D;break}R=c[H>>2]|0;S=0;T=c[F>>2]|0;do{U=T+8|0;T=R>>>0>U>>>0?U:R;S=S+1|0;}while((S|0)<(M|0));c[F>>2]=T;Q=D}else{Q=0}}while(0);M=(Q|0)<3?3:Q;S=o+16560|0;c[S>>2]=M;do{if((c[K>>2]|0)==0){V=M}else{R=0;while(1){U=c[s>>2]|0;W=(U|0)<1;if(U>>>0>1073741822>>>0&(W^1)){A=40;break}X=c[S>>2]|0;Y=X+(c[r>>2]|0)|0;if(!(Y>>>0<1073741823>>>0&Y>>>0>X>>>0)){A=42;break}X=_Db(p+100+(R<<2)|0,W?4:U<<2)|0;if((X|0)<0){C=X;A=208;break}X=p+68+(R<<2)|0;U=_Db(X,(c[S>>2]|0)+(c[r>>2]|0)<<2)|0;if((U|0)<0){C=U;A=208;break}U=c[S>>2]|0;W=c[X>>2]|0;if((U|0)>0){X=0;while(1){c[W+(X<<2)>>2]=0;Y=X+1|0;Z=c[S>>2]|0;if((Y|0)<(Z|0)){X=Y}else{_=Z;break}}}else{_=U}c[p+36+(R<<2)>>2]=W+(_<<2);X=R+1|0;if(X>>>0<(c[K>>2]|0)>>>0){R=X}else{A=48;break}}if((A|0)==40){yDb(c[L>>2]|0,16,2151048,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}else if((A|0)==42){yDb(c[L>>2]|0,16,2143976,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}else if((A|0)==48){V=c[S>>2]|0;break}else if((A|0)==208){i=j;return C|0}}}while(0);S=_Db(o+132|0,V<<2)|0;if((S|0)<0){C=S;i=j;return C|0}S=c[s>>2]|0;r=(S|0)<1?1:S;S=c[E>>2]|0;if((S|0)==3|(S|0)==5){c[(c[L>>2]|0)+420>>2]=6;$=0}else if((S|0)==2){c[(c[L>>2]|0)+420>>2]=5;$=128}else{yDb(c[L>>2]|0,16,2157920,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1163346256;i=j;return C|0}if((c[K>>2]|0)!=0&(r|0)>0){S=0;do{M=c[p+100+(S<<2)>>2]|0;R=0;do{c[M+(R<<2)>>2]=$;R=R+1|0;}while((R|0)<(r|0));S=S+1|0;}while(S>>>0<(c[K>>2]|0)>>>0)}if((c[t>>2]|0)>1){c[u>>2]=32}if((zXa(q,2)|0)!=9){yDb(c[L>>2]|0,16,2306080,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}K=zXa(q,5)|0;S=o+152|0;c[S>>2]=K;if((K-44|0)>>>0>16339>>>0){yDb(c[L>>2]|0,16,2287912,(B=i,i=i+8|0,c[B>>2]=K,B)|0);i=B;C=-1094995529;i=j;return C|0}if((K|0)>0){r=0;while(1){a[p+156+r|0]=zXa(q,8)|0;E=r+1|0;s=c[S>>2]|0;if((E|0)<(s|0)){r=E}else{aa=s;break}}}else{aa=K}r=c[L>>2]|0;if(!((aa|0)>-1)){yDb(0,0,2191448,(B=i,i=i+24|0,c[B>>2]=2174880,c[B+8>>2]=2164640,c[B+16>>2]=135,B)|0);i=B;Cd();return 0}S=p+156+aa|0;do{if((aa|0)>=4){u=o+156|0;if((d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)!=1179011410){break}u=(aa-4|0)>>>0>4>>>0?8:aa;do{if((aa-u|0)>=4){t=p+156+u|0;if((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)!=1163280727){break}t=u+4+(p+156)|0;while(1){if((S-t|0)<4){ca=0;da=t}else{s=t;ca=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)==544501094;da=t+4|0}if((S-da|0)<4){ea=0;fa=da}else{s=da;ea=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;fa=da+4|0}if(ca){break}s=S-fa|0;E=fa+(s>>>0>ea>>>0?ea:s)|0;if((ea|0)<0){A=82;break}if((S-E|0)>>>0<16>>>0){A=82;break}else{t=E}}if((A|0)==82){yDb(r,16,2242096,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}if((ea|0)<16){yDb(r,16,2229696,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}do{if((S-fa|0)>=2){t=fa;if(!((d[t]|d[t+1|0]<<8)<<16>>16<<16>>16==1)){break}t=S-(fa+2)|0;W=t>>>0>2>>>0?4:t+2|0;t=fa+W|0;if((S-t|0)<4){ga=0;ha=t}else{U=t;ga=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;ha=fa+(W+4)|0}c[r+412>>2]=ga;W=S-ha|0;U=W>>>0>4>>>0?4:W;W=S-(ha+U)|0;t=ha+((W>>>0>2>>>0?2:W)+U)|0;do{if((S-t|0)<2){c[r+792>>2]=0;ia=0}else{U=t;W=(d[U]|d[U+1|0]<<8)<<16>>16&65535;c[r+792>>2]=W;if(!((W|0)==16|(W|0)==8)){ia=W;break}W=ea-16|0;if((W|0)>0){yDb(r,32,2200048,(B=i,i=i+8|0,c[B>>2]=W,B)|0);i=B}c[o+16544>>2]=0;c[o+16548>>2]=0;c[h>>2]=1;c[g>>2]=0;break a}}while(0);yDb(r,16,2208536,(B=i,i=i+8|0,c[B>>2]=ia,B)|0);i=B;C=-38;i=j;return C|0}}while(0);yDb(r,16,2217840,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-38;i=j;return C|0}}while(0);yDb(r,16,2256464,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}}while(0);yDb(r,16,2271776,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}else{S=o+16580|0;if((c[S>>2]|0)!=0){c[g>>2]=0;C=c[n>>2]|0;i=j;return C|0}L=o+16544|0;c[L>>2]=0;K=o+32|0;b:do{if((c[K>>2]|0)!=0){u=o+16548|0;t=o+16564|0;W=o+16540|0;U=o+16552|0;E=o+100|0;s=o+36|0;R=o+16560|0;M=f+76|0;D=f+64|0;T=o+16556|0;X=o+132|0;Z=o+16572|0;Y=y;ja=v;c:while(1){if((ja-Y|0)<5){A=102;break}ka=zXa(q,2)|0;if(ka>>>0>9>>>0){A=104;break}do{if((399>>>(ka>>>0)&1|0)==0){if((ka|0)==6){c[u>>2]=zXa(q,2)|0;break}else if((ka|0)==5){la=c[t>>2]|0;ma=la>>>0>65535>>>0;na=ma?la>>>16:la;la=ma?16:0;if((na&65280|0)==0){oa=la;pa=na}else{oa=la|8;pa=na>>>8}if((c[W>>2]|0)==0){qa=(d[1191992+pa|0]|0)+oa|0}else{qa=zXa(q,2)|0}ra=zXa(q,qa)|0;if(ra>>>0>(c[t>>2]|0)>>>0){A=115;break c}if((ra|0)==0|ra>>>0>65535>>>0){A=117;break c}c[t>>2]=ra}else if((ka|0)==4){A=119;break c}else if((ka|0)==9){na=zXa(q,5)|0;if((na|0)==0){break}else{sa=na}do{sa=sa-1|0;zXa(q,8)|0;}while((sa|0)!=0)}if((ka-4|0)>>>0<2>>>0){break c}}else{na=c[L>>2]|0;la=(ka|0)==8;if(la){ta=1}else{ma=zXa(q,3)|0;ta=ma+1+(((c[W>>2]|0)==0)<<31>>31)|0}ma=c[U>>2]|0;do{if((ma|0)==0){ua=c[c[E+(na<<2)>>2]>>2]|0}else{va=c[W>>2]|0;if((va|0)<2){wa=0}else{wa=(ma|0)/2|0}if((ma|0)>0){xa=c[E+(na<<2)>>2]|0;ya=0;za=wa;while(1){Aa=(c[xa+(ya<<2)>>2]|0)+za|0;Ba=ya+1|0;if((Ba|0)<(ma|0)){ya=Ba;za=Aa}else{Ca=Aa;break}}}else{Ca=wa}za=(Ca|0)/(ma|0)|0;if((va|0)<=1){ua=za;break}ya=c[u>>2]|0;if((ya|0)==0){ua=za;break}ua=za>>ya-1>>1}}while(0);do{if(la){ma=c[t>>2]|0;if((ma|0)<=0){Da=ma;break}ma=c[s+(na<<2)>>2]|0;ya=0;while(1){c[ma+(ya<<2)>>2]=0;za=ya+1|0;xa=c[t>>2]|0;if((za|0)<(xa|0)){ya=za}else{Da=xa;break}}}else{ya=(ka|0)==7;do{if(ya){Ea=zXa(q,2)|0;if((Ea|0)>(c[R>>2]|0)){A=142;break c}if((Ea|0)>0){ma=0;while(1){va=zXa(q,6)|0;xa=c[X>>2]|0;c[xa+(ma<<2)>>2]=va<<31>>31^va>>1;va=ma+1|0;if((va|0)<(Ea|0)){ma=va}else{Fa=xa;Ga=5;Ha=Ea;break}}}else{Fa=c[X>>2]|0;Ga=5;Ha=Ea;break}}else{if(ka>>>0>3>>>0){A=145;break c}Fa=1049904+(ka*12|0)|0;Ga=0;Ha=ka}}while(0);ma=ya^1;xa=ya&(ua|0)!=0;va=(Ha|0)>0;if(xa&va){za=c[p+36+(na<<2)>>2]|0;Aa=-Ha|0;do{Ba=za+(Aa<<2)|0;c[Ba>>2]=(c[Ba>>2]|0)-ua;Aa=Aa+1|0;}while((Aa|0)<0)}Aa=(Ha|0)==0;if(Aa|ma){Ia=Aa?ua:0}else{Ia=c[Z>>2]|0}Aa=c[t>>2]|0;if((Aa|0)<=0){Da=Aa;break}Aa=p+36+(na<<2)|0;if(va){za=0;ya=c[Aa>>2]|0;while(1){Ba=za-1|0;Ja=Ia;Ka=0;do{Ja=(ba(c[ya+(Ba-Ka<<2)>>2]|0,c[Fa+(Ka<<2)>>2]|0)|0)+Ja|0;Ka=Ka+1|0;}while((Ka|0)<(Ha|0));Ka=zXa(q,ta)|0;Ba=c[Aa>>2]|0;c[Ba+(za<<2)>>2]=(Ka<<31>>31^Ka>>1)+(Ja>>Ga);Ka=za+1|0;La=c[t>>2]|0;if((Ka|0)<(La|0)){za=Ka;ya=Ba}else{Ma=La;Na=Ba;break}}}else{ya=Ia>>Ga;za=0;while(1){va=zXa(q,ta)|0;ma=c[Aa>>2]|0;c[ma+(za<<2)>>2]=(va<<31>>31^va>>1)+ya;va=za+1|0;Ba=c[t>>2]|0;if((va|0)<(Ba|0)){za=va}else{Ma=Ba;Na=ma;break}}}if(xa&(Ma|0)>0){Oa=0}else{Da=Ma;break}while(1){za=Na+(Oa<<2)|0;c[za>>2]=(c[za>>2]|0)+ua;za=Oa+1|0;ya=c[t>>2]|0;if((za|0)<(ya|0)){Oa=za}else{Da=ya;break}}}}while(0);la=c[U>>2]|0;do{if((la|0)>0){xa=c[W>>2]|0;if((xa|0)<2){Pa=0}else{Pa=(Da|0)/2|0}if((Da|0)>0){ya=c[s+(na<<2)>>2]|0;za=0;Aa=Pa;while(1){ma=(c[ya+(za<<2)>>2]|0)+Aa|0;Ba=za+1|0;if((Ba|0)<(Da|0)){za=Ba;Aa=ma}else{Qa=ma;break}}}else{Qa=Pa}if((la|0)>1){Aa=c[E+(na<<2)>>2]|0;za=1;do{c[Aa+(za-1<<2)>>2]=c[Aa+(za<<2)>>2];za=za+1|0;Ra=c[U>>2]|0;}while((za|0)<(Ra|0));Sa=Ra;Ta=c[W>>2]|0;Ua=c[t>>2]|0}else{Sa=la;Ta=xa;Ua=Da}za=(Qa|0)/(Ua|0)|0;if((Ta|0)<2){c[(c[E+(na<<2)>>2]|0)+(Sa-1<<2)>>2]=za;break}else{c[(c[E+(na<<2)>>2]|0)+(Sa-1<<2)>>2]=za<<c[u>>2];break}}}while(0);la=c[R>>2]|0;if((la|0)>0){za=c[s+(na<<2)>>2]|0;Aa=-la|0;while(1){c[za+(Aa<<2)>>2]=c[za+((c[t>>2]|0)+Aa<<2)>>2];la=Aa+1|0;if((la|0)<0){Aa=la}else{Va=za;break}}}else{Va=c[s+(na<<2)>>2]|0}za=c[u>>2]|0;do{if((za|0)!=0){if((c[t>>2]|0)<=0){break}c[Va>>2]=c[Va>>2]<<za;if((c[t>>2]|0)>1){Wa=1}else{break}do{Aa=Va+(Wa<<2)|0;c[Aa>>2]=c[Aa>>2]<<c[u>>2];Wa=Wa+1|0;}while((Wa|0)<(c[t>>2]|0))}}while(0);za=(c[L>>2]|0)+1|0;c[L>>2]=za;if((za|0)!=(c[K>>2]|0)){break}c[M>>2]=c[t>>2];za=_$a(e,k,0)|0;if((za|0)<0){C=za;A=208;break c}za=c[K>>2]|0;if((za|0)!=0){na=0;xa=c[t>>2]|0;Aa=za;while(1){za=c[(c[D>>2]|0)+(na<<2)>>2]|0;if((xa|0)>0){la=s+(na<<2)|0;ya=0;ma=za;Ba=za;za=xa;while(1){va=c[T>>2]|0;if((va|0)==3|(va|0)==5){La=c[(c[la>>2]|0)+(ya<<2)>>2]|0;if((La+32768|0)>>>0>65535>>>0){Xa=(La>>31^32767)&65535}else{Xa=La&65535}b[Ba>>1]=Xa;Ya=Ba+2|0;Za=ma;_a=za}else if((va|0)==2){va=c[(c[la>>2]|0)+(ya<<2)>>2]|0;if(va>>>0>255>>>0){$a=-va>>31&255}else{$a=va&255}a[ma]=$a;Ya=Ba;Za=ma+1|0;_a=c[t>>2]|0}else{Ya=Ba;Za=ma;_a=za}va=ya+1|0;if((va|0)<(_a|0)){ya=va;ma=Za;Ba=Ya;za=_a}else{break}}ab=_a;bb=c[K>>2]|0}else{ab=xa;bb=Aa}za=na+1|0;if(za>>>0<bb>>>0){na=za;xa=ab;Aa=bb}else{break}}}c[g>>2]=1}}while(0);if(!((c[L>>2]|0)>>>0<(c[K>>2]|0)>>>0)){break b}Y=c[F>>2]|0;ja=c[l>>2]|0}if((A|0)==102){c[g>>2]=0;break}else if((A|0)==104){yDb(e,16,2104976,(B=i,i=i+8|0,c[B>>2]=ka,B)|0);i=B;c[g>>2]=0;break}else if((A|0)==115){yDb(e,16,2048256,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1163346256;i=j;return C|0}else if((A|0)==117){yDb(e,16,2002784,(B=i,i=i+8|0,c[B>>2]=ra,B)|0);i=B;C=-22;i=j;return C|0}else if((A|0)==119){c[S>>2]=1}else if((A|0)==142){yDb(c[o>>2]|0,16,1937336,(B=i,i=i+8|0,c[B>>2]=Ea,B)|0);i=B;C=-22;i=j;return C|0}else if((A|0)==145){yDb(c[o>>2]|0,16,1937336,(B=i,i=i+8|0,c[B>>2]=ka,B)|0);i=B;C=-1094995529;i=j;return C|0}else if((A|0)==208){i=j;return C|0}c[g>>2]=0}}while(0);if(!((c[L>>2]|0)>>>0<(c[K>>2]|0)>>>0)){break}c[g>>2]=0}}while(0);g=c[F>>2]|0;F=(g|0)/8|0;c[z>>2]=g-(F<<3);if((F|0)>(w|0)){yDb(c[o>>2]|0,16,1965384,(B=i,i=i+8|0,c[B>>2]=F-w,B)|0);i=B;c[o+140>>2]=0;c[o+144>>2]=0;C=-1094995529;i=j;return C|0}B=o+140|0;w=c[B>>2]|0;if((w|0)==0){C=F;i=j;return C|0}g=o+144|0;c[g>>2]=(c[g>>2]|0)+F;c[B>>2]=w-F;C=x;i=j;return C|0}function yXa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+60>>2]|0;a=b+32|0;if((c[a>>2]|0)==0){d=b+136|0;$Db(d);e=b+132|0;$Db(e);return 0}f=b+36|0;g=b+68|0;h=b+100|0;i=0;do{c[f+(i<<2)>>2]=0;$Db(g+(i<<2)|0);$Db(h+(i<<2)|0);i=i+1|0;}while(i>>>0<(c[a>>2]|0)>>>0);d=b+136|0;$Db(d);e=b+132|0;$Db(e);return 0}function zXa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=c[a>>2]|0;i=h+(f>>>3)|0;j=(fe(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(f&7);i=j>>>0>65535>>>0;k=i?j>>>16:j;l=i?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=(d[1191992+n|0]|0)+m|0;m=k-b|0;if(!((m|0)<7|(k|0)==-2147483615)){n=b+32+f-k|0;c[e>>2]=g>>>0>n>>>0?n:g;o=(j>>>(m>>>0))+(30-k<<b)|0;return o|0}do{if((j|0)>-1){k=c[a+12>>2]|0;m=f;n=0;do{if(!(k>>>0>m>>>0)){o=-1;p=16;break}l=m+1|0;m=g>>>0>l>>>0?l:g;l=h+(m>>>3)|0;q=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7);n=n+1|0;}while((n|0)!=2147483647&(q|0)>-1);if((p|0)==16){return o|0}k=m+1|0;l=g>>>0>k>>>0?k:g;if((n|0)<2147483646){r=n;s=q;t=l;break}if((n|0)!=2147483646){o=-1;return o|0}c[e>>2]=l;o=0;return o|0}else{l=f+1|0;r=0;s=j;t=g>>>0>l>>>0?l:g}}while(0);if((b|0)==0){u=t;v=0}else{j=t+b|0;u=g>>>0>j>>>0?j:g;v=s<<1>>>((32-b|0)>>>0)}c[e>>2]=u;o=v+(r<<b)|0;return o|0}function AXa(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;BXa(e);BXa(e+16|0);BXa(e+32|0);BXa(e+48|0);BXa(e+64|0);BXa(e+80|0);BXa(e+96|0);BXa(e+112|0);f=d<<1;g=f+d|0;h=g+d|0;i=h+d|0;j=i+d|0;k=j+d|0;l=0;do{m=((b[e+(l<<1)>>1]|0)*16383|0)+524256|0;n=b[e+(l+16<<1)>>1]|0;o=m+(n*21407|0)|0;p=m+(n*8867|0)|0;q=m+(n*-8867|0)|0;r=m+(n*-21407|0)|0;n=b[e+(l+8<<1)>>1]|0;m=b[e+(l+24<<1)>>1]|0;s=(m*19266|0)+(n*22725|0)|0;t=(m*-4520|0)+(n*19266|0)|0;u=(m*-22725|0)+(n*12873|0)|0;v=(m*-12873|0)+(n*4520|0)|0;n=b[e+(l+32<<1)>>1]|0;if(n<<16>>16==0){w=r;x=q;y=p;z=o}else{m=n<<16>>16;n=m*16383|0;A=m*-16383|0;w=n+r|0;x=A+q|0;y=A+p|0;z=n+o|0}o=b[e+(l+40<<1)>>1]|0;if(o<<16>>16==0){B=v;C=u;D=t;E=s}else{n=o<<16>>16;B=(n*19266|0)+v|0;C=(n*4520|0)+u|0;D=(n*-22725|0)+t|0;E=(n*12873|0)+s|0}s=b[e+(l+48<<1)>>1]|0;if(s<<16>>16==0){F=w;G=x;H=y;I=z}else{n=s<<16>>16;F=(n*-8867|0)+w|0;G=(n*21407|0)+x|0;H=(n*-21407|0)+y|0;I=(n*8867|0)+z|0}n=b[e+(l+56<<1)>>1]|0;if(n<<16>>16==0){J=B;K=C;L=D;M=E}else{s=n<<16>>16;J=(s*-22725|0)+B|0;K=(s*19266|0)+C|0;L=(s*-12873|0)+D|0;M=(s*4520|0)+E|0}s=M+I>>20;if(s>>>0>255>>>0){N=-s>>31&255}else{N=s&255}a[c+l|0]=N;s=L+H>>20;if(s>>>0>255>>>0){O=-s>>31&255}else{O=s&255}a[c+(l+d)|0]=O;s=K+G>>20;if(s>>>0>255>>>0){P=-s>>31&255}else{P=s&255}a[c+(l+f)|0]=P;s=J+F>>20;if(s>>>0>255>>>0){Q=-s>>31&255}else{Q=s&255}a[c+(l+g)|0]=Q;s=F-J>>20;if(s>>>0>255>>>0){R=-s>>31&255}else{R=s&255}a[c+(l+h)|0]=R;s=G-K>>20;if(s>>>0>255>>>0){S=-s>>31&255}else{S=s&255}a[c+(l+i)|0]=S;s=H-L>>20;if(s>>>0>255>>>0){T=-s>>31&255}else{T=s&255}a[c+(l+j)|0]=T;s=I-M>>20;if(s>>>0>255>>>0){U=-s>>31&255}else{U=s&255}a[c+(k+l)|0]=U;l=l+1|0;}while((l|0)<8);return}function BXa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=a+4|0;e=d;f=c[e>>2]|0;g=a+8|0;h=g;i=a+12|0;j=i;k=c[j>>2]|0;l=a+2|0;m=b[l>>1]|0;n=b[a>>1]|0;if((c[h>>2]|f|k|m|0)==0){o=n<<3&65528|n<<19;c[j>>2]=o;c[h>>2]=o;c[e>>2]=o;c[a>>2]=o;return}o=(n*16383|0)+1024|0;n=f<<16>>16;f=n*21407|0;e=f+o|0;h=n*8867|0;n=h+o|0;j=o-h|0;h=o-f|0;f=a+6|0;o=b[f>>1]|0;p=(o*19266|0)+(m*22725|0)|0;q=(o*-4520|0)+(m*19266|0)|0;r=(o*-22725|0)+(m*12873|0)|0;s=(o*-12873|0)+(m*4520|0)|0;m=g;o=c[m>>2]|0;if((o|0)==0&(c[m+4>>2]|0)==0){t=s;u=r;v=q;w=p;x=h;y=j;z=n;A=e;B=a+14|0;C=a+10|0}else{m=(o&65535)<<16>>16;o=m*16383|0;D=k<<16>>16;k=D*8867|0;E=m*-16383|0;m=D*21407|0;D=a+10|0;F=b[D>>1]|0;G=a+14|0;H=b[G>>1]|0;t=(F*19266|0)+s+(H*-22725|0)|0;u=(F*4520|0)+r+(H*19266|0)|0;v=(F*-22725|0)+q+(H*-12873|0)|0;w=(F*12873|0)+p+(H*4520|0)|0;x=o+h-k|0;y=E+j+m|0;z=E+n-m|0;A=o+e+k|0;B=G;C=D}b[a>>1]=(w+A|0)>>>11;b[B>>1]=(A-w|0)>>>11;b[l>>1]=(v+z|0)>>>11;b[i>>1]=(z-v|0)>>>11;b[d>>1]=(u+y|0)>>>11;b[C>>1]=(y-u|0)>>>11;b[f>>1]=(t+x|0)>>>11;b[g>>1]=(x-t|0)>>>11;return}function CXa(a,b,c){a=a|0;b=b|0;c=c|0;BXa(c);BXa(c+16|0);BXa(c+32|0);BXa(c+48|0);BXa(c+64|0);BXa(c+80|0);BXa(c+96|0);BXa(c+112|0);DXa(a,b,c);DXa(a+1|0,b,c+2|0);DXa(a+2|0,b,c+4|0);DXa(a+3|0,b,c+6|0);DXa(a+4|0,b,c+8|0);DXa(a+5|0,b,c+10|0);DXa(a+6|0,b,c+12|0);DXa(a+7|0,b,c+14|0);return}function DXa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=((b[f>>1]|0)*16383|0)+524256|0;h=b[f+32>>1]|0;i=g+(h*21407|0)|0;j=g+(h*8867|0)|0;k=g+(h*-8867|0)|0;l=g+(h*-21407|0)|0;h=b[f+16>>1]|0;g=b[f+48>>1]|0;m=(g*19266|0)+(h*22725|0)|0;n=(g*-4520|0)+(h*19266|0)|0;o=(g*-22725|0)+(h*12873|0)|0;p=(g*-12873|0)+(h*4520|0)|0;h=b[f+64>>1]|0;if(h<<16>>16==0){q=l;r=k;s=j;t=i}else{g=h<<16>>16;h=g*16383|0;u=g*-16383|0;q=h+l|0;r=u+k|0;s=u+j|0;t=h+i|0}i=b[f+80>>1]|0;if(i<<16>>16==0){v=p;w=o;x=n;y=m}else{h=i<<16>>16;v=(h*19266|0)+p|0;w=(h*4520|0)+o|0;x=(h*-22725|0)+n|0;y=(h*12873|0)+m|0}m=b[f+96>>1]|0;if(m<<16>>16==0){z=q;A=r;B=s;C=t}else{h=m<<16>>16;z=(h*-8867|0)+q|0;A=(h*21407|0)+r|0;B=(h*-21407|0)+s|0;C=(h*8867|0)+t|0}t=b[f+112>>1]|0;if(t<<16>>16==0){D=v;E=w;F=x;G=y}else{f=t<<16>>16;D=(f*-22725|0)+v|0;E=(f*19266|0)+w|0;F=(f*-12873|0)+x|0;G=(f*4520|0)+y|0}y=(d[c]|0)+(G+C>>20)|0;if(y>>>0>255>>>0){H=-y>>31&255}else{H=y&255}a[c]=H;H=c+e|0;y=(d[H]|0)+(F+B>>20)|0;if(y>>>0>255>>>0){I=-y>>31&255}else{I=y&255}a[H]=I;I=e<<1;H=c+I|0;y=(d[H]|0)+(E+A>>20)|0;if(y>>>0>255>>>0){J=-y>>31&255}else{J=y&255}a[H]=J;J=I+e|0;I=c+J|0;H=(d[I]|0)+(D+z>>20)|0;if(H>>>0>255>>>0){K=-H>>31&255}else{K=H&255}a[I]=K;K=J+e|0;J=c+K|0;I=(d[J]|0)+(z-D>>20)|0;if(I>>>0>255>>>0){L=-I>>31&255}else{L=I&255}a[J]=L;L=K+e|0;K=c+L|0;J=(d[K]|0)+(A-E>>20)|0;if(J>>>0>255>>>0){M=-J>>31&255}else{M=J&255}a[K]=M;M=L+e|0;L=c+M|0;K=(d[L]|0)+(B-F>>20)|0;if(K>>>0>255>>>0){N=-K>>31&255}else{N=K&255}a[L]=N;N=c+(M+e)|0;e=(d[N]|0)+(C-G>>20)|0;if(!(e>>>0>255>>>0)){O=e&255;a[N]=O;return}O=-e>>31&255;a[N]=O;return}function EXa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;BXa(a);BXa(a+16|0);BXa(a+32|0);BXa(a+48|0);BXa(a+64|0);BXa(a+80|0);BXa(a+96|0);BXa(a+112|0);c=0;do{d=a+(c<<1)|0;e=((b[d>>1]|0)*16383|0)+524256|0;f=a+(c+16<<1)|0;g=b[f>>1]|0;h=e+(g*21407|0)|0;i=e+(g*8867|0)|0;j=e+(g*-8867|0)|0;k=e+(g*-21407|0)|0;g=a+(c+8<<1)|0;e=b[g>>1]|0;l=a+(c+24<<1)|0;m=b[l>>1]|0;n=(m*19266|0)+(e*22725|0)|0;o=(m*-4520|0)+(e*19266|0)|0;p=(m*-22725|0)+(e*12873|0)|0;q=(m*-12873|0)+(e*4520|0)|0;e=a+(c+32<<1)|0;m=b[e>>1]|0;if(m<<16>>16==0){r=k;s=j;t=i;u=h}else{v=m<<16>>16;m=v*16383|0;w=v*-16383|0;r=m+k|0;s=w+j|0;t=w+i|0;u=m+h|0}h=a+(c+40<<1)|0;m=b[h>>1]|0;if(m<<16>>16==0){x=q;y=p;z=o;A=n}else{i=m<<16>>16;x=(i*19266|0)+q|0;y=(i*4520|0)+p|0;z=(i*-22725|0)+o|0;A=(i*12873|0)+n|0}n=a+(c+48<<1)|0;i=b[n>>1]|0;if(i<<16>>16==0){B=r;C=s;D=t;E=u}else{o=i<<16>>16;B=(o*-8867|0)+r|0;C=(o*21407|0)+s|0;D=(o*-21407|0)+t|0;E=(o*8867|0)+u|0}o=a+(c+56<<1)|0;i=b[o>>1]|0;if(i<<16>>16==0){F=x;G=y;H=z;I=A}else{p=i<<16>>16;F=(p*-22725|0)+x|0;G=(p*19266|0)+y|0;H=(p*-12873|0)+z|0;I=(p*4520|0)+A|0}b[d>>1]=I+E>>20;b[g>>1]=H+D>>20;b[f>>1]=G+C>>20;b[l>>1]=F+B>>20;b[e>>1]=B-F>>20;b[h>>1]=C-G>>20;b[n>>1]=D-H>>20;b[o>>1]=E-I>>20;c=c+1|0;}while((c|0)<8);return}function FXa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=a;GXa(d,0);GXa(d+16|0,0);GXa(d+32|0,0);GXa(d+48|0,0);GXa(d+64|0,0);GXa(d+80|0,0);GXa(d+96|0,0);GXa(d+112|0,0);a=c>>>1;c=a<<1;g=c+a|0;h=g+a|0;i=h+a|0;j=i+a|0;k=j+a|0;l=0;do{m=(e[d+(l<<1)>>1]<<16)+524288|0;n=b[d+(l+16<<1)>>1]|0;o=m+(n*85628|0)|0;p=m+(n*35468|0)|0;q=m+(n*-35468|0)|0;r=m+(n*-85628|0)|0;n=b[d+(l+8<<1)>>1]|0;m=b[d+(l+24<<1)>>1]|0;s=(m*77060|0)+(n*90900|0)|0;t=(m*-18080|0)+(n*77060|0)|0;u=(m*-90900|0)+(n*51492|0)|0;v=(m*-51492|0)+(n*18080|0)|0;n=b[d+(l+32<<1)>>1]|0;if(n<<16>>16==0){w=r;x=q;y=p;z=o}else{m=n<<16>>16;n=m<<16;A=m*-65536|0;w=n+r|0;x=A+q|0;y=A+p|0;z=n+o|0}o=b[d+(l+40<<1)>>1]|0;if(o<<16>>16==0){B=v;C=u;D=t;E=s}else{n=o<<16>>16;B=(n*77060|0)+v|0;C=(n*18080|0)+u|0;D=(n*-90900|0)+t|0;E=(n*51492|0)+s|0}s=b[d+(l+48<<1)>>1]|0;if(s<<16>>16==0){F=w;G=x;H=y;I=z}else{n=s<<16>>16;F=(n*-35468|0)+w|0;G=(n*85628|0)+x|0;H=(n*-85628|0)+y|0;I=(n*35468|0)+z|0}n=b[d+(l+56<<1)>>1]|0;if(n<<16>>16==0){J=B;K=C;L=D;M=E}else{s=n<<16>>16;J=(s*-90900|0)+B|0;K=(s*77060|0)+C|0;L=(s*-51492|0)+D|0;M=(s*18080|0)+E|0}s=M+I>>20;if(s>>>0<1024>>>0){N=s&65535}else{N=-s>>31&1023}b[f+(l<<1)>>1]=N;s=L+H>>20;if(s>>>0<1024>>>0){O=s&65535}else{O=-s>>31&1023}b[f+(l+a<<1)>>1]=O;s=K+G>>20;if(s>>>0<1024>>>0){P=s&65535}else{P=-s>>31&1023}b[f+(l+c<<1)>>1]=P;s=J+F>>20;if(s>>>0<1024>>>0){Q=s&65535}else{Q=-s>>31&1023}b[f+(l+g<<1)>>1]=Q;s=F-J>>20;if(s>>>0<1024>>>0){R=s&65535}else{R=-s>>31&1023}b[f+(l+h<<1)>>1]=R;s=G-K>>20;if(s>>>0<1024>>>0){S=s&65535}else{S=-s>>31&1023}b[f+(l+i<<1)>>1]=S;s=H-L>>20;if(s>>>0<1024>>>0){T=s&65535}else{T=-s>>31&1023}b[f+(l+j<<1)>>1]=T;s=I-M>>20;if(s>>>0<1024>>>0){U=s&65535}else{U=-s>>31&1023}b[f+(k+l<<1)>>1]=U;l=l+1|0;}while((l|0)<8);return}function GXa(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=a;f=a+4|0;g=f;h=c[g>>2]|0;i=a+8|0;j=i;k=a+12|0;l=k;m=c[l>>2]|0;n=a+2|0;o=b[n>>1]|0;if((c[j>>2]|h|m|o|0)==0){p=1-d|0;q=b[a>>1]|0;if((p|0)>-1){r=q<<p}else{r=q+(1<<d-2)>>d-1}q=r&65535|r<<16;c[l>>2]=q;c[j>>2]=q;c[g>>2]=q;c[e>>2]=q;return}else{q=d+15|0;e=(b[a>>1]<<16)+(1<<d+14)|0;d=h<<16>>16;h=d*85628|0;g=e+h|0;j=d*35468|0;d=e+j|0;l=e-j|0;j=e-h|0;h=a+6|0;e=b[h>>1]|0;r=(e*77060|0)+(o*90900|0)|0;p=(e*-18080|0)+(o*77060|0)|0;s=(e*-90900|0)+(o*51492|0)|0;t=(e*-51492|0)+(o*18080|0)|0;o=i;e=c[o>>2]|0;if((e|0)==0&(c[o+4>>2]|0)==0){u=t;v=s;w=p;x=r;y=j;z=l;A=d;B=g;C=a+14|0;D=a+10|0}else{o=(e&65535)<<16>>16;e=o<<16;E=m<<16>>16;m=E*35468|0;F=o*-65536|0;o=E*85628|0;E=a+10|0;G=b[E>>1]|0;H=a+14|0;I=b[H>>1]|0;u=(G*77060|0)+t+(I*-90900|0)|0;v=(G*18080|0)+s+(I*77060|0)|0;w=(G*-90900|0)+p+(I*-51492|0)|0;x=(G*51492|0)+r+(I*18080|0)|0;y=e+j-m|0;z=F+l+o|0;A=F+d-o|0;B=e+g+m|0;C=H;D=E}b[a>>1]=x+B>>q;b[C>>1]=B-x>>q;b[n>>1]=w+A>>q;b[k>>1]=A-w>>q;b[f>>1]=v+z>>q;b[D>>1]=z-v>>q;b[h>>1]=u+y>>q;b[i>>1]=y-u>>q;return}}function HXa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=a;GXa(d,0);GXa(d+16|0,0);GXa(d+32|0,0);GXa(d+48|0,0);GXa(d+64|0,0);GXa(d+80|0,0);GXa(d+96|0,0);GXa(d+112|0,0);a=c>>>1;c=a<<1;g=c+a|0;h=g+a|0;i=h+a|0;j=i+a|0;k=j+a|0;l=0;do{m=f+(l<<1)|0;n=(e[d+(l<<1)>>1]<<16)+524288|0;o=b[d+(l+16<<1)>>1]|0;p=n+(o*85628|0)|0;q=n+(o*35468|0)|0;r=n+(o*-35468|0)|0;s=n+(o*-85628|0)|0;o=b[d+(l+8<<1)>>1]|0;n=b[d+(l+24<<1)>>1]|0;t=(n*77060|0)+(o*90900|0)|0;u=(n*-18080|0)+(o*77060|0)|0;v=(n*-90900|0)+(o*51492|0)|0;w=(n*-51492|0)+(o*18080|0)|0;o=b[d+(l+32<<1)>>1]|0;if(o<<16>>16==0){x=s;y=r;z=q;A=p}else{n=o<<16>>16;o=n<<16;B=n*-65536|0;x=o+s|0;y=B+r|0;z=B+q|0;A=o+p|0}p=b[d+(l+40<<1)>>1]|0;if(p<<16>>16==0){C=w;D=v;E=u;F=t}else{o=p<<16>>16;C=(o*77060|0)+w|0;D=(o*18080|0)+v|0;E=(o*-90900|0)+u|0;F=(o*51492|0)+t|0}t=b[d+(l+48<<1)>>1]|0;if(t<<16>>16==0){G=x;H=y;I=z;J=A}else{o=t<<16>>16;G=(o*-35468|0)+x|0;H=(o*85628|0)+y|0;I=(o*-85628|0)+z|0;J=(o*35468|0)+A|0}o=b[d+(l+56<<1)>>1]|0;if(o<<16>>16==0){K=C;L=D;M=E;N=F}else{t=o<<16>>16;K=(t*-90900|0)+C|0;L=(t*77060|0)+D|0;M=(t*-51492|0)+E|0;N=(t*18080|0)+F|0}t=(e[m>>1]|0)+(N+J>>20)|0;if(t>>>0<1024>>>0){O=t&65535}else{O=-t>>31&1023}b[m>>1]=O;m=f+(l+a<<1)|0;t=(e[m>>1]|0)+(M+I>>20)|0;if(t>>>0<1024>>>0){P=t&65535}else{P=-t>>31&1023}b[m>>1]=P;m=f+(l+c<<1)|0;t=(e[m>>1]|0)+(L+H>>20)|0;if(t>>>0<1024>>>0){Q=t&65535}else{Q=-t>>31&1023}b[m>>1]=Q;m=f+(l+g<<1)|0;t=(e[m>>1]|0)+(K+G>>20)|0;if(t>>>0<1024>>>0){R=t&65535}else{R=-t>>31&1023}b[m>>1]=R;m=f+(l+h<<1)|0;t=(e[m>>1]|0)+(G-K>>20)|0;if(t>>>0<1024>>>0){S=t&65535}else{S=-t>>31&1023}b[m>>1]=S;m=f+(l+i<<1)|0;t=(e[m>>1]|0)+(H-L>>20)|0;if(t>>>0<1024>>>0){T=t&65535}else{T=-t>>31&1023}b[m>>1]=T;m=f+(l+j<<1)|0;t=(e[m>>1]|0)+(I-M>>20)|0;if(t>>>0<1024>>>0){U=t&65535}else{U=-t>>31&1023}b[m>>1]=U;m=f+(k+l<<1)|0;t=(e[m>>1]|0)+(J-N>>20)|0;if(t>>>0<1024>>>0){V=t&65535}else{V=-t>>31&1023}b[m>>1]=V;l=l+1|0;}while((l|0)<8);return}function IXa(a){a=a|0;GXa(a,0);GXa(a+16|0,0);GXa(a+32|0,0);GXa(a+48|0,0);GXa(a+64|0,0);GXa(a+80|0,0);GXa(a+96|0,0);GXa(a+112|0,0);JXa(a);JXa(a+2|0);JXa(a+4|0);JXa(a+6|0);JXa(a+8|0);JXa(a+10|0);JXa(a+12|0);JXa(a+14|0);return}function JXa(a){a=a|0;var c=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;c=(e[a>>1]<<16)+524288|0;d=a+32|0;f=b[d>>1]|0;g=c+(f*85628|0)|0;h=c+(f*35468|0)|0;i=c+(f*-35468|0)|0;j=c+(f*-85628|0)|0;f=a+16|0;c=b[f>>1]|0;k=a+48|0;l=b[k>>1]|0;m=(l*77060|0)+(c*90900|0)|0;n=(l*-18080|0)+(c*77060|0)|0;o=(l*-90900|0)+(c*51492|0)|0;p=(l*-51492|0)+(c*18080|0)|0;c=a+64|0;l=b[c>>1]|0;if(l<<16>>16==0){q=j;r=i;s=h;t=g}else{u=l<<16>>16;l=u<<16;v=u*-65536|0;q=l+j|0;r=v+i|0;s=v+h|0;t=l+g|0}g=a+80|0;l=b[g>>1]|0;if(l<<16>>16==0){w=p;x=o;y=n;z=m}else{h=l<<16>>16;w=(h*77060|0)+p|0;x=(h*18080|0)+o|0;y=(h*-90900|0)+n|0;z=(h*51492|0)+m|0}m=a+96|0;h=b[m>>1]|0;if(h<<16>>16==0){A=q;B=r;C=s;D=t}else{n=h<<16>>16;A=(n*-35468|0)+q|0;B=(n*85628|0)+r|0;C=(n*-85628|0)+s|0;D=(n*35468|0)+t|0}t=a+112|0;n=b[t>>1]|0;if(n<<16>>16==0){E=w;F=x;G=y;H=z}else{s=n<<16>>16;E=(s*-90900|0)+w|0;F=(s*77060|0)+x|0;G=(s*-51492|0)+y|0;H=(s*18080|0)+z|0}b[a>>1]=H+D>>20;b[f>>1]=G+C>>20;b[d>>1]=F+B>>20;b[k>>1]=E+A>>20;b[c>>1]=A-E>>20;b[g>>1]=B-F>>20;b[m>>1]=C-G>>20;b[t>>1]=D-H>>20;return}function KXa(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=a;LXa(d);LXa(d+16|0);LXa(d+32|0);LXa(d+48|0);LXa(d+64|0);LXa(d+80|0);LXa(d+96|0);LXa(d+112|0);a=c>>>1;c=a<<1;f=c+a|0;g=f+a|0;h=g+a|0;i=h+a|0;j=i+a|0;k=0;do{l=((b[d+(k<<1)>>1]|0)*32767|0)+65534|0;m=b[d+(k+16<<1)>>1]|0;n=l+(m*42813|0)|0;o=l+(m*17734|0)|0;p=l+(m*-17734|0)|0;q=l+(m*-42813|0)|0;m=b[d+(k+8<<1)>>1]|0;l=b[d+(k+24<<1)>>1]|0;r=(l*38531|0)+(m*45451|0)|0;s=(l*-9041|0)+(m*38531|0)|0;t=(l*-45451|0)+(m*25746|0)|0;u=(l*-25746|0)+(m*9041|0)|0;m=b[d+(k+32<<1)>>1]|0;if(m<<16>>16==0){v=q;w=p;x=o;y=n}else{l=m<<16>>16;m=l*32767|0;z=l*-32767|0;v=m+q|0;w=z+p|0;x=z+o|0;y=m+n|0}n=b[d+(k+40<<1)>>1]|0;if(n<<16>>16==0){A=u;B=t;C=s;D=r}else{m=n<<16>>16;A=(m*38531|0)+u|0;B=(m*9041|0)+t|0;C=(m*-45451|0)+s|0;D=(m*25746|0)+r|0}r=b[d+(k+48<<1)>>1]|0;if(r<<16>>16==0){E=v;F=w;G=x;H=y}else{m=r<<16>>16;E=(m*-17734|0)+v|0;F=(m*42813|0)+w|0;G=(m*-42813|0)+x|0;H=(m*17734|0)+y|0}m=b[d+(k+56<<1)>>1]|0;if(m<<16>>16==0){I=A;J=B;K=C;L=D}else{r=m<<16>>16;I=(r*-45451|0)+A|0;J=(r*38531|0)+B|0;K=(r*-25746|0)+C|0;L=(r*9041|0)+D|0}r=L+H>>17;if(r>>>0<4096>>>0){M=r&65535}else{M=-r>>31&4095}b[e+(k<<1)>>1]=M;r=K+G>>17;if(r>>>0<4096>>>0){N=r&65535}else{N=-r>>31&4095}b[e+(k+a<<1)>>1]=N;r=J+F>>17;if(r>>>0<4096>>>0){O=r&65535}else{O=-r>>31&4095}b[e+(k+c<<1)>>1]=O;r=I+E>>17;if(r>>>0<4096>>>0){P=r&65535}else{P=-r>>31&4095}b[e+(k+f<<1)>>1]=P;r=E-I>>17;if(r>>>0<4096>>>0){Q=r&65535}else{Q=-r>>31&4095}b[e+(k+g<<1)>>1]=Q;r=F-J>>17;if(r>>>0<4096>>>0){R=r&65535}else{R=-r>>31&4095}b[e+(k+h<<1)>>1]=R;r=G-K>>17;if(r>>>0<4096>>>0){S=r&65535}else{S=-r>>31&4095}b[e+(k+i<<1)>>1]=S;r=H-L>>17;if(r>>>0<4096>>>0){T=r&65535}else{T=-r>>31&4095}b[e+(j+k<<1)>>1]=T;k=k+1|0;}while((k|0)<8);return}function LXa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=a+4|0;e=d;f=c[e>>2]|0;g=a+8|0;h=g;i=a+12|0;j=i;k=c[j>>2]|0;l=a+2|0;m=b[l>>1]|0;n=b[a>>1]|0;if((c[h>>2]|f|k|m|0)==0){o=(n+1|0)>>>1;p=o&65535|o<<16;c[j>>2]=p;c[h>>2]=p;c[e>>2]=p;c[a>>2]=p;return}p=(n*32767|0)+32768|0;n=f<<16>>16;f=n*42813|0;e=f+p|0;h=n*17734|0;n=h+p|0;j=p-h|0;h=p-f|0;f=a+6|0;p=b[f>>1]|0;o=(p*38531|0)+(m*45451|0)|0;q=(p*-9041|0)+(m*38531|0)|0;r=(p*-45451|0)+(m*25746|0)|0;s=(p*-25746|0)+(m*9041|0)|0;m=g;p=c[m>>2]|0;if((p|0)==0&(c[m+4>>2]|0)==0){t=s;u=r;v=q;w=o;x=h;y=j;z=n;A=e;B=a+14|0;C=a+10|0}else{m=(p&65535)<<16>>16;p=m*32767|0;D=k<<16>>16;k=D*17734|0;E=m*-32767|0;m=D*42813|0;D=a+10|0;F=b[D>>1]|0;G=a+14|0;H=b[G>>1]|0;t=(F*38531|0)+s+(H*-45451|0)|0;u=(F*9041|0)+r+(H*38531|0)|0;v=(F*-45451|0)+q+(H*-25746|0)|0;w=(F*25746|0)+o+(H*9041|0)|0;x=p+h-k|0;y=E+j+m|0;z=E+n-m|0;A=p+e+k|0;B=G;C=D}b[a>>1]=(w+A|0)>>>16;b[B>>1]=(A-w|0)>>>16;b[l>>1]=(v+z|0)>>>16;b[i>>1]=(z-v|0)>>>16;b[d>>1]=(u+y|0)>>>16;b[C>>1]=(y-u|0)>>>16;b[f>>1]=(t+x|0)>>>16;b[g>>1]=(x-t|0)>>>16;return}function MXa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=a;LXa(d);LXa(d+16|0);LXa(d+32|0);LXa(d+48|0);LXa(d+64|0);LXa(d+80|0);LXa(d+96|0);LXa(d+112|0);a=c>>>1;c=a<<1;g=c+a|0;h=g+a|0;i=h+a|0;j=i+a|0;k=j+a|0;l=0;do{m=f+(l<<1)|0;n=((b[d+(l<<1)>>1]|0)*32767|0)+65534|0;o=b[d+(l+16<<1)>>1]|0;p=n+(o*42813|0)|0;q=n+(o*17734|0)|0;r=n+(o*-17734|0)|0;s=n+(o*-42813|0)|0;o=b[d+(l+8<<1)>>1]|0;n=b[d+(l+24<<1)>>1]|0;t=(n*38531|0)+(o*45451|0)|0;u=(n*-9041|0)+(o*38531|0)|0;v=(n*-45451|0)+(o*25746|0)|0;w=(n*-25746|0)+(o*9041|0)|0;o=b[d+(l+32<<1)>>1]|0;if(o<<16>>16==0){x=s;y=r;z=q;A=p}else{n=o<<16>>16;o=n*32767|0;B=n*-32767|0;x=o+s|0;y=B+r|0;z=B+q|0;A=o+p|0}p=b[d+(l+40<<1)>>1]|0;if(p<<16>>16==0){C=w;D=v;E=u;F=t}else{o=p<<16>>16;C=(o*38531|0)+w|0;D=(o*9041|0)+v|0;E=(o*-45451|0)+u|0;F=(o*25746|0)+t|0}t=b[d+(l+48<<1)>>1]|0;if(t<<16>>16==0){G=x;H=y;I=z;J=A}else{o=t<<16>>16;G=(o*-17734|0)+x|0;H=(o*42813|0)+y|0;I=(o*-42813|0)+z|0;J=(o*17734|0)+A|0}o=b[d+(l+56<<1)>>1]|0;if(o<<16>>16==0){K=C;L=D;M=E;N=F}else{t=o<<16>>16;K=(t*-45451|0)+C|0;L=(t*38531|0)+D|0;M=(t*-25746|0)+E|0;N=(t*9041|0)+F|0}t=(e[m>>1]|0)+(N+J>>17)|0;if(t>>>0<4096>>>0){O=t&65535}else{O=-t>>31&4095}b[m>>1]=O;m=f+(l+a<<1)|0;t=(e[m>>1]|0)+(M+I>>17)|0;if(t>>>0<4096>>>0){P=t&65535}else{P=-t>>31&4095}b[m>>1]=P;m=f+(l+c<<1)|0;t=(e[m>>1]|0)+(L+H>>17)|0;if(t>>>0<4096>>>0){Q=t&65535}else{Q=-t>>31&4095}b[m>>1]=Q;m=f+(l+g<<1)|0;t=(e[m>>1]|0)+(K+G>>17)|0;if(t>>>0<4096>>>0){R=t&65535}else{R=-t>>31&4095}b[m>>1]=R;m=f+(l+h<<1)|0;t=(e[m>>1]|0)+(G-K>>17)|0;if(t>>>0<4096>>>0){S=t&65535}else{S=-t>>31&4095}b[m>>1]=S;m=f+(l+i<<1)|0;t=(e[m>>1]|0)+(H-L>>17)|0;if(t>>>0<4096>>>0){T=t&65535}else{T=-t>>31&4095}b[m>>1]=T;m=f+(l+j<<1)|0;t=(e[m>>1]|0)+(I-M>>17)|0;if(t>>>0<4096>>>0){U=t&65535}else{U=-t>>31&4095}b[m>>1]=U;m=f+(k+l<<1)|0;t=(e[m>>1]|0)+(J-N>>17)|0;if(t>>>0<4096>>>0){V=t&65535}else{V=-t>>31&4095}b[m>>1]=V;l=l+1|0;}while((l|0)<8);return}function NXa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;LXa(a);LXa(a+16|0);LXa(a+32|0);LXa(a+48|0);LXa(a+64|0);LXa(a+80|0);LXa(a+96|0);LXa(a+112|0);c=0;do{d=a+(c<<1)|0;e=((b[d>>1]|0)*32767|0)+65534|0;f=a+(c+16<<1)|0;g=b[f>>1]|0;h=e+(g*42813|0)|0;i=e+(g*17734|0)|0;j=e+(g*-17734|0)|0;k=e+(g*-42813|0)|0;g=a+(c+8<<1)|0;e=b[g>>1]|0;l=a+(c+24<<1)|0;m=b[l>>1]|0;n=(m*38531|0)+(e*45451|0)|0;o=(m*-9041|0)+(e*38531|0)|0;p=(m*-45451|0)+(e*25746|0)|0;q=(m*-25746|0)+(e*9041|0)|0;e=a+(c+32<<1)|0;m=b[e>>1]|0;if(m<<16>>16==0){r=k;s=j;t=i;u=h}else{v=m<<16>>16;m=v*32767|0;w=v*-32767|0;r=m+k|0;s=w+j|0;t=w+i|0;u=m+h|0}h=a+(c+40<<1)|0;m=b[h>>1]|0;if(m<<16>>16==0){x=q;y=p;z=o;A=n}else{i=m<<16>>16;x=(i*38531|0)+q|0;y=(i*9041|0)+p|0;z=(i*-45451|0)+o|0;A=(i*25746|0)+n|0}n=a+(c+48<<1)|0;i=b[n>>1]|0;if(i<<16>>16==0){B=r;C=s;D=t;E=u}else{o=i<<16>>16;B=(o*-17734|0)+r|0;C=(o*42813|0)+s|0;D=(o*-42813|0)+t|0;E=(o*17734|0)+u|0}o=a+(c+56<<1)|0;i=b[o>>1]|0;if(i<<16>>16==0){F=x;G=y;H=z;I=A}else{p=i<<16>>16;F=(p*-45451|0)+x|0;G=(p*38531|0)+y|0;H=(p*-25746|0)+z|0;I=(p*9041|0)+A|0}b[d>>1]=I+E>>17;b[g>>1]=H+D>>17;b[f>>1]=G+C>>17;b[l>>1]=F+B>>17;b[e>>1]=B-F>>17;b[h>>1]=C-G>>17;b[n>>1]=D-H>>17;b[o>>1]=E-I>>17;c=c+1|0;}while((c|0)<8);return}function OXa(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=e;g=0;while(1){h=b[f>>1]|0;i=f+16|0;j=b[i>>1]|0;b[f>>1]=j+h;b[i>>1]=h-j;j=f+2|0;h=b[j>>1]|0;i=f+18|0;k=b[i>>1]|0;b[j>>1]=k+h;b[i>>1]=h-k;k=f+4|0;h=b[k>>1]|0;i=f+20|0;j=b[i>>1]|0;b[k>>1]=j+h;b[i>>1]=h-j;j=f+6|0;h=b[j>>1]|0;i=f+22|0;k=b[i>>1]|0;b[j>>1]=k+h;b[i>>1]=h-k;k=f+8|0;h=b[k>>1]|0;i=f+24|0;j=b[i>>1]|0;b[k>>1]=j+h;b[i>>1]=h-j;j=f+10|0;h=b[j>>1]|0;i=f+26|0;k=b[i>>1]|0;b[j>>1]=k+h;b[i>>1]=h-k;k=f+12|0;h=b[k>>1]|0;i=f+28|0;j=b[i>>1]|0;b[k>>1]=j+h;b[i>>1]=h-j;j=f+14|0;h=b[j>>1]|0;i=f+30|0;k=b[i>>1]|0;b[j>>1]=k+h;b[i>>1]=h-k;k=g+1|0;if((k|0)<4){f=f+32|0;g=k}else{break}}BXa(e);BXa(e+16|0);BXa(e+32|0);BXa(e+48|0);BXa(e+64|0);BXa(e+80|0);BXa(e+96|0);BXa(e+112|0);g=d<<1;f=d<<2;k=f+g|0;h=0;do{i=b[e+(h<<1)>>1]|0;j=b[e+(h+16<<1)>>1]|0;l=b[e+(h+32<<1)>>1]|0;m=b[e+(h+48<<1)>>1]|0;n=(l+i<<11)+65536|0;o=(i-l<<11)+65536|0;l=(m*1108|0)+(j*2676|0)|0;i=(m*-2676|0)+(j*1108|0)|0;j=n+l>>17;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[c+h|0]=p;j=o+i>>17;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[c+(h+g)|0]=q;j=o-i>>17;if(j>>>0>255>>>0){r=-j>>31&255}else{r=j&255}a[c+(h+f)|0]=r;j=n-l>>17;if(j>>>0>255>>>0){s=-j>>31&255}else{s=j&255}a[c+(h+k)|0]=s;j=h+d|0;l=b[e+(h+8<<1)>>1]|0;n=b[e+(h+24<<1)>>1]|0;i=b[e+(h+40<<1)>>1]|0;o=b[e+(h+56<<1)>>1]|0;m=(i+l<<11)+65536|0;t=(l-i<<11)+65536|0;i=(o*1108|0)+(n*2676|0)|0;l=(o*-2676|0)+(n*1108|0)|0;n=m+i>>17;if(n>>>0>255>>>0){u=-n>>31&255}else{u=n&255}a[c+j|0]=u;n=t+l>>17;if(n>>>0>255>>>0){v=-n>>31&255}else{v=n&255}a[c+(j+g)|0]=v;n=t-l>>17;if(n>>>0>255>>>0){w=-n>>31&255}else{w=n&255}a[c+(j+f)|0]=w;n=m-i>>17;if(n>>>0>255>>>0){x=-n>>31&255}else{x=n&255}a[c+(j+k)|0]=x;h=h+1|0;}while((h|0)<8);return}function PXa(a,b,c){a=a|0;b=b|0;c=c|0;BXa(c);BXa(c+16|0);BXa(c+32|0);BXa(c+48|0);QXa(a,b,c);QXa(a+1|0,b,c+2|0);QXa(a+2|0,b,c+4|0);QXa(a+3|0,b,c+6|0);QXa(a+4|0,b,c+8|0);QXa(a+5|0,b,c+10|0);QXa(a+6|0,b,c+12|0);QXa(a+7|0,b,c+14|0);return}function QXa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=b[f>>1]|0;h=b[f+16>>1]|0;i=b[f+32>>1]|0;j=b[f+48>>1]|0;f=((i+g|0)*2896|0)+65536|0;k=((g-i|0)*2896|0)+65536|0;i=(j*1567|0)+(h*3784|0)|0;g=(j*-3784|0)+(h*1567|0)|0;h=(f+i>>17)+(d[c]|0)|0;if(h>>>0>255>>>0){l=-h>>31&255}else{l=h&255}a[c]=l;l=c+e|0;h=(d[l]|0)+(k+g>>17)|0;if(h>>>0>255>>>0){m=-h>>31&255}else{m=h&255}a[l]=m;m=e<<1;l=c+m|0;h=(d[l]|0)+(k-g>>17)|0;if(h>>>0>255>>>0){n=-h>>31&255}else{n=h&255}a[l]=n;n=c+(m+e)|0;e=(d[n]|0)+(f-i>>17)|0;if(!(e>>>0>255>>>0)){o=e&255;a[n]=o;return}o=-e>>31&255;a[n]=o;return}function RXa(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=0;do{f=e<<3;g=d+(f<<1)|0;h=b[g>>1]|0;i=d+((f|1)<<1)|0;j=b[i>>1]|0;k=d+((f|2)<<1)|0;l=b[k>>1]|0;m=d+((f|3)<<1)|0;f=b[m>>1]|0;n=((l+h|0)*23170|0)+1024|0;o=((h-l|0)*23170|0)+1024|0;l=(f*12540|0)+(j*30274|0)|0;h=(f*-30274|0)+(j*12540|0)|0;b[g>>1]=(n+l|0)>>>11;b[i>>1]=(o+h|0)>>>11;b[k>>1]=(o-h|0)>>>11;b[m>>1]=(n-l|0)>>>11;e=e+1|0;}while((e|0)<8);DXa(a,c,d);DXa(a+1|0,c,d+2|0);DXa(a+2|0,c,d+4|0);DXa(a+3|0,c,d+6|0);return}function SXa(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=0;do{f=e<<3;g=d+(f<<1)|0;h=b[g>>1]|0;i=d+((f|1)<<1)|0;j=b[i>>1]|0;k=d+((f|2)<<1)|0;l=b[k>>1]|0;m=d+((f|3)<<1)|0;f=b[m>>1]|0;n=((l+h|0)*23170|0)+1024|0;o=((h-l|0)*23170|0)+1024|0;l=(f*12540|0)+(j*30274|0)|0;h=(f*-30274|0)+(j*12540|0)|0;b[g>>1]=(n+l|0)>>>11;b[i>>1]=(o+h|0)>>>11;b[k>>1]=(o-h|0)>>>11;b[m>>1]=(n-l|0)>>>11;e=e+1|0;}while((e|0)<4);QXa(a,c,d);QXa(a+1|0,c,d+2|0);QXa(a+2|0,c,d+4|0);QXa(a+3|0,c,d+6|0);return}function TXa(a,c){a=a|0;c=c|0;var d=0,e=0;d=0;do{e=a+(d<<1)|0;b[e>>1]=ba(b[e>>1]|0,b[c+(d<<1)>>1]|0)|0;d=d+1|0;}while((d|0)<64);GXa(a,2);GXa(a+16|0,2);GXa(a+32|0,2);GXa(a+48|0,2);GXa(a+64|0,2);GXa(a+80|0,2);GXa(a+96|0,2);GXa(a+112|0,2);b[a>>1]=(b[a>>1]|0)+8192;JXa(a);d=a+2|0;b[d>>1]=(b[d>>1]|0)+8192;JXa(d);d=a+4|0;b[d>>1]=(b[d>>1]|0)+8192;JXa(d);d=a+6|0;b[d>>1]=(b[d>>1]|0)+8192;JXa(d);d=a+8|0;b[d>>1]=(b[d>>1]|0)+8192;JXa(d);d=a+10|0;b[d>>1]=(b[d>>1]|0)+8192;JXa(d);d=a+12|0;b[d>>1]=(b[d>>1]|0)+8192;JXa(d);d=a+14|0;b[d>>1]=(b[d>>1]|0)+8192;JXa(d);return}function UXa(a,b){a=a|0;b=b|0;var c=0.0,d=0;if((b|0)<=0){return}c=3.141592653589793/(+(b|0)*2.0);d=0;do{g[a+(d<<2)>>2]=+U((+(d|0)+.5)*c);d=d+1|0;}while((d|0)<(b|0));return}function VXa(a){a=a|0;var b=0,d=0,e=0.0;b=c[1138224+(a<<2)>>2]|0;d=1<<a;if((d|0)<=0){return}e=3.141592653589793/(+(d|0)*2.0);a=0;do{g[b+(a<<2)>>2]=+U(e*(+(a|0)+.5));a=a+1|0;}while((a|0)<(d|0));return}function WXa(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+60>>2]|0;e=d;f=a+432|0;h=c[f>>2]|0;if((h|0)==29){c[d+4>>2]=2;j=2}else if((h|0)==37){c[d+4>>2]=3;j=3}else if((h|0)==20){c[d+4>>2]=0;j=0}else if((h|0)==19){c[d+4>>2]=1;j=1}else{h=a+72|0;k=c[h>>2]|0;do{if((k|0)>12200){c[d+4>>2]=0;l=0}else{if((k|0)>7500){c[d+4>>2]=1;l=1;break}m=d+4|0;if((k|0)>5750){c[m>>2]=2;l=2;break}else{c[m>>2]=3;l=3;break}}}while(0);k=c[676808+(l*36|0)>>2]|0;l=c[h>>2]|0;yDb(a,24,1937272,(n=i,i=i+24|0,c[n>>2]=c[f>>2],c[n+8>>2]=k,c[n+16>>2]=l,n)|0);i=n;j=c[d+4>>2]|0}yDb(a,48,1913488,(n=i,i=i+8|0,c[n>>2]=c[676808+(j*36|0)>>2],n)|0);i=n;if((c[d+4>>2]|0)==0){_Xa(e);c[d+5688>>2]=1968}else{c[d+5688>>2]=1252}g[d+2912>>2]=.9594929814338684;g[d+2916>>2]=.8412535190582275;g[d+2920>>2]=.6548607349395752;g[d+2924>>2]=.4154150187969208;g[d+2928>>2]=.1423148363828659;g[d+2932>>2]=-.1423148363828659;g[d+2936>>2]=-.4154150187969208;g[d+2940>>2]=-.6548607349395752;g[d+2944>>2]=-.8412535190582275;g[d+2948>>2]=-.9594929814338684;g[d+2956>>2]=-14.0;g[d+2960>>2]=-14.0;g[d+2964>>2]=-14.0;g[d+2968>>2]=-14.0;c[a+416>>2]=1;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;c[a+420>>2]=3;i=b;return 0}function XXa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;j=i;i=i+184|0;k=j|0;l=c[a+60>>2]|0;m=l;n=c[h+24>>2]|0;o=c[l+4>>2]|0;p=(o|0)==0;q=p?80:48;c[l>>2]=a;r=c[h+28>>2]|0;h=e[676812+(o*36|0)>>1]|0;s=h>>>3;if((r|0)<(s|0)){yDb(a,16,2181832,(t=i,i=i+8|0,c[t>>2]=r,t)|0);i=t;u=-1;i=j;return u|0}t=d[676815+(o*36|0)|0]|0;r=ba(t,q)|0;v=d[676814+(o*36|0)|0]|0;c[f+76>>2]=ba(r,v)|0;r=_$a(a,f,0)|0;if((r|0)<0){u=r;i=j;return u|0}r=(n|0)==0?8:h+8|0;h=676821+(o*36|0)|0;a=k|0;w=d[676822+(o*36|0)|0]|0;x=32-w|0;y=k+4|0;z=d[676823+(o*36|0)|0]|0;A=32-z|0;B=k+8|0;C=d[676824+(o*36|0)|0]|0;D=32-C|0;E=k+12|0;F=d[676825+(o*36|0)|0]|0;G=32-F|0;H=k+16|0;I=d[676826+(o*36|0)|0]|0;J=32-I|0;K=k+20|0;L=676832+(o*36|0)|0;M=d[676820+(o*36|0)|0]|0;N=d[676843+(o*36|0)|0]|0;O=32-N|0;P=l+5688|0;l=ba(v,q)|0;q=c[f>>2]|0;f=0;Q=0;while(1){if(p){R=d[h]|0;S=n+(Q>>>3)|0;T=32-R|0;U=Q+R|0;c[a>>2]=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((Q&7)>>>0)<<T>>>(T>>>0);V=r>>>0>U>>>0?U:r}else{V=Q}U=n+(V>>>3)|0;T=V+w|0;S=r>>>0>T>>>0?T:r;c[y>>2]=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((V&7)>>>0)<<x>>>(x>>>0);U=n+(S>>>3)|0;T=S+z|0;R=r>>>0>T>>>0?T:r;c[B>>2]=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((S&7)>>>0)<<A>>>(A>>>0);S=n+(R>>>3)|0;U=R+C|0;T=r>>>0>U>>>0?U:r;c[E>>2]=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((R&7)>>>0)<<D>>>(D>>>0);R=n+(T>>>3)|0;S=T+F|0;U=r>>>0>S>>>0?S:r;c[H>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((T&7)>>>0)<<G>>>(G>>>0);T=n+(U>>>3)|0;R=U+I|0;S=r>>>0>R>>>0?R:r;c[K>>2]=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((U&7)>>>0)<<J>>>(J>>>0);if(p){U=0;T=S;while(1){R=d[676827+U|0]|0;W=n+(T>>>3)|0;X=32-R|0;Y=T+R|0;R=r>>>0>Y>>>0?Y:r;c[k+24+(U<<2)>>2]=(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)>>>((T&7)>>>0)<<X>>>(X>>>0);X=d[L]|0;W=n+(R>>>3)|0;Y=32-X|0;Z=R+X|0;c[k+44+(U<<2)>>2]=(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)>>>((R&7)>>>0)<<Y>>>(Y>>>0);Y=0;R=r>>>0>Z>>>0?Z:r;while(1){Z=d[676833+Y|0]|0;W=n+(R>>>3)|0;X=32-Z|0;_=Z+R|0;$=r>>>0>_>>>0?_:r;b[k+64+(U*20|0)+(Y<<1)>>1]=(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)>>>((R&7)>>>0)<<X>>>(X>>>0);X=Y+1|0;if((X|0)<(M|0)){Y=X;R=$}else{break}}R=n+($>>>3)|0;Y=N+$|0;X=r>>>0>Y>>>0?Y:r;c[k+164+(U<<2)>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>(($&7)>>>0)<<O>>>(O>>>0);R=U+1|0;if((R|0)<(v|0)){U=R;T=X}else{aa=X;break}}}else{T=0;U=S;while(1){X=d[676827+(o*36|0)+T|0]|0;R=n+(U>>>3)|0;Y=32-X|0;W=U+X|0;c[k+24+(T<<2)>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((U&7)>>>0)<<Y>>>(Y>>>0);Y=0;R=r>>>0>W>>>0?W:r;while(1){W=d[676833+(o*36|0)+Y|0]|0;X=n+(R>>>3)|0;_=32-W|0;Z=W+R|0;ca=r>>>0>Z>>>0?Z:r;b[k+64+(T*20|0)+(Y<<1)>>1]=(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)>>>((R&7)>>>0)<<_>>>(_>>>0);_=Y+1|0;if((_|0)<(M|0)){Y=_;R=ca}else{break}}R=n+(ca>>>3)|0;Y=N+ca|0;_=r>>>0>Y>>>0?Y:r;c[k+164+(T<<2)>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((ca&7)>>>0)<<O>>>(O>>>0);R=T+1|0;if((R|0)<(v|0)){T=R;U=_}else{aa=_;break}}}Xe[c[P>>2]&4095](m,k,q);U=f+1|0;if((U|0)<(t|0)){q=q+(l<<2)|0;f=U;Q=aa}else{break}}c[g>>2]=1;u=s;i=j;return u|0}function YXa(a,e,f){a=a|0;e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0.0,P=0,Q=0.0,R=0,S=0.0,U=0,V=0.0,W=0,X=0.0,Y=0,Z=0.0,_=0.0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0.0,va=0,wa=0.0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0.0,Ha=0,Ia=0.0,Ja=0.0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;j=i;i=i+1472|0;k=j|0;l=j+232|0;m=j+272|0;n=j+312|0;o=j+512|0;p=j+560|0;q=j+640|0;r=j+680|0;s=j+880|0;t=j+1112|0;u=j+1152|0;v=j+1248|0;w=j+1440|0;x=j+1448|0;y=j+1456|0;z=j+1464|0;A=a+4|0;B=d[676814+((c[A>>2]|0)*36|0)|0]|0;C=s+40|0;TGb(s|0,0,40)|0;D=t|0;E=q;F=q|0;G=q;H=(c[182742]|0)+(c[e+4>>2]<<1<<2)|0;I=c[H+4>>2]|0;c[F>>2]=c[H>>2];c[F+4>>2]=I;I=q+8|0;F=(c[182743]|0)+(c[e+8>>2]<<1<<2)|0;H=c[F+4>>2]|0;c[I>>2]=c[F>>2];c[I+4>>2]=H;H=q+16|0;I=(c[182744]|0)+(c[e+12>>2]<<1<<2)|0;F=c[I+4>>2]|0;c[H>>2]=c[I>>2];c[H+4>>2]=F;F=q+24|0;H=(c[182745]|0)+(c[e+16>>2]<<1<<2)|0;I=c[H+4>>2]|0;c[F>>2]=c[H>>2];c[F+4>>2]=I;I=q+32|0;q=(c[182746]|0)+(c[e+20>>2]<<1<<2)|0;F=c[q+4>>2]|0;c[I>>2]=c[q>>2];c[I+4>>2]=F;F=0;do{g[t+(F<<2)>>2]=+g[a+12+(F<<2)>>2]*.33+ +g[G+(F<<2)>>2]+ +g[679048+(F<<2)>>2];F=F+1|0;}while((F|0)<10);F=a;G=B*48|0;I=a+1952|0;RKa(D,9);KKa(D,.039269908169872414,9);q=t+36|0;J=+g[q>>2];UGb(a+12|0,E|0,40)|0;K=+T(+g[D>>2]);g[D>>2]=K;E=t+4|0;L=+T(+g[E>>2]);g[E>>2]=L;H=t+8|0;M=+T(+g[H>>2]);g[H>>2]=M;N=t+12|0;O=+T(+g[N>>2]);g[N>>2]=O;P=t+16|0;Q=+T(+g[P>>2]);g[P>>2]=Q;R=t+20|0;S=+T(+g[R>>2]);g[R>>2]=S;U=t+24|0;V=+T(+g[U>>2]);g[U>>2]=V;W=t+28|0;X=+T(+g[W>>2]);g[W>>2]=X;Y=t+32|0;Z=+T(+g[Y>>2]);g[Y>>2]=Z;_=J>4.084070449666731?8.00000286102295:J*1.9588306564723479;g[q>>2]=_;$=a+2912|0;aa=$|0;J=1.0/+(B|0);ba=p|0;ca=a+2916|0;da=p+8|0;ea=a+2920|0;fa=p+16|0;ga=a+2924|0;ha=p+24|0;ia=a+2928|0;ja=p+32|0;ka=a+2932|0;la=p+40|0;ma=a+2936|0;na=p+48|0;oa=a+2940|0;pa=p+56|0;qa=a+2944|0;ra=p+64|0;sa=a+2948|0;ta=p+72|0;p=1;ua=J*.5;va=r|0;wa=K;K=L;L=M;M=O;O=Q;Q=S;S=V;V=X;X=Z;Z=_;while(1){_=1.0-ua;h[ba>>3]=_*+g[aa>>2]+ua*wa;h[da>>3]=_*+g[ca>>2]+ua*K;h[fa>>3]=_*+g[ea>>2]+ua*L;h[ha>>3]=_*+g[ga>>2]+ua*M;h[ja>>3]=_*+g[ia>>2]+ua*O;h[la>>3]=_*+g[ka>>2]+ua*Q;h[na>>3]=_*+g[ma>>2]+ua*S;h[pa>>3]=_*+g[oa>>2]+ua*V;h[ra>>3]=_*+g[qa>>2]+ua*X;h[ta>>3]=_*+g[sa>>2]+ua*Z;OKa(ba,va,10);if((p|0)>=(B|0)){break}p=p+1|0;ua=J+ua;va=va+40|0;wa=+g[D>>2];K=+g[E>>2];L=+g[H>>2];M=+g[N>>2];O=+g[P>>2];Q=+g[R>>2];S=+g[U>>2];V=+g[W>>2];X=+g[Y>>2];Z=+g[q>>2]}UGb($|0,t|0,40)|0;t=a+76|0;$=a+8|0;q=u+44|0;Y=u+4|0;W=u+48|0;U=u+8|0;R=u+52|0;P=u+12|0;N=u|0;H=n|0;E=n+44|0;D=o|0;va=v|0;p=v;ba=a+2956|0;sa=a+2952|0;ta=k;qa=k+40|0;ra=a+2980|0;oa=m|0;pa=k+192|0;k=a+3592|0;ma=a+3600|0;na=l|0;ka=u+16|0;la=u+56|0;ia=u+20|0;ja=u+24|0;ga=u+60|0;ha=u+64|0;ea=B*192|0;fa=0;ca=a+692|0;da=0;while(1){aa=da*10|0;xa=r+(aa<<2)|0;Igb(w,x,c[e+24+(da<<2)>>2]|0,fa,da,(c[A>>2]|0)==3|0,6);if((da|0)==2){if((c[A>>2]|0)==3){ya=9}else{za=fa}}else if((da|0)==0){ya=9}else{za=fa}if((ya|0)==9){ya=0;za=c[w>>2]|0}Aa=c[x>>2]|0;xgb(ca,ca+(((Aa|0)<1)-(c[w>>2]|0)<<2)|0,1257976,6,(((Aa+2|0)%3|0)<<1)+2|0,10,48);Aa=e+64+(da*20|0)|0;Ba=c[A>>2]|0;do{if((Ba|0)==1){Ca=b[Aa>>1]|0;Da=Ca&65535;Ea=(Da>>>4&15)*3|0;c[Y>>2]=Ea;Fa=(Da&15)*3|0;c[U>>2]=Fa;Z=(Ca&256)!=0?-1.0:1.0;g[q>>2]=Z;if(Fa>>>0<Ea>>>0){Ga=-0.0-Z}else{Ga=Z}g[W>>2]=Ga;Fa=b[e+64+(da*20|0)+2>>1]|0;Ca=Fa&65535;Da=((Ca>>>4&15)*3|0)+1|0;c[P>>2]=Da;Ha=((Ca&15)*3|0)+1|0;c[ka>>2]=Ha;Z=(Fa&256)!=0?-1.0:1.0;g[R>>2]=Z;if(Ha>>>0<Da>>>0){Ia=-0.0-Z}else{Ia=Z}g[la>>2]=Ia;Da=b[e+64+(da*20|0)+4>>1]|0;Ha=Da&65535;Fa=((Ha>>>4&15)*3|0)+2|0;c[ia>>2]=Fa;Ca=((Ha&15)*3|0)+2|0;c[ja>>2]=Ca;Z=(Da&256)!=0?-1.0:1.0;g[ga>>2]=Z;if(Ca>>>0<Fa>>>0){Ja=-0.0-Z}else{Ja=Z}g[ha>>2]=Ja;c[N>>2]=6;Ka=6;La=Ea}else if((Ba|0)==2){Ea=b[Aa>>1]|0;Fa=(Ea&15)*3|0;c[Y>>2]=Fa;g[q>>2]=(Ea&16)!=0?-1.0:1.0;Ea=b[e+64+(da*20|0)+2>>1]|0;c[U>>2]=((Ea&15)*3|0)+1;g[W>>2]=(Ea&16)!=0?-1.0:1.0;Ea=b[e+64+(da*20|0)+4>>1]|0;c[P>>2]=((Ea&15)*3|0)+2;g[R>>2]=(Ea&16)!=0?-1.0:1.0;c[N>>2]=3;Ka=3;La=Fa}else{Fa=b[Aa>>1]|0;Ea=Fa<<16>>16;Ca=Ea>>>8;if(+g[$>>2]<.8){Da=Ca&2;Ha=((Ea&7)*6|0)+4|0;g[q>>2]=(Ha+Da&3|0)!=0?-1.0:1.0;c[Y>>2]=Ha;Ma=((Ea>>>3&7)*6|0)+2|0;g[W>>2]=(Ma+Da&3|0)!=0?-1.0:1.0;c[U>>2]=Ma;Ma=(Ea>>>6&7)*6|0;g[R>>2]=(Ma+Da&3|0)!=0?-1.0:1.0;c[P>>2]=Ma;c[N>>2]=3;Ka=3;La=Ha;break}else{Ha=Ca&1;Ca=((Ea>>>4&15)*3|0)+Ha|0;c[Y>>2]=Ca;c[U>>2]=Ha+1+((Fa&15)*3|0);Z=(Fa&512)!=0?-1.0:1.0;g[q>>2]=Z;g[W>>2]=-0.0-Z;c[N>>2]=2;Ka=2;La=Ca;break}}}while(0);Aa=c[w>>2]|0;Z=+g[676816+(Ba*36|0)>>2];g[H>>2]=1.0;Ca=0;while(1){X=+g[r+(Ca+aa<<2)>>2];Fa=Ca+1|0;g[n+(Fa<<2)>>2]=X*+g[1155448+(Ca<<2)>>2];g[o+(Ca<<2)>>2]=X*+g[1155408+(Ca<<2)>>2];if((Fa|0)<10){Ca=Fa}else{break}}TGb(E|0,0,148)|0;y$(C,D,H,48,10);if((Aa|0)<48){Ca=10-Aa|0;Ba=Aa;do{Fa=s+(Ba+10<<2)|0;g[Fa>>2]=+g[Fa>>2]+Z*+g[s+(Ca+Ba<<2)>>2];Ba=Ba+1|0;}while((Ba|0)<48)}TGb(p|0,0,192)|0;Ba=0;Ca=La;while(1){if((Ca|0)<48){Z=+g[u+44+(Ba<<2)>>2];Aa=10-Ca|0;Fa=Ca;do{Ha=v+(Fa<<2)|0;g[Ha>>2]=+g[Ha>>2]+Z*+g[s+(Aa+Fa<<2)>>2];Fa=Fa+1|0;}while((Fa|0)<48)}Fa=Ba+1|0;if((Fa|0)>=(Ka|0)){break}Ba=Fa;Ca=c[u+4+(Fa<<2)>>2]|0}Z=(+eCb(va,va,48)+.01)/48.0;Ca=c[e+164+(da<<2)>>2]|0;X=+g[1038576+(Ca<<3)>>2];g[$>>2]=X;V=+Hgb(+g[1038580+(Ca<<3)>>2],Z,ba,-56.308998107910156,562544);Mgb(ca,ca,va,X,V,48);Z=X;X=Z*Z*.5;Z=X>.4?.4000000059604645:X;X=+g[sa>>2]*.7+Z*.3;S=X>Z?Z:X;g[sa>>2]=S;X=V*S;Ca=0;do{Ba=v+(Ca<<2)|0;g[Ba>>2]=+g[ca+(Ca<<2)>>2]-X*+g[Ba>>2];Ca=Ca+1|0;}while((Ca|0)<48);if((c[A>>2]|0)==3){Ca=0;do{X=+g[r+(Ca+aa<<2)>>2];g[m+(Ca<<2)>>2]=X*+g[1155368+(Ca<<2)>>2];g[l+(Ca<<2)>>2]=X*+g[1155488+(Ca<<2)>>2];Ca=Ca+1|0;}while((Ca|0)<10);UGb(ta|0,ra|0,40)|0;y$(qa,oa,va,48,10);UGb(ra|0,pa|0,40)|0;Agb(k,.4000000059604645,qa,48);UGb(ta|0,ma|0,40)|0;UGb(ma|0,pa|0,40)|0;z$(va,na,qa,48,10);Ca=da*48|0;y$(a+4212+((Ca|10)<<2)|0,xa,ca,48,10);Na=Ca}else{Na=da*48|0}y$(a+1888+(Na+16<<2)|0,xa,va,48,10);Ca=da+1|0;if((Ca|0)<(B|0)){fa=za;ca=ca+192|0;da=Ca}else{break}}UGb(a+1912|0,a+1888+((G|6)<<2)|0,40)|0;if((c[A>>2]|0)!=3){Oa=t;Pa=ea+76|0;Qa=F+Pa|0;VGb(Oa|0,Qa|0,616)|0;Ra=y|0;g[Ra>>2]=-1.9999699592590332;Sa=y+4|0;g[Sa>>2]=1.0;Ta=z|0;g[Ta>>2]=-1.9330735206604004;Ua=z+4|0;g[Ua>>2]=.9358919858932495;Va=a+2972|0;zgb(f,I,Ra,Ta,.939805805683136,Va,G);i=j;return}A=a+3596|0;da=0;do{ca=da*48|0;za=a+4212+((ca|10)<<2)|0;fa=a+1888+(ca+16<<2)|0;Ngb(fa,fa,+eCb(za,za,48),48,.8999999761581421,A);da=da+1|0;}while((da|0)<(B|0));UGb(a+4212|0,a+4212+(G<<2)|0,40)|0;Oa=t;Pa=ea+76|0;Qa=F+Pa|0;VGb(Oa|0,Qa|0,616)|0;Ra=y|0;g[Ra>>2]=-1.9999699592590332;Sa=y+4|0;g[Sa>>2]=1.0;Ta=z|0;g[Ta>>2]=-1.9330735206604004;Ua=z+4|0;g[Ua>>2]=.9358919858932495;Va=a+2972|0;zgb(f,I,Ra,Ta,.939805805683136,Va,G);i=j;return}function ZXa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0;e=i;i=i+1112|0;f=e|0;j=e+128|0;k=e+312|0;l=e+376|0;m=e+440|0;n=e+568|0;o=e+696|0;p=e+1016|0;q=a+1952|0;r=a+12|0;s=c[b>>2]|0;t=k;u=(c[182736]|0)+(((c[b+4>>2]|0)*3|0)<<2)|0;c[t>>2]=c[u>>2];c[t+4>>2]=c[u+4>>2];c[t+8>>2]=c[u+8>>2];u=k+12|0;v=(c[182737]|0)+(((c[b+8>>2]|0)*3|0)<<2)|0;c[u>>2]=c[v>>2];c[u+4>>2]=c[v+4>>2];c[u+8>>2]=c[v+8>>2];v=k+24|0;u=(c[182738]|0)+(((c[b+12>>2]|0)*3|0)<<2)|0;c[v>>2]=c[u>>2];c[v+4>>2]=c[u+4>>2];c[v+8>>2]=c[u+8>>2];u=k+36|0;v=(c[182739]|0)+(((c[b+16>>2]|0)*3|0)<<2)|0;c[u>>2]=c[v>>2];c[u+4>>2]=c[v+4>>2];c[u+8>>2]=c[v+8>>2];v=k+48|0;u=(c[182740]|0)+(c[b+20>>2]<<2<<2)|0;c[v>>2]=c[u>>2];c[v+4>>2]=c[u+4>>2];c[v+8>>2]=c[u+8>>2];c[v+12>>2]=c[u+12>>2];w=+g[555312+(s<<2)>>2];x=1.0-w;s=0;do{g[l+(s<<2)>>2]=+g[678984+(s<<2)>>2]+(x*+g[k+(s<<2)>>2]+w*+g[a+12+(s<<2)>>2]);s=s+1|0;}while((s|0)<16);s=a+76|0;k=l|0;UGb(r|0,t|0,64)|0;KKa(k,.019634954084936207,16);t=m|0;w=+T(+g[k>>2]);h[t>>3]=w;h[m+8>>3]=+T(+g[l+4>>2]);h[m+16>>3]=+T(+g[l+8>>2]);h[m+24>>3]=+T(+g[l+12>>2]);h[m+32>>3]=+T(+g[l+16>>2]);h[m+40>>3]=+T(+g[l+20>>2]);h[m+48>>3]=+T(+g[l+24>>2]);h[m+56>>3]=+T(+g[l+28>>2]);h[m+64>>3]=+T(+g[l+32>>2]);h[m+72>>3]=+T(+g[l+36>>2]);h[m+80>>3]=+T(+g[l+40>>2]);h[m+88>>3]=+T(+g[l+44>>2]);h[m+96>>3]=+T(+g[l+48>>2]);h[m+104>>3]=+T(+g[l+52>>2]);h[m+112>>3]=+T(+g[l+56>>2]);h[m+120>>3]=+T(+g[l+60>>2]);l=n+64|0;k=l|0;r=0;x=w;while(1){h[f+(r<<3)>>3]=(x+ +h[a+5560+(r<<3)>>3])*.5;u=r+1|0;if((u|0)>=16){break}r=u;x=+h[m+(u<<3)>>3]}QKa(f|0,n|0,8);QKa(t,k,8);UGb(a+5560|0,m|0,128)|0;m=a+1888|0;k=a+5492|0;UGb(m|0,k|0,64)|0;t=p+92|0;f=p+88|0;r=a+5212|0;u=o;v=o|0;o=a+2956|0;y=a+2960|0;z=0;do{A=z*80|0;B=c[b+24+(z<<2)>>2]|0;do{if((z|0)==0){if((B|0)<390){C=B+88|0;break}else{C=(B*3|0)-690|0;break}}else{D=c[r>>2]|0;if((B|0)>=62){C=D*3|0;break}E=D-10|0;if((E|0)<30){F=90}else{F=(E|0)>262?786:E*3|0}C=B-2+F|0}}while(0);B=c[b+44+(z<<2)>>2]|0;x=+g[1038216+(B<<2)>>2];g[t>>2]=(B-12|0)>>>0<4>>>0?1.0:x;B=C*10923|0;E=B+10923>>15;c[f>>2]=E;c[r>>2]=E;E=B+21846>>15;B=a+76+(A+292<<2)|0;xgb(B,a+76+(A+293-E<<2)|0,436792,3,C+3+(E*-3|0)|0,10,80);TGb(u|0,0,320)|0;Kgb(b+64+(z*20|0)|0,p,1221984,5,4);Pgb(v,p,1.0,80);w=+g[1038448+(c[b+164+(z<<2)>>2]<<2)>>2];G=+_((+eCb(562536,o,2)+ -71.30899810791016)*.11512925464970229)*8.9442720413208;H=w*(G/+R(+eCb(v,v,80)+.01));g[y>>2]=+g[o>>2];g[o>>2]=+ad(+w)*20.0;Mgb(B,B,v,x,H,80);y$(a+1888+(A+16<<2)|0,n+(z<<6)|0,B,80,16);z=z+1|0;}while((z|0)<2);UGb(k|0,a+2528|0,64)|0;VGb(s|0,a+716|0,1168)|0;s=a+5420|0;k=j;z=c[s>>2]|0;n=0;do{g[z+(n<<2)>>2]=+g[a+5216+(n<<2)>>2]*+g[1155488+(n<<2)>>2];n=n+1|0;}while((n|0)<16);n=a+5216|0;z=a+5428|0;UGb(k|0,z|0,64)|0;k=a+5424|0;y$(j+64|0,c[k>>2]|0,q,30,16);UGb(m|0,z|0,64)|0;y$(q,c[s>>2]|0,q,30,16);UGb(d+56|0,a+2008|0,64)|0;y$(d+120|0,c[s>>2]|0,a+2072|0,130,16);UGb(z|0,d+576|0,64)|0;z=c[k>>2]|0;c[k>>2]=c[s>>2];c[s>>2]=z;z=0;H=0.0;while(1){s=z+16|0;x=+g[j+(s<<2)>>2];g[d+(z<<2)>>2]=x+H*(+g[a+1888+(s<<2)>>2]-x);s=z+1|0;if((s|0)<30){z=s;H=H+.03333333333333333}else{break}}UGb(n|0,l|0,64)|0;i=e;return}function _Xa(a){a=a|0;h[a+5560>>3]=.9829730996839018;h[a+5568>>3]=.9324722294043558;h[a+5576>>3]=.8502171357296142;h[a+5584>>3]=.7390089172206591;h[a+5592>>3]=.6026346363792564;h[a+5600>>3]=.4457383557765383;h[a+5608>>3]=.273662990072083;h[a+5616>>3]=.092268359463302;h[a+5624>>3]=-.09226835946330189;h[a+5632>>3]=-.2736629900720829;h[a+5640>>3]=-.4457383557765378;h[a+5648>>3]=-.6026346363792563;h[a+5656>>3]=-.7390089172206593;h[a+5664>>3]=-.850217135729614;h[a+5672>>3]=-.9324722294043557;h[a+5680>>3]=-.9829730996839018;c[a+5420>>2]=a+5284;c[a+5424>>2]=a+5352;c[a+5212>>2]=180;return}function $Xa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+24|0;f=e|0;g=b+60|0;h=c[g>>2]|0;j=h;k=h;c[k>>2]=b;c[b+140>>2]=11;l=ICb()|0;c[h+4>>2]=l;if((l|0)==0){m=-12;i=e;return m|0}if((c[b+100>>2]|0)<16){yDb(b,16,2229672,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-22;i=e;return m|0}b=c[k>>2]|0;l=c[b+96>>2]|0;o=l;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+8|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+12|0;s=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+16|0;l=(c[b+100>>2]|0)-16|0;t=l>>>0>268435455>>>0?-8:l<<3;l=t>>>0>2147483639>>>0|(o|0)==0;u=l?0:o;o=l?0:t;t=f|0;c[t>>2]=u;c[f+12>>2]=o;l=o+8|0;v=f+16|0;c[v>>2]=l;c[f+4>>2]=u+(o>>3);o=f+8|0;c[o>>2]=0;w=a[u]|0;c[o>>2]=(l|0)>0;do{if((w&1)==0){yDb(b,32,2217816,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=WDb(8)|0;u=l;c[h+8>>2]=u;if((l|0)==0){x=-12;break}c[u>>2]=0;c[h+32>>2]=1;c[h+28>>2]=1;c[h+24>>2]=1;y=8}else{u=fYa(j,f,h+8|0,h+24|0,p)|0;if((u|0)<0){x=u}else{y=8}}}while(0);do{if((y|0)==8){p=c[o>>2]|0;b=d[(c[t>>2]|0)+(p>>>3)|0]|0;c[o>>2]=((p|0)<(c[v>>2]|0))+p;if((b&1<<(p&7)|0)==0){yDb(c[k>>2]|0,32,2208512,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=WDb(8)|0;b=p;c[h+12>>2]=b;if((p|0)==0){x=-12;break}c[b>>2]=0;c[h+44>>2]=1;c[h+40>>2]=1;c[h+36>>2]=1}else{b=fYa(j,f,h+12|0,h+36|0,q)|0;if((b|0)<0){x=b;break}}b=c[o>>2]|0;p=d[(c[t>>2]|0)+(b>>>3)|0]|0;c[o>>2]=((b|0)<(c[v>>2]|0))+b;if((p&1<<(b&7)|0)==0){yDb(c[k>>2]|0,32,2200024,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;b=WDb(8)|0;p=b;c[h+16>>2]=p;if((b|0)==0){x=-12;break}c[p>>2]=0;c[h+56>>2]=1;c[h+52>>2]=1;c[h+48>>2]=1}else{p=fYa(j,f,h+16|0,h+48|0,r)|0;if((p|0)<0){x=p;break}}p=c[o>>2]|0;b=d[(c[t>>2]|0)+(p>>>3)|0]|0;c[o>>2]=((p|0)<(c[v>>2]|0))+p;if((b&1<<(p&7)|0)!=0){p=fYa(j,f,h+20|0,h+60|0,s)|0;if((p|0)<0){x=p;break}else{m=0}i=e;return m|0}yDb(c[k>>2]|0,32,2191424,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=WDb(8)|0;b=p;c[h+20>>2]=b;if((p|0)==0){x=-12;break}c[b>>2]=0;c[h+68>>2]=1;c[h+64>>2]=1;c[h+60>>2]=1;m=0;i=e;return m|0}}while(0);h=c[g>>2]|0;$Db(h+8|0);$Db(h+12|0);$Db(h+16|0);$Db(h+20|0);JCb(h+4|0);m=x;i=e;return m|0}function aYa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0;h=i;j=c[b+60>>2]|0;k=g+28|0;if((c[k>>2]|0)<770){l=-1094995529;i=h;return l|0}m=j+4|0;n=$$a(b,c[m>>2]|0)|0;if((n|0)<0){l=n;i=h;return l|0}n=c[m>>2]|0;o=g+24|0;g=c[o>>2]|0;if(!((c[k>>2]|0)>-1)){yDb(0,0,2271744,(p=i,i=i+24|0,c[p>>2]=2256448,c[p+8>>2]=2242064,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}p=c[n+4>>2]|0;q=d[g]|0;c[n+304>>2]=q&1;r=q>>>1&1;c[n+84>>2]=r;c[n+88>>2]=2-r;r=g+1|0;g=0;n=p;while(1){c[n>>2]=(d[r]|0)<<16|(d[r+1|0]|0)<<8|(d[r+2|0]|0)|-16777216;p=g+1|0;if((p|0)<256){r=r+3|0;g=p;n=n+4|0}else{break}}n=j+8|0;g=c[n>>2]|0;r=j+24|0;p=j+32|0;c[g+(c[p>>2]<<2)>>2]=0;q=j+28|0;c[g+(c[q>>2]<<2)>>2]=0;c[g+(c[r>>2]<<2)>>2]=0;g=j+12|0;s=c[g>>2]|0;t=j+36|0;u=j+44|0;c[s+(c[u>>2]<<2)>>2]=0;v=j+40|0;c[s+(c[v>>2]<<2)>>2]=0;c[s+(c[t>>2]<<2)>>2]=0;s=j+16|0;w=c[s>>2]|0;y=j+48|0;z=j+56|0;c[w+(c[z>>2]<<2)>>2]=0;A=j+52|0;c[w+(c[A>>2]<<2)>>2]=0;c[w+(c[y>>2]<<2)>>2]=0;w=j+20|0;B=c[w>>2]|0;C=j+60|0;D=j+68|0;c[B+(c[D>>2]<<2)>>2]=0;E=j+64|0;c[B+(c[E>>2]<<2)>>2]=0;c[B+(c[C>>2]<<2)>>2]=0;B=(c[o>>2]|0)+769|0;o=(c[k>>2]|0)-769|0;j=o>>>0>268435455>>>0?-8:o<<3;o=j>>>0>2147483639>>>0|(B|0)==0;F=o?0:B;B=o?8:j+8|0;if(o){l=o?-1094995529:0;i=h;return l|0}o=c[b+120>>2]>>2;j=ba(c[b+124>>2]>>2,o)|0;G=c[(c[m>>2]|0)+32>>2]|0;if((j|0)>0){H=b+52|0;b=G<<2;I=G+2|0;J=G<<1;K=0;L=0;while(1){M=K;while(1){N=c[w>>2]|0;O=c[N>>2]|0;if((O|0)<0){P=N;Q=M;R=O;while(1){S=((Q|0)<(B|0))+Q|0;if(((d[F+(Q>>>3)|0]|0)&1<<(Q&7)|0)==0){T=P}else{T=P+((R&2147483647)<<2)|0}U=T+4|0;V=c[U>>2]|0;if((V|0)<0){P=U;Q=S;R=V}else{W=V;X=S;break}}}else{W=O;X=M}if((W|0)!=(c[N+(c[C>>2]<<2)>>2]|0)){c[N+(c[D>>2]<<2)>>2]=c[N+(c[E>>2]<<2)>>2];c[N+(c[E>>2]<<2)>>2]=c[N+(c[C>>2]<<2)>>2];c[N+(c[C>>2]<<2)>>2]=W}Y=c[1680456+((W>>>2&63)<<2)>>2]|0;R=W&3;if((R|0)==1){Z=48;break}else if((R|0)==2){Z=24;break}else if((R|0)==0){Z=22;break}else if((R|0)==3){Z=96;break}else{M=X}}do{if((Z|0)==22){Z=0;if((L|0)>=(j|0)){_=L;$=X;break}M=-Y|0;R=L-j|0;Q=R>>>0<M>>>0?M:R;R=X;M=L;P=Y;while(1){S=P-1|0;V=c[g>>2]|0;U=c[V>>2]|0;if((U|0)<0){aa=V;ca=R;da=U;while(1){ea=((ca|0)<(B|0))+ca|0;if(((d[F+(ca>>>3)|0]|0)&1<<(ca&7)|0)==0){fa=aa}else{fa=aa+((da&2147483647)<<2)|0}ga=fa+4|0;ha=c[ga>>2]|0;if((ha|0)<0){aa=ga;ca=ea;da=ha}else{ia=ha;ja=ea;break}}}else{ia=U;ja=R}if((ia|0)!=(c[V+(c[t>>2]<<2)>>2]|0)){c[V+(c[u>>2]<<2)>>2]=c[V+(c[v>>2]<<2)>>2];c[V+(c[v>>2]<<2)>>2]=c[V+(c[t>>2]<<2)>>2];c[V+(c[t>>2]<<2)>>2]=ia}da=c[n>>2]|0;ca=c[da>>2]|0;if((ca|0)<0){aa=da;ea=ja;ha=ca;while(1){ga=((ea|0)<(B|0))+ea|0;if(((d[F+(ea>>>3)|0]|0)&1<<(ea&7)|0)==0){ka=aa}else{ka=aa+((ha&2147483647)<<2)|0}la=ka+4|0;ma=c[la>>2]|0;if((ma|0)<0){aa=la;ea=ga;ha=ma}else{na=ma;oa=ga;break}}}else{na=ca;oa=ja}if((na|0)!=(c[da+(c[r>>2]<<2)>>2]|0)){c[da+(c[p>>2]<<2)>>2]=c[da+(c[q>>2]<<2)>>2];c[da+(c[q>>2]<<2)>>2]=c[da+(c[r>>2]<<2)>>2];c[da+(c[r>>2]<<2)>>2]=na}ha=c[c[m>>2]>>2]|0;ea=((M|0)%(o|0)|0)+(ba((M|0)/(o|0)|0,G)|0)<<2;aa=ia>>8;V=ia&255;U=aa&255;a[ha+ea|0]=(na&1|0)==0?ia:aa;if((na&2|0)==0){pa=V}else{pa=U}a[ha+(ea|1)|0]=pa;if((na&4|0)==0){qa=V}else{qa=U}a[ha+(ea|2)|0]=qa;if((na&8|0)==0){ra=V}else{ra=U}a[ha+(ea|3)|0]=ra;ga=na>>4;ma=ea+G|0;a[ha+ma|0]=(ga&1|0)==0?ia:aa;if((ga&2|0)==0){sa=V}else{sa=U}a[ha+(ma+1)|0]=sa;if((ga&4|0)==0){ta=V}else{ta=U}a[ha+(ma+2)|0]=ta;if((ga&8|0)==0){ua=V}else{ua=U}a[ha+(ma+3)|0]=ua;ga=na>>8;ea=ma+G|0;a[ha+ea|0]=(ga&1|0)==0?ia:aa;if((ga&2|0)==0){va=V}else{va=U}a[ha+(ea+1)|0]=va;if((ga&4|0)==0){wa=V}else{wa=U}a[ha+(ea+2)|0]=wa;if((ga&8|0)==0){xa=V}else{xa=U}a[ha+(ea+3)|0]=xa;ga=na>>12;ma=ea+G|0;a[ha+ma|0]=(ga&1|0)==0?ia:aa;if((ga&2|0)==0){ya=V}else{ya=U}a[ha+(ma+1)|0]=ya;if((ga&4|0)==0){za=V}else{za=U}a[ha+(ma+2)|0]=za;if((ga&8|0)==0){Aa=V}else{Aa=U}a[ha+(ma+3)|0]=Aa;ma=M+1|0;if((S|0)!=0&(ma|0)<(j|0)){R=oa;M=ma;P=S}else{break}}_=L-Q|0;$=oa}else if((Z|0)==24){Z=0;if((L|0)>=(j|0)){_=L;$=X;break}P=-Y|0;M=L-j|0;_=L-(M>>>0<P>>>0?P:M)|0;$=X}else if((Z|0)==48){Z=0;do{if((c[H>>2]|0)==877350227){M=((X|0)<(B|0))+X|0;if(((d[F+(X>>>3)|0]|0)&1<<(X&7)|0)!=0){Ba=1;Ca=M;break}Ba=((d[F+(M>>>3)|0]|0)&1<<(M&7)|0)==0?0:2;Ca=((M|0)<(B|0))+M|0}else{Ba=0;Ca=X}}while(0);if((L|0)>=(j|0)){_=L;$=Ca;break}Q=-Y|0;M=L-j|0;P=M>>>0<Q>>>0?Q:M;M=Ca;Q=L;R=Y;while(1){N=R-1|0;O=c[c[m>>2]>>2]|0;ma=(((Q|0)%(o|0)|0)<<2)+(ba(b,(Q|0)/(o|0)|0)|0)|0;ha=O+ma|0;a:do{if((Ba|0)==1){U=c[s>>2]|0;V=c[U>>2]|0;if((V|0)<0){ga=U;aa=M;ea=V;while(1){la=((aa|0)<(B|0))+aa|0;if(((d[F+(aa>>>3)|0]|0)&1<<(aa&7)|0)==0){Da=ga}else{Da=ga+((ea&2147483647)<<2)|0}Ea=Da+4|0;Fa=c[Ea>>2]|0;if((Fa|0)<0){ga=Ea;aa=la;ea=Fa}else{Ga=Fa;Ha=la;break}}}else{Ga=V;Ha=M}if((Ga|0)!=(c[U+(c[y>>2]<<2)>>2]|0)){c[U+(c[z>>2]<<2)>>2]=c[U+(c[A>>2]<<2)>>2];c[U+(c[A>>2]<<2)>>2]=c[U+(c[y>>2]<<2)>>2];c[U+(c[y>>2]<<2)>>2]=Ga}ea=Ga&255;a[O+(ma|1)|0]=ea;a[ha]=ea;aa=Ga>>>8&255;a[O+(ma|3)|0]=aa;a[O+(ma|2)|0]=aa;ga=ma+G|0;a[O+(ga+1)|0]=ea;a[O+ga|0]=ea;a[O+(ga+3)|0]=aa;a[O+(ga+2)|0]=aa;aa=ga+G|0;ga=O+aa|0;ea=c[s>>2]|0;la=c[ea>>2]|0;if((la|0)<0){Fa=ea;Ea=Ha;Ia=la;while(1){Ja=((Ea|0)<(B|0))+Ea|0;if(((d[F+(Ea>>>3)|0]|0)&1<<(Ea&7)|0)==0){Ka=Fa}else{Ka=Fa+((Ia&2147483647)<<2)|0}La=Ka+4|0;Ma=c[La>>2]|0;if((Ma|0)<0){Fa=La;Ea=Ja;Ia=Ma}else{Na=Ma;Oa=Ja;break}}}else{Na=la;Oa=Ha}if((Na|0)!=(c[ea+(c[y>>2]<<2)>>2]|0)){c[ea+(c[z>>2]<<2)>>2]=c[ea+(c[A>>2]<<2)>>2];c[ea+(c[A>>2]<<2)>>2]=c[ea+(c[y>>2]<<2)>>2];c[ea+(c[y>>2]<<2)>>2]=Na}Ia=Na&255;a[O+(aa+1)|0]=Ia;a[ga]=Ia;Ea=Na>>>8&255;a[O+(aa+3)|0]=Ea;a[O+(aa+2)|0]=Ea;Fa=aa+G|0;a[O+(Fa+1)|0]=Ia;a[O+Fa|0]=Ia;a[O+(Fa+3)|0]=Ea;a[O+(Fa+2)|0]=Ea;Pa=Oa}else if((Ba|0)==2){Ea=M;Fa=1;Ia=ha;while(1){U=c[s>>2]|0;V=c[U>>2]|0;if((V|0)<0){Ja=U;Ma=Ea;La=V;while(1){Qa=((Ma|0)<(B|0))+Ma|0;if(((d[F+(Ma>>>3)|0]|0)&1<<(Ma&7)|0)==0){Ra=Ja}else{Ra=Ja+((La&2147483647)<<2)|0}Sa=Ra+4|0;Ta=c[Sa>>2]|0;if((Ta|0)<0){Ja=Sa;Ma=Qa;La=Ta}else{Ua=Ta;Va=Qa;break}}}else{Ua=V;Va=Ea}if((Ua|0)==(c[U+(c[y>>2]<<2)>>2]|0)){Wa=V}else{c[U+(c[z>>2]<<2)>>2]=c[U+(c[A>>2]<<2)>>2];c[U+(c[A>>2]<<2)>>2]=c[U+(c[y>>2]<<2)>>2];c[U+(c[y>>2]<<2)>>2]=Ua;Wa=c[U>>2]|0}La=Ua&65535;if((Wa|0)<0){Ma=U;Ja=Va;Qa=Wa;while(1){Ta=((Ja|0)<(B|0))+Ja|0;if(((d[F+(Ja>>>3)|0]|0)&1<<(Ja&7)|0)==0){Xa=Ma}else{Xa=Ma+((Qa&2147483647)<<2)|0}Sa=Xa+4|0;Ya=c[Sa>>2]|0;if((Ya|0)<0){Ma=Sa;Ja=Ta;Qa=Ya}else{Za=Ya;_a=Ta;break}}}else{Za=Wa;_a=Va}if((Za|0)!=(c[U+(c[y>>2]<<2)>>2]|0)){c[U+(c[z>>2]<<2)>>2]=c[U+(c[A>>2]<<2)>>2];c[U+(c[A>>2]<<2)>>2]=c[U+(c[y>>2]<<2)>>2];c[U+(c[y>>2]<<2)>>2]=Za}Qa=Za&65535;Ja=Ia;x=Qa;a[Ja]=x;x=x>>8;a[Ja+1|0]=x;Ja=Ia+2|0;x=La;a[Ja]=x;x=x>>8;a[Ja+1|0]=x;Ja=Ia+G|0;x=Qa;a[Ja]=x;x=x>>8;a[Ja+1|0]=x;Ja=Ia+I|0;x=La;a[Ja]=x;x=x>>8;a[Ja+1|0]=x;if((Fa|0)>=2){Pa=_a;break a}Ea=_a;Fa=Fa+1|0;Ia=Ia+J|0}}else if((Ba|0)==0){Ia=M;Fa=1;Ea=ha;while(1){aa=c[s>>2]|0;ga=c[aa>>2]|0;if((ga|0)<0){ea=aa;la=Ia;Ja=ga;while(1){Qa=((la|0)<(B|0))+la|0;if(((d[F+(la>>>3)|0]|0)&1<<(la&7)|0)==0){$a=ea}else{$a=ea+((Ja&2147483647)<<2)|0}Ma=$a+4|0;V=c[Ma>>2]|0;if((V|0)<0){ea=Ma;la=Qa;Ja=V}else{ab=V;bb=Qa;break}}}else{ab=ga;bb=Ia}if((ab|0)!=(c[aa+(c[y>>2]<<2)>>2]|0)){c[aa+(c[z>>2]<<2)>>2]=c[aa+(c[A>>2]<<2)>>2];c[aa+(c[A>>2]<<2)>>2]=c[aa+(c[y>>2]<<2)>>2];c[aa+(c[y>>2]<<2)>>2]=ab}Ja=Ea+2|0;x=ab&65535;a[Ja]=x;x=x>>8;a[Ja+1|0]=x;Ja=c[s>>2]|0;la=c[Ja>>2]|0;if((la|0)<0){ea=Ja;La=bb;U=la;while(1){Qa=((La|0)<(B|0))+La|0;if(((d[F+(La>>>3)|0]|0)&1<<(La&7)|0)==0){cb=ea}else{cb=ea+((U&2147483647)<<2)|0}V=cb+4|0;Ma=c[V>>2]|0;if((Ma|0)<0){ea=V;La=Qa;U=Ma}else{db=Ma;eb=Qa;break}}}else{db=la;eb=bb}if((db|0)!=(c[Ja+(c[y>>2]<<2)>>2]|0)){c[Ja+(c[z>>2]<<2)>>2]=c[Ja+(c[A>>2]<<2)>>2];c[Ja+(c[A>>2]<<2)>>2]=c[Ja+(c[y>>2]<<2)>>2];c[Ja+(c[y>>2]<<2)>>2]=db}U=Ea;x=db&65535;a[U]=x;x=x>>8;a[U+1|0]=x;if((Fa|0)>=4){Pa=eb;break a}Ia=eb;Fa=Fa+1|0;Ea=Ea+G|0}}else{Pa=M}}while(0);ha=Q+1|0;if((N|0)!=0&(ha|0)<(j|0)){M=Pa;Q=ha;R=N}else{break}}_=L-P|0;$=Pa}else if((Z|0)==96){Z=0;if((L|0)>=(j|0)){_=L;$=X;break}R=c[c[m>>2]>>2]|0;Q=ba(W>>8,16843009)|0;M=-Y|0;ha=L-j|0;O=ha>>>0<M>>>0?M:ha;ha=L;M=Y;do{ma=((ha|0)%(o|0)|0)+(ba((ha|0)/(o|0)|0,G)|0)<<2;c[R+ma>>2]=Q;S=ma+G|0;c[R+S>>2]=Q;ma=S+G|0;c[R+ma>>2]=Q;c[R+(ma+G)>>2]=Q;M=M-1|0;ha=ha+1|0;}while((M|0)!=0&(ha|0)<(j|0));_=L-O|0;$=X}}while(0);if((_|0)<(j|0)){K=$;L=_}else{break}}}_=MCb(e,c[m>>2]|0)|0;if((_|0)<0){l=_;i=h;return l|0}c[f>>2]=1;l=c[k>>2]|0;i=h;return l|0}function bYa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+8|0);$Db(b+12|0);$Db(b+16|0);$Db(b+20|0);JCb(b+4|0);return 0}function cYa(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+416>>2]|0;if((d-1|0)>>>0>1>>>0){yDb(a,16,2287880,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}else{e=(d|0)==2;d=a+448|0;c[d>>2]=e?3:4;c[d+4>>2]=e?0:0;c[a+420>>2]=(c[a+792>>2]|0)!=8;f=0;i=b;return f|0}return 0}function dYa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;j=i;i=i+208|0;k=j|0;l=j+24|0;m=j+120|0;n=j+200|0;o=n;p=c[h+24>>2]|0;q=c[h+28>>2]|0;TGb(l|0,0,96)|0;TGb(m|0,0,80)|0;c[n>>2]=0;c[n+4>>2]=0;if((q|0)<5){yDb(e,16,2048192,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=j;return s|0}h=p;t=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;if(t>>>0>16777216>>>0){yDb(e,16,2002720,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}h=p+4|0;p=q-4|0;u=p>>>0>268435455>>>0?-8:p<<3;p=u>>>0>2147483639>>>0|(h|0)==0;v=p?0:h;h=p?0:u;u=k|0;c[u>>2]=v;w=k+12|0;c[w>>2]=h;x=h+8|0;y=k+16|0;c[y>>2]=x;c[k+4>>2]=v+(h>>3);h=k+8|0;c[h>>2]=0;if(p){s=p?-1094995529:0;i=j;return s|0}p=a[v]|0;z=(x|0)>0|0;c[h>>2]=z;if((p&1)==0){yDb(e,32,1965352,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;c[g>>2]=0;s=1;i=j;return s|0}p=(d[v]|0)>>>(z>>>0);A=((z|0)<(x|0))+z|0;c[h>>2]=A;z=p&1;B=(d[v+(A>>>3)|0]|0)>>>((A&7)>>>0);c[h>>2]=((A|0)<(x|0))+A;A=B&1;B=c[e+416>>2]|0;if((B|0)!=1^(z|0)!=0){yDb(e,16,1937248,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=j;return s|0}if(!((c[e+420>>2]|0)==0^(A|0)!=0)){yDb(e,16,1913464,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=j;return s|0}c[f+76>>2]=(t|0)/(ba(A+1|0,B)|0)|0;B=_$a(e,f,0)|0;if((B|0)<0){s=B;i=j;return s|0}B=c[f>>2]|0;f=B;x=1<<A+z;a:do{if((x|0)>0){v=0;while(1){C=l+(v*24|0)|0;D=C|0;c[D>>2]=256;c[l+(v*24|0)+4>>2]=0;E=l+(v*24|0)+8|0;c[E>>2]=0;F=l+(v*24|0)+12|0;c[F>>2]=cEb(1024)|0;G=l+(v*24|0)+16|0;c[G>>2]=cEb(1024)|0;H=cEb(1024)|0;c[l+(v*24|0)+20>>2]=H;if((c[F>>2]|0)==0){I=-12;break a}if((c[G>>2]|0)==0|(H|0)==0){I=-12;break a}H=c[y>>2]|0;J=(c[h>>2]|0)+1|0;c[h>>2]=H>>>0>J>>>0?J:H;if((eYa(k,C,0,0)|0)<0){I=-1094995529;break a}C=c[y>>2]|0;H=(c[h>>2]|0)+1|0;c[h>>2]=C>>>0>H>>>0?H:C;if((c[E>>2]|0)>1){if((N_(m+(v*20|0)|0,9,c[D>>2]|0,c[G>>2]|0,4,4,c[F>>2]|0,4,4,0,0,0,2)|0)<0){break}}F=v+1|0;if((F|0)<(x|0)){v=F}else{K=21;break a}}yDb(e,16,1893e3,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;I=-1094995529}else{K=21}}while(0);if((K|0)==21){x=c[h>>2]|0;k=c[y>>2]|0;v=c[u>>2]|0;b:do{if((A|0)==0){F=z;G=x;while(1){D=v+(G>>>3)|0;E=(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)>>>((G&7)>>>0)&255;D=G+8|0;C=k>>>0>D>>>0?D:k;c[h>>2]=C;c[o+(F<<2)>>2]=E;if((F|0)>0){F=F-1|0;G=C}else{break}}G=(p&1)+1|0;F=0;C=B;while(1){a[C]=c[o+(F<<2)>>2];E=F+1|0;if((E|0)>(z|0)){break}else{F=E;C=C+1|0}}if((G|0)>=(t|0)){break}C=m+4|0;F=l+20|0;E=n;D=m+24|0;H=l+44|0;J=o+4|0;L=G;M=B+G|0;while(1){N=c[h>>2]|0;if(((c[w>>2]|0)-N|0)<0){s=-1094995529;K=83;break}if((L&z|0)==0){O=c[C>>2]|0;if((O|0)==0){P=0}else{Q=c[y>>2]|0;R=c[u>>2]|0;S=R+(N>>>3)|0;T=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((N&7)>>>0)&511;S=b[O+(T<<2)>>1]|0;U=b[O+(T<<2)+2>>1]|0;T=U<<16>>16;do{if(U<<16>>16<0){V=N+9|0;W=Q>>>0>V>>>0?V:Q;V=R+(W>>>3)|0;X=T+32|0;Y=((d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((W&7)>>>0)<<X>>>(X>>>0))+S|0;X=b[O+(Y<<2)>>1]|0;V=b[O+(Y<<2)+2>>1]|0;Y=V<<16>>16;if(!(V<<16>>16<0)){Z=Y;_=X;$=W;break}V=W-T|0;W=Q>>>0>V>>>0?V:Q;V=R+(W>>>3)|0;aa=Y+32|0;Y=((d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((W&7)>>>0)<<aa>>>(aa>>>0))+X|0;Z=b[O+(Y<<2)+2>>1]|0;_=b[O+(Y<<2)>>1]|0;$=W}else{Z=T;_=S;$=N}}while(0);S=Z+$|0;c[h>>2]=Q>>>0>S>>>0?S:Q;if((_|0)<0){K=76;break}else{P=_}}S=(c[(c[F>>2]|0)+(P<<2)>>2]<<24>>24)+(c[E>>2]|0)|0;c[E>>2]=S;ca=S&255}else{S=c[D>>2]|0;if((S|0)==0){da=0}else{T=c[y>>2]|0;O=c[u>>2]|0;R=O+(N>>>3)|0;U=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((N&7)>>>0)&511;R=b[S+(U<<2)>>1]|0;W=b[S+(U<<2)+2>>1]|0;U=W<<16>>16;do{if(W<<16>>16<0){Y=N+9|0;X=T>>>0>Y>>>0?Y:T;Y=O+(X>>>3)|0;aa=U+32|0;V=((d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((X&7)>>>0)<<aa>>>(aa>>>0))+R|0;aa=b[S+(V<<2)>>1]|0;Y=b[S+(V<<2)+2>>1]|0;V=Y<<16>>16;if(!(Y<<16>>16<0)){ea=V;fa=aa;ga=X;break}Y=X-U|0;X=T>>>0>Y>>>0?Y:T;Y=O+(X>>>3)|0;ha=V+32|0;V=((d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((X&7)>>>0)<<ha>>>(ha>>>0))+aa|0;ea=b[S+(V<<2)+2>>1]|0;fa=b[S+(V<<2)>>1]|0;ga=X}else{ea=U;fa=R;ga=N}}while(0);N=ea+ga|0;c[h>>2]=T>>>0>N>>>0?N:T;if((fa|0)<0){K=69;break}else{da=fa}}N=(c[(c[H>>2]|0)+(da<<2)>>2]<<24>>24)+(c[J>>2]|0)|0;c[J>>2]=N;ca=N&255}a[M]=ca;N=L+1|0;if((N|0)<(t|0)){L=N;M=M+1|0}else{break b}}if((K|0)==69){yDb(e,16,2350656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==76){yDb(e,16,2350656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==83){i=j;return s|0}}else{M=z;L=x;while(1){J=v+(L>>>3)|0;H=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((L&7)>>>0);J=L+16|0;ia=k>>>0>J>>>0?J:k;c[h>>2]=ia;c[o+(M<<2)>>2]=(de(H&65535|0)|0)<<16>>16;if((M|0)>0){M=M-1|0;L=ia}else{break}}L=p&1;M=B+((L<<1)+2)|0;H=0;J=f;while(1){b[J>>1]=c[o+(H<<2)>>2];D=H+1|0;if((D|0)>(z|0)){break}else{H=D;J=J+2|0}}J=L+1|0;H=(t|0)/2|0;if((J|0)>=(H|0)){break}D=m+4|0;E=l+20|0;F=m+24|0;C=l+44|0;G=n;N=m+44|0;R=l+68|0;U=m+64|0;S=l+92|0;O=o+4|0;W=J;J=M;Q=ia;while(1){if(((c[w>>2]|0)-Q|0)<0){s=-1094995529;K=83;break}if((W&z|0)==0){X=c[D>>2]|0;if((X|0)==0){ja=0;ka=Q}else{V=c[y>>2]|0;aa=c[u>>2]|0;ha=aa+(Q>>>3)|0;Y=(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)>>>((Q&7)>>>0)&511;ha=b[X+(Y<<2)>>1]|0;la=b[X+(Y<<2)+2>>1]|0;Y=la<<16>>16;do{if(la<<16>>16<0){ma=Q+9|0;na=V>>>0>ma>>>0?ma:V;ma=aa+(na>>>3)|0;oa=Y+32|0;pa=((d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)>>>((na&7)>>>0)<<oa>>>(oa>>>0))+ha|0;oa=b[X+(pa<<2)>>1]|0;ma=b[X+(pa<<2)+2>>1]|0;pa=ma<<16>>16;if(!(ma<<16>>16<0)){qa=pa;ra=oa;sa=na;break}ma=na-Y|0;na=V>>>0>ma>>>0?ma:V;ma=aa+(na>>>3)|0;ta=pa+32|0;pa=((d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)>>>((na&7)>>>0)<<ta>>>(ta>>>0))+oa|0;qa=b[X+(pa<<2)+2>>1]|0;ra=b[X+(pa<<2)>>1]|0;sa=na}else{qa=Y;ra=ha;sa=Q}}while(0);ha=qa+sa|0;Y=V>>>0>ha>>>0?ha:V;c[h>>2]=Y;if((ra|0)<0){K=47;break}else{ja=ra;ka=Y}}Y=c[(c[E>>2]|0)+(ja<<2)>>2]|0;ha=c[F>>2]|0;if((ha|0)==0){ua=0}else{X=c[y>>2]|0;aa=c[u>>2]|0;la=aa+(ka>>>3)|0;T=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ka&7)>>>0)&511;la=b[ha+(T<<2)>>1]|0;na=b[ha+(T<<2)+2>>1]|0;T=na<<16>>16;do{if(na<<16>>16<0){pa=ka+9|0;oa=X>>>0>pa>>>0?pa:X;pa=aa+(oa>>>3)|0;ta=T+32|0;ma=((d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)>>>((oa&7)>>>0)<<ta>>>(ta>>>0))+la|0;ta=b[ha+(ma<<2)>>1]|0;pa=b[ha+(ma<<2)+2>>1]|0;ma=pa<<16>>16;if(!(pa<<16>>16<0)){va=ma;wa=ta;xa=oa;break}pa=oa-T|0;oa=X>>>0>pa>>>0?pa:X;pa=aa+(oa>>>3)|0;ya=ma+32|0;ma=((d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)>>>((oa&7)>>>0)<<ya>>>(ya>>>0))+ta|0;va=b[ha+(ma<<2)+2>>1]|0;wa=b[ha+(ma<<2)>>1]|0;xa=oa}else{va=T;wa=la;xa=ka}}while(0);la=va+xa|0;c[h>>2]=X>>>0>la>>>0?la:X;if((wa|0)<0){K=53;break}else{ua=wa}}la=((c[(c[C>>2]|0)+(ua<<2)>>2]<<8|Y)<<16>>16)+(c[G>>2]|0)|0;c[G>>2]=la;za=la&65535}else{la=c[N>>2]|0;if((la|0)==0){Aa=0;Ba=Q}else{T=c[y>>2]|0;ha=c[u>>2]|0;aa=ha+(Q>>>3)|0;na=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((Q&7)>>>0)&511;aa=b[la+(na<<2)>>1]|0;V=b[la+(na<<2)+2>>1]|0;na=V<<16>>16;do{if(V<<16>>16<0){oa=Q+9|0;ma=T>>>0>oa>>>0?oa:T;oa=ha+(ma>>>3)|0;ta=na+32|0;ya=((d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)>>>((ma&7)>>>0)<<ta>>>(ta>>>0))+aa|0;ta=b[la+(ya<<2)>>1]|0;oa=b[la+(ya<<2)+2>>1]|0;ya=oa<<16>>16;if(!(oa<<16>>16<0)){Ca=ya;Da=ta;Ea=ma;break}oa=ma-na|0;ma=T>>>0>oa>>>0?oa:T;oa=ha+(ma>>>3)|0;pa=ya+32|0;ya=((d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)>>>((ma&7)>>>0)<<pa>>>(pa>>>0))+ta|0;Ca=b[la+(ya<<2)+2>>1]|0;Da=b[la+(ya<<2)>>1]|0;Ea=ma}else{Ca=na;Da=aa;Ea=Q}}while(0);aa=Ca+Ea|0;na=T>>>0>aa>>>0?aa:T;c[h>>2]=na;if((Da|0)<0){K=34;break}else{Aa=Da;Ba=na}}na=c[(c[R>>2]|0)+(Aa<<2)>>2]|0;aa=c[U>>2]|0;if((aa|0)==0){Fa=0}else{la=c[y>>2]|0;ha=c[u>>2]|0;V=ha+(Ba>>>3)|0;Y=(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((Ba&7)>>>0)&511;V=b[aa+(Y<<2)>>1]|0;X=b[aa+(Y<<2)+2>>1]|0;Y=X<<16>>16;do{if(X<<16>>16<0){ma=Ba+9|0;ya=la>>>0>ma>>>0?ma:la;ma=ha+(ya>>>3)|0;ta=Y+32|0;pa=((d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)>>>((ya&7)>>>0)<<ta>>>(ta>>>0))+V|0;ta=b[aa+(pa<<2)>>1]|0;ma=b[aa+(pa<<2)+2>>1]|0;pa=ma<<16>>16;if(!(ma<<16>>16<0)){Ga=pa;Ha=ta;Ia=ya;break}ma=ya-Y|0;ya=la>>>0>ma>>>0?ma:la;ma=ha+(ya>>>3)|0;oa=pa+32|0;pa=((d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)>>>((ya&7)>>>0)<<oa>>>(oa>>>0))+ta|0;Ga=b[aa+(pa<<2)+2>>1]|0;Ha=b[aa+(pa<<2)>>1]|0;Ia=ya}else{Ga=Y;Ha=V;Ia=Ba}}while(0);V=Ga+Ia|0;c[h>>2]=la>>>0>V>>>0?V:la;if((Ha|0)<0){K=40;break}else{Fa=Ha}}V=((c[(c[S>>2]|0)+(Fa<<2)>>2]<<8|na)<<16>>16)+(c[O>>2]|0)|0;c[O>>2]=V;za=V&65535}b[J>>1]=za;V=W+1|0;if((V|0)>=(H|0)){break b}W=V;J=J+2|0;Q=c[h>>2]|0}if((K|0)==34){yDb(e,16,2350656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==40){yDb(e,16,2350656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==47){yDb(e,16,2350656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==53){yDb(e,16,2350656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==83){i=j;return s|0}}}while(0);c[g>>2]=1;I=q}if((c[m+4>>2]|0)!=0){Q_(m|0)}ZDb(c[l+12>>2]|0);ZDb(c[l+16>>2]|0);ZDb(c[l+20>>2]|0);if((c[m+24>>2]|0)!=0){Q_(m+20|0)}ZDb(c[l+36>>2]|0);ZDb(c[l+40>>2]|0);ZDb(c[l+44>>2]|0);if((c[m+44>>2]|0)!=0){Q_(m+40|0)}ZDb(c[l+60>>2]|0);ZDb(c[l+64>>2]|0);ZDb(c[l+68>>2]|0);if((c[m+64>>2]|0)!=0){Q_(m+60|0)}ZDb(c[l+84>>2]|0);ZDb(c[l+88>>2]|0);ZDb(c[l+92>>2]|0);s=I;i=j;return s|0}function eYa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;a:do{if((f|0)<=27){h=a+8|0;j=a|0;k=a+16|0;l=e;m=f;while(1){n=c[h>>2]|0;o=c[j>>2]|0;p=d[o+(n>>>3)|0]|0;c[h>>2]=((n|0)<(c[k>>2]|0))+n;if((p&1<<(n&7)|0)==0){break}n=m+1|0;p=eYa(a,b,l,n)|0;if((p|0)!=0){q=p;r=14;break}if((n|0)>27){break a}else{l=1<<m|l;m=n}}if((r|0)==14){i=g;return q|0}j=b+8|0;n=c[j>>2]|0;if((n|0)>=(c[b>>2]|0)){yDb(0,16,2306016,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;q=-1094995529;i=g;return q|0}p=(c[b+12>>2]|0)+(n<<2)|0;if((m|0)==0){c[p>>2]=0;c[(c[b+16>>2]|0)+(c[j>>2]<<2)>>2]=0}else{c[p>>2]=l;c[(c[b+16>>2]|0)+(c[j>>2]<<2)>>2]=m}p=c[h>>2]|0;n=c[k>>2]|0;t=o+(p>>>3)|0;u=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>((p&7)>>>0)&255;t=p+8|0;c[h>>2]=n>>>0>t>>>0?t:n;c[(c[b+20>>2]|0)+(c[j>>2]<<2)>>2]=u;c[j>>2]=(c[j>>2]|0)+1;j=b+4|0;if((c[j>>2]|0)>=(m|0)){q=0;i=g;return q|0}c[j>>2]=m;q=0;i=g;return q|0}}while(0);yDb(0,16,2330280,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;q=-1094995529;i=g;return q|0}function fYa(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=i;i=i+152|0;j=h|0;k=h+24|0;l=h+48|0;m=h+72|0;n=h+112|0;TGb(m|0,0,40)|0;if(g>>>0>268435454>>>0){yDb(c[a>>2]|0,16,2174840,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}q=k|0;c[q>>2]=256;c[k+4>>2]=0;r=k+8|0;c[r>>2]=0;s=cEb(1024)|0;t=k+12|0;c[t>>2]=s;u=cEb(1024)|0;v=k+16|0;c[v>>2]=u;w=cEb(1024)|0;x=k+20|0;c[x>>2]=w;y=l|0;c[y>>2]=256;c[l+4>>2]=0;z=l+8|0;c[z>>2]=0;A=cEb(1024)|0;B=l+12|0;c[B>>2]=A;C=cEb(1024)|0;D=l+16|0;c[D>>2]=C;E=cEb(1024)|0;F=l+20|0;c[F>>2]=E;a:do{if((s|0)==0|(u|0)==0|(w|0)==0|(A|0)==0){G=-12}else{if((C|0)==0|(E|0)==0){G=-12;break}H=b+8|0;I=c[H>>2]|0;J=b|0;K=d[(c[J>>2]|0)+(I>>>3)|0]|0;L=b+16|0;c[H>>2]=((I|0)<(c[L>>2]|0))+I;do{if((K&1<<(I&7)|0)!=0){M=eYa(b,k,0,0)|0;if((M|0)<0){G=M;break a}M=c[L>>2]|0;N=(c[H>>2]|0)+1|0;c[H>>2]=M>>>0>N>>>0?N:M;if((c[r>>2]|0)<=1){break}M=N_(m|0,9,c[q>>2]|0,c[v>>2]|0,4,4,c[t>>2]|0,4,4,0,0,0,2)|0;if((M|0)>=0){break}yDb(c[a>>2]|0,16,1893e3,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;G=M;break a}}while(0);I=m|0;if((c[m+4>>2]|0)==0){yDb(c[a>>2]|0,16,2164608,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}K=c[H>>2]|0;M=d[(c[J>>2]|0)+(K>>>3)|0]|0;c[H>>2]=((K|0)<(c[L>>2]|0))+K;do{if((M&1<<(K&7)|0)!=0){N=eYa(b,l,0,0)|0;if((N|0)<0){G=N;break a}N=c[L>>2]|0;O=(c[H>>2]|0)+1|0;c[H>>2]=N>>>0>O>>>0?O:N;if((c[z>>2]|0)<=1){break}N=N_(m+20|0,9,c[y>>2]|0,c[D>>2]|0,4,4,c[B>>2]|0,4,4,0,0,0,2)|0;if((N|0)>=0){break}yDb(c[a>>2]|0,16,1893e3,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;G=N;break a}}while(0);if((c[m+24>>2]|0)==0){yDb(c[a>>2]|0,16,2157888,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}K=c[H>>2]|0;M=c[L>>2]|0;N=c[J>>2]|0;O=N+(K>>>3)|0;P=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((K&7)>>>0)&65535;O=K+16|0;K=M>>>0>O>>>0?O:M;c[H>>2]=K;O=N+(K>>>3)|0;Q=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((K&7)>>>0)&65535;O=K+16|0;K=M>>>0>O>>>0?O:M;c[H>>2]=K;O=N+(K>>>3)|0;N=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((K&7)>>>0)&65535;O=K+16|0;c[H>>2]=M>>>0>O>>>0?O:M;c[f+8>>2]=-1;c[f+4>>2]=-1;c[f>>2]=-1;c[n+16>>2]=P;c[n+20>>2]=Q;c[n+24>>2]=N;c[n>>2]=I;c[n+4>>2]=m+20;c[n+8>>2]=c[x>>2];c[n+12>>2]=c[F>>2];N=n+28|0;c[N>>2]=f;Q=(g+3>>2)+4|0;P=j|0;c[P>>2]=Q;c[j+4>>2]=0;M=j+8|0;c[M>>2]=0;O=cEb(Q<<2)|0;Q=j+20|0;c[Q>>2]=O;if((O|0)==0){G=-12;break}O=(gYa(b,j,n)|0)>>31;K=c[L>>2]|0;R=(c[H>>2]|0)+1|0;c[H>>2]=K>>>0>R>>>0?R:K;K=c[N>>2]|0;if((c[K>>2]|0)==-1){N=c[M>>2]|0;c[M>>2]=N+1;c[K>>2]=N}N=K+4|0;if((c[N>>2]|0)==-1){R=c[M>>2]|0;c[M>>2]=R+1;c[N>>2]=R}R=K+8|0;S=c[R>>2]|0;if((S|0)==-1){T=c[M>>2]|0;c[M>>2]=T+1;c[R>>2]=T;U=T}else{U=S}S=c[P>>2]|0;if((c[K>>2]|0)<(S|0)){if((c[N>>2]|0)<(S|0)&(U|0)<(S|0)){V=O}else{W=28}}else{W=28}if((W|0)==28){yDb(c[a>>2]|0,16,2151016,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;V=-1094995529}c[e>>2]=c[Q>>2];G=V}}while(0);if((c[m+4>>2]|0)!=0){Q_(m|0)}if((c[m+24>>2]|0)!=0){Q_(m+20|0)}ZDb(c[t>>2]|0);ZDb(c[v>>2]|0);ZDb(c[x>>2]|0);ZDb(c[B>>2]|0);ZDb(c[D>>2]|0);ZDb(c[F>>2]|0);p=G;i=h;return p|0}function gYa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;h=e+8|0;if(((c[h>>2]|0)+1|0)>=(c[e>>2]|0)){yDb(0,16,2306016,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=g;return k|0}j=a+8|0;l=c[j>>2]|0;m=c[a>>2]|0;n=d[m+(l>>>3)|0]|0;o=c[a+16>>2]|0;p=((l|0)<(o|0))+l|0;c[j>>2]=p;if((n&1<<(l&7)|0)!=0){l=c[h>>2]|0;c[h>>2]=l+1;n=gYa(a,e,f)|0;if((n|0)<0){k=n;i=g;return k|0}c[(c[e+20>>2]|0)+(l<<2)>>2]=n|-2147483648;l=gYa(a,e,f)|0;if((l|0)<0){k=l;i=g;return k|0}k=n+1+l|0;i=g;return k|0}l=c[(c[f>>2]|0)+4>>2]|0;if((l|0)==0){q=0;r=p}else{n=m+(p>>>3)|0;a=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((p&7)>>>0)&511;n=b[l+(a<<2)>>1]|0;s=b[l+(a<<2)+2>>1]|0;a=s<<16>>16;do{if(s<<16>>16<0){t=p+9|0;u=o>>>0>t>>>0?t:o;t=m+(u>>>3)|0;v=a+32|0;w=((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>((u&7)>>>0)<<v>>>(v>>>0))+n|0;v=b[l+(w<<2)>>1]|0;t=b[l+(w<<2)+2>>1]|0;w=t<<16>>16;if(!(t<<16>>16<0)){x=w;y=v;z=u;break}t=u-a|0;u=o>>>0>t>>>0?t:o;t=m+(u>>>3)|0;A=w+32|0;w=((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>((u&7)>>>0)<<A>>>(A>>>0))+v|0;x=b[l+(w<<2)+2>>1]|0;y=b[l+(w<<2)>>1]|0;z=u}else{x=a;y=n;z=p}}while(0);p=x+z|0;z=o>>>0>p>>>0?p:o;c[j>>2]=z;q=y;r=z}z=c[(c[f+4>>2]|0)+4>>2]|0;if((z|0)==0){B=0}else{y=m+(r>>>3)|0;p=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((r&7)>>>0)&511;y=b[z+(p<<2)>>1]|0;x=b[z+(p<<2)+2>>1]|0;p=x<<16>>16;do{if(x<<16>>16<0){n=r+9|0;a=o>>>0>n>>>0?n:o;n=m+(a>>>3)|0;l=p+32|0;s=((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((a&7)>>>0)<<l>>>(l>>>0))+y|0;l=b[z+(s<<2)>>1]|0;n=b[z+(s<<2)+2>>1]|0;s=n<<16>>16;if(!(n<<16>>16<0)){C=s;D=l;E=a;break}n=a-p|0;a=o>>>0>n>>>0?n:o;n=m+(a>>>3)|0;u=s+32|0;s=((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((a&7)>>>0)<<u>>>(u>>>0))+l|0;C=b[z+(s<<2)+2>>1]|0;D=b[z+(s<<2)>>1]|0;E=a}else{C=p;D=y;E=r}}while(0);r=C+E|0;c[j>>2]=o>>>0>r>>>0?r:o;B=D}if((B|q|0)<0){k=-1094995529;i=g;return k|0}D=c[(c[f+12>>2]|0)+(B<<2)>>2]<<8|c[(c[f+8>>2]|0)+(q<<2)>>2];do{if((D|0)==(c[f+16>>2]|0)){c[c[f+28>>2]>>2]=c[h>>2];F=0}else{if((D|0)==(c[f+20>>2]|0)){c[(c[f+28>>2]|0)+4>>2]=c[h>>2];F=0;break}if((D|0)!=(c[f+24>>2]|0)){F=D;break}c[(c[f+28>>2]|0)+8>>2]=c[h>>2];F=0}}while(0);f=c[h>>2]|0;c[h>>2]=f+1;c[(c[e+20>>2]|0)+(f<<2)>>2]=F;k=1;i=g;return k|0}function hYa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;a=ICb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function iYa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;l=c[b+60>>2]|0;m=l;n=HZ(g,0,0)|0;if(!((k|0)>-1)){yDb(0,0,1913392,(o=i,i=i+24|0,c[o>>2]=1892984,c[o+8>>2]=2350632,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}g=l+8|0;c[g>>2]=j;p=l+16|0;c[p>>2]=j;q=l+12|0;c[q>>2]=j+k;j=l+4|0;r=$$a(b,c[j>>2]|0)|0;if((r|0)<0){s=r;i=h;return s|0}r=c[j>>2]|0;if((n|0)==0){t=l+3604|0}else{c[r+304>>2]=1;b=l+3604|0;UGb(b|0,n|0,1024)|0;t=b}b=l;l=c[b>>2]|0;n=c[l+120>>2]|0;u=c[r+32>>2]|0;v=(c[q>>2]|0)-(c[p>>2]|0)|0;p=c[r>>2]|0;w=ba(u,c[l+124>>2]|0)|0;l=u-4|0;UGb(c[r+4>>2]|0,t|0,1024)|0;t=c[g>>2]|0;r=c[q>>2]|0;x=r-t|0;y=x>>>0>1>>>0?1:x;x=t+y|0;c[g>>2]=x;if((r-x|0)<3){z=0}else{c[g>>2]=t+(y+3);z=(d[t+(y+1)|0]|0)<<8|(d[x]|0)<<16|(d[t+(y+2)|0]|0)}if((z|0)!=(v|0)){yDb(c[b>>2]|0,32,2181736,(o=i,i=i+16|0,c[o>>2]=z,c[o+8>>2]=v,o)|0);i=o}v=c[b>>2]|0;z=ba(((c[v+124>>2]|0)+3|0)/4|0,((c[v+120>>2]|0)+3|0)/4|0)|0;a:do{if((z|0)!=0){v=u<<2;y=u<<1;t=u*3|0;x=0;r=0;A=z;B=0;C=0;D=0;b:while(1){if((x|0)>=(w|0)){E=14;break}F=c[g>>2]|0;G=c[q>>2]|0;c:do{if((G-F|0)<1){H=0;E=20}else{I=F+1|0;c[g>>2]=I;J=d[F]|0;K=J&240;switch(K|0){case 32:case 48:{do{if((J&16|0)==0){L=J&15}else{if((G-I|0)<1){L=0;break}c[g>>2]=F+2;L=d[I]|0}}while(0);if((x|r|0)==0){E=30;break b}if((r|0)==0){M=c[(c[b>>2]|0)+120>>2]|0;N=x-4+M-(M<<2)|0;O=0}else{N=r-4+x|0;O=r}M=p+N|0;P=p+(N+1)|0;Q=p+(N+2)|0;R=p+(N+3)|0;S=N+u|0;T=p+S|0;U=p+(S+1)|0;V=p+(S+2)|0;W=p+(S+3)|0;X=S+u|0;S=p+X|0;Y=p+(X+1)|0;Z=p+(X+2)|0;_=p+(X+3)|0;$=X+u|0;X=p+$|0;aa=p+($+1)|0;ca=p+($+2)|0;da=p+($+3)|0;$=L+1|0;ea=A;fa=O;ga=x;while(1){if(($|0)==0){ha=D;ia=C;ja=B;ka=ea;la=fa;ma=ga;break c}na=fa+ga|0;a[p+na|0]=a[M]|0;a[p+(na+1)|0]=a[P]|0;a[p+(na+2)|0]=a[Q]|0;a[p+(na+3)|0]=a[R]|0;oa=na+u|0;a[p+oa|0]=a[T]|0;a[p+(oa+1)|0]=a[U]|0;a[p+(oa+2)|0]=a[V]|0;a[p+(oa+3)|0]=a[W]|0;na=oa+u|0;a[p+na|0]=a[S]|0;a[p+(na+1)|0]=a[Y]|0;a[p+(na+2)|0]=a[Z]|0;a[p+(na+3)|0]=a[_]|0;oa=na+u|0;a[p+oa|0]=a[X]|0;a[p+(oa+1)|0]=a[aa]|0;a[p+(oa+2)|0]=a[ca]|0;a[p+(oa+3)|0]=a[da]|0;oa=fa+4|0;na=(oa|0)<(n|0);pa=ea-1|0;if((pa|0)<0){E=37;break b}else{$=$-1|0;ea=pa;fa=na?oa:0;ga=(na?0:v)+ga|0}}break};case 224:{ga=(J&15)+1|0;fa=A;ea=r;$=x;while(1){da=ga-1|0;if((ga|0)==0){ha=D;ia=C;ja=B;ka=fa;la=ea;ma=$;break c}ca=1;aa=ea+$|0;while(1){X=c[g>>2]|0;if(((c[q>>2]|0)-X|0)<1){qa=0}else{c[g>>2]=X+1;qa=a[X]|0}a[p+aa|0]=qa;X=c[g>>2]|0;if(((c[q>>2]|0)-X|0)<1){ra=0}else{c[g>>2]=X+1;ra=a[X]|0}a[p+(aa+1)|0]=ra;X=c[g>>2]|0;if(((c[q>>2]|0)-X|0)<1){sa=0}else{c[g>>2]=X+1;sa=a[X]|0}a[p+(aa+2)|0]=sa;X=c[g>>2]|0;if(((c[q>>2]|0)-X|0)<1){ta=0}else{c[g>>2]=X+1;ta=a[X]|0}a[p+(aa+3)|0]=ta;if((ca|0)>=4){break}ca=ca+1|0;aa=aa+u|0}aa=ea+4|0;ca=(aa|0)<(n|0);X=fa-1|0;if((X|0)<0){E=116;break b}else{ga=da;fa=X;ea=ca?aa:0;$=(ca?0:v)+$|0}}break};case 160:case 176:{$=(J&15)+1|0;do{if((K|0)==160){ea=C<<2;if((G-I|0)<1){ua=0}else{c[g>>2]=F+2;ua=a[I]|0}a[m+532+ea|0]=ua;fa=c[g>>2]|0;if(((c[q>>2]|0)-fa|0)<1){va=0}else{c[g>>2]=fa+1;va=a[fa]|0}a[(ea|1)+(m+532)|0]=va;fa=c[g>>2]|0;if(((c[q>>2]|0)-fa|0)<1){wa=0}else{c[g>>2]=fa+1;wa=a[fa]|0}a[(ea|2)+(m+532)|0]=wa;fa=c[g>>2]|0;if(((c[q>>2]|0)-fa|0)<1){xa=0}else{c[g>>2]=fa+1;xa=a[fa]|0}a[(ea|3)+(m+532)|0]=xa;fa=C+1|0;ya=(fa|0)==256?0:fa;za=ea}else{if((G-I|0)<1){ya=C;za=0;break}c[g>>2]=F+2;ya=C;za=(d[I]|0)<<2}}while(0);ea=$;fa=A;ga=r;ca=x;while(1){aa=ea-1|0;if((ea|0)==0){ha=D;ia=ya;ja=B;ka=fa;la=ga;ma=ca;break c}X=c[g>>2]|0;if(((c[q>>2]|0)-X|0)<4){Aa=0}else{c[g>>2]=X+4;_=X;Aa=fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0}_=30;X=0;Z=ga+ca|0;while(1){a[p+Z|0]=a[(Aa>>>(_>>>0)&3|za)+(m+532)|0]|0;a[p+(Z+1)|0]=a[(Aa>>>((_-2|0)>>>0)&3|za)+(m+532)|0]|0;a[p+(Z+2)|0]=a[(Aa>>>((_-4|0)>>>0)&3|za)+(m+532)|0]|0;a[p+(Z+3)|0]=a[(Aa>>>((_-6|0)>>>0)&3|za)+(m+532)|0]|0;Y=X+1|0;if((Y|0)<4){_=_-8|0;X=Y;Z=Z+u|0}else{break}}Z=ga+4|0;X=(Z|0)<(n|0);_=fa-1|0;if((_|0)<0){E=90;break b}else{ea=aa;fa=_;ga=X?Z:0;ca=(X?0:v)+ca|0}}break};case 240:{DDb(c[b>>2]|0,1937160,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ha=D;ia=C;ja=B;ka=A;la=r;ma=x;break c;break};case 128:case 144:{ca=(J&15)+1|0;do{if((K|0)==128){ga=B<<1;if((G-I|0)<1){Ba=0}else{c[g>>2]=F+2;Ba=a[I]|0}a[m+20+ga|0]=Ba;fa=c[g>>2]|0;if(((c[q>>2]|0)-fa|0)<1){Ca=0}else{c[g>>2]=fa+1;Ca=a[fa]|0}a[(ga|1)+(m+20)|0]=Ca;fa=B+1|0;Da=(fa|0)==256?0:fa;Ea=ga}else{if((G-I|0)<1){Da=B;Ea=0;break}c[g>>2]=F+2;Da=B;Ea=(d[I]|0)<<1}}while(0);ga=ca;fa=A;ea=r;$=x;while(1){X=ga-1|0;if((ga|0)==0){ha=D;ia=C;ja=Da;ka=fa;la=ea;ma=$;break c}Z=c[g>>2]|0;if(((c[q>>2]|0)-Z|0)<2){Fa=0}else{c[g>>2]=Z+2;_=Z;Fa=(de((d[_]|d[_+1|0]<<8)<<16>>16|0)|0)&65535}_=32768;Z=0;da=ea+$|0;while(1){a[p+da|0]=a[((_&Fa|0)!=0|Ea)+(m+20)|0]|0;a[p+(da+1)|0]=a[((_>>>1&Fa|0)!=0|Ea)+(m+20)|0]|0;a[p+(da+2)|0]=a[((_>>>2&Fa|0)!=0|Ea)+(m+20)|0]|0;a[p+(da+3)|0]=a[((_>>>3&Fa|0)!=0|Ea)+(m+20)|0]|0;Y=Z+1|0;if((Y|0)<4){_=_>>>4;Z=Y;da=da+u|0}else{break}}da=ea+4|0;Z=(da|0)<(n|0);_=fa-1|0;if((_|0)<0){E=76;break b}else{ga=X;fa=_;ea=Z?da:0;$=(Z?0:v)+$|0}}break};case 96:case 112:{do{if((J&16|0)==0){Ga=J&15;Ha=I}else{if((G-I|0)<1){Ga=0;Ha=I;break}$=F+2|0;c[g>>2]=$;Ga=d[I]|0;Ha=$}}while(0);if((G-Ha|0)<1){Ia=0}else{c[g>>2]=Ha+1;Ia=a[Ha]|0}$=Ga+1|0;ea=A;fa=r;ga=x;while(1){if(($|0)==0){ha=D;ia=C;ja=B;ka=ea;la=fa;ma=ga;break c}ca=fa+ga|0;TGb(p+ca|0,Ia|0,4)|0;TGb(p+(ca+u)|0,Ia|0,4)|0;TGb(p+(ca+y)|0,Ia|0,4)|0;TGb(p+(ca+t)|0,Ia|0,4)|0;ca=fa+4|0;Z=(ca|0)<(n|0);da=ea-1|0;if((da|0)<0){E=62;break b}else{$=$-1|0;ea=da;fa=Z?ca:0;ga=(Z?0:v)+ga|0}}break};case 64:case 80:{do{if((J&16|0)==0){Ja=J&15}else{if((G-I|0)<1){Ja=0;break}c[g>>2]=F+2;Ja=d[I]|0}}while(0);ga=(Ja<<1)+2|0;if((x|0)==0&(r|0)<8){E=43;break b}if((r|0)==0){fa=c[(c[b>>2]|0)+120>>2]|0;ea=fa<<2;Ka=x+l-ea|0;La=x-8+fa-ea|0}else if((r|0)==4){Ma=x+l-(c[(c[b>>2]|0)+120>>2]<<2)|0;E=48}else{Ma=r-8+x|0;E=48}if((E|0)==48){E=0;Ka=r-4+x|0;La=Ma}ea=ga;ga=A;fa=0;$=r;Z=x;while(1){if((ea|0)==0){ha=D;ia=C;ja=B;ka=ga;la=$;ma=Z;break c}ca=$+Z|0;da=(fa|0)!=0;_=da?Ka:La;a[p+ca|0]=a[p+_|0]|0;a[p+(ca+1)|0]=a[p+(_+1)|0]|0;a[p+(ca+2)|0]=a[p+(_+2)|0]|0;a[p+(ca+3)|0]=a[p+(_+3)|0]|0;aa=ca+u|0;ca=_+u|0;a[p+aa|0]=a[p+ca|0]|0;a[p+(aa+1)|0]=a[p+(ca+1)|0]|0;a[p+(aa+2)|0]=a[p+(ca+2)|0]|0;a[p+(aa+3)|0]=a[p+(ca+3)|0]|0;_=aa+u|0;aa=ca+u|0;a[p+_|0]=a[p+aa|0]|0;a[p+(_+1)|0]=a[p+(aa+1)|0]|0;a[p+(_+2)|0]=a[p+(aa+2)|0]|0;a[p+(_+3)|0]=a[p+(aa+3)|0]|0;ca=_+u|0;_=aa+u|0;a[p+ca|0]=a[p+_|0]|0;a[p+(ca+1)|0]=a[p+(_+1)|0]|0;a[p+(ca+2)|0]=a[p+(_+2)|0]|0;a[p+(ca+3)|0]=a[p+(_+3)|0]|0;_=$+4|0;ca=(_|0)<(n|0);aa=ga-1|0;if((aa|0)<0){E=52;break b}else{ea=ea-1|0;ga=aa;fa=da&1^1;$=ca?_:0;Z=(ca?0:v)+Z|0}}break};case 192:case 208:{Z=(J&15)+1|0;do{if((K|0)==192){$=D<<3;if((G-I|0)<1){Na=0;Oa=I}else{fa=F+2|0;c[g>>2]=fa;Na=a[I]|0;Oa=fa}a[m+1556+$|0]=Na;if(((c[q>>2]|0)-Oa|0)<1){Pa=0;Qa=Oa}else{fa=Oa+1|0;c[g>>2]=fa;Pa=a[Oa]|0;Qa=fa}a[($|1)+(m+1556)|0]=Pa;if(((c[q>>2]|0)-Qa|0)<1){Ra=0;Sa=Qa}else{fa=Qa+1|0;c[g>>2]=fa;Ra=a[Qa]|0;Sa=fa}a[($|2)+(m+1556)|0]=Ra;if(((c[q>>2]|0)-Sa|0)<1){Ta=0;Ua=Sa}else{fa=Sa+1|0;c[g>>2]=fa;Ta=a[Sa]|0;Ua=fa}a[($|3)+(m+1556)|0]=Ta;fa=c[q>>2]|0;if((fa-Ua|0)<1){Va=0}else{c[g>>2]=Ua+1;Va=a[Ua]|0}a[($|4)+(m+1556)|0]=Va;ga=c[g>>2]|0;if((fa-ga|0)<1){Wa=0}else{c[g>>2]=ga+1;Wa=a[ga]|0}a[($|5)+(m+1556)|0]=Wa;ga=c[g>>2]|0;if((fa-ga|0)<1){Xa=0}else{c[g>>2]=ga+1;Xa=a[ga]|0}a[($|6)+(m+1556)|0]=Xa;ga=c[g>>2]|0;if((fa-ga|0)<1){Ya=0}else{c[g>>2]=ga+1;Ya=a[ga]|0}a[($|7)+(m+1556)|0]=Ya;ga=D+1|0;Za=(ga|0)==256?0:ga;_a=$}else{if((G-I|0)<1){Za=D;_a=0;break}c[g>>2]=F+2;Za=D;_a=(d[I]|0)<<3}}while(0);$=Z;ga=A;fa=r;ea=x;while(1){ca=$-1|0;if(($|0)==0){ha=Za;ia=C;ja=B;ka=ga;la=fa;ma=ea;break c}_=c[g>>2]|0;da=c[q>>2]|0;if((da-_|0)<2){$a=0;ab=_}else{aa=_+2|0;c[g>>2]=aa;Y=_;$a=((de((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<8;ab=aa}if((da-ab|0)<2){bb=0;cb=ab}else{aa=ab+2|0;c[g>>2]=aa;Y=ab;bb=(de((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535;cb=aa}if((da-cb|0)<2){db=0}else{c[g>>2]=cb+2;da=cb;db=(de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535}da=bb<<4&240|$a&3840|db&15|db<<8&16773120;aa=21;Y=0;_=bb>>>4|$a&16773120;S=fa+ea|0;while(1){W=(Y|0)==2;V=W?21:aa;U=W?da:_;a[p+S|0]=a[(U>>>(V>>>0)&7|_a)+(m+1556)|0]|0;a[p+(S+1)|0]=a[(U>>>((V-3|0)>>>0)&7|_a)+(m+1556)|0]|0;a[p+(S+2)|0]=a[(U>>>((V-6|0)>>>0)&7|_a)+(m+1556)|0]|0;a[p+(S+3)|0]=a[(U>>>((V-9|0)>>>0)&7|_a)+(m+1556)|0]|0;W=Y+1|0;if((W|0)<4){aa=V-12|0;Y=W;_=U;S=S+u|0}else{break}}S=fa+4|0;_=(S|0)<(n|0);Y=ga-1|0;if((Y|0)<0){E=108;break b}else{$=ca;ga=Y;fa=_?S:0;ea=(_?0:v)+ea|0}}break};case 0:case 16:{if((J&16|0)==0){H=J;E=20;break c}if((G-I|0)<1){eb=0;E=21;break c}c[g>>2]=F+2;eb=d[I]|0;E=21;break c;break};default:{ha=D;ia=C;ja=B;ka=A;la=r;ma=x;break c}}}}while(0);if((E|0)==20){E=0;eb=H&15;E=21}d:do{if((E|0)==21){E=0;F=eb+1|0;G=A;ea=r;fa=x;while(1){if((F|0)==0){ha=D;ia=C;ja=B;ka=G;la=ea;ma=fa;break d}ga=ea+4|0;$=(ga|0)<(n|0);Z=G-1|0;if((Z|0)<0){E=24;break b}else{F=F-1|0;G=Z;ea=$?ga:0;fa=($?0:v)+fa|0}}}}while(0);if((ka|0)==0){break a}else{x=ma;r=la;A=ka;B=ja;C=ia;D=ha}}if((E|0)==14){yDb(c[b>>2]|0,32,2104816,(o=i,i=i+16|0,c[o>>2]=x,c[o+8>>2]=w,o)|0);i=o;break}else if((E|0)==24){yDb(c[b>>2]|0,32,2048120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==30){yDb(c[b>>2]|0,32,2002624,(o=i,i=i+8|0,c[o>>2]=K,o)|0);i=o;break}else if((E|0)==37){yDb(c[b>>2]|0,32,2048120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==43){yDb(c[b>>2]|0,32,1965184,(o=i,i=i+8|0,c[o>>2]=K,o)|0);i=o;break}else if((E|0)==52){yDb(c[b>>2]|0,32,2048120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==62){yDb(c[b>>2]|0,32,2048120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==76){yDb(c[b>>2]|0,32,2048120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==90){yDb(c[b>>2]|0,32,2048120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==108){yDb(c[b>>2]|0,32,2048120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==116){yDb(c[b>>2]|0,32,2048120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);c[f>>2]=1;f=MCb(e,c[j>>2]|0)|0;s=(f|0)<0?f:k;i=h;return s|0}function jYa(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function kYa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+8|0;e=b|0;f=c[a+60>>2]|0;c[e>>2]=0;g=f+3020|0;c[g>>2]=0;h=ICb()|0;j=f+3008|0;c[j>>2]=h;if((h|0)==0){k=-12;i=b;return k|0}h=ICb()|0;c[f+3012>>2]=h;if((h|0)==0){k=-12;i=b;return k|0}c[f+1140>>2]=c[j>>2];if((c[a+100>>2]|0)>3){j=c[a+96>>2]|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[g>>2]=h;l=h}else{l=c[g>>2]|0}if((l|0)<1){yDb(a,16,2104776,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1}else{n=0}l=q0a(8)|0;if((l|0)==0){yDb(a,16,2048096,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;o=-1}else{o=n}n=f+3016|0;c[n>>2]=ARa(l)|0;CBb(e,2002616,1965176,0)|0;f=c[n>>2]|0;c[f+488>>2]=1;c[f+88>>2]=c[a+88>>2];c[f+788>>2]=c[a+788>>2];if((l0a(f,l,e)|0)<0){yDb(a,16,1937128,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;p=-1}else{p=o}DBb(e);k=p;i=b;return k|0}function lYa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;k=c[e+60>>2]|0;l=c[k+3008>>2]|0;m=h+8|0;n=k+3020|0;o=c[n>>2]|0;p=fHb(c[m>>2]|0,c[m+4>>2]|0,o,(o|0)<0|0?-1:0)|0;o=p;do{if((o|0)==0){KCb(l);p=k+3016|0;q=x0a(c[p>>2]|0,l,k+3024|0,h)|0;r=p}else{if((c[k+3024>>2]|0)==0){s=-22;i=j;return s|0}else{q=0;r=k+3016|0;break}}}while(0);h=bFb(c[(c[r>>2]|0)+140>>2]|0)|0;p=l+72|0;do{if((h|0)!=0){if(((c[p>>2]|0)%(c[n>>2]<<(d[h+6|0]|0)|0)|0|0)==0){break}yDb(e,16,2181720,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;s=-1094995529;i=j;return s|0}}while(0);c[g>>2]=c[k+3024>>2];h=e+140|0;c[h>>2]=c[(c[r>>2]|0)+140>>2];U$a(e,c[l+68>>2]|0,(c[p>>2]|0)/(c[n>>2]|0)|0);if((c[g>>2]|0)==0){s=q;i=j;return s|0}q=k+3012|0;c[(c[q>>2]|0)+64>>2]=0;k=c[q>>2]|0;c[k+68>>2]=c[e+120>>2];g=e+124|0;c[k+72>>2]=c[g>>2];e=c[h>>2]|0;c[k+80>>2]=e;h=c[g>>2]|0;g=bFb(e)|0;e=g+7|0;n=a[e]|0;do{if((n&8)==0){p=a[g+4|0]|0;do{if(p<<24>>24==0){t=n}else{r=p&255;m=0;u=0;do{v=(b[g+8+(m<<1)>>1]&3)+1|0;u=(u|0)>(v|0)?u:v;m=m+1|0;}while((m|0)<(r|0));if((u|0)<=0){t=n;break}r=-h|0;m=g+6|0;v=0;do{if((v-1|0)>>>0<2>>>0){w=-(r>>(d[m]|0))|0}else{w=h}x=k+(v<<2)|0;y=c[l+(v<<2)>>2]|0;if(!((x|0)==0|(y|0)==0)){c[x>>2]=y+(ba(ba(w,o)|0,c[l+32+(v<<2)>>2]|0)|0)}v=v+1|0;}while((v|0)<(u|0));t=a[e]|0}}while(0);if((t&66)==0){break}c[k+4>>2]=c[l+4>>2]}}while(0);k=c[q>>2]|0;c[k+32>>2]=c[l+32>>2];c[k+36>>2]=c[l+36>>2];c[k+40>>2]=c[l+40>>2];c[k+44>>2]=c[l+44>>2];c[k+48>>2]=c[l+48>>2];c[k+52>>2]=c[l+52>>2];c[k+56>>2]=c[l+56>>2];c[k+60>>2]=c[l+60>>2];s=MCb(f,k)|0;i=j;return s|0}function mYa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+1140>>2]=0;JCb(b+3008|0);JCb(b+3012|0);a=b+3016|0;D0a(c[a>>2]|0)|0;$Db(a);return 0}function nYa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;c[a+24>>2]=f;c[a+12>>2]=b;c[a+16>>2]=e;c[a+20>>2]=d;f=cEb(b<<2)|0;c[a>>2]=f;if((f|0)==0){g=-12;return g|0}f=WDb(d<<2)|0;b=a+4|0;c[b>>2]=f;if((f|0)==0){$Db(a);g=-12;return g|0}f=e<<1;e=0;while(1){if((e|0)>=(d|0)){h=11;break}i=WDb(f)|0;c[(c[b>>2]|0)+(e<<2)>>2]=i;j=c[b>>2]|0;if((c[j+(e<<2)>>2]|0)==0){break}else{e=e+1|0}}if((h|0)==11){c[a+8>>2]=d-1;g=0;return g|0}a:do{if((e|0)>0){d=e;h=j;while(1){f=d-1|0;$Db(h+(f<<2)|0);if((f|0)<=0){break a}d=f;h=c[b>>2]|0}}}while(0);$Db(b);$Db(a);g=-12;return g|0}function oYa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a+8|0;f=c[e>>2]|0;if(!((f|0)>-1)){yDb(0,0,2220656,(g=i,i=i+24|0,c[g>>2]=2315800,c[g+8>>2]=2181696,c[g+16>>2]=66,g)|0);i=g;Cd();return 0}g=(c[a>>2]|0)+(b<<2)|0;b=c[g>>2]|0;if((b|0)!=0){h=b;i=d;return h|0}b=c[(c[a+4>>2]|0)+(f<<2)>>2]|0;c[e>>2]=f-1;c[g>>2]=b;h=b;i=d;return h|0}function pYa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a|0;e=c[(c[d>>2]|0)+(b<<2)>>2]|0;f=a+8|0;g=(c[f>>2]|0)+1|0;c[f>>2]=g;c[(c[a+4>>2]|0)+(g<<2)>>2]=e;c[(c[d>>2]|0)+(b<<2)>>2]=0;return}function qYa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+12>>2]|0;if((b|0)<=0){return}d=a|0;e=a+8|0;f=a+4|0;a=0;do{g=c[(c[d>>2]|0)+(a<<2)>>2]|0;if((g|0)!=0){h=(c[e>>2]|0)+1|0;c[e>>2]=h;c[(c[f>>2]|0)+(h<<2)>>2]=g;c[(c[d>>2]|0)+(a<<2)>>2]=0}a=a+1|0;}while((a|0)<(b|0));return}function rYa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+12>>2]|0;if((b|0)>0){d=a|0;e=a+8|0;f=a+4|0;g=0;while(1){h=c[(c[d>>2]|0)+(g<<2)>>2]|0;if((h|0)!=0){i=(c[e>>2]|0)+1|0;c[e>>2]=i;c[(c[f>>2]|0)+(i<<2)>>2]=h;c[(c[d>>2]|0)+(g<<2)>>2]=0}h=g+1|0;if((h|0)<(b|0)){g=h}else{j=f;break}}}else{j=a+4|0}f=c[a+20>>2]|0;if((f|0)>0){k=f}else{l=j;$Db(l);m=a;$Db(m);return}do{k=k-1|0;$Db((c[j>>2]|0)+(k<<2)|0);}while((k|0)>0);l=j;$Db(l);m=a;$Db(m);return}function sYa(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((h|0)>0){i=0}else{return}do{a:do{if((g|0)==0){j=d>>i;k=e>>i;l=f<<i;m=k-1|0;if(m>>>0<4294967291>>>0){n=m<<1;o=-5;while(1){p=((o|0)>0?n:0)-o|0;if(p>>>0>m>>>0){o=p}else{q=p;break}}}else{q=-5}o=a+((ba(q,l)|0)<<2)|0;if(m>>>0<4294967292>>>0){n=m<<1;p=-4;while(1){r=((p|0)>0?n:0)-p|0;if(r>>>0>m>>>0){p=r}else{s=r;break}}}else{s=-4}p=a+((ba(s,l)|0)<<2)|0;if(m>>>0<4294967293>>>0){n=m<<1;r=-3;while(1){t=((r|0)>0?n:0)-r|0;if(t>>>0>m>>>0){r=t}else{u=t;break}}}else{u=-3}r=a+((ba(u,l)|0)<<2)|0;n=m<<1;if(m>>>0<4294967294>>>0){t=-2;do{t=((t|0)>0?n:0)-t|0;}while(t>>>0>m>>>0);if((k|0)>-4){v=t}else{break}}else{v=-2}w=(j|0)>0;x=p;y=r;z=a+((ba(v,l)|0)<<2)|0;A=o;B=-4;while(1){C=B+3|0;if(C>>>0>m>>>0){D=C;while(1){E=((D|0)>0?n:0)-D|0;if(E>>>0>m>>>0){D=E}else{F=E;break}}}else{F=C}D=ba(F,l)|0;E=a+(D<<2)|0;G=B+4|0;if(G>>>0>m>>>0){H=G;while(1){I=((H|0)>0?n:0)-H|0;if(I>>>0>m>>>0){H=I}else{J=I;break}}}else{J=G}H=ba(J,l)|0;I=a+(H<<2)|0;K=C>>>0<k>>>0;if(K){JYa(E,b,j)}if(G>>>0<k>>>0){JYa(I,b,j)}if(K&w){K=0;do{L=a+(K+D<<2)|0;c[L>>2]=(c[L>>2]|0)-((((c[a+(K+H<<2)>>2]|0)+(c[z+(K<<2)>>2]|0)|0)*3|0)>>1);K=K+1|0;}while((K|0)<(j|0))}K=B+2|0;if(K>>>0<k>>>0&w){H=0;do{G=z+(H<<2)|0;c[G>>2]=(((c[G>>2]<<6)+671088680-((c[a+(H+D<<2)>>2]|0)+(c[y+(H<<2)>>2]|0)<<2)|0)/80|0)-8388608;H=H+1|0;}while((H|0)<(j|0))}if((B|1)>>>0<k>>>0&w){H=0;do{D=y+(H<<2)|0;c[D>>2]=(c[z+(H<<2)>>2]|0)+(c[x+(H<<2)>>2]|0)+(c[D>>2]|0);H=H+1|0;}while((H|0)<(j|0))}if(B>>>0<k>>>0&w){H=0;do{D=x+(H<<2)|0;c[D>>2]=((((c[y+(H<<2)>>2]|0)+(c[A+(H<<2)>>2]|0)|0)*3|0)+4>>3)+(c[D>>2]|0);H=H+1|0;}while((H|0)<(j|0))}if((K|0)<(k|0)){x=z;A=y;y=E;z=I;B=K}else{break}}}else if((g|0)==1){B=d>>i;z=e>>i;y=f<<i;A=z-1|0;if(A>>>0<4294967293>>>0){x=A<<1;k=-3;while(1){j=((k|0)>0?x:0)-k|0;if(j>>>0>A>>>0){k=j}else{M=j;break}}}else{M=-3}k=a+((ba(M,y)|0)<<2)|0;if(A>>>0<4294967294>>>0){x=A<<1;j=-2;do{j=((j|0)>0?x:0)-j|0;}while(j>>>0>A>>>0);w=ba(j,y)|0;if((z|0)>-2){N=w;O=x}else{break}}else{N=y*-2|0;O=A<<1}if((B|0)<=0){w=-2;while(1){l=w|1;if(l>>>0>A>>>0){m=l;while(1){n=((m|0)>0?O:0)-m|0;if(n>>>0>A>>>0){m=n}else{P=n;break}}}else{P=l}m=a+((ba(P,y)|0)<<2)|0;w=w+2|0;if(w>>>0>A>>>0){K=w;while(1){I=((K|0)>0?O:0)-K|0;if(I>>>0>A>>>0){K=I}else{Q=I;break}}}else{Q=w}K=a+((ba(Q,y)|0)<<2)|0;if(l>>>0<z>>>0){IYa(m,b,B)}if(w>>>0<z>>>0){IYa(K,b,B)}if((w|0)>=(z|0)){break a}}}w=a+(N<<2)|0;x=k;j=-2;while(1){K=j|1;if(K>>>0>A>>>0){I=K;while(1){E=((I|0)>0?O:0)-I|0;if(E>>>0>A>>>0){I=E}else{R=E;break}}}else{R=K}I=ba(R,y)|0;m=a+(I<<2)|0;l=j+2|0;if(l>>>0>A>>>0){E=l;while(1){n=((E|0)>0?O:0)-E|0;if(n>>>0>A>>>0){E=n}else{S=n;break}}}else{S=l}E=ba(S,y)|0;n=a+(E<<2)|0;o=K>>>0<z>>>0;if(o){IYa(m,b,B)}if(l>>>0<z>>>0){IYa(n,b,B)}if(o){o=0;do{r=a+(o+I<<2)|0;c[r>>2]=(c[r>>2]|0)-((c[a+(o+E<<2)>>2]|0)+(c[w+(o<<2)>>2]|0)>>1);o=o+1|0;}while((o|0)<(B|0))}if(j>>>0<z>>>0){o=0;do{E=w+(o<<2)|0;c[E>>2]=((c[x+(o<<2)>>2]|0)+2+(c[a+(o+I<<2)>>2]|0)>>2)+(c[E>>2]|0);o=o+1|0;}while((o|0)<(B|0))}if((l|0)<(z|0)){w=n;x=m;j=l}else{break}}}}while(0);i=i+1|0;}while((i|0)<(h|0));return}function tYa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=d+1>>1;b[c>>1]=(e[a>>1]|0)-((((b[a+(f<<1)>>1]|0)*3|0)+2|0)>>>2);g=d>>1;if((g|0)>1){h=1;while(1){i=h+f|0;j=a+(i-1<<1)|0;k=(e[a+(h<<1)>>1]|0)-(((((b[a+(i<<1)>>1]|0)+(b[j>>1]|0)|0)*3|0)+4|0)>>>3)&65535;i=h<<1;b[c+(i<<1)>>1]=k;b[c+(i-1<<1)>>1]=((b[j>>1]|0)-(b[c+(i-2<<1)>>1]|0)&65535)-k;k=h+1|0;if((k|0)<(g|0)){h=k}else{l=g;break}}}else{l=1}g=(d&1|0)!=0;if(g){h=a+(f-1+l<<1)|0;k=(e[a+(l<<1)>>1]|0)-((((b[h>>1]|0)*3|0)+2|0)>>>2)&65535;i=l<<1;b[c+(i<<1)>>1]=k;b[c+(i-1<<1)>>1]=((b[h>>1]|0)-(b[c+(i-2<<1)>>1]|0)&65535)-k}else{k=l<<1;b[c+(k-1<<1)>>1]=(b[a+(f-1+l<<1)>>1]|0)-(b[c+(k-2<<1)>>1]<<1)}k=b[c>>1]|0;l=(((b[c+2>>1]|0)+4+(k<<1)|0)>>>3)+k&65535;b[a>>1]=l;k=d-1|0;if((k|0)>2){d=2;f=l;while(1){i=b[c+(d<<1)>>1]|0;h=d-1|0;j=c+(h<<1)|0;m=(((b[j>>1]|0)+8+(i<<2)+(b[c+((d|1)<<1)>>1]|0)|0)>>>4)+i&65535;b[a+(d<<1)>>1]=m;b[a+(h<<1)>>1]=((((m<<16>>16)+(f<<16>>16)|0)*3|0)>>>1)+(e[j>>1]|0);j=d+2|0;if((j|0)<(k|0)){d=j;f=m}else{n=j;o=m;break}}}else{n=2;o=l}if(g){g=b[c+(n<<1)>>1]|0;l=n-1|0;f=c+(l<<1)|0;d=(((b[f>>1]|0)+4+(g<<1)|0)>>>3)+g&65535;b[a+(n<<1)>>1]=d;b[a+(l<<1)>>1]=((((d<<16>>16)+(o<<16>>16)|0)*3|0)>>>1)+(e[f>>1]|0);return}else{f=n-1|0;b[a+(f<<1)>>1]=(o*3&65535)+(b[c+(f<<1)>>1]|0);return}}function uYa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;if((i|0)>0){j=0}else{return}do{k=f+(j<<1)|0;l=g+(j<<1)|0;m=(e[l>>1]|0)-(((((b[h+(j<<1)>>1]|0)+(b[k>>1]|0)|0)*3|0)+4|0)>>>3)&65535;b[l>>1]=m;l=d+(j<<1)|0;n=((b[k>>1]|0)-(b[l>>1]|0)&65535)-m&65535;b[k>>1]=n;k=c+(j<<1)|0;m=b[l>>1]|0;o=(((b[k>>1]|0)+8+(m<<2)+(n<<16>>16)|0)>>>4)+m&65535;b[l>>1]=o;b[k>>1]=((((o<<16>>16)+(b[a+(j<<1)>>1]|0)|0)*3|0)>>>1)+(e[k>>1]|0);j=j+1|0;}while((j|0)<(i|0));return}function vYa(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=i;if((h|0)<=0){i=d;return}j=b|0;k=b+8|0;l=b+4|0;b=h;a:while(1){h=b-1|0;if((g|0)==0){m=e>>h;n=f<<h;o=m-1|0;do{if(o>>>0<4294967292>>>0){p=o<<1;q=-4;do{q=((q|0)>0?p:0)-q|0;}while(q>>>0>o>>>0);r=ba(q,n)|0;s=c[j>>2]|0;t=c[s+(r<<2)>>2]|0;r=-4;do{r=((r|0)>0?p:0)-r|0;}while(r>>>0>o>>>0);p=ba(r,n)|0;if((t|0)==0){u=p;v=s;w=13;break}x=c[s+(p<<2)>>2]|0}else{p=n*-4|0;q=c[j>>2]|0;y=c[q+(p<<2)>>2]|0;if((y|0)==0){u=p;v=q;w=13}else{x=y}}}while(0);do{if((w|0)==13){w=0;y=c[k>>2]|0;if(!((y|0)>-1)){w=14;break a}q=v+(u<<2)|0;p=c[q>>2]|0;if((p|0)!=0){x=p;break}p=c[(c[l>>2]|0)+(y<<2)>>2]|0;c[k>>2]=y-1;c[q>>2]=p;x=p}}while(0);c[a+(h*20|0)>>2]=x;do{if(o>>>0<4294967293>>>0){p=o<<1;q=-3;do{q=((q|0)>0?p:0)-q|0;}while(q>>>0>o>>>0);s=ba(q,n)|0;t=c[j>>2]|0;r=c[t+(s<<2)>>2]|0;s=-3;do{s=((s|0)>0?p:0)-s|0;}while(s>>>0>o>>>0);p=ba(s,n)|0;if((r|0)==0){z=p;A=t;w=25;break}B=c[t+(p<<2)>>2]|0}else{p=n*-3|0;q=c[j>>2]|0;y=c[q+(p<<2)>>2]|0;if((y|0)==0){z=p;A=q;w=25}else{B=y}}}while(0);do{if((w|0)==25){w=0;y=c[k>>2]|0;if(!((y|0)>-1)){w=26;break a}q=A+(z<<2)|0;p=c[q>>2]|0;if((p|0)!=0){B=p;break}p=c[(c[l>>2]|0)+(y<<2)>>2]|0;c[k>>2]=y-1;c[q>>2]=p;B=p}}while(0);c[a+(h*20|0)+4>>2]=B;do{if(o>>>0<4294967294>>>0){p=o<<1;q=-2;do{q=((q|0)>0?p:0)-q|0;}while(q>>>0>o>>>0);t=ba(q,n)|0;r=c[j>>2]|0;s=c[r+(t<<2)>>2]|0;t=-2;do{t=((t|0)>0?p:0)-t|0;}while(t>>>0>o>>>0);p=ba(t,n)|0;if((s|0)==0){C=p;D=r;w=37;break}E=c[r+(p<<2)>>2]|0}else{p=n*-2|0;q=c[j>>2]|0;y=c[q+(p<<2)>>2]|0;if((y|0)==0){C=p;D=q;w=37}else{E=y}}}while(0);do{if((w|0)==37){w=0;y=c[k>>2]|0;if(!((y|0)>-1)){w=38;break a}q=D+(C<<2)|0;p=c[q>>2]|0;if((p|0)!=0){E=p;break}p=c[(c[l>>2]|0)+(y<<2)>>2]|0;c[k>>2]=y-1;c[q>>2]=p;E=p}}while(0);c[a+(h*20|0)+8>>2]=E;do{if((m|0)==0){p=-n|0;q=c[j>>2]|0;y=c[q+(p<<2)>>2]|0;if((y|0)==0){F=p;G=q;w=49}else{H=y}}else{y=o<<1;q=-1;do{q=((q|0)>0?y:0)-q|0;}while(q>>>0>o>>>0);r=ba(q,n)|0;s=c[j>>2]|0;t=c[s+(r<<2)>>2]|0;r=-1;do{r=((r|0)>0?y:0)-r|0;}while(r>>>0>o>>>0);y=ba(r,n)|0;if((t|0)==0){F=y;G=s;w=49;break}H=c[s+(y<<2)>>2]|0}}while(0);do{if((w|0)==49){w=0;n=c[k>>2]|0;if(!((n|0)>-1)){w=50;break a}o=G+(F<<2)|0;m=c[o>>2]|0;if((m|0)!=0){H=m;break}m=c[(c[l>>2]|0)+(n<<2)>>2]|0;c[k>>2]=n-1;c[o>>2]=m;H=m}}while(0);c[a+(h*20|0)+12>>2]=H;c[a+(h*20|0)+16>>2]=-3}else if((g|0)==1){m=e>>h;o=f<<h;n=m-1|0;do{if(n>>>0<4294967294>>>0){y=n<<1;q=-2;do{q=((q|0)>0?y:0)-q|0;}while(q>>>0>n>>>0);s=ba(q,o)|0;t=c[j>>2]|0;r=c[t+(s<<2)>>2]|0;s=-2;do{s=((s|0)>0?y:0)-s|0;}while(s>>>0>n>>>0);y=ba(s,o)|0;if((r|0)==0){I=y;J=t;w=62;break}K=c[t+(y<<2)>>2]|0}else{y=o*-2|0;q=c[j>>2]|0;p=c[q+(y<<2)>>2]|0;if((p|0)==0){I=y;J=q;w=62}else{K=p}}}while(0);do{if((w|0)==62){w=0;p=c[k>>2]|0;if(!((p|0)>-1)){w=63;break a}q=J+(I<<2)|0;y=c[q>>2]|0;if((y|0)!=0){K=y;break}y=c[(c[l>>2]|0)+(p<<2)>>2]|0;c[k>>2]=p-1;c[q>>2]=y;K=y}}while(0);c[a+(h*20|0)>>2]=K;do{if((m|0)==0){y=-o|0;q=c[j>>2]|0;p=c[q+(y<<2)>>2]|0;if((p|0)==0){L=y;M=q;w=74}else{N=p}}else{p=n<<1;q=-1;do{q=((q|0)>0?p:0)-q|0;}while(q>>>0>n>>>0);t=ba(q,o)|0;r=c[j>>2]|0;s=c[r+(t<<2)>>2]|0;t=-1;do{t=((t|0)>0?p:0)-t|0;}while(t>>>0>n>>>0);p=ba(t,o)|0;if((s|0)==0){L=p;M=r;w=74;break}N=c[r+(p<<2)>>2]|0}}while(0);do{if((w|0)==74){w=0;o=c[k>>2]|0;if(!((o|0)>-1)){w=75;break a}n=M+(L<<2)|0;m=c[n>>2]|0;if((m|0)!=0){N=m;break}m=c[(c[l>>2]|0)+(o<<2)>>2]|0;c[k>>2]=o-1;c[n>>2]=m;N=m}}while(0);c[a+(h*20|0)+4>>2]=N;c[a+(h*20|0)+16>>2]=-1}if((h|0)>0){b=h}else{w=79;break}}if((w|0)==14){yDb(0,0,2220656,(O=i,i=i+24|0,c[O>>2]=2315800,c[O+8>>2]=2181696,c[O+16>>2]=66,O)|0);i=O;Cd()}else if((w|0)==26){yDb(0,0,2220656,(O=i,i=i+24|0,c[O>>2]=2315800,c[O+8>>2]=2181696,c[O+16>>2]=66,O)|0);i=O;Cd()}else if((w|0)==38){yDb(0,0,2220656,(O=i,i=i+24|0,c[O>>2]=2315800,c[O+8>>2]=2181696,c[O+16>>2]=66,O)|0);i=O;Cd()}else if((w|0)==50){yDb(0,0,2220656,(O=i,i=i+24|0,c[O>>2]=2315800,c[O+8>>2]=2181696,c[O+16>>2]=66,O)|0);i=O;Cd()}else if((w|0)==63){yDb(0,0,2220656,(O=i,i=i+24|0,c[O>>2]=2315800,c[O+8>>2]=2181696,c[O+16>>2]=66,O)|0);i=O;Cd()}else if((w|0)==75){yDb(0,0,2220656,(O=i,i=i+24|0,c[O>>2]=2315800,c[O+8>>2]=2181696,c[O+16>>2]=66,O)|0);i=O;Cd()}else if((w|0)==79){i=d;return}}function wYa(a,d,f,g,h,j,k,l,m,n){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;o=i;p=(l|0)==1?3:5;if(!((l|0)!=2&(m|0)>0)){i=o;return}q=f|0;r=f+8|0;s=f+4|0;f=a|0;t=a+4|0;a=m;a:while(1){m=a-1|0;u=d+(m*20|0)+16|0;v=c[u>>2]|0;w=(n>>m)+p|0;x=j>>m;y=(w|0)>(x|0)?x:w;if((v|0)<=(y|0)){w=h>>m;z=k<<m;A=d+(m*20|0)|0;B=d+(m*20|0)+4|0;C=d+(m*20|0)+8|0;D=d+(m*20|0)+12|0;E=x-1|0;F=E<<1;G=(w|0)>0;H=v;while(1){if((l|0)==1){v=c[A>>2]|0;I=c[B>>2]|0;J=H+1|0;do{if(J>>>0>E>>>0){K=J;do{K=((K|0)>0?F:0)-K|0;}while(K>>>0>E>>>0);L=ba(K,z)|0;M=c[q>>2]|0;N=c[M+(L<<2)>>2]|0;L=J;do{L=((L|0)>0?F:0)-L|0;}while(L>>>0>E>>>0);K=ba(L,z)|0;if((N|0)==0){O=K;P=M;Q=51;break}R=c[M+(K<<2)>>2]|0}else{K=ba(J,z)|0;S=c[q>>2]|0;T=c[S+(K<<2)>>2]|0;if((T|0)==0){O=K;P=S;Q=51}else{R=T}}}while(0);do{if((Q|0)==51){Q=0;T=c[r>>2]|0;if(!((T|0)>-1)){Q=52;break a}S=P+(O<<2)|0;K=c[S>>2]|0;if((K|0)!=0){R=K;break}K=c[(c[s>>2]|0)+(T<<2)>>2]|0;c[r>>2]=T-1;c[S>>2]=K;R=K}}while(0);K=H+2|0;do{if(K>>>0>E>>>0){S=K;do{S=((S|0)>0?F:0)-S|0;}while(S>>>0>E>>>0);M=ba(S,z)|0;N=c[q>>2]|0;L=c[N+(M<<2)>>2]|0;M=K;do{M=((M|0)>0?F:0)-M|0;}while(M>>>0>E>>>0);S=ba(M,z)|0;if((L|0)==0){U=S;V=N;Q=62;break}W=c[N+(S<<2)>>2]|0}else{S=ba(K,z)|0;T=c[q>>2]|0;X=c[T+(S<<2)>>2]|0;if((X|0)==0){U=S;V=T;Q=62}else{W=X}}}while(0);do{if((Q|0)==62){Q=0;K=c[r>>2]|0;if(!((K|0)>-1)){Q=63;break a}X=V+(U<<2)|0;T=c[X>>2]|0;if((T|0)!=0){W=T;break}T=c[(c[s>>2]|0)+(K<<2)>>2]|0;c[r>>2]=K-1;c[X>>2]=T;W=T}}while(0);T=J>>>0<x>>>0;X=H>>>0<x>>>0;do{if(T&X){if(G){Y=0}else{break}do{K=I+(Y<<1)|0;S=R+(Y<<1)|0;Z=(e[S>>1]|0)-(((b[K>>1]|0)+2+(b[W+(Y<<1)>>1]|0)|0)>>>2)&65535;b[S>>1]=Z;b[K>>1]=(((Z<<16>>16)+(b[v+(Y<<1)>>1]|0)|0)>>>1)+(e[K>>1]|0);Y=Y+1|0;}while((Y|0)<(w|0))}else{if(T&G){N=0;do{L=R+(N<<1)|0;b[L>>1]=(e[L>>1]|0)-(((b[I+(N<<1)>>1]|0)+2+(b[W+(N<<1)>>1]|0)|0)>>>2);N=N+1|0;}while((N|0)<(w|0))}if(X&G){_=0}else{break}do{N=I+(_<<1)|0;b[N>>1]=(((b[R+(_<<1)>>1]|0)+(b[v+(_<<1)>>1]|0)|0)>>>1)+(e[N>>1]|0);_=_+1|0;}while((_|0)<(w|0))}}while(0);if((H-1|0)>>>0<x>>>0){HYa(v,g,w)}if(X){HYa(I,g,w)}c[A>>2]=R;c[B>>2]=W;T=(c[u>>2]|0)+2|0;c[u>>2]=T;$=T}else if((l|0)==0){T=c[A>>2]|0;J=c[B>>2]|0;N=c[C>>2]|0;L=c[D>>2]|0;M=H+3|0;do{if(M>>>0>E>>>0){K=M;do{K=((K|0)>0?F:0)-K|0;}while(K>>>0>E>>>0);Z=ba(K,z)|0;S=c[q>>2]|0;aa=c[S+(Z<<2)>>2]|0;Z=M;do{Z=((Z|0)>0?F:0)-Z|0;}while(Z>>>0>E>>>0);K=ba(Z,z)|0;if((aa|0)==0){ca=K;da=S;Q=14;break}ea=c[S+(K<<2)>>2]|0}else{K=ba(M,z)|0;fa=c[q>>2]|0;ga=c[fa+(K<<2)>>2]|0;if((ga|0)==0){ca=K;da=fa;Q=14}else{ea=ga}}}while(0);do{if((Q|0)==14){Q=0;I=c[r>>2]|0;if(!((I|0)>-1)){Q=15;break a}X=da+(ca<<2)|0;v=c[X>>2]|0;if((v|0)!=0){ea=v;break}v=c[(c[s>>2]|0)+(I<<2)>>2]|0;c[r>>2]=I-1;c[X>>2]=v;ea=v}}while(0);v=H+4|0;do{if(v>>>0>E>>>0){X=v;do{X=((X|0)>0?F:0)-X|0;}while(X>>>0>E>>>0);S=ba(X,z)|0;aa=c[q>>2]|0;Z=c[aa+(S<<2)>>2]|0;S=v;do{S=((S|0)>0?F:0)-S|0;}while(S>>>0>E>>>0);X=ba(S,z)|0;if((Z|0)==0){ha=X;ia=aa;Q=25;break}ja=c[aa+(X<<2)>>2]|0}else{X=ba(v,z)|0;I=c[q>>2]|0;ga=c[I+(X<<2)>>2]|0;if((ga|0)==0){ha=X;ia=I;Q=25}else{ja=ga}}}while(0);do{if((Q|0)==25){Q=0;ga=c[r>>2]|0;if(!((ga|0)>-1)){Q=26;break a}I=ia+(ha<<2)|0;X=c[I>>2]|0;if((X|0)!=0){ja=X;break}X=c[(c[s>>2]|0)+(ga<<2)>>2]|0;c[r>>2]=ga-1;c[I>>2]=X;ja=X}}while(0);do{if((H|0)>0&(v|0)<(x|0)){Ke[c[f>>2]&1023](T,J,N,L,ea,ja,w)}else{if(M>>>0<x>>>0&G){X=0;do{I=ea+(X<<1)|0;b[I>>1]=(e[I>>1]|0)-(((((b[ja+(X<<1)>>1]|0)+(b[L+(X<<1)>>1]|0)|0)*3|0)+4|0)>>>3);X=X+1|0;}while((X|0)<(w|0))}if((H+2|0)>>>0<x>>>0&G){X=0;do{aa=L+(X<<1)|0;b[aa>>1]=(b[aa>>1]|0)-((b[ea+(X<<1)>>1]|0)+(b[N+(X<<1)>>1]|0)&65535);X=X+1|0;}while((X|0)<(w|0))}if((H+1|0)>>>0<x>>>0&G){X=0;do{aa=N+(X<<1)|0;Z=b[aa>>1]|0;b[aa>>1]=(((b[J+(X<<1)>>1]|0)+8+(b[L+(X<<1)>>1]|0)+(Z<<2)|0)>>>4)+Z;X=X+1|0;}while((X|0)<(w|0))}if(H>>>0<x>>>0&G){ka=0}else{break}do{X=J+(ka<<1)|0;b[X>>1]=((((b[N+(ka<<1)>>1]|0)+(b[T+(ka<<1)>>1]|0)|0)*3|0)>>>1)+(e[X>>1]|0);ka=ka+1|0;}while((ka|0)<(w|0))}}while(0);if((H-1|0)>>>0<x>>>0){Xe[c[t>>2]&4095](T,g,w)}if(H>>>0<x>>>0){Xe[c[t>>2]&4095](J,g,w)}c[A>>2]=N;c[B>>2]=L;c[C>>2]=ea;c[D>>2]=ja;M=(c[u>>2]|0)+2|0;c[u>>2]=M;$=M}else{$=H}if(($|0)>(y|0)){break}else{H=$}}}if((m|0)>0){a=m}else{Q=79;break}}if((Q|0)==15){yDb(0,0,2220656,(la=i,i=i+24|0,c[la>>2]=2315800,c[la+8>>2]=2181696,c[la+16>>2]=66,la)|0);i=la;Cd()}else if((Q|0)==26){yDb(0,0,2220656,(la=i,i=i+24|0,c[la>>2]=2315800,c[la+8>>2]=2181696,c[la+16>>2]=66,la)|0);i=la;Cd()}else if((Q|0)==52){yDb(0,0,2220656,(la=i,i=i+24|0,c[la>>2]=2315800,c[la+8>>2]=2181696,c[la+16>>2]=66,la)|0);i=la;Cd()}else if((Q|0)==63){yDb(0,0,2220656,(la=i,i=i+24|0,c[la>>2]=2315800,c[la+8>>2]=2181696,c[la+16>>2]=66,la)|0);i=la;Cd()}else if((Q|0)==79){i=o;return}}function xYa(a,d,f,g,h,j,k){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;l=i;i=i+160|0;m=l|0;n=(k|0)>0;if(n){o=k;do{o=o-1|0;if((j|0)==1){p=g>>o;q=h<<o;r=p-1|0;if(r>>>0<4294967294>>>0){s=r<<1;t=-2;while(1){u=((t|0)>0?s:0)-t|0;if(u>>>0>r>>>0){t=u}else{v=u;break}}}else{v=-2}c[m+(o*20|0)>>2]=a+((ba(v,q)|0)<<1);if((p|0)==0){w=-1}else{t=r<<1;s=-1;while(1){u=((s|0)>0?t:0)-s|0;if(u>>>0>r>>>0){s=u}else{w=u;break}}}c[m+(o*20|0)+4>>2]=a+((ba(w,q)|0)<<1);c[m+(o*20|0)+16>>2]=-1}else if((j|0)==0){s=g>>o;r=h<<o;t=s-1|0;if(t>>>0<4294967292>>>0){p=t<<1;u=-4;while(1){x=((u|0)>0?p:0)-u|0;if(x>>>0>t>>>0){u=x}else{y=x;break}}}else{y=-4}c[m+(o*20|0)>>2]=a+((ba(y,r)|0)<<1);if(t>>>0<4294967293>>>0){u=t<<1;p=-3;while(1){q=((p|0)>0?u:0)-p|0;if(q>>>0>t>>>0){p=q}else{z=q;break}}}else{z=-3}c[m+(o*20|0)+4>>2]=a+((ba(z,r)|0)<<1);if(t>>>0<4294967294>>>0){p=t<<1;u=-2;while(1){q=((u|0)>0?p:0)-u|0;if(q>>>0>t>>>0){u=q}else{A=q;break}}}else{A=-2}c[m+(o*20|0)+8>>2]=a+((ba(A,r)|0)<<1);if((s|0)==0){B=-1}else{u=t<<1;p=-1;while(1){q=((p|0)>0?u:0)-p|0;if(q>>>0>t>>>0){p=q}else{B=q;break}}}c[m+(o*20|0)+12>>2]=a+((ba(B,r)|0)<<1);c[m+(o*20|0)+16>>2]=-3}}while((o|0)>0)}if((g|0)<=0){i=l;return}o=(j|0)==1?3:5;B=(j|0)!=2&n;n=0;do{if(B){A=k;do{A=A-1|0;z=m+(A*20|0)+16|0;y=c[z>>2]|0;w=(n>>A)+o|0;v=g>>A;p=(w|0)>(v|0)?v:w;if((y|0)<=(p|0)){w=f>>A;t=h<<A;u=m+(A*20|0)|0;s=m+(A*20|0)+4|0;q=m+(A*20|0)+8|0;x=m+(A*20|0)+12|0;C=v-1|0;D=C<<1;E=(w|0)>0;F=y;while(1){if((j|0)==1){y=c[u>>2]|0;G=c[s>>2]|0;H=F+1|0;if(H>>>0>C>>>0){I=H;while(1){J=((I|0)>0?D:0)-I|0;if(J>>>0>C>>>0){I=J}else{K=J;break}}}else{K=H}I=ba(K,t)|0;J=a+(I<<1)|0;L=F+2|0;if(L>>>0>C>>>0){M=L;while(1){N=((M|0)>0?D:0)-M|0;if(N>>>0>C>>>0){M=N}else{O=N;break}}}else{O=L}M=ba(O,t)|0;N=a+(M<<1)|0;if(H>>>0<v>>>0&E){P=0;do{Q=a+(P+I<<1)|0;b[Q>>1]=(e[Q>>1]|0)-(((b[G+(P<<1)>>1]|0)+2+(b[a+(P+M<<1)>>1]|0)|0)>>>2);P=P+1|0;}while((P|0)<(w|0))}P=F>>>0<v>>>0;if(P&E){M=0;do{H=G+(M<<1)|0;b[H>>1]=(((b[a+(M+I<<1)>>1]|0)+(b[y+(M<<1)>>1]|0)|0)>>>1)+(e[H>>1]|0);M=M+1|0;}while((M|0)<(w|0))}if((F-1|0)>>>0<v>>>0){HYa(y,d,w)}if(P){HYa(G,d,w)}c[u>>2]=J;c[s>>2]=N;c[z>>2]=L;R=L}else if((j|0)==0){M=c[u>>2]|0;I=c[s>>2]|0;H=c[q>>2]|0;Q=c[x>>2]|0;S=F+3|0;if(S>>>0>C>>>0){T=S;while(1){U=((T|0)>0?D:0)-T|0;if(U>>>0>C>>>0){T=U}else{V=U;break}}}else{V=S}T=ba(V,t)|0;L=a+(T<<1)|0;N=F+4|0;if(N>>>0>C>>>0){J=N;while(1){G=((J|0)>0?D:0)-J|0;if(G>>>0>C>>>0){J=G}else{W=G;break}}}else{W=N}J=ba(W,t)|0;G=a+(J<<1)|0;if(S>>>0<v>>>0&E){P=0;do{y=a+(P+T<<1)|0;b[y>>1]=(e[y>>1]|0)-(((((b[a+(P+J<<1)>>1]|0)+(b[Q+(P<<1)>>1]|0)|0)*3|0)+4|0)>>>3);P=P+1|0;}while((P|0)<(w|0))}P=F+2|0;if(P>>>0<v>>>0&E){J=0;do{S=Q+(J<<1)|0;b[S>>1]=(b[S>>1]|0)-((b[a+(J+T<<1)>>1]|0)+(b[H+(J<<1)>>1]|0)&65535);J=J+1|0;}while((J|0)<(w|0))}if((F+1|0)>>>0<v>>>0&E){J=0;do{T=H+(J<<1)|0;S=b[T>>1]|0;b[T>>1]=(((b[I+(J<<1)>>1]|0)+8+(b[Q+(J<<1)>>1]|0)+(S<<2)|0)>>>4)+S;J=J+1|0;}while((J|0)<(w|0))}J=F>>>0<v>>>0;if(J&E){S=0;do{T=I+(S<<1)|0;b[T>>1]=((((b[H+(S<<1)>>1]|0)+(b[M+(S<<1)>>1]|0)|0)*3|0)>>>1)+(e[T>>1]|0);S=S+1|0;}while((S|0)<(w|0))}if((F-1|0)>>>0<v>>>0){tYa(M,d,w)}if(J){tYa(I,d,w)}c[u>>2]=H;c[s>>2]=Q;c[q>>2]=L;c[x>>2]=G;c[z>>2]=P;R=P}else{R=F}if((R|0)>(p|0)){break}else{F=R}}}}while((A|0)>0)}n=n+4|0;}while((n|0)<(g|0));i=l;return}function yYa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zYa(b,c,d,32,e,1)|0}function zYa(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;i=i+4224|0;k=j|0;l=j+4096|0;m=(f|0)==8?3:4;if((g|0)>0){n=(f|0)>0;o=0;p=b;b=a;while(1){if(n){a=o<<5;q=0;do{r=q+a|0;c[k+(r<<2)>>2]=(d[b+q|0]|0)-(d[p+q|0]|0)<<4;s=q|1;c[k+((r|1)<<2)>>2]=(d[b+s|0]|0)-(d[p+s|0]|0)<<4;s=q|2;c[k+((r|2)<<2)>>2]=(d[b+s|0]|0)-(d[p+s|0]|0)<<4;s=q|3;c[k+((r|3)<<2)>>2]=(d[b+s|0]|0)-(d[p+s|0]|0)<<4;q=q+4|0;}while((q|0)<(f|0))}q=o+1|0;if((q|0)<(g|0)){o=q;p=p+e|0;b=b+e|0}else{break}}}sYa(k|0,l|0,f,g,32,h,m);g=m-3|0;l=0;e=0;while(1){b=m-l|0;p=f>>b;o=32<<b;b=o>>1;n=(p|0)>0;q=(l|0)!=0|0;a=e;while(1){if(n){s=((q&1|0)!=0?p:0)+((q&2|0)==0?0:b)|0;r=58264+(h<<7)+(g<<6)+(l<<4)+(q<<2)|0;t=0;u=a;while(1){v=s+(ba(t,o)|0)|0;w=c[r>>2]|0;x=0;y=u;do{z=ba(w,c[k+(v+x<<2)>>2]|0)|0;y=((z|0)>-1?z:-z|0)+y|0;x=x+1|0;}while((x|0)<(p|0));x=t+1|0;if((x|0)<(p|0)){t=x;u=y}else{A=y;break}}}else{A=a}u=q+1|0;if((u|0)<4){q=u;a=A}else{break}}a=l+1|0;if((a|0)<(m|0)){l=a;e=A}else{break}}i=j;return A>>9|0}function AYa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zYa(b,c,d,32,e,0)|0}function BYa(a){a=a|0;c[a+292>>2]=126;c[a+296>>2]=120;c[a+316>>2]=144;c[a+320>>2]=94;return}function CYa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zYa(b,c,d,16,e,1)|0}function DYa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zYa(b,c,d,8,e,1)|0}function EYa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zYa(b,c,d,16,e,0)|0}function FYa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zYa(b,c,d,8,e,0)|0}function GYa(a){a=a|0;c[a>>2]=188;c[a+4>>2]=1028;c[a+8>>2]=28;return}function HYa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d>>1;g=d+1>>1;if((f|0)>0){h=0;while(1){i=h<<1;b[c+(i<<1)>>1]=b[a+(h<<1)>>1]|0;b[c+((i|1)<<1)>>1]=b[a+(h+g<<1)>>1]|0;i=h+1|0;if((i|0)<(f|0)){h=i}else{j=f;break}}}else{j=0}f=(d&1|0)!=0;if(f){b[c+(j<<1<<1)>>1]=b[a+(j<<1)>>1]|0}j=(e[c>>1]|0)-(((b[c+2>>1]|0)+1|0)>>>1)&65535;b[a>>1]=j;h=d-1|0;if((h|0)>2){d=2;g=j;while(1){i=d-1|0;k=c+(i<<1)|0;l=(e[c+(d<<1)>>1]|0)-(((b[k>>1]|0)+2+(b[c+((d|1)<<1)>>1]|0)|0)>>>2)&65535;b[a+(d<<1)>>1]=l;b[a+(i<<1)>>1]=(((g<<16>>16)+1+(l<<16>>16)|0)>>>1)+(e[k>>1]|0);k=d+2|0;if((k|0)<(h|0)){d=k;g=l}else{m=k;n=l;break}}}else{m=2;n=j}if(f){f=m-1|0;j=c+(f<<1)|0;g=(e[c+(m<<1)>>1]|0)-(((b[j>>1]|0)+1|0)>>>1)&65535;b[a+(m<<1)>>1]=g;b[a+(f<<1)>>1]=(((n<<16>>16)+1+(g<<16>>16)|0)>>>1)+(e[j>>1]|0);return}else{j=m-1|0;b[a+(j<<1)>>1]=n+(b[c+(j<<1)>>1]|0);return}}function IYa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=d>>1;f=d+1>>1;if((e|0)>0){g=0;while(1){h=g<<1;c[b+(g<<2)>>2]=c[a+(h<<2)>>2];c[b+(g+f<<2)>>2]=c[a+((h|1)<<2)>>2];h=g+1|0;if((h|0)<(e|0)){g=h}else{i=e;break}}}else{i=0}g=d&1;d=(g|0)==0;if(!d){c[b+(i<<2)>>2]=c[a+(i<<1<<2)>>2]}i=a+(f<<2)|0;h=e-1|0;j=h+g|0;if((j|0)>0){g=0;while(1){k=g+f|0;l=g+1|0;c[a+(k<<2)>>2]=(-((c[b+(l<<2)>>2]|0)+(c[b+(g<<2)>>2]|0)|0)>>1)+(c[b+(k<<2)>>2]|0);if((l|0)<(j|0)){g=l}else{break}}}if(d){g=j+f|0;c[a+(g<<2)>>2]=(((c[b+(j<<2)>>2]|0)*-2|0)>>1)+(c[b+(g<<2)>>2]|0)}c[a>>2]=((c[i>>2]<<1)+2>>2)+(c[b>>2]|0);if((h|0)>0){i=0;while(1){g=i+1|0;c[a+(g<<2)>>2]=((c[a+(i+f<<2)>>2]|0)+2+(c[a+(g+f<<2)>>2]|0)>>2)+(c[b+(g<<2)>>2]|0);if((g|0)<(h|0)){i=g}else{break}}}if(d){return}c[a+(e<<2)>>2]=((c[a+(f+h<<2)>>2]<<1)+2>>2)+(c[b+(e<<2)>>2]|0);return}function JYa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=d+1>>1;f=b+(e<<2)|0;g=d&1;h=d>>1;d=h-1|0;i=d+g|0;j=(i|0)>0;if(j){k=0;while(1){l=k<<1;m=k+1|0;c[b+(k+e<<2)>>2]=(c[a+((l|1)<<2)>>2]|0)-((((c[a+(m<<1<<2)>>2]|0)+(c[a+(l<<2)>>2]|0)|0)*3|0)>>1);if((m|0)<(i|0)){k=m}else{break}}}k=(g|0)!=0;if(!k){m=i<<1;c[b+(i+e<<2)>>2]=(c[a+((m|1)<<2)>>2]|0)-(((c[a+(m<<2)>>2]|0)*6|0)>>1)}c[b>>2]=8388608-(((c[f>>2]<<1)+167772171+((c[a>>2]|0)*-16|0)|0)/20|0);f=(d|0)>0;if(f){m=0;while(1){l=m+1|0;c[b+(l<<2)>>2]=8388608-(((c[b+(l+e<<2)>>2]|0)+167772171+(c[b+(m+e<<2)>>2]|0)+((c[a+((m<<1)+2<<2)>>2]|0)*-16|0)|0)/20|0);if((l|0)<(d|0)){m=l}else{break}}}m=(g|0)==0;if(!m){c[b+(h<<2)>>2]=8388608-(((c[b+(e+d<<2)>>2]<<1)+167772171+((c[a+((d<<1)+2<<2)>>2]|0)*-16|0)|0)/20|0)}g=a+(e<<2)|0;if(j){j=0;while(1){l=j+e|0;n=j+1|0;c[a+(l<<2)>>2]=(c[b+(j<<2)>>2]|0)+(c[b+(l<<2)>>2]|0)+(c[b+(n<<2)>>2]|0);if((n|0)<(i|0)){j=n}else{break}}}if(!k){k=i+e|0;c[a+(k<<2)>>2]=(c[b+(i<<2)>>2]<<1)+(c[b+(k<<2)>>2]|0)}c[a>>2]=(((c[g>>2]|0)*6|0)+4>>3)+(c[b>>2]|0);if(f){f=0;while(1){g=f+1|0;c[a+(g<<2)>>2]=((((c[a+(g+e<<2)>>2]|0)+(c[a+(f+e<<2)>>2]|0)|0)*3|0)+4>>3)+(c[b+(g<<2)>>2]|0);if((g|0)<(d|0)){f=g}else{break}}}if(m){return}c[a+(h<<2)>>2]=(((c[a+(e+d<<2)>>2]|0)*6|0)+4>>3)+(c[b+(h<<2)>>2]|0);return}function KYa(a){a=a|0;var b=0,d=0;b=Kob(a)|0;if((b|0)>=0){d=0;return d|0}Wob(c[a+60>>2]|0);d=b;return d|0}function LYa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0,$i=0,aj=0,bj=0,cj=0,dj=0,ej=0,fj=0,gj=0,hj=0,ij=0,jj=0,kj=0,lj=0,mj=0,nj=0,oj=0,pj=0,qj=0,rj=0,sj=0,tj=0,uj=0,vj=0,wj=0,xj=0,yj=0,zj=0,Aj=0,Bj=0,Cj=0,Dj=0,Ej=0,Fj=0,Gj=0,Hj=0,Ij=0,Jj=0,Kj=0,Lj=0,Mj=0,Nj=0,Oj=0,Pj=0,Qj=0,Rj=0,Sj=0;k=i;i=i+304|0;l=k|0;m=k+16|0;n=k+144|0;o=c[f+60>>2]|0;p=o;q=o+8|0;r=q;s=g;fUa(r,c[j+24>>2]|0,c[j+28>>2]|0);gUa(r,214748364,248);j=o+2540|0;c[(c[j>>2]|0)+88>>2]=1;g=o+12|0;t=c[g>>2]|0;u=t>>1;v=t-u|0;c[g>>2]=v;t=q;q=c[t>>2]|0;if((q|0)<(v|0)){if((v|0)<256){c[g>>2]=v<<8;w=q<<8;c[t>>2]=w;y=o+540|0;z=c[y>>2]|0;if(z>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[z]|w}c[y>>2]=z+1}z=o+7348|0;c[z>>2]=0;if((c[o+7352>>2]|0)==0){A=13}else{B=z;A=12}}else{z=q-v|0;c[t>>2]=z;c[g>>2]=u;if((u|0)<256){c[g>>2]=u<<8;u=z<<8;c[t>>2]=u;z=o+540|0;v=c[z>>2]|0;if(v>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[v]|u}c[z>>2]=v+1}v=o+7348|0;c[v>>2]=1;B=v;A=12}a:do{if((A|0)==12){Gob(p);c[o+7536>>2]=0;c[o+7512>>2]=0;c[o+7520>>2]=0;c[o+7492>>2]=0;c[o+7360>>2]=0;if((c[B>>2]|0)==0){A=13;break}v=o+3092|0;z=c[g>>2]|0;u=d[v]|0;q=(ba(u,z)|0)>>8;y=z-q|0;c[g>>2]=y;z=c[t>>2]|0;b:do{if((z|0)<(y|0)){a[v]=a[r+16+u|0]|0;if((y|0)<256){w=y<<8;c[g>>2]=w;C=z<<8;c[t>>2]=C;D=o+540|0;E=c[D>>2]|0;if(E>>>0<(c[o+544>>2]|0)>>>0){F=d[E]|C;c[t>>2]=F;G=F}else{G=C}c[D>>2]=E+1;H=w;I=G}else{H=y;I=z}w=o+3093|0;E=a[w]|0;D=(ba(E&255,H)|0)>>8;C=H-D|0;c[g>>2]=C;if((I|0)<(C|0)){J=0;K=w;L=E}else{E=o+540|0;F=o+544|0;M=1;N=w;w=D;D=C;C=I;while(1){c[t>>2]=C-D;a[N]=a[(d[N]|0)+(r+272)|0]|0;c[g>>2]=w;if((w|0)<256){O=w<<8;c[g>>2]=O;P=c[t>>2]<<8;c[t>>2]=P;Q=c[E>>2]|0;if(Q>>>0<(c[F>>2]|0)>>>0){R=d[Q]|P;c[t>>2]=R;S=R}else{S=P}c[E>>2]=Q+1;T=O;U=S}else{T=w;U=c[t>>2]|0}V=o+((M|0)>9?3102:M+3093|0)|0;O=(ba(d[V]|0,T)|0)>>8;Q=T-O|0;c[g>>2]=Q;if((U|0)<(Q|0)){break}else{M=M+1|0;N=V;w=O;D=Q;C=U}}J=M;K=V;L=a[V]|0}a[K]=a[(L&255)+(r+16)|0]|0;C=c[g>>2]|0;if((C|0)<256){D=C<<8;c[g>>2]=D;w=c[t>>2]<<8;c[t>>2]=w;N=o+540|0;E=c[N>>2]|0;if(E>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[E]|w}c[N>>2]=E+1;W=D}else{W=C}do{if((J|0)>0){C=o+540|0;D=o+544|0;E=2;N=J;w=W;while(1){F=N-1|0;Q=o+((F|0)>9?3123:N+3113|0)|0;O=(ba(d[Q]|0,w)|0)>>8;P=w-O|0;c[g>>2]=P;R=c[t>>2]|0;do{if((R|0)<(P|0)){a[Q]=a[(d[Q]|0)+(r+16)|0]|0;X=c[g>>2]|0;if((X|0)>=256){Y=0;Z=X;break}_=X<<8;c[g>>2]=_;X=c[t>>2]<<8;c[t>>2]=X;$=c[C>>2]|0;if($>>>0<(c[D>>2]|0)>>>0){c[t>>2]=d[$]|X}c[C>>2]=$+1;Y=0;Z=_}else{c[t>>2]=R-P;a[Q]=a[(d[Q]|0)+(r+272)|0]|0;c[g>>2]=O;if((O|0)>=256){Y=1;Z=O;break}_=O<<8;c[g>>2]=_;$=c[t>>2]<<8;c[t>>2]=$;X=c[C>>2]|0;if(X>>>0<(c[D>>2]|0)>>>0){c[t>>2]=d[X]|$}c[C>>2]=X+1;Y=1;Z=_}}while(0);aa=Y|E;if((F|0)<=0){break}E=aa<<1;N=F;w=Z}if((aa|0)!=0){ca=aa;break}da=Z;ea=a[v]|0;fa=c[t>>2]|0;break b}else{ca=1}}while(0);yDb(c[o+4>>2]|0,16,2002592,(ga=i,i=i+8|0,c[ga>>2]=ca,ga)|0);i=ga;ha=-1;i=k;return ha|0}else{M=z-y|0;c[t>>2]=M;w=a[r+272+u|0]|0;a[v]=w;c[g>>2]=q;if((q|0)>=256){da=q;ea=w;fa=M;break}N=q<<8;c[g>>2]=N;E=M<<8;c[t>>2]=E;M=o+540|0;C=c[M>>2]|0;if(C>>>0<(c[o+544>>2]|0)>>>0){D=d[C]|E;c[t>>2]=D;ia=D}else{ia=E}c[M>>2]=C+1;da=N;ea=w;fa=ia}}while(0);c[o+7356>>2]=0;q=ea&255;u=(ba(q,da)|0)>>8;y=da-u|0;c[g>>2]=y;do{if((fa|0)<(y|0)){z=a[r+16+q|0]|0;a[v]=z;if((y|0)>=256){ja=0;ka=y;la=z;ma=fa;break}w=y<<8;c[g>>2]=w;N=fa<<8;c[t>>2]=N;C=o+540|0;M=c[C>>2]|0;if(M>>>0<(c[o+544>>2]|0)>>>0){E=d[M]|N;c[t>>2]=E;na=E}else{na=N}c[C>>2]=M+1;ja=0;ka=w;la=z;ma=na}else{z=fa-y|0;c[t>>2]=z;w=a[r+272+q|0]|0;a[v]=w;c[g>>2]=u;if((u|0)>=256){ja=1;ka=u;la=w;ma=z;break}M=u<<8;c[g>>2]=M;C=z<<8;c[t>>2]=C;z=o+540|0;N=c[z>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){E=d[N]|C;c[t>>2]=E;oa=E}else{oa=C}c[z>>2]=N+1;ja=1;ka=M;la=w;ma=oa}}while(0);c[o+7352>>2]=ja;u=la&255;q=(ba(u,ka)|0)>>8;y=ka-q|0;c[g>>2]=y;c:do{if((ma|0)<(y|0)){a[v]=a[r+16+u|0]|0;if((y|0)<256){w=y<<8;c[g>>2]=w;M=ma<<8;c[t>>2]=M;N=o+540|0;z=c[N>>2]|0;if(z>>>0<(c[o+544>>2]|0)>>>0){C=d[z]|M;c[t>>2]=C;pa=C}else{pa=M}c[N>>2]=z+1;qa=w;ra=pa}else{qa=y;ra=ma}w=o+3093|0;z=a[w]|0;N=(ba(z&255,qa)|0)>>8;M=qa-N|0;c[g>>2]=M;if((ra|0)<(M|0)){sa=0;ta=w;ua=z}else{z=o+540|0;C=o+544|0;E=1;D=w;w=N;N=M;M=ra;while(1){c[t>>2]=M-N;a[D]=a[(d[D]|0)+(r+272)|0]|0;c[g>>2]=w;if((w|0)<256){O=w<<8;c[g>>2]=O;Q=c[t>>2]<<8;c[t>>2]=Q;P=c[z>>2]|0;if(P>>>0<(c[C>>2]|0)>>>0){R=d[P]|Q;c[t>>2]=R;va=R}else{va=Q}c[z>>2]=P+1;wa=O;xa=va}else{wa=w;xa=c[t>>2]|0}ya=o+((E|0)>9?3102:E+3093|0)|0;O=(ba(d[ya]|0,wa)|0)>>8;P=wa-O|0;c[g>>2]=P;if((xa|0)<(P|0)){break}else{E=E+1|0;D=ya;w=O;N=P;M=xa}}sa=E;ta=ya;ua=a[ya]|0}a[ta]=a[(ua&255)+(r+16)|0]|0;M=c[g>>2]|0;if((M|0)<256){N=M<<8;c[g>>2]=N;w=c[t>>2]<<8;c[t>>2]=w;D=o+540|0;z=c[D>>2]|0;if(z>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[z]|w}c[D>>2]=z+1;za=N}else{za=M}if((sa|0)<=0){Aa=1;Ba=za;break}M=o+540|0;N=o+544|0;z=2;D=sa;w=za;while(1){C=D-1|0;P=o+((C|0)>9?3123:D+3113|0)|0;O=(ba(d[P]|0,w)|0)>>8;Q=w-O|0;c[g>>2]=Q;R=c[t>>2]|0;do{if((R|0)<(Q|0)){a[P]=a[(d[P]|0)+(r+16)|0]|0;_=c[g>>2]|0;if((_|0)>=256){Ca=0;Da=_;break}X=_<<8;c[g>>2]=X;_=c[t>>2]<<8;c[t>>2]=_;$=c[M>>2]|0;if($>>>0<(c[N>>2]|0)>>>0){c[t>>2]=d[$]|_}c[M>>2]=$+1;Ca=0;Da=X}else{c[t>>2]=R-Q;a[P]=a[(d[P]|0)+(r+272)|0]|0;c[g>>2]=O;if((O|0)>=256){Ca=1;Da=O;break}X=O<<8;c[g>>2]=X;$=c[t>>2]<<8;c[t>>2]=$;_=c[M>>2]|0;if(_>>>0<(c[N>>2]|0)>>>0){c[t>>2]=d[_]|$}c[M>>2]=_+1;Ca=1;Da=X}}while(0);O=Ca|z;if((C|0)<=0){Aa=O;Ba=Da;break c}z=O<<1;D=C;w=Da}}else{w=ma-y|0;c[t>>2]=w;a[v]=a[r+272+u|0]|0;c[g>>2]=q;if((q|0)>=256){Aa=0;Ba=q;break}D=q<<8;c[g>>2]=D;z=w<<8;c[t>>2]=z;w=o+540|0;M=c[w>>2]|0;if(M>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[M]|z}c[w>>2]=M+1;Aa=0;Ba=D}}while(0);c[o+7368>>2]=Aa;q=d[v]|0;u=(ba(q,Ba)|0)>>8;y=Ba-u|0;c[g>>2]=y;D=c[t>>2]|0;d:do{if((D|0)<(y|0)){a[v]=a[r+16+q|0]|0;if((y|0)<256){M=y<<8;c[g>>2]=M;w=D<<8;c[t>>2]=w;z=o+540|0;N=c[z>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){E=d[N]|w;c[t>>2]=E;Ea=E}else{Ea=w}c[z>>2]=N+1;Fa=M;Ga=Ea}else{Fa=y;Ga=D}M=o+3093|0;N=a[M]|0;z=(ba(N&255,Fa)|0)>>8;w=Fa-z|0;c[g>>2]=w;if((Ga|0)<(w|0)){Ha=0;Ia=M;Ja=N}else{N=o+540|0;E=o+544|0;O=1;P=M;M=z;z=w;w=Ga;while(1){c[t>>2]=w-z;a[P]=a[(d[P]|0)+(r+272)|0]|0;c[g>>2]=M;if((M|0)<256){Q=M<<8;c[g>>2]=Q;R=c[t>>2]<<8;c[t>>2]=R;X=c[N>>2]|0;if(X>>>0<(c[E>>2]|0)>>>0){_=d[X]|R;c[t>>2]=_;Ka=_}else{Ka=R}c[N>>2]=X+1;La=Q;Ma=Ka}else{La=M;Ma=c[t>>2]|0}Na=o+((O|0)>9?3102:O+3093|0)|0;Q=(ba(d[Na]|0,La)|0)>>8;X=La-Q|0;c[g>>2]=X;if((Ma|0)<(X|0)){break}else{O=O+1|0;P=Na;M=Q;z=X;w=Ma}}Ha=O;Ia=Na;Ja=a[Na]|0}a[Ia]=a[(Ja&255)+(r+16)|0]|0;w=c[g>>2]|0;if((w|0)<256){z=w<<8;c[g>>2]=z;M=c[t>>2]<<8;c[t>>2]=M;P=o+540|0;N=c[P>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[N]|M}c[P>>2]=N+1;Oa=z}else{Oa=w}if((Ha|0)<=0){Pa=1;Qa=Oa;break}w=o+540|0;z=o+544|0;N=2;P=Ha;M=Oa;while(1){E=P-1|0;X=o+((E|0)>9?3123:P+3113|0)|0;Q=(ba(d[X]|0,M)|0)>>8;R=M-Q|0;c[g>>2]=R;_=c[t>>2]|0;do{if((_|0)<(R|0)){a[X]=a[(d[X]|0)+(r+16)|0]|0;$=c[g>>2]|0;if(($|0)>=256){Ra=0;Sa=$;break}Ta=$<<8;c[g>>2]=Ta;$=c[t>>2]<<8;c[t>>2]=$;Ua=c[w>>2]|0;if(Ua>>>0<(c[z>>2]|0)>>>0){c[t>>2]=d[Ua]|$}c[w>>2]=Ua+1;Ra=0;Sa=Ta}else{c[t>>2]=_-R;a[X]=a[(d[X]|0)+(r+272)|0]|0;c[g>>2]=Q;if((Q|0)>=256){Ra=1;Sa=Q;break}Ta=Q<<8;c[g>>2]=Ta;Ua=c[t>>2]<<8;c[t>>2]=Ua;$=c[w>>2]|0;if($>>>0<(c[z>>2]|0)>>>0){c[t>>2]=d[$]|Ua}c[w>>2]=$+1;Ra=1;Sa=Ta}}while(0);Q=Ra|N;if((E|0)<=0){Pa=Q;Qa=Sa;break d}N=Q<<1;P=E;M=Sa}}else{M=D-y|0;c[t>>2]=M;a[v]=a[r+272+q|0]|0;c[g>>2]=u;if((u|0)>=256){Pa=0;Qa=u;break}P=u<<8;c[g>>2]=P;N=M<<8;c[t>>2]=N;M=o+540|0;w=c[M>>2]|0;if(w>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[w]|N}c[M>>2]=w+1;Pa=0;Qa=P}}while(0);c[o+7380>>2]=Pa;u=d[v]|0;q=(ba(u,Qa)|0)>>8;y=Qa-q|0;c[g>>2]=y;D=c[t>>2]|0;do{if((D|0)<(y|0)){a[v]=a[r+16+u|0]|0;if((y|0)<256){P=y<<8;c[g>>2]=P;w=D<<8;c[t>>2]=w;M=o+540|0;N=c[M>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){z=d[N]|w;c[t>>2]=z;Va=z}else{Va=w}c[M>>2]=N+1;Wa=P;Xa=Va}else{Wa=y;Xa=D}P=o+3093|0;N=a[P]|0;M=(ba(N&255,Wa)|0)>>8;w=Wa-M|0;c[g>>2]=w;if((Xa|0)<(w|0)){Ya=0;Za=P;_a=N}else{N=o+540|0;z=o+544|0;O=1;Q=P;X=M;M=w;w=Xa;while(1){c[t>>2]=w-M;a[Q]=a[(d[Q]|0)+(r+272)|0]|0;c[g>>2]=X;if((X|0)<256){R=X<<8;c[g>>2]=R;_=c[t>>2]<<8;c[t>>2]=_;C=c[N>>2]|0;if(C>>>0<(c[z>>2]|0)>>>0){Ta=d[C]|_;c[t>>2]=Ta;$a=Ta}else{$a=_}c[N>>2]=C+1;ab=R;bb=$a}else{ab=X;bb=c[t>>2]|0}cb=o+((O|0)>9?3102:O+3093|0)|0;R=(ba(d[cb]|0,ab)|0)>>8;C=ab-R|0;c[g>>2]=C;if((bb|0)<(C|0)){break}else{O=O+1|0;Q=cb;X=R;M=C;w=bb}}Ya=O;Za=cb;_a=a[cb]|0}a[Za]=a[(_a&255)+(r+16)|0]|0;w=c[g>>2]|0;if((w|0)<256){M=w<<8;c[g>>2]=M;X=c[t>>2]<<8;c[t>>2]=X;Q=o+540|0;N=c[Q>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[N]|X}c[Q>>2]=N+1;db=M}else{db=w}if((Ya|0)>0){w=o+540|0;M=o+544|0;N=2;Q=Ya;X=db;while(1){z=Q-1|0;C=o+((z|0)>9?3123:Q+3113|0)|0;R=(ba(d[C]|0,X)|0)>>8;_=X-R|0;c[g>>2]=_;Ta=c[t>>2]|0;do{if((Ta|0)<(_|0)){a[C]=a[(d[C]|0)+(r+16)|0]|0;$=c[g>>2]|0;if(($|0)>=256){eb=0;fb=$;break}Ua=$<<8;c[g>>2]=Ua;$=c[t>>2]<<8;c[t>>2]=$;gb=c[w>>2]|0;if(gb>>>0<(c[M>>2]|0)>>>0){c[t>>2]=d[gb]|$}c[w>>2]=gb+1;eb=0;fb=Ua}else{c[t>>2]=Ta-_;a[C]=a[(d[C]|0)+(r+272)|0]|0;c[g>>2]=R;if((R|0)>=256){eb=1;fb=R;break}Ua=R<<8;c[g>>2]=Ua;gb=c[t>>2]<<8;c[t>>2]=gb;$=c[w>>2]|0;if($>>>0<(c[M>>2]|0)>>>0){c[t>>2]=d[$]|gb}c[w>>2]=$+1;eb=1;fb=Ua}}while(0);hb=eb|N;if((z|0)<=0){break}N=hb<<1;Q=z;X=fb}if((hb-1|0)>>>0<8>>>0){ib=hb;jb=fb}else{kb=hb;break}}else{ib=1;jb=db}X=o+7372|0;c[X>>2]=ib;Q=d[v]|0;N=(ba(Q,jb)|0)>>8;w=jb-N|0;c[g>>2]=w;M=c[t>>2]|0;e:do{if((M|0)<(w|0)){a[v]=a[r+16+Q|0]|0;if((w|0)<256){O=w<<8;c[g>>2]=O;R=M<<8;c[t>>2]=R;C=o+540|0;_=c[C>>2]|0;if(_>>>0<(c[o+544>>2]|0)>>>0){Ta=d[_]|R;c[t>>2]=Ta;lb=Ta}else{lb=R}c[C>>2]=_+1;mb=O;nb=lb}else{mb=w;nb=M}O=a[P]|0;_=(ba(O&255,mb)|0)>>8;C=mb-_|0;c[g>>2]=C;if((nb|0)<(C|0)){ob=0;pb=P;qb=O}else{O=o+540|0;R=o+544|0;Ta=1;E=P;Ua=_;_=C;C=nb;while(1){c[t>>2]=C-_;a[E]=a[(d[E]|0)+(r+272)|0]|0;c[g>>2]=Ua;if((Ua|0)<256){$=Ua<<8;c[g>>2]=$;gb=c[t>>2]<<8;c[t>>2]=gb;rb=c[O>>2]|0;if(rb>>>0<(c[R>>2]|0)>>>0){sb=d[rb]|gb;c[t>>2]=sb;tb=sb}else{tb=gb}c[O>>2]=rb+1;ub=$;vb=tb}else{ub=Ua;vb=c[t>>2]|0}wb=o+((Ta|0)>9?3102:Ta+3093|0)|0;$=(ba(d[wb]|0,ub)|0)>>8;rb=ub-$|0;c[g>>2]=rb;if((vb|0)<(rb|0)){break}else{Ta=Ta+1|0;E=wb;Ua=$;_=rb;C=vb}}ob=Ta;pb=wb;qb=a[wb]|0}a[pb]=a[(qb&255)+(r+16)|0]|0;C=c[g>>2]|0;if((C|0)<256){_=C<<8;c[g>>2]=_;Ua=c[t>>2]<<8;c[t>>2]=Ua;E=o+540|0;O=c[E>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[O]|Ua}c[E>>2]=O+1;xb=_}else{xb=C}do{if((ob|0)>0){C=o+540|0;_=o+544|0;O=2;E=ob;Ua=xb;while(1){R=E-1|0;z=o+((R|0)>9?3123:E+3113|0)|0;rb=(ba(d[z]|0,Ua)|0)>>8;$=Ua-rb|0;c[g>>2]=$;gb=c[t>>2]|0;do{if((gb|0)<($|0)){a[z]=a[(d[z]|0)+(r+16)|0]|0;sb=c[g>>2]|0;if((sb|0)>=256){yb=0;zb=sb;break}Ab=sb<<8;c[g>>2]=Ab;sb=c[t>>2]<<8;c[t>>2]=sb;Bb=c[C>>2]|0;if(Bb>>>0<(c[_>>2]|0)>>>0){c[t>>2]=d[Bb]|sb}c[C>>2]=Bb+1;yb=0;zb=Ab}else{c[t>>2]=gb-$;a[z]=a[(d[z]|0)+(r+272)|0]|0;c[g>>2]=rb;if((rb|0)>=256){yb=1;zb=rb;break}Ab=rb<<8;c[g>>2]=Ab;Bb=c[t>>2]<<8;c[t>>2]=Bb;sb=c[C>>2]|0;if(sb>>>0<(c[_>>2]|0)>>>0){c[t>>2]=d[sb]|Bb}c[C>>2]=sb+1;yb=1;zb=Ab}}while(0);Cb=yb|O;if((R|0)<=0){break}O=Cb<<1;E=R;Ua=zb}c[o+7476>>2]=Cb;if((Cb|0)==0){Db=zb;Eb=a[v]|0;Fb=c[t>>2]|0;A=208;break e}else if((Cb|0)==1){Gb=zb;break}yDb(o,16,1913344,(ga=i,i=i+1|0,i=i+7&-8,c[ga>>2]=0,ga)|0);i=ga;c[o+7484>>2]=1;c[o+7480>>2]=1;c[(c[o+4>>2]|0)+140>>2]=0;ha=-1;i=k;return ha|0}else{c[o+7476>>2]=1;Gb=xb}}while(0);c[(c[o+4>>2]|0)+140>>2]=8;c[o+7544>>2]=1;Hb=Gb}else{Ta=M-w|0;c[t>>2]=Ta;Ua=a[r+272+Q|0]|0;a[v]=Ua;c[g>>2]=N;if((N|0)<256){E=N<<8;c[g>>2]=E;O=Ta<<8;c[t>>2]=O;C=o+540|0;_=c[C>>2]|0;if(_>>>0<(c[o+544>>2]|0)>>>0){F=d[_]|O;c[t>>2]=F;Ib=F}else{Ib=O}c[C>>2]=_+1;Jb=E;Kb=Ib}else{Jb=N;Kb=Ta}c[o+7476>>2]=0;Db=Jb;Eb=Ua;Fb=Kb;A=208}}while(0);if((A|0)==208){N=Eb&255;Q=(ba(N,Db)|0)>>8;w=Db-Q|0;c[g>>2]=w;f:do{if((Fb|0)<(w|0)){a[v]=a[r+16+N|0]|0;if((w|0)<256){M=w<<8;c[g>>2]=M;Ua=Fb<<8;c[t>>2]=Ua;Ta=o+540|0;E=c[Ta>>2]|0;if(E>>>0<(c[o+544>>2]|0)>>>0){_=d[E]|Ua;c[t>>2]=_;Lb=_}else{Lb=Ua}c[Ta>>2]=E+1;Mb=M;Nb=Lb}else{Mb=w;Nb=Fb}M=a[P]|0;E=(ba(M&255,Mb)|0)>>8;Ta=Mb-E|0;c[g>>2]=Ta;if((Nb|0)<(Ta|0)){Ob=0;Pb=P;Qb=M}else{M=o+540|0;Ua=o+544|0;_=1;C=P;O=E;E=Ta;Ta=Nb;while(1){c[t>>2]=Ta-E;a[C]=a[(d[C]|0)+(r+272)|0]|0;c[g>>2]=O;if((O|0)<256){F=O<<8;c[g>>2]=F;rb=c[t>>2]<<8;c[t>>2]=rb;z=c[M>>2]|0;if(z>>>0<(c[Ua>>2]|0)>>>0){$=d[z]|rb;c[t>>2]=$;Rb=$}else{Rb=rb}c[M>>2]=z+1;Sb=F;Tb=Rb}else{Sb=O;Tb=c[t>>2]|0}Ub=o+((_|0)>9?3102:_+3093|0)|0;F=(ba(d[Ub]|0,Sb)|0)>>8;z=Sb-F|0;c[g>>2]=z;if((Tb|0)<(z|0)){break}else{_=_+1|0;C=Ub;O=F;E=z;Ta=Tb}}Ob=_;Pb=Ub;Qb=a[Ub]|0}a[Pb]=a[(Qb&255)+(r+16)|0]|0;Ta=c[g>>2]|0;if((Ta|0)<256){E=Ta<<8;c[g>>2]=E;O=c[t>>2]<<8;c[t>>2]=O;C=o+540|0;M=c[C>>2]|0;if(M>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[M]|O}c[C>>2]=M+1;Vb=E}else{Vb=Ta}if((Ob|0)<=0){Wb=1;Xb=Vb;break}Ta=o+540|0;E=o+544|0;M=2;C=Ob;O=Vb;while(1){Ua=C-1|0;z=o+((Ua|0)>9?3123:C+3113|0)|0;F=(ba(d[z]|0,O)|0)>>8;rb=O-F|0;c[g>>2]=rb;$=c[t>>2]|0;do{if(($|0)<(rb|0)){a[z]=a[(d[z]|0)+(r+16)|0]|0;gb=c[g>>2]|0;if((gb|0)>=256){Yb=0;Zb=gb;break}Ab=gb<<8;c[g>>2]=Ab;gb=c[t>>2]<<8;c[t>>2]=gb;sb=c[Ta>>2]|0;if(sb>>>0<(c[E>>2]|0)>>>0){c[t>>2]=d[sb]|gb}c[Ta>>2]=sb+1;Yb=0;Zb=Ab}else{c[t>>2]=$-rb;a[z]=a[(d[z]|0)+(r+272)|0]|0;c[g>>2]=F;if((F|0)>=256){Yb=1;Zb=F;break}Ab=F<<8;c[g>>2]=Ab;sb=c[t>>2]<<8;c[t>>2]=sb;gb=c[Ta>>2]|0;if(gb>>>0<(c[E>>2]|0)>>>0){c[t>>2]=d[gb]|sb}c[Ta>>2]=gb+1;Yb=1;Zb=Ab}}while(0);F=Yb|M;if((Ua|0)<=0){Wb=F;Xb=Zb;break f}M=F<<1;C=Ua;O=Zb}}else{O=Fb-w|0;c[t>>2]=O;a[v]=a[r+272+N|0]|0;c[g>>2]=Q;if((Q|0)>=256){Wb=0;Xb=Q;break}C=Q<<8;c[g>>2]=C;M=O<<8;c[t>>2]=M;O=o+540|0;Ta=c[O>>2]|0;if(Ta>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Ta]|M}c[O>>2]=Ta+1;Wb=0;Xb=C}}while(0);Q=o+7480|0;c[Q>>2]=Wb;N=d[v]|0;w=(ba(N,Xb)|0)>>8;C=Xb-w|0;c[g>>2]=C;Ta=c[t>>2]|0;do{if((Ta|0)<(C|0)){a[v]=a[r+16+N|0]|0;if((C|0)<256){O=C<<8;c[g>>2]=O;M=Ta<<8;c[t>>2]=M;E=o+540|0;_=c[E>>2]|0;if(_>>>0<(c[o+544>>2]|0)>>>0){F=d[_]|M;c[t>>2]=F;_b=F}else{_b=M}c[E>>2]=_+1;$b=O;ac=_b}else{$b=C;ac=Ta}O=a[P]|0;_=(ba(O&255,$b)|0)>>8;E=$b-_|0;c[g>>2]=E;if((ac|0)<(E|0)){bc=0;cc=P;dc=O}else{O=o+540|0;M=o+544|0;F=1;z=P;rb=_;_=E;E=ac;while(1){c[t>>2]=E-_;a[z]=a[(d[z]|0)+(r+272)|0]|0;c[g>>2]=rb;if((rb|0)<256){$=rb<<8;c[g>>2]=$;Ab=c[t>>2]<<8;c[t>>2]=Ab;gb=c[O>>2]|0;if(gb>>>0<(c[M>>2]|0)>>>0){sb=d[gb]|Ab;c[t>>2]=sb;ec=sb}else{ec=Ab}c[O>>2]=gb+1;fc=$;gc=ec}else{fc=rb;gc=c[t>>2]|0}hc=o+((F|0)>9?3102:F+3093|0)|0;$=(ba(d[hc]|0,fc)|0)>>8;gb=fc-$|0;c[g>>2]=gb;if((gc|0)<(gb|0)){break}else{F=F+1|0;z=hc;rb=$;_=gb;E=gc}}bc=F;cc=hc;dc=a[hc]|0}a[cc]=a[(dc&255)+(r+16)|0]|0;E=c[g>>2]|0;if((E|0)<256){_=E<<8;c[g>>2]=_;rb=c[t>>2]<<8;c[t>>2]=rb;z=o+540|0;O=c[z>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[O]|rb}c[z>>2]=O+1;ic=_}else{ic=E}g:do{if((bc|0)>0){E=o+540|0;_=o+544|0;O=2;z=bc;rb=ic;while(1){M=z-1|0;gb=o+((M|0)>9?3123:z+3113|0)|0;$=(ba(d[gb]|0,rb)|0)>>8;Ab=rb-$|0;c[g>>2]=Ab;sb=c[t>>2]|0;do{if((sb|0)<(Ab|0)){a[gb]=a[(d[gb]|0)+(r+16)|0]|0;Bb=c[g>>2]|0;if((Bb|0)>=256){jc=0;kc=Bb;break}lc=Bb<<8;c[g>>2]=lc;Bb=c[t>>2]<<8;c[t>>2]=Bb;mc=c[E>>2]|0;if(mc>>>0<(c[_>>2]|0)>>>0){c[t>>2]=d[mc]|Bb}c[E>>2]=mc+1;jc=0;kc=lc}else{c[t>>2]=sb-Ab;a[gb]=a[(d[gb]|0)+(r+272)|0]|0;c[g>>2]=$;if(($|0)>=256){jc=1;kc=$;break}lc=$<<8;c[g>>2]=lc;mc=c[t>>2]<<8;c[t>>2]=mc;Bb=c[E>>2]|0;if(Bb>>>0<(c[_>>2]|0)>>>0){c[t>>2]=d[Bb]|mc}c[E>>2]=Bb+1;jc=1;kc=lc}}while(0);$=jc|O;if((M|0)<=0){nc=$;oc=kc;break g}O=$<<1;z=M;rb=kc}}else{nc=1;oc=ic}}while(0);F=o+7484|0;c[F>>2]=nc;rb=c[Q>>2]|0;if(!((rb|0)==1&(nc|0)==1)){pc=nc;qc=F;rc=rb;sc=oc;A=281;break}c[(c[o+4>>2]|0)+140>>2]=0;tc=oc}else{rb=Ta-C|0;c[t>>2]=rb;a[v]=a[r+272+N|0]|0;c[g>>2]=w;if((w|0)<256){F=w<<8;c[g>>2]=F;z=rb<<8;c[t>>2]=z;rb=o+540|0;O=c[rb>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[O]|z}c[rb>>2]=O+1;uc=F}else{uc=w}F=o+7484|0;c[F>>2]=0;pc=0;qc=F;rc=Wb;sc=uc;A=281}}while(0);do{if((A|0)==281){if((pc|rc|0)==0){c[(c[o+4>>2]|0)+140>>2]=5;tc=sc;break}if((rc|0)==2&(pc|0)==2){c[(c[o+4>>2]|0)+140>>2]=6;tc=sc;break}yDb(o,16,1937088,(ga=i,i=i+16|0,c[ga>>2]=rc,c[ga+8>>2]=pc,ga)|0);i=ga;c[qc>>2]=1;c[Q>>2]=1;c[(c[o+4>>2]|0)+140>>2]=0;ha=-1;i=k;return ha|0}}while(0);c[o+7544>>2]=3;Hb=tc}Q=d[v]|0;w=(ba(Q,Hb)|0)>>8;N=Hb-w|0;c[g>>2]=N;C=c[t>>2]|0;do{if((C|0)<(N|0)){Ta=a[r+16+Q|0]|0;a[v]=Ta;if((N|0)>=256){vc=0;wc=N;xc=Ta;yc=C;break}F=N<<8;c[g>>2]=F;O=C<<8;c[t>>2]=O;rb=o+540|0;z=c[rb>>2]|0;if(z>>>0<(c[o+544>>2]|0)>>>0){E=d[z]|O;c[t>>2]=E;zc=E}else{zc=O}c[rb>>2]=z+1;vc=0;wc=F;xc=Ta;yc=zc}else{Ta=C-N|0;c[t>>2]=Ta;F=a[r+272+Q|0]|0;a[v]=F;c[g>>2]=w;if((w|0)>=256){vc=1;wc=w;xc=F;yc=Ta;break}z=w<<8;c[g>>2]=z;rb=Ta<<8;c[t>>2]=rb;Ta=o+540|0;O=c[Ta>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){E=d[O]|rb;c[t>>2]=E;Ac=E}else{Ac=rb}c[Ta>>2]=O+1;vc=1;wc=z;xc=F;yc=Ac}}while(0);c[o+7488>>2]=vc;w=xc&255;Q=(ba(w,wc)|0)>>8;N=wc-Q|0;c[g>>2]=N;do{if((yc|0)<(N|0)){a[v]=a[r+16+w|0]|0;if((N|0)<256){C=N<<8;c[g>>2]=C;F=yc<<8;c[t>>2]=F;z=o+540|0;O=c[z>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){Ta=d[O]|F;c[t>>2]=Ta;Bc=Ta}else{Bc=F}c[z>>2]=O+1;Cc=C;Dc=Bc}else{Cc=N;Dc=yc}C=a[P]|0;O=(ba(C&255,Cc)|0)>>8;z=Cc-O|0;c[g>>2]=z;if((Dc|0)<(z|0)){Ec=0;Fc=P;Gc=C}else{C=o+540|0;F=o+544|0;Ta=1;rb=P;E=O;O=z;z=Dc;while(1){c[t>>2]=z-O;a[rb]=a[(d[rb]|0)+(r+272)|0]|0;c[g>>2]=E;if((E|0)<256){_=E<<8;c[g>>2]=_;Ua=c[t>>2]<<8;c[t>>2]=Ua;$=c[C>>2]|0;if($>>>0<(c[F>>2]|0)>>>0){gb=d[$]|Ua;c[t>>2]=gb;Hc=gb}else{Hc=Ua}c[C>>2]=$+1;Ic=_;Jc=Hc}else{Ic=E;Jc=c[t>>2]|0}Kc=o+((Ta|0)>9?3102:Ta+3093|0)|0;_=(ba(d[Kc]|0,Ic)|0)>>8;$=Ic-_|0;c[g>>2]=$;if((Jc|0)<($|0)){break}else{Ta=Ta+1|0;rb=Kc;E=_;O=$;z=Jc}}Ec=Ta;Fc=Kc;Gc=a[Kc]|0}a[Fc]=a[(Gc&255)+(r+16)|0]|0;z=c[g>>2]|0;if((z|0)<256){O=z<<8;c[g>>2]=O;E=c[t>>2]<<8;c[t>>2]=E;rb=o+540|0;C=c[rb>>2]|0;if(C>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[C]|E}c[rb>>2]=C+1;Lc=O}else{Lc=z}if((Ec|0)<=0){Mc=2;break}z=o+540|0;O=o+544|0;C=2;rb=Ec;E=Lc;while(1){F=rb-1|0;$=o+((F|0)>9?3123:rb+3113|0)|0;_=(ba(d[$]|0,E)|0)>>8;Ua=E-_|0;c[g>>2]=Ua;gb=c[t>>2]|0;do{if((gb|0)<(Ua|0)){a[$]=a[(d[$]|0)+(r+16)|0]|0;Ab=c[g>>2]|0;if((Ab|0)>=256){Nc=0;Oc=Ab;break}sb=Ab<<8;c[g>>2]=sb;Ab=c[t>>2]<<8;c[t>>2]=Ab;R=c[z>>2]|0;if(R>>>0<(c[O>>2]|0)>>>0){c[t>>2]=d[R]|Ab}c[z>>2]=R+1;Nc=0;Oc=sb}else{c[t>>2]=gb-Ua;a[$]=a[(d[$]|0)+(r+272)|0]|0;c[g>>2]=_;if((_|0)>=256){Nc=1;Oc=_;break}sb=_<<8;c[g>>2]=sb;R=c[t>>2]<<8;c[t>>2]=R;Ab=c[z>>2]|0;if(Ab>>>0<(c[O>>2]|0)>>>0){c[t>>2]=d[Ab]|R}c[z>>2]=Ab+1;Nc=1;Oc=sb}}while(0);Pc=Nc|C;if((F|0)<=0){break}C=Pc<<1;rb=F;E=Oc}if(Pc>>>0<8>>>0){Mc=Pc+1|0;break}yDb(c[o+4>>2]|0,16,1892888,(ga=i,i=i+8|0,c[ga>>2]=Pc,ga)|0);i=ga;ha=-1;i=k;return ha|0}else{E=yc-N|0;c[t>>2]=E;a[v]=a[r+272+w|0]|0;c[g>>2]=Q;if((Q|0)>=256){Mc=1;break}c[g>>2]=Q<<8;rb=E<<8;c[t>>2]=rb;E=o+540|0;C=c[E>>2]|0;if(C>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[C]|rb}c[E>>2]=C+1;Mc=1}}while(0);c[o+7384>>2]=Mc;Q=o+7544|0;w=c[Q>>2]|0;if((w|0)>0){N=o+540|0;C=o+544|0;E=0;rb=c[X>>2]|0;z=w;while(1){h:do{if((rb|0)>0){if((E|0)==2){w=0;while(1){O=(w|0)!=0|0;do{c[p+1073612+(w*66624|0)+(O*16656|0)+16>>2]=c[p+540584+(w*66624|0)+(O*16656|0)+16>>2];O=O+1|0;}while((O|0)<4);O=c[X>>2]|0;M=w+1|0;if((M|0)<(O|0)){w=M}else{Qc=O;Rc=z;break h}}}else{Sc=0}do{w=p+7548+(E*533028|0)+8+(Sc*66624|0)+16672|0;F=p+7548+(E*533028|0)+8+(Sc*66624|0)+33328|0;O=(Sc|0)!=0|0;while(1){if((O|0)==2){c[F>>2]=c[w>>2];O=3;continue}M=c[g>>2]|0;Ta=d[v]|0;_=(ba(Ta,M)|0)>>8;$=M-_|0;c[g>>2]=$;M=c[t>>2]|0;do{if((M|0)<($|0)){a[v]=a[r+16+Ta|0]|0;if(($|0)<256){Ua=$<<8;c[g>>2]=Ua;gb=M<<8;c[t>>2]=gb;sb=c[N>>2]|0;if(sb>>>0<(c[C>>2]|0)>>>0){Ab=d[sb]|gb;c[t>>2]=Ab;Tc=Ab}else{Tc=gb}c[N>>2]=sb+1;Uc=Ua;Vc=Tc}else{Uc=$;Vc=M}Ua=a[P]|0;sb=(ba(Ua&255,Uc)|0)>>8;gb=Uc-sb|0;c[g>>2]=gb;if((Vc|0)<(gb|0)){Wc=0;Xc=P;Yc=Ua}else{Ua=1;Ab=P;R=sb;sb=gb;gb=Vc;while(1){c[t>>2]=gb-sb;a[Ab]=a[(d[Ab]|0)+(r+272)|0]|0;c[g>>2]=R;if((R|0)<256){lc=R<<8;c[g>>2]=lc;Bb=c[t>>2]<<8;c[t>>2]=Bb;mc=c[N>>2]|0;if(mc>>>0<(c[C>>2]|0)>>>0){Zc=d[mc]|Bb;c[t>>2]=Zc;_c=Zc}else{_c=Bb}c[N>>2]=mc+1;$c=lc;ad=_c}else{$c=R;ad=c[t>>2]|0}lc=Ua+1|0;bd=((Ua|0)>9?10:lc)+(p+3092)|0;mc=(ba(d[bd]|0,$c)|0)>>8;Bb=$c-mc|0;c[g>>2]=Bb;if((ad|0)<(Bb|0)){break}else{Ua=lc;Ab=bd;R=mc;sb=Bb;gb=ad}}Wc=Ua;Xc=bd;Yc=a[bd]|0}a[Xc]=a[(Yc&255)+(r+16)|0]|0;gb=c[g>>2]|0;if((gb|0)<256){sb=gb<<8;c[g>>2]=sb;R=c[t>>2]<<8;c[t>>2]=R;Ab=c[N>>2]|0;if(Ab>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[Ab]|R}c[N>>2]=Ab+1;cd=sb}else{cd=gb}i:do{if((Wc|0)>0){gb=2;sb=Wc;Ab=cd;while(1){R=sb-1|0;Bb=((R|0)>9?31:sb+21|0)+(p+3092)|0;mc=(ba(d[Bb]|0,Ab)|0)>>8;lc=Ab-mc|0;c[g>>2]=lc;Zc=c[t>>2]|0;do{if((Zc|0)<(lc|0)){a[Bb]=a[(d[Bb]|0)+(r+16)|0]|0;dd=c[g>>2]|0;if((dd|0)>=256){ed=0;fd=dd;break}gd=dd<<8;c[g>>2]=gd;dd=c[t>>2]<<8;c[t>>2]=dd;hd=c[N>>2]|0;if(hd>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[hd]|dd}c[N>>2]=hd+1;ed=0;fd=gd}else{c[t>>2]=Zc-lc;a[Bb]=a[(d[Bb]|0)+(r+272)|0]|0;c[g>>2]=mc;if((mc|0)>=256){ed=1;fd=mc;break}gd=mc<<8;c[g>>2]=gd;hd=c[t>>2]<<8;c[t>>2]=hd;dd=c[N>>2]|0;if(dd>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[dd]|hd}c[N>>2]=dd+1;ed=1;fd=gd}}while(0);mc=ed|gb;if((R|0)<=0){id=mc;jd=fd;break i}gb=mc<<1;sb=R;Ab=fd}}else{id=1;jd=cd}}while(0);Ua=((Wc|0)>10?21:Wc+11|0)+(p+3092)|0;Ab=(ba(d[Ua]|0,jd)|0)>>8;sb=jd-Ab|0;c[g>>2]=sb;gb=c[t>>2]|0;do{if((gb|0)<(sb|0)){a[Ua]=a[(d[Ua]|0)+(p+24)|0]|0;mc=c[g>>2]|0;if((mc|0)>=256){kd=0;break}c[g>>2]=mc<<8;mc=c[t>>2]<<8;c[t>>2]=mc;Bb=c[N>>2]|0;if(Bb>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[Bb]|mc}c[N>>2]=Bb+1;kd=0}else{c[t>>2]=gb-sb;a[Ua]=a[(d[Ua]|0)+(p+280)|0]|0;c[g>>2]=Ab;if((Ab|0)>=256){kd=1;break}c[g>>2]=Ab<<8;Bb=c[t>>2]<<8;c[t>>2]=Bb;mc=c[N>>2]|0;if(mc>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[mc]|Bb}c[N>>2]=mc+1;kd=1}}while(0);ld=(id^-kd)+kd|0}else{Ab=M-$|0;c[t>>2]=Ab;a[v]=a[r+272+Ta|0]|0;c[g>>2]=_;if((_|0)>=256){ld=0;break}c[g>>2]=_<<8;Ua=Ab<<8;c[t>>2]=Ua;Ab=c[N>>2]|0;if(Ab>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[Ab]|Ua}c[N>>2]=Ab+1;ld=0}}while(0);c[p+7548+(E*533028|0)+8+(Sc*66624|0)+(O*16656|0)+16>>2]=ld;O=O+1|0;if((O|0)>=4){break}}md=c[X>>2]|0;Sc=Sc+1|0;}while((Sc|0)<(md|0));Qc=md;Rc=c[Q>>2]|0}else{Qc=rb;Rc=z}}while(0);O=E+1|0;if((O|0)<(Rc|0)){E=O;rb=Qc;z=Rc}else{break}}}if((c[B>>2]|0)==0){nd=v;A=393;break a}else{break a}}else{z=D-y|0;c[t>>2]=z;a[v]=a[r+272+u|0]|0;c[g>>2]=q;if((q|0)>=256){kb=0;break}c[g>>2]=q<<8;rb=z<<8;c[t>>2]=rb;z=o+540|0;E=c[z>>2]|0;if(E>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[E]|rb}c[z>>2]=E+1;kb=0}}while(0);yDb(c[o+4>>2]|0,16,1965128,(ga=i,i=i+8|0,c[ga>>2]=kb,ga)|0);i=ga;ha=-1;i=k;return ha|0}}while(0);if((A|0)==13){nd=o+3092|0;A=393}j:do{if((A|0)==393){kb=c[g>>2]|0;r=d[nd]|0;B=(ba(r,kb)|0)>>8;Rc=kb-B|0;c[g>>2]=Rc;kb=c[t>>2]|0;do{if((kb|0)<(Rc|0)){Qc=a[p+24+r|0]|0;a[nd]=Qc;if((Rc|0)>=256){od=Rc;pd=Qc;qd=kb;break}md=Rc<<8;c[g>>2]=md;Sc=kb<<8;c[t>>2]=Sc;ld=o+540|0;kd=c[ld>>2]|0;if(kd>>>0<(c[o+544>>2]|0)>>>0){id=d[kd]|Sc;c[t>>2]=id;rd=id}else{rd=Sc}c[ld>>2]=kd+1;od=md;pd=Qc;qd=rd}else{Qc=kb-Rc|0;c[t>>2]=Qc;md=a[p+280+r|0]|0;a[nd]=md;c[g>>2]=B;if((B|0)<256){kd=B<<8;c[g>>2]=kd;ld=Qc<<8;c[t>>2]=ld;Sc=o+540|0;id=c[Sc>>2]|0;if(id>>>0<(c[o+544>>2]|0)>>>0){jd=d[id]|ld;c[t>>2]=jd;sd=jd}else{sd=ld}c[Sc>>2]=id+1;td=kd;ud=sd}else{td=B;ud=Qc}Qc=o+7544|0;k:do{if((c[Qc>>2]|0)>0){kd=o+540|0;id=o+544|0;Sc=o+3093|0;ld=0;jd=td;Wc=md;cd=ud;while(1){fd=Wc&255;ed=(ba(fd,jd)|0)>>8;Yc=jd-ed|0;c[g>>2]=Yc;do{if((cd|0)<(Yc|0)){a[nd]=a[p+24+fd|0]|0;if((Yc|0)>=256){vd=0;break}c[g>>2]=Yc<<8;Xc=cd<<8;c[t>>2]=Xc;bd=c[kd>>2]|0;if(bd>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[bd]|Xc}c[kd>>2]=bd+1;vd=0}else{bd=cd-Yc|0;c[t>>2]=bd;a[nd]=a[p+280+fd|0]|0;c[g>>2]=ed;if((ed|0)>=256){vd=1;break}c[g>>2]=ed<<8;Xc=bd<<8;c[t>>2]=Xc;bd=c[kd>>2]|0;if(bd>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[bd]|Xc}c[kd>>2]=bd+1;vd=1}}while(0);c[p+7548+(ld*533028|0)+533008>>2]=vd;ed=c[g>>2]|0;fd=d[nd]|0;Yc=(ba(fd,ed)|0)>>8;bd=ed-Yc|0;c[g>>2]=bd;ed=c[t>>2]|0;do{if((ed|0)<(bd|0)){a[nd]=a[p+24+fd|0]|0;if((bd|0)<256){Xc=bd<<8;c[g>>2]=Xc;ad=ed<<8;c[t>>2]=ad;$c=c[kd>>2]|0;if($c>>>0<(c[id>>2]|0)>>>0){_c=d[$c]|ad;c[t>>2]=_c;wd=_c}else{wd=ad}c[kd>>2]=$c+1;xd=Xc;yd=wd}else{xd=bd;yd=ed}Xc=a[Sc]|0;$c=(ba(Xc&255,xd)|0)>>8;ad=xd-$c|0;c[g>>2]=ad;if((yd|0)<(ad|0)){zd=0;Ad=Sc;Bd=Xc}else{Xc=1;_c=Sc;Vc=$c;$c=ad;ad=yd;while(1){c[t>>2]=ad-$c;a[_c]=a[(d[_c]|0)+(p+280)|0]|0;c[g>>2]=Vc;if((Vc|0)<256){Uc=Vc<<8;c[g>>2]=Uc;Tc=c[t>>2]<<8;c[t>>2]=Tc;Mc=c[kd>>2]|0;if(Mc>>>0<(c[id>>2]|0)>>>0){yc=d[Mc]|Tc;c[t>>2]=yc;Cd=yc}else{Cd=Tc}c[kd>>2]=Mc+1;Dd=Uc;Ed=Cd}else{Dd=Vc;Ed=c[t>>2]|0}Uc=Xc+1|0;Fd=((Xc|0)>9?10:Uc)+(p+3092)|0;Mc=(ba(d[Fd]|0,Dd)|0)>>8;Tc=Dd-Mc|0;c[g>>2]=Tc;if((Ed|0)<(Tc|0)){break}else{Xc=Uc;_c=Fd;Vc=Mc;$c=Tc;ad=Ed}}zd=Xc;Ad=Fd;Bd=a[Fd]|0}a[Ad]=a[(Bd&255)+(p+24)|0]|0;ad=c[g>>2]|0;if((ad|0)<256){$c=ad<<8;c[g>>2]=$c;Vc=c[t>>2]<<8;c[t>>2]=Vc;_c=c[kd>>2]|0;if(_c>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[_c]|Vc}c[kd>>2]=_c+1;Gd=$c}else{Gd=ad}if((zd|0)>0){Hd=2;Id=zd;Jd=Gd}else{Kd=4;break}while(1){ad=Id-1|0;$c=((ad|0)>9?31:Id+21|0)+(p+3092)|0;_c=(ba(d[$c]|0,Jd)|0)>>8;Vc=Jd-_c|0;c[g>>2]=Vc;Tc=c[t>>2]|0;do{if((Tc|0)<(Vc|0)){a[$c]=a[(d[$c]|0)+(p+24)|0]|0;Mc=c[g>>2]|0;if((Mc|0)>=256){Ld=0;Md=Mc;break}Uc=Mc<<8;c[g>>2]=Uc;Mc=c[t>>2]<<8;c[t>>2]=Mc;yc=c[kd>>2]|0;if(yc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[yc]|Mc}c[kd>>2]=yc+1;Ld=0;Md=Uc}else{c[t>>2]=Tc-Vc;a[$c]=a[(d[$c]|0)+(p+280)|0]|0;c[g>>2]=_c;if((_c|0)>=256){Ld=1;Md=_c;break}Uc=_c<<8;c[g>>2]=Uc;yc=c[t>>2]<<8;c[t>>2]=yc;Mc=c[kd>>2]|0;if(Mc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[Mc]|yc}c[kd>>2]=Mc+1;Ld=1;Md=Uc}}while(0);Nd=(Ld|Hd)<<1;if((ad|0)>0){Hd=Nd;Id=ad;Jd=Md}else{break}}Kd=Nd+2|0}else{Xc=ed-bd|0;c[t>>2]=Xc;a[nd]=a[p+280+fd|0]|0;c[g>>2]=Yc;if((Yc|0)>=256){Kd=2;break}c[g>>2]=Yc<<8;_c=Xc<<8;c[t>>2]=_c;Xc=c[kd>>2]|0;if(Xc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[Xc]|_c}c[kd>>2]=Xc+1;Kd=2}}while(0);if(Kd>>>0>8>>>0|(Kd|0)==0){ha=-1;break}c[p+7548+(ld*533028|0)+533e3>>2]=Kd;if((Kd|1)>>>0<3>>>0){Od=0}else{Yc=(Kd|0)/2|0;fd=0;while(1){bd=c[g>>2]|0;ed=d[nd]|0;Xc=(ba(ed,bd)|0)>>8;_c=bd-Xc|0;c[g>>2]=_c;bd=c[t>>2]|0;l:do{if((bd|0)<(_c|0)){a[nd]=a[p+24+ed|0]|0;if((_c|0)<256){$c=_c<<8;c[g>>2]=$c;Vc=bd<<8;c[t>>2]=Vc;Tc=c[kd>>2]|0;if(Tc>>>0<(c[id>>2]|0)>>>0){Uc=d[Tc]|Vc;c[t>>2]=Uc;Pd=Uc}else{Pd=Vc}c[kd>>2]=Tc+1;Qd=$c;Rd=Pd}else{Qd=_c;Rd=bd}$c=a[Sc]|0;Tc=(ba($c&255,Qd)|0)>>8;Vc=Qd-Tc|0;c[g>>2]=Vc;if((Rd|0)<(Vc|0)){Sd=0;Td=Sc;Ud=$c}else{$c=1;Uc=Sc;Mc=Tc;Tc=Vc;Vc=Rd;while(1){c[t>>2]=Vc-Tc;a[Uc]=a[(d[Uc]|0)+(p+280)|0]|0;c[g>>2]=Mc;if((Mc|0)<256){yc=Mc<<8;c[g>>2]=yc;Pc=c[t>>2]<<8;c[t>>2]=Pc;Oc=c[kd>>2]|0;if(Oc>>>0<(c[id>>2]|0)>>>0){Nc=d[Oc]|Pc;c[t>>2]=Nc;Vd=Nc}else{Vd=Pc}c[kd>>2]=Oc+1;Wd=yc;Xd=Vd}else{Wd=Mc;Xd=c[t>>2]|0}yc=$c+1|0;Yd=(($c|0)>9?10:yc)+(p+3092)|0;Oc=(ba(d[Yd]|0,Wd)|0)>>8;Pc=Wd-Oc|0;c[g>>2]=Pc;if((Xd|0)<(Pc|0)){break}else{$c=yc;Uc=Yd;Mc=Oc;Tc=Pc;Vc=Xd}}Sd=$c;Td=Yd;Ud=a[Yd]|0}a[Td]=a[(Ud&255)+(p+24)|0]|0;Vc=c[g>>2]|0;if((Vc|0)<256){Tc=Vc<<8;c[g>>2]=Tc;Mc=c[t>>2]<<8;c[t>>2]=Mc;Uc=c[kd>>2]|0;if(Uc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[Uc]|Mc}c[kd>>2]=Uc+1;Zd=Tc}else{Zd=Vc}if((Sd|0)>0){_d=2;$d=Sd;ae=Zd}else{be=1;break}while(1){Vc=$d-1|0;Tc=((Vc|0)>9?31:$d+21|0)+(p+3092)|0;Uc=(ba(d[Tc]|0,ae)|0)>>8;Mc=ae-Uc|0;c[g>>2]=Mc;ad=c[t>>2]|0;do{if((ad|0)<(Mc|0)){a[Tc]=a[(d[Tc]|0)+(p+24)|0]|0;Pc=c[g>>2]|0;if((Pc|0)>=256){ce=0;de=Pc;break}Oc=Pc<<8;c[g>>2]=Oc;Pc=c[t>>2]<<8;c[t>>2]=Pc;yc=c[kd>>2]|0;if(yc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[yc]|Pc}c[kd>>2]=yc+1;ce=0;de=Oc}else{c[t>>2]=ad-Mc;a[Tc]=a[(d[Tc]|0)+(p+280)|0]|0;c[g>>2]=Uc;if((Uc|0)>=256){ce=1;de=Uc;break}Oc=Uc<<8;c[g>>2]=Oc;yc=c[t>>2]<<8;c[t>>2]=yc;Pc=c[kd>>2]|0;if(Pc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[Pc]|yc}c[kd>>2]=Pc+1;ce=1;de=Oc}}while(0);Uc=ce|_d;if((Vc|0)<=0){be=Uc;break l}_d=Uc<<1;$d=Vc;ae=de}}else{$c=bd-_c|0;c[t>>2]=$c;a[nd]=a[p+280+ed|0]|0;c[g>>2]=Xc;if((Xc|0)>=256){be=0;break}c[g>>2]=Xc<<8;Uc=$c<<8;c[t>>2]=Uc;$c=c[kd>>2]|0;if($c>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[$c]|Uc}c[kd>>2]=$c+1;be=0}}while(0);Xc=(ba(be,1-(Yc<<1&2)|0)|0)&255;a[p+7548+(ld*533028|0)+533004+Yc|0]=Xc;ed=(Xc<<24>>24)+fd|0;Xc=Yc-1|0;if((Xc|0)==0){Od=ed;break}else{Yc=Xc;fd=ed}}}a[p+7548+(ld*533028|0)+533004|0]=32-Od;fd=ld+1|0;Yc=c[Qc>>2]|0;ed=c[g>>2]|0;Xc=a[nd]|0;_c=c[t>>2]|0;if((fd|0)<(((Yc|0)>2?2:Yc)|0)){ld=fd;jd=ed;Wc=Xc;cd=_c}else{ee=ed;fe=Xc;ge=_c;break k}}i=k;return ha|0}else{ee=td;fe=md;ge=ud}}while(0);c[o+1606612>>2]=c[o+1073584>>2];c[o+1606604>>2]=c[o+1073576>>2];md=o+1073580|0;Qc=o+1606608|0;x=d[md]|d[md+1|0]<<8|d[md+2|0]<<16|d[md+3|0]<<24|0;a[Qc]=x;x=x>>8;a[Qc+1|0]=x;x=x>>8;a[Qc+2|0]=x;x=x>>8;a[Qc+3|0]=x;od=ee;pd=fe;qd=ge}}while(0);B=pd&255;r=(ba(B,od)|0)>>8;Rc=od-r|0;c[g>>2]=Rc;if((qd|0)<(Rc|0)){a[nd]=a[p+24+B|0]|0;if((Rc|0)>=256){break}c[g>>2]=Rc<<8;kb=qd<<8;c[t>>2]=kb;Qc=o+540|0;md=c[Qc>>2]|0;if(md>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[md]|kb}c[Qc>>2]=md+1;break}md=qd-Rc|0;c[t>>2]=md;Rc=a[p+280+B|0]|0;a[nd]=Rc;c[g>>2]=r;if((r|0)<256){B=r<<8;c[g>>2]=B;Qc=md<<8;c[t>>2]=Qc;kb=o+540|0;cd=c[kb>>2]|0;if(cd>>>0<(c[o+544>>2]|0)>>>0){Wc=d[cd]|Qc;c[t>>2]=Wc;he=Wc}else{he=Qc}c[kb>>2]=cd+1;ie=B;je=he}else{ie=r;je=md}md=Rc&255;Rc=(ba(ie,md)|0)>>8;r=ie-Rc|0;c[g>>2]=r;do{if((je|0)<(r|0)){a[nd]=a[p+24+md|0]|0;if((r|0)<256){B=r<<8;c[g>>2]=B;cd=je<<8;c[t>>2]=cd;kb=o+540|0;Qc=c[kb>>2]|0;if(Qc>>>0<(c[o+544>>2]|0)>>>0){Wc=d[Qc]|cd;c[t>>2]=Wc;ke=Wc}else{ke=cd}c[kb>>2]=Qc+1;le=B;me=ke}else{le=r;me=je}B=o+3093|0;Qc=a[B]|0;kb=(ba(Qc&255,le)|0)>>8;cd=le-kb|0;c[g>>2]=cd;if((me|0)<(cd|0)){ne=0;oe=B;pe=Qc}else{Qc=o+540|0;Wc=o+544|0;jd=1;ld=B;kd=kb;kb=cd;cd=me;while(1){c[t>>2]=cd-kb;a[ld]=a[(d[ld]|0)+(p+280)|0]|0;c[g>>2]=kd;if((kd|0)<256){id=kd<<8;c[g>>2]=id;Sc=c[t>>2]<<8;c[t>>2]=Sc;_c=c[Qc>>2]|0;if(_c>>>0<(c[Wc>>2]|0)>>>0){Xc=d[_c]|Sc;c[t>>2]=Xc;qe=Xc}else{qe=Sc}c[Qc>>2]=_c+1;re=id;te=qe}else{re=kd;te=c[t>>2]|0}id=jd+1|0;ue=((jd|0)>9?10:id)+(p+3092)|0;_c=(ba(d[ue]|0,re)|0)>>8;Sc=re-_c|0;c[g>>2]=Sc;if((te|0)<(Sc|0)){break}else{jd=id;ld=ue;kd=_c;kb=Sc;cd=te}}ne=jd;oe=ue;pe=a[ue]|0}a[oe]=a[(pe&255)+(p+24)|0]|0;cd=c[g>>2]|0;if((cd|0)<256){kb=cd<<8;c[g>>2]=kb;kd=c[t>>2]<<8;c[t>>2]=kd;ld=o+540|0;Qc=c[ld>>2]|0;if(Qc>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Qc]|kd}c[ld>>2]=Qc+1;ve=kb}else{ve=cd}if((ne|0)>0){cd=o+540|0;kb=o+544|0;Qc=2;ld=ne;kd=ve;while(1){Wc=ld-1|0;Sc=((Wc|0)>9?31:ld+21|0)+(p+3092)|0;_c=(ba(d[Sc]|0,kd)|0)>>8;id=kd-_c|0;c[g>>2]=id;Xc=c[t>>2]|0;do{if((Xc|0)<(id|0)){a[Sc]=a[(d[Sc]|0)+(p+24)|0]|0;ed=c[g>>2]|0;if((ed|0)>=256){we=0;xe=ed;break}fd=ed<<8;c[g>>2]=fd;ed=c[t>>2]<<8;c[t>>2]=ed;Yc=c[cd>>2]|0;if(Yc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Yc]|ed}c[cd>>2]=Yc+1;we=0;xe=fd}else{c[t>>2]=Xc-id;a[Sc]=a[(d[Sc]|0)+(p+280)|0]|0;c[g>>2]=_c;if((_c|0)>=256){we=1;xe=_c;break}fd=_c<<8;c[g>>2]=fd;Yc=c[t>>2]<<8;c[t>>2]=Yc;ed=c[cd>>2]|0;if(ed>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[ed]|Yc}c[cd>>2]=ed+1;we=1;xe=fd}}while(0);ye=we|Qc;if((Wc|0)<=0){break}Qc=ye<<1;ld=Wc;kd=xe}if((ye-1|0)>>>0<8>>>0){ze=ye}else{Ae=ye;break}}else{ze=1}kd=o+7372|0;c[kd>>2]=ze;ld=o+7544|0;Qc=c[ld>>2]|0;if((Qc|0)<=0){break j}cd=o+540|0;kb=o+544|0;jd=0;_c=ze;Sc=Qc;while(1){m:do{if((_c|0)>0){if((jd|0)==2){Qc=0;while(1){id=(Qc|0)!=0|0;do{c[p+1073612+(Qc*66624|0)+(id*16656|0)+16>>2]=c[p+540584+(Qc*66624|0)+(id*16656|0)+16>>2];id=id+1|0;}while((id|0)<4);id=c[kd>>2]|0;Xc=Qc+1|0;if((Xc|0)<(id|0)){Qc=Xc}else{Be=id;Ce=Sc;break m}}}else{De=0}do{Qc=p+7548+(jd*533028|0)+8+(De*66624|0)+16672|0;id=p+7548+(jd*533028|0)+8+(De*66624|0)+33328|0;Xc=(De|0)!=0|0;while(1){if((Xc|0)==2){c[id>>2]=c[Qc>>2];Xc=3;continue}fd=c[g>>2]|0;ed=d[nd]|0;Yc=(ba(ed,fd)|0)>>8;bd=fd-Yc|0;c[g>>2]=bd;fd=c[t>>2]|0;do{if((fd|0)<(bd|0)){a[nd]=a[p+24+ed|0]|0;if((bd|0)<256){$c=bd<<8;c[g>>2]=$c;Uc=fd<<8;c[t>>2]=Uc;Tc=c[cd>>2]|0;if(Tc>>>0<(c[kb>>2]|0)>>>0){Mc=d[Tc]|Uc;c[t>>2]=Mc;Ee=Mc}else{Ee=Uc}c[cd>>2]=Tc+1;Fe=$c;Ge=Ee}else{Fe=bd;Ge=fd}$c=a[B]|0;Tc=(ba($c&255,Fe)|0)>>8;Uc=Fe-Tc|0;c[g>>2]=Uc;if((Ge|0)<(Uc|0)){He=0;Ie=B;Je=$c}else{$c=1;Mc=B;ad=Tc;Tc=Uc;Uc=Ge;while(1){c[t>>2]=Uc-Tc;a[Mc]=a[(d[Mc]|0)+(p+280)|0]|0;c[g>>2]=ad;if((ad|0)<256){Oc=ad<<8;c[g>>2]=Oc;Pc=c[t>>2]<<8;c[t>>2]=Pc;yc=c[cd>>2]|0;if(yc>>>0<(c[kb>>2]|0)>>>0){Nc=d[yc]|Pc;c[t>>2]=Nc;Ke=Nc}else{Ke=Pc}c[cd>>2]=yc+1;Le=Oc;Me=Ke}else{Le=ad;Me=c[t>>2]|0}Oc=$c+1|0;Ne=(($c|0)>9?10:Oc)+(p+3092)|0;yc=(ba(d[Ne]|0,Le)|0)>>8;Pc=Le-yc|0;c[g>>2]=Pc;if((Me|0)<(Pc|0)){break}else{$c=Oc;Mc=Ne;ad=yc;Tc=Pc;Uc=Me}}He=$c;Ie=Ne;Je=a[Ne]|0}a[Ie]=a[(Je&255)+(p+24)|0]|0;Uc=c[g>>2]|0;if((Uc|0)<256){Tc=Uc<<8;c[g>>2]=Tc;ad=c[t>>2]<<8;c[t>>2]=ad;Mc=c[cd>>2]|0;if(Mc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Mc]|ad}c[cd>>2]=Mc+1;Oe=Tc}else{Oe=Uc}n:do{if((He|0)>0){Uc=2;Tc=He;Mc=Oe;while(1){ad=Tc-1|0;Vc=((ad|0)>9?31:Tc+21|0)+(p+3092)|0;Pc=(ba(d[Vc]|0,Mc)|0)>>8;yc=Mc-Pc|0;c[g>>2]=yc;Oc=c[t>>2]|0;do{if((Oc|0)<(yc|0)){a[Vc]=a[(d[Vc]|0)+(p+24)|0]|0;Nc=c[g>>2]|0;if((Nc|0)>=256){Pe=0;Qe=Nc;break}Lc=Nc<<8;c[g>>2]=Lc;Nc=c[t>>2]<<8;c[t>>2]=Nc;Ec=c[cd>>2]|0;if(Ec>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Ec]|Nc}c[cd>>2]=Ec+1;Pe=0;Qe=Lc}else{c[t>>2]=Oc-yc;a[Vc]=a[(d[Vc]|0)+(p+280)|0]|0;c[g>>2]=Pc;if((Pc|0)>=256){Pe=1;Qe=Pc;break}Lc=Pc<<8;c[g>>2]=Lc;Ec=c[t>>2]<<8;c[t>>2]=Ec;Nc=c[cd>>2]|0;if(Nc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Nc]|Ec}c[cd>>2]=Nc+1;Pe=1;Qe=Lc}}while(0);Pc=Pe|Uc;if((ad|0)<=0){Re=Pc;Se=Qe;break n}Uc=Pc<<1;Tc=ad;Mc=Qe}}else{Re=1;Se=Oe}}while(0);$c=((He|0)>10?21:He+11|0)+(p+3092)|0;Mc=(ba(d[$c]|0,Se)|0)>>8;Tc=Se-Mc|0;c[g>>2]=Tc;Uc=c[t>>2]|0;do{if((Uc|0)<(Tc|0)){a[$c]=a[(d[$c]|0)+(p+24)|0]|0;Pc=c[g>>2]|0;if((Pc|0)>=256){Te=0;break}c[g>>2]=Pc<<8;Pc=c[t>>2]<<8;c[t>>2]=Pc;Vc=c[cd>>2]|0;if(Vc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Vc]|Pc}c[cd>>2]=Vc+1;Te=0}else{c[t>>2]=Uc-Tc;a[$c]=a[(d[$c]|0)+(p+280)|0]|0;c[g>>2]=Mc;if((Mc|0)>=256){Te=1;break}c[g>>2]=Mc<<8;Vc=c[t>>2]<<8;c[t>>2]=Vc;Pc=c[cd>>2]|0;if(Pc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Pc]|Vc}c[cd>>2]=Pc+1;Te=1}}while(0);Ue=(Re^-Te)+Te|0}else{Mc=fd-bd|0;c[t>>2]=Mc;a[nd]=a[p+280+ed|0]|0;c[g>>2]=Yc;if((Yc|0)>=256){Ue=0;break}c[g>>2]=Yc<<8;$c=Mc<<8;c[t>>2]=$c;Mc=c[cd>>2]|0;if(Mc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Mc]|$c}c[cd>>2]=Mc+1;Ue=0}}while(0);c[p+7548+(jd*533028|0)+8+(De*66624|0)+(Xc*16656|0)+16>>2]=Ue;Xc=Xc+1|0;if((Xc|0)>=4){break}}Ve=c[kd>>2]|0;De=De+1|0;}while((De|0)<(Ve|0));Be=Ve;Ce=c[ld>>2]|0}else{Be=_c;Ce=Sc}}while(0);Wc=jd+1|0;if((Wc|0)<(Ce|0)){jd=Wc;_c=Be;Sc=Ce}else{break j}}}else{Sc=je-r|0;c[t>>2]=Sc;a[nd]=a[p+280+md|0]|0;c[g>>2]=Rc;if((Rc|0)>=256){Ae=0;break}c[g>>2]=Rc<<8;_c=Sc<<8;c[t>>2]=_c;Sc=o+540|0;jd=c[Sc>>2]|0;if(jd>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[jd]|_c}c[Sc>>2]=jd+1;Ae=0}}while(0);yDb(c[o+4>>2]|0,16,1965128,(ga=i,i=i+8|0,c[ga>>2]=Ae,ga)|0);i=ga;ha=-1;i=k;return ha|0}}while(0);Ae=o+3092|0;nd=c[g>>2]|0;je=d[Ae]|0;Ce=(ba(je,nd)|0)>>8;Be=nd-Ce|0;c[g>>2]=Be;nd=c[t>>2]|0;do{if((nd|0)<(Be|0)){a[Ae]=a[p+24+je|0]|0;if((Be|0)<256){Ve=Be<<8;c[g>>2]=Ve;De=nd<<8;c[t>>2]=De;Ue=o+540|0;Te=c[Ue>>2]|0;if(Te>>>0<(c[o+544>>2]|0)>>>0){Re=d[Te]|De;c[t>>2]=Re;We=Re}else{We=De}c[Ue>>2]=Te+1;Xe=Ve;Ye=We}else{Xe=Be;Ye=nd}Ve=o+3093|0;Te=a[Ve]|0;Ue=(ba(Te&255,Xe)|0)>>8;De=Xe-Ue|0;c[g>>2]=De;if((Ye|0)<(De|0)){Ze=0;_e=Ve;$e=Te}else{Te=o+540|0;Re=o+544|0;Se=1;He=Ve;Ve=Ue;Ue=De;De=Ye;while(1){c[t>>2]=De-Ue;a[He]=a[(d[He]|0)+(p+280)|0]|0;c[g>>2]=Ve;if((Ve|0)<256){Oe=Ve<<8;c[g>>2]=Oe;Qe=c[t>>2]<<8;c[t>>2]=Qe;Pe=c[Te>>2]|0;if(Pe>>>0<(c[Re>>2]|0)>>>0){Je=d[Pe]|Qe;c[t>>2]=Je;af=Je}else{af=Qe}c[Te>>2]=Pe+1;bf=Oe;cf=af}else{bf=Ve;cf=c[t>>2]|0}Oe=Se+1|0;df=((Se|0)>9?10:Oe)+(p+3092)|0;Pe=(ba(d[df]|0,bf)|0)>>8;Qe=bf-Pe|0;c[g>>2]=Qe;if((cf|0)<(Qe|0)){break}else{Se=Oe;He=df;Ve=Pe;Ue=Qe;De=cf}}Ze=Se;_e=df;$e=a[df]|0}a[_e]=a[($e&255)+(p+24)|0]|0;De=c[g>>2]|0;if((De|0)<256){Ue=De<<8;c[g>>2]=Ue;Ve=c[t>>2]<<8;c[t>>2]=Ve;He=o+540|0;Te=c[He>>2]|0;if(Te>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Te]|Ve}c[He>>2]=Te+1;ef=Ue}else{ef=De}o:do{if((Ze|0)>0){De=o+540|0;Ue=o+544|0;Te=2;He=Ze;Ve=ef;while(1){Re=He-1|0;Qe=((Re|0)>9?31:He+21|0)+(p+3092)|0;Pe=(ba(d[Qe]|0,Ve)|0)>>8;Oe=Ve-Pe|0;c[g>>2]=Oe;Je=c[t>>2]|0;do{if((Je|0)<(Oe|0)){a[Qe]=a[(d[Qe]|0)+(p+24)|0]|0;Ie=c[g>>2]|0;if((Ie|0)>=256){ff=0;gf=Ie;break}Ne=Ie<<8;c[g>>2]=Ne;Ie=c[t>>2]<<8;c[t>>2]=Ie;Me=c[De>>2]|0;if(Me>>>0<(c[Ue>>2]|0)>>>0){c[t>>2]=d[Me]|Ie}c[De>>2]=Me+1;ff=0;gf=Ne}else{c[t>>2]=Je-Oe;a[Qe]=a[(d[Qe]|0)+(p+280)|0]|0;c[g>>2]=Pe;if((Pe|0)>=256){ff=1;gf=Pe;break}Ne=Pe<<8;c[g>>2]=Ne;Me=c[t>>2]<<8;c[t>>2]=Me;Ie=c[De>>2]|0;if(Ie>>>0<(c[Ue>>2]|0)>>>0){c[t>>2]=d[Ie]|Me}c[De>>2]=Ie+1;ff=1;gf=Ne}}while(0);Pe=ff|Te;if((Re|0)<=0){hf=Pe;jf=gf;break o}Te=Pe<<1;He=Re;Ve=gf}}else{hf=1;jf=ef}}while(0);Se=((Ze|0)>10?21:Ze+11|0)+(p+3092)|0;Ve=(ba(d[Se]|0,jf)|0)>>8;He=jf-Ve|0;c[g>>2]=He;Te=c[t>>2]|0;do{if((Te|0)<(He|0)){a[Se]=a[(d[Se]|0)+(p+24)|0]|0;De=c[g>>2]|0;if((De|0)>=256){kf=0;lf=De;break}Ue=De<<8;c[g>>2]=Ue;De=c[t>>2]<<8;c[t>>2]=De;Pe=o+540|0;Qe=c[Pe>>2]|0;if(Qe>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Qe]|De}c[Pe>>2]=Qe+1;kf=0;lf=Ue}else{c[t>>2]=Te-He;a[Se]=a[(d[Se]|0)+(p+280)|0]|0;c[g>>2]=Ve;if((Ve|0)>=256){kf=1;lf=Ve;break}Ue=Ve<<8;c[g>>2]=Ue;Qe=c[t>>2]<<8;c[t>>2]=Qe;Pe=o+540|0;De=c[Pe>>2]|0;if(De>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[De]|Qe}c[Pe>>2]=De+1;kf=1;lf=Ue}}while(0);mf=(hf^-kf)+kf|0;nf=lf}else{Ve=nd-Be|0;c[t>>2]=Ve;a[Ae]=a[p+280+je|0]|0;c[g>>2]=Ce;if((Ce|0)>=256){mf=0;nf=Ce;break}Se=Ce<<8;c[g>>2]=Se;He=Ve<<8;c[t>>2]=He;Ve=o+540|0;Te=c[Ve>>2]|0;if(Te>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Te]|He}c[Ve>>2]=Te+1;mf=0;nf=Se}}while(0);Ce=o+7360|0;je=(c[Ce>>2]|0)+mf|0;c[Ce>>2]=je;mf=o+4|0;Be=c[mf>>2]|0;if(je>>>0>1>>>0){yDb(Be,16,2350576,(ga=i,i=i+8|0,c[ga>>2]=je,ga)|0);i=ga;ha=-1;i=k;return ha|0}je=o+7480|0;nd=c[Be+120>>2]>>c[je>>2];lf=o+7484|0;kf=c[Be+124>>2]>>c[lf>>2];hf=o+7372|0;jf=c[hf>>2]|0;if((((nd|0)>(kf|0)?kf:nd)>>jf-1|0)<2){yDb(Be,16,2330216,(ga=i,i=i+8|0,c[ga>>2]=jf,ga)|0);i=ga;ha=-1;i=k;return ha|0}jf=d[Ae]|0;Be=(ba(jf,nf)|0)>>8;nd=nf-Be|0;c[g>>2]=nd;nf=c[t>>2]|0;do{if((nf|0)<(nd|0)){a[Ae]=a[p+24+jf|0]|0;if((nd|0)<256){kf=nd<<8;c[g>>2]=kf;Ze=nf<<8;c[t>>2]=Ze;ef=o+540|0;gf=c[ef>>2]|0;if(gf>>>0<(c[o+544>>2]|0)>>>0){ff=d[gf]|Ze;c[t>>2]=ff;of=ff}else{of=Ze}c[ef>>2]=gf+1;pf=kf;qf=of}else{pf=nd;qf=nf}kf=o+3093|0;gf=a[kf]|0;ef=(ba(gf&255,pf)|0)>>8;Ze=pf-ef|0;c[g>>2]=Ze;if((qf|0)<(Ze|0)){rf=0;sf=kf;tf=gf}else{gf=o+540|0;ff=o+544|0;$e=1;_e=kf;kf=ef;ef=Ze;Ze=qf;while(1){c[t>>2]=Ze-ef;a[_e]=a[(d[_e]|0)+(p+280)|0]|0;c[g>>2]=kf;if((kf|0)<256){df=kf<<8;c[g>>2]=df;cf=c[t>>2]<<8;c[t>>2]=cf;bf=c[gf>>2]|0;if(bf>>>0<(c[ff>>2]|0)>>>0){af=d[bf]|cf;c[t>>2]=af;uf=af}else{uf=cf}c[gf>>2]=bf+1;vf=df;wf=uf}else{vf=kf;wf=c[t>>2]|0}df=$e+1|0;xf=(($e|0)>9?10:df)+(p+3092)|0;bf=(ba(d[xf]|0,vf)|0)>>8;cf=vf-bf|0;c[g>>2]=cf;if((wf|0)<(cf|0)){break}else{$e=df;_e=xf;kf=bf;ef=cf;Ze=wf}}rf=$e;sf=xf;tf=a[xf]|0}a[sf]=a[(tf&255)+(p+24)|0]|0;Ze=c[g>>2]|0;if((Ze|0)<256){ef=Ze<<8;c[g>>2]=ef;kf=c[t>>2]<<8;c[t>>2]=kf;_e=o+540|0;gf=c[_e>>2]|0;if(gf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[gf]|kf}c[_e>>2]=gf+1;yf=ef}else{yf=Ze}p:do{if((rf|0)>0){Ze=o+540|0;ef=o+544|0;gf=2;_e=rf;kf=yf;while(1){ff=_e-1|0;cf=((ff|0)>9?31:_e+21|0)+(p+3092)|0;bf=(ba(d[cf]|0,kf)|0)>>8;df=kf-bf|0;c[g>>2]=df;af=c[t>>2]|0;do{if((af|0)<(df|0)){a[cf]=a[(d[cf]|0)+(p+24)|0]|0;Ye=c[g>>2]|0;if((Ye|0)>=256){zf=0;Af=Ye;break}Xe=Ye<<8;c[g>>2]=Xe;Ye=c[t>>2]<<8;c[t>>2]=Ye;We=c[Ze>>2]|0;if(We>>>0<(c[ef>>2]|0)>>>0){c[t>>2]=d[We]|Ye}c[Ze>>2]=We+1;zf=0;Af=Xe}else{c[t>>2]=af-df;a[cf]=a[(d[cf]|0)+(p+280)|0]|0;c[g>>2]=bf;if((bf|0)>=256){zf=1;Af=bf;break}Xe=bf<<8;c[g>>2]=Xe;We=c[t>>2]<<8;c[t>>2]=We;Ye=c[Ze>>2]|0;if(Ye>>>0<(c[ef>>2]|0)>>>0){c[t>>2]=d[Ye]|We}c[Ze>>2]=Ye+1;zf=1;Af=Xe}}while(0);bf=zf|gf;if((ff|0)<=0){Bf=bf;Cf=Af;break p}gf=bf<<1;_e=ff;kf=Af}}else{Bf=1;Cf=yf}}while(0);$e=((rf|0)>10?21:rf+11|0)+(p+3092)|0;kf=(ba(d[$e]|0,Cf)|0)>>8;_e=Cf-kf|0;c[g>>2]=_e;gf=c[t>>2]|0;do{if((gf|0)<(_e|0)){a[$e]=a[(d[$e]|0)+(p+24)|0]|0;Ze=c[g>>2]|0;if((Ze|0)>=256){Df=0;Ef=Ze;break}ef=Ze<<8;c[g>>2]=ef;Ze=c[t>>2]<<8;c[t>>2]=Ze;bf=o+540|0;cf=c[bf>>2]|0;if(cf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[cf]|Ze}c[bf>>2]=cf+1;Df=0;Ef=ef}else{c[t>>2]=gf-_e;a[$e]=a[(d[$e]|0)+(p+280)|0]|0;c[g>>2]=kf;if((kf|0)>=256){Df=1;Ef=kf;break}ef=kf<<8;c[g>>2]=ef;cf=c[t>>2]<<8;c[t>>2]=cf;bf=o+540|0;Ze=c[bf>>2]|0;if(Ze>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Ze]|cf}c[bf>>2]=Ze+1;Df=1;Ef=ef}}while(0);Ff=(Bf^-Df)+Df|0;Gf=Ef;Hf=a[Ae]|0;If=c[t>>2]|0}else{kf=nf-nd|0;c[t>>2]=kf;$e=a[p+280+jf|0]|0;a[Ae]=$e;c[g>>2]=Be;if((Be|0)>=256){Ff=0;Gf=Be;Hf=$e;If=kf;break}_e=Be<<8;c[g>>2]=_e;gf=kf<<8;c[t>>2]=gf;kf=o+540|0;ef=c[kf>>2]|0;if(ef>>>0<(c[o+544>>2]|0)>>>0){Ze=d[ef]|gf;c[t>>2]=Ze;Jf=Ze}else{Jf=gf}c[kf>>2]=ef+1;Ff=0;Gf=_e;Hf=$e;If=Jf}}while(0);Jf=o+7492|0;c[Jf>>2]=(c[Jf>>2]|0)+Ff;Ff=Hf&255;Hf=(ba(Ff,Gf)|0)>>8;Be=Gf-Hf|0;c[g>>2]=Be;do{if((If|0)<(Be|0)){a[Ae]=a[p+24+Ff|0]|0;if((Be|0)<256){Gf=Be<<8;c[g>>2]=Gf;jf=If<<8;c[t>>2]=jf;nd=o+540|0;nf=c[nd>>2]|0;if(nf>>>0<(c[o+544>>2]|0)>>>0){Ef=d[nf]|jf;c[t>>2]=Ef;Kf=Ef}else{Kf=jf}c[nd>>2]=nf+1;Lf=Gf;Mf=Kf}else{Lf=Be;Mf=If}Gf=o+3093|0;nf=a[Gf]|0;nd=(ba(nf&255,Lf)|0)>>8;jf=Lf-nd|0;c[g>>2]=jf;if((Mf|0)<(jf|0)){Nf=0;Of=Gf;Pf=nf}else{nf=o+540|0;Ef=o+544|0;Df=1;Bf=Gf;Gf=nd;nd=jf;jf=Mf;while(1){c[t>>2]=jf-nd;a[Bf]=a[(d[Bf]|0)+(p+280)|0]|0;c[g>>2]=Gf;if((Gf|0)<256){Cf=Gf<<8;c[g>>2]=Cf;rf=c[t>>2]<<8;c[t>>2]=rf;yf=c[nf>>2]|0;if(yf>>>0<(c[Ef>>2]|0)>>>0){Af=d[yf]|rf;c[t>>2]=Af;Qf=Af}else{Qf=rf}c[nf>>2]=yf+1;Rf=Cf;Sf=Qf}else{Rf=Gf;Sf=c[t>>2]|0}Cf=Df+1|0;Tf=((Df|0)>9?10:Cf)+(p+3092)|0;yf=(ba(d[Tf]|0,Rf)|0)>>8;rf=Rf-yf|0;c[g>>2]=rf;if((Sf|0)<(rf|0)){break}else{Df=Cf;Bf=Tf;Gf=yf;nd=rf;jf=Sf}}Nf=Df;Of=Tf;Pf=a[Tf]|0}a[Of]=a[(Pf&255)+(p+24)|0]|0;jf=c[g>>2]|0;if((jf|0)<256){nd=jf<<8;c[g>>2]=nd;Gf=c[t>>2]<<8;c[t>>2]=Gf;Bf=o+540|0;nf=c[Bf>>2]|0;if(nf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[nf]|Gf}c[Bf>>2]=nf+1;Uf=nd}else{Uf=jf}q:do{if((Nf|0)>0){jf=o+540|0;nd=o+544|0;nf=2;Bf=Nf;Gf=Uf;while(1){Ef=Bf-1|0;rf=((Ef|0)>9?31:Bf+21|0)+(p+3092)|0;yf=(ba(d[rf]|0,Gf)|0)>>8;Cf=Gf-yf|0;c[g>>2]=Cf;Af=c[t>>2]|0;do{if((Af|0)<(Cf|0)){a[rf]=a[(d[rf]|0)+(p+24)|0]|0;zf=c[g>>2]|0;if((zf|0)>=256){Vf=0;Wf=zf;break}tf=zf<<8;c[g>>2]=tf;zf=c[t>>2]<<8;c[t>>2]=zf;sf=c[jf>>2]|0;if(sf>>>0<(c[nd>>2]|0)>>>0){c[t>>2]=d[sf]|zf}c[jf>>2]=sf+1;Vf=0;Wf=tf}else{c[t>>2]=Af-Cf;a[rf]=a[(d[rf]|0)+(p+280)|0]|0;c[g>>2]=yf;if((yf|0)>=256){Vf=1;Wf=yf;break}tf=yf<<8;c[g>>2]=tf;sf=c[t>>2]<<8;c[t>>2]=sf;zf=c[jf>>2]|0;if(zf>>>0<(c[nd>>2]|0)>>>0){c[t>>2]=d[zf]|sf}c[jf>>2]=zf+1;Vf=1;Wf=tf}}while(0);yf=Vf|nf;if((Ef|0)<=0){Xf=yf;Yf=Wf;break q}nf=yf<<1;Bf=Ef;Gf=Wf}}else{Xf=1;Yf=Uf}}while(0);Df=((Nf|0)>10?21:Nf+11|0)+(p+3092)|0;Gf=(ba(d[Df]|0,Yf)|0)>>8;Bf=Yf-Gf|0;c[g>>2]=Bf;nf=c[t>>2]|0;do{if((nf|0)<(Bf|0)){a[Df]=a[(d[Df]|0)+(p+24)|0]|0;jf=c[g>>2]|0;if((jf|0)>=256){Zf=0;_f=jf;break}nd=jf<<8;c[g>>2]=nd;jf=c[t>>2]<<8;c[t>>2]=jf;yf=o+540|0;rf=c[yf>>2]|0;if(rf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[rf]|jf}c[yf>>2]=rf+1;Zf=0;_f=nd}else{c[t>>2]=nf-Bf;a[Df]=a[(d[Df]|0)+(p+280)|0]|0;c[g>>2]=Gf;if((Gf|0)>=256){Zf=1;_f=Gf;break}nd=Gf<<8;c[g>>2]=nd;rf=c[t>>2]<<8;c[t>>2]=rf;yf=o+540|0;jf=c[yf>>2]|0;if(jf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[jf]|rf}c[yf>>2]=jf+1;Zf=1;_f=nd}}while(0);$f=(Xf^-Zf)+Zf|0;ag=_f;bg=a[Ae]|0;cg=c[t>>2]|0}else{Gf=If-Be|0;c[t>>2]=Gf;Df=a[p+280+Ff|0]|0;a[Ae]=Df;c[g>>2]=Hf;if((Hf|0)>=256){$f=0;ag=Hf;bg=Df;cg=Gf;break}Bf=Hf<<8;c[g>>2]=Bf;nf=Gf<<8;c[t>>2]=nf;Gf=o+540|0;nd=c[Gf>>2]|0;if(nd>>>0<(c[o+544>>2]|0)>>>0){jf=d[nd]|nf;c[t>>2]=jf;dg=jf}else{dg=nf}c[Gf>>2]=nd+1;$f=0;ag=Bf;bg=Df;cg=dg}}while(0);dg=o+7512|0;c[dg>>2]=(c[dg>>2]|0)+$f;$f=bg&255;bg=(ba($f,ag)|0)>>8;dg=ag-bg|0;c[g>>2]=dg;do{if((cg|0)<(dg|0)){a[Ae]=a[p+24+$f|0]|0;if((dg|0)<256){ag=dg<<8;c[g>>2]=ag;Hf=cg<<8;c[t>>2]=Hf;Ff=o+540|0;Be=c[Ff>>2]|0;if(Be>>>0<(c[o+544>>2]|0)>>>0){If=d[Be]|Hf;c[t>>2]=If;eg=If}else{eg=Hf}c[Ff>>2]=Be+1;fg=ag;gg=eg}else{fg=dg;gg=cg}ag=o+3093|0;Be=a[ag]|0;Ff=(ba(Be&255,fg)|0)>>8;Hf=fg-Ff|0;c[g>>2]=Hf;if((gg|0)<(Hf|0)){hg=0;ig=ag;jg=Be}else{Be=o+540|0;If=o+544|0;_f=1;Zf=ag;ag=Ff;Ff=Hf;Hf=gg;while(1){c[t>>2]=Hf-Ff;a[Zf]=a[(d[Zf]|0)+(p+280)|0]|0;c[g>>2]=ag;if((ag|0)<256){Xf=ag<<8;c[g>>2]=Xf;Yf=c[t>>2]<<8;c[t>>2]=Yf;Nf=c[Be>>2]|0;if(Nf>>>0<(c[If>>2]|0)>>>0){Uf=d[Nf]|Yf;c[t>>2]=Uf;kg=Uf}else{kg=Yf}c[Be>>2]=Nf+1;lg=Xf;mg=kg}else{lg=ag;mg=c[t>>2]|0}Xf=_f+1|0;ng=((_f|0)>9?10:Xf)+(p+3092)|0;Nf=(ba(d[ng]|0,lg)|0)>>8;Yf=lg-Nf|0;c[g>>2]=Yf;if((mg|0)<(Yf|0)){break}else{_f=Xf;Zf=ng;ag=Nf;Ff=Yf;Hf=mg}}hg=_f;ig=ng;jg=a[ng]|0}a[ig]=a[(jg&255)+(p+24)|0]|0;Hf=c[g>>2]|0;if((Hf|0)<256){Ff=Hf<<8;c[g>>2]=Ff;ag=c[t>>2]<<8;c[t>>2]=ag;Zf=o+540|0;Be=c[Zf>>2]|0;if(Be>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Be]|ag}c[Zf>>2]=Be+1;og=Ff}else{og=Hf}r:do{if((hg|0)>0){Hf=o+540|0;Ff=o+544|0;Be=2;Zf=hg;ag=og;while(1){If=Zf-1|0;Yf=((If|0)>9?31:Zf+21|0)+(p+3092)|0;Nf=(ba(d[Yf]|0,ag)|0)>>8;Xf=ag-Nf|0;c[g>>2]=Xf;Uf=c[t>>2]|0;do{if((Uf|0)<(Xf|0)){a[Yf]=a[(d[Yf]|0)+(p+24)|0]|0;Wf=c[g>>2]|0;if((Wf|0)>=256){pg=0;qg=Wf;break}Vf=Wf<<8;c[g>>2]=Vf;Wf=c[t>>2]<<8;c[t>>2]=Wf;Pf=c[Hf>>2]|0;if(Pf>>>0<(c[Ff>>2]|0)>>>0){c[t>>2]=d[Pf]|Wf}c[Hf>>2]=Pf+1;pg=0;qg=Vf}else{c[t>>2]=Uf-Xf;a[Yf]=a[(d[Yf]|0)+(p+280)|0]|0;c[g>>2]=Nf;if((Nf|0)>=256){pg=1;qg=Nf;break}Vf=Nf<<8;c[g>>2]=Vf;Pf=c[t>>2]<<8;c[t>>2]=Pf;Wf=c[Hf>>2]|0;if(Wf>>>0<(c[Ff>>2]|0)>>>0){c[t>>2]=d[Wf]|Pf}c[Hf>>2]=Wf+1;pg=1;qg=Vf}}while(0);Nf=pg|Be;if((If|0)<=0){rg=Nf;sg=qg;break r}Be=Nf<<1;Zf=If;ag=qg}}else{rg=1;sg=og}}while(0);_f=((hg|0)>10?21:hg+11|0)+(p+3092)|0;ag=(ba(d[_f]|0,sg)|0)>>8;Zf=sg-ag|0;c[g>>2]=Zf;Be=c[t>>2]|0;do{if((Be|0)<(Zf|0)){a[_f]=a[(d[_f]|0)+(p+24)|0]|0;Hf=c[g>>2]|0;if((Hf|0)>=256){tg=0;ug=Hf;break}Ff=Hf<<8;c[g>>2]=Ff;Hf=c[t>>2]<<8;c[t>>2]=Hf;Nf=o+540|0;Yf=c[Nf>>2]|0;if(Yf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Yf]|Hf}c[Nf>>2]=Yf+1;tg=0;ug=Ff}else{c[t>>2]=Be-Zf;a[_f]=a[(d[_f]|0)+(p+280)|0]|0;c[g>>2]=ag;if((ag|0)>=256){tg=1;ug=ag;break}Ff=ag<<8;c[g>>2]=Ff;Yf=c[t>>2]<<8;c[t>>2]=Yf;Nf=o+540|0;Hf=c[Nf>>2]|0;if(Hf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Hf]|Yf}c[Nf>>2]=Hf+1;tg=1;ug=Ff}}while(0);vg=(rg^-tg)+tg|0;wg=ug;xg=a[Ae]|0;yg=c[t>>2]|0}else{ag=cg-dg|0;c[t>>2]=ag;_f=a[p+280+$f|0]|0;a[Ae]=_f;c[g>>2]=bg;if((bg|0)>=256){vg=0;wg=bg;xg=_f;yg=ag;break}Zf=bg<<8;c[g>>2]=Zf;Be=ag<<8;c[t>>2]=Be;ag=o+540|0;Ff=c[ag>>2]|0;if(Ff>>>0<(c[o+544>>2]|0)>>>0){Hf=d[Ff]|Be;c[t>>2]=Hf;zg=Hf}else{zg=Be}c[ag>>2]=Ff+1;vg=0;wg=Zf;xg=_f;yg=zg}}while(0);zg=o+7520|0;c[zg>>2]=(c[zg>>2]|0)+vg;vg=xg&255;xg=(ba(vg,wg)|0)>>8;bg=wg-xg|0;c[g>>2]=bg;do{if((yg|0)<(bg|0)){a[Ae]=a[p+24+vg|0]|0;if((bg|0)<256){wg=bg<<8;c[g>>2]=wg;$f=yg<<8;c[t>>2]=$f;dg=o+540|0;cg=c[dg>>2]|0;if(cg>>>0<(c[o+544>>2]|0)>>>0){ug=d[cg]|$f;c[t>>2]=ug;Ag=ug}else{Ag=$f}c[dg>>2]=cg+1;Bg=wg;Cg=Ag}else{Bg=bg;Cg=yg}wg=o+3093|0;cg=a[wg]|0;dg=(ba(cg&255,Bg)|0)>>8;$f=Bg-dg|0;c[g>>2]=$f;if((Cg|0)<($f|0)){Dg=0;Eg=wg;Fg=cg}else{cg=o+540|0;ug=o+544|0;tg=1;rg=wg;wg=dg;dg=$f;$f=Cg;while(1){c[t>>2]=$f-dg;a[rg]=a[(d[rg]|0)+(p+280)|0]|0;c[g>>2]=wg;if((wg|0)<256){sg=wg<<8;c[g>>2]=sg;hg=c[t>>2]<<8;c[t>>2]=hg;og=c[cg>>2]|0;if(og>>>0<(c[ug>>2]|0)>>>0){qg=d[og]|hg;c[t>>2]=qg;Gg=qg}else{Gg=hg}c[cg>>2]=og+1;Hg=sg;Ig=Gg}else{Hg=wg;Ig=c[t>>2]|0}sg=tg+1|0;Jg=((tg|0)>9?10:sg)+(p+3092)|0;og=(ba(d[Jg]|0,Hg)|0)>>8;hg=Hg-og|0;c[g>>2]=hg;if((Ig|0)<(hg|0)){break}else{tg=sg;rg=Jg;wg=og;dg=hg;$f=Ig}}Dg=tg;Eg=Jg;Fg=a[Jg]|0}a[Eg]=a[(Fg&255)+(p+24)|0]|0;$f=c[g>>2]|0;if(($f|0)<256){dg=$f<<8;c[g>>2]=dg;wg=c[t>>2]<<8;c[t>>2]=wg;rg=o+540|0;cg=c[rg>>2]|0;if(cg>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[cg]|wg}c[rg>>2]=cg+1;Kg=dg}else{Kg=$f}s:do{if((Dg|0)>0){$f=o+540|0;dg=o+544|0;cg=2;rg=Dg;wg=Kg;while(1){ug=rg-1|0;hg=((ug|0)>9?31:rg+21|0)+(p+3092)|0;og=(ba(d[hg]|0,wg)|0)>>8;sg=wg-og|0;c[g>>2]=sg;qg=c[t>>2]|0;do{if((qg|0)<(sg|0)){a[hg]=a[(d[hg]|0)+(p+24)|0]|0;pg=c[g>>2]|0;if((pg|0)>=256){Lg=0;Mg=pg;break}jg=pg<<8;c[g>>2]=jg;pg=c[t>>2]<<8;c[t>>2]=pg;ig=c[$f>>2]|0;if(ig>>>0<(c[dg>>2]|0)>>>0){c[t>>2]=d[ig]|pg}c[$f>>2]=ig+1;Lg=0;Mg=jg}else{c[t>>2]=qg-sg;a[hg]=a[(d[hg]|0)+(p+280)|0]|0;c[g>>2]=og;if((og|0)>=256){Lg=1;Mg=og;break}jg=og<<8;c[g>>2]=jg;ig=c[t>>2]<<8;c[t>>2]=ig;pg=c[$f>>2]|0;if(pg>>>0<(c[dg>>2]|0)>>>0){c[t>>2]=d[pg]|ig}c[$f>>2]=pg+1;Lg=1;Mg=jg}}while(0);og=Lg|cg;if((ug|0)<=0){Ng=og;Og=Mg;break s}cg=og<<1;rg=ug;wg=Mg}}else{Ng=1;Og=Kg}}while(0);tg=((Dg|0)>10?21:Dg+11|0)+(p+3092)|0;wg=(ba(d[tg]|0,Og)|0)>>8;rg=Og-wg|0;c[g>>2]=rg;cg=c[t>>2]|0;do{if((cg|0)<(rg|0)){a[tg]=a[(d[tg]|0)+(p+24)|0]|0;$f=c[g>>2]|0;if(($f|0)>=256){Pg=0;break}c[g>>2]=$f<<8;$f=c[t>>2]<<8;c[t>>2]=$f;dg=o+540|0;og=c[dg>>2]|0;if(og>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[og]|$f}c[dg>>2]=og+1;Pg=0}else{c[t>>2]=cg-rg;a[tg]=a[(d[tg]|0)+(p+280)|0]|0;c[g>>2]=wg;if((wg|0)>=256){Pg=1;break}c[g>>2]=wg<<8;og=c[t>>2]<<8;c[t>>2]=og;dg=o+540|0;$f=c[dg>>2]|0;if($f>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[$f]|og}c[dg>>2]=$f+1;Pg=1}}while(0);Qg=(Ng^-Pg)+Pg|0}else{wg=yg-bg|0;c[t>>2]=wg;a[Ae]=a[p+280+vg|0]|0;c[g>>2]=xg;if((xg|0)>=256){Qg=0;break}c[g>>2]=xg<<8;tg=wg<<8;c[t>>2]=tg;wg=o+540|0;rg=c[wg>>2]|0;if(rg>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[rg]|tg}c[wg>>2]=rg+1;Qg=0}}while(0);xg=o+7536|0;vg=(c[xg>>2]|0)+Qg|0;c[xg>>2]=vg;if(vg>>>0>1>>>0){yDb(c[mf>>2]|0,16,2305976,(ga=i,i=i+8|0,c[ga>>2]=vg,ga)|0);i=ga;c[xg>>2]=0;ha=-1;i=k;return ha|0}vg=Tob(f)|0;if((vg|0)<0){ha=vg;i=k;return ha|0}vg=o+2143764|0;Qg=vg;rYa(Qg);Ae=o+7548|0;bg=Ae;yg=o+7464|0;Pg=nYa(Qg,c[o+7552>>2]|0,(16>>>((c[xg>>2]|0)>>>0))+1+((c[hf>>2]|0)*11|0)|0,c[Ae>>2]|0,c[yg>>2]|0)|0;if((Pg|0)<0){ha=Pg;i=k;return ha|0}Pg=o+7544|0;if((c[Pg>>2]|0)>0){Ae=0;do{do{if((c[bg+(Ae*533028|0)+533008>>2]|0)==0){Rg=0}else{if((c[bg+(Ae*533028|0)+533e3>>2]|0)!=6){Rg=0;break}if((a[bg+(Ae*533028|0)+533004|0]|0)!=40){Rg=0;break}if(!((a[bg+(Ae*533028|0)+533005|0]|0)==-10)){Rg=0;break}Rg=(a[bg+(Ae*533028|0)+533006|0]|0)==2|0}}while(0);c[bg+(Ae*533028|0)+533012>>2]=Rg;Ae=Ae+1|0;}while((Ae|0)<(c[Pg>>2]|0))}Hob(p)|0;if((Vob(p)|0)<0){ha=-1;i=k;return ha|0}if((c[f+688>>2]&1|0)!=0){Ae=c[Jf>>2]|0;yDb(f,16,2181672,(ga=i,i=i+16|0,c[ga>>2]=c[o+7348>>2],c[ga+8>>2]=Ae,ga)|0);i=ga}Ae=o+7528|0;Rg=c[Ae>>2]|0;Ng=o+7532|0;Og=c[Ng>>2]|0;t:do{if((Og|0)>0){Dg=0;u:while(1){Kg=0;while(1){if((Kg|0)>=(Rg|0)){break}Mg=OYa(p,0,Kg,Dg)|0;if((Mg|0)<0){ha=Mg;break u}else{Kg=Kg+1|0}}Dg=Dg+1|0;if((Dg|0)>=(Og|0)){break t}}i=k;return ha|0}}while(0);if((c[Pg>>2]|0)>0){Og=o+7456|0;Rg=o+7348|0;Dg=o+2139660|0;Kg=o+2158472|0;Mg=o+3088|0;Lg=n|0;n=l|0;Fg=l+4|0;Eg=l+8|0;Jg=l+12|0;l=o+2528|0;Ig=vg;vg=o+2520|0;Hg=o+7468|0;Gg=m|0;Cg=o+540|0;Bg=o+544|0;Ag=0;do{rg=c[bg+(Ag*533028|0)>>2]|0;wg=bg+(Ag*533028|0)+4|0;tg=c[wg>>2]|0;do{if((c[(c[mf>>2]|0)+688>>2]&2048|0)!=0){TGb(c[Og>>2]|0,0,ba(rg<<2,tg)|0)|0;cg=c[yg>>2]|0;$f=c[Ng>>2]|0;dg=c[xg>>2]|0;og=$f<<dg;v:do{if((og|0)>=0){hg=(Ag|0)==0;sg=p+7548+(Ag*533028|0)|0;qg=p+7548+(Ag*533028|0)+4|0;If=0;jg=dg;pg=$f;while(1){ig=c[Ae>>2]|0;ng=ig<<jg;mg=pg<<jg;lg=16>>>(jg>>>0);if(hg){Sg=lg<<1;Tg=lg;Ug=lg;Vg=jg}else{kg=c[je>>2]|0;Sg=lg<<1>>kg;Tg=lg>>c[lf>>2];Ug=lg>>kg;Vg=kg+jg|0}kg=c[1167680+(Vg<<2)>>2]|0;lg=c[j>>2]|0;gg=c[lg+32+(Ag<<2)>>2]|0;fg=c[lg+(Ag<<2)>>2]|0;lg=c[sg>>2]|0;eg=c[qg>>2]|0;w:do{if((c[Rg>>2]|0)==0){if((c[(c[mf>>2]|0)+688>>2]&512|0)!=0){A=848;break}if((ng|0)<0){break}_f=(Ug|0)/2|0;Zf=(ba(Tg,If)|0)-((Tg|0)/2|0)|0;Ff=If-1|0;ag=(gg|0)>111?16:gg<<4;Be=(Ff|0)<0;Hf=(Zf|0)<0;Nf=ba(Zf,-Sg|0)|0;Yf=Zf+Tg|0;Xf=ag*3|0;Uf=Xf+ag|0;Ef=Sg>>1;Vf=Uf+ag|0;Wf=0;Pf=ig;Of=jg;Tf=pg;while(1){Sf=(ba(Wf,Ug)|0)-_f|0;Rf=Wf-1|0;Qf=Pf<<Of;Mf=ba(Qf,Ff)|0;Lf=Mf+Rf|0;Kf=c[Dg>>2]|0;Df=Kf+(Lf*10|0)|0;Bf=Kf+((Mf+Wf|0)*10|0)|0;Mf=Lf+Qf|0;Lf=Kf+(Mf*10|0)|0;nd=Kf+((Mf+1|0)*10|0)|0;Mf=c[Kg>>2]|0;if((Rf|0)<0){Wg=nd;Xg=nd;Yg=Bf;Zg=Bf}else{Rf=(Wf|0)<(Qf|0);Wg=Rf?nd:Lf;Xg=Lf;Yg=Rf?Bf:Df;Zg=Df}if(Be){_g=Wg;$g=Xg;ah=Wg;bh=Xg}else{Df=(Tf<<Of|0)>(If|0);_g=Df?Wg:Yg;$g=Df?Xg:Zg;ah=Yg;bh=Zg}if((Sf|0)<0){ch=kg+(-Sf|0)|0;dh=0;eh=Sf+Ug|0}else{ch=kg;dh=Sf;eh=Ug}Sf=(dh+eh|0)>(lg|0)?lg-dh|0:eh;if(Hf){fh=ch+Nf|0;gh=0;hh=Yf}else{fh=ch;gh=Zf;hh=Tg}Df=(gh+hh|0)>(eg|0)?eg-gh|0:hh;do{if(!((Sf|0)<1|(Df|0)<1)){Bf=(ba(gh,gg)|0)+dh|0;Rf=Mf+Xf|0;Lf=Mf+Uf|0;Iob(p,Rf,Mf,gg,dh,gh,Sf,Df,bh,Ag,lg,eg);nd=bh+8|0;Qf=a[nd]|0;Kf=ah+8|0;Gf=a[Kf]|0;do{if((Qf&1)==0){A=869}else{if((Gf&1)==0){A=869;break}ih=(d[bh+6|0]|0)-(d[ah+6|0]|0)|(d[bh+5|0]|0)-(d[ah+5|0]|0)|(d[bh+7|0]|0)-(d[ah+7|0]|0)}}while(0);if((A|0)==869){A=0;ih=(b[bh>>1]|0)-(b[ah>>1]|0)|(Gf^Qf)&1|(b[bh+2>>1]|0)-(b[ah+2>>1]|0)|(d[bh+4|0]|0)-(d[ah+4|0]|0)}if((ih|0)==0){jh=Lf;kh=Rf;lh=Qf}else{Iob(p,Lf,Mf,gg,dh,gh,Sf,Df,ah,Ag,lg,eg);jh=Mf+Vf|0;kh=Lf;lh=a[nd]|0}nf=$g+8|0;jf=a[nf]|0;do{if((lh&1)==0){A=875}else{if((jf&1)==0){A=875;break}mh=(d[bh+6|0]|0)-(d[$g+6|0]|0)|(d[bh+5|0]|0)-(d[$g+5|0]|0)|(d[bh+7|0]|0)-(d[$g+7|0]|0)}}while(0);if((A|0)==875){A=0;mh=(b[bh>>1]|0)-(b[$g>>1]|0)|(jf^lh)&1|(b[bh+2>>1]|0)-(b[$g+2>>1]|0)|(d[bh+4|0]|0)-(d[$g+4|0]|0)}do{if((mh|0)==0){nh=jh;oh=Rf;ph=lh}else{Lf=a[Kf]|0;do{if((Lf&1)==0){A=880}else{if((jf&1)==0){A=880;break}qh=(d[ah+6|0]|0)-(d[$g+6|0]|0)|(d[ah+5|0]|0)-(d[$g+5|0]|0)|(d[ah+7|0]|0)-(d[$g+7|0]|0)}}while(0);if((A|0)==880){A=0;qh=(b[ah>>1]|0)-(b[$g>>1]|0)|(Lf^jf)&1|(b[ah+2>>1]|0)-(b[$g+2>>1]|0)|(d[ah+4|0]|0)-(d[$g+4|0]|0)}if((qh|0)==0){nh=jh;oh=kh;ph=lh;break}Iob(p,jh,Mf,gg,dh,gh,Sf,Df,$g,Ag,lg,eg);nh=jh+ag|0;oh=jh;ph=a[nd]|0}}while(0);nd=a[_g+8|0]|0;do{if((ph&1)==0){A=886}else{if((nd&1)==0){A=886;break}rh=(d[bh+6|0]|0)-(d[_g+6|0]|0)|(d[bh+5|0]|0)-(d[_g+5|0]|0)|(d[bh+7|0]|0)-(d[_g+7|0]|0)}}while(0);if((A|0)==886){A=0;rh=(b[bh>>1]|0)-(b[_g>>1]|0)|(nd^ph)&1|(b[bh+2>>1]|0)-(b[_g+2>>1]|0)|(d[bh+4|0]|0)-(d[_g+4|0]|0)}do{if((rh|0)==0){sh=Rf}else{jf=a[Kf]|0;do{if((jf&1)==0){A=891}else{if((nd&1)==0){A=891;break}th=(d[ah+6|0]|0)-(d[_g+6|0]|0)|(d[ah+5|0]|0)-(d[_g+5|0]|0)|(d[ah+7|0]|0)-(d[_g+7|0]|0)}}while(0);if((A|0)==891){A=0;th=(b[ah>>1]|0)-(b[_g>>1]|0)|(jf^nd)&1|(b[ah+2>>1]|0)-(b[_g+2>>1]|0)|(d[ah+4|0]|0)-(d[_g+4|0]|0)}if((th|0)==0){sh=kh;break}Lf=a[nf]|0;do{if((Lf&1)==0){A=896}else{if((nd&1)==0){A=896;break}uh=(d[$g+6|0]|0)-(d[_g+6|0]|0)|(d[$g+5|0]|0)-(d[_g+5|0]|0)|(d[$g+7|0]|0)-(d[_g+7|0]|0)}}while(0);if((A|0)==896){A=0;uh=(b[$g>>1]|0)-(b[_g>>1]|0)|(Lf^nd)&1|(b[$g+2>>1]|0)-(b[_g+2>>1]|0)|(d[$g+4|0]|0)-(d[_g+4|0]|0)}if((uh|0)==0){sh=oh;break}Iob(p,nh,Mf,gg,dh,gh,Sf,Df,_g,Ag,lg,eg);sh=nh}}while(0);if((Df|0)<=0){break}nd=(Sf|0)>0;nf=0;do{Kf=ba(nf,Sg)|0;Rf=Kf+Ef|0;jf=ba(nf+Ef|0,Sg)|0;Qf=jf+Ef|0;if(nd){Gf=ba(nf,gg)|0;yf=(ba(nf+gh|0,lg)|0)+dh|0;rf=0;do{Cf=rf+Gf|0;Af=((ba(d[fh+(rf+Kf)|0]|0,d[sh+Cf|0]|0)|0)+(ba(d[fh+(Rf+rf)|0]|0,d[oh+Cf|0]|0)|0)+(ba(d[fh+(rf+jf)|0]|0,d[kh+Cf|0]|0)|0)+(ba(d[fh+(Qf+rf)|0]|0,d[Mf+(Cf+Xf)|0]|0)|0)|0)>>>4;ff=(b[cg+(yf+rf<<1)>>1]|0)+8+Af|0;Af=ff>>4;if(Af>>>0>255>>>0){vh=(ff>>31^255)&255}else{vh=Af&255}a[fg+(Bf+Cf)|0]=vh;rf=rf+1|0;}while((rf|0)<(Sf|0))}nf=nf+1|0;}while((nf|0)<(Df|0))}}while(0);Df=Wf+1|0;if((Df|0)>(ng|0)){break w}Wf=Df;Pf=c[Ae>>2]|0;Of=c[xg>>2]|0;Tf=c[Ng>>2]|0}}else{A=848}}while(0);do{if((A|0)==848){A=0;if((mg|0)==(If|0)){break}ng=ba(Tg,If)|0;kg=ba(Tg,If+1|0)|0;ig=(eg|0)>(kg|0)?kg:eg;if((ng|0)>=(ig|0)){break}kg=(lg|0)>0;Tf=ng;do{if(kg){ng=ba(Tf,lg)|0;Of=ba(Tf,gg)|0;Pf=0;do{Wf=(b[cg+(Pf+ng<<1)>>1]|0)+2056|0;Xf=Wf>>4;if(Xf>>>0>255>>>0){wh=(Wf>>31^255)&255}else{wh=Xf&255}a[fg+(Pf+Of)|0]=wh;Pf=Pf+1|0;}while((Pf|0)<(lg|0))}Tf=Tf+1|0;}while((Tf|0)<(ig|0))}}while(0);lg=If+1|0;if((lg|0)>(og|0)){break v}If=lg;jg=c[xg>>2]|0;pg=c[Ng>>2]|0}}}while(0);if((tg|0)<=0){break}og=(rg|0)>0;cg=0;do{if(og){$f=0;do{dg=c[j>>2]|0;pg=(ba(c[dg+32+(Ag<<2)>>2]|0,cg)|0)+$f|0;jg=c[Mg>>2]|0;If=(ba(c[jg+32+(Ag<<2)>>2]|0,cg)|0)+$f|0;a[(c[jg+(Ag<<2)>>2]|0)+If|0]=a[(c[dg+(Ag<<2)>>2]|0)+pg|0]|0;$f=$f+1|0;}while(($f|0)<(rg|0))}cg=cg+1|0;}while((cg|0)<(tg|0))}}while(0);cg=c[hf>>2]|0;if((cg|0)>0){og=0;while(1){$f=(og|0)!=0|0;do{pg=c[bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+44>>2]|0;dg=c[bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+8>>2]|0;If=c[bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+12>>2]|0;jg=c[bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+40>>2]|0;if((pg|0)==0){xh=0}else{xh=c[pg+40>>2]|0}qg=0;sg=1;hg=0;ug=c[g>>2]|0;while(1){yh=qg+4+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+1008)|0;lg=(ba(d[yh]|0,ug)|0)>>8;fg=ug-lg|0;c[g>>2]=fg;gg=c[t>>2]|0;if((gg|0)<(fg|0)){A=923;break}c[t>>2]=gg-fg;a[yh]=a[(d[yh]|0)+(p+280)|0]|0;c[g>>2]=lg;if((lg|0)<256){fg=lg<<8;c[g>>2]=fg;gg=c[t>>2]<<8;c[t>>2]=gg;eg=c[Cg>>2]|0;if(eg>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[eg]|gg}c[Cg>>2]=eg+1;zh=fg}else{zh=lg}lg=sg+hg|0;fg=qg+1|0;if((fg|0)>=28){Ah=lg;Bh=fg;Ch=zh;A=933;break}qg=fg;sg=sg<<1;hg=lg;ug=zh}if((A|0)==923){A=0;a[yh]=a[(d[yh]|0)+(p+24)|0]|0;ug=c[g>>2]|0;if((ug|0)<256){sg=ug<<8;c[g>>2]=sg;lg=c[t>>2]<<8;c[t>>2]=lg;fg=c[Cg>>2]|0;if(fg>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[fg]|lg}c[Cg>>2]=fg+1;Dh=sg}else{Dh=ug}if((qg|0)>0){Ah=hg;Bh=qg;Ch=Dh;A=933}else{Eh=hg;Fh=Dh}}if((A|0)==933){while(1){A=0;ug=Bh-1|0;sg=32-Bh+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+1008)|0;fg=(ba(d[sg]|0,Ch)|0)>>8;lg=Ch-fg|0;c[g>>2]=lg;eg=c[t>>2]|0;do{if((eg|0)<(lg|0)){a[sg]=a[(d[sg]|0)+(p+24)|0]|0;gg=c[g>>2]|0;if((gg|0)>=256){Gh=0;Hh=gg;break}mg=gg<<8;c[g>>2]=mg;gg=c[t>>2]<<8;c[t>>2]=gg;ig=c[Cg>>2]|0;if(ig>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[ig]|gg}c[Cg>>2]=ig+1;Gh=0;Hh=mg}else{c[t>>2]=eg-lg;a[sg]=a[(d[sg]|0)+(p+280)|0]|0;c[g>>2]=fg;if((fg|0)>=256){Gh=1;Hh=fg;break}mg=fg<<8;c[g>>2]=mg;ig=c[t>>2]<<8;c[t>>2]=ig;gg=c[Cg>>2]|0;if(gg>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[gg]|ig}c[Cg>>2]=gg+1;Gh=1;Hh=mg}}while(0);fg=(Gh<<ug)+Ah|0;if((ug|0)>0){Ah=fg;Bh=ug;Ch=Hh;A=933}else{Eh=fg;Fh=Hh;break}}}hg=Eh-1|0;do{if((Eh|0)>0){qg=3;fg=8;sg=0;lg=Fh;while(1){Ih=qg+4+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+80)|0;eg=(ba(d[Ih]|0,lg)|0)>>8;mg=lg-eg|0;c[g>>2]=mg;gg=c[t>>2]|0;if((gg|0)<(mg|0)){A=946;break}c[t>>2]=gg-mg;a[Ih]=a[(d[Ih]|0)+(p+280)|0]|0;c[g>>2]=eg;if((eg|0)<256){mg=eg<<8;c[g>>2]=mg;gg=c[t>>2]<<8;c[t>>2]=gg;ig=c[Cg>>2]|0;if(ig>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[ig]|gg}c[Cg>>2]=ig+1;Jh=mg}else{Jh=eg}eg=fg+sg|0;mg=qg+1|0;if((mg|0)>=28){Kh=eg;Lh=mg;Mh=Jh;break}qg=mg;fg=fg<<1;sg=eg;lg=Jh}if((A|0)==946){A=0;a[Ih]=a[(d[Ih]|0)+(p+24)|0]|0;lg=c[g>>2]|0;if((lg|0)<256){fg=lg<<8;c[g>>2]=fg;ug=c[t>>2]<<8;c[t>>2]=ug;eg=c[Cg>>2]|0;if(eg>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[eg]|ug}c[Cg>>2]=eg+1;Nh=fg}else{Nh=lg}if((qg|0)>0){Kh=sg;Lh=qg;Mh=Nh}else{Oh=sg;Ph=Nh;break}}while(1){lg=Lh-1|0;fg=32-Lh+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+80)|0;eg=(ba(d[fg]|0,Mh)|0)>>8;ug=Mh-eg|0;c[g>>2]=ug;mg=c[t>>2]|0;do{if((mg|0)<(ug|0)){a[fg]=a[(d[fg]|0)+(p+24)|0]|0;ig=c[g>>2]|0;if((ig|0)>=256){Qh=0;Rh=ig;break}gg=ig<<8;c[g>>2]=gg;ig=c[t>>2]<<8;c[t>>2]=ig;Tf=c[Cg>>2]|0;if(Tf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Tf]|ig}c[Cg>>2]=Tf+1;Qh=0;Rh=gg}else{c[t>>2]=mg-ug;a[fg]=a[(d[fg]|0)+(p+280)|0]|0;c[g>>2]=eg;if((eg|0)>=256){Qh=1;Rh=eg;break}gg=eg<<8;c[g>>2]=gg;Tf=c[t>>2]<<8;c[t>>2]=Tf;ig=c[Cg>>2]|0;if(ig>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[ig]|Tf}c[Cg>>2]=ig+1;Qh=1;Rh=gg}}while(0);eg=(Qh<<lg)+Kh|0;if((lg|0)>0){Kh=eg;Lh=lg;Mh=Rh}else{Oh=eg;Ph=Rh;break}}}else{Oh=2147483647;Ph=Fh}}while(0);if((If|0)>0){sg=(dg|0)>0;qg=dg+1&65535;eg=pg+8|0;fg=bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+68|0;ug=bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+112|0;mg=Oh;gg=hg;ig=jg;Tf=0;kg=xh;Pf=xh;Of=0;ng=Ph;while(1){Xf=(Of|0)!=0;do{if(Xf){if((b[Tf>>1]|0)!=0){Sh=0;break}Sh=e[Tf+2>>1]|0}else{Sh=0}}while(0);if(sg){Wf=mg;Ef=gg;ag=ig;Vf=Tf;Uf=kg;Zf=0;Yf=0;Nf=Sh;Hf=0;Be=ng;while(1){do{if(Xf){Ff=(b[Vf>>1]|0)>(Hf|0)?Vf:Vf+4|0;if((b[Ff>>1]|0)!=(Hf+1|0)){Th=0;Uh=Ff;break}Th=e[Ff+2>>1]|0;Uh=Ff}else{Th=Nf;Uh=Vf}}while(0);do{if((Uf|0)==0){Vh=0;Wh=0}else{lg=Hf>>1;Ff=(lg|0)>(b[Uf>>1]|0)?Uf+4|0:Uf;if((lg|0)!=(b[Ff>>1]|0)){Vh=0;Wh=Ff;break}Vh=e[Ff+2>>1]|0;Wh=Ff}}while(0);do{if((Yf|Nf|Zf|Th|Vh|0)==0){if((Wf|0)!=0){Ff=Wf-1|0;if(Xf){lg=(b[Uh>>1]|0)-Hf-2|0;Xh=(Ff|0)>(lg|0)?lg:Ff}else{lg=dg-Hf-1|0;Xh=(Ff|0)>(lg|0)?lg:Ff}if((Wh|0)==0){Yh=Xh}else{lg=(b[Wh>>1]<<1)-Hf-1|0;Yh=(Xh|0)>(lg|0)?lg:Xh}Zh=Yh+Hf|0;_h=0;$h=ag;ai=Ef;bi=Ff-Yh|0;ci=Be;break}Ff=Ef-1|0;do{if((Ef|0)>0){lg=3;_f=8;Df=0;Sf=Be;while(1){di=lg+4+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+80)|0;Mf=(ba(d[di]|0,Sf)|0)>>8;nf=Sf-Mf|0;c[g>>2]=nf;Bf=c[t>>2]|0;if((Bf|0)<(nf|0)){A=1029;break}c[t>>2]=Bf-nf;a[di]=a[(d[di]|0)+(p+280)|0]|0;c[g>>2]=Mf;if((Mf|0)<256){nf=Mf<<8;c[g>>2]=nf;Bf=c[t>>2]<<8;c[t>>2]=Bf;nd=c[Cg>>2]|0;if(nd>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[nd]|Bf}c[Cg>>2]=nd+1;ei=nf}else{ei=Mf}Mf=_f+Df|0;nf=lg+1|0;if((nf|0)>=28){fi=Mf;gi=nf;hi=ei;break}lg=nf;_f=_f<<1;Df=Mf;Sf=ei}if((A|0)==1029){A=0;a[di]=a[(d[di]|0)+(p+24)|0]|0;Sf=c[g>>2]|0;if((Sf|0)<256){_f=Sf<<8;c[g>>2]=_f;Mf=c[t>>2]<<8;c[t>>2]=Mf;nf=c[Cg>>2]|0;if(nf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[nf]|Mf}c[Cg>>2]=nf+1;ii=_f}else{ii=Sf}if((lg|0)>0){fi=Df;gi=lg;hi=ii}else{ji=Df;ki=ii;break}}while(1){Sf=gi-1|0;_f=32-gi+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+80)|0;nf=(ba(d[_f]|0,hi)|0)>>8;Mf=hi-nf|0;c[g>>2]=Mf;nd=c[t>>2]|0;do{if((nd|0)<(Mf|0)){a[_f]=a[(d[_f]|0)+(p+24)|0]|0;Bf=c[g>>2]|0;if((Bf|0)>=256){li=0;mi=Bf;break}rf=Bf<<8;c[g>>2]=rf;Bf=c[t>>2]<<8;c[t>>2]=Bf;yf=c[Cg>>2]|0;if(yf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[yf]|Bf}c[Cg>>2]=yf+1;li=0;mi=rf}else{c[t>>2]=nd-Mf;a[_f]=a[(d[_f]|0)+(p+280)|0]|0;c[g>>2]=nf;if((nf|0)>=256){li=1;mi=nf;break}rf=nf<<8;c[g>>2]=rf;yf=c[t>>2]<<8;c[t>>2]=yf;Bf=c[Cg>>2]|0;if(Bf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Bf]|yf}c[Cg>>2]=Bf+1;li=1;mi=rf}}while(0);nf=(li<<Sf)+fi|0;if((Sf|0)>0){fi=nf;gi=Sf;hi=mi}else{ji=nf;ki=mi;break}}}else{ji=2147483647;ki=Be}}while(0);Df=(ba(d[ug]|0,ki)|0)>>8;lg=ki-Df|0;c[g>>2]=lg;nf=c[t>>2]|0;x:do{if((nf|0)<(lg|0)){ni=0;oi=-4;pi=ug;A=1051}else{_f=0;Mf=1;nd=-4;rf=ug;Bf=Df;yf=lg;Qf=nf;while(1){c[t>>2]=Qf-yf;a[rf]=a[(d[rf]|0)+(p+280)|0]|0;c[g>>2]=Bf;if((Bf|0)<256){jf=Bf<<8;c[g>>2]=jf;Rf=c[t>>2]<<8;c[t>>2]=Rf;Kf=c[Cg>>2]|0;if(Kf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Kf]|Rf}c[Cg>>2]=Kf+1;qi=jf}else{qi=Bf}jf=Mf+_f|0;Kf=nd+1|0;if((Kf|0)>=28){ri=jf;si=Kf;ti=qi;A=1061;break x}Rf=nd+5+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+112)|0;Gf=(ba(d[Rf]|0,qi)|0)>>8;Lf=qi-Gf|0;c[g>>2]=Lf;Cf=c[t>>2]|0;if((Cf|0)<(Lf|0)){ni=jf;oi=Kf;pi=Rf;A=1051;break}else{_f=jf;Mf=Mf<<((Kf|0)>0);nd=Kf;rf=Rf;Bf=Gf;yf=Lf;Qf=Cf}}}}while(0);if((A|0)==1051){A=0;a[pi]=a[(d[pi]|0)+(p+24)|0]|0;nf=c[g>>2]|0;if((nf|0)<256){lg=nf<<8;c[g>>2]=lg;Df=c[t>>2]<<8;c[t>>2]=Df;Qf=c[Cg>>2]|0;if(Qf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Qf]|Df}c[Cg>>2]=Qf+1;ui=lg}else{ui=nf}if((oi|0)>0){ri=ni;si=oi;ti=ui;A=1061}else{vi=ni;wi=ui}}if((A|0)==1061){while(1){A=0;nf=si-1|0;lg=32-si+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+112)|0;Qf=(ba(d[lg]|0,ti)|0)>>8;Df=ti-Qf|0;c[g>>2]=Df;yf=c[t>>2]|0;do{if((yf|0)<(Df|0)){a[lg]=a[(d[lg]|0)+(p+24)|0]|0;Bf=c[g>>2]|0;if((Bf|0)>=256){xi=0;yi=Bf;break}rf=Bf<<8;c[g>>2]=rf;Bf=c[t>>2]<<8;c[t>>2]=Bf;nd=c[Cg>>2]|0;if(nd>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[nd]|Bf}c[Cg>>2]=nd+1;xi=0;yi=rf}else{c[t>>2]=yf-Df;a[lg]=a[(d[lg]|0)+(p+280)|0]|0;c[g>>2]=Qf;if((Qf|0)>=256){xi=1;yi=Qf;break}rf=Qf<<8;c[g>>2]=rf;nd=c[t>>2]<<8;c[t>>2]=nd;Bf=c[Cg>>2]|0;if(Bf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Bf]|nd}c[Cg>>2]=Bf+1;xi=1;yi=rf}}while(0);Qf=(xi<<nf)+ri|0;if((nf|0)>0){ri=Qf;si=nf;ti=yi;A=1061}else{vi=Qf;wi=yi;break}}}Qf=(vi<<1)+2|0;lg=(ba(d[fg]|0,wi)|0)>>8;Df=wi-lg|0;c[g>>2]=Df;yf=c[t>>2]|0;do{if((yf|0)<(Df|0)){a[fg]=a[(d[fg]|0)+(p+24)|0]|0;rf=c[g>>2]|0;if((rf|0)>=256){zi=0;Ai=rf;break}Bf=rf<<8;c[g>>2]=Bf;rf=c[t>>2]<<8;c[t>>2]=rf;nd=c[Cg>>2]|0;if(nd>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[nd]|rf}c[Cg>>2]=nd+1;zi=0;Ai=Bf}else{c[t>>2]=yf-Df;a[fg]=a[(d[fg]|0)+(p+280)|0]|0;c[g>>2]=lg;if((lg|0)>=256){zi=1;Ai=lg;break}Bf=lg<<8;c[g>>2]=Bf;nd=c[t>>2]<<8;c[t>>2]=nd;rf=c[Cg>>2]|0;if(rf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[rf]|nd}c[Cg>>2]=rf+1;zi=1;Ai=Bf}}while(0);lg=zi|Qf;b[ag>>1]=Hf;b[ag+2>>1]=lg;Zh=Hf;_h=lg;$h=ag+4|0;ai=Ff;bi=ji;ci=Ai}else{lg=(Yf>>1)+(Nf&-2)+((Zf>>1)*3|0)+(Th>>1)+(Vh>>>1)|0;Df=lg>>>0>65535>>>0;yf=Df?lg>>>16:lg;lg=Df?16:0;if((yf&65280|0)==0){Bi=lg;Ci=yf}else{Bi=lg|8;Ci=yf>>>8}yf=(d[1191992+Ci|0]|0)+Bi|0;lg=bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48+yf|0;Df=(ba(d[lg]|0,Be)|0)>>8;Bf=Be-Df|0;c[g>>2]=Bf;rf=c[t>>2]|0;if((rf|0)<(Bf|0)){a[lg]=a[(d[lg]|0)+(p+24)|0]|0;nd=c[g>>2]|0;if((nd|0)>=256){Zh=Hf;_h=0;$h=ag;ai=Ef;bi=Wf;ci=nd;break}Mf=nd<<8;c[g>>2]=Mf;nd=c[t>>2]<<8;c[t>>2]=nd;_f=c[Cg>>2]|0;if(_f>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[_f]|nd}c[Cg>>2]=_f+1;Zh=Hf;_h=0;$h=ag;ai=Ef;bi=Wf;ci=Mf;break}c[t>>2]=rf-Bf;a[lg]=a[(d[lg]|0)+(p+280)|0]|0;c[g>>2]=Df;if((Df|0)<256){lg=Df<<8;c[g>>2]=lg;Bf=c[t>>2]<<8;c[t>>2]=Bf;rf=c[Cg>>2]|0;if(rf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[rf]|Bf}c[Cg>>2]=rf+1;Di=lg}else{Di=Df}Df=yf+2|0;lg=yf-4|0;y:do{if((lg|0)<28){rf=bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48+(Df<<5)+yf|0;Bf=(ba(d[rf]|0,Di)|0)>>8;Mf=Di-Bf|0;c[g>>2]=Mf;_f=c[t>>2]|0;if((_f|0)<(Mf|0)){Ei=0;Fi=lg;Gi=rf}else{nd=0;Cf=(lg|0)>-1?1<<lg:1;Lf=lg;Gf=rf;rf=Bf;Bf=Mf;Mf=_f;while(1){c[t>>2]=Mf-Bf;a[Gf]=a[(d[Gf]|0)+(p+280)|0]|0;c[g>>2]=rf;if((rf|0)<256){_f=rf<<8;c[g>>2]=_f;Rf=c[t>>2]<<8;c[t>>2]=Rf;Kf=c[Cg>>2]|0;if(Kf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Kf]|Rf}c[Cg>>2]=Kf+1;Hi=_f}else{Hi=rf}_f=Cf+nd|0;Kf=Lf+1|0;if((Kf|0)>=28){Ii=_f;Ji=Kf;Ki=Hi;A=1005;break y}Rf=Lf+5+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48+(Df<<5))|0;jf=(ba(d[Rf]|0,Hi)|0)>>8;Af=Hi-jf|0;c[g>>2]=Af;ff=c[t>>2]|0;if((ff|0)<(Af|0)){Ei=_f;Fi=Kf;Gi=Rf;break}else{nd=_f;Cf=Cf<<((Kf|0)>0);Lf=Kf;Gf=Rf;rf=jf;Bf=Af;Mf=ff}}}a[Gi]=a[(d[Gi]|0)+(p+24)|0]|0;Mf=c[g>>2]|0;if((Mf|0)<256){Bf=Mf<<8;c[g>>2]=Bf;rf=c[t>>2]<<8;c[t>>2]=rf;Gf=c[Cg>>2]|0;if(Gf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Gf]|rf}c[Cg>>2]=Gf+1;Li=Bf}else{Li=Mf}if((Fi|0)>0){Ii=Ei;Ji=Fi;Ki=Li;A=1005}else{Mi=Ei;Ni=Li}}else{Ii=0;Ji=lg;Ki=Di;A=1005}}while(0);if((A|0)==1005){while(1){A=0;lg=Ji-1|0;yf=32-Ji+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48+(Df<<5))|0;Ff=(ba(d[yf]|0,Ki)|0)>>8;Qf=Ki-Ff|0;c[g>>2]=Qf;Mf=c[t>>2]|0;do{if((Mf|0)<(Qf|0)){a[yf]=a[(d[yf]|0)+(p+24)|0]|0;Bf=c[g>>2]|0;if((Bf|0)>=256){Oi=0;Pi=Bf;break}Gf=Bf<<8;c[g>>2]=Gf;Bf=c[t>>2]<<8;c[t>>2]=Bf;rf=c[Cg>>2]|0;if(rf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[rf]|Bf}c[Cg>>2]=rf+1;Oi=0;Pi=Gf}else{c[t>>2]=Mf-Qf;a[yf]=a[(d[yf]|0)+(p+280)|0]|0;c[g>>2]=Ff;if((Ff|0)>=256){Oi=1;Pi=Ff;break}Gf=Ff<<8;c[g>>2]=Gf;rf=c[t>>2]<<8;c[t>>2]=rf;Bf=c[Cg>>2]|0;if(Bf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Bf]|rf}c[Cg>>2]=Bf+1;Oi=1;Pi=Gf}}while(0);Ff=(Oi<<lg)+Ii|0;if((lg|0)>0){Ii=Ff;Ji=lg;Ki=Pi;A=1005}else{Mi=Ff;Ni=Pi;break}}}Df=(Mi<<1)+2|0;Ff=(a[1152320+(Zf&255)|0]|0)+20+((a[1152320+(Nf&255)|0]|0)*3|0)+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48)|0;yf=(ba(d[Ff]|0,Ni)|0)>>8;Qf=Ni-yf|0;c[g>>2]=Qf;Mf=c[t>>2]|0;do{if((Mf|0)<(Qf|0)){a[Ff]=a[(d[Ff]|0)+(p+24)|0]|0;Gf=c[g>>2]|0;if((Gf|0)>=256){Qi=0;Ri=Gf;break}Bf=Gf<<8;c[g>>2]=Bf;Gf=c[t>>2]<<8;c[t>>2]=Gf;rf=c[Cg>>2]|0;if(rf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[rf]|Gf}c[Cg>>2]=rf+1;Qi=0;Ri=Bf}else{c[t>>2]=Mf-Qf;a[Ff]=a[(d[Ff]|0)+(p+280)|0]|0;c[g>>2]=yf;if((yf|0)>=256){Qi=1;Ri=yf;break}Bf=yf<<8;c[g>>2]=Bf;rf=c[t>>2]<<8;c[t>>2]=rf;Gf=c[Cg>>2]|0;if(Gf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Gf]|rf}c[Cg>>2]=Gf+1;Qi=1;Ri=Bf}}while(0);yf=Qi|Df;b[ag>>1]=Hf;b[ag+2>>1]=yf;Zh=Hf;_h=yf;$h=ag+4|0;ai=Ef;bi=Wf;ci=Ri}}while(0);yf=Zh+1|0;if((yf|0)<(dg|0)){Wf=bi;Ef=ai;ag=$h;Vf=Uh;Uf=Wh;Zf=_h;Yf=Nf;Nf=Th;Hf=yf;Be=ci}else{Si=bi;Ti=ai;Ui=$h;Vi=Wh;Wi=ci;break}}}else{Si=mg;Ti=gg;Ui=ig;Vi=kg;Wi=ng}Be=Ui+4|0;b[Ui>>1]=qg;do{if((Vi|0)==0){Xi=Pf;Yi=0}else{if((Of&1|0)==0){Xi=Pf;Yi=Pf;break}Hf=(c[eg>>2]|0)+1|0;Nf=Vi;while(1){Yf=Nf+4|0;if((b[Nf>>1]|0)==(Hf|0)){Xi=Yf;Yi=Yf;break}else{Nf=Yf}}}}while(0);Nf=Of+1|0;if((Nf|0)<(If|0)){mg=Si;gg=Ti;Tf=ig;ig=Be;kg=Yi;Pf=Xi;Of=Nf;ng=Wi}else{Zi=Be;_i=qg;break}}}else{Zi=jg;_i=dg+1&65535}b[Zi>>1]=_i;$f=$f+1|0;}while(($f|0)<4);$f=og+1|0;qg=c[hf>>2]|0;if(($f|0)<(qg|0)){og=$f}else{$i=qg;break}}}else{$i=cg}og=c[xg>>2]|0;qg=c[Ng>>2]<<og;$f=16>>>(og>>>0);og=(Ag|0)==0;if(og){aj=$f}else{aj=$f>>c[lf>>2]}vYa(Lg,Qg,rg,tg,1,c[Ce>>2]|0,$i);if((qg|0)>=0){$f=aj>>1;ng=p+7548+(Ag*533028|0)|0;Of=p+7548+(Ag*533028|0)+4|0;Pf=(rg|0)>0;kg=bg+(Ag*533028|0)+8|0;ig=bg+(Ag*533028|0)+16|0;Tf=bg+(Ag*533028|0)+44|0;gg=bg+(Ag*533028|0)+40|0;mg=bg+(Ag*533028|0)+36|0;If=bg+(Ag*533028|0)+24|0;eg=0;fg=0;ug=0;while(1){sg=ba(ug,aj)|0;hg=ug+1|0;pg=ba(hg,aj)|0;do{if((c[Rg>>2]|0)==0){if((c[(c[mf>>2]|0)+688>>2]&512|0)!=0){bj=pg;cj=sg;break}Nf=sg-$f|0;bj=pg-$f|0;cj=(Nf|0)<0?0:Nf}else{bj=pg;cj=sg}}while(0);Nf=c[hf>>2]|0;if((Nf|0)>0){Hf=(ug|0)==0;Yf=0;Zf=0;while(1){Uf=Zf+3|0;Vf=Zf+1|0;ag=(Yf|0)!=0|0;do{Ef=bg+(Ag*533028|0)+8+(Yf*66624|0)+(ag*16656|0)|0;if(Hf){dj=0}else{Wf=c[hf>>2]|0;dj=Uf+Wf+(sg>>Wf-Yf)|0}Wf=c[hf>>2]|0;Xf=Uf+Wf+(pg>>Wf-Yf)|0;do{if((c[Rg>>2]|0)==0){if((c[(c[mf>>2]|0)+688>>2]&512|0)!=0){ej=Xf;fj=dj;break}yf=aj>>Vf+Wf;Ff=dj-yf|0;Qf=Xf-yf|0;ej=(Qf|0)<0?0:Qf;fj=(Ff|0)<0?0:Ff}else{ej=Xf;fj=dj}}while(0);Xf=c[bg+(Ag*533028|0)+8+(Yf*66624|0)+(ag*16656|0)+12>>2]|0;Wf=(Xf|0)>(fj|0)?fj:Xf;Be=(Xf|0)>(ej|0)?ej:Xf;do{if((Wf|0)!=(Be|0)){if((ag|0)!=0){NYa(p,Ef,Qg,Wf,Be,m+(Yf<<4)+(ag<<2)|0);break}Ff=Be+1|0;Qf=(Xf|0)>(Ff|0)?Ff:Xf;Ff=(Wf|0)!=0?Wf+1|0:0;yf=(Xf|0)>(Ff|0)?Ff:Xf;NYa(p,kg,Qg,yf,Qf,Gg);Ff=c[ig>>2]|0;if((yf|0)==0){gj=0;hj=0}else{Mf=ba(c[Tf>>2]|0,yf-1|0)|0;Bf=Mf+(c[gg>>2]|0)|0;Mf=c[(c[Ig>>2]|0)+(Bf<<2)>>2]|0;if((Mf|0)==0){ij=oYa(Qg,Bf)|0}else{ij=Mf}gj=ij+(c[mg>>2]<<1)|0;hj=yf}if((hj|0)<(Qf|0)){yf=(Ff|0)>0;Mf=hj;Bf=gj;while(1){Gf=ba(c[Tf>>2]|0,Mf)|0;rf=Gf+(c[gg>>2]|0)|0;Gf=c[(c[Ig>>2]|0)+(rf<<2)>>2]|0;if((Gf|0)==0){jj=oYa(Qg,rf)|0}else{jj=Gf}Gf=c[mg>>2]|0;rf=jj+(Gf<<1)|0;if(yf){Lf=(Mf|0)==0;Cf=0;do{do{if((Cf|0)==0){if(Lf){break}b[rf>>1]=(b[rf>>1]|0)+(b[Bf>>1]|0)}else{nd=Cf-1|0;nf=b[jj+(nd+Gf<<1)>>1]|0;ff=nf<<16>>16;if(Lf){Af=jj+(Cf+Gf<<1)|0;b[Af>>1]=(b[Af>>1]|0)+nf;break}Af=b[Bf+(Cf<<1)>>1]|0;jf=Af<<16>>16;Rf=jf+ff-(b[Bf+(nd<<1)>>1]|0)|0;do{if(nf<<16>>16>Af<<16>>16){if((Rf|0)<=(jf|0)){kj=jf;break}kj=(Rf|0)>(ff|0)?ff:Rf}else{if((jf|0)<=(Rf|0)){kj=jf;break}kj=(Rf|0)>(ff|0)?Rf:ff}}while(0);ff=jj+(Cf+Gf<<1)|0;b[ff>>1]=(e[ff>>1]|0)+kj}}while(0);Cf=Cf+1|0;}while((Cf|0)<(Ff|0))}Cf=Mf+1|0;if((Cf|0)<(Qf|0)){Mf=Cf;Bf=rf}else{break}}}Bf=c[ig>>2]|0;Mf=c[Jf>>2]|0;Qf=(c[If>>2]|0)+Mf|0;if((Qf|0)<0){lj=0}else{lj=(Qf|0)>512?512:Qf}Qf=d[5728784+(lj&31)|0]<<(lj>>5);Ff=(ba(Qf,c[zg>>2]|0)|0)>>3;if(!((Mf|0)!=-128&(Wf|0)<(Be|0))){break}Mf=(Bf|0)>0;yf=Wf;do{Cf=ba(c[Tf>>2]|0,yf)|0;Gf=Cf+(c[gg>>2]|0)|0;Cf=c[(c[Ig>>2]|0)+(Gf<<2)>>2]|0;if((Cf|0)==0){mj=oYa(Qg,Gf)|0}else{mj=Cf}Cf=c[mg>>2]|0;if(Mf){Gf=0;do{Lf=mj+(Gf+Cf<<1)|0;Df=b[Lf>>1]|0;lg=Df<<16>>16;do{if(Df<<16>>16<0){b[Lf>>1]=-((Ff-(ba(lg,Qf)|0)|0)>>>11)}else{if(!(Df<<16>>16>0)){break}b[Lf>>1]=((ba(lg,Qf)|0)+Ff|0)>>>11}}while(0);Gf=Gf+1|0;}while((Gf|0)<(Bf|0))}yf=yf+1|0;}while((yf|0)<(Be|0))}}while(0);ag=ag+1|0;}while((ag|0)<4);ag=Yf+1|0;Vf=~Yf;Uf=c[hf>>2]|0;if((ag|0)<(Uf|0)){Yf=ag;Zf=Vf}else{nj=Uf;break}}}else{nj=Nf}z:do{if((fg|0)<(bj|0)){Zf=fg;Yf=nj;while(1){wYa(vg,Lg,Qg,c[Hg>>2]|0,rg,tg,1,c[Ce>>2]|0,Yf,Zf);pg=Zf+4|0;if((pg|0)>=(bj|0)){oj=pg;break z}Zf=pg;Yf=c[hf>>2]|0}}else{oj=fg}}while(0);do{if((c[Jf>>2]|0)==-128){if(!((eg|0)<(bj|0)&(eg|0)<(tg|0))){pj=eg;break}Nf=eg-bj|0;Yf=eg-tg|0;Zf=Nf>>>0>Yf>>>0?Nf:Yf;Yf=eg;do{Nf=c[(c[Ig>>2]|0)+(Yf<<2)>>2]|0;if((Nf|0)==0){qj=oYa(Qg,Yf)|0}else{qj=Nf}if(Pf){Nf=0;do{pg=qj+(Nf<<1)|0;b[pg>>1]=b[pg>>1]<<4;Nf=Nf+1|0;}while((Nf|0)<(rg|0))}Yf=Yf+1|0;}while((Yf|0)<(bj|0)&(Yf|0)<(tg|0));pj=eg-Zf|0}else{pj=eg}}while(0);Yf=c[Ae>>2]|0;Nf=c[xg>>2]|0;pg=Yf<<Nf;sg=c[Ng>>2]|0;Hf=sg<<Nf;Uf=16>>>(Nf>>>0);if(og){rj=Uf<<1;sj=Uf;tj=Uf;uj=Nf}else{Vf=c[je>>2]|0;rj=Uf<<1>>Vf;sj=Uf>>c[lf>>2];tj=Uf>>Vf;uj=Vf+Nf|0}Vf=c[1167680+(uj<<2)>>2]|0;Uf=c[j>>2]|0;ag=c[Uf+32+(Ag<<2)>>2]|0;dg=c[Uf+(Ag<<2)>>2]|0;Uf=c[ng>>2]|0;jg=c[Of>>2]|0;A:do{if((c[Rg>>2]|0)==0){if((c[(c[mf>>2]|0)+688>>2]&512|0)!=0){A=1171;break}if((pg|0)<0){break}Be=(tj|0)/2|0;Wf=(ba(sj,ug)|0)-((sj|0)/2|0)|0;Xf=ug-1|0;Ef=(ag|0)>111?16:ag<<4;yf=(Xf|0)<0;Bf=(Wf|0)<0;Ff=ba(Wf,-rj|0)|0;Qf=Wf+sj|0;Mf=Ef*3|0;Gf=Mf+Ef|0;Cf=Gf+Ef|0;rf=0;lg=Yf;Lf=Nf;Df=sg;while(1){ff=(ba(rf,tj)|0)-Be|0;Rf=rf-1|0;jf=lg<<Lf;Af=ba(jf,Xf)|0;nf=Af+Rf|0;Sf=c[Dg>>2]|0;nd=Sf+(nf*10|0)|0;Kf=Sf+((Af+rf|0)*10|0)|0;Af=nf+jf|0;nf=Sf+(Af*10|0)|0;_f=Sf+((Af+1|0)*10|0)|0;Af=c[Kg>>2]|0;if((Rf|0)<0){vj=_f;wj=_f;xj=Kf;yj=Kf}else{Rf=(rf|0)<(jf|0);vj=Rf?_f:nf;wj=nf;xj=Rf?Kf:nd;yj=nd}if(yf){zj=vj;Aj=wj;Bj=vj;Cj=wj}else{nd=(Df<<Lf|0)>(ug|0);zj=nd?vj:xj;Aj=nd?wj:yj;Bj=xj;Cj=yj}if((ff|0)<0){Dj=Vf+(-ff|0)|0;Ej=0;Fj=ff+tj|0}else{Dj=Vf;Ej=ff;Fj=tj}ff=(Ej+Fj|0)>(Uf|0)?Uf-Ej|0:Fj;if(Bf){Gj=Dj+Ff|0;Hj=0;Ij=Qf}else{Gj=Dj;Hj=Wf;Ij=sj}nd=(Hj+Ij|0)>(jg|0)?jg-Hj|0:Ij;if(!((ff|0)<1|(nd|0)<1)){Kf=dg+((ba(Hj,ag)|0)+Ej)|0;Rf=Af+Mf|0;c[n>>2]=Rf;nf=Af+Gf|0;Iob(p,Rf,Af,ag,Ej,Hj,ff,nd,Cj,Ag,Uf,jg);_f=Cj+8|0;jf=a[_f]|0;Sf=Bj+8|0;tf=a[Sf]|0;do{if((jf&1)==0){A=1192}else{if((tf&1)==0){A=1192;break}Jj=(d[Cj+6|0]|0)-(d[Bj+6|0]|0)|(d[Cj+5|0]|0)-(d[Bj+5|0]|0)|(d[Cj+7|0]|0)-(d[Bj+7|0]|0)}}while(0);if((A|0)==1192){A=0;Jj=(b[Cj>>1]|0)-(b[Bj>>1]|0)|(tf^jf)&1|(b[Cj+2>>1]|0)-(b[Bj+2>>1]|0)|(d[Cj+4|0]|0)-(d[Bj+4|0]|0)}if((Jj|0)==0){c[Fg>>2]=Rf;Kj=nf}else{c[Fg>>2]=nf;Iob(p,nf,Af,ag,Ej,Hj,ff,nd,Bj,Ag,Uf,jg);Kj=Af+Cf|0}zf=a[_f]|0;sf=Aj+8|0;xf=a[sf]|0;do{if((zf&1)==0){A=1199}else{if((xf&1)==0){A=1199;break}Lj=(d[Cj+6|0]|0)-(d[Aj+6|0]|0)|(d[Cj+5|0]|0)-(d[Aj+5|0]|0)|(d[Cj+7|0]|0)-(d[Aj+7|0]|0)}}while(0);if((A|0)==1199){A=0;Lj=(b[Cj>>1]|0)-(b[Aj>>1]|0)|(xf^zf)&1|(b[Cj+2>>1]|0)-(b[Aj+2>>1]|0)|(d[Cj+4|0]|0)-(d[Aj+4|0]|0)}do{if((Lj|0)==0){c[Eg>>2]=c[n>>2];Mj=Kj}else{nf=a[Sf]|0;do{if((nf&1)==0){A=1205}else{if((xf&1)==0){A=1205;break}Nj=(d[Bj+6|0]|0)-(d[Aj+6|0]|0)|(d[Bj+5|0]|0)-(d[Aj+5|0]|0)|(d[Bj+7|0]|0)-(d[Aj+7|0]|0)}}while(0);if((A|0)==1205){A=0;Nj=(b[Bj>>1]|0)-(b[Aj>>1]|0)|(nf^xf)&1|(b[Bj+2>>1]|0)-(b[Aj+2>>1]|0)|(d[Bj+4|0]|0)-(d[Aj+4|0]|0)}if((Nj|0)==0){c[Eg>>2]=c[Fg>>2];Mj=Kj;break}else{c[Eg>>2]=Kj;Iob(p,Kj,Af,ag,Ej,Hj,ff,nd,Aj,Ag,Uf,jg);Mj=Kj+Ef|0;break}}}while(0);xf=a[_f]|0;zf=a[zj+8|0]|0;do{if((xf&1)==0){A=1212}else{if((zf&1)==0){A=1212;break}Oj=(d[Cj+6|0]|0)-(d[zj+6|0]|0)|(d[Cj+5|0]|0)-(d[zj+5|0]|0)|(d[Cj+7|0]|0)-(d[zj+7|0]|0)}}while(0);if((A|0)==1212){A=0;Oj=(b[Cj>>1]|0)-(b[zj>>1]|0)|(zf^xf)&1|(b[Cj+2>>1]|0)-(b[zj+2>>1]|0)|(d[Cj+4|0]|0)-(d[zj+4|0]|0)}do{if((Oj|0)==0){c[Jg>>2]=c[n>>2]}else{_f=a[Sf]|0;do{if((_f&1)==0){A=1218}else{if((zf&1)==0){A=1218;break}Pj=(d[Bj+6|0]|0)-(d[zj+6|0]|0)|(d[Bj+5|0]|0)-(d[zj+5|0]|0)|(d[Bj+7|0]|0)-(d[zj+7|0]|0)}}while(0);if((A|0)==1218){A=0;Pj=(b[Bj>>1]|0)-(b[zj>>1]|0)|(_f^zf)&1|(b[Bj+2>>1]|0)-(b[zj+2>>1]|0)|(d[Bj+4|0]|0)-(d[zj+4|0]|0)}if((Pj|0)==0){c[Jg>>2]=c[Fg>>2];break}nf=a[sf]|0;do{if((nf&1)==0){A=1224}else{if((zf&1)==0){A=1224;break}Qj=(d[Aj+6|0]|0)-(d[zj+6|0]|0)|(d[Aj+5|0]|0)-(d[zj+5|0]|0)|(d[Aj+7|0]|0)-(d[zj+7|0]|0)}}while(0);if((A|0)==1224){A=0;Qj=(b[Aj>>1]|0)-(b[zj>>1]|0)|(nf^zf)&1|(b[Aj+2>>1]|0)-(b[zj+2>>1]|0)|(d[Aj+4|0]|0)-(d[zj+4|0]|0)}if((Qj|0)==0){c[Jg>>2]=c[Eg>>2];break}else{c[Jg>>2]=Mj;Iob(p,Mj,Af,ag,Ej,Hj,ff,nd,zj,Ag,Uf,jg);break}}}while(0);se[c[l>>2]&127](Gj,rj,n,ff,nd,Ej,Hj,ag,Qg,1,Kf)}Af=rf+1|0;if((Af|0)>(pg|0)){break A}rf=Af;lg=c[Ae>>2]|0;Lf=c[xg>>2]|0;Df=c[Ng>>2]|0}}else{A=1171}}while(0);do{if((A|0)==1171){A=0;if((Hf|0)==(ug|0)){break}pg=ba(sj,ug)|0;Vf=ba(sj,hg)|0;sg=(jg|0)>(Vf|0)?Vf:jg;if((pg|0)>=(sg|0)){break}Vf=(Uf|0)>0;Nf=pg;do{pg=c[(c[Ig>>2]|0)+(Nf<<2)>>2]|0;if(Vf){Yf=ba(Nf,ag)|0;Df=0;do{Lf=(b[pg+(Df<<1)>>1]|0)+2056|0;lg=Lf>>4;if(lg>>>0>255>>>0){Rj=(Lf>>31^255)&255}else{Rj=lg&255}a[dg+(Df+Yf)|0]=Rj;Df=Df+1|0;}while((Df|0)<(Uf|0))}Nf=Nf+1|0;}while((Nf|0)<(sg|0))}}while(0);Uf=c[wg>>2]|0;dg=(Uf|0)>(cj|0)?cj:Uf;ag=(Uf|0)>(bj|0)?bj:Uf;if((dg|0)<(ag|0)){Uf=dg;while(1){dg=Uf+1|0;pYa(Qg,Uf);if((dg|0)<(ag|0)){Uf=dg}else{break}}}if((hg|0)>(qg|0)){break}else{eg=pj;fg=oj;ug=hg}}}qYa(Qg);Ag=Ag+1|0;}while((Ag|0)<(c[Pg>>2]|0))}Uob(f);if((c[(c[mf>>2]|0)+688>>2]&2048|0)==0){Sj=MCb(s,c[j>>2]|0)|0}else{Sj=MCb(s,c[o+3088>>2]|0)|0}if((Sj|0)<0){ha=Sj;i=k;return ha|0}c[h>>2]=1;h=c[o+540>>2]|0;Sj=c[o+536>>2]|0;o=h-Sj|0;if((h|0)!=(Sj|0)){ha=o;i=k;return ha|0}yDb(c[mf>>2]|0,16,2104752,(ga=i,i=i+1|0,i=i+7&-8,c[ga>>2]=0,ga)|0);i=ga;ha=o;i=k;return ha|0}function MYa(a){a=a|0;var b=0;b=c[a+60>>2]|0;rYa(b+2143764|0);Wob(b);return 0}function NYa(a,f,g,h,i,j){a=a|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;k=f+8|0;l=c[k>>2]|0;m=c[a+7492>>2]|0;n=(c[f+16>>2]|0)+m|0;if((n|0)<0){o=0}else{o=(n|0)>512?512:n}n=d[5728784+(o&31)|0]<<(o>>5);if((c[f+24>>2]|0)==(c[a+7464>>2]|0)){p=5}else{o=(ba(c[a+7520>>2]|0,n)|0)>>3;if((m|0)==-128){p=5}else{q=n;r=o}}if((p|0)==5){q=2048;r=0}if((h|0)==0){s=0;t=0}else{s=h;t=c[j>>2]|0}if((s|0)>=(i|0)){u=t;c[j>>2]=u;return}h=f+36|0;p=f+32|0;o=g|0;n=f+28|0;m=f+40|0;f=t;t=s;while(1){s=ba(c[h>>2]|0,t)|0;a=s+(c[p>>2]|0)|0;s=c[(c[o>>2]|0)+(a<<2)>>2]|0;if((s|0)==0){v=oYa(g,a)|0}else{v=s}s=c[n>>2]|0;TGb(v+(s<<1)|0,0,c[k>>2]<<1|0)|0;a=c[m>>2]|0;w=b[a+(f<<2)>>1]|0;x=f+1|0;if((w|0)<(l|0)){y=f;z=w;w=x;while(1){A=e[a+(y<<2)+2>>1]|0;B=A&1;b[v+(z+s<<1)>>1]=(((ba(A>>>1,q)|0)+r|0)>>>11^-B)+B;B=b[a+(w<<2)>>1]|0;A=w+1|0;if((B|0)<(l|0)){y=w;z=B;w=A}else{C=A;break}}}else{C=x}w=t+1|0;if((w|0)<(i|0)){f=C;t=w}else{u=C;break}}c[j>>2]=u;return}function OYa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=e+7528|0;n=e+7536|0;o=c[n>>2]|0;p=c[m>>2]<<o;q=o-f|0;r=(ba(p,h)|0)+g<<q;s=g+1<<q;t=(g|0)!=0;if(t){u=(c[e+2139660>>2]|0)+((r-1|0)*10|0)|0}else{u=630272}do{if((h|0)==0){v=u;w=630272;x=u}else{y=r-p|0;z=c[e+2139660>>2]|0;A=z+(y*10|0)|0;if(t){B=z+((y-1|0)*10|0)|0}else{B=u}if((s|0)>=(p|0)){v=B;w=A;x=B;break}if(!((g&1|0)==0|(f|0)==0)){v=B;w=A;x=B;break}v=z+(((1<<q)-p+r|0)*10|0)|0;w=A;x=B}}while(0);B=d[u+9|0]|0;s=d[w+9|0]|0;t=d[x+9|0]|0;x=d[v+9|0]|0;if((c[e+7348>>2]|0)!=0){A=1<<q;q=f&255;if((A|0)<=0){C=0;i=j;return C|0}z=e+2139660|0;y=0;while(1){D=(ba(y,p)|0)+r|0;E=0;do{F=D+E|0;G=c[z>>2]|0;TGb(G+(F*10|0)|0,0,5)|0;a[G+(F*10|0)+5|0]=-128;a[G+(F*10|0)+6|0]=-128;a[G+(F*10|0)+7|0]=-128;a[G+(F*10|0)+8|0]=1;a[G+(F*10|0)+9|0]=q;E=E+1|0;}while((E|0)<(A|0));E=y+1|0;if((E|0)<(A|0)){y=E}else{C=0;break}}i=j;return C|0}do{if((o|0)==(f|0)){H=25}else{y=t+4+x+(s+B<<1)+(e+3124)|0;A=e+12|0;q=c[A>>2]|0;z=(ba(d[y]|0,q)|0)>>8;r=q-z|0;c[A>>2]=r;q=e+8|0;p=c[q>>2]|0;if((p|0)>=(r|0)){c[q>>2]=p-r;a[y]=a[(d[y]|0)+(e+280)|0]|0;c[A>>2]=z;if((z|0)>=256){H=25;break}c[A>>2]=z<<8;z=c[q>>2]<<8;c[q>>2]=z;r=e+540|0;p=c[r>>2]|0;if(p>>>0<(c[e+544>>2]|0)>>>0){c[q>>2]=d[p]|z}c[r>>2]=p+1;H=25;break}a[y]=a[(d[y]|0)+(e+24)|0]|0;y=c[A>>2]|0;if((y|0)<256){c[A>>2]=y<<8;y=c[q>>2]<<8;c[q>>2]=y;A=e+540|0;p=c[A>>2]|0;if(p>>>0<(c[e+544>>2]|0)>>>0){c[q>>2]=d[p]|y}c[A>>2]=p+1}p=f+1|0;A=g<<1;y=h<<1;q=OYa(e,p,A,y)|0;if((q|0)<0){C=q;i=j;return C|0}q=A|1;r=OYa(e,p,q,y)|0;if((r|0)<0){C=r;i=j;return C|0}r=y|1;y=OYa(e,p,A,r)|0;if((y|0)<0){C=y;i=j;return C|0}y=OYa(e,p,q,r)|0;if((y|0)<0){C=y}else{break}i=j;return C|0}}while(0);do{if((H|0)==25){B=a[u+5|0]|0;s=B&255;x=a[u+6|0]|0;t=x&255;o=a[u+7|0]|0;y=o&255;r=d[u+4|0]|0;q=r<<1;p=q&256;A=d[w+4|0]|0;z=A<<1;E=z&256;D=(d[1191992+((E|0)==0?z:A>>>7)|0]|0)+(d[1191992+((p|0)==0?q:r>>>7)|0]|0)|0;r=(b[u>>1]|0)-(b[w>>1]|0)|0;q=(r|0)>-1?r:-r|0;r=q<<1;A=r>>>0>65535>>>0;z=A?q>>>15&65535:r;r=A?16:0;if((z&65280|0)==0){I=r;J=z}else{I=r|8;J=z>>>8}z=(d[1191992+J|0]|0)+I|0;r=(b[u+2>>1]|0)-(b[w+2>>1]|0)|0;A=(r|0)>-1?r:-r|0;r=A<<1;q=r>>>0>65535>>>0;F=q?A>>>15&65535:r;r=q?16:0;if((F&65280|0)==0){K=r;L=F}else{K=r|8;L=F>>>8}F=(d[1191992+L|0]|0)+K|0;r=(d[u+8|0]|0)+1+(d[w+8|0]|0)+(e+3124)|0;q=e+12|0;A=c[q>>2]|0;G=(ba(d[r]|0,A)|0)>>8;M=A-G|0;c[q>>2]=M;A=e+8|0;N=c[A>>2]|0;do{if((N|0)<(M|0)){a[r]=a[(d[r]|0)+(e+24)|0]|0;O=c[q>>2]|0;if((O|0)<256){P=O<<8;c[q>>2]=P;Q=c[A>>2]<<8;c[A>>2]=Q;R=e+540|0;S=c[R>>2]|0;if(S>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[S]|Q}c[R>>2]=S+1;T=P}else{T=O}O=e+7388|0;a:do{if((c[O>>2]|0)>1){P=((D<<5)+p&-32)+E|0;S=P+1152|0;R=e+3124+S|0;Q=(ba(d[R]|0,T)|0)>>8;U=T-Q|0;c[q>>2]=U;V=c[A>>2]|0;if((V|0)>=(U|0)){c[A>>2]=V-U;a[R]=a[(d[R]|0)+(e+280)|0]|0;c[q>>2]=Q;if((Q|0)>=256){W=0;break}c[q>>2]=Q<<8;Q=c[A>>2]<<8;c[A>>2]=Q;U=e+540|0;V=c[U>>2]|0;if(V>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[V]|Q}c[U>>2]=V+1;W=0;break}a[R]=a[(d[R]|0)+(e+24)|0]|0;R=c[q>>2]|0;if((R|0)<256){V=R<<8;c[q>>2]=V;U=c[A>>2]<<8;c[A>>2]=U;Q=e+540|0;X=c[Q>>2]|0;if(X>>>0<(c[e+544>>2]|0)>>>0){Y=d[X]|U;c[A>>2]=Y;Z=Y}else{Z=U}c[Q>>2]=X+1;_=V;$=Z}else{_=R;$=c[A>>2]|0}R=P+1153+(e+3124)|0;P=(ba(d[R]|0,_)|0)>>8;V=_-P|0;c[q>>2]=V;if(($|0)<(V|0)){aa=0;ca=R}else{X=e+540|0;Q=e+544|0;U=1;Y=R;R=P;P=V;V=$;while(1){c[A>>2]=V-P;a[Y]=a[(d[Y]|0)+(e+280)|0]|0;c[q>>2]=R;if((R|0)<256){da=R<<8;c[q>>2]=da;ea=c[A>>2]<<8;c[A>>2]=ea;fa=c[X>>2]|0;if(fa>>>0<(c[Q>>2]|0)>>>0){ga=d[fa]|ea;c[A>>2]=ga;ha=ga}else{ha=ea}c[X>>2]=fa+1;ia=da;ja=ha}else{ia=R;ja=c[A>>2]|0}da=U+1|0;fa=((U|0)>9?10:da)+S+(e+3124)|0;ea=(ba(d[fa]|0,ia)|0)>>8;ga=ia-ea|0;c[q>>2]=ga;if((ja|0)<(ga|0)){aa=U;ca=fa;break}else{U=da;Y=fa;R=ea;P=ga;V=ja}}}a[ca]=a[(d[ca]|0)+(e+24)|0]|0;V=c[q>>2]|0;if((V|0)<256){P=V<<8;c[q>>2]=P;R=c[A>>2]<<8;c[A>>2]=R;Y=e+540|0;U=c[Y>>2]|0;if(U>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[U]|R}c[Y>>2]=U+1;ka=P}else{ka=V}if((aa|0)<=0){W=1;break}V=e+540|0;P=e+544|0;U=2;Y=aa;R=ka;while(1){X=Y-1|0;Q=((X|0)>9?31:Y+21|0)+S+(e+3124)|0;ga=(ba(d[Q]|0,R)|0)>>8;ea=R-ga|0;c[q>>2]=ea;fa=c[A>>2]|0;do{if((fa|0)<(ea|0)){a[Q]=a[(d[Q]|0)+(e+24)|0]|0;da=c[q>>2]|0;if((da|0)>=256){la=0;ma=da;break}na=da<<8;c[q>>2]=na;da=c[A>>2]<<8;c[A>>2]=da;oa=c[V>>2]|0;if(oa>>>0<(c[P>>2]|0)>>>0){c[A>>2]=d[oa]|da}c[V>>2]=oa+1;la=0;ma=na}else{c[A>>2]=fa-ea;a[Q]=a[(d[Q]|0)+(e+280)|0]|0;c[q>>2]=ga;if((ga|0)>=256){la=1;ma=ga;break}na=ga<<8;c[q>>2]=na;oa=c[A>>2]<<8;c[A>>2]=oa;da=c[V>>2]|0;if(da>>>0<(c[P>>2]|0)>>>0){c[A>>2]=d[da]|oa}c[V>>2]=da+1;la=1;ma=na}}while(0);ga=la|U;if((X|0)<=0){W=ga;break a}U=ga<<1;Y=X;R=ma}}else{W=0}}while(0);R=c[O>>2]|0;if((W|0)>=(R|0)){yDb(c[e+4>>2]|0,16,2048080,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;C=-1094995529;i=j;return C|0}PYa(R,k,l,W,u,w,v);R=((W|0)!=0)<<4;Y=z+R<<5;U=Y+128|0;V=e+3124+U|0;P=c[q>>2]|0;S=d[V]|0;ga=(ba(S,P)|0)>>8;Q=P-ga|0;c[q>>2]=Q;P=c[A>>2]|0;do{if((P|0)<(Q|0)){a[V]=a[e+24+S|0]|0;if((Q|0)<256){ea=Q<<8;c[q>>2]=ea;fa=P<<8;c[A>>2]=fa;na=e+540|0;da=c[na>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){oa=d[da]|fa;c[A>>2]=oa;pa=oa}else{pa=fa}c[na>>2]=da+1;qa=ea;ra=pa}else{qa=Q;ra=P}ea=Y+129+(e+3124)|0;da=a[ea]|0;na=(ba(da&255,qa)|0)>>8;fa=qa-na|0;c[q>>2]=fa;if((ra|0)<(fa|0)){sa=0;ta=ea;ua=da}else{da=e+540|0;oa=e+544|0;va=1;wa=ea;ea=na;na=fa;fa=ra;while(1){c[A>>2]=fa-na;a[wa]=a[(d[wa]|0)+(e+280)|0]|0;c[q>>2]=ea;if((ea|0)<256){xa=ea<<8;c[q>>2]=xa;ya=c[A>>2]<<8;c[A>>2]=ya;za=c[da>>2]|0;if(za>>>0<(c[oa>>2]|0)>>>0){Aa=d[za]|ya;c[A>>2]=Aa;Ba=Aa}else{Ba=ya}c[da>>2]=za+1;Ca=xa;Da=Ba}else{Ca=ea;Da=c[A>>2]|0}xa=va+1|0;Ea=((va|0)>9?10:xa)+U+(e+3124)|0;za=(ba(d[Ea]|0,Ca)|0)>>8;ya=Ca-za|0;c[q>>2]=ya;if((Da|0)<(ya|0)){break}else{va=xa;wa=Ea;ea=za;na=ya;fa=Da}}sa=va;ta=Ea;ua=a[Ea]|0}a[ta]=a[(ua&255)+(e+24)|0]|0;fa=c[q>>2]|0;if((fa|0)<256){na=fa<<8;c[q>>2]=na;ea=c[A>>2]<<8;c[A>>2]=ea;wa=e+540|0;da=c[wa>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[da]|ea}c[wa>>2]=da+1;Fa=na}else{Fa=fa}b:do{if((sa|0)>0){fa=e+540|0;na=e+544|0;da=2;wa=sa;ea=Fa;while(1){oa=wa-1|0;ya=((oa|0)>9?31:wa+21|0)+U+(e+3124)|0;za=(ba(d[ya]|0,ea)|0)>>8;xa=ea-za|0;c[q>>2]=xa;Aa=c[A>>2]|0;do{if((Aa|0)<(xa|0)){a[ya]=a[(d[ya]|0)+(e+24)|0]|0;Ga=c[q>>2]|0;if((Ga|0)>=256){Ha=0;Ia=Ga;break}Ja=Ga<<8;c[q>>2]=Ja;Ga=c[A>>2]<<8;c[A>>2]=Ga;Ka=c[fa>>2]|0;if(Ka>>>0<(c[na>>2]|0)>>>0){c[A>>2]=d[Ka]|Ga}c[fa>>2]=Ka+1;Ha=0;Ia=Ja}else{c[A>>2]=Aa-xa;a[ya]=a[(d[ya]|0)+(e+280)|0]|0;c[q>>2]=za;if((za|0)>=256){Ha=1;Ia=za;break}Ja=za<<8;c[q>>2]=Ja;Ka=c[A>>2]<<8;c[A>>2]=Ka;Ga=c[fa>>2]|0;if(Ga>>>0<(c[na>>2]|0)>>>0){c[A>>2]=d[Ga]|Ka}c[fa>>2]=Ga+1;Ha=1;Ia=Ja}}while(0);za=Ha|da;if((oa|0)<=0){La=za;Ma=Ia;break b}da=za<<1;wa=oa;ea=Ia}}else{La=1;Ma=Fa}}while(0);va=((sa|0)>10?21:sa+11|0)+U+(e+3124)|0;ea=(ba(d[va]|0,Ma)|0)>>8;wa=Ma-ea|0;c[q>>2]=wa;da=c[A>>2]|0;do{if((da|0)<(wa|0)){a[va]=a[(d[va]|0)+(e+24)|0]|0;fa=c[q>>2]|0;if((fa|0)>=256){Na=0;Oa=fa;break}na=fa<<8;c[q>>2]=na;fa=c[A>>2]<<8;c[A>>2]=fa;X=e+540|0;za=c[X>>2]|0;if(za>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[za]|fa}c[X>>2]=za+1;Na=0;Oa=na}else{c[A>>2]=da-wa;a[va]=a[(d[va]|0)+(e+280)|0]|0;c[q>>2]=ea;if((ea|0)>=256){Na=1;Oa=ea;break}na=ea<<8;c[q>>2]=na;za=c[A>>2]<<8;c[A>>2]=za;X=e+540|0;fa=c[X>>2]|0;if(fa>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[fa]|za}c[X>>2]=fa+1;Na=1;Oa=na}}while(0);Pa=(La^-Na)+Na|0;Qa=Oa;Ra=c[A>>2]|0}else{ea=P-Q|0;c[A>>2]=ea;a[V]=a[e+280+S|0]|0;c[q>>2]=ga;if((ga|0)>=256){Pa=0;Qa=ga;Ra=ea;break}va=ga<<8;c[q>>2]=va;wa=ea<<8;c[A>>2]=wa;ea=e+540|0;da=c[ea>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){na=d[da]|wa;c[A>>2]=na;Sa=na}else{Sa=wa}c[ea>>2]=da+1;Pa=0;Qa=va;Ra=Sa}}while(0);c[k>>2]=(c[k>>2]|0)+Pa;ga=F+R<<5;S=ga+128|0;V=e+3124+S|0;Q=d[V]|0;P=(ba(Q,Qa)|0)>>8;U=Qa-P|0;c[q>>2]=U;do{if((Ra|0)<(U|0)){a[V]=a[e+24+Q|0]|0;if((U|0)<256){Y=U<<8;c[q>>2]=Y;O=Ra<<8;c[A>>2]=O;va=e+540|0;da=c[va>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){ea=d[da]|O;c[A>>2]=ea;Ta=ea}else{Ta=O}c[va>>2]=da+1;Ua=Y;Va=Ta}else{Ua=U;Va=Ra}Y=ga+129+(e+3124)|0;da=a[Y]|0;va=(ba(da&255,Ua)|0)>>8;O=Ua-va|0;c[q>>2]=O;if((Va|0)<(O|0)){Wa=0;Xa=Y;Ya=da}else{da=e+540|0;ea=e+544|0;wa=1;na=Y;Y=va;va=O;O=Va;while(1){c[A>>2]=O-va;a[na]=a[(d[na]|0)+(e+280)|0]|0;c[q>>2]=Y;if((Y|0)<256){fa=Y<<8;c[q>>2]=fa;X=c[A>>2]<<8;c[A>>2]=X;za=c[da>>2]|0;if(za>>>0<(c[ea>>2]|0)>>>0){ya=d[za]|X;c[A>>2]=ya;Za=ya}else{Za=X}c[da>>2]=za+1;_a=fa;$a=Za}else{_a=Y;$a=c[A>>2]|0}fa=wa+1|0;ab=((wa|0)>9?10:fa)+S+(e+3124)|0;za=(ba(d[ab]|0,_a)|0)>>8;X=_a-za|0;c[q>>2]=X;if(($a|0)<(X|0)){break}else{wa=fa;na=ab;Y=za;va=X;O=$a}}Wa=wa;Xa=ab;Ya=a[ab]|0}a[Xa]=a[(Ya&255)+(e+24)|0]|0;O=c[q>>2]|0;if((O|0)<256){va=O<<8;c[q>>2]=va;Y=c[A>>2]<<8;c[A>>2]=Y;na=e+540|0;da=c[na>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[da]|Y}c[na>>2]=da+1;bb=va}else{bb=O}c:do{if((Wa|0)>0){O=e+540|0;va=e+544|0;da=2;na=Wa;Y=bb;while(1){ea=na-1|0;X=((ea|0)>9?31:na+21|0)+S+(e+3124)|0;za=(ba(d[X]|0,Y)|0)>>8;fa=Y-za|0;c[q>>2]=fa;ya=c[A>>2]|0;do{if((ya|0)<(fa|0)){a[X]=a[(d[X]|0)+(e+24)|0]|0;xa=c[q>>2]|0;if((xa|0)>=256){cb=0;db=xa;break}Aa=xa<<8;c[q>>2]=Aa;xa=c[A>>2]<<8;c[A>>2]=xa;Ja=c[O>>2]|0;if(Ja>>>0<(c[va>>2]|0)>>>0){c[A>>2]=d[Ja]|xa}c[O>>2]=Ja+1;cb=0;db=Aa}else{c[A>>2]=ya-fa;a[X]=a[(d[X]|0)+(e+280)|0]|0;c[q>>2]=za;if((za|0)>=256){cb=1;db=za;break}Aa=za<<8;c[q>>2]=Aa;Ja=c[A>>2]<<8;c[A>>2]=Ja;xa=c[O>>2]|0;if(xa>>>0<(c[va>>2]|0)>>>0){c[A>>2]=d[xa]|Ja}c[O>>2]=xa+1;cb=1;db=Aa}}while(0);za=cb|da;if((ea|0)<=0){eb=za;fb=db;break c}da=za<<1;na=ea;Y=db}}else{eb=1;fb=bb}}while(0);wa=((Wa|0)>10?21:Wa+11|0)+S+(e+3124)|0;Y=(ba(d[wa]|0,fb)|0)>>8;na=fb-Y|0;c[q>>2]=na;da=c[A>>2]|0;do{if((da|0)<(na|0)){a[wa]=a[(d[wa]|0)+(e+24)|0]|0;O=c[q>>2]|0;if((O|0)>=256){gb=0;break}c[q>>2]=O<<8;O=c[A>>2]<<8;c[A>>2]=O;va=e+540|0;za=c[va>>2]|0;if(za>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[za]|O}c[va>>2]=za+1;gb=0}else{c[A>>2]=da-na;a[wa]=a[(d[wa]|0)+(e+280)|0]|0;c[q>>2]=Y;if((Y|0)>=256){gb=1;break}c[q>>2]=Y<<8;za=c[A>>2]<<8;c[A>>2]=za;va=e+540|0;O=c[va>>2]|0;if(O>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[O]|za}c[va>>2]=O+1;gb=1}}while(0);hb=(eb^-gb)+gb|0}else{Y=Ra-U|0;c[A>>2]=Y;a[V]=a[e+280+Q|0]|0;c[q>>2]=P;if((P|0)>=256){hb=0;break}c[q>>2]=P<<8;wa=Y<<8;c[A>>2]=wa;Y=e+540|0;na=c[Y>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[na]|wa}c[Y>>2]=na+1;hb=0}}while(0);c[l>>2]=(c[l>>2]|0)+hb;ib=B;jb=W&255;kb=o;lb=x;mb=0}else{c[A>>2]=N-M;a[r]=a[(d[r]|0)+(e+280)|0]|0;c[q>>2]=G;if((G|0)<256){c[q>>2]=G<<8;P=c[A>>2]<<8;c[A>>2]=P;Q=e+540|0;V=c[Q>>2]|0;if(V>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[V]|P}c[Q>>2]=V+1}PYa(c[e+7388>>2]|0,k,l,0,u,w,v);V=e+3156|0;Q=c[q>>2]|0;P=d[V]|0;U=(ba(P,Q)|0)>>8;S=Q-U|0;c[q>>2]=S;Q=c[A>>2]|0;do{if((Q|0)<(S|0)){a[V]=a[e+24+P|0]|0;if((S|0)<256){ga=S<<8;c[q>>2]=ga;R=Q<<8;c[A>>2]=R;na=e+540|0;Y=c[na>>2]|0;if(Y>>>0<(c[e+544>>2]|0)>>>0){wa=d[Y]|R;c[A>>2]=wa;nb=wa}else{nb=R}c[na>>2]=Y+1;ob=ga;pb=nb}else{ob=S;pb=Q}ga=e+3157|0;Y=a[ga]|0;na=(ba(Y&255,ob)|0)>>8;R=ob-na|0;c[q>>2]=R;if((pb|0)<(R|0)){qb=0;rb=ga;sb=Y}else{Y=e+540|0;wa=e+544|0;da=1;O=ga;ga=na;na=R;R=pb;while(1){c[A>>2]=R-na;a[O]=a[(d[O]|0)+(e+280)|0]|0;c[q>>2]=ga;if((ga|0)<256){va=ga<<8;c[q>>2]=va;za=c[A>>2]<<8;c[A>>2]=za;X=c[Y>>2]|0;if(X>>>0<(c[wa>>2]|0)>>>0){fa=d[X]|za;c[A>>2]=fa;tb=fa}else{tb=za}c[Y>>2]=X+1;ub=va;vb=tb}else{ub=ga;vb=c[A>>2]|0}wb=((da|0)>9?42:da+33|0)+(e+3124)|0;va=(ba(d[wb]|0,ub)|0)>>8;X=ub-va|0;c[q>>2]=X;if((vb|0)<(X|0)){break}else{da=da+1|0;O=wb;ga=va;na=X;R=vb}}qb=da;rb=wb;sb=a[wb]|0}a[rb]=a[(sb&255)+(e+24)|0]|0;R=c[q>>2]|0;if((R|0)<256){na=R<<8;c[q>>2]=na;ga=c[A>>2]<<8;c[A>>2]=ga;O=e+540|0;Y=c[O>>2]|0;if(Y>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[Y]|ga}c[O>>2]=Y+1;xb=na}else{xb=R}d:do{if((qb|0)>0){R=e+540|0;na=e+544|0;Y=2;O=qb;ga=xb;while(1){wa=O-1|0;X=((wa|0)>9?63:O+53|0)+(e+3124)|0;va=(ba(d[X]|0,ga)|0)>>8;za=ga-va|0;c[q>>2]=za;fa=c[A>>2]|0;do{if((fa|0)<(za|0)){a[X]=a[(d[X]|0)+(e+24)|0]|0;ya=c[q>>2]|0;if((ya|0)>=256){yb=0;zb=ya;break}oa=ya<<8;c[q>>2]=oa;ya=c[A>>2]<<8;c[A>>2]=ya;Aa=c[R>>2]|0;if(Aa>>>0<(c[na>>2]|0)>>>0){c[A>>2]=d[Aa]|ya}c[R>>2]=Aa+1;yb=0;zb=oa}else{c[A>>2]=fa-za;a[X]=a[(d[X]|0)+(e+280)|0]|0;c[q>>2]=va;if((va|0)>=256){yb=1;zb=va;break}oa=va<<8;c[q>>2]=oa;Aa=c[A>>2]<<8;c[A>>2]=Aa;ya=c[R>>2]|0;if(ya>>>0<(c[na>>2]|0)>>>0){c[A>>2]=d[ya]|Aa}c[R>>2]=ya+1;yb=1;zb=oa}}while(0);va=yb|Y;if((wa|0)<=0){Ab=va;Bb=zb;break d}Y=va<<1;O=wa;ga=zb}}else{Ab=1;Bb=xb}}while(0);da=((qb|0)>10?53:qb+43|0)+(e+3124)|0;ga=(ba(d[da]|0,Bb)|0)>>8;O=Bb-ga|0;c[q>>2]=O;Y=c[A>>2]|0;do{if((Y|0)<(O|0)){a[da]=a[(d[da]|0)+(e+24)|0]|0;R=c[q>>2]|0;if((R|0)>=256){Cb=0;Db=R;break}na=R<<8;c[q>>2]=na;R=c[A>>2]<<8;c[A>>2]=R;va=e+540|0;X=c[va>>2]|0;if(X>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[X]|R}c[va>>2]=X+1;Cb=0;Db=na}else{c[A>>2]=Y-O;a[da]=a[(d[da]|0)+(e+280)|0]|0;c[q>>2]=ga;if((ga|0)>=256){Cb=1;Db=ga;break}na=ga<<8;c[q>>2]=na;X=c[A>>2]<<8;c[A>>2]=X;va=e+540|0;R=c[va>>2]|0;if(R>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[R]|X}c[va>>2]=R+1;Cb=1;Db=na}}while(0);Eb=(Ab^-Cb)+Cb|0;Fb=Db}else{ga=Q-S|0;c[A>>2]=ga;a[V]=a[e+280+P|0]|0;c[q>>2]=U;if((U|0)>=256){Eb=0;Fb=U;break}da=U<<8;c[q>>2]=da;O=ga<<8;c[A>>2]=O;ga=e+540|0;Y=c[ga>>2]|0;if(Y>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[Y]|O}c[ga>>2]=Y+1;Eb=0;Fb=da}}while(0);U=Eb+s&255;if((c[e+7544>>2]|0)<=2){ib=U;jb=0;kb=o;lb=x;mb=1;break}P=e+3188|0;V=d[P]|0;S=(ba(V,Fb)|0)>>8;Q=Fb-S|0;c[q>>2]=Q;da=c[A>>2]|0;do{if((da|0)<(Q|0)){a[P]=a[e+24+V|0]|0;if((Q|0)<256){Y=Q<<8;c[q>>2]=Y;ga=da<<8;c[A>>2]=ga;O=e+540|0;na=c[O>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){R=d[na]|ga;c[A>>2]=R;Gb=R}else{Gb=ga}c[O>>2]=na+1;Hb=Y;Ib=Gb}else{Hb=Q;Ib=da}Y=e+3189|0;na=a[Y]|0;O=(ba(na&255,Hb)|0)>>8;ga=Hb-O|0;c[q>>2]=ga;if((Ib|0)<(ga|0)){Jb=0;Kb=Y;Lb=na}else{na=e+540|0;R=e+544|0;va=1;X=Y;Y=O;O=ga;ga=Ib;while(1){c[A>>2]=ga-O;a[X]=a[(d[X]|0)+(e+280)|0]|0;c[q>>2]=Y;if((Y|0)<256){za=Y<<8;c[q>>2]=za;fa=c[A>>2]<<8;c[A>>2]=fa;ea=c[na>>2]|0;if(ea>>>0<(c[R>>2]|0)>>>0){oa=d[ea]|fa;c[A>>2]=oa;Mb=oa}else{Mb=fa}c[na>>2]=ea+1;Nb=za;Ob=Mb}else{Nb=Y;Ob=c[A>>2]|0}Pb=((va|0)>9?74:va+65|0)+(e+3124)|0;za=(ba(d[Pb]|0,Nb)|0)>>8;ea=Nb-za|0;c[q>>2]=ea;if((Ob|0)<(ea|0)){break}else{va=va+1|0;X=Pb;Y=za;O=ea;ga=Ob}}Jb=va;Kb=Pb;Lb=a[Pb]|0}a[Kb]=a[(Lb&255)+(e+24)|0]|0;ga=c[q>>2]|0;if((ga|0)<256){O=ga<<8;c[q>>2]=O;Y=c[A>>2]<<8;c[A>>2]=Y;X=e+540|0;na=c[X>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[na]|Y}c[X>>2]=na+1;Qb=O}else{Qb=ga}e:do{if((Jb|0)>0){ga=e+540|0;O=e+544|0;na=2;X=Jb;Y=Qb;while(1){R=X-1|0;ea=((R|0)>9?95:X+85|0)+(e+3124)|0;za=(ba(d[ea]|0,Y)|0)>>8;fa=Y-za|0;c[q>>2]=fa;oa=c[A>>2]|0;do{if((oa|0)<(fa|0)){a[ea]=a[(d[ea]|0)+(e+24)|0]|0;ya=c[q>>2]|0;if((ya|0)>=256){Rb=0;Sb=ya;break}Aa=ya<<8;c[q>>2]=Aa;ya=c[A>>2]<<8;c[A>>2]=ya;xa=c[ga>>2]|0;if(xa>>>0<(c[O>>2]|0)>>>0){c[A>>2]=d[xa]|ya}c[ga>>2]=xa+1;Rb=0;Sb=Aa}else{c[A>>2]=oa-fa;a[ea]=a[(d[ea]|0)+(e+280)|0]|0;c[q>>2]=za;if((za|0)>=256){Rb=1;Sb=za;break}Aa=za<<8;c[q>>2]=Aa;xa=c[A>>2]<<8;c[A>>2]=xa;ya=c[ga>>2]|0;if(ya>>>0<(c[O>>2]|0)>>>0){c[A>>2]=d[ya]|xa}c[ga>>2]=ya+1;Rb=1;Sb=Aa}}while(0);za=Rb|na;if((R|0)<=0){Tb=za;Ub=Sb;break e}na=za<<1;X=R;Y=Sb}}else{Tb=1;Ub=Qb}}while(0);va=((Jb|0)>10?85:Jb+75|0)+(e+3124)|0;Y=(ba(d[va]|0,Ub)|0)>>8;X=Ub-Y|0;c[q>>2]=X;na=c[A>>2]|0;do{if((na|0)<(X|0)){a[va]=a[(d[va]|0)+(e+24)|0]|0;ga=c[q>>2]|0;if((ga|0)>=256){Vb=0;Wb=ga;break}O=ga<<8;c[q>>2]=O;ga=c[A>>2]<<8;c[A>>2]=ga;za=e+540|0;ea=c[za>>2]|0;if(ea>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[ea]|ga}c[za>>2]=ea+1;Vb=0;Wb=O}else{c[A>>2]=na-X;a[va]=a[(d[va]|0)+(e+280)|0]|0;c[q>>2]=Y;if((Y|0)>=256){Vb=1;Wb=Y;break}O=Y<<8;c[q>>2]=O;ea=c[A>>2]<<8;c[A>>2]=ea;za=e+540|0;ga=c[za>>2]|0;if(ga>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[ga]|ea}c[za>>2]=ga+1;Vb=1;Wb=O}}while(0);Xb=(Tb^-Vb)+Vb|0;Yb=Wb;Zb=c[A>>2]|0}else{Y=da-Q|0;c[A>>2]=Y;a[P]=a[e+280+V|0]|0;c[q>>2]=S;if((S|0)>=256){Xb=0;Yb=S;Zb=Y;break}va=S<<8;c[q>>2]=va;X=Y<<8;c[A>>2]=X;Y=e+540|0;na=c[Y>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){O=d[na]|X;c[A>>2]=O;_b=O}else{_b=X}c[Y>>2]=na+1;Xb=0;Yb=va;Zb=_b}}while(0);S=Xb+t|0;V=e+3220|0;P=d[V]|0;Q=(ba(P,Yb)|0)>>8;da=Yb-Q|0;c[q>>2]=da;do{if((Zb|0)<(da|0)){a[V]=a[e+24+P|0]|0;if((da|0)<256){va=da<<8;c[q>>2]=va;na=Zb<<8;c[A>>2]=na;Y=e+540|0;X=c[Y>>2]|0;if(X>>>0<(c[e+544>>2]|0)>>>0){O=d[X]|na;c[A>>2]=O;$b=O}else{$b=na}c[Y>>2]=X+1;ac=va;bc=$b}else{ac=da;bc=Zb}va=e+3221|0;X=a[va]|0;Y=(ba(X&255,ac)|0)>>8;na=ac-Y|0;c[q>>2]=na;if((bc|0)<(na|0)){cc=0;dc=va;ec=X}else{X=e+540|0;O=e+544|0;ga=1;za=va;va=Y;Y=na;na=bc;while(1){c[A>>2]=na-Y;a[za]=a[(d[za]|0)+(e+280)|0]|0;c[q>>2]=va;if((va|0)<256){ea=va<<8;c[q>>2]=ea;fa=c[A>>2]<<8;c[A>>2]=fa;oa=c[X>>2]|0;if(oa>>>0<(c[O>>2]|0)>>>0){wa=d[oa]|fa;c[A>>2]=wa;fc=wa}else{fc=fa}c[X>>2]=oa+1;gc=ea;hc=fc}else{gc=va;hc=c[A>>2]|0}ic=((ga|0)>9?106:ga+97|0)+(e+3124)|0;ea=(ba(d[ic]|0,gc)|0)>>8;oa=gc-ea|0;c[q>>2]=oa;if((hc|0)<(oa|0)){break}else{ga=ga+1|0;za=ic;va=ea;Y=oa;na=hc}}cc=ga;dc=ic;ec=a[ic]|0}a[dc]=a[(ec&255)+(e+24)|0]|0;na=c[q>>2]|0;if((na|0)<256){Y=na<<8;c[q>>2]=Y;va=c[A>>2]<<8;c[A>>2]=va;za=e+540|0;X=c[za>>2]|0;if(X>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[X]|va}c[za>>2]=X+1;jc=Y}else{jc=na}f:do{if((cc|0)>0){na=e+540|0;Y=e+544|0;X=2;za=cc;va=jc;while(1){O=za-1|0;oa=((O|0)>9?127:za+117|0)+(e+3124)|0;ea=(ba(d[oa]|0,va)|0)>>8;fa=va-ea|0;c[q>>2]=fa;wa=c[A>>2]|0;do{if((wa|0)<(fa|0)){a[oa]=a[(d[oa]|0)+(e+24)|0]|0;Aa=c[q>>2]|0;if((Aa|0)>=256){kc=0;lc=Aa;break}ya=Aa<<8;c[q>>2]=ya;Aa=c[A>>2]<<8;c[A>>2]=Aa;xa=c[na>>2]|0;if(xa>>>0<(c[Y>>2]|0)>>>0){c[A>>2]=d[xa]|Aa}c[na>>2]=xa+1;kc=0;lc=ya}else{c[A>>2]=wa-fa;a[oa]=a[(d[oa]|0)+(e+280)|0]|0;c[q>>2]=ea;if((ea|0)>=256){kc=1;lc=ea;break}ya=ea<<8;c[q>>2]=ya;xa=c[A>>2]<<8;c[A>>2]=xa;Aa=c[na>>2]|0;if(Aa>>>0<(c[Y>>2]|0)>>>0){c[A>>2]=d[Aa]|xa}c[na>>2]=Aa+1;kc=1;lc=ya}}while(0);ea=kc|X;if((O|0)<=0){mc=ea;nc=lc;break f}X=ea<<1;za=O;va=lc}}else{mc=1;nc=jc}}while(0);ga=((cc|0)>10?117:cc+107|0)+(e+3124)|0;va=(ba(d[ga]|0,nc)|0)>>8;za=nc-va|0;c[q>>2]=za;X=c[A>>2]|0;do{if((X|0)<(za|0)){a[ga]=a[(d[ga]|0)+(e+24)|0]|0;na=c[q>>2]|0;if((na|0)>=256){oc=0;break}c[q>>2]=na<<8;na=c[A>>2]<<8;c[A>>2]=na;Y=e+540|0;ea=c[Y>>2]|0;if(ea>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[ea]|na}c[Y>>2]=ea+1;oc=0}else{c[A>>2]=X-za;a[ga]=a[(d[ga]|0)+(e+280)|0]|0;c[q>>2]=va;if((va|0)>=256){oc=1;break}c[q>>2]=va<<8;ea=c[A>>2]<<8;c[A>>2]=ea;Y=e+540|0;na=c[Y>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[na]|ea}c[Y>>2]=na+1;oc=1}}while(0);pc=(mc^-oc)+oc|0}else{va=Zb-da|0;c[A>>2]=va;a[V]=a[e+280+P|0]|0;c[q>>2]=Q;if((Q|0)>=256){pc=0;break}c[q>>2]=Q<<8;ga=va<<8;c[A>>2]=ga;va=e+540|0;za=c[va>>2]|0;if(za>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[za]|ga}c[va>>2]=za+1;pc=0}}while(0);ib=U;jb=0;kb=pc+y&255;lb=S&255;mb=1}}while(0);y=c[n>>2]|0;A=c[m>>2]<<y;q=y-f|0;y=(ba(A,h)|0)+g<<q;t=1<<q;q=c[k>>2]&65535;x=c[l>>2]&65535;o=f&255;if((t|0)<=0){break}s=e+2139660|0;G=0;do{r=(ba(G,A)|0)+y|0;M=0;do{N=r+M|0;B=c[s>>2]|0;b[B+(N*10|0)>>1]=q;b[B+(N*10|0)+2>>1]=x;a[B+(N*10|0)+4|0]=jb;a[B+(N*10|0)+5|0]=ib;a[B+(N*10|0)+6|0]=lb;a[B+(N*10|0)+7|0]=kb;a[B+(N*10|0)+8|0]=mb;a[B+(N*10|0)+9|0]=o;M=M+1|0;}while((M|0)<(t|0));G=G+1|0;}while((G|0)<(t|0))}}while(0);C=0;i=j;return C|0}function PYa(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=b[h>>1]|0;l=k<<16>>16;if((a|0)==1){a=b[i>>1]|0;m=a<<16>>16;n=b[j>>1]|0;o=n<<16>>16;do{if(k<<16>>16>a<<16>>16){if(!(n<<16>>16>a<<16>>16)){p=m;break}p=(o|0)>(l|0)?l:o}else{if(!(a<<16>>16>n<<16>>16)){p=m;break}p=(o|0)>(l|0)?o:l}}while(0);c[e>>2]=p;p=b[h+2>>1]|0;o=p<<16>>16;m=b[i+2>>1]|0;n=m<<16>>16;a=b[j+2>>1]|0;k=a<<16>>16;if(p<<16>>16>m<<16>>16){if(!(a<<16>>16>m<<16>>16)){q=n;c[f>>2]=q;return}q=(k|0)>(o|0)?o:k;c[f>>2]=q;return}else{if(!(m<<16>>16>a<<16>>16)){q=n;c[f>>2]=q;return}q=(k|0)>(o|0)?k:o;c[f>>2]=q;return}}else{o=h+4|0;k=(ba(c[5728520+(g<<5)+(d[o]<<2)>>2]|0,l)|0)+128>>8;l=i+4|0;n=(ba(c[5728520+(g<<5)+(d[l]<<2)>>2]|0,b[i>>1]|0)|0)+128>>8;a=j+4|0;m=(ba(c[5728520+(g<<5)+(d[a]<<2)>>2]|0,b[j>>1]|0)|0)+128>>8;do{if((k|0)>(n|0)){if((m|0)<=(n|0)){r=n;break}r=(m|0)>(k|0)?k:m}else{if((n|0)<=(m|0)){r=n;break}r=(m|0)>(k|0)?m:k}}while(0);c[e>>2]=r;r=(ba(c[5728520+(g<<5)+(d[o]<<2)>>2]|0,b[h+2>>1]|0)|0)+128>>8;h=(ba(c[5728520+(g<<5)+(d[l]<<2)>>2]|0,b[i+2>>1]|0)|0)+128>>8;i=(ba(c[5728520+(g<<5)+(d[a]<<2)>>2]|0,b[j+2>>1]|0)|0)+128>>8;if((r|0)>(h|0)){if((i|0)<=(h|0)){q=h;c[f>>2]=q;return}q=(i|0)>(r|0)?r:i;c[f>>2]=q;return}else{if((h|0)<=(i|0)){q=h;c[f>>2]=q;return}q=(i|0)>(r|0)?i:r;c[f>>2]=q;return}}}function QYa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=b+60|0;f=c[e>>2]|0;g=f;if((c[b+680>>2]|0)>-2){yDb(b,16,2305736,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1;i=d;return j|0}k=c[b+216>>2]|0;l=b+88|0;do{if((k|0)==0){if((c[l>>2]&2|0)==0){break}if((c[b+80>>2]|0)!=0){break}yDb(b,16,2287816,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1;i=d;return j|0}}while(0);c[f+7360>>2]=k;c[f+7512>>2]=((c[l>>2]|0)>>>3&2^2)+2;k=f+7536|0;c[k>>2]=(c[l>>2]|0)>>>2&1;c[f+540556>>2]=1;c[f+540548>>2]=6;a[f+540552|0]=40;a[f+540553|0]=-10;a[f+540554|0]=2;c[f+540560>>2]=1;c[f+1073584>>2]=1;c[f+1073576>>2]=6;a[f+1073580|0]=40;a[f+1073581|0]=-10;a[f+1073582|0]=2;c[f+1073588>>2]=1;c[f+1606612>>2]=1;c[f+1606604>>2]=6;a[f+1606608|0]=40;a[f+1606609|0]=-10;a[f+1606610|0]=2;c[f+1606616>>2]=1;m=Kob(b)|0;if((m|0)<0){Wob(c[e>>2]|0);j=m;i=d;return j|0}Hob(g)|0;c[f+7356>>2]=0;g=f+2143800|0;c[f+2143804>>2]=b;c[f+2143860>>2]=c[l>>2];c[f+2143824>>2]=c[b+72>>2];m=cEb((c[b+120>>2]<<6)+4096|0)|0;e=f+2155992|0;c[e>>2]=m;c[f+2156008>>2]=m;m=f+2156016|0;c[m>>2]=cEb(256)|0;n=f+2156020|0;c[n>>2]=cEb(256)|0;o=cEb(12288)|0;c[f+2153752>>2]=o;if((c[e>>2]|0)==0){j=-12;i=d;return j|0}if((c[m>>2]|0)==0){j=-12;i=d;return j|0}if((c[n>>2]|0)==0|(o|0)==0){j=-12;i=d;return j|0}Olb(g);o=c[b+364>>2]|0;if((o|0)>1){p=(o|0)>8?8:o}else{p=1}o=f+7384|0;c[o>>2]=p;p=c[l>>2]|0;do{if((p&512|0)==0){q=p}else{n=b+668|0;if((c[n>>2]|0)!=0){q=p;break}m=cEb(256)|0;c[n>>2]=m;if((m|0)==0){j=-12;i=d;return j|0}else{q=c[l>>2]|0;break}}}while(0);do{if((q&1026|0)==2){r=q}else{if((kUa(g)|0)<0){j=-1;i=d;return j|0}else{r=c[l>>2]|0;break}}}while(0);c[f+7508>>2]=(r&1026|0)==0;r=c[b+140>>2]|0;if((r|0)==5|(r|0)==0|(r|0)==6){c[f+7544>>2]=3;c[f+7476>>2]=0}else if((r|0)==8){c[f+7544>>2]=1;c[f+7476>>2]=1}else{yDb(b,16,2271712,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1;i=d;return j|0}_Ga(r,f+7480|0,f+7484|0);r=f+548|0;h=f+4|0;V3(r,f+960|0,c[(c[h>>2]|0)+232>>2]|0);V3(r,f+984|0,c[(c[h>>2]|0)+236>>2]|0);r=ICb()|0;c[f+2536>>2]=r;if((r|0)==0){j=-12;i=d;return j|0}b=_$a(c[h>>2]|0,r,1)|0;if((b|0)<0){j=b;i=d;return j|0}if((c[(c[h>>2]|0)+144>>2]|0)!=50){j=0;i=d;return j|0}h=ba(c[f+7532>>2]|0,c[f+7528>>2]|0)|0;b=h<<(c[k>>2]<<1)<<2;k=f+7392|0;h=f+7424|0;f=0;while(1){if((f|0)>=(c[o>>2]|0)){j=0;s=31;break}r=k+(f<<2)|0;c[r>>2]=cEb(b)|0;l=cEb(b)|0;c[h+(f<<2)>>2]=l;if((c[r>>2]|0)==0|(l|0)==0){j=-12;s=31;break}else{f=f+1|0}}if((s|0)==31){i=d;return j|0}return 0}function RYa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0.0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0;k=i;i=i+4256|0;l=k|0;m=k+32|0;n=c[f+60>>2]|0;o=n;p=n+8|0;q=n+4|0;r=c[q>>2]|0;s=c[r+120>>2]|0;t=c[r+124>>2]|0;r=n+7528|0;u=n+7532|0;v=(ba((c[r>>2]|0)*768|0,c[u>>2]|0)|0)+16384|0;w=r0a(f,g,v,(v|0)<0|0?-1:0)|0;if((w|0)<0){y=w;i=k;return y|0}w=g+24|0;v=g+28|0;eUa(p,c[w>>2]|0,c[v>>2]|0);gUa(p,214748364,248);z=n+7544|0;if((c[z>>2]|0)>0){A=n+1752|0;B=n+2536|0;C=n+7480|0;D=n+7484|0;E=0;do{if((E|0)==0){G=0;H=0}else{G=c[D>>2]|0;H=c[C>>2]|0}I=t>>G;if((I|0)>0){J=h+32+(E<<2)|0;K=h+(E<<2)|0;L=s>>H;M=0;while(1){N=c[B>>2]|0;O=ba(c[N+32+(E<<2)>>2]|0,M)|0;P=ba(c[J>>2]|0,M)|0;UGb((c[N+(E<<2)>>2]|0)+O|0,(c[K>>2]|0)+P|0,L)|0;P=M+1|0;if((P|0)<(I|0)){M=P}else{Q=L;break}}}else{Q=s>>H}L=c[B>>2]|0;Ke[c[A>>2]&1023](c[L+(E<<2)>>2]|0,c[L+32+(E<<2)>>2]|0,Q,I,16>>>(H>>>0),16>>>(G>>>0),3);E=E+1|0;}while((E|0)<(c[z>>2]|0))}c[n+2532>>2]=h;E=f+428|0;G=n+2143800|0;c[n+2143908>>2]=c[E>>2];H=f+88|0;do{if((c[H>>2]&1024|0)==0){Q=c[f+136>>2]|0;if((Q|0)==0){S=1}else{S=((c[E>>2]|0)%(Q|0)|0|0)==0}c[n+7348>>2]=S&1;Q=S?1:2;c[h+88>>2]=Q;c[n+2153792>>2]=Q}else{Q=c[(c[n+2157036>>2]|0)+((c[E>>2]|0)*80|0)+40>>2]|0;c[h+88>>2]=Q;c[n+2153792>>2]=Q;c[n+7348>>2]=(Q|0)==1;if((c[H>>2]&2|0)!=0){break}Q=~~+rUa(G,0);c[h+168>>2]=Q;if((Q|0)<0){y=-1}else{break}i=k;return y|0}}while(0);S=n+7508|0;do{if((c[S>>2]|0)!=0){if((c[E>>2]|0)!=0){break}c[h+168>>2]=236}}while(0);Q=h+168|0;A=c[Q>>2]|0;if((A|0)==0){T=c[n+7492>>2]|0}else{B=~~(+Gc(+(+gc(+(+(A|0)/118.0))*32.0))+244.0);c[n+7492>>2]=B;c[n+7500>>2]=((c[Q>>2]|0)*3|0|0)/2|0;T=B}B=n+7492|0;do{if((T|0)<0){U=26}else{if((c[Q>>2]|0)!=0){break}if((c[H>>2]&2|0)!=0){U=26}}}while(0);if((U|0)==26){c[B>>2]=-128;c[n+7500>>2]=0}Vob(o)|0;T=n+2540|0;A=f+804|0;c[A>>2]=c[T>>2];C=n+2151424|0;c[n+2153656>>2]=C;D=n+2151560|0;L=c[D+4>>2]|0;M=n+2144752|0;K=M;J=n+2144888|0;c[J>>2]=c[D>>2];c[J+4>>2]=L;L=h+136|0;J=c[L+4>>2]|0;c[D>>2]=c[L>>2];c[D+4>>2]=J;J=h+88|0;do{if((c[J>>2]|0)==2){D=s+15>>4;L=c[T>>2]|0;P=c[L+32>>2]|0;O=L|0;if((c[O>>2]|0)==0){yDb(0,0,2181632,(V=i,i=i+24|0,c[V>>2]=2104720,c[V+8>>2]=2048056,c[V+16>>2]=1621,V)|0);i=V;Cd();return 0}N=c[n+2544>>2]|0;if((c[N>>2]|0)==0){yDb(0,0,2181632,(V=i,i=i+24|0,c[V>>2]=2002560,c[V+8>>2]=2048056,c[V+16>>2]=1622,V)|0);i=V;Cd();return 0}else{W=c[q>>2]|0;c[n+2143804>>2]=W;c[C>>2]=c[O>>2];c[M>>2]=c[N>>2];c[n+2149200>>2]=c[c[n+2536>>2]>>2];c[n+2153648>>2]=K;c[n+2151456>>2]=P;c[n+2149232>>2]=P;c[n+2144784>>2]=P;c[n+2143948>>2]=P;c[n+2143952>>2]=c[L+36>>2];c[n+2143808>>2]=s;c[n+2143812>>2]=t;c[n+2143916>>2]=D;c[n+2143920>>2]=t+15>>4;c[n+2143924>>2]=D+1;c[n+2143928>>2]=D<<1|1;c[n+2155356>>2]=1;c[n+2153792>>2]=2;c[n+2155532>>2]=c[W+144>>2];c[n+2156240>>2]=0;D=W+88|0;c[n+2143860>>2]=c[D>>2];c[n+2157724>>2]=(c[D>>2]|0)>>>4&1;c[n+2143828>>2]=2;c[n+2153848>>2]=1;D=c[n+7500>>2]|0;c[n+2153768>>2]=D;c[n+2153760>>2]=((D*139|0)+8192|0)>>>14;W=((ba(D,D)|0)+64|0)>>>7;c[n+2153772>>2]=W;c[n+7504>>2]=W;W=n+2153856|0;D=n+548|0;UGb(W|0,D|0,1244)|0;L=n+2155132|0;P=n+1792|0;UGb(L|0,P|0,208)|0;lmb(G)|0;UGb(P|0,L|0,208)|0;UGb(D|0,W|0,1244)|0;break}}}while(0);if((c[S>>2]|0)==0){X=n+3092|0;Y=l|0;Z=n+3124|0;_=m|0}else{K=l|0;l=n+3092|0;UGb(K|0,l|0,32)|0;M=m|0;m=n+3124|0;UGb(M|0,m|0,4224)|0;X=l;Y=K;Z=m;_=M}M=n+7372|0;m=n+7484|0;K=n+7480|0;l=n+2153792|0;C=n+7520|0;W=n+7376|0;D=n+540|0;L=n+536|0;P=n+2157496|0;N=n+7348|0;O=n+544|0;aa=n+2157464|0;ca=n+7548|0;da=n+2143792|0;ea=n+7464|0;fa=n+7536|0;ga=n+2156240|0;ha=n+7456|0;ia=n+7460|0;ja=n+7360|0;ka=n+2153592|0;la=n+2153600|0;ma=n+7500|0;na=n+7468|0;oa=n+2139660|0;pa=n+2158472|0;qa=n+2143796|0;ra=n+7472|0;a:while(1){sa=c[K>>2]|0;ta=c[m>>2]|0;ua=5;while(1){if((s>>sa+ua|0)!=0){if((t>>ta+ua|0)!=0){break}}ua=ua-1|0}c[M>>2]=ua;if((ua|0)<1){U=42;break}ta=c[J>>2]|0;c[l>>2]=ta;c[C>>2]=(ta|0)==2?2:0;Tob(f)|0;ta=c[M>>2]|0;do{if((c[W>>2]|0)!=(ta|0)){sa=c[z>>2]|0;if((sa|0)>0){va=0;wa=ta;xa=sa}else{break}while(1){sa=c[ca+(va*533028|0)>>2]|0;I=c[ca+(va*533028|0)+4>>2]|0;if((wa|0)>0){ya=ba(sa<<1,I)|0;za=(I|0)<1|(sa|0)<1;Aa=0;do{Ba=(Aa|0)!=0|0;do{Ca=c[ca+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+24>>2]|0;TGb(c[ea>>2]|0,0,ya|0)|0;b[Ca+((ba(c[ca+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+4>>2]|0,(c[ca+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+12>>2]|0)/2|0)|0)+((c[ca+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+8>>2]|0)/2|0)<<1)>>1]=4096;xYa(c[ea>>2]|0,c[na>>2]|0,sa,I,sa,c[ja>>2]|0,c[M>>2]|0);if(za){Da=0.0}else{Ca=c[ea>>2]|0;Ea=0;Fa=0;Ga=0;while(1){Ha=ba(Ea,sa)|0;Ia=0;Ja=Fa;Ka=Ga;do{La=b[Ca+(Ia+Ha<<1)>>1]<<4;Ma=La;Na=(La|0)<0|0?-1:0;La=gHb(Ma,Na,Ma,Na)|0;Ka=YGb(La,F,Ka,Ja)|0;Ja=F;Ia=Ia+1|0;}while((Ia|0)<(sa|0));Ia=Ea+1|0;if((Ia|0)<(I|0)){Ea=Ia;Fa=Ja;Ga=Ka}else{break}}Da=+(Ka>>>0)+ +(Ja|0)*4294967296.0}c[ca+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+16>>2]=~~(+$(352256.0/+R(Da))/.02166084939249824+.5);Ba=Ba+1|0;}while((Ba|0)<4);Aa=Aa+1|0;Oa=c[M>>2]|0;}while((Aa|0)<(Oa|0));Pa=Oa;Qa=c[z>>2]|0}else{Pa=wa;Qa=xa}Aa=va+1|0;if((Aa|0)<(Qa|0)){va=Aa;wa=Pa;xa=Qa}else{break}}}}while(0);TYa(o);c[P>>2]=(c[D>>2]|0)-(c[L>>2]|0)<<3;ta=c[r>>2]|0;ua=c[u>>2]|0;do{if((c[(c[q>>2]|0)+144>>2]|0)==50){if((c[N>>2]|0)!=0){break}WYa(o)}}while(0);b:do{if((ua|0)>0){Aa=ta*768|0;I=(ta|0)>0;sa=0;while(1){if(((c[O>>2]|0)-(c[D>>2]|0)|0)<(Aa|0)){break}if(I){za=0;do{if((c[(c[q>>2]|0)+144>>2]|0)==50){XYa(o,0,za,sa)}else{YYa(o,0,za,sa)|0}za=za+1|0;}while((za|0)<(ta|0))}sa=sa+1|0;if((sa|0)>=(ua|0)){break b}}yDb(c[q>>2]|0,16,1913312,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}}while(0);c[aa>>2]=((c[D>>2]|0)-(c[L>>2]|0)<<3)-(c[P>>2]|0);if((c[z>>2]|0)>0){Ra=0}else{U=522;break}c:while(1){ua=c[ca+(Ra*533028|0)>>2]|0;ta=c[ca+(Ra*533028|0)+4>>2]|0;d:do{if((c[da>>2]|0)==0){sa=c[h+(Ra<<2)>>2]|0;if((sa|0)!=0&(ta|0)>0){I=(ua|0)>0;Aa=h+32+(Ra<<2)|0;za=0;do{if(I){ya=ba(za,ua)|0;Ba=c[Aa>>2]|0;Ga=c[ea>>2]|0;Fa=0;do{b[Ga+(Fa+ya<<1)>>1]=d[sa+((ba(Ba,za)|0)+Fa)|0]<<4;Fa=Fa+1|0;}while((Fa|0)<(ua|0))}za=za+1|0;}while((za|0)<(ta|0))}za=c[ea>>2]|0;sa=c[u>>2]|0;Aa=c[fa>>2]|0;I=sa<<Aa;e:do{if((I|0)>=0){Fa=(Ra|0)==0;Ba=o+7548+(Ra*533028|0)|0;ya=o+7548+(Ra*533028|0)+4|0;Ga=0;Ea=Aa;Ca=sa;while(1){Ia=c[r>>2]|0;Ha=Ia<<Ea;La=Ca<<Ea;Na=16>>>(Ea>>>0);if(Fa){Sa=Na<<1;Ta=Na;Ua=Na;Va=Ea}else{Ma=c[K>>2]|0;Sa=Na<<1>>Ma;Ta=Na>>c[m>>2];Ua=Na>>Ma;Va=Ma+Ea|0}Ma=c[1167680+(Va<<2)>>2]|0;Na=c[(c[T>>2]|0)+32+(Ra<<2)>>2]|0;Wa=c[Ba>>2]|0;Xa=c[ya>>2]|0;f:do{if((c[N>>2]|0)==0){if((c[(c[q>>2]|0)+688>>2]&512|0)!=0){U=88;break}if((Ha|0)<0){break}Ya=(Ua|0)/2|0;Za=(ba(Ta,Ga)|0)-((Ta|0)/2|0)|0;_a=Ga-1|0;$a=(Na|0)>111?16:Na<<4;ab=(_a|0)<0;bb=(Za|0)<0;cb=ba(Za,-Sa|0)|0;db=Za+Ta|0;eb=$a*3|0;fb=eb+$a|0;gb=Sa>>1;hb=fb+$a|0;ib=0;jb=Ia;kb=Ea;lb=Ca;while(1){mb=(ba(ib,Ua)|0)-Ya|0;nb=ib-1|0;ob=jb<<kb;pb=ba(ob,_a)|0;qb=pb+nb|0;rb=c[oa>>2]|0;sb=rb+(qb*10|0)|0;tb=rb+((pb+ib|0)*10|0)|0;pb=qb+ob|0;qb=rb+(pb*10|0)|0;ub=rb+((pb+1|0)*10|0)|0;pb=c[pa>>2]|0;if((nb|0)<0){vb=ub;wb=ub;xb=tb;yb=tb}else{nb=(ib|0)<(ob|0);vb=nb?ub:qb;wb=qb;xb=nb?tb:sb;yb=sb}if(ab){zb=vb;Ab=wb;Bb=vb;Cb=wb}else{sb=(lb<<kb|0)>(Ga|0);zb=sb?vb:xb;Ab=sb?wb:yb;Bb=xb;Cb=yb}if((mb|0)<0){Db=Ma+(-mb|0)|0;Eb=0;Fb=mb+Ua|0}else{Db=Ma;Eb=mb;Fb=Ua}mb=(Eb+Fb|0)>(Wa|0)?Wa-Eb|0:Fb;if(bb){Gb=Db+cb|0;Hb=0;Ib=db}else{Gb=Db;Hb=Za;Ib=Ta}sb=(Hb+Ib|0)>(Xa|0)?Xa-Hb|0:Ib;do{if(!((mb|0)<1|(sb|0)<1)){tb=pb+eb|0;nb=pb+fb|0;Iob(o,tb,pb,Na,Eb,Hb,mb,sb,Cb,Ra,Wa,Xa);qb=Cb+8|0;ub=a[qb]|0;ob=Bb+8|0;rb=a[ob]|0;do{if((ub&1)==0){U=107}else{if((rb&1)==0){U=107;break}Jb=(d[Cb+6|0]|0)-(d[Bb+6|0]|0)|(d[Cb+5|0]|0)-(d[Bb+5|0]|0)|(d[Cb+7|0]|0)-(d[Bb+7|0]|0)}}while(0);if((U|0)==107){U=0;Jb=(b[Cb>>1]|0)-(b[Bb>>1]|0)|(rb^ub)&1|(b[Cb+2>>1]|0)-(b[Bb+2>>1]|0)|(d[Cb+4|0]|0)-(d[Bb+4|0]|0)}if((Jb|0)==0){Kb=nb;Lb=tb;Mb=ub}else{Iob(o,nb,pb,Na,Eb,Hb,mb,sb,Bb,Ra,Wa,Xa);Kb=pb+hb|0;Lb=nb;Mb=a[qb]|0}Nb=Ab+8|0;Ob=a[Nb]|0;do{if((Mb&1)==0){U=113}else{if((Ob&1)==0){U=113;break}Pb=(d[Cb+6|0]|0)-(d[Ab+6|0]|0)|(d[Cb+5|0]|0)-(d[Ab+5|0]|0)|(d[Cb+7|0]|0)-(d[Ab+7|0]|0)}}while(0);if((U|0)==113){U=0;Pb=(b[Cb>>1]|0)-(b[Ab>>1]|0)|(Ob^Mb)&1|(b[Cb+2>>1]|0)-(b[Ab+2>>1]|0)|(d[Cb+4|0]|0)-(d[Ab+4|0]|0)}do{if((Pb|0)==0){Qb=Kb;Rb=tb;Sb=Mb}else{nb=a[ob]|0;do{if((nb&1)==0){U=118}else{if((Ob&1)==0){U=118;break}Tb=(d[Bb+6|0]|0)-(d[Ab+6|0]|0)|(d[Bb+5|0]|0)-(d[Ab+5|0]|0)|(d[Bb+7|0]|0)-(d[Ab+7|0]|0)}}while(0);if((U|0)==118){U=0;Tb=(b[Bb>>1]|0)-(b[Ab>>1]|0)|(nb^Ob)&1|(b[Bb+2>>1]|0)-(b[Ab+2>>1]|0)|(d[Bb+4|0]|0)-(d[Ab+4|0]|0)}if((Tb|0)==0){Qb=Kb;Rb=Lb;Sb=Mb;break}Iob(o,Kb,pb,Na,Eb,Hb,mb,sb,Ab,Ra,Wa,Xa);Qb=Kb+$a|0;Rb=Kb;Sb=a[qb]|0}}while(0);qb=a[zb+8|0]|0;do{if((Sb&1)==0){U=124}else{if((qb&1)==0){U=124;break}Ub=(d[Cb+6|0]|0)-(d[zb+6|0]|0)|(d[Cb+5|0]|0)-(d[zb+5|0]|0)|(d[Cb+7|0]|0)-(d[zb+7|0]|0)}}while(0);if((U|0)==124){U=0;Ub=(b[Cb>>1]|0)-(b[zb>>1]|0)|(qb^Sb)&1|(b[Cb+2>>1]|0)-(b[zb+2>>1]|0)|(d[Cb+4|0]|0)-(d[zb+4|0]|0)}do{if((Ub|0)==0){Vb=tb}else{Ob=a[ob]|0;do{if((Ob&1)==0){U=129}else{if((qb&1)==0){U=129;break}Wb=(d[Bb+6|0]|0)-(d[zb+6|0]|0)|(d[Bb+5|0]|0)-(d[zb+5|0]|0)|(d[Bb+7|0]|0)-(d[zb+7|0]|0)}}while(0);if((U|0)==129){U=0;Wb=(b[Bb>>1]|0)-(b[zb>>1]|0)|(Ob^qb)&1|(b[Bb+2>>1]|0)-(b[zb+2>>1]|0)|(d[Bb+4|0]|0)-(d[zb+4|0]|0)}if((Wb|0)==0){Vb=Lb;break}nb=a[Nb]|0;do{if((nb&1)==0){U=134}else{if((qb&1)==0){U=134;break}Xb=(d[Ab+6|0]|0)-(d[zb+6|0]|0)|(d[Ab+5|0]|0)-(d[zb+5|0]|0)|(d[Ab+7|0]|0)-(d[zb+7|0]|0)}}while(0);if((U|0)==134){U=0;Xb=(b[Ab>>1]|0)-(b[zb>>1]|0)|(nb^qb)&1|(b[Ab+2>>1]|0)-(b[zb+2>>1]|0)|(d[Ab+4|0]|0)-(d[zb+4|0]|0)}if((Xb|0)==0){Vb=Rb;break}Iob(o,Qb,pb,Na,Eb,Hb,mb,sb,zb,Ra,Wa,Xa);Vb=Qb}}while(0);if((sb|0)<=0){break}qb=(mb|0)>0;Nb=0;do{ob=ba(Nb,Sa)|0;tb=ob+gb|0;Ob=ba(Nb+gb|0,Sa)|0;ub=Ob+gb|0;if(qb){rb=ba(Nb,Na)|0;Yb=(ba(Nb+Hb|0,Wa)|0)+Eb|0;Zb=0;do{_b=Zb+rb|0;$b=ba(d[Vb+_b|0]|0,d[Gb+(Zb+ob)|0]|0)|0;ac=(ba(d[Rb+_b|0]|0,d[Gb+(tb+Zb)|0]|0)|0)+$b|0;$b=ac+(ba(d[Lb+_b|0]|0,d[Gb+(Zb+Ob)|0]|0)|0)|0;ac=($b+(ba(d[pb+(_b+eb)|0]|0,d[Gb+(ub+Zb)|0]|0)|0)|0)>>>4;_b=za+(Yb+Zb<<1)|0;b[_b>>1]=(e[_b>>1]|0)-ac;Zb=Zb+1|0;}while((Zb|0)<(mb|0))}Nb=Nb+1|0;}while((Nb|0)<(sb|0))}}while(0);sb=ib+1|0;if((sb|0)>(Ha|0)){break f}ib=sb;jb=c[r>>2]|0;kb=c[fa>>2]|0;lb=c[u>>2]|0}}else{U=88}}while(0);do{if((U|0)==88){U=0;if((La|0)==(Ga|0)){break}Ha=ba(Ta,Ga)|0;Na=ba(Ta,Ga+1|0)|0;Ma=(Xa|0)>(Na|0)?Na:Xa;if((Ha|0)>=(Ma|0)){break}Na=(Wa|0)>0;Ia=Ha;do{if(Na){Ha=ba(Ia,Wa)|0;lb=0;do{kb=za+(lb+Ha<<1)|0;b[kb>>1]=(b[kb>>1]|0)-2048;lb=lb+1|0;}while((lb|0)<(Wa|0))}Ia=Ia+1|0;}while((Ia|0)<(Ma|0))}}while(0);Wa=Ga+1|0;if((Wa|0)>(I|0)){break e}Ga=Wa;Ea=c[fa>>2]|0;Ca=c[u>>2]|0}}}while(0);I=(Ra|0)==0;do{if(I){if((c[J>>2]|0)!=2){break}if((c[H>>2]&1024|0)!=0){break}if((c[ga>>2]|0)>(c[(c[q>>2]|0)+308>>2]|0)){break c}}}while(0);za=(ta|0)>0;do{if((c[B>>2]|0)==-128){if(!za){break}sa=(ua|0)>0;Aa=0;do{if(sa){Ca=ba(Aa,ua)|0;Ea=c[ea>>2]|0;Ga=c[ha>>2]|0;ya=0;do{Ba=ya+Ca|0;c[Ga+(Ba<<2)>>2]=(b[Ea+(Ba<<1)>>1]|0)+7>>4;ya=ya+1|0;}while((ya|0)<(ua|0))}Aa=Aa+1|0;}while((Aa|0)<(ta|0))}else{if(!za){break}Aa=(ua|0)>0;sa=0;do{if(Aa){ya=ba(sa,ua)|0;Ea=c[ea>>2]|0;Ga=c[ha>>2]|0;Ca=0;do{Ba=Ca+ya|0;c[Ga+(Ba<<2)>>2]=b[Ea+(Ba<<1)>>1]<<4;Ca=Ca+1|0;}while((Ca|0)<(ua|0))}sa=sa+1|0;}while((sa|0)<(ta|0))}}while(0);sYa(c[ha>>2]|0,c[ia>>2]|0,ua,ta,ua,c[ja>>2]|0,c[M>>2]|0);g:do{if(!((c[S>>2]|0)==0|I^1)){if((c[M>>2]|0)>0){za=0;sa=0;while(1){Aa=o+7556+(za*66624|0)+8|0;Ca=o+7556+(za*66624|0)+12|0;Ea=(za|0)!=0|0;Ga=sa;while(1){ya=c[o+7556+(za*66624|0)+(Ea*16656|0)+24>>2]|0;Ba=c[o+7556+(za*66624|0)+(Ea*16656|0)+8>>2]|0;Fa=c[o+7556+(za*66624|0)+(Ea*16656|0)+12>>2]|0;Wa=c[o+7556+(za*66624|0)+(Ea*16656|0)+4>>2]|0;Xa=(c[o+7556+(za*66624|0)+(Ea*16656|0)+16>>2]|0)+64|0;if((Xa|0)<0){bc=0}else{bc=(Xa|0)>512?512:Xa}Xa=65536/(d[5728784+(bc&31)|0]<<(bc>>5)|0)|0;La=(Fa|0)>0;if(La){Ma=(Ba|0)>0;Ia=o+7556+(za*66624|0)+(Ea*16656|0)+20|0;Na=0;do{if(Ma){lb=ba(Na,Wa)|0;Ha=c[Ia>>2]|0;kb=0;do{jb=kb+lb|0;b[ya+(jb<<1)>>1]=c[Ha+(jb<<2)>>2];kb=kb+1|0;}while((kb|0)<(Ba|0))}Na=Na+1|0;}while((Na|0)<(Fa|0))}if((Ea|0)==0){UYa(c[Aa>>2]|0,c[Ca>>2]|0,ya,Wa)}if(La){Na=(Ba|0)>0;Ia=Ga;Ma=0;while(1){if(Na){kb=ba(Ma,Wa)|0;Ha=Ia;lb=0;while(1){jb=b[ya+(lb+kb<<1)>>1]|0;ib=jb<<16>>16;eb=((ba(jb<<16>>16>-1?ib:-ib|0,Xa)|0)>>16)+Ha|0;ib=lb+1|0;if((ib|0)<(Ba|0)){Ha=eb;lb=ib}else{cc=eb;break}}}else{cc=Ia}lb=Ma+1|0;if((lb|0)<(Fa|0)){Ia=cc;Ma=lb}else{dc=cc;break}}}else{dc=Ga}Ma=Ea+1|0;if((Ma|0)<4){Ea=Ma;Ga=dc}else{break}}Ga=za+1|0;if((Ga|0)<(c[M>>2]|0)){za=Ga;sa=dc}else{break}}if(dc>>>0<2147483647>>>0){ec=dc}else{U=187;break a}}else{ec=0}sa=ec;za=0;Ga=gHb(sa,za,sa,za)|0;za=F;sa=Ga>>>16|za<<16|0;Ga=(za>>>16|0<<16)&0;if((c[J>>2]|0)==1){c[ka>>2]=sa;c[ka+4>>2]=Ga;c[la>>2]=0;c[la+4>>2]=0}else{c[la>>2]=sa;c[la+4>>2]=Ga;c[ka>>2]=0;c[ka+4>>2]=0}Ga=~~+rUa(G,1);c[Q>>2]=Ga;if((Ga|0)<0){y=-1;U=531;break a}c[ma>>2]=(Ga*3|0|0)/2|0;Ga=~~(+Gc(+(+gc(+(+(c[Q>>2]|0)/118.0))*32.0))+244.0);sa=Ga-(c[B>>2]|0)|0;c[B>>2]=Ga;if((sa|0)==(-2147483648|0)){y=-1;U=531;break a}else if((sa|0)==0){break}eUa(p,c[w>>2]|0,c[v>>2]|0);UGb(X|0,Y|0,32)|0;UGb(Z|0,_|0,4224)|0;TYa(o);sa=c[r>>2]|0;Ga=c[u>>2]|0;if((Ga|0)<=0){break}za=sa*768|0;Ea=(sa|0)>0;Ca=0;while(1){if(((c[O>>2]|0)-(c[D>>2]|0)|0)<(za|0)){break}if(Ea){Aa=0;do{XYa(o,0,Aa,Ca);Aa=Aa+1|0;}while((Aa|0)<(sa|0))}Ca=Ca+1|0;if((Ca|0)>=(Ga|0)){break g}}yDb(c[q>>2]|0,16,1913312,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}}while(0);Ga=c[M>>2]|0;do{if((Ga|0)>0){Ca=0;do{sa=(Ca|0)!=0|0;while(1){Ea=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+24|0;za=c[Ea>>2]|0;Aa=c[ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+20>>2]|0;Ma=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+4|0;Ia=c[Ma>>2]|0;Fa=c[C>>2]|0;Ba=c[B>>2]|0;Xa=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+8|0;ya=c[Xa>>2]|0;Wa=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+12|0;Na=c[Wa>>2]|0;La=(c[ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+16>>2]|0)+Ba|0;if((La|0)<0){fc=0}else{fc=(La|0)>512?512:La}La=d[5728784+(fc&31)|0]<<(fc>>5)+4;h:do{if((Ba|0)==-128){if((Na|0)<=0){break}lb=(ya|0)>0;Ha=0;do{if(lb){kb=ba(Ha,Ia)|0;eb=0;do{ib=eb+kb|0;b[za+(ib<<1)>>1]=c[Aa+(ib<<2)>>2];eb=eb+1|0;}while((eb|0)<(ya|0))}Ha=Ha+1|0;}while((Ha|0)<(Na|0))}else{do{if((Fa|0)==0){Ha=(La*3|0)>>3;lb=(La-Ha>>11)-1|0;eb=lb<<1;if((Ha|0)==0){hc=lb;ic=eb;break}if((Na|0)<=0){break h}kb=(ya|0)>0;ib=0;while(1){if(kb){jb=ba(ib,Ia)|0;gb=0;do{$a=gb+jb|0;hb=c[Aa+($a<<2)>>2]|0;do{if((hb+lb|0)>>>0>eb>>>0){if((hb|0)>-1){b[za+($a<<1)>>1]=((hb<<11)+Ha|0)/(La|0)|0;break}else{b[za+($a<<1)>>1]=-(((hb*-2048|0)+Ha|0)/(La|0)|0);break}}else{b[za+($a<<1)>>1]=0}}while(0);gb=gb+1|0;}while((gb|0)<(ya|0))}ib=ib+1|0;if((ib|0)>=(Na|0)){break h}}}else{ib=(La>>11)-1|0;hc=ib;ic=ib<<1}}while(0);if((Na|0)<=0){break}ib=(ya|0)>0;Ha=0;do{if(ib){eb=ba(Ha,Ia)|0;lb=0;do{kb=lb+eb|0;gb=c[Aa+(kb<<2)>>2]|0;do{if((gb+hc|0)>>>0>ic>>>0){if((gb|0)>-1){b[za+(kb<<1)>>1]=(gb<<11|0)/(La|0)|0;break}else{b[za+(kb<<1)>>1]=-((-gb<<11|0)/(La|0)|0);break}}else{b[za+(kb<<1)>>1]=0}}while(0);lb=lb+1|0;}while((lb|0)<(ya|0))}Ha=Ha+1|0;}while((Ha|0)<(Na|0))}}while(0);La=(sa|0)==0;if(La){UYa(ya,Na,za,Ia)}i:do{if((c[qa>>2]|0)==0){Aa=c[Ea>>2]|0;Fa=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+44|0;Ba=c[Fa>>2]|0;if((Ba|0)==0){jc=0}else{jc=c[Ba+24>>2]|0}Ha=c[Ma>>2]|0;ib=c[Xa>>2]|0;lb=c[Wa>>2]|0;eb=c[ra>>2]|0;kb=(lb|0)>0;do{if(kb){gb=(ib|0)>0;jb=(jc|0)==0;$a=Ha<<1;hb=0;fb=0;Za=0;while(1){if(gb){db=ba(Za,Ha)|0;cb=(Za|0)==0;bb=Za>>1;ab=ba($a,bb)|0;_a=db-1|0;Ya=ba(Za-1|0,Ha)|0;sb=Ya-1|0;mb=hb;pb=fb;Nb=0;while(1){qb=b[Aa+(Nb+db<<1)>>1]|0;do{if(cb){kc=0;lc=0;mc=0}else{Zb=b[Aa+(Nb+Ya<<1)>>1]|0;if((Nb|0)==0){nc=0}else{nc=b[Aa+(sb+Nb<<1)>>1]|0}Yb=Nb+1|0;if((Yb|0)>=(ib|0)){kc=nc;lc=Zb;mc=0;break}kc=nc;lc=Zb;mc=b[Aa+(Yb+Ya<<1)>>1]|0}}while(0);if((Nb|0)==0){oc=0}else{oc=b[Aa+(_a+Nb<<1)>>1]|0}do{if(jb){pc=0}else{Yb=Nb>>1;if((Yb|0)>=(c[Ba+8>>2]|0)){pc=0;break}if((bb|0)>=(c[Ba+12>>2]|0)){pc=0;break}pc=b[jc+(Yb+ab<<1)>>1]|0}}while(0);do{if((lc|mc|kc|oc|pc|0)==0){if(qb<<16>>16==0){qc=pb+1|0;rc=mb;break}else{c[eb+(mb<<2)>>2]=pb;qc=0;rc=mb+1|0;break}}else{qc=pb;rc=mb}}while(0);qb=Nb+1|0;if((qb|0)<(ib|0)){mb=rc;pb=qc;Nb=qb}else{sc=rc;tc=qc;break}}}else{sc=hb;tc=fb}Nb=Za+1|0;if((Nb|0)<(lb|0)){hb=sc;fb=tc;Za=Nb}else{break}}c[eb+(sc<<2)>>2]=tc;Za=c[eb>>2]|0;fb=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+1012|0;if((sc|0)<1){uc=sc;vc=Za;wc=fb;U=265;break}else{xc=sc;yc=0;zc=1;Ac=fb}while(1){VYa(p,Ac,1);Bc=xc-zc|0;Cc=yc+1|0;Dc=(Cc|0)>0;fb=zc<<(Dc&1);Ec=yc+5+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+1008)|0;if((Bc|0)<(fb|0)){break}else{xc=Bc;yc=Cc;zc=fb;Ac=Ec}}VYa(p,Ec,0);if(Dc){Fc=Cc}else{Hc=sc;Ic=Za;break}while(1){fb=Fc-1|0;VYa(p,32-Fc+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+1008)|0,Bc>>>(fb>>>0)&1);if((fb|0)>0){Fc=fb}else{Hc=sc;Ic=Za;break}}}else{c[eb>>2]=0;uc=0;vc=0;wc=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+1012|0;U=265}}while(0);if((U|0)==265){U=0;VYa(p,wc,0);Hc=uc;Ic=vc}do{if((Hc|0)>0){Ba=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+87|0;if((Ic|0)<8){VYa(p,Ba,0);Jc=3;Kc=Ic}else{Za=Ic;fb=3;hb=8;jb=Ba;while(1){VYa(p,jb,1);Lc=Za-hb|0;Mc=fb+1|0;Nc=(Mc|0)>0;Ba=hb<<(Nc&1);Oc=fb+5+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+80)|0;if((Lc|0)<(Ba|0)){break}else{Za=Lc;fb=Mc;hb=Ba;jb=Oc}}VYa(p,Oc,0);if(Nc){Jc=Mc;Kc=Lc}else{break}}jb=Jc;while(1){hb=jb-1|0;VYa(p,32-jb+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+80)|0,Kc>>>(hb>>>0)&1);if((hb|0)>0){jb=hb}else{break}}}}while(0);if(!kb){Pc=Fa;break}jb=ib*40|0;hb=(ib|0)>0;fb=(jc|0)==0;Za=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+87|0;Ba=Ha<<1;$a=1;gb=Ic;Nb=0;while(1){if(((c[O>>2]|0)-(c[D>>2]|0)|0)<(jb|0)){break}if(hb){pb=ba(Nb,Ha)|0;mb=(Nb|0)==0;ab=Nb>>1;bb=ba(Ba,ab)|0;_a=pb-1|0;Ya=ba(Nb-1|0,Ha)|0;sb=Ya-1|0;cb=$a;db=gb;qb=0;while(1){Yb=b[Aa+(qb+pb<<1)>>1]|0;Zb=Yb<<16>>16;do{if(mb){Qc=0;Rc=0;Sc=0}else{ub=b[Aa+(qb+Ya<<1)>>1]|0;if((qb|0)==0){Tc=0}else{Tc=b[Aa+(sb+qb<<1)>>1]|0}Ob=qb+1|0;if((Ob|0)>=(ib|0)){Qc=0;Rc=ub;Sc=Tc;break}Qc=b[Aa+(Ob+Ya<<1)>>1]|0;Rc=ub;Sc=Tc}}while(0);if((qb|0)==0){Uc=0}else{Uc=b[Aa+(_a+qb<<1)>>1]|0}do{if(fb){Vc=0}else{ub=qb>>1;Ob=c[Fa>>2]|0;if((ub|0)>=(c[Ob+8>>2]|0)){Vc=0;break}if((ab|0)>=(c[Ob+12>>2]|0)){Vc=0;break}Vc=b[jc+(ub+bb<<1)>>1]|0}}while(0);do{if((Rc|Sc|Qc|Uc|Vc|0)==0){if((db|0)!=0){Wc=db-1|0;Xc=cb;break}ub=cb+1|0;Ob=c[eb+(cb<<2)>>2]|0;if((ub|0)>(Hc|0)){Wc=Ob;Xc=ub;break}if((Ob|0)<8){VYa(p,Za,0);Yc=3;Zc=Ob}else{tb=Ob;ob=3;rb=8;nb=Za;while(1){VYa(p,nb,1);_c=tb-rb|0;$c=ob+1|0;ad=($c|0)>0;ac=rb<<(ad&1);bd=ob+5+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+80)|0;if((_c|0)<(ac|0)){break}else{tb=_c;ob=$c;rb=ac;nb=bd}}VYa(p,bd,0);if(ad){Yc=$c;Zc=_c}else{Wc=Ob;Xc=ub;break}}nb=Yc;while(1){rb=nb-1|0;VYa(p,32-nb+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+80)|0,Zc>>>(rb>>>0)&1);if((rb|0)>0){nb=rb}else{Wc=Ob;Xc=ub;break}}}else{ub=(((Rc|0)>-1?Rc:-Rc|0)<<1)+((Sc|0)>-1?Sc:-Sc|0)+((Qc|0)>-1?Qc:-Qc|0)+(((Uc|0)>-1?Uc:-Uc|0)*3|0)+((Vc|0)>-1?Vc:-Vc|0)|0;Ob=ub>>>0>65535>>>0;nb=Ob?ub>>>16:ub;ub=Ob?16:0;if((nb&65280|0)==0){cd=ub;dd=nb}else{cd=ub|8;dd=nb>>>8}VYa(p,(d[1191992+dd|0]|0)+cd+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48)|0,Yb<<16>>16!=0|0);Wc=db;Xc=cb}}while(0);if(!(Yb<<16>>16==0)){nb=(Uc|0)>-1?Uc:-Uc|0;ub=((Rc|0)>-1?Rc:-Rc|0)<<1;Ob=ub+((Sc|0)>-1?Sc:-Sc|0)+((Qc|0)>-1?Qc:-Qc|0)+(nb*3|0)+((Vc|0)>-1?Vc:-Vc|0)|0;rb=Ob>>>0>65535>>>0;ob=rb?Ob>>>16:Ob;Ob=rb?16:0;if((ob&65280|0)==0){ed=Ob;fd=ob}else{ed=Ob|8;fd=ob>>>8}ob=(d[1191992+fd|0]|0)+ed|0;Ob=nb<<1;nb=Uc>>>31;rb=Rc>>>31;tb=ob+2|0;ac=(Yb<<16>>16>-1?Zb:-Zb|0)-1|0;_b=ob-4|0;$b=(_b|0)>-1?1<<_b:1;gd=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48+(tb<<5)+ob|0;if(($b|0)>(ac|0)){hd=ac;id=_b;jd=gd}else{ob=ac;ac=_b;_b=$b;$b=gd;while(1){VYa(p,$b,1);gd=ob-_b|0;kd=ac+1|0;ld=_b<<((kd|0)>0);md=ac+5+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48+(tb<<5))|0;if((gd|0)<(ld|0)){hd=gd;id=kd;jd=md;break}else{ob=gd;ac=kd;_b=ld;$b=md}}}VYa(p,jd,0);if((id|0)>0){$b=id;while(1){_b=$b-1|0;VYa(p,32-$b+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48+(tb<<5))|0,hd>>>(_b>>>0)&1);if((_b|0)>0){$b=_b}else{break}}}VYa(p,(a[1152320+(Ob&254|nb)|0]|0)+20+((a[1152320+(ub&254|rb)|0]|0)*3|0)+(ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48)|0,(Yb&65535)>>>15&65535)}$b=qb+1|0;if(($b|0)<(ib|0)){cb=Xc;db=Wc;qb=$b}else{nd=Xc;od=Wc;break}}}else{nd=$a;od=gb}qb=Nb+1|0;if((qb|0)<(lb|0)){$a=nd;gb=od;Nb=qb}else{Pc=Fa;break i}}yDb(c[q>>2]|0,16,1913312,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V;Pc=Fa}else{Pc=ca+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+44|0}}while(0);Ia=c[Pc>>2]|0;if((Ia|0)!=0){if((c[Ia+4>>2]|0)!=(c[Ma>>2]<<1|0)){U=318;break a}}if(La){Ia=c[Ea>>2]|0;za=c[Ma>>2]|0;Na=c[Xa>>2]|0;ya=c[Wa>>2]|0;if((ya|0)<=0){sa=sa+1|0;continue}Nb=(Na|0)>0;gb=0;do{if(Nb){$a=ba(gb,za)|0;lb=(gb|0)==0;ib=0;do{Za=ib+$a|0;do{if((ib|0)==0){if(lb){break}eb=Ia+(Za<<1)|0;b[eb>>1]=(b[eb>>1]|0)+(b[Ia+(Za-za<<1)>>1]|0)}else{eb=Za-1|0;fb=b[Ia+(eb<<1)>>1]|0;Aa=fb<<16>>16;if(lb){Ha=Ia+(Za<<1)|0;b[Ha>>1]=(b[Ha>>1]|0)+fb;break}Ha=b[Ia+(Za-za<<1)>>1]|0;Ba=Ha<<16>>16;hb=Ba+Aa-(b[Ia+(eb-za<<1)>>1]|0)|0;do{if(fb<<16>>16>Ha<<16>>16){if((hb|0)<=(Ba|0)){pd=Ba;break}pd=(hb|0)>(Aa|0)?Aa:hb}else{if((Ba|0)<=(hb|0)){pd=Ba;break}pd=(hb|0)>(Aa|0)?hb:Aa}}while(0);Aa=Ia+(Za<<1)|0;b[Aa>>1]=(e[Aa>>1]|0)+pd}}while(0);ib=ib+1|0;}while((ib|0)<(Na|0))}gb=gb+1|0;}while((gb|0)<(ya|0))}sa=sa+1|0;if((sa|0)>=4){break}}Ca=Ca+1|0;qd=c[M>>2]|0;}while((Ca|0)<(qd|0));if((qd|0)<=0){rd=qd;break}Ca=c[B>>2]|0;sa=0;while(1){ya=(sa|0)!=0|0;do{gb=c[ca+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+24>>2]|0;Na=c[ca+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+4>>2]|0;Ia=c[ca+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+8>>2]|0;za=c[ca+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+12>>2]|0;Nb=Ca+(c[ca+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+16>>2]|0)|0;if((Nb|0)<0){sd=0}else{sd=(Nb|0)>512?512:Nb}Nb=d[5728784+(sd&31)|0]<<(sd>>5);Wa=(ba(Nb,c[C>>2]|0)|0)>>3;if((Ca|0)!=-128&(za|0)>0){Xa=(Ia|0)>0;Ma=0;do{if(Xa){Ea=ba(Ma,Na)|0;La=0;do{ib=gb+(La+Ea<<1)|0;lb=b[ib>>1]|0;$a=lb<<16>>16;do{if(lb<<16>>16<0){b[ib>>1]=-((Wa-(ba($a,Nb)|0)|0)>>>11)}else{if(!(lb<<16>>16>0)){break}b[ib>>1]=((ba($a,Nb)|0)+Wa|0)>>>11}}while(0);La=La+1|0;}while((La|0)<(Ia|0))}Ma=Ma+1|0;}while((Ma|0)<(za|0))}ya=ya+1|0;}while((ya|0)<4);ya=sa+1|0;if((ya|0)<(qd|0)){sa=ya}else{rd=qd;break}}}else{rd=Ga}}while(0);xYa(c[ea>>2]|0,c[na>>2]|0,ua,ta,ua,c[ja>>2]|0,rd);if((c[B>>2]|0)==-128&(ta|0)>0){Ga=(ua|0)>0;sa=0;do{if(Ga){Ca=ba(sa,ua)|0;ya=c[ea>>2]|0;za=0;do{Ma=ya+(za+Ca<<1)|0;b[Ma>>1]=b[Ma>>1]<<4;za=za+1|0;}while((za|0)<(ua|0))}sa=sa+1|0;}while((sa|0)<(ta|0))}sa=c[ea>>2]|0;Ga=c[u>>2]|0;za=c[fa>>2]|0;Ca=Ga<<za;if((Ca|0)<0){break}ya=o+7548+(Ra*533028|0)|0;Ma=o+7548+(Ra*533028|0)+4|0;Ia=0;Wa=za;za=Ga;while(1){Ga=c[r>>2]|0;Nb=Ga<<Wa;gb=za<<Wa;Na=16>>>(Wa>>>0);if(I){td=Na<<1;ud=Na;vd=Na;wd=Wa}else{Xa=c[K>>2]|0;td=Na<<1>>Xa;ud=Na>>c[m>>2];vd=Na>>Xa;wd=Xa+Wa|0}Xa=c[1167680+(wd<<2)>>2]|0;Na=c[T>>2]|0;La=c[Na+32+(Ra<<2)>>2]|0;Ea=c[Na+(Ra<<2)>>2]|0;Na=c[ya>>2]|0;$a=c[Ma>>2]|0;j:do{if((c[N>>2]|0)==0){if((c[(c[q>>2]|0)+688>>2]&512|0)!=0){U=372;break}if((Nb|0)<0){break}ib=(vd|0)/2|0;lb=(ba(ud,Ia)|0)-((ud|0)/2|0)|0;Fa=Ia-1|0;Za=(La|0)>111?16:La<<4;Aa=(Fa|0)<0;hb=(lb|0)<0;Ba=ba(lb,-td|0)|0;Ha=lb+ud|0;fb=Za*3|0;Yb=fb+Za|0;rb=td>>1;ub=Yb+Za|0;nb=0;Ob=Ga;eb=Wa;jb=za;while(1){kb=(ba(nb,vd)|0)-ib|0;qb=nb-1|0;db=Ob<<eb;cb=ba(db,Fa)|0;bb=cb+qb|0;ab=c[oa>>2]|0;_a=ab+(bb*10|0)|0;Ya=ab+((cb+nb|0)*10|0)|0;cb=bb+db|0;bb=ab+(cb*10|0)|0;sb=ab+((cb+1|0)*10|0)|0;cb=c[pa>>2]|0;if((qb|0)<0){xd=sb;yd=sb;zd=Ya;Ad=Ya}else{qb=(nb|0)<(db|0);xd=qb?sb:bb;yd=bb;zd=qb?Ya:_a;Ad=_a}if(Aa){Bd=xd;Dd=yd;Ed=xd;Fd=yd}else{_a=(jb<<eb|0)>(Ia|0);Bd=_a?xd:zd;Dd=_a?yd:Ad;Ed=zd;Fd=Ad}if((kb|0)<0){Gd=Xa+(-kb|0)|0;Hd=0;Id=kb+vd|0}else{Gd=Xa;Hd=kb;Id=vd}kb=(Hd+Id|0)>(Na|0)?Na-Hd|0:Id;if(hb){Jd=Gd+Ba|0;Kd=0;Ld=Ha}else{Jd=Gd;Kd=lb;Ld=ud}_a=(Kd+Ld|0)>($a|0)?$a-Kd|0:Ld;do{if(!((kb|0)<1|(_a|0)<1)){Ya=(ba(Kd,La)|0)+Hd|0;qb=cb+fb|0;bb=cb+Yb|0;Iob(o,qb,cb,La,Hd,Kd,kb,_a,Fd,Ra,Na,$a);sb=Fd+8|0;db=a[sb]|0;ab=Ed+8|0;mb=a[ab]|0;do{if((db&1)==0){U=393}else{if((mb&1)==0){U=393;break}Md=(d[Fd+6|0]|0)-(d[Ed+6|0]|0)|(d[Fd+5|0]|0)-(d[Ed+5|0]|0)|(d[Fd+7|0]|0)-(d[Ed+7|0]|0)}}while(0);if((U|0)==393){U=0;Md=(b[Fd>>1]|0)-(b[Ed>>1]|0)|(mb^db)&1|(b[Fd+2>>1]|0)-(b[Ed+2>>1]|0)|(d[Fd+4|0]|0)-(d[Ed+4|0]|0)}if((Md|0)==0){Nd=bb;Od=qb;Pd=db}else{Iob(o,bb,cb,La,Hd,Kd,kb,_a,Ed,Ra,Na,$a);Nd=cb+ub|0;Od=bb;Pd=a[sb]|0}pb=Dd+8|0;$b=a[pb]|0;do{if((Pd&1)==0){U=399}else{if(($b&1)==0){U=399;break}Qd=(d[Fd+6|0]|0)-(d[Dd+6|0]|0)|(d[Fd+5|0]|0)-(d[Dd+5|0]|0)|(d[Fd+7|0]|0)-(d[Dd+7|0]|0)}}while(0);if((U|0)==399){U=0;Qd=(b[Fd>>1]|0)-(b[Dd>>1]|0)|($b^Pd)&1|(b[Fd+2>>1]|0)-(b[Dd+2>>1]|0)|(d[Fd+4|0]|0)-(d[Dd+4|0]|0)}do{if((Qd|0)==0){Rd=Nd;Sd=qb;Td=Pd}else{bb=a[ab]|0;do{if((bb&1)==0){U=404}else{if(($b&1)==0){U=404;break}Ud=(d[Ed+6|0]|0)-(d[Dd+6|0]|0)|(d[Ed+5|0]|0)-(d[Dd+5|0]|0)|(d[Ed+7|0]|0)-(d[Dd+7|0]|0)}}while(0);if((U|0)==404){U=0;Ud=(b[Ed>>1]|0)-(b[Dd>>1]|0)|(bb^$b)&1|(b[Ed+2>>1]|0)-(b[Dd+2>>1]|0)|(d[Ed+4|0]|0)-(d[Dd+4|0]|0)}if((Ud|0)==0){Rd=Nd;Sd=Od;Td=Pd;break}Iob(o,Nd,cb,La,Hd,Kd,kb,_a,Dd,Ra,Na,$a);Rd=Nd+Za|0;Sd=Nd;Td=a[sb]|0}}while(0);sb=a[Bd+8|0]|0;do{if((Td&1)==0){U=410}else{if((sb&1)==0){U=410;break}Vd=(d[Fd+6|0]|0)-(d[Bd+6|0]|0)|(d[Fd+5|0]|0)-(d[Bd+5|0]|0)|(d[Fd+7|0]|0)-(d[Bd+7|0]|0)}}while(0);if((U|0)==410){U=0;Vd=(b[Fd>>1]|0)-(b[Bd>>1]|0)|(sb^Td)&1|(b[Fd+2>>1]|0)-(b[Bd+2>>1]|0)|(d[Fd+4|0]|0)-(d[Bd+4|0]|0)}do{if((Vd|0)==0){Wd=qb}else{$b=a[ab]|0;do{if(($b&1)==0){U=415}else{if((sb&1)==0){U=415;break}Xd=(d[Ed+6|0]|0)-(d[Bd+6|0]|0)|(d[Ed+5|0]|0)-(d[Bd+5|0]|0)|(d[Ed+7|0]|0)-(d[Bd+7|0]|0)}}while(0);if((U|0)==415){U=0;Xd=(b[Ed>>1]|0)-(b[Bd>>1]|0)|($b^sb)&1|(b[Ed+2>>1]|0)-(b[Bd+2>>1]|0)|(d[Ed+4|0]|0)-(d[Bd+4|0]|0)}if((Xd|0)==0){Wd=Od;break}bb=a[pb]|0;do{if((bb&1)==0){U=420}else{if((sb&1)==0){U=420;break}Yd=(d[Dd+6|0]|0)-(d[Bd+6|0]|0)|(d[Dd+5|0]|0)-(d[Bd+5|0]|0)|(d[Dd+7|0]|0)-(d[Bd+7|0]|0)}}while(0);if((U|0)==420){U=0;Yd=(b[Dd>>1]|0)-(b[Bd>>1]|0)|(bb^sb)&1|(b[Dd+2>>1]|0)-(b[Bd+2>>1]|0)|(d[Dd+4|0]|0)-(d[Bd+4|0]|0)}if((Yd|0)==0){Wd=Sd;break}Iob(o,Rd,cb,La,Hd,Kd,kb,_a,Bd,Ra,Na,$a);Wd=Rd}}while(0);if((_a|0)<=0){break}sb=(kb|0)>0;pb=0;do{ab=ba(pb,td)|0;qb=ab+rb|0;$b=ba(pb+rb|0,td)|0;db=$b+rb|0;if(sb){mb=ba(pb,La)|0;tb=(ba(pb+Kd|0,Na)|0)+Hd|0;_b=0;do{ac=_b+mb|0;ob=ba(d[Wd+ac|0]|0,d[Jd+(_b+ab)|0]|0)|0;Zb=(ba(d[Sd+ac|0]|0,d[Jd+(qb+_b)|0]|0)|0)+ob|0;ob=Zb+(ba(d[Od+ac|0]|0,d[Jd+(_b+$b)|0]|0)|0)|0;Zb=(ob+(ba(d[cb+(ac+fb)|0]|0,d[Jd+(db+_b)|0]|0)|0)|0)>>>4;ob=(b[sa+(tb+_b<<1)>>1]|0)+8+Zb|0;Zb=ob>>4;if(Zb>>>0>255>>>0){Zd=(ob>>31^255)&255}else{Zd=Zb&255}a[Ea+(Ya+ac)|0]=Zd;_b=_b+1|0;}while((_b|0)<(kb|0))}pb=pb+1|0;}while((pb|0)<(_a|0))}}while(0);_a=nb+1|0;if((_a|0)>(Nb|0)){break j}nb=_a;Ob=c[r>>2]|0;eb=c[fa>>2]|0;jb=c[u>>2]|0}}else{U=372}}while(0);do{if((U|0)==372){U=0;if((gb|0)==(Ia|0)){break}Nb=ba(ud,Ia)|0;Xa=ba(ud,Ia+1|0)|0;Ga=($a|0)>(Xa|0)?Xa:$a;if((Nb|0)>=(Ga|0)){break}Xa=(Na|0)>0;jb=Nb;do{if(Xa){Nb=ba(jb,Na)|0;eb=ba(jb,La)|0;Ob=0;do{nb=(b[sa+(Ob+Nb<<1)>>1]|0)+2056|0;fb=nb>>4;if(fb>>>0>255>>>0){_d=(nb>>31^255)&255}else{_d=fb&255}a[Ea+(Ob+eb)|0]=_d;Ob=Ob+1|0;}while((Ob|0)<(Na|0))}jb=jb+1|0;}while((jb|0)<(Ga|0))}}while(0);Na=Ia+1|0;if((Na|0)>(Ca|0)){break d}Ia=Na;Wa=c[fa>>2]|0;za=c[u>>2]|0}}else{if((c[J>>2]|0)==1){if((ta|0)<=0){break}za=(ua|0)>0;Wa=h+32+(Ra<<2)|0;Ia=h+(Ra<<2)|0;Ca=0;while(1){if(za){sa=0;do{Ma=(ba(c[Wa>>2]|0,Ca)|0)+sa|0;ya=c[T>>2]|0;I=(ba(c[ya+32+(Ra<<2)>>2]|0,Ca)|0)+sa|0;a[(c[ya+(Ra<<2)>>2]|0)+I|0]=a[(c[Ia>>2]|0)+Ma|0]|0;sa=sa+1|0;}while((sa|0)<(ua|0))}Ca=Ca+1|0;if((Ca|0)>=(ta|0)){break d}}}TGb(c[ea>>2]|0,0,ba(ua<<1,ta)|0)|0;Ca=c[ea>>2]|0;Ia=c[u>>2]|0;Wa=c[fa>>2]|0;za=Ia<<Wa;if((za|0)<0){break}sa=(Ra|0)==0;Ma=o+7548+(Ra*533028|0)|0;I=o+7548+(Ra*533028|0)+4|0;ya=0;Na=Wa;Wa=Ia;while(1){Ia=c[r>>2]|0;Ea=Ia<<Na;La=Wa<<Na;$a=16>>>(Na>>>0);if(sa){$d=$a<<1;ae=$a;be=$a;ce=Na}else{gb=c[K>>2]|0;$d=$a<<1>>gb;ae=$a>>c[m>>2];be=$a>>gb;ce=gb+Na|0}gb=c[1167680+(ce<<2)>>2]|0;$a=c[T>>2]|0;Ga=c[$a+32+(Ra<<2)>>2]|0;jb=c[$a+(Ra<<2)>>2]|0;$a=c[Ma>>2]|0;Xa=c[I>>2]|0;k:do{if((c[N>>2]|0)==0){if((c[(c[q>>2]|0)+688>>2]&512|0)!=0){U=450;break}if((Ea|0)<0){break}Ob=(be|0)/2|0;eb=(ba(ae,ya)|0)-((ae|0)/2|0)|0;Nb=ya-1|0;fb=(Ga|0)>111?16:Ga<<4;nb=(Nb|0)<0;rb=(eb|0)<0;Za=ba(eb,-$d|0)|0;ub=eb+ae|0;Yb=fb*3|0;lb=Yb+fb|0;Ha=$d>>1;Ba=lb+fb|0;hb=0;Aa=Ia;Fa=Na;ib=Wa;while(1){_a=(ba(hb,be)|0)-Ob|0;kb=hb-1|0;cb=Aa<<Fa;pb=ba(cb,Nb)|0;Ya=pb+kb|0;sb=c[oa>>2]|0;_b=sb+(Ya*10|0)|0;tb=sb+((pb+hb|0)*10|0)|0;pb=Ya+cb|0;Ya=sb+(pb*10|0)|0;db=sb+((pb+1|0)*10|0)|0;pb=c[pa>>2]|0;if((kb|0)<0){de=db;ee=db;fe=tb;ge=tb}else{kb=(hb|0)<(cb|0);de=kb?db:Ya;ee=Ya;fe=kb?tb:_b;ge=_b}if(nb){he=de;ie=ee;je=de;ke=ee}else{_b=(ib<<Fa|0)>(ya|0);he=_b?de:fe;ie=_b?ee:ge;je=fe;ke=ge}if((_a|0)<0){le=gb+(-_a|0)|0;me=0;ne=_a+be|0}else{le=gb;me=_a;ne=be}_a=(me+ne|0)>($a|0)?$a-me|0:ne;if(rb){oe=le+Za|0;pe=0;qe=ub}else{oe=le;pe=eb;qe=ae}_b=(pe+qe|0)>(Xa|0)?Xa-pe|0:qe;do{if(!((_a|0)<1|(_b|0)<1)){tb=(ba(pe,Ga)|0)+me|0;kb=pb+Yb|0;Ya=pb+lb|0;Iob(o,kb,pb,Ga,me,pe,_a,_b,ke,Ra,$a,Xa);db=ke+8|0;cb=a[db]|0;sb=je+8|0;$b=a[sb]|0;do{if((cb&1)==0){U=471}else{if(($b&1)==0){U=471;break}re=(d[ke+6|0]|0)-(d[je+6|0]|0)|(d[ke+5|0]|0)-(d[je+5|0]|0)|(d[ke+7|0]|0)-(d[je+7|0]|0)}}while(0);if((U|0)==471){U=0;re=(b[ke>>1]|0)-(b[je>>1]|0)|($b^cb)&1|(b[ke+2>>1]|0)-(b[je+2>>1]|0)|(d[ke+4|0]|0)-(d[je+4|0]|0)}if((re|0)==0){se=Ya;te=kb;ue=cb}else{Iob(o,Ya,pb,Ga,me,pe,_a,_b,je,Ra,$a,Xa);se=pb+Ba|0;te=Ya;ue=a[db]|0}qb=ie+8|0;ab=a[qb]|0;do{if((ue&1)==0){U=477}else{if((ab&1)==0){U=477;break}ve=(d[ke+6|0]|0)-(d[ie+6|0]|0)|(d[ke+5|0]|0)-(d[ie+5|0]|0)|(d[ke+7|0]|0)-(d[ie+7|0]|0)}}while(0);if((U|0)==477){U=0;ve=(b[ke>>1]|0)-(b[ie>>1]|0)|(ab^ue)&1|(b[ke+2>>1]|0)-(b[ie+2>>1]|0)|(d[ke+4|0]|0)-(d[ie+4|0]|0)}do{if((ve|0)==0){we=se;xe=kb;ye=ue}else{Ya=a[sb]|0;do{if((Ya&1)==0){U=482}else{if((ab&1)==0){U=482;break}ze=(d[je+6|0]|0)-(d[ie+6|0]|0)|(d[je+5|0]|0)-(d[ie+5|0]|0)|(d[je+7|0]|0)-(d[ie+7|0]|0)}}while(0);if((U|0)==482){U=0;ze=(b[je>>1]|0)-(b[ie>>1]|0)|(Ya^ab)&1|(b[je+2>>1]|0)-(b[ie+2>>1]|0)|(d[je+4|0]|0)-(d[ie+4|0]|0)}if((ze|0)==0){we=se;xe=te;ye=ue;break}Iob(o,se,pb,Ga,me,pe,_a,_b,ie,Ra,$a,Xa);we=se+fb|0;xe=se;ye=a[db]|0}}while(0);db=a[he+8|0]|0;do{if((ye&1)==0){U=488}else{if((db&1)==0){U=488;break}Ae=(d[ke+6|0]|0)-(d[he+6|0]|0)|(d[ke+5|0]|0)-(d[he+5|0]|0)|(d[ke+7|0]|0)-(d[he+7|0]|0)}}while(0);if((U|0)==488){U=0;Ae=(b[ke>>1]|0)-(b[he>>1]|0)|(db^ye)&1|(b[ke+2>>1]|0)-(b[he+2>>1]|0)|(d[ke+4|0]|0)-(d[he+4|0]|0)}do{if((Ae|0)==0){Be=kb}else{ab=a[sb]|0;do{if((ab&1)==0){U=493}else{if((db&1)==0){U=493;break}Ce=(d[je+6|0]|0)-(d[he+6|0]|0)|(d[je+5|0]|0)-(d[he+5|0]|0)|(d[je+7|0]|0)-(d[he+7|0]|0)}}while(0);if((U|0)==493){U=0;Ce=(b[je>>1]|0)-(b[he>>1]|0)|(ab^db)&1|(b[je+2>>1]|0)-(b[he+2>>1]|0)|(d[je+4|0]|0)-(d[he+4|0]|0)}if((Ce|0)==0){Be=te;break}Ya=a[qb]|0;do{if((Ya&1)==0){U=498}else{if((db&1)==0){U=498;break}De=(d[ie+6|0]|0)-(d[he+6|0]|0)|(d[ie+5|0]|0)-(d[he+5|0]|0)|(d[ie+7|0]|0)-(d[he+7|0]|0)}}while(0);if((U|0)==498){U=0;De=(b[ie>>1]|0)-(b[he>>1]|0)|(Ya^db)&1|(b[ie+2>>1]|0)-(b[he+2>>1]|0)|(d[ie+4|0]|0)-(d[he+4|0]|0)}if((De|0)==0){Be=xe;break}Iob(o,we,pb,Ga,me,pe,_a,_b,he,Ra,$a,Xa);Be=we}}while(0);if((_b|0)<=0){break}db=(_a|0)>0;qb=0;do{sb=ba(qb,$d)|0;kb=sb+Ha|0;ab=ba(qb+Ha|0,$d)|0;cb=ab+Ha|0;if(db){$b=ba(qb,Ga)|0;mb=(ba(qb+pe|0,$a)|0)+me|0;bb=0;do{ac=bb+$b|0;Zb=ba(d[Be+ac|0]|0,d[oe+(bb+sb)|0]|0)|0;ob=(ba(d[xe+ac|0]|0,d[oe+(kb+bb)|0]|0)|0)+Zb|0;Zb=ob+(ba(d[te+ac|0]|0,d[oe+(bb+ab)|0]|0)|0)|0;ob=(Zb+(ba(d[pb+(ac+Yb)|0]|0,d[oe+(cb+bb)|0]|0)|0)|0)>>>4;Zb=(b[Ca+(mb+bb<<1)>>1]|0)+8+ob|0;ob=Zb>>4;if(ob>>>0>255>>>0){Ee=(Zb>>31^255)&255}else{Ee=ob&255}a[jb+(tb+ac)|0]=Ee;bb=bb+1|0;}while((bb|0)<(_a|0))}qb=qb+1|0;}while((qb|0)<(_b|0))}}while(0);_b=hb+1|0;if((_b|0)>(Ea|0)){break k}hb=_b;Aa=c[r>>2]|0;Fa=c[fa>>2]|0;ib=c[u>>2]|0}}else{U=450}}while(0);do{if((U|0)==450){U=0;if((La|0)==(ya|0)){break}Ea=ba(ae,ya)|0;gb=ba(ae,ya+1|0)|0;Ia=(Xa|0)>(gb|0)?gb:Xa;if((Ea|0)>=(Ia|0)){break}gb=($a|0)>0;ib=Ea;do{if(gb){Ea=ba(ib,$a)|0;Fa=ba(ib,Ga)|0;Aa=0;do{hb=(b[Ca+(Aa+Ea<<1)>>1]|0)+2056|0;Yb=hb>>4;if(Yb>>>0>255>>>0){Fe=(hb>>31^255)&255}else{Fe=Yb&255}a[jb+(Aa+Fa)|0]=Fe;Aa=Aa+1|0;}while((Aa|0)<($a|0))}ib=ib+1|0;}while((ib|0)<(Ia|0))}}while(0);$a=ya+1|0;if(($a|0)>(za|0)){break d}ya=$a;Na=c[fa>>2]|0;Wa=c[u>>2]|0}}}while(0);Wa=c[q>>2]|0;if((c[Wa+88>>2]&32768|0)!=0){Na=c[h+(Ra<<2)>>2]|0;if((Na|0)!=0&(ta|0)>0){ya=(ua|0)>0;za=h+32+(Ra<<2)|0;Ca=0;I=0;Ma=0;while(1){if(ya){sa=c[T>>2]|0;$a=ba(c[sa+32+(Ra<<2)>>2]|0,Ca)|0;jb=c[sa+(Ra<<2)>>2]|0;sa=ba(c[za>>2]|0,Ca)|0;Ga=0;Xa=I;La=Ma;while(1){Ia=(d[jb+($a+Ga)|0]|0)-(d[Na+(sa+Ga)|0]|0)|0;ib=YGb(ba(Ia,Ia)|0,0,La,Xa)|0;Ia=F;gb=Ga+1|0;if((gb|0)<(ua|0)){Ga=gb;Xa=Ia;La=ib}else{Ge=Ia;He=ib;break}}}else{Ge=I;He=Ma}La=Ca+1|0;if((La|0)<(ta|0)){Ca=La;I=Ge;Ma=He}else{Ie=Ge;Je=He;break}}}else{Ie=0;Je=0}Ma=Wa+720+(Ra<<3)|0;I=YGb(c[Ma>>2]|0,c[Ma+4>>2]|0,Je,Ie)|0;c[Ma>>2]=I;c[Ma+4>>2]=F;Ma=(c[T>>2]|0)+224+(Ra<<3)|0;c[Ma>>2]=Je;c[Ma+4>>2]=Ie}Ma=Ra+1|0;if((Ma|0)<(c[z>>2]|0)){Ra=Ma}else{U=522;break a}}eUa(p,c[w>>2]|0,c[v>>2]|0);gUa(p,214748364,248);c[J>>2]=1;c[N>>2]=1;c[(c[T>>2]|0)+84>>2]=1}if((U|0)==42){yDb(f,16,1965104,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V;y=-22;i=k;return y|0}else if((U|0)==187){yDb(0,0,2181632,(V=i,i=i+24|0,c[V>>2]=1892864,c[V+8>>2]=2048056,c[V+16>>2]=1505,V)|0);i=V;Cd();return 0}else if((U|0)==318){yDb(0,0,2181632,(V=i,i=i+24|0,c[V>>2]=1937032,c[V+8>>2]=2048056,c[V+16>>2]=1765,V)|0);i=V;Cd();return 0}else if((U|0)==522){if((c[N>>2]|0)==0){c[n+540572>>2]=c[n+540556>>2];c[n+540564>>2]=c[n+540548>>2];N=n+540552|0;V=n+540568|0;x=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[n+1073600>>2]=c[n+1073584>>2];c[n+1073592>>2]=c[n+1073576>>2];V=n+1073580|0;N=n+1073596|0;x=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x}c[n+7364>>2]=c[ja>>2];c[n+7496>>2]=c[B>>2];c[n+7524>>2]=c[C>>2];c[n+7516>>2]=c[n+7512>>2];c[n+7540>>2]=c[fa>>2];c[W>>2]=c[M>>2];Uob(f);M=c[T>>2]|0;c[M+160>>2]=c[E>>2];c[M+88>>2]=c[J>>2];c[M+168>>2]=c[Q>>2];M=(c[D>>2]|0)-(c[L>>2]|0)<<3;L=n+2157016|0;c[L>>2]=M;D=n+2157476|0;c[D>>2]=M-((c[aa>>2]|0)+(c[P>>2]|0));J=c[E>>2]|0;c[n+2151584>>2]=J;c[n+2151588>>2]=J;c[n+2151592>>2]=c[Q>>2];Q=n+2157008|0;J=YGb(M,(M|0)<0|0?-1:0,c[Q>>2]|0,c[Q+4>>2]|0)|0;c[Q>>2]=J;c[Q+4>>2]=F;do{if((c[S>>2]|0)!=0){if(+rUa(G,0)<0.0){y=-1}else{break}i=k;return y|0}}while(0);if((c[H>>2]&512|0)!=0){jUa(G)}c[n+2153800>>2]=c[l>>2];c[f+664>>2]=c[L>>2];c[f+632>>2]=c[aa>>2];c[f+660>>2]=c[P>>2];c[f+644>>2]=c[D>>2];c[v>>2]=hUa(p)|0;if((c[(c[A>>2]|0)+84>>2]|0)!=0){A=g+36|0;c[A>>2]=c[A>>2]|1}c[j>>2]=1;y=0;i=k;return y|0}else if((U|0)==531){i=k;return y|0}return 0}function SYa(a){a=a|0;var b=0;b=c[a+60>>2]|0;Wob(b);oUa(b+2143800|0);JCb(b+2536|0);ZDb(c[a+668>>2]|0);return 0}function TYa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;d=i;i=i+32|0;e=d|0;TGb(e|0,-128|0,32)|0;f=b+8|0;g=b+7348|0;VYa(f,e,c[g>>2]|0);if((c[g>>2]|0)==0){if((c[b+7352>>2]|0)==0){h=4}else{h=3}}else{h=3}do{if((h|0)==3){Gob(b);c[b+7540>>2]=0;c[b+7516>>2]=0;c[b+7524>>2]=0;c[b+7496>>2]=0;c[b+7364>>2]=0;c[b+540564>>2]=0;c[b+540572>>2]=0;e=b+540568|0;x=0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;c[b+1073592>>2]=0;c[b+1073600>>2]=0;e=b+1073596|0;x=0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;if((c[g>>2]|0)==0){h=4;break}e=b+3092|0;ZYa(f,e,c[b+7356>>2]|0,0);VYa(f,e,c[b+7352>>2]|0);ZYa(f,e,c[b+7368>>2]|0,0);ZYa(f,e,c[b+7380>>2]|0,0);j=b+7372|0;ZYa(f,e,c[j>>2]|0,0);ZYa(f,e,c[b+7476>>2]|0,0);k=b+7544|0;if((c[k>>2]|0)>2){ZYa(f,e,c[b+7480>>2]|0,0);ZYa(f,e,c[b+7484>>2]|0,0)}VYa(f,e,c[b+7488>>2]|0);ZYa(f,e,(c[b+7384>>2]|0)-1|0,0);l=c[k>>2]|0;if((l|0)>0){m=0;n=c[j>>2]|0;o=l;while(1){if((n|0)>0){p=0;do{q=(p|0)!=0|0;while(1){if((q|0)==2){q=3;continue}ZYa(f,e,c[b+7548+(m*533028|0)+8+(p*66624|0)+(q*16656|0)+16>>2]|0,1);q=q+1|0;if((q|0)>=4){break}}p=p+1|0;r=c[j>>2]|0;}while((p|0)<(r|0));s=r;t=c[k>>2]|0}else{s=n;t=o}p=m+1|0;if((p|0)<(((t|0)>2?2:t)|0)){m=p;n=s;o=t}else{u=t;break}}}else{u=l}if((c[g>>2]|0)==0){v=u;h=17}}}while(0);if((h|0)==4){v=c[b+7544>>2]|0;h=17}do{if((h|0)==17){u=b+7544|0;do{if((v|0)>0){g=(v|0)>2?2:v;t=0;s=0;do{r=(c[b+7548+(s*533028|0)+533016>>2]|0)!=(c[b+7548+(s*533028|0)+533e3>>2]|0)|t|(c[b+7548+(s*533028|0)+533024>>2]|0)!=(c[b+7548+(s*533028|0)+533008>>2]|0);t=r|(PGb(b+7548+(s*533028|0)+533020|0,b+7548+(s*533028|0)+533004|0,4)|0)!=0;s=s+1|0;}while((s|0)<(g|0));g=b+3092|0;VYa(f,g,t);if((t|0)==0){w=g;break}if((c[u>>2]|0)>0){y=0}else{w=g;break}while(1){VYa(f,g,c[b+7548+(y*533028|0)+533008>>2]|0);s=b+7548+(y*533028|0)+533e3|0;ZYa(f,g,((c[s>>2]|0)/2|0)-1|0,0);r=c[s>>2]|0;if(!((r+1|0)>>>0<3>>>0)){s=(r|0)/2|0;do{r=a[b+7548+(y*533028|0)+533004+s|0]|0;o=r<<24>>24;ZYa(f,g,r<<24>>24>-1?o:-o|0,0);s=s-1|0;}while((s|0)!=0)}s=y+1|0;o=c[u>>2]|0;if((s|0)<(((o|0)>2?2:o)|0)){y=s}else{w=g;break}}}else{g=b+3092|0;VYa(f,g,0);w=g}}while(0);l=b+7372|0;if((c[b+7376>>2]|0)==(c[l>>2]|0)){VYa(f,w,0);break}VYa(f,w,1);ZYa(f,w,c[l>>2]|0,0);g=c[u>>2]|0;if((g|0)<=0){break}t=0;s=c[l>>2]|0;o=g;while(1){if((s|0)>0){g=0;do{r=(g|0)!=0|0;while(1){if((r|0)==2){r=3;continue}ZYa(f,w,c[b+7548+(t*533028|0)+8+(g*66624|0)+(r*16656|0)+16>>2]|0,1);r=r+1|0;if((r|0)>=4){break}}g=g+1|0;z=c[l>>2]|0;}while((g|0)<(z|0));A=z;B=c[u>>2]|0}else{A=s;B=o}g=t+1|0;if((g|0)<(((B|0)>2?2:B)|0)){t=g;s=A;o=B}else{break}}}}while(0);B=b+3092|0;ZYa(f,B,(c[b+7360>>2]|0)-(c[b+7364>>2]|0)|0,1);ZYa(f,B,(c[b+7492>>2]|0)-(c[b+7496>>2]|0)|0,1);ZYa(f,B,(c[b+7512>>2]|0)-(c[b+7516>>2]|0)|0,1);ZYa(f,B,(c[b+7520>>2]|0)-(c[b+7524>>2]|0)|0,1);ZYa(f,B,(c[b+7536>>2]|0)-(c[b+7540>>2]|0)|0,1);i=d;return}function UYa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c|0)<=0){return}g=(a|0)>0;h=c;a:while(1){c=h-1|0;b:do{if(g){i=ba(c,f)|0;j=(c|0)==0;k=a;while(1){k=k-1|0;l=k+i|0;if((k|0)==0){break}m=l-1|0;n=b[d+(m<<1)>>1]|0;o=n<<16>>16;if(j){p=d+(l<<1)|0;b[p>>1]=(b[p>>1]|0)-n}else{p=b[d+(l-f<<1)>>1]|0;q=p<<16>>16;r=q+o-(b[d+(m-f<<1)>>1]|0)|0;do{if(n<<16>>16>p<<16>>16){if((r|0)<=(q|0)){s=q;break}s=(r|0)>(o|0)?o:r}else{if((q|0)<=(r|0)){s=q;break}s=(r|0)>(o|0)?r:o}}while(0);o=d+(l<<1)|0;b[o>>1]=(e[o>>1]|0)-s}if((k|0)<=0){break b}}if(j){t=18;break a}k=d+(l<<1)|0;b[k>>1]=(b[k>>1]|0)-(b[d+(l-f<<1)>>1]|0)}}while(0);if((c|0)>0){h=c}else{t=18;break}}if((t|0)==18){return}}function VYa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b+4|0;h=c[g>>2]|0;i=(ba(d[e]|0,h)|0)>>8;j=h-i|0;if((f|0)==0){c[g>>2]=j;k=(d[e]|0)+(b+16)|0}else{f=b|0;c[f>>2]=(c[f>>2]|0)+j;c[g>>2]=i;k=(d[e]|0)+(b+272)|0}a[e]=a[k]|0;if((c[g>>2]|0)>=256){return}k=b+12|0;e=b|0;i=b+532|0;j=b+8|0;b=c[k>>2]|0;f=c[e>>2]|0;while(1){do{if((b|0)<0){h=f>>8;c[k>>2]=h;l=h;m=f}else{if((f|0)<65281){h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=-1;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>8;c[k>>2]=n;l=n;m=h;break}if((f|0)<=65535){c[j>>2]=(c[j>>2]|0)+1;l=b;m=f;break}h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b+1;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=0;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>>8&255;c[k>>2]=n;l=n;m=h}}while(0);h=m<<8&65280;c[e>>2]=h;n=c[g>>2]<<8;c[g>>2]=n;if((n|0)<256){b=l;f=h}else{break}}return}function WYa(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0;g=i;i=i+6200|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;y=g+240|0;z=g+256|0;A=g+272|0;B=g+288|0;C=g+304|0;D=g+320|0;E=g+336|0;F=g+352|0;G=g+368|0;H=g+5152|0;I=g+5160|0;J=g+6184|0;K=g+928|0;L=f+7528|0;M=c[L>>2]|0;N=f+7536|0;O=c[N>>2]|0;P=M<<O;Q=f+7532|0;R=c[Q>>2]|0;S=R<<O;O=g+384|0;T=f+8|0;UGb(O|0,T|0,540)|0;U=f+3124|0;UGb(K|0,U|0,4224)|0;if((R|0)>0){V=0;W=M;M=R;while(1){if((W|0)>0){R=0;do{YYa(f,0,R,V)|0;R=R+1|0;X=c[L>>2]|0;}while((R|0)<(X|0));Y=X;Z=c[Q>>2]|0}else{Y=W;Z=M}R=V+1|0;if((R|0)<(Z|0)){V=R;W=Y;M=Z}else{break}}}UGb(T|0,O|0,540)|0;UGb(U|0,K|0,4224)|0;K=(S|0)>0;U=f+4|0;O=(P|0)>0;T=f+2139660|0;Z=f+2143760|0;M=f+2139664|0;Y=P-1|0;W=S-1|0;V=f+2536|0;X=f+2540|0;R=f+7548|0;_=f+7552|0;$=f+7544|0;aa=E;E=f+2153752|0;ca=f+2158472|0;da=f+2158476|0;ea=f+7500|0;fa=f+7504|0;ga=f+960|0;ha=f+2143800|0;ia=D;D=H|0;H=f+7388|0;ja=G|0;ka=q;q=G+4|0;la=G+8|0;ma=C;C=B;B=f+2139664|0;na=w;w=v;v=u;u=t;t=s;s=r;r=y;y=z;z=A;A=F;F=f+7480|0;oa=f+7484|0;pa=I|0;qa=P+1|0;ra=1-P|0;sa=~P;ta=0;while(1){if((ta|0)>=25){break}if(K){ua=(ta|0)==0;va=(ta|0)>0;wa=0;xa=0;while(1){a:do{if(O){ya=ba(xa,P)|0;za=(xa|0)!=0;Aa=xa+1|0;Ba=(Aa|0)<(S|0);Ca=za^1;Da=Ba^1;Ea=(xa|0)==0;Fa=(xa|0)==(W|0);Ga=wa;Ha=0;while(1){Ia=Ha;while(1){Ja=Ia+ya|0;Ka=c[T>>2]|0;La=Ka+(Ja*10|0)|0;if(za){Ma=Ka+((Ja-P|0)*10|0)|0}else{Ma=0}Na=(Ia|0)!=0;if(Na){Oa=Ka+((Ja-1|0)*10|0)|0}else{Oa=0}Pa=Ia+1|0;Qa=(Pa|0)<(P|0);if(Qa){Ra=Ka+((Ja+1|0)*10|0)|0}else{Ra=0}if(Ba){Sa=Ka+((Ja+P|0)*10|0)|0}else{Sa=0}Ta=Na^1;if(Ta|Ca){Ua=0}else{Ua=Ka+((Ja+sa|0)*10|0)|0}Na=Qa^1;if(Na|Ca){Va=0}else{Va=Ka+((ra+Ja|0)*10|0)|0}if(Ta|Da){Wa=0}else{Wa=Ka+((Y+Ja|0)*10|0)|0}if(Na|Da){Xa=0}else{Xa=Ka+((qa+Ja|0)*10|0)|0}Na=16>>>((c[N>>2]|0)>>>0);Ta=a[Ka+(Ja*10|0)+8|0]|0;if(ua){Ya=33}else{if((Ta&2)==0){Ya=33}}if((Ya|0)==33){Ya=0;Za=Ka+(Ja*10|0)+8|0;a[Za]=Ta|2;_a=La|0;$a=b[_a>>1]|0;ab=Ka+(Ja*10|0)+2|0;bb=b[ab>>1]|0;cb=Ka+(Ja*10|0)+4|0;db=a[cb]|0;eb=Ka+(Ja*10|0)+5|0;fb=a[eb]|0;gb=Ka+(Ja*10|0)+6|0;hb=a[gb]|0;ib=Ka+(Ja*10|0)+7|0;Ka=a[ib]|0;jb=c[Z>>2]|0;if((jb|0)==0){TGb(M|0,0,4096)|0}c[Z>>2]=jb+4194304;jb=Na<<1;kb=(jb|0)>0;if(kb){lb=c[1167680+(c[N>>2]<<2)>>2]|0;mb=0;do{UGb(I+(mb<<5)|0,lb+(ba(jb,mb)|0)|0,jb)|0;mb=mb+1|0;}while((mb|0)<(jb|0))}mb=(Ia|0)==0;if(mb&kb){lb=Na-1|0;nb=0;do{ob=I+(nb<<5)|0;TGb(ob|0,(a[I+(nb<<5)+lb|0]|0)+(a[ob]|0)&255|0,Na|0)|0;nb=nb+1|0;}while((nb|0)<(jb|0))}nb=(Ia|0)==(Y|0);if(nb&kb){lb=jb-1|0;ob=0;do{pb=I+(ob<<5)+Na|0;TGb(pb|0,(a[I+(ob<<5)+lb|0]|0)+(a[pb]|0)&255|0,Na|0)|0;ob=ob+1|0;}while((ob|0)<(jb|0))}do{if(Ea){if(kb){ob=Na-1|0;lb=0;do{pb=I+lb|0;a[pb]=(a[pb]|0)+(a[I+(ob<<5)+lb|0]|0);lb=lb+1|0;}while((lb|0)<(jb|0))}if((Na|0)>1){qb=1}else{break}do{UGb(I+(qb<<5)|0,pa|0,jb)|0;qb=qb+1|0;}while((qb|0)<(Na|0))}}while(0);do{if(Fa){lb=jb-1|0;if(kb){ob=0;do{pb=I+(lb<<5)+ob|0;a[pb]=(a[pb]|0)+(a[I+(Na<<5)+ob|0]|0);ob=ob+1|0;}while((ob|0)<(jb|0))}if((Na|0)>=(lb|0)){break}ob=I+(lb<<5)|0;pb=Na;do{UGb(I+(pb<<5)|0,ob|0,jb)|0;pb=pb+1|0;}while((pb|0)<(lb|0))}}while(0);do{if(mb|Ea|nb|Fa){jb=c[c[V>>2]>>2]|0;Na=c[X>>2]|0;kb=c[Na>>2]|0;lb=c[Na+32>>2]|0;Na=16>>>((c[N>>2]|0)>>>0);pb=(Na|0)/2|0;ob=(ba(Na,Ia)|0)-pb|0;rb=(ba(Na,xa)|0)-pb|0;pb=c[R>>2]|0;sb=c[_>>2]|0;tb=Na<<1;if((rb|0)<0){Na=rb;do{ub=(ba(Na,lb)|0)+ob|0;UGb(kb+ub|0,jb+ub|0,tb)|0;Na=Na+1|0;}while((Na|0)<0)}Na=rb+tb|0;if((sb|0)<(Na|0)){ub=sb;do{vb=(ba(ub,lb)|0)+ob|0;UGb(kb+vb|0,jb+vb|0,tb)|0;ub=ub+1|0;}while((ub|0)<(Na|0))}if((ob|0)<0&(tb|0)>0){ub=-ob|0;sb=rb;do{vb=(ba(sb,lb)|0)+ob|0;UGb(kb+vb|0,jb+vb|0,ub)|0;sb=sb+1|0;}while((sb|0)<(Na|0))}sb=ob+tb|0;if(!((sb|0)>(pb|0)&(tb|0)>0)){break}ub=sb-pb|0;sb=rb;do{vb=(ba(sb,lb)|0)+pb|0;UGb(kb+vb|0,jb+vb|0,ub)|0;sb=sb+1|0;}while((sb|0)<(Na|0))}}while(0);if((c[$>>2]|0)>0){nb=0;do{Na=c[N>>2]|0;sb=16>>>(Na>>>0);if((nb|0)==0){wb=sb<<1;xb=sb;yb=sb;zb=Na}else{ub=c[F>>2]|0;wb=sb<<1>>ub;xb=sb>>c[oa>>2];yb=sb>>ub;zb=ub+Na|0}ub=c[1167680+(zb<<2)>>2]|0;jb=c[(c[X>>2]|0)+32+(nb<<2)>>2]|0;kb=c[(c[V>>2]|0)+(nb<<2)>>2]|0;pb=c[E>>2]|0;lb=ba(ba(nb<<2,sb)|0,sb)|0;sb=c[f+7548+(nb*533028|0)>>2]|0;rb=c[f+7548+(nb*533028|0)+4>>2]|0;tb=(ba(c[L>>2]<<Na,xa)|0)+Ia|0;Na=c[T>>2]|0;ob=Na+(tb*10|0)|0;b[A>>1]=b[ob>>1]|0;b[A+2>>1]=b[ob+2>>1]|0;b[A+4>>1]=b[ob+4>>1]|0;b[A+6>>1]=b[ob+6>>1]|0;b[A+8>>1]=b[ob+8>>1]|0;vb=Na+(tb*10|0)+8|0;a[vb]=a[vb]|1;a[Na+(tb*10|0)+5+nb|0]=0;TGb(pb+(lb<<1)|0,0,ba(wb<<1,wb)|0)|0;tb=(yb|0)/2|0;Na=(xb|0)/2|0;vb=ba(wb,xb)|0;Ab=(jb|0)>111?16:jb<<4;Bb=-wb|0;Cb=tb-(ba(yb,Ia)|0)|0;Db=Na-(ba(xb,xa)|0)|0;Eb=Ab*3|0;Fb=Eb+Ab|0;Gb=wb>>1;Hb=Fb+Ab|0;Ib=0;Jb=0;Kb=0;while(1){Lb=Kb&1;Mb=Lb+Ia|0;Nb=Mb-1|0;Ob=Kb>>1;Pb=Ob+xa|0;Qb=Pb-1|0;Rb=(ba(Nb,yb)|0)+tb|0;Sb=(ba(Qb,xb)|0)+Na|0;Tb=(yb&-Lb)+lb+(ba(Ob,vb)|0)|0;Ob=c[N>>2]|0;Lb=c[L>>2]<<Ob;Ub=ba(Lb,Qb)|0;Vb=Ub+Nb|0;Wb=c[T>>2]|0;Xb=Wb+(Vb*10|0)|0;Yb=Wb+((Ub+Mb|0)*10|0)|0;Ub=Vb+Lb|0;Vb=Wb+(Ub*10|0)|0;Zb=Wb+((Ub+1|0)*10|0)|0;Ub=c[ca>>2]|0;if((Nb|0)<0){_b=Zb;$b=Zb;ac=Yb;bc=Yb}else{Nb=(Mb|0)<(Lb|0);_b=Nb?Zb:Vb;$b=Vb;ac=Nb?Yb:Xb;bc=Xb}if((Qb|0)<0){cc=_b;dc=$b;ec=_b;fc=$b}else{Qb=(Pb|0)<(c[Q>>2]<<Ob|0);cc=Qb?_b:ac;dc=Qb?$b:bc;ec=ac;fc=bc}Qb=(Rb|0)<0;if(Qb){gc=Tb-Rb|0;hc=ub+(-Rb|0)|0;ic=0;jc=Rb+yb|0}else{gc=Tb;hc=ub;ic=Rb;jc=yb}Tb=(ic+jc|0)>(sb|0)?sb-ic|0:jc;Ob=(Sb|0)<0;if(Ob){Pb=ba(Sb,Bb)|0;kc=gc+Pb|0;lc=hc+Pb|0;mc=0;nc=Sb+xb|0}else{kc=gc;lc=hc;mc=Sb;nc=xb}Pb=(mc+nc|0)>(rb|0)?rb-mc|0:nc;do{if(!((Tb|0)<1|(Pb|0)<1)){Xb=Ub+Eb|0;Yb=Ub+Fb|0;Iob(f,Xb,Ub,jb,ic,mc,Tb,Pb,fc,nb,sb,rb);Nb=fc+8|0;Vb=a[Nb]|0;Zb=ec+8|0;Lb=a[Zb]|0;do{if((Vb&1)==0){Ya=84}else{if((Lb&1)==0){Ya=84;break}oc=(d[fc+6|0]|0)-(d[ec+6|0]|0)|(d[fc+5|0]|0)-(d[ec+5|0]|0)|(d[fc+7|0]|0)-(d[ec+7|0]|0)}}while(0);if((Ya|0)==84){Ya=0;oc=(b[fc>>1]|0)-(b[ec>>1]|0)|(Lb^Vb)&1|(b[fc+2>>1]|0)-(b[ec+2>>1]|0)|(d[fc+4|0]|0)-(d[ec+4|0]|0)}if((oc|0)==0){pc=Yb;qc=Xb;rc=Vb}else{Iob(f,Yb,Ub,jb,ic,mc,Tb,Pb,ec,nb,sb,rb);pc=Ub+Hb|0;qc=Yb;rc=a[Nb]|0}Mb=dc+8|0;Wb=a[Mb]|0;do{if((rc&1)==0){Ya=90}else{if((Wb&1)==0){Ya=90;break}sc=(d[fc+6|0]|0)-(d[dc+6|0]|0)|(d[fc+5|0]|0)-(d[dc+5|0]|0)|(d[fc+7|0]|0)-(d[dc+7|0]|0)}}while(0);if((Ya|0)==90){Ya=0;sc=(b[fc>>1]|0)-(b[dc>>1]|0)|(Wb^rc)&1|(b[fc+2>>1]|0)-(b[dc+2>>1]|0)|(d[fc+4|0]|0)-(d[dc+4|0]|0)}do{if((sc|0)==0){tc=pc;uc=Xb;vc=rc}else{Yb=a[Zb]|0;do{if((Yb&1)==0){Ya=95}else{if((Wb&1)==0){Ya=95;break}wc=(d[ec+6|0]|0)-(d[dc+6|0]|0)|(d[ec+5|0]|0)-(d[dc+5|0]|0)|(d[ec+7|0]|0)-(d[dc+7|0]|0)}}while(0);if((Ya|0)==95){Ya=0;wc=(b[ec>>1]|0)-(b[dc>>1]|0)|(Yb^Wb)&1|(b[ec+2>>1]|0)-(b[dc+2>>1]|0)|(d[ec+4|0]|0)-(d[dc+4|0]|0)}if((wc|0)==0){tc=pc;uc=qc;vc=rc;break}Iob(f,pc,Ub,jb,ic,mc,Tb,Pb,dc,nb,sb,rb);tc=pc+Ab|0;uc=pc;vc=a[Nb]|0}}while(0);Nb=a[cc+8|0]|0;do{if((vc&1)==0){Ya=101}else{if((Nb&1)==0){Ya=101;break}xc=(d[fc+6|0]|0)-(d[cc+6|0]|0)|(d[fc+5|0]|0)-(d[cc+5|0]|0)|(d[fc+7|0]|0)-(d[cc+7|0]|0)}}while(0);if((Ya|0)==101){Ya=0;xc=(b[fc>>1]|0)-(b[cc>>1]|0)|(Nb^vc)&1|(b[fc+2>>1]|0)-(b[cc+2>>1]|0)|(d[fc+4|0]|0)-(d[cc+4|0]|0)}do{if((xc|0)==0){yc=Xb}else{Wb=a[Zb]|0;do{if((Wb&1)==0){Ya=106}else{if((Nb&1)==0){Ya=106;break}zc=(d[ec+6|0]|0)-(d[cc+6|0]|0)|(d[ec+5|0]|0)-(d[cc+5|0]|0)|(d[ec+7|0]|0)-(d[cc+7|0]|0)}}while(0);if((Ya|0)==106){Ya=0;zc=(b[ec>>1]|0)-(b[cc>>1]|0)|(Wb^Nb)&1|(b[ec+2>>1]|0)-(b[cc+2>>1]|0)|(d[ec+4|0]|0)-(d[cc+4|0]|0)}if((zc|0)==0){yc=qc;break}Yb=a[Mb]|0;do{if((Yb&1)==0){Ya=111}else{if((Nb&1)==0){Ya=111;break}Ac=(d[dc+6|0]|0)-(d[cc+6|0]|0)|(d[dc+5|0]|0)-(d[cc+5|0]|0)|(d[dc+7|0]|0)-(d[cc+7|0]|0)}}while(0);if((Ya|0)==111){Ya=0;Ac=(b[dc>>1]|0)-(b[cc>>1]|0)|(Yb^Nb)&1|(b[dc+2>>1]|0)-(b[cc+2>>1]|0)|(d[dc+4|0]|0)-(d[cc+4|0]|0)}if((Ac|0)==0){yc=uc;break}Iob(f,tc,Ub,jb,ic,mc,Tb,Pb,cc,nb,sb,rb);yc=tc}}while(0);if((Pb|0)>0&(Tb|0)>0){Bc=0}else{break}do{Nb=ba(Bc,wb)|0;Mb=Nb+Gb|0;Zb=ba(Bc+Gb|0,wb)|0;Xb=Zb+Gb|0;Wb=ba(Bc,jb)|0;Vb=Nb+kc|0;Lb=0;do{Cc=Lb+Wb|0;Dc=ba(d[yc+Cc|0]|0,d[lc+(Lb+Nb)|0]|0)|0;Ec=(ba(d[uc+Cc|0]|0,d[lc+(Mb+Lb)|0]|0)|0)+Dc|0;Dc=Ec+(ba(d[qc+Cc|0]|0,d[lc+(Lb+Zb)|0]|0)|0)|0;Ec=(Dc+(ba(d[Ub+(Cc+Eb)|0]|0,d[lc+(Xb+Lb)|0]|0)|0)|0)>>>4;Cc=pb+(Vb+Lb<<1)|0;b[Cc>>1]=(e[Cc>>1]|0)-Ec;Lb=Lb+1|0;}while((Lb|0)<(Tb|0));Bc=Bc+1|0;}while((Bc|0)<(Pb|0))}}while(0);Pb=(Sb|0)>0?Sb:0;Tb=Sb+xb|0;Ub=(rb|0)>(Tb|0)?Tb:rb;if((Pb|0)<(Ub|0)){Lb=(Rb|0)>0?Rb:0;Vb=Rb+yb|0;Xb=(sb|0)>(Vb|0)?Vb:sb;Zb=(Lb|0)<(Xb|0);Mb=(Tb|0)>(rb|0);Tb=(Vb|0)>(sb|0);Vb=Ib;Nb=Jb;Wb=Pb;while(1){if(Zb){Pb=Cb+(ba(Db+Wb|0,wb)|0)|0;Yb=ba(Wb,jb)|0;Ec=Vb;Cc=Nb;Dc=Lb;while(1){Fc=Pb+Dc|0;Gc=d[ub+Fc|0]|0;if(Ob){Hc=(d[ub+(Fc+vb)|0]|0)+Gc|0}else{Hc=Gc}if(Qb){Ic=(d[ub+(Fc+yb)|0]|0)+Hc|0}else{Ic=Hc}if(Mb){Jc=(d[ub+(Fc-vb)|0]|0)+Ic|0}else{Jc=Ic}if(Tb){Kc=(d[ub+(Fc-yb)|0]|0)+Jc|0}else{Kc=Jc}Gc=pb+(Fc+lb<<1)|0;Fc=8-(b[Gc>>1]|0)|0;b[Gc>>1]=Fc;Gc=(ba((d[kb+(Dc+Yb)|0]|0)-(Fc>>4)|0,Kc)|0)+Cc|0;Fc=(ba(Kc,Kc)|0)+Ec|0;Lc=Dc+1|0;if((Lc|0)<(Xb|0)){Ec=Fc;Cc=Gc;Dc=Lc}else{Mc=Fc;Nc=Gc;break}}}else{Mc=Vb;Nc=Nb}Dc=Wb+1|0;if((Dc|0)<(Ub|0)){Vb=Mc;Nb=Nc;Wb=Dc}else{Oc=Mc;Pc=Nc;break}}}else{Oc=Ib;Pc=Jb}Wb=Kb+1|0;if((Wb|0)<4){Ib=Oc;Jb=Pc;Kb=Wb}else{break}}b[ob>>1]=b[A>>1]|0;b[ob+2>>1]=b[A+2>>1]|0;b[ob+4>>1]=b[A+4>>1]|0;b[ob+6>>1]=b[A+6>>1]|0;b[ob+8>>1]=b[A+8>>1]|0;Kb=Pc<<8;Jb=Oc>>1;Ib=(((Kb|0)>0?Jb:-Jb|0)+Kb|0)/(Oc|0)|0;if((Ib|0)<0){Qc=0}else{Qc=(Ib|0)>255?255:Ib}c[G+(nb<<2)>>2]=Qc;nb=nb+1|0;}while((nb|0)<(c[$>>2]|0))}do{if(va){if((a[Za]&1)==0){Ya=169;break}nb=a[eb]|0;Ib=a[gb]|0;Kb=a[ib]|0;Jb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;kb=c[T>>2]|0;lb=kb+(Jb*10|0)|0;b[aa>>1]=b[lb>>1]|0;b[aa+2>>1]=b[lb+2>>1]|0;b[aa+4>>1]=b[lb+4>>1]|0;b[aa+6>>1]=b[lb+6>>1]|0;b[aa+8>>1]=b[lb+8>>1]|0;a[kb+(Jb*10|0)+5|0]=nb;a[kb+(Jb*10|0)+6|0]=Ib;a[kb+(Jb*10|0)+7|0]=Kb;Kb=kb+(Jb*10|0)+8|0;a[Kb]=a[Kb]|1;Kb=c[N>>2]|0;Jb=16>>>(Kb>>>0);kb=Jb<<1;Ib=c[X>>2]|0;nb=c[Ib+32>>2]|0;pb=c[Ib>>2]|0;Ib=c[c[V>>2]>>2]|0;ub=c[E>>2]|0;vb=c[ca>>2]|0;jb=c[L>>2]<<Kb;Db=c[Q>>2]<<Kb;Kb=c[R>>2]|0;Cb=c[_>>2]|0;sb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Rc=(sb*3|0)>>8;break};case 11:{Rc=sb>>5;break};case 12:{Rc=sb>>6;break};case 2:case 14:{Rc=sb>>6;break};case 6:case 4:case 1:case 10:{Rc=c[fa>>2]>>7;break};case 5:{Rc=1;break};default:{Rc=sb>>7}}sb=(Jb|0)/2|0;rb=(ba(Jb,Ia)|0)-sb|0;Eb=(ba(Jb,xa)|0)-sb|0;sb=(rb|0)>0?0:-rb|0;Gb=(Eb|0)>0?0:-Eb|0;Ab=Kb-rb|0;Hb=(kb|0)>(Ab|0)?Ab:kb;Ab=Cb-Eb|0;Fb=(kb|0)>(Ab|0)?Ab:kb;Ab=(ba(jb,xa)|0)+Ia|0;Iob(f,vb,c[da>>2]|0,nb,rb,Eb,kb,kb,(c[T>>2]|0)+(Ab*10|0)|0,0,Kb,Cb);if((Gb|0)<(Fb|0)){Cb=(sb|0)<(Hb|0);Kb=Gb;do{Ab=ba(Kb,kb)|0;Bb=ba(Kb,nb)|0;Na=(ba(Kb+Eb|0,nb)|0)+rb|0;if(Cb){tb=sb;do{Wb=((ba(d[I+(Kb<<5)+tb|0]|0,d[vb+(tb+Bb)|0]|0)|0)+8|0)>>>4;Nb=Wb+(b[ub+(tb+Ab<<1)>>1]|0)|0;Wb=Nb>>4;if(Wb>>>0>255>>>0){Sc=(Nb>>31^255)&255}else{Sc=Wb&255}a[pb+(Na+tb)|0]=Sc;tb=tb+1|0;}while((tb|0)<(Hb|0))}Kb=Kb+1|0;}while((Kb|0)<(Fb|0))}if(mb){Ya=154}else{if((jb-1|0)==(Ia|0)){Ya=154}}do{if((Ya|0)==154){Ya=0;if(!Ea){if((Db-1|0)!=(xa|0)){break}}Kb=mb?sb:Jb;ub=Ea?Jb:Fb;Cb=Ea?Gb:Jb;if((Cb|0)>=(ub|0)){break}ob=Kb+rb|0;tb=(mb?Jb:Hb)-Kb|0;Na=Cb;do{UGb(pb+(ob+(ba(Na+Eb|0,nb)|0))|0,vb+((ba(Na,nb)|0)+Kb)|0,tb)|0;Na=Na+1|0;}while((Na|0)<(ub|0))}}while(0);do{if((Jb|0)==16){vb=c[(c[U>>2]|0)+232>>2]|0;if((vb|0)==11){Hb=(ba(Eb,nb)|0)+rb|0;Tc=yYa(ha,Ib+Hb|0,pb+Hb|0,nb,32)|0;break}else if((vb|0)==12){vb=(ba(Eb,nb)|0)+rb|0;Tc=AYa(ha,Ib+vb|0,pb+vb|0,nb,32)|0;break}else{vb=ba(Eb,nb)|0;Hb=vb+rb|0;Gb=Pe[c[ga>>2]&255](ha,Ib+Hb|0,pb+Hb|0,nb,16)|0;Hb=rb+16|0;Fb=Hb+vb|0;vb=(Pe[c[ga>>2]&255](ha,Ib+Fb|0,pb+Fb|0,nb,16)|0)+Gb|0;Gb=ba(Eb+16|0,nb)|0;Fb=Gb+rb|0;sb=vb+(Pe[c[ga>>2]&255](ha,Ib+Fb|0,pb+Fb|0,nb,16)|0)|0;Fb=Gb+Hb|0;Tc=sb+(Pe[c[ga>>2]&255](ha,Ib+Fb|0,pb+Fb|0,nb,16)|0)|0;break}}else{Fb=(ba(Eb,nb)|0)+rb|0;Tc=Pe[c[ga>>2]&255](ha,Ib+Fb|0,pb+Fb|0,nb,kb)|0}}while(0);kb=aZa(f,Ia,xa,1)|0;nb=(aZa(f,Pa,xa,1)|0)+kb|0;kb=nb+(aZa(f,Ia-1|0,Aa,1)|0)|0;nb=kb+(aZa(f,Ia,Aa,1)|0)|0;if((jb-2|0)==(Ia|0)){Uc=(aZa(f,Pa,Aa,1)|0)+nb|0}else{Uc=nb}nb=(ba(Uc,Rc)|0)+Tc|0;if((nb|0)!=2147483647){Vc=nb;break}b[lb>>1]=b[aa>>1]|0;b[lb+2>>1]=b[aa+2>>1]|0;b[lb+4>>1]=b[aa+4>>1]|0;b[lb+6>>1]=b[aa+6>>1]|0;b[lb+8>>1]=b[aa+8>>1]|0;Vc=2147483647}else{Ya=169}}while(0);do{if((Ya|0)==169){Ya=0;nb=b[_a>>1]|0;kb=nb<<16>>16;pb=b[ab>>1]|0;Ib=pb<<16>>16;rb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Eb=c[T>>2]|0;Jb=Eb+(rb*10|0)|0;Fb=Jb;b[ia>>1]=b[Fb>>1]|0;b[ia+2>>1]=b[Fb+2>>1]|0;b[ia+4>>1]=b[Fb+4>>1]|0;b[ia+6>>1]=b[Fb+6>>1]|0;b[ia+8>>1]=b[Fb+8>>1]|0;sb=(Ib<<6)+(kb>>10)+(c[Z>>2]|0)+(d[Eb+(rb*10|0)+4|0]<<12)|0;Hb=f+2139664+(((Ib*31|0)+kb&1023)<<2)|0;if((c[Hb>>2]|0)==(sb|0)){Vc=2147483647;break}c[Hb>>2]=sb;b[Jb>>1]=nb;b[Eb+(rb*10|0)+2>>1]=pb;pb=Eb+(rb*10|0)+8|0;a[pb]=a[pb]&-2;pb=c[N>>2]|0;rb=16>>>(pb>>>0);Eb=rb<<1;nb=c[X>>2]|0;Jb=c[nb+32>>2]|0;sb=c[nb>>2]|0;nb=c[c[V>>2]>>2]|0;Hb=c[E>>2]|0;kb=c[ca>>2]|0;Ib=c[L>>2]<<pb;Gb=c[Q>>2]<<pb;pb=c[R>>2]|0;vb=c[_>>2]|0;Db=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 2:case 14:{Wc=Db>>6;break};case 6:case 4:case 1:case 10:{Wc=c[fa>>2]>>7;break};case 5:{Wc=1;break};case 3:{Wc=(Db*3|0)>>8;break};case 11:{Wc=Db>>5;break};case 12:{Wc=Db>>6;break};default:{Wc=Db>>7}}Db=(rb|0)/2|0;ub=(ba(rb,Ia)|0)-Db|0;Na=(ba(rb,xa)|0)-Db|0;Db=(ub|0)>0?0:-ub|0;tb=(Na|0)>0?0:-Na|0;Kb=pb-ub|0;ob=(Eb|0)>(Kb|0)?Kb:Eb;Kb=vb-Na|0;Cb=(Eb|0)>(Kb|0)?Kb:Eb;Kb=(ba(Ib,xa)|0)+Ia|0;Iob(f,kb,c[da>>2]|0,Jb,ub,Na,Eb,Eb,(c[T>>2]|0)+(Kb*10|0)|0,0,pb,vb);if((tb|0)<(Cb|0)){vb=(Db|0)<(ob|0);pb=tb;do{Kb=ba(pb,Eb)|0;Ab=ba(pb,Jb)|0;Bb=(ba(pb+Na|0,Jb)|0)+ub|0;if(vb){Wb=Db;do{Nb=((ba(d[I+(pb<<5)+Wb|0]|0,d[kb+(Wb+Ab)|0]|0)|0)+8|0)>>>4;Vb=Nb+(b[Hb+(Wb+Kb<<1)>>1]|0)|0;Nb=Vb>>4;if(Nb>>>0>255>>>0){Xc=(Vb>>31^255)&255}else{Xc=Nb&255}a[sb+(Bb+Wb)|0]=Xc;Wb=Wb+1|0;}while((Wb|0)<(ob|0))}pb=pb+1|0;}while((pb|0)<(Cb|0))}if(mb){Ya=186}else{if((Ib-1|0)==(Ia|0)){Ya=186}}do{if((Ya|0)==186){Ya=0;if(!Ea){if((Gb-1|0)!=(xa|0)){break}}pb=mb?Db:rb;Hb=Ea?rb:Cb;vb=Ea?tb:rb;if((vb|0)>=(Hb|0)){break}lb=pb+ub|0;jb=(mb?rb:ob)-pb|0;Wb=vb;do{UGb(sb+(lb+(ba(Wb+Na|0,Jb)|0))|0,kb+((ba(Wb,Jb)|0)+pb)|0,jb)|0;Wb=Wb+1|0;}while((Wb|0)<(Hb|0))}}while(0);do{if((rb|0)==16){kb=c[(c[U>>2]|0)+232>>2]|0;if((kb|0)==12){ob=(ba(Na,Jb)|0)+ub|0;Yc=AYa(ha,nb+ob|0,sb+ob|0,Jb,32)|0;break}else if((kb|0)==11){kb=(ba(Na,Jb)|0)+ub|0;Yc=yYa(ha,nb+kb|0,sb+kb|0,Jb,32)|0;break}else{kb=ba(Na,Jb)|0;ob=kb+ub|0;tb=Pe[c[ga>>2]&255](ha,nb+ob|0,sb+ob|0,Jb,16)|0;ob=ub+16|0;Cb=ob+kb|0;kb=(Pe[c[ga>>2]&255](ha,nb+Cb|0,sb+Cb|0,Jb,16)|0)+tb|0;tb=ba(Na+16|0,Jb)|0;Cb=tb+ub|0;Db=kb+(Pe[c[ga>>2]&255](ha,nb+Cb|0,sb+Cb|0,Jb,16)|0)|0;Cb=tb+ob|0;Yc=Db+(Pe[c[ga>>2]&255](ha,nb+Cb|0,sb+Cb|0,Jb,16)|0)|0;break}}else{Cb=(ba(Na,Jb)|0)+ub|0;Yc=Pe[c[ga>>2]&255](ha,nb+Cb|0,sb+Cb|0,Jb,Eb)|0}}while(0);Eb=aZa(f,Ia,xa,1)|0;Jb=(aZa(f,Pa,xa,1)|0)+Eb|0;Eb=Jb+(aZa(f,Ia-1|0,Aa,1)|0)|0;Jb=Eb+(aZa(f,Ia,Aa,1)|0)|0;if((Ib-2|0)==(Ia|0)){Zc=(aZa(f,Pa,Aa,1)|0)+Jb|0}else{Zc=Jb}Jb=(ba(Zc,Wc)|0)+Yc|0;if((Jb|0)!=2147483647){Vc=Jb;break}b[Fb>>1]=b[ia>>1]|0;b[Fb+2>>1]=b[ia+2>>1]|0;b[Fb+4>>1]=b[ia+4>>1]|0;b[Fb+6>>1]=b[ia+6>>1]|0;b[Fb+8>>1]=b[ia+8>>1]|0;Vc=2147483647}}while(0);Jb=La;Eb=e[Jb>>1]|e[Jb+2>>1]<<16;sb=a[cb]|0;a[D]=a[eb]|0;a[D+1|0]=a[eb+1|0]|0;a[D+2|0]=a[eb+2|0]|0;a[D+3|0]=a[eb+3|0]|0;a[D+4|0]=a[eb+4|0]|0;if((c[H>>2]|0)>0){nb=(Ma|0)==0;ub=(Oa|0)==0;Na=(Ra|0)==0;rb=(Sa|0)==0;Cb=Ja+P|0;Db=Ia-1|0;ob=Ja+1|0;tb=Ja-1|0;kb=Ja-P|0;Gb=Eb;Hb=sb;Wb=Vc;jb=0;while(1){pb=c[f+7392+(jb<<2)>>2]|0;do{if((c[(c[f+7424+(jb<<2)>>2]|0)+(Ja<<2)>>2]|0)>>>0>((c[(c[f+7424+((Hb&255)<<2)>>2]|0)+(Ja<<2)>>2]|0)*3|0)>>>1>>>0){_c=Wb;$c=Hb;ad=Gb}else{a[cb]=jb;lb=pb+(Ja<<2)|0;vb=b[lb>>1]|0;Bb=vb<<16>>16;Kb=pb+(Ja<<2)+2|0;Ab=b[Kb>>1]|0;Nb=Ab<<16>>16;Vb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Ub=c[T>>2]|0;Xb=Ub+(Vb*10|0)|0;Tb=Xb;b[ma>>1]=b[Tb>>1]|0;b[ma+2>>1]=b[Tb+2>>1]|0;b[ma+4>>1]=b[Tb+4>>1]|0;b[ma+6>>1]=b[Tb+6>>1]|0;b[ma+8>>1]=b[Tb+8>>1]|0;Mb=(Nb<<6)+(Bb>>10)+(c[Z>>2]|0)+(d[Ub+(Vb*10|0)+4|0]<<12)|0;Qb=f+2139664+(((Nb*31|0)+Bb&1023)<<2)|0;do{if((c[Qb>>2]|0)==(Mb|0)){bd=2147483647}else{c[Qb>>2]=Mb;b[Xb>>1]=vb;b[Ub+(Vb*10|0)+2>>1]=Ab;Bb=Ub+(Vb*10|0)+8|0;a[Bb]=a[Bb]&-2;Bb=c[N>>2]|0;Nb=16>>>(Bb>>>0);Ob=Nb<<1;Lb=c[X>>2]|0;Zb=c[Lb+32>>2]|0;Rb=c[Lb>>2]|0;Lb=c[c[V>>2]>>2]|0;Sb=c[E>>2]|0;Dc=c[ca>>2]|0;Cc=c[L>>2]<<Bb;Ec=c[Q>>2]<<Bb;Bb=c[R>>2]|0;Yb=c[_>>2]|0;Pb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{cd=(Pb*3|0)>>8;break};case 12:{cd=Pb>>6;break};case 2:case 14:{cd=Pb>>6;break};case 11:{cd=Pb>>5;break};case 6:case 4:case 1:case 10:{cd=c[fa>>2]>>7;break};case 5:{cd=1;break};default:{cd=Pb>>7}}Pb=(Nb|0)/2|0;Gc=(ba(Nb,Ia)|0)-Pb|0;Fc=(ba(Nb,xa)|0)-Pb|0;Pb=(Gc|0)>0?0:-Gc|0;Lc=(Fc|0)>0?0:-Fc|0;dd=Bb-Gc|0;ed=(Ob|0)>(dd|0)?dd:Ob;dd=Yb-Fc|0;fd=(Ob|0)>(dd|0)?dd:Ob;dd=(ba(Cc,xa)|0)+Ia|0;Iob(f,Dc,c[da>>2]|0,Zb,Gc,Fc,Ob,Ob,(c[T>>2]|0)+(dd*10|0)|0,0,Bb,Yb);if((Lc|0)<(fd|0)){Yb=(Pb|0)<(ed|0);Bb=Lc;do{dd=ba(Bb,Ob)|0;gd=ba(Bb,Zb)|0;hd=(ba(Bb+Fc|0,Zb)|0)+Gc|0;if(Yb){id=Pb;do{jd=((ba(d[I+(Bb<<5)+id|0]|0,d[Dc+(id+gd)|0]|0)|0)+8|0)>>>4;kd=jd+(b[Sb+(id+dd<<1)>>1]|0)|0;jd=kd>>4;if(jd>>>0>255>>>0){ld=(kd>>31^255)&255}else{ld=jd&255}a[Rb+(hd+id)|0]=ld;id=id+1|0;}while((id|0)<(ed|0))}Bb=Bb+1|0;}while((Bb|0)<(fd|0))}if(mb){Ya=221}else{if((Cc-1|0)==(Ia|0)){Ya=221}}do{if((Ya|0)==221){Ya=0;if(!Ea){if((Ec-1|0)!=(xa|0)){break}}Bb=mb?Pb:Nb;Sb=Ea?Nb:fd;Yb=Ea?Lc:Nb;if((Yb|0)>=(Sb|0)){break}id=Bb+Gc|0;hd=(mb?Nb:ed)-Bb|0;dd=Yb;do{UGb(Rb+(id+(ba(dd+Fc|0,Zb)|0))|0,Dc+((ba(dd,Zb)|0)+Bb)|0,hd)|0;dd=dd+1|0;}while((dd|0)<(Sb|0))}}while(0);do{if((Nb|0)==16){Dc=c[(c[U>>2]|0)+232>>2]|0;if((Dc|0)==12){ed=(ba(Fc,Zb)|0)+Gc|0;md=AYa(ha,Lb+ed|0,Rb+ed|0,Zb,32)|0;break}else if((Dc|0)==11){Dc=(ba(Fc,Zb)|0)+Gc|0;md=yYa(ha,Lb+Dc|0,Rb+Dc|0,Zb,32)|0;break}else{Dc=ba(Fc,Zb)|0;ed=Dc+Gc|0;Lc=Pe[c[ga>>2]&255](ha,Lb+ed|0,Rb+ed|0,Zb,16)|0;ed=Gc+16|0;fd=ed+Dc|0;Dc=(Pe[c[ga>>2]&255](ha,Lb+fd|0,Rb+fd|0,Zb,16)|0)+Lc|0;Lc=ba(Fc+16|0,Zb)|0;fd=Lc+Gc|0;Pb=Dc+(Pe[c[ga>>2]&255](ha,Lb+fd|0,Rb+fd|0,Zb,16)|0)|0;fd=Lc+ed|0;md=Pb+(Pe[c[ga>>2]&255](ha,Lb+fd|0,Rb+fd|0,Zb,16)|0)|0;break}}else{fd=(ba(Fc,Zb)|0)+Gc|0;md=Pe[c[ga>>2]&255](ha,Lb+fd|0,Rb+fd|0,Zb,Ob)|0}}while(0);Ob=aZa(f,Ia,xa,1)|0;Zb=(aZa(f,Pa,xa,1)|0)+Ob|0;Ob=Zb+(aZa(f,Db,Aa,1)|0)|0;Zb=Ob+(aZa(f,Ia,Aa,1)|0)|0;if((Cc-2|0)==(Ia|0)){nd=(aZa(f,Pa,Aa,1)|0)+Zb|0}else{nd=Zb}Zb=(ba(nd,cd)|0)+md|0;if((Zb|0)!=2147483647){bd=Zb;break}b[Tb>>1]=b[ma>>1]|0;b[Tb+2>>1]=b[ma+2>>1]|0;b[Tb+4>>1]=b[ma+4>>1]|0;b[Tb+6>>1]=b[ma+6>>1]|0;b[Tb+8>>1]=b[ma+8>>1]|0;bd=2147483647}}while(0);Tb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Vb=c[T>>2]|0;Ub=Vb+(Tb*10|0)|0;Ab=Ub;b[C>>1]=b[Ab>>1]|0;b[C+2>>1]=b[Ab+2>>1]|0;b[C+4>>1]=b[Ab+4>>1]|0;b[C+6>>1]=b[Ab+6>>1]|0;b[C+8>>1]=b[Ab+8>>1]|0;vb=(d[Vb+(Tb*10|0)+4|0]<<12)+(c[Z>>2]|0)|0;do{if((c[B>>2]|0)==(vb|0)){od=bd}else{c[B>>2]=vb;b[Ub>>1]=0;b[Vb+(Tb*10|0)+2>>1]=0;Xb=Vb+(Tb*10|0)+8|0;a[Xb]=a[Xb]&-2;Xb=c[N>>2]|0;Mb=16>>>(Xb>>>0);Qb=Mb<<1;Zb=c[X>>2]|0;Ob=c[Zb+32>>2]|0;Rb=c[Zb>>2]|0;Zb=c[c[V>>2]>>2]|0;Lb=c[E>>2]|0;Gc=c[ca>>2]|0;Fc=c[L>>2]<<Xb;Nb=c[Q>>2]<<Xb;Xb=c[R>>2]|0;fd=c[_>>2]|0;Pb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{pd=(Pb*3|0)>>8;break};case 11:{pd=Pb>>5;break};case 12:{pd=Pb>>6;break};case 2:case 14:{pd=Pb>>6;break};case 6:case 4:case 1:case 10:{pd=c[fa>>2]>>7;break};case 5:{pd=1;break};default:{pd=Pb>>7}}Pb=(Mb|0)/2|0;ed=(ba(Mb,Ia)|0)-Pb|0;Lc=(ba(Mb,xa)|0)-Pb|0;Pb=(ed|0)>0?0:-ed|0;Dc=(Lc|0)>0?0:-Lc|0;Ec=Xb-ed|0;Sb=(Qb|0)>(Ec|0)?Ec:Qb;Ec=fd-Lc|0;dd=(Qb|0)>(Ec|0)?Ec:Qb;Ec=(ba(Fc,xa)|0)+Ia|0;Iob(f,Gc,c[da>>2]|0,Ob,ed,Lc,Qb,Qb,(c[T>>2]|0)+(Ec*10|0)|0,0,Xb,fd);if((Dc|0)<(dd|0)){fd=(Pb|0)<(Sb|0);Xb=Dc;do{Ec=ba(Xb,Qb)|0;hd=ba(Xb,Ob)|0;Bb=(ba(Xb+Lc|0,Ob)|0)+ed|0;if(fd){id=Pb;do{Yb=((ba(d[I+(Xb<<5)+id|0]|0,d[Gc+(id+hd)|0]|0)|0)+8|0)>>>4;gd=Yb+(b[Lb+(id+Ec<<1)>>1]|0)|0;Yb=gd>>4;if(Yb>>>0>255>>>0){qd=(gd>>31^255)&255}else{qd=Yb&255}a[Rb+(Bb+id)|0]=qd;id=id+1|0;}while((id|0)<(Sb|0))}Xb=Xb+1|0;}while((Xb|0)<(dd|0))}if(mb){Ya=253}else{if((Fc-1|0)==(Ia|0)){Ya=253}}do{if((Ya|0)==253){Ya=0;if(!Ea){if((Nb-1|0)!=(xa|0)){break}}Xb=mb?Pb:Mb;Lb=Ea?Mb:dd;fd=Ea?Dc:Mb;if((fd|0)>=(Lb|0)){break}Cc=Xb+ed|0;id=(mb?Mb:Sb)-Xb|0;Bb=fd;do{UGb(Rb+(Cc+(ba(Bb+Lc|0,Ob)|0))|0,Gc+((ba(Bb,Ob)|0)+Xb)|0,id)|0;Bb=Bb+1|0;}while((Bb|0)<(Lb|0))}}while(0);do{if((Mb|0)==16){Gc=c[(c[U>>2]|0)+232>>2]|0;if((Gc|0)==12){Sb=(ba(Lc,Ob)|0)+ed|0;rd=AYa(ha,Zb+Sb|0,Rb+Sb|0,Ob,32)|0;break}else if((Gc|0)==11){Gc=(ba(Lc,Ob)|0)+ed|0;rd=yYa(ha,Zb+Gc|0,Rb+Gc|0,Ob,32)|0;break}else{Gc=ba(Lc,Ob)|0;Sb=Gc+ed|0;Dc=Pe[c[ga>>2]&255](ha,Zb+Sb|0,Rb+Sb|0,Ob,16)|0;Sb=ed+16|0;dd=Sb+Gc|0;Gc=(Pe[c[ga>>2]&255](ha,Zb+dd|0,Rb+dd|0,Ob,16)|0)+Dc|0;Dc=ba(Lc+16|0,Ob)|0;dd=Dc+ed|0;Pb=Gc+(Pe[c[ga>>2]&255](ha,Zb+dd|0,Rb+dd|0,Ob,16)|0)|0;dd=Dc+Sb|0;rd=Pb+(Pe[c[ga>>2]&255](ha,Zb+dd|0,Rb+dd|0,Ob,16)|0)|0;break}}else{dd=(ba(Lc,Ob)|0)+ed|0;rd=Pe[c[ga>>2]&255](ha,Zb+dd|0,Rb+dd|0,Ob,Qb)|0}}while(0);Qb=aZa(f,Ia,xa,1)|0;Ob=(aZa(f,Pa,xa,1)|0)+Qb|0;Qb=Ob+(aZa(f,Db,Aa,1)|0)|0;Ob=Qb+(aZa(f,Ia,Aa,1)|0)|0;if((Fc-2|0)==(Ia|0)){sd=(aZa(f,Pa,Aa,1)|0)+Ob|0}else{sd=Ob}Ob=(ba(sd,pd)|0)+rd|0;if((Ob|0)<(bd|0)){od=Ob;break}b[Ab>>1]=b[C>>1]|0;b[Ab+2>>1]=b[C+2>>1]|0;b[Ab+4>>1]=b[C+4>>1]|0;b[Ab+6>>1]=b[C+6>>1]|0;b[Ab+8>>1]=b[C+8>>1]|0;od=bd}}while(0);do{if(nb){td=od}else{Ab=b[pb+(kb<<2)>>1]|0;Tb=Ab<<16>>16;Vb=b[pb+(kb<<2)+2>>1]|0;Ub=Vb<<16>>16;vb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Ob=c[T>>2]|0;Qb=Ob+(vb*10|0)|0;Rb=Qb;b[z>>1]=b[Rb>>1]|0;b[z+2>>1]=b[Rb+2>>1]|0;b[z+4>>1]=b[Rb+4>>1]|0;b[z+6>>1]=b[Rb+6>>1]|0;b[z+8>>1]=b[Rb+8>>1]|0;Zb=(Ub<<6)+(Tb>>10)+(c[Z>>2]|0)+(d[Ob+(vb*10|0)+4|0]<<12)|0;ed=f+2139664+(((Ub*31|0)+Tb&1023)<<2)|0;if((c[ed>>2]|0)==(Zb|0)){td=od;break}c[ed>>2]=Zb;b[Qb>>1]=Ab;b[Ob+(vb*10|0)+2>>1]=Vb;Vb=Ob+(vb*10|0)+8|0;a[Vb]=a[Vb]&-2;Vb=c[N>>2]|0;vb=16>>>(Vb>>>0);Ob=vb<<1;Ab=c[X>>2]|0;Qb=c[Ab+32>>2]|0;Zb=c[Ab>>2]|0;Ab=c[c[V>>2]>>2]|0;ed=c[E>>2]|0;Tb=c[ca>>2]|0;Ub=c[L>>2]<<Vb;Lc=c[Q>>2]<<Vb;Vb=c[R>>2]|0;Mb=c[_>>2]|0;dd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{ud=(dd*3|0)>>8;break};case 11:{ud=dd>>5;break};case 12:{ud=dd>>6;break};case 2:case 14:{ud=dd>>6;break};case 6:case 4:case 1:case 10:{ud=c[fa>>2]>>7;break};case 5:{ud=1;break};default:{ud=dd>>7}}dd=(vb|0)/2|0;Pb=(ba(vb,Ia)|0)-dd|0;Sb=(ba(vb,xa)|0)-dd|0;dd=(Pb|0)>0?0:-Pb|0;Dc=(Sb|0)>0?0:-Sb|0;Gc=Vb-Pb|0;Nb=(Ob|0)>(Gc|0)?Gc:Ob;Gc=Mb-Sb|0;Lb=(Ob|0)>(Gc|0)?Gc:Ob;Gc=(ba(Ub,xa)|0)+Ia|0;Iob(f,Tb,c[da>>2]|0,Qb,Pb,Sb,Ob,Ob,(c[T>>2]|0)+(Gc*10|0)|0,0,Vb,Mb);if((Dc|0)<(Lb|0)){Mb=(dd|0)<(Nb|0);Vb=Dc;do{Gc=ba(Vb,Ob)|0;Bb=ba(Vb,Qb)|0;id=(ba(Vb+Sb|0,Qb)|0)+Pb|0;if(Mb){Xb=dd;do{Cc=((ba(d[I+(Vb<<5)+Xb|0]|0,d[Tb+(Xb+Bb)|0]|0)|0)+8|0)>>>4;fd=Cc+(b[ed+(Xb+Gc<<1)>>1]|0)|0;Cc=fd>>4;if(Cc>>>0>255>>>0){vd=(fd>>31^255)&255}else{vd=Cc&255}a[Zb+(id+Xb)|0]=vd;Xb=Xb+1|0;}while((Xb|0)<(Nb|0))}Vb=Vb+1|0;}while((Vb|0)<(Lb|0))}if(mb){Ya=286}else{if((Ub-1|0)==(Ia|0)){Ya=286}}do{if((Ya|0)==286){Ya=0;if(!Ea){if((Lc-1|0)!=(xa|0)){break}}Vb=mb?dd:vb;ed=Ea?vb:Lb;Mb=Ea?Dc:vb;if((Mb|0)>=(ed|0)){break}Fc=Vb+Pb|0;Xb=(mb?vb:Nb)-Vb|0;id=Mb;do{UGb(Zb+(Fc+(ba(id+Sb|0,Qb)|0))|0,Tb+((ba(id,Qb)|0)+Vb)|0,Xb)|0;id=id+1|0;}while((id|0)<(ed|0))}}while(0);do{if((vb|0)==16){Tb=c[(c[U>>2]|0)+232>>2]|0;if((Tb|0)==12){Nb=(ba(Sb,Qb)|0)+Pb|0;wd=AYa(ha,Ab+Nb|0,Zb+Nb|0,Qb,32)|0;break}else if((Tb|0)==11){Tb=(ba(Sb,Qb)|0)+Pb|0;wd=yYa(ha,Ab+Tb|0,Zb+Tb|0,Qb,32)|0;break}else{Tb=ba(Sb,Qb)|0;Nb=Tb+Pb|0;Dc=Pe[c[ga>>2]&255](ha,Ab+Nb|0,Zb+Nb|0,Qb,16)|0;Nb=Pb+16|0;Lb=Nb+Tb|0;Tb=(Pe[c[ga>>2]&255](ha,Ab+Lb|0,Zb+Lb|0,Qb,16)|0)+Dc|0;Dc=ba(Sb+16|0,Qb)|0;Lb=Dc+Pb|0;dd=Tb+(Pe[c[ga>>2]&255](ha,Ab+Lb|0,Zb+Lb|0,Qb,16)|0)|0;Lb=Dc+Nb|0;wd=dd+(Pe[c[ga>>2]&255](ha,Ab+Lb|0,Zb+Lb|0,Qb,16)|0)|0;break}}else{Lb=(ba(Sb,Qb)|0)+Pb|0;wd=Pe[c[ga>>2]&255](ha,Ab+Lb|0,Zb+Lb|0,Qb,Ob)|0}}while(0);Ob=aZa(f,Ia,xa,1)|0;Qb=(aZa(f,Pa,xa,1)|0)+Ob|0;Ob=Qb+(aZa(f,Db,Aa,1)|0)|0;Qb=Ob+(aZa(f,Ia,Aa,1)|0)|0;if((Ub-2|0)==(Ia|0)){xd=(aZa(f,Pa,Aa,1)|0)+Qb|0}else{xd=Qb}Qb=(ba(xd,ud)|0)+wd|0;if((Qb|0)<(od|0)){td=Qb;break}b[Rb>>1]=b[z>>1]|0;b[Rb+2>>1]=b[z+2>>1]|0;b[Rb+4>>1]=b[z+4>>1]|0;b[Rb+6>>1]=b[z+6>>1]|0;b[Rb+8>>1]=b[z+8>>1]|0;td=od}}while(0);do{if(ub){yd=td}else{Qb=b[pb+(tb<<2)>>1]|0;Ob=Qb<<16>>16;Zb=b[pb+(tb<<2)+2>>1]|0;Ab=Zb<<16>>16;Pb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Sb=c[T>>2]|0;vb=Sb+(Pb*10|0)|0;Lb=vb;b[y>>1]=b[Lb>>1]|0;b[y+2>>1]=b[Lb+2>>1]|0;b[y+4>>1]=b[Lb+4>>1]|0;b[y+6>>1]=b[Lb+6>>1]|0;b[y+8>>1]=b[Lb+8>>1]|0;dd=(Ab<<6)+(Ob>>10)+(c[Z>>2]|0)+(d[Sb+(Pb*10|0)+4|0]<<12)|0;Nb=f+2139664+(((Ab*31|0)+Ob&1023)<<2)|0;if((c[Nb>>2]|0)==(dd|0)){yd=td;break}c[Nb>>2]=dd;b[vb>>1]=Qb;b[Sb+(Pb*10|0)+2>>1]=Zb;Zb=Sb+(Pb*10|0)+8|0;a[Zb]=a[Zb]&-2;Zb=c[N>>2]|0;Pb=16>>>(Zb>>>0);Sb=Pb<<1;Qb=c[X>>2]|0;vb=c[Qb+32>>2]|0;dd=c[Qb>>2]|0;Qb=c[c[V>>2]>>2]|0;Nb=c[E>>2]|0;Ob=c[ca>>2]|0;Ab=c[L>>2]<<Zb;Dc=c[Q>>2]<<Zb;Zb=c[R>>2]|0;Tb=c[_>>2]|0;Lc=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{zd=(Lc*3|0)>>8;break};case 11:{zd=Lc>>5;break};case 12:{zd=Lc>>6;break};case 2:case 14:{zd=Lc>>6;break};case 6:case 4:case 1:case 10:{zd=c[fa>>2]>>7;break};case 5:{zd=1;break};default:{zd=Lc>>7}}Lc=(Pb|0)/2|0;ed=(ba(Pb,Ia)|0)-Lc|0;id=(ba(Pb,xa)|0)-Lc|0;Lc=(ed|0)>0?0:-ed|0;Xb=(id|0)>0?0:-id|0;Vb=Zb-ed|0;Fc=(Sb|0)>(Vb|0)?Vb:Sb;Vb=Tb-id|0;Mb=(Sb|0)>(Vb|0)?Vb:Sb;Vb=(ba(Ab,xa)|0)+Ia|0;Iob(f,Ob,c[da>>2]|0,vb,ed,id,Sb,Sb,(c[T>>2]|0)+(Vb*10|0)|0,0,Zb,Tb);if((Xb|0)<(Mb|0)){Tb=(Lc|0)<(Fc|0);Zb=Xb;do{Vb=ba(Zb,Sb)|0;Gc=ba(Zb,vb)|0;Bb=(ba(Zb+id|0,vb)|0)+ed|0;if(Tb){Cc=Lc;do{fd=((ba(d[I+(Zb<<5)+Cc|0]|0,d[Ob+(Cc+Gc)|0]|0)|0)+8|0)>>>4;Ec=fd+(b[Nb+(Cc+Vb<<1)>>1]|0)|0;fd=Ec>>4;if(fd>>>0>255>>>0){Ad=(Ec>>31^255)&255}else{Ad=fd&255}a[dd+(Bb+Cc)|0]=Ad;Cc=Cc+1|0;}while((Cc|0)<(Fc|0))}Zb=Zb+1|0;}while((Zb|0)<(Mb|0))}if(mb){Ya=319}else{if((Ab-1|0)==(Ia|0)){Ya=319}}do{if((Ya|0)==319){Ya=0;if(!Ea){if((Dc-1|0)!=(xa|0)){break}}Zb=mb?Lc:Pb;Nb=Ea?Pb:Mb;Tb=Ea?Xb:Pb;if((Tb|0)>=(Nb|0)){break}Rb=Zb+ed|0;Ub=(mb?Pb:Fc)-Zb|0;Cc=Tb;do{UGb(dd+(Rb+(ba(Cc+id|0,vb)|0))|0,Ob+((ba(Cc,vb)|0)+Zb)|0,Ub)|0;Cc=Cc+1|0;}while((Cc|0)<(Nb|0))}}while(0);do{if((Pb|0)==16){Ob=c[(c[U>>2]|0)+232>>2]|0;if((Ob|0)==12){Fc=(ba(id,vb)|0)+ed|0;Bd=AYa(ha,Qb+Fc|0,dd+Fc|0,vb,32)|0;break}else if((Ob|0)==11){Ob=(ba(id,vb)|0)+ed|0;Bd=yYa(ha,Qb+Ob|0,dd+Ob|0,vb,32)|0;break}else{Ob=ba(id,vb)|0;Fc=Ob+ed|0;Xb=Pe[c[ga>>2]&255](ha,Qb+Fc|0,dd+Fc|0,vb,16)|0;Fc=ed+16|0;Mb=Fc+Ob|0;Ob=(Pe[c[ga>>2]&255](ha,Qb+Mb|0,dd+Mb|0,vb,16)|0)+Xb|0;Xb=ba(id+16|0,vb)|0;Mb=Xb+ed|0;Lc=Ob+(Pe[c[ga>>2]&255](ha,Qb+Mb|0,dd+Mb|0,vb,16)|0)|0;Mb=Xb+Fc|0;Bd=Lc+(Pe[c[ga>>2]&255](ha,Qb+Mb|0,dd+Mb|0,vb,16)|0)|0;break}}else{Mb=(ba(id,vb)|0)+ed|0;Bd=Pe[c[ga>>2]&255](ha,Qb+Mb|0,dd+Mb|0,vb,Sb)|0}}while(0);Sb=aZa(f,Ia,xa,1)|0;vb=(aZa(f,Pa,xa,1)|0)+Sb|0;Sb=vb+(aZa(f,Db,Aa,1)|0)|0;vb=Sb+(aZa(f,Ia,Aa,1)|0)|0;if((Ab-2|0)==(Ia|0)){Cd=(aZa(f,Pa,Aa,1)|0)+vb|0}else{Cd=vb}vb=(ba(Cd,zd)|0)+Bd|0;if((vb|0)<(td|0)){yd=vb;break}b[Lb>>1]=b[y>>1]|0;b[Lb+2>>1]=b[y+2>>1]|0;b[Lb+4>>1]=b[y+4>>1]|0;b[Lb+6>>1]=b[y+6>>1]|0;b[Lb+8>>1]=b[y+8>>1]|0;yd=td}}while(0);do{if(Na){Dd=yd}else{vb=b[pb+(ob<<2)>>1]|0;Sb=vb<<16>>16;dd=b[pb+(ob<<2)+2>>1]|0;Qb=dd<<16>>16;ed=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;id=c[T>>2]|0;Pb=id+(ed*10|0)|0;Mb=Pb;b[r>>1]=b[Mb>>1]|0;b[r+2>>1]=b[Mb+2>>1]|0;b[r+4>>1]=b[Mb+4>>1]|0;b[r+6>>1]=b[Mb+6>>1]|0;b[r+8>>1]=b[Mb+8>>1]|0;Lc=(Qb<<6)+(Sb>>10)+(c[Z>>2]|0)+(d[id+(ed*10|0)+4|0]<<12)|0;Fc=f+2139664+(((Qb*31|0)+Sb&1023)<<2)|0;if((c[Fc>>2]|0)==(Lc|0)){Dd=yd;break}c[Fc>>2]=Lc;b[Pb>>1]=vb;b[id+(ed*10|0)+2>>1]=dd;dd=id+(ed*10|0)+8|0;a[dd]=a[dd]&-2;dd=c[N>>2]|0;ed=16>>>(dd>>>0);id=ed<<1;vb=c[X>>2]|0;Pb=c[vb+32>>2]|0;Lc=c[vb>>2]|0;vb=c[c[V>>2]>>2]|0;Fc=c[E>>2]|0;Sb=c[ca>>2]|0;Qb=c[L>>2]<<dd;Xb=c[Q>>2]<<dd;dd=c[R>>2]|0;Ob=c[_>>2]|0;Dc=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 6:case 4:case 1:case 10:{Ed=c[fa>>2]>>7;break};case 5:{Ed=1;break};case 3:{Ed=(Dc*3|0)>>8;break};case 11:{Ed=Dc>>5;break};case 12:{Ed=Dc>>6;break};case 2:case 14:{Ed=Dc>>6;break};default:{Ed=Dc>>7}}Dc=(ed|0)/2|0;Nb=(ba(ed,Ia)|0)-Dc|0;Cc=(ba(ed,xa)|0)-Dc|0;Dc=(Nb|0)>0?0:-Nb|0;Ub=(Cc|0)>0?0:-Cc|0;Zb=dd-Nb|0;Rb=(id|0)>(Zb|0)?Zb:id;Zb=Ob-Cc|0;Tb=(id|0)>(Zb|0)?Zb:id;Zb=(ba(Qb,xa)|0)+Ia|0;Iob(f,Sb,c[da>>2]|0,Pb,Nb,Cc,id,id,(c[T>>2]|0)+(Zb*10|0)|0,0,dd,Ob);if((Ub|0)<(Tb|0)){Ob=(Dc|0)<(Rb|0);dd=Ub;do{Zb=ba(dd,id)|0;Bb=ba(dd,Pb)|0;Vb=(ba(dd+Cc|0,Pb)|0)+Nb|0;if(Ob){Gc=Dc;do{fd=((ba(d[I+(dd<<5)+Gc|0]|0,d[Sb+(Gc+Bb)|0]|0)|0)+8|0)>>>4;Ec=fd+(b[Fc+(Gc+Zb<<1)>>1]|0)|0;fd=Ec>>4;if(fd>>>0>255>>>0){Fd=(Ec>>31^255)&255}else{Fd=fd&255}a[Lc+(Vb+Gc)|0]=Fd;Gc=Gc+1|0;}while((Gc|0)<(Rb|0))}dd=dd+1|0;}while((dd|0)<(Tb|0))}if(mb){Ya=352}else{if((Qb-1|0)==(Ia|0)){Ya=352}}do{if((Ya|0)==352){Ya=0;if(!Ea){if((Xb-1|0)!=(xa|0)){break}}dd=mb?Dc:ed;Fc=Ea?ed:Tb;Ob=Ea?Ub:ed;if((Ob|0)>=(Fc|0)){break}Lb=dd+Nb|0;Ab=(mb?ed:Rb)-dd|0;Gc=Ob;do{UGb(Lc+(Lb+(ba(Gc+Cc|0,Pb)|0))|0,Sb+((ba(Gc,Pb)|0)+dd)|0,Ab)|0;Gc=Gc+1|0;}while((Gc|0)<(Fc|0))}}while(0);do{if((ed|0)==16){Sb=c[(c[U>>2]|0)+232>>2]|0;if((Sb|0)==12){Rb=(ba(Cc,Pb)|0)+Nb|0;Gd=AYa(ha,vb+Rb|0,Lc+Rb|0,Pb,32)|0;break}else if((Sb|0)==11){Sb=(ba(Cc,Pb)|0)+Nb|0;Gd=yYa(ha,vb+Sb|0,Lc+Sb|0,Pb,32)|0;break}else{Sb=ba(Cc,Pb)|0;Rb=Sb+Nb|0;Ub=Pe[c[ga>>2]&255](ha,vb+Rb|0,Lc+Rb|0,Pb,16)|0;Rb=Nb+16|0;Tb=Rb+Sb|0;Sb=(Pe[c[ga>>2]&255](ha,vb+Tb|0,Lc+Tb|0,Pb,16)|0)+Ub|0;Ub=ba(Cc+16|0,Pb)|0;Tb=Ub+Nb|0;Dc=Sb+(Pe[c[ga>>2]&255](ha,vb+Tb|0,Lc+Tb|0,Pb,16)|0)|0;Tb=Ub+Rb|0;Gd=Dc+(Pe[c[ga>>2]&255](ha,vb+Tb|0,Lc+Tb|0,Pb,16)|0)|0;break}}else{Tb=(ba(Cc,Pb)|0)+Nb|0;Gd=Pe[c[ga>>2]&255](ha,vb+Tb|0,Lc+Tb|0,Pb,id)|0}}while(0);id=aZa(f,Ia,xa,1)|0;Pb=(aZa(f,Pa,xa,1)|0)+id|0;id=Pb+(aZa(f,Db,Aa,1)|0)|0;Pb=id+(aZa(f,Ia,Aa,1)|0)|0;if((Qb-2|0)==(Ia|0)){Hd=(aZa(f,Pa,Aa,1)|0)+Pb|0}else{Hd=Pb}Pb=(ba(Hd,Ed)|0)+Gd|0;if((Pb|0)<(yd|0)){Dd=Pb;break}b[Mb>>1]=b[r>>1]|0;b[Mb+2>>1]=b[r+2>>1]|0;b[Mb+4>>1]=b[r+4>>1]|0;b[Mb+6>>1]=b[r+6>>1]|0;b[Mb+8>>1]=b[r+8>>1]|0;Dd=yd}}while(0);do{if(rb){Id=0;Jd=0;Kd=Dd}else{Pb=b[pb+(Cb<<2)>>1]|0;id=Pb<<16>>16;Lc=b[pb+(Cb<<2)+2>>1]|0;vb=Lc<<16>>16;Nb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Cc=c[T>>2]|0;ed=Cc+(Nb*10|0)|0;Tb=ed;b[na>>1]=b[Tb>>1]|0;b[na+2>>1]=b[Tb+2>>1]|0;b[na+4>>1]=b[Tb+4>>1]|0;b[na+6>>1]=b[Tb+6>>1]|0;b[na+8>>1]=b[Tb+8>>1]|0;Dc=(vb<<6)+(id>>10)+(c[Z>>2]|0)+(d[Cc+(Nb*10|0)+4|0]<<12)|0;Rb=f+2139664+(((vb*31|0)+id&1023)<<2)|0;if((c[Rb>>2]|0)==(Dc|0)){Id=0;Jd=0;Kd=Dd;break}c[Rb>>2]=Dc;b[ed>>1]=Pb;b[Cc+(Nb*10|0)+2>>1]=Lc;Lc=Cc+(Nb*10|0)+8|0;a[Lc]=a[Lc]&-2;Lc=c[N>>2]|0;Nb=16>>>(Lc>>>0);Cc=Nb<<1;Pb=c[X>>2]|0;ed=c[Pb+32>>2]|0;Dc=c[Pb>>2]|0;Pb=c[c[V>>2]>>2]|0;Rb=c[E>>2]|0;id=c[ca>>2]|0;vb=c[L>>2]<<Lc;Ub=c[Q>>2]<<Lc;Lc=c[R>>2]|0;Sb=c[_>>2]|0;Xb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Ld=(Xb*3|0)>>8;break};case 11:{Ld=Xb>>5;break};case 12:{Ld=Xb>>6;break};case 2:case 14:{Ld=Xb>>6;break};case 6:case 4:case 1:case 10:{Ld=c[fa>>2]>>7;break};case 5:{Ld=1;break};default:{Ld=Xb>>7}}Xb=(Nb|0)/2|0;Fc=(ba(Nb,Ia)|0)-Xb|0;Gc=(ba(Nb,xa)|0)-Xb|0;Xb=(Fc|0)>0?0:-Fc|0;Ab=(Gc|0)>0?0:-Gc|0;dd=Lc-Fc|0;Lb=(Cc|0)>(dd|0)?dd:Cc;dd=Sb-Gc|0;Ob=(Cc|0)>(dd|0)?dd:Cc;dd=(ba(vb,xa)|0)+Ia|0;Iob(f,id,c[da>>2]|0,ed,Fc,Gc,Cc,Cc,(c[T>>2]|0)+(dd*10|0)|0,0,Lc,Sb);if((Ab|0)<(Ob|0)){Sb=(Xb|0)<(Lb|0);Lc=Ab;do{dd=ba(Lc,Cc)|0;Vb=ba(Lc,ed)|0;Zb=(ba(Lc+Gc|0,ed)|0)+Fc|0;if(Sb){Bb=Xb;do{fd=((ba(d[I+(Lc<<5)+Bb|0]|0,d[id+(Bb+Vb)|0]|0)|0)+8|0)>>>4;Ec=fd+(b[Rb+(Bb+dd<<1)>>1]|0)|0;fd=Ec>>4;if(fd>>>0>255>>>0){Md=(Ec>>31^255)&255}else{Md=fd&255}a[Dc+(Zb+Bb)|0]=Md;Bb=Bb+1|0;}while((Bb|0)<(Lb|0))}Lc=Lc+1|0;}while((Lc|0)<(Ob|0))}if(mb){Ya=385}else{if((vb-1|0)==(Ia|0)){Ya=385}}do{if((Ya|0)==385){Ya=0;if(!Ea){if((Ub-1|0)!=(xa|0)){break}}Lc=mb?Xb:Nb;Rb=Ea?Nb:Ob;Sb=Ea?Ab:Nb;if((Sb|0)>=(Rb|0)){break}Mb=Lc+Fc|0;Qb=(mb?Nb:Lb)-Lc|0;Bb=Sb;do{UGb(Dc+(Mb+(ba(Bb+Gc|0,ed)|0))|0,id+((ba(Bb,ed)|0)+Lc)|0,Qb)|0;Bb=Bb+1|0;}while((Bb|0)<(Rb|0))}}while(0);do{if((Nb|0)==16){id=c[(c[U>>2]|0)+232>>2]|0;if((id|0)==12){Lb=(ba(Gc,ed)|0)+Fc|0;Nd=AYa(ha,Pb+Lb|0,Dc+Lb|0,ed,32)|0;break}else if((id|0)==11){id=(ba(Gc,ed)|0)+Fc|0;Nd=yYa(ha,Pb+id|0,Dc+id|0,ed,32)|0;break}else{id=ba(Gc,ed)|0;Lb=id+Fc|0;Ab=Pe[c[ga>>2]&255](ha,Pb+Lb|0,Dc+Lb|0,ed,16)|0;Lb=Fc+16|0;Ob=Lb+id|0;id=(Pe[c[ga>>2]&255](ha,Pb+Ob|0,Dc+Ob|0,ed,16)|0)+Ab|0;Ab=ba(Gc+16|0,ed)|0;Ob=Ab+Fc|0;Xb=id+(Pe[c[ga>>2]&255](ha,Pb+Ob|0,Dc+Ob|0,ed,16)|0)|0;Ob=Ab+Lb|0;Nd=Xb+(Pe[c[ga>>2]&255](ha,Pb+Ob|0,Dc+Ob|0,ed,16)|0)|0;break}}else{Ob=(ba(Gc,ed)|0)+Fc|0;Nd=Pe[c[ga>>2]&255](ha,Pb+Ob|0,Dc+Ob|0,ed,Cc)|0}}while(0);Cc=aZa(f,Ia,xa,1)|0;ed=(aZa(f,Pa,xa,1)|0)+Cc|0;Cc=ed+(aZa(f,Db,Aa,1)|0)|0;ed=Cc+(aZa(f,Ia,Aa,1)|0)|0;if((vb-2|0)==(Ia|0)){Od=(aZa(f,Pa,Aa,1)|0)+ed|0}else{Od=ed}ed=(ba(Od,Ld)|0)+Nd|0;if((ed|0)<(Dd|0)){Id=0;Jd=0;Kd=ed;break}b[Tb>>1]=b[na>>1]|0;b[Tb+2>>1]=b[na+2>>1]|0;b[Tb+4>>1]=b[na+4>>1]|0;b[Tb+6>>1]=b[na+6>>1]|0;b[Tb+8>>1]=b[na+8>>1]|0;Id=0;Jd=0;Kd=Dd}}while(0);b:while(1){ed=c[(c[U>>2]|0)+248>>2]|0;Cc=(ed|0)>1?ed:1;ed=Id;Dc=Jd;while(1){if((Dc|0)<(Cc|0)){break}if((ed|0)==0){Pd=0;Qd=0;Rd=Kd;break b}else{ed=0;Dc=0}}if((Dc|0)>0){Cc=Kd;Tb=0;vb=ed;while(1){Pb=Dc-Tb<<2;Fc=(b[_a>>1]|0)+Pb|0;Gc=Tb<<2;Nb=(b[ab>>1]|0)+Gc|0;Ob=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Xb=c[T>>2]|0;Lb=Xb+(Ob*10|0)|0;Ab=Lb;b[w>>1]=b[Ab>>1]|0;b[w+2>>1]=b[Ab+2>>1]|0;b[w+4>>1]=b[Ab+4>>1]|0;b[w+6>>1]=b[Ab+6>>1]|0;b[w+8>>1]=b[Ab+8>>1]|0;id=(Nb<<6)+(Fc>>10)+(c[Z>>2]|0)+(d[Xb+(Ob*10|0)+4|0]<<12)|0;Ub=f+2139664+(((Nb*31|0)+Fc&1023)<<2)|0;do{if((c[Ub>>2]|0)==(id|0)){Sd=0;Td=Cc}else{c[Ub>>2]=id;b[Lb>>1]=Fc;b[Xb+(Ob*10|0)+2>>1]=Nb;Rb=Xb+(Ob*10|0)+8|0;a[Rb]=a[Rb]&-2;Rb=c[N>>2]|0;Bb=16>>>(Rb>>>0);Qb=Bb<<1;Lc=c[X>>2]|0;Mb=c[Lc+32>>2]|0;Sb=c[Lc>>2]|0;Lc=c[c[V>>2]>>2]|0;Zb=c[E>>2]|0;dd=c[ca>>2]|0;Vb=c[L>>2]<<Rb;fd=c[Q>>2]<<Rb;Rb=c[R>>2]|0;Ec=c[_>>2]|0;hd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Ud=(hd*3|0)>>8;break};case 11:{Ud=hd>>5;break};case 12:{Ud=hd>>6;break};case 2:case 14:{Ud=hd>>6;break};case 6:case 4:case 1:case 10:{Ud=c[fa>>2]>>7;break};case 5:{Ud=1;break};default:{Ud=hd>>7}}hd=(Bb|0)/2|0;Yb=(ba(Bb,Ia)|0)-hd|0;gd=(ba(Bb,xa)|0)-hd|0;hd=(Yb|0)>0?0:-Yb|0;jd=(gd|0)>0?0:-gd|0;kd=Rb-Yb|0;Vd=(Qb|0)>(kd|0)?kd:Qb;kd=Ec-gd|0;Wd=(Qb|0)>(kd|0)?kd:Qb;kd=(ba(Vb,xa)|0)+Ia|0;Iob(f,dd,c[da>>2]|0,Mb,Yb,gd,Qb,Qb,(c[T>>2]|0)+(kd*10|0)|0,0,Rb,Ec);if((jd|0)<(Wd|0)){Ec=(hd|0)<(Vd|0);Rb=jd;do{kd=ba(Rb,Qb)|0;Xd=ba(Rb,Mb)|0;Yd=(ba(Rb+gd|0,Mb)|0)+Yb|0;if(Ec){Zd=hd;do{_d=((ba(d[I+(Rb<<5)+Zd|0]|0,d[dd+(Zd+Xd)|0]|0)|0)+8|0)>>>4;$d=_d+(b[Zb+(Zd+kd<<1)>>1]|0)|0;_d=$d>>4;if(_d>>>0>255>>>0){ae=($d>>31^255)&255}else{ae=_d&255}a[Sb+(Yd+Zd)|0]=ae;Zd=Zd+1|0;}while((Zd|0)<(Vd|0))}Rb=Rb+1|0;}while((Rb|0)<(Wd|0))}if(mb){Ya=420}else{if((Vb-1|0)==(Ia|0)){Ya=420}}do{if((Ya|0)==420){Ya=0;if(!Ea){if((fd-1|0)!=(xa|0)){break}}Rb=mb?hd:Bb;Zb=Ea?Bb:Wd;Ec=Ea?jd:Bb;if((Ec|0)>=(Zb|0)){break}Zd=Rb+Yb|0;Yd=(mb?Bb:Vd)-Rb|0;kd=Ec;do{UGb(Sb+(Zd+(ba(kd+gd|0,Mb)|0))|0,dd+((ba(kd,Mb)|0)+Rb)|0,Yd)|0;kd=kd+1|0;}while((kd|0)<(Zb|0))}}while(0);do{if((Bb|0)==16){dd=c[(c[U>>2]|0)+232>>2]|0;if((dd|0)==12){Vd=(ba(gd,Mb)|0)+Yb|0;be=AYa(ha,Lc+Vd|0,Sb+Vd|0,Mb,32)|0;break}else if((dd|0)==11){dd=(ba(gd,Mb)|0)+Yb|0;be=yYa(ha,Lc+dd|0,Sb+dd|0,Mb,32)|0;break}else{dd=ba(gd,Mb)|0;Vd=dd+Yb|0;jd=Pe[c[ga>>2]&255](ha,Lc+Vd|0,Sb+Vd|0,Mb,16)|0;Vd=Yb+16|0;Wd=Vd+dd|0;dd=(Pe[c[ga>>2]&255](ha,Lc+Wd|0,Sb+Wd|0,Mb,16)|0)+jd|0;jd=ba(gd+16|0,Mb)|0;Wd=jd+Yb|0;hd=dd+(Pe[c[ga>>2]&255](ha,Lc+Wd|0,Sb+Wd|0,Mb,16)|0)|0;Wd=jd+Vd|0;be=hd+(Pe[c[ga>>2]&255](ha,Lc+Wd|0,Sb+Wd|0,Mb,16)|0)|0;break}}else{Wd=(ba(gd,Mb)|0)+Yb|0;be=Pe[c[ga>>2]&255](ha,Lc+Wd|0,Sb+Wd|0,Mb,Qb)|0}}while(0);Qb=aZa(f,Ia,xa,1)|0;Mb=(aZa(f,Pa,xa,1)|0)+Qb|0;Qb=Mb+(aZa(f,Db,Aa,1)|0)|0;Mb=Qb+(aZa(f,Ia,Aa,1)|0)|0;if((Vb-2|0)==(Ia|0)){ce=(aZa(f,Pa,Aa,1)|0)+Mb|0}else{ce=Mb}Mb=(ba(ce,Ud)|0)+be|0;if((Mb|0)<(Cc|0)){Sd=1;Td=Mb;break}b[Ab>>1]=b[w>>1]|0;b[Ab+2>>1]=b[w+2>>1]|0;b[Ab+4>>1]=b[w+4>>1]|0;b[Ab+6>>1]=b[w+6>>1]|0;b[Ab+8>>1]=b[w+8>>1]|0;Sd=0;Td=Cc}}while(0);Ab=Sd|vb;Ob=(b[_a>>1]|0)-Pb|0;Xb=(b[ab>>1]|0)-Gc|0;Nb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Fc=c[T>>2]|0;Lb=Fc+(Nb*10|0)|0;id=Lb;b[v>>1]=b[id>>1]|0;b[v+2>>1]=b[id+2>>1]|0;b[v+4>>1]=b[id+4>>1]|0;b[v+6>>1]=b[id+6>>1]|0;b[v+8>>1]=b[id+8>>1]|0;Ub=(Xb<<6)+(Ob>>10)+(c[Z>>2]|0)+(d[Fc+(Nb*10|0)+4|0]<<12)|0;Mb=f+2139664+(((Xb*31|0)+Ob&1023)<<2)|0;do{if((c[Mb>>2]|0)==(Ub|0)){de=0;ee=Td}else{c[Mb>>2]=Ub;b[Lb>>1]=Ob;b[Fc+(Nb*10|0)+2>>1]=Xb;Qb=Fc+(Nb*10|0)+8|0;a[Qb]=a[Qb]&-2;Qb=c[N>>2]|0;Sb=16>>>(Qb>>>0);Lc=Sb<<1;Yb=c[X>>2]|0;gd=c[Yb+32>>2]|0;Bb=c[Yb>>2]|0;Yb=c[c[V>>2]>>2]|0;Wd=c[E>>2]|0;hd=c[ca>>2]|0;Vd=c[L>>2]<<Qb;jd=c[Q>>2]<<Qb;Qb=c[R>>2]|0;dd=c[_>>2]|0;fd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{fe=(fd*3|0)>>8;break};case 11:{fe=fd>>5;break};case 12:{fe=fd>>6;break};case 2:case 14:{fe=fd>>6;break};case 6:case 4:case 1:case 10:{fe=c[fa>>2]>>7;break};case 5:{fe=1;break};default:{fe=fd>>7}}fd=(Sb|0)/2|0;Zb=(ba(Sb,Ia)|0)-fd|0;kd=(ba(Sb,xa)|0)-fd|0;fd=(Zb|0)>0?0:-Zb|0;Yd=(kd|0)>0?0:-kd|0;Rb=Qb-Zb|0;Zd=(Lc|0)>(Rb|0)?Rb:Lc;Rb=dd-kd|0;Ec=(Lc|0)>(Rb|0)?Rb:Lc;Rb=(ba(Vd,xa)|0)+Ia|0;Iob(f,hd,c[da>>2]|0,gd,Zb,kd,Lc,Lc,(c[T>>2]|0)+(Rb*10|0)|0,0,Qb,dd);if((Yd|0)<(Ec|0)){dd=(fd|0)<(Zd|0);Qb=Yd;do{Rb=ba(Qb,Lc)|0;Xd=ba(Qb,gd)|0;_d=(ba(Qb+kd|0,gd)|0)+Zb|0;if(dd){$d=fd;do{ge=((ba(d[I+(Qb<<5)+$d|0]|0,d[hd+($d+Xd)|0]|0)|0)+8|0)>>>4;he=ge+(b[Wd+($d+Rb<<1)>>1]|0)|0;ge=he>>4;if(ge>>>0>255>>>0){ie=(he>>31^255)&255}else{ie=ge&255}a[Bb+(_d+$d)|0]=ie;$d=$d+1|0;}while(($d|0)<(Zd|0))}Qb=Qb+1|0;}while((Qb|0)<(Ec|0))}if(mb){Ya=452}else{if((Vd-1|0)==(Ia|0)){Ya=452}}do{if((Ya|0)==452){Ya=0;if(!Ea){if((jd-1|0)!=(xa|0)){break}}Qb=mb?fd:Sb;Wd=Ea?Sb:Ec;dd=Ea?Yd:Sb;if((dd|0)>=(Wd|0)){break}Vb=Qb+Zb|0;$d=(mb?Sb:Zd)-Qb|0;_d=dd;do{UGb(Bb+(Vb+(ba(_d+kd|0,gd)|0))|0,hd+((ba(_d,gd)|0)+Qb)|0,$d)|0;_d=_d+1|0;}while((_d|0)<(Wd|0))}}while(0);do{if((Sb|0)==16){hd=c[(c[U>>2]|0)+232>>2]|0;if((hd|0)==12){Zd=(ba(kd,gd)|0)+Zb|0;je=AYa(ha,Yb+Zd|0,Bb+Zd|0,gd,32)|0;break}else if((hd|0)==11){hd=(ba(kd,gd)|0)+Zb|0;je=yYa(ha,Yb+hd|0,Bb+hd|0,gd,32)|0;break}else{hd=ba(kd,gd)|0;Zd=hd+Zb|0;Yd=Pe[c[ga>>2]&255](ha,Yb+Zd|0,Bb+Zd|0,gd,16)|0;Zd=Zb+16|0;Ec=Zd+hd|0;hd=(Pe[c[ga>>2]&255](ha,Yb+Ec|0,Bb+Ec|0,gd,16)|0)+Yd|0;Yd=ba(kd+16|0,gd)|0;Ec=Yd+Zb|0;fd=hd+(Pe[c[ga>>2]&255](ha,Yb+Ec|0,Bb+Ec|0,gd,16)|0)|0;Ec=Yd+Zd|0;je=fd+(Pe[c[ga>>2]&255](ha,Yb+Ec|0,Bb+Ec|0,gd,16)|0)|0;break}}else{Ec=(ba(kd,gd)|0)+Zb|0;je=Pe[c[ga>>2]&255](ha,Yb+Ec|0,Bb+Ec|0,gd,Lc)|0}}while(0);Lc=aZa(f,Ia,xa,1)|0;gd=(aZa(f,Pa,xa,1)|0)+Lc|0;Lc=gd+(aZa(f,Db,Aa,1)|0)|0;gd=Lc+(aZa(f,Ia,Aa,1)|0)|0;if((Vd-2|0)==(Ia|0)){ke=(aZa(f,Pa,Aa,1)|0)+gd|0}else{ke=gd}gd=(ba(ke,fe)|0)+je|0;if((gd|0)<(Td|0)){de=1;ee=gd;break}b[id>>1]=b[v>>1]|0;b[id+2>>1]=b[v+2>>1]|0;b[id+4>>1]=b[v+4>>1]|0;b[id+6>>1]=b[v+6>>1]|0;b[id+8>>1]=b[v+8>>1]|0;de=0;ee=Td}}while(0);id=Ab|de;Nb=(b[_a>>1]|0)+Pb|0;Fc=(b[ab>>1]|0)-Gc|0;Xb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Ob=c[T>>2]|0;Lb=Ob+(Xb*10|0)|0;Ub=Lb;b[u>>1]=b[Ub>>1]|0;b[u+2>>1]=b[Ub+2>>1]|0;b[u+4>>1]=b[Ub+4>>1]|0;b[u+6>>1]=b[Ub+6>>1]|0;b[u+8>>1]=b[Ub+8>>1]|0;Mb=(Fc<<6)+(Nb>>10)+(c[Z>>2]|0)+(d[Ob+(Xb*10|0)+4|0]<<12)|0;gd=f+2139664+(((Fc*31|0)+Nb&1023)<<2)|0;do{if((c[gd>>2]|0)==(Mb|0)){le=0;me=ee}else{c[gd>>2]=Mb;b[Lb>>1]=Nb;b[Ob+(Xb*10|0)+2>>1]=Fc;Lc=Ob+(Xb*10|0)+8|0;a[Lc]=a[Lc]&-2;Lc=c[N>>2]|0;Bb=16>>>(Lc>>>0);Yb=Bb<<1;Zb=c[X>>2]|0;kd=c[Zb+32>>2]|0;Sb=c[Zb>>2]|0;Zb=c[c[V>>2]>>2]|0;Ec=c[E>>2]|0;fd=c[ca>>2]|0;Zd=c[L>>2]<<Lc;Yd=c[Q>>2]<<Lc;Lc=c[R>>2]|0;hd=c[_>>2]|0;jd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{ne=(jd*3|0)>>8;break};case 11:{ne=jd>>5;break};case 12:{ne=jd>>6;break};case 2:case 14:{ne=jd>>6;break};case 6:case 4:case 1:case 10:{ne=c[fa>>2]>>7;break};case 5:{ne=1;break};default:{ne=jd>>7}}jd=(Bb|0)/2|0;Wd=(ba(Bb,Ia)|0)-jd|0;_d=(ba(Bb,xa)|0)-jd|0;jd=(Wd|0)>0?0:-Wd|0;$d=(_d|0)>0?0:-_d|0;Qb=Lc-Wd|0;Vb=(Yb|0)>(Qb|0)?Qb:Yb;Qb=hd-_d|0;dd=(Yb|0)>(Qb|0)?Qb:Yb;Qb=(ba(Zd,xa)|0)+Ia|0;Iob(f,fd,c[da>>2]|0,kd,Wd,_d,Yb,Yb,(c[T>>2]|0)+(Qb*10|0)|0,0,Lc,hd);if(($d|0)<(dd|0)){hd=(jd|0)<(Vb|0);Lc=$d;do{Qb=ba(Lc,Yb)|0;Rb=ba(Lc,kd)|0;Xd=(ba(Lc+_d|0,kd)|0)+Wd|0;if(hd){ge=jd;do{he=((ba(d[I+(Lc<<5)+ge|0]|0,d[fd+(ge+Rb)|0]|0)|0)+8|0)>>>4;oe=he+(b[Ec+(ge+Qb<<1)>>1]|0)|0;he=oe>>4;if(he>>>0>255>>>0){pe=(oe>>31^255)&255}else{pe=he&255}a[Sb+(Xd+ge)|0]=pe;ge=ge+1|0;}while((ge|0)<(Vb|0))}Lc=Lc+1|0;}while((Lc|0)<(dd|0))}if(mb){Ya=484}else{if((Zd-1|0)==(Ia|0)){Ya=484}}do{if((Ya|0)==484){Ya=0;if(!Ea){if((Yd-1|0)!=(xa|0)){break}}Lc=mb?jd:Bb;Ec=Ea?Bb:dd;hd=Ea?$d:Bb;if((hd|0)>=(Ec|0)){break}Vd=Lc+Wd|0;ge=(mb?Bb:Vb)-Lc|0;Xd=hd;do{UGb(Sb+(Vd+(ba(Xd+_d|0,kd)|0))|0,fd+((ba(Xd,kd)|0)+Lc)|0,ge)|0;Xd=Xd+1|0;}while((Xd|0)<(Ec|0))}}while(0);do{if((Bb|0)==16){fd=c[(c[U>>2]|0)+232>>2]|0;if((fd|0)==12){Vb=(ba(_d,kd)|0)+Wd|0;qe=AYa(ha,Zb+Vb|0,Sb+Vb|0,kd,32)|0;break}else if((fd|0)==11){fd=(ba(_d,kd)|0)+Wd|0;qe=yYa(ha,Zb+fd|0,Sb+fd|0,kd,32)|0;break}else{fd=ba(_d,kd)|0;Vb=fd+Wd|0;$d=Pe[c[ga>>2]&255](ha,Zb+Vb|0,Sb+Vb|0,kd,16)|0;Vb=Wd+16|0;dd=Vb+fd|0;fd=(Pe[c[ga>>2]&255](ha,Zb+dd|0,Sb+dd|0,kd,16)|0)+$d|0;$d=ba(_d+16|0,kd)|0;dd=$d+Wd|0;jd=fd+(Pe[c[ga>>2]&255](ha,Zb+dd|0,Sb+dd|0,kd,16)|0)|0;dd=$d+Vb|0;qe=jd+(Pe[c[ga>>2]&255](ha,Zb+dd|0,Sb+dd|0,kd,16)|0)|0;break}}else{dd=(ba(_d,kd)|0)+Wd|0;qe=Pe[c[ga>>2]&255](ha,Zb+dd|0,Sb+dd|0,kd,Yb)|0}}while(0);Yb=aZa(f,Ia,xa,1)|0;kd=(aZa(f,Pa,xa,1)|0)+Yb|0;Yb=kd+(aZa(f,Db,Aa,1)|0)|0;kd=Yb+(aZa(f,Ia,Aa,1)|0)|0;if((Zd-2|0)==(Ia|0)){re=(aZa(f,Pa,Aa,1)|0)+kd|0}else{re=kd}kd=(ba(re,ne)|0)+qe|0;if((kd|0)<(ee|0)){le=1;me=kd;break}b[Ub>>1]=b[u>>1]|0;b[Ub+2>>1]=b[u+2>>1]|0;b[Ub+4>>1]=b[u+4>>1]|0;b[Ub+6>>1]=b[u+6>>1]|0;b[Ub+8>>1]=b[u+8>>1]|0;le=0;me=ee}}while(0);Ub=id|le;Xb=(b[_a>>1]|0)-Pb|0;Ob=(b[ab>>1]|0)+Gc|0;Fc=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Nb=c[T>>2]|0;Lb=Nb+(Fc*10|0)|0;Mb=Lb;b[t>>1]=b[Mb>>1]|0;b[t+2>>1]=b[Mb+2>>1]|0;b[t+4>>1]=b[Mb+4>>1]|0;b[t+6>>1]=b[Mb+6>>1]|0;b[t+8>>1]=b[Mb+8>>1]|0;gd=(Ob<<6)+(Xb>>10)+(c[Z>>2]|0)+(d[Nb+(Fc*10|0)+4|0]<<12)|0;Ab=f+2139664+(((Ob*31|0)+Xb&1023)<<2)|0;do{if((c[Ab>>2]|0)==(gd|0)){se=0;te=me}else{c[Ab>>2]=gd;b[Lb>>1]=Xb;b[Nb+(Fc*10|0)+2>>1]=Ob;kd=Nb+(Fc*10|0)+8|0;a[kd]=a[kd]&-2;kd=c[N>>2]|0;Yb=16>>>(kd>>>0);Sb=Yb<<1;Zb=c[X>>2]|0;Wd=c[Zb+32>>2]|0;_d=c[Zb>>2]|0;Zb=c[c[V>>2]>>2]|0;Bb=c[E>>2]|0;dd=c[ca>>2]|0;jd=c[L>>2]<<kd;Vb=c[Q>>2]<<kd;kd=c[R>>2]|0;$d=c[_>>2]|0;fd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{ue=(fd*3|0)>>8;break};case 11:{ue=fd>>5;break};case 12:{ue=fd>>6;break};case 2:case 14:{ue=fd>>6;break};case 6:case 4:case 1:case 10:{ue=c[fa>>2]>>7;break};case 5:{ue=1;break};default:{ue=fd>>7}}fd=(Yb|0)/2|0;Yd=(ba(Yb,Ia)|0)-fd|0;Ec=(ba(Yb,xa)|0)-fd|0;fd=(Yd|0)>0?0:-Yd|0;Xd=(Ec|0)>0?0:-Ec|0;ge=kd-Yd|0;Lc=(Sb|0)>(ge|0)?ge:Sb;ge=$d-Ec|0;Vd=(Sb|0)>(ge|0)?ge:Sb;ge=(ba(jd,xa)|0)+Ia|0;Iob(f,dd,c[da>>2]|0,Wd,Yd,Ec,Sb,Sb,(c[T>>2]|0)+(ge*10|0)|0,0,kd,$d);if((Xd|0)<(Vd|0)){$d=(fd|0)<(Lc|0);kd=Xd;do{ge=ba(kd,Sb)|0;hd=ba(kd,Wd)|0;Qb=(ba(kd+Ec|0,Wd)|0)+Yd|0;if($d){Rb=fd;do{he=((ba(d[I+(kd<<5)+Rb|0]|0,d[dd+(Rb+hd)|0]|0)|0)+8|0)>>>4;oe=he+(b[Bb+(Rb+ge<<1)>>1]|0)|0;he=oe>>4;if(he>>>0>255>>>0){ve=(oe>>31^255)&255}else{ve=he&255}a[_d+(Qb+Rb)|0]=ve;Rb=Rb+1|0;}while((Rb|0)<(Lc|0))}kd=kd+1|0;}while((kd|0)<(Vd|0))}if(mb){Ya=516}else{if((jd-1|0)==(Ia|0)){Ya=516}}do{if((Ya|0)==516){Ya=0;if(!Ea){if((Vb-1|0)!=(xa|0)){break}}kd=mb?fd:Yb;Bb=Ea?Yb:Vd;$d=Ea?Xd:Yb;if(($d|0)>=(Bb|0)){break}Zd=kd+Yd|0;Rb=(mb?Yb:Lc)-kd|0;Qb=$d;do{UGb(_d+(Zd+(ba(Qb+Ec|0,Wd)|0))|0,dd+((ba(Qb,Wd)|0)+kd)|0,Rb)|0;Qb=Qb+1|0;}while((Qb|0)<(Bb|0))}}while(0);do{if((Yb|0)==16){dd=c[(c[U>>2]|0)+232>>2]|0;if((dd|0)==12){Lc=(ba(Ec,Wd)|0)+Yd|0;we=AYa(ha,Zb+Lc|0,_d+Lc|0,Wd,32)|0;break}else if((dd|0)==11){dd=(ba(Ec,Wd)|0)+Yd|0;we=yYa(ha,Zb+dd|0,_d+dd|0,Wd,32)|0;break}else{dd=ba(Ec,Wd)|0;Lc=dd+Yd|0;Xd=Pe[c[ga>>2]&255](ha,Zb+Lc|0,_d+Lc|0,Wd,16)|0;Lc=Yd+16|0;Vd=Lc+dd|0;dd=(Pe[c[ga>>2]&255](ha,Zb+Vd|0,_d+Vd|0,Wd,16)|0)+Xd|0;Xd=ba(Ec+16|0,Wd)|0;Vd=Xd+Yd|0;fd=dd+(Pe[c[ga>>2]&255](ha,Zb+Vd|0,_d+Vd|0,Wd,16)|0)|0;Vd=Xd+Lc|0;we=fd+(Pe[c[ga>>2]&255](ha,Zb+Vd|0,_d+Vd|0,Wd,16)|0)|0;break}}else{Vd=(ba(Ec,Wd)|0)+Yd|0;we=Pe[c[ga>>2]&255](ha,Zb+Vd|0,_d+Vd|0,Wd,Sb)|0}}while(0);Sb=aZa(f,Ia,xa,1)|0;Wd=(aZa(f,Pa,xa,1)|0)+Sb|0;Sb=Wd+(aZa(f,Db,Aa,1)|0)|0;Wd=Sb+(aZa(f,Ia,Aa,1)|0)|0;if((jd-2|0)==(Ia|0)){xe=(aZa(f,Pa,Aa,1)|0)+Wd|0}else{xe=Wd}Wd=(ba(xe,ue)|0)+we|0;if((Wd|0)<(me|0)){se=1;te=Wd;break}b[Mb>>1]=b[t>>1]|0;b[Mb+2>>1]=b[t+2>>1]|0;b[Mb+4>>1]=b[t+4>>1]|0;b[Mb+6>>1]=b[t+6>>1]|0;b[Mb+8>>1]=b[t+8>>1]|0;se=0;te=me}}while(0);Mb=Ub|se;Fc=Tb+1|0;if((Fc|0)<(Dc|0)){Cc=te;Tb=Fc;vb=Mb}else{ye=te;ze=Mb;break}}}else{ye=Kd;ze=ed}Id=ze;Jd=Dc+1|0;Kd=ye}c:while(1){vb=Pd;Tb=Qd;while(1){if((Tb|0)<8){break}if((vb|0)==0){break c}else{vb=0;Tb=0}}Dc=(b[_a>>1]|0)+(c[900968+(Tb<<3)>>2]|0)|0;ed=(b[ab>>1]|0)+(c[900972+(Tb<<3)>>2]|0)|0;Cc=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Mb=c[T>>2]|0;Fc=Mb+(Cc*10|0)|0;Nb=Fc;b[s>>1]=b[Nb>>1]|0;b[s+2>>1]=b[Nb+2>>1]|0;b[s+4>>1]=b[Nb+4>>1]|0;b[s+6>>1]=b[Nb+6>>1]|0;b[s+8>>1]=b[Nb+8>>1]|0;Ob=(ed<<6)+(Dc>>10)+(c[Z>>2]|0)+(d[Mb+(Cc*10|0)+4|0]<<12)|0;Xb=f+2139664+(((ed*31|0)+Dc&1023)<<2)|0;do{if((c[Xb>>2]|0)==(Ob|0)){Ae=0;Be=Rd}else{c[Xb>>2]=Ob;b[Fc>>1]=Dc;b[Mb+(Cc*10|0)+2>>1]=ed;Lb=Mb+(Cc*10|0)+8|0;a[Lb]=a[Lb]&-2;Lb=c[N>>2]|0;gd=16>>>(Lb>>>0);Ab=gd<<1;Gc=c[X>>2]|0;Pb=c[Gc+32>>2]|0;id=c[Gc>>2]|0;Gc=c[c[V>>2]>>2]|0;Wd=c[E>>2]|0;Sb=c[ca>>2]|0;_d=c[L>>2]<<Lb;Zb=c[Q>>2]<<Lb;Lb=c[R>>2]|0;Yd=c[_>>2]|0;Ec=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Ce=(Ec*3|0)>>8;break};case 11:{Ce=Ec>>5;break};case 12:{Ce=Ec>>6;break};case 2:case 14:{Ce=Ec>>6;break};case 6:case 4:case 1:case 10:{Ce=c[fa>>2]>>7;break};case 5:{Ce=1;break};default:{Ce=Ec>>7}}Ec=(gd|0)/2|0;Yb=(ba(gd,Ia)|0)-Ec|0;Vd=(ba(gd,xa)|0)-Ec|0;Ec=(Yb|0)>0?0:-Yb|0;fd=(Vd|0)>0?0:-Vd|0;Lc=Lb-Yb|0;Xd=(Ab|0)>(Lc|0)?Lc:Ab;Lc=Yd-Vd|0;dd=(Ab|0)>(Lc|0)?Lc:Ab;Lc=(ba(_d,xa)|0)+Ia|0;Iob(f,Sb,c[da>>2]|0,Pb,Yb,Vd,Ab,Ab,(c[T>>2]|0)+(Lc*10|0)|0,0,Lb,Yd);if((fd|0)<(dd|0)){Yd=(Ec|0)<(Xd|0);Lb=fd;do{Lc=ba(Lb,Ab)|0;Vb=ba(Lb,Pb)|0;Bb=(ba(Lb+Vd|0,Pb)|0)+Yb|0;if(Yd){Qb=Ec;do{Rb=((ba(d[I+(Lb<<5)+Qb|0]|0,d[Sb+(Qb+Vb)|0]|0)|0)+8|0)>>>4;kd=Rb+(b[Wd+(Qb+Lc<<1)>>1]|0)|0;Rb=kd>>4;if(Rb>>>0>255>>>0){De=(kd>>31^255)&255}else{De=Rb&255}a[id+(Bb+Qb)|0]=De;Qb=Qb+1|0;}while((Qb|0)<(Xd|0))}Lb=Lb+1|0;}while((Lb|0)<(dd|0))}if(mb){Ya=553}else{if((_d-1|0)==(Ia|0)){Ya=553}}do{if((Ya|0)==553){Ya=0;if(!Ea){if((Zb-1|0)!=(xa|0)){break}}Lb=mb?Ec:gd;Wd=Ea?gd:dd;Yd=Ea?fd:gd;if((Yd|0)>=(Wd|0)){break}Ub=Lb+Yb|0;Qb=(mb?gd:Xd)-Lb|0;Bb=Yd;do{UGb(id+(Ub+(ba(Bb+Vd|0,Pb)|0))|0,Sb+((ba(Bb,Pb)|0)+Lb)|0,Qb)|0;Bb=Bb+1|0;}while((Bb|0)<(Wd|0))}}while(0);do{if((gd|0)==16){Sb=c[(c[U>>2]|0)+232>>2]|0;if((Sb|0)==12){Xd=(ba(Vd,Pb)|0)+Yb|0;Ee=AYa(ha,Gc+Xd|0,id+Xd|0,Pb,32)|0;break}else if((Sb|0)==11){Sb=(ba(Vd,Pb)|0)+Yb|0;Ee=yYa(ha,Gc+Sb|0,id+Sb|0,Pb,32)|0;break}else{Sb=ba(Vd,Pb)|0;Xd=Sb+Yb|0;fd=Pe[c[ga>>2]&255](ha,Gc+Xd|0,id+Xd|0,Pb,16)|0;Xd=Yb+16|0;dd=Xd+Sb|0;Sb=(Pe[c[ga>>2]&255](ha,Gc+dd|0,id+dd|0,Pb,16)|0)+fd|0;fd=ba(Vd+16|0,Pb)|0;dd=fd+Yb|0;Ec=Sb+(Pe[c[ga>>2]&255](ha,Gc+dd|0,id+dd|0,Pb,16)|0)|0;dd=fd+Xd|0;Ee=Ec+(Pe[c[ga>>2]&255](ha,Gc+dd|0,id+dd|0,Pb,16)|0)|0;break}}else{dd=(ba(Vd,Pb)|0)+Yb|0;Ee=Pe[c[ga>>2]&255](ha,Gc+dd|0,id+dd|0,Pb,Ab)|0}}while(0);Ab=aZa(f,Ia,xa,1)|0;Pb=(aZa(f,Pa,xa,1)|0)+Ab|0;Ab=Pb+(aZa(f,Db,Aa,1)|0)|0;Pb=Ab+(aZa(f,Ia,Aa,1)|0)|0;if((_d-2|0)==(Ia|0)){Fe=(aZa(f,Pa,Aa,1)|0)+Pb|0}else{Fe=Pb}Pb=(ba(Fe,Ce)|0)+Ee|0;if((Pb|0)<(Rd|0)){Ae=1;Be=Pb;break}b[Nb>>1]=b[s>>1]|0;b[Nb+2>>1]=b[s+2>>1]|0;b[Nb+4>>1]=b[s+4>>1]|0;b[Nb+6>>1]=b[s+6>>1]|0;b[Nb+8>>1]=b[s+8>>1]|0;Ae=0;Be=Rd}}while(0);Pd=Ae|vb;Qd=Tb+1|0;Rd=Be}b[lb>>1]=b[_a>>1]|0;b[Kb>>1]=b[ab>>1]|0;if((Wb|0)<=(Rd|0)){_c=Wb;$c=Hb;ad=Gb;break}Nb=e[Jb>>1]|e[Jb+2>>1]<<16;Cc=a[cb]|0;a[D]=a[eb]|0;a[D+1|0]=a[eb+1|0]|0;a[D+2|0]=a[eb+2|0]|0;a[D+3|0]=a[eb+3|0]|0;a[D+4|0]=a[eb+4|0]|0;_c=Rd;$c=Cc;ad=Nb}}while(0);pb=jb+1|0;if((pb|0)<(c[H>>2]|0)){Gb=ad;Hb=$c;Wb=_c;jb=pb}else{Ge=ad;He=$c;Ie=_c;break}}}else{Ge=Eb;He=sb;Ie=Vc}x=Ge;b[Jb>>1]=x;b[Jb+2>>1]=x>>16;a[cb]=He;a[eb]=a[D]|0;a[eb+1|0]=a[D+1|0]|0;a[eb+2|0]=a[D+2|0]|0;a[eb+3|0]=a[D+3|0]|0;a[eb+4|0]=a[D+4|0]|0;jb=(ba(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Wb=c[T>>2]|0;Hb=Wb+(jb*10|0)|0;b[ka>>1]=b[Hb>>1]|0;b[ka+2>>1]=b[Hb+2>>1]|0;b[ka+4>>1]=b[Hb+4>>1]|0;b[ka+6>>1]=b[Hb+6>>1]|0;b[ka+8>>1]=b[Hb+8>>1]|0;a[Wb+(jb*10|0)+5|0]=c[ja>>2];a[Wb+(jb*10|0)+6|0]=c[q>>2];a[Wb+(jb*10|0)+7|0]=c[la>>2];Gb=Wb+(jb*10|0)+8|0;a[Gb]=a[Gb]|1;Gb=c[N>>2]|0;jb=16>>>(Gb>>>0);Wb=jb<<1;Db=c[X>>2]|0;Cb=c[Db+32>>2]|0;rb=c[Db>>2]|0;Db=c[c[V>>2]>>2]|0;ob=c[E>>2]|0;Na=c[ca>>2]|0;tb=c[L>>2]<<Gb;ub=c[Q>>2]<<Gb;Gb=c[R>>2]|0;kb=c[_>>2]|0;nb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Je=(nb*3|0)>>8;break};case 11:{Je=nb>>5;break};case 12:{Je=nb>>6;break};case 2:case 14:{Je=nb>>6;break};case 6:case 4:case 1:case 10:{Je=c[fa>>2]>>7;break};case 5:{Je=1;break};default:{Je=nb>>7}}nb=(jb|0)/2|0;Ja=(ba(jb,Ia)|0)-nb|0;La=(ba(jb,xa)|0)-nb|0;nb=(Ja|0)>0?0:-Ja|0;pb=(La|0)>0?0:-La|0;Fb=Gb-Ja|0;Ib=(Wb|0)>(Fb|0)?Fb:Wb;Fb=kb-La|0;Nb=(Wb|0)>(Fb|0)?Fb:Wb;Fb=(ba(tb,xa)|0)+Ia|0;Iob(f,Na,c[da>>2]|0,Cb,Ja,La,Wb,Wb,(c[T>>2]|0)+(Fb*10|0)|0,0,Gb,kb);if((pb|0)<(Nb|0)){kb=(nb|0)<(Ib|0);Gb=pb;do{Fb=ba(Gb,Wb)|0;Cc=ba(Gb,Cb)|0;Mb=(ba(Gb+La|0,Cb)|0)+Ja|0;if(kb){ed=nb;do{Dc=((ba(d[I+(Gb<<5)+ed|0]|0,d[Na+(ed+Cc)|0]|0)|0)+8|0)>>>4;Fc=Dc+(b[ob+(ed+Fb<<1)>>1]|0)|0;Dc=Fc>>4;if(Dc>>>0>255>>>0){Ke=(Fc>>31^255)&255}else{Ke=Dc&255}a[rb+(Mb+ed)|0]=Ke;ed=ed+1|0;}while((ed|0)<(Ib|0))}Gb=Gb+1|0;}while((Gb|0)<(Nb|0))}if(mb){Ya=589}else{if((tb-1|0)==(Ia|0)){Ya=589}}do{if((Ya|0)==589){Ya=0;if(!Ea){if((ub-1|0)!=(xa|0)){break}}Gb=mb?nb:jb;ob=Ea?jb:Nb;kb=Ea?pb:jb;if((kb|0)>=(ob|0)){break}Jb=Gb+Ja|0;sb=(mb?jb:Ib)-Gb|0;Eb=kb;do{UGb(rb+(Jb+(ba(Eb+La|0,Cb)|0))|0,Na+((ba(Eb,Cb)|0)+Gb)|0,sb)|0;Eb=Eb+1|0;}while((Eb|0)<(ob|0))}}while(0);do{if((jb|0)==16){Na=c[(c[U>>2]|0)+232>>2]|0;if((Na|0)==12){Ib=(ba(La,Cb)|0)+Ja|0;Le=AYa(ha,Db+Ib|0,rb+Ib|0,Cb,32)|0;break}else if((Na|0)==11){Na=(ba(La,Cb)|0)+Ja|0;Le=yYa(ha,Db+Na|0,rb+Na|0,Cb,32)|0;break}else{Na=ba(La,Cb)|0;Ib=Na+Ja|0;mb=Pe[c[ga>>2]&255](ha,Db+Ib|0,rb+Ib|0,Cb,16)|0;Ib=Ja+16|0;pb=Ib+Na|0;Na=(Pe[c[ga>>2]&255](ha,Db+pb|0,rb+pb|0,Cb,16)|0)+mb|0;mb=ba(La+16|0,Cb)|0;pb=mb+Ja|0;Nb=Na+(Pe[c[ga>>2]&255](ha,Db+pb|0,rb+pb|0,Cb,16)|0)|0;pb=mb+Ib|0;Le=Nb+(Pe[c[ga>>2]&255](ha,Db+pb|0,rb+pb|0,Cb,16)|0)|0;break}}else{pb=(ba(La,Cb)|0)+Ja|0;Le=Pe[c[ga>>2]&255](ha,Db+pb|0,rb+pb|0,Cb,Wb)|0}}while(0);Wb=aZa(f,Ia,xa,1)|0;Cb=(aZa(f,Pa,xa,1)|0)+Wb|0;Wb=Cb+(aZa(f,Ia-1|0,Aa,1)|0)|0;Cb=Wb+(aZa(f,Ia,Aa,1)|0)|0;if((tb-2|0)==(Ia|0)){Me=(aZa(f,Pa,Aa,1)|0)+Cb|0}else{Me=Cb}if(((ba(Me,Je)|0)+Le|0)>=(Ie|0)){b[Hb>>1]=b[ka>>1]|0;b[Hb+2>>1]=b[ka+2>>1]|0;b[Hb+4>>1]=b[ka+4>>1]|0;b[Hb+6>>1]=b[ka+6>>1]|0;b[Hb+8>>1]=b[ka+8>>1]|0}Cb=a[Za]|0;do{if((Cb&1)==0){Ya=607}else{if((Ta&1)==0){Ya=607;break}Ne=(d[gb]|0)-(hb&255)|(d[eb]|0)-(fb&255)|(d[ib]|0)-(Ka&255)}}while(0);if((Ya|0)==607){Ya=0;Ne=(b[_a>>1]|0)-($a<<16>>16)|(Cb^Ta)&1|(b[ab>>1]|0)-(bb<<16>>16)|(d[cb]|0)-(db&255)}if((Ne|0)!=0){break}}if(Qa){Ia=Pa}else{Oe=Ga;Qe=Aa;break a}}if((Ma|0)!=0){Ia=Ma+8|0;a[Ia]=a[Ia]&-3}if((Oa|0)!=0){Ia=Oa+8|0;a[Ia]=a[Ia]&-3}if((Ra|0)!=0){Ia=Ra+8|0;a[Ia]=a[Ia]&-3}if((Sa|0)!=0){Ia=Sa+8|0;a[Ia]=a[Ia]&-3}if((Ua|0)!=0){Ia=Ua+8|0;a[Ia]=a[Ia]&-3}if((Va|0)!=0){Ia=Va+8|0;a[Ia]=a[Ia]&-3}if((Wa|0)!=0){Ia=Wa+8|0;a[Ia]=a[Ia]&-3}if((Xa|0)!=0){Ia=Xa+8|0;a[Ia]=a[Ia]&-3}Ia=Ga+1|0;if(Qa){Ga=Ia;Ha=Pa}else{Oe=Ia;Qe=Aa;break}}}else{Oe=wa;Qe=xa+1|0}}while(0);if((Qe|0)<(S|0)){wa=Oe;xa=Qe}else{Re=Oe;break}}}else{Re=0}yDb(c[U>>2]|0,16,2350552,(Se=i,i=i+16|0,c[Se>>2]=ta,c[Se+8>>2]=Re,Se)|0);i=Se;if((Re|0)==0){break}else{ta=ta+1|0}}if((c[N>>2]|0)!=1){i=g;return}if(K){K=J|0;ta=J+4|0;Re=J+8|0;Oe=J+12|0;Qe=m;m=n;n=o;o=p;p=h;h=j;j=k;k=l;l=0;Pa=0;while(1){if(O){Qa=ba(l,P)|0;Xa=Pa;Wa=0;while(1){Va=Wa+Qa|0;Ua=c[T>>2]|0;Sa=Ua+(Va*10|0)|0;c[K>>2]=Sa;Ra=Va|1;Oa=Ua+(Ra*10|0)|0;c[ta>>2]=Oa;Ma=Va+P|0;Ne=Ua+(Ma*10|0)|0;c[Re>>2]=Ne;ka=Va+qa|0;Ie=Ua+(ka*10|0)|0;c[Oe>>2]=Ie;Le=a[Ua+(Va*10|0)+8|0]|0;Je=(Le&1)==0;Me=a[Ua+(Ra*10|0)+8|0]|0;do{if(Je){Ya=636}else{if((Me&1)==0){Ya=636;break}Te=(d[Ua+(Va*10|0)+6|0]|0)-(d[Ua+(Ra*10|0)+6|0]|0)|(d[Ua+(Va*10|0)+5|0]|0)-(d[Ua+(Ra*10|0)+5|0]|0)|(d[Ua+(Va*10|0)+7|0]|0)-(d[Ua+(Ra*10|0)+7|0]|0)}}while(0);if((Ya|0)==636){Ya=0;Te=(b[Sa>>1]|0)-(b[Oa>>1]|0)|(Me^Le)&1|(b[Ua+(Va*10|0)+2>>1]|0)-(b[Ua+(Ra*10|0)+2>>1]|0)|(d[Ua+(Va*10|0)+4|0]|0)-(d[Ua+(Ra*10|0)+4|0]|0)}do{if((Te|0)==0){ha=a[Ua+(Ma*10|0)+8|0]|0;do{if(Je){Ya=641}else{if((ha&1)==0){Ya=641;break}Ue=(d[Ua+(Va*10|0)+6|0]|0)-(d[Ua+(Ma*10|0)+6|0]|0)|(d[Ua+(Va*10|0)+5|0]|0)-(d[Ua+(Ma*10|0)+5|0]|0)|(d[Ua+(Va*10|0)+7|0]|0)-(d[Ua+(Ma*10|0)+7|0]|0)}}while(0);if((Ya|0)==641){Ya=0;Ue=(b[Sa>>1]|0)-(b[Ne>>1]|0)|(ha^Le)&1|(b[Ua+(Va*10|0)+2>>1]|0)-(b[Ua+(Ma*10|0)+2>>1]|0)|(d[Ua+(Va*10|0)+4|0]|0)-(d[Ua+(Ma*10|0)+4|0]|0)}if((Ue|0)!=0){Ya=648;break}ga=a[Ua+(ka*10|0)+8|0]|0;do{if(Je){Ya=646}else{if((ga&1)==0){Ya=646;break}Ve=(d[Ua+(Va*10|0)+6|0]|0)-(d[Ua+(ka*10|0)+6|0]|0)|(d[Ua+(Va*10|0)+5|0]|0)-(d[Ua+(ka*10|0)+5|0]|0)|(d[Ua+(Va*10|0)+7|0]|0)-(d[Ua+(ka*10|0)+7|0]|0)}}while(0);if((Ya|0)==646){Ya=0;Ve=(b[Sa>>1]|0)-(b[Ie>>1]|0)|(ga^Le)&1|(b[Ua+(Va*10|0)+2>>1]|0)-(b[Ua+(ka*10|0)+2>>1]|0)|(d[Ua+(Va*10|0)+4|0]|0)-(d[Ua+(ka*10|0)+4|0]|0)}if((Ve|0)==0){We=Xa}else{Ya=648}}else{Ya=648}}while(0);if((Ya|0)==648){Ya=0;Le=c[Z>>2]|0;if((Le|0)==0){TGb(M|0,0,4096)|0}c[Z>>2]=Le+4194304;Le=$Ya(f,Wa,l)|0;Je=(b[Sa>>1]|0)+2+(b[Oa>>1]|0)+(b[Ne>>1]|0)+(b[Ie>>1]|0)|0;Me=Je>>2;ha=(b[Ua+(Va*10|0)+2>>1]|0)+2+(b[Ua+(Ra*10|0)+2>>1]|0)+(b[Ua+(Ma*10|0)+2>>1]|0)+(b[Ua+(ka*10|0)+2>>1]|0)>>2;Ke=c[L>>2]<<c[N>>2];I=(ba(Ke,l)|0)+Wa|0;da=c[T>>2]|0;fa=da+(I*10|0)|0;ea=fa;b[Qe>>1]=b[ea>>1]|0;b[Qe+2>>1]=b[ea+2>>1]|0;b[Qe+4>>1]=b[ea+4>>1]|0;b[Qe+6>>1]=b[ea+6>>1]|0;b[Qe+8>>1]=b[ea+8>>1]|0;_=da+((I|1)*10|0)|0;b[m>>1]=b[_>>1]|0;b[m+2>>1]=b[_+2>>1]|0;b[m+4>>1]=b[_+4>>1]|0;b[m+6>>1]=b[_+6>>1]|0;b[m+8>>1]=b[_+8>>1]|0;R=da+((I+Ke|0)*10|0)|0;b[n>>1]=b[R>>1]|0;b[n+2>>1]=b[R+2>>1]|0;b[n+4>>1]=b[R+4>>1]|0;b[n+6>>1]=b[R+6>>1]|0;b[n+8>>1]=b[R+8>>1]|0;Q=da+((Ke+1+I|0)*10|0)|0;b[o>>1]=b[Q>>1]|0;b[o+2>>1]=b[Q+2>>1]|0;b[o+4>>1]=b[Q+4>>1]|0;b[o+6>>1]=b[Q+6>>1]|0;b[o+8>>1]=b[Q+8>>1]|0;Ke=da+(I*10|0)+4|0;ca=(ha<<6)+(Je>>12)+(c[Z>>2]|0)+(d[Ke]<<12)|0;Je=f+2139664+(((ha*31|0)+Me&1023)<<2)|0;do{if((c[Je>>2]|0)==(ca|0)){Xe=Le;Ye=1;Ze=Sa}else{c[Je>>2]=ca;b[fa>>1]=Me;b[da+(I*10|0)+2>>1]=ha;a[Ke]=0;E=da+(I*10|0)+8|0;a[E]=a[E]&-2;b[Q>>1]=b[ea>>1]|0;b[Q+2>>1]=b[ea+2>>1]|0;b[Q+4>>1]=b[ea+4>>1]|0;b[Q+6>>1]=b[ea+6>>1]|0;b[Q+8>>1]=b[ea+8>>1]|0;VGb(R|0,ea|0,10)|0;b[_>>1]=b[R>>1]|0;b[_+2>>1]=b[R+2>>1]|0;b[_+4>>1]=b[R+4>>1]|0;b[_+6>>1]=b[R+6>>1]|0;b[_+8>>1]=b[R+8>>1]|0;E=$Ya(f,Wa,l)|0;if((E|0)<(Le|0)){Xe=E;Ye=1;Ze=Sa;break}b[ea>>1]=b[Qe>>1]|0;b[ea+2>>1]=b[Qe+2>>1]|0;b[ea+4>>1]=b[Qe+4>>1]|0;b[ea+6>>1]=b[Qe+6>>1]|0;b[ea+8>>1]=b[Qe+8>>1]|0;b[_>>1]=b[m>>1]|0;b[_+2>>1]=b[m+2>>1]|0;b[_+4>>1]=b[m+4>>1]|0;b[_+6>>1]=b[m+6>>1]|0;b[_+8>>1]=b[m+8>>1]|0;b[R>>1]=b[n>>1]|0;b[R+2>>1]=b[n+2>>1]|0;b[R+4>>1]=b[n+4>>1]|0;b[R+6>>1]=b[n+6>>1]|0;b[R+8>>1]=b[n+8>>1]|0;b[Q>>1]=b[o>>1]|0;b[Q+2>>1]=b[o+2>>1]|0;b[Q+4>>1]=b[o+4>>1]|0;b[Q+6>>1]=b[o+6>>1]|0;b[Q+8>>1]=b[o+8>>1]|0;Xe=Le;Ye=1;Ze=Sa}}while(0);while(1){do{if((a[Ze+8|0]&1)==0){Sa=b[Ze>>1]|0;Q=Sa<<16>>16;R=b[Ze+2>>1]|0;_=R<<16>>16;ea=a[Ze+4|0]|0;I=c[L>>2]<<c[N>>2];da=(ba(I,l)|0)+Wa|0;Ke=c[T>>2]|0;ha=Ke+(da*10|0)|0;Me=ha;b[p>>1]=b[Me>>1]|0;b[p+2>>1]=b[Me+2>>1]|0;b[p+4>>1]=b[Me+4>>1]|0;b[p+6>>1]=b[Me+6>>1]|0;b[p+8>>1]=b[Me+8>>1]|0;fa=Ke+((da|1)*10|0)|0;b[h>>1]=b[fa>>1]|0;b[h+2>>1]=b[fa+2>>1]|0;b[h+4>>1]=b[fa+4>>1]|0;b[h+6>>1]=b[fa+6>>1]|0;b[h+8>>1]=b[fa+8>>1]|0;ca=Ke+((da+I|0)*10|0)|0;b[j>>1]=b[ca>>1]|0;b[j+2>>1]=b[ca+2>>1]|0;b[j+4>>1]=b[ca+4>>1]|0;b[j+6>>1]=b[ca+6>>1]|0;b[j+8>>1]=b[ca+8>>1]|0;Je=Ke+((I+1+da|0)*10|0)|0;b[k>>1]=b[Je>>1]|0;b[k+2>>1]=b[Je+2>>1]|0;b[k+4>>1]=b[Je+4>>1]|0;b[k+6>>1]=b[Je+6>>1]|0;b[k+8>>1]=b[Je+8>>1]|0;I=Ke+(da*10|0)+4|0;ka=(_<<6)+(Q>>10)+(c[Z>>2]|0)+(d[I]<<12)|0;Ua=f+2139664+(((_*31|0)+Q&1023)<<2)|0;if((c[Ua>>2]|0)==(ka|0)){_e=Xe;break}c[Ua>>2]=ka;b[ha>>1]=Sa;b[Ke+(da*10|0)+2>>1]=R;a[I]=ea;ea=Ke+(da*10|0)+8|0;a[ea]=a[ea]&-2;b[Je>>1]=b[Me>>1]|0;b[Je+2>>1]=b[Me+2>>1]|0;b[Je+4>>1]=b[Me+4>>1]|0;b[Je+6>>1]=b[Me+6>>1]|0;b[Je+8>>1]=b[Me+8>>1]|0;VGb(ca|0,Me|0,10)|0;b[fa>>1]=b[ca>>1]|0;b[fa+2>>1]=b[ca+2>>1]|0;b[fa+4>>1]=b[ca+4>>1]|0;b[fa+6>>1]=b[ca+6>>1]|0;b[fa+8>>1]=b[ca+8>>1]|0;ea=$Ya(f,Wa,l)|0;if((ea|0)<(Xe|0)){_e=ea;break}b[Me>>1]=b[p>>1]|0;b[Me+2>>1]=b[p+2>>1]|0;b[Me+4>>1]=b[p+4>>1]|0;b[Me+6>>1]=b[p+6>>1]|0;b[Me+8>>1]=b[p+8>>1]|0;b[fa>>1]=b[h>>1]|0;b[fa+2>>1]=b[h+2>>1]|0;b[fa+4>>1]=b[h+4>>1]|0;b[fa+6>>1]=b[h+6>>1]|0;b[fa+8>>1]=b[h+8>>1]|0;b[ca>>1]=b[j>>1]|0;b[ca+2>>1]=b[j+2>>1]|0;b[ca+4>>1]=b[j+4>>1]|0;b[ca+6>>1]=b[j+6>>1]|0;b[ca+8>>1]=b[j+8>>1]|0;b[Je>>1]=b[k>>1]|0;b[Je+2>>1]=b[k+2>>1]|0;b[Je+4>>1]=b[k+4>>1]|0;b[Je+6>>1]=b[k+6>>1]|0;b[Je+8>>1]=b[k+8>>1]|0;_e=Xe}else{_e=Xe}}while(0);if((Ye|0)>=4){break}ga=c[J+(Ye<<2)>>2]|0;Xe=_e;Ye=Ye+1|0;Ze=ga}We=((Le|0)!=(_e|0))+Xa|0}ga=Wa+2|0;if((ga|0)<(P|0)){Xa=We;Wa=ga}else{$e=We;break}}}else{$e=Pa}Wa=l+2|0;if((Wa|0)<(S|0)){l=Wa;Pa=$e}else{af=$e;break}}}else{af=0}yDb(c[U>>2]|0,16,2330192,(Se=i,i=i+8|0,c[Se>>2]=af<<2,Se)|0);i=Se;i=g;return}function XYa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=e+7528|0;n=e+7536|0;o=c[n>>2]|0;p=c[m>>2]<<o;q=o-f|0;r=(ba(p,h)|0)+g<<q;s=g+1<<q;t=e+2139660|0;u=c[t>>2]|0;v=u+(r*10|0)|0;w=(g|0)!=0;if(w){x=u+((r-1|0)*10|0)|0}else{x=630256}do{if((h|0)==0){y=x;z=630256;A=x}else{B=r-p|0;C=u+(B*10|0)|0;if(w){D=u+((B-1|0)*10|0)|0}else{D=x}if((s|0)>=(p|0)){y=D;z=C;A=D;break}if(!((g&1|0)==0|(f|0)==0)){y=D;z=C;A=D;break}y=u+(((1<<q)-p+r|0)*10|0)|0;z=C;A=D}}while(0);D=a[x+5|0]|0;s=D&255;w=a[x+6|0]|0;C=w&255;B=a[x+7|0]|0;E=B&255;F=d[x+4|0]|0;G=F<<1;H=G&256;I=d[z+4|0]|0;J=I<<1;K=J&256;L=(d[1191992+((K|0)==0?J:I>>>7)|0]|0)+(d[1191992+((H|0)==0?G:F>>>7)|0]|0)|0;F=(b[x>>1]|0)-(b[z>>1]|0)|0;G=(F|0)>-1?F:-F|0;F=G<<1;I=F>>>0>65535>>>0;J=I?G>>>15&65535:F;F=I?16:0;if((J&65280|0)==0){M=F;N=J}else{M=F|8;N=J>>>8}J=u+(r*10|0)+4|0;F=a[J]|0;I=(F<<24>>24!=0)<<4;G=(d[1191992+N|0]|0)+M+I|0;M=(b[x+2>>1]|0)-(b[z+2>>1]|0)|0;N=(M|0)>-1?M:-M|0;M=N<<1;O=M>>>0>65535>>>0;P=O?N>>>15&65535:M;M=O?16:0;if((P&65280|0)==0){Q=M;R=P}else{Q=M|8;R=P>>>8}P=Q+I+(d[1191992+R|0]|0)|0;R=(d[y+9|0]|0)+(d[A+9|0]|0)+((d[z+9|0]|0)+(d[x+9|0]|0)<<1)|0;if((c[e+7348>>2]|0)!=0){A=1<<q;q=f&255;if((A|0)>0){S=0}else{i=j;return}do{I=(ba(S,p)|0)+r|0;Q=0;do{M=I+Q|0;O=c[t>>2]|0;TGb(O+(M*10|0)|0,0,5)|0;a[O+(M*10|0)+5|0]=D;a[O+(M*10|0)+6|0]=w;a[O+(M*10|0)+7|0]=B;a[O+(M*10|0)+8|0]=1;a[O+(M*10|0)+9|0]=q;Q=Q+1|0;}while((Q|0)<(A|0));S=S+1|0;}while((S|0)<(A|0));i=j;return}a:do{if((o|0)==(f|0)){T=u+(r*10|0)+8|0}else{A=r+1|0;S=u+(r*10|0)+8|0;q=a[S]|0;Q=(q&1)==0;I=a[u+(A*10|0)+8|0]|0;do{if(Q){U=23}else{if((I&1)==0){U=23;break}V=(d[u+(r*10|0)+6|0]|0)-(d[u+(A*10|0)+6|0]|0)|(d[u+(r*10|0)+5|0]|0)-(d[u+(A*10|0)+5|0]|0)|(d[u+(r*10|0)+7|0]|0)-(d[u+(A*10|0)+7|0]|0)}}while(0);if((U|0)==23){V=(b[v>>1]|0)-(b[u+(A*10|0)>>1]|0)|(I^q)&1|(b[u+(r*10|0)+2>>1]|0)-(b[u+(A*10|0)+2>>1]|0)|(F&255)-(d[u+(A*10|0)+4|0]|0)}do{if((V|0)==0){M=r+p|0;O=a[u+(M*10|0)+8|0]|0;do{if(Q){U=28}else{if((O&1)==0){U=28;break}W=(d[u+(r*10|0)+6|0]|0)-(d[u+(M*10|0)+6|0]|0)|(d[u+(r*10|0)+5|0]|0)-(d[u+(M*10|0)+5|0]|0)|(d[u+(r*10|0)+7|0]|0)-(d[u+(M*10|0)+7|0]|0)}}while(0);if((U|0)==28){W=(b[v>>1]|0)-(b[u+(M*10|0)>>1]|0)|(O^q)&1|(b[u+(r*10|0)+2>>1]|0)-(b[u+(M*10|0)+2>>1]|0)|(F&255)-(d[u+(M*10|0)+4|0]|0)}if((W|0)!=0){break}N=M+1|0;X=a[u+(N*10|0)+8|0]|0;do{if(Q){U=33}else{if((X&1)==0){U=33;break}Y=(d[u+(r*10|0)+6|0]|0)-(d[u+(N*10|0)+6|0]|0)|(d[u+(r*10|0)+5|0]|0)-(d[u+(N*10|0)+5|0]|0)|(d[u+(r*10|0)+7|0]|0)-(d[u+(N*10|0)+7|0]|0)}}while(0);if((U|0)==33){Y=(b[v>>1]|0)-(b[u+(N*10|0)>>1]|0)|(X^q)&1|(b[u+(r*10|0)+2>>1]|0)-(b[u+(N*10|0)+2>>1]|0)|(F&255)-(d[u+(N*10|0)+4|0]|0)}if((Y|0)!=0){break}VYa(e+8|0,R+4+(e+3124)|0,1);T=S;break a}}while(0);VYa(e+8|0,R+4+(e+3124)|0,0);S=f+1|0;q=g<<1;Q=h<<1;XYa(e,S,q,Q);A=q|1;XYa(e,S,A,Q);I=Q|1;XYa(e,S,q,I);XYa(e,S,A,I);i=j;return}}while(0);if((a[T]&1)==0){T=e+7388|0;_Ya(c[T>>2]|0,k,l,d[J]|0,x,z,y);R=e+8|0;VYa(R,(a[x+8|0]&1)+1+(a[z+8|0]&1)+(e+3124)|0,0);if((c[T>>2]|0)>1){ZYa(R,(((L<<5)+H&-32)+K+1152&-32)+(e+3124)|0,d[J]|0,0)}K=v|0;ZYa(R,(G<<5)+128+(e+3124)|0,(b[K>>1]|0)-(c[k>>2]|0)|0,1);G=u+(r*10|0)+2|0;ZYa(R,(P<<5)+128+(e+3124)|0,(b[G>>1]|0)-(c[l>>2]|0)|0,1);P=b[K>>1]|0;K=b[G>>1]|0;G=a[J]|0;J=c[n>>2]|0;R=c[m>>2]<<J;v=J-f|0;J=(ba(R,h)|0)+g<<v;H=1<<v;v=f&255;if((H|0)>0){Z=0}else{i=j;return}do{L=(ba(Z,R)|0)+J|0;T=0;do{Y=L+T|0;F=c[t>>2]|0;b[F+(Y*10|0)>>1]=P;b[F+(Y*10|0)+2>>1]=K;a[F+(Y*10|0)+4|0]=G;a[F+(Y*10|0)+5|0]=D;a[F+(Y*10|0)+6|0]=w;a[F+(Y*10|0)+7|0]=B;a[F+(Y*10|0)+8|0]=0;a[F+(Y*10|0)+9|0]=v;T=T+1|0;}while((T|0)<(H|0));Z=Z+1|0;}while((Z|0)<(H|0));i=j;return}_Ya(c[e+7388>>2]|0,k,l,0,x,z,y);y=e+8|0;VYa(y,(a[x+8|0]&1)+1+(a[z+8|0]&1)+(e+3124)|0,1);z=u+(r*10|0)+5|0;ZYa(y,e+3156|0,(d[z]|0)-s|0,1);if((c[e+7544>>2]|0)>2){s=u+(r*10|0)+6|0;ZYa(y,e+3188|0,(d[s]|0)-C|0,1);C=u+(r*10|0)+7|0;ZYa(y,e+3220|0,(d[C]|0)-E|0,1);_=s;$=C}else{_=u+(r*10|0)+6|0;$=u+(r*10|0)+7|0}r=a[z]|0;z=a[_]|0;_=a[$]|0;$=c[n>>2]|0;n=c[m>>2]<<$;m=$-f|0;$=(ba(n,h)|0)+g<<m;g=1<<m;m=c[k>>2]&65535;k=c[l>>2]&65535;l=f&255;if((g|0)>0){aa=0}else{i=j;return}do{f=(ba(aa,n)|0)+$|0;h=0;do{u=f+h|0;C=c[t>>2]|0;b[C+(u*10|0)>>1]=m;b[C+(u*10|0)+2>>1]=k;a[C+(u*10|0)+4|0]=0;a[C+(u*10|0)+5|0]=r;a[C+(u*10|0)+6|0]=z;a[C+(u*10|0)+7|0]=_;a[C+(u*10|0)+8|0]=1;a[C+(u*10|0)+9|0]=l;h=h+1|0;}while((h|0)<(g|0));aa=aa+1|0;}while((aa|0)<(g|0));i=j;return}function YYa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0;j=i;i=i+11712|0;k=j|0;l=j+1024|0;m=j+2048|0;n=j+6272|0;o=j+10496|0;p=j+11040|0;q=j+11584|0;r=j+11592|0;s=j+11600|0;t=j+11680|0;u=j+11696|0;v=j+11704|0;w=e+8|0;x=e+540|0;y=c[x>>2]|0;z=e+536|0;A=c[z>>2]|0;B=e+7528|0;C=e+7536|0;D=c[C>>2]|0;E=c[B>>2]<<D;G=c[e+7532>>2]<<D;H=D-f|0;I=(ba(E,h)|0)+g<<H;J=4-f|0;K=1<<J;L=(g|0)!=0;if(L){M=(c[e+2139660>>2]|0)+((I-1|0)*10|0)|0}else{M=630256}N=(h|0)!=0;if(N){O=(c[e+2139660>>2]|0)+((I-E|0)*10|0)|0}else{O=630256}P=(g+1<<H|0)<(E|0);if(P){Q=(c[e+2139660>>2]|0)+((I+1|0)*10|0)|0}else{Q=630256}if((h+1<<H|0)<(G|0)){R=(c[e+2139660>>2]|0)+((I+E|0)*10|0)|0}else{R=630256}S=N^1;if(S|L^1){T=M}else{T=(c[e+2139660>>2]|0)+((I+~E|0)*10|0)|0}do{if(S|P^1){U=T}else{if(!((g&1|0)==0|(f|0)==0)){U=T;break}U=(c[e+2139660>>2]|0)+(((1<<H)-E+I|0)*10|0)|0}}while(0);P=a[M+5|0]|0;S=P&255;L=a[M+6|0]|0;V=L&255;W=a[M+7|0]|0;X=W&255;Y=c[e+2540>>2]|0;Z=c[Y+32>>2]|0;_=c[Y+36>>2]|0;Y=c[e+2536>>2]|0;$=(c[Y>>2]|0)+((ba(Z,h)|0)+g<<J)|0;aa=g<<J;ca=e+7480|0;da=(ba(_,h)|0)<<J;ea=e+7484|0;fa=(da>>c[ea>>2])+(aa>>c[ca>>2])|0;da=(c[Y+4>>2]|0)+fa|0;ga=(c[Y+8>>2]|0)+fa|0;fa=((c[(c[e+4>>2]|0)+88>>2]|0)>>>4&1)+1|0;Y=e+2143800|0;ha=d[M+4|0]|0;ia=ha<<1;ja=ia&256;ka=d[O+4|0]|0;la=ka<<1;ma=la&256;na=(d[1191992+((ma|0)==0?la:ka>>>7)|0]|0)+(d[1191992+((ja|0)==0?ia:ha>>>7)|0]|0)|0;ha=b[M>>1]|0;ia=b[O>>1]|0;ka=ha-ia|0;la=(ka|0)>-1?ka:-ka|0;ka=la<<1;oa=ka>>>0>65535>>>0;pa=oa?la>>>15&65535:ka;ka=oa?16:0;if((pa&65280|0)==0){qa=ka;ra=pa}else{qa=ka|8;ra=pa>>>8}pa=(d[1191992+ra|0]|0)+qa|0;qa=b[M+2>>1]|0;ra=b[O+2>>1]|0;ka=qa-ra|0;oa=(ka|0)>-1?ka:-ka|0;ka=oa<<1;la=ka>>>0>65535>>>0;sa=la?oa>>>15&65535:ka;ka=la?16:0;if((sa&65280|0)==0){ta=ka;ua=sa}else{ta=ka|8;ua=sa>>>8}sa=(d[1191992+ua|0]|0)+ta|0;ta=(d[U+9|0]|0)+(d[T+9|0]|0)+((d[O+9|0]|0)+(d[M+9|0]|0)<<1)|0;if((c[e+7348>>2]|0)!=0){T=1<<H;H=f&255;if((T|0)<=0){va=0;i=j;return va|0}ua=e+2139660|0;ka=0;while(1){la=(ba(ka,E)|0)+I|0;oa=0;do{wa=la+oa|0;xa=c[ua>>2]|0;TGb(xa+(wa*10|0)|0,0,5)|0;a[xa+(wa*10|0)+5|0]=P;a[xa+(wa*10|0)+6|0]=L;a[xa+(wa*10|0)+7|0]=W;a[xa+(wa*10|0)+8|0]=1;a[xa+(wa*10|0)+9|0]=H;oa=oa+1|0;}while((oa|0)<(T|0));oa=ka+1|0;if((oa|0)<(T|0)){ka=oa}else{va=0;break}}i=j;return va|0}ka=s+8|0;c[ka>>2]=ha;T=s+12|0;c[T>>2]=qa;H=s+16|0;c[H>>2]=ia;ua=s+20|0;c[ua>>2]=ra;oa=b[U>>1]|0;la=s+24|0;c[la>>2]=oa;wa=b[U+2>>1]|0;xa=s+28|0;c[xa>>2]=wa;ya=e+2139660|0;za=c[ya>>2]|0;Aa=t|0;b[t>>1]=b[za+(I*10|0)>>1]|0;b[t+2>>1]=b[za+(I*10|0)+2>>1]|0;b[t+4>>1]=b[Q>>1]|0;b[t+6>>1]=b[Q+2>>1]|0;b[t+8>>1]=b[R>>1]|0;b[t+10>>1]=b[R+2>>1]|0;c[e+2143924>>2]=2;c[e+2156280>>2]=0;c[e+2156276>>2]=0;c[e+2155924>>2]=0;R=c[e+7500>>2]|0;t=e+7504|0;Q=c[t>>2]|0;za=e+2155920|0;Ba=c[za>>2]|0;switch(c[Ba+232>>2]&255|0){case 3:{Ca=(R*3|0)>>8;break};case 11:{Ca=R>>5;break};case 12:{Ca=R>>6;break};case 2:case 14:{Ca=R>>6;break};case 6:case 4:case 1:case 10:{Ca=Q>>7;break};case 5:{Ca=1;break};default:{Ca=R>>7}}Da=e+2156032|0;c[Da>>2]=Ca;switch(c[Ba+236>>2]&255|0){case 3:{Ea=(R*3|0)>>8;break};case 11:{Ea=R>>5;break};case 12:{Ea=R>>6;break};case 2:case 14:{Ea=R>>6;break};case 6:case 4:case 1:case 10:{Ea=Q>>7;break};case 5:{Ea=1;break};default:{Ea=R>>7}}c[e+2156036>>2]=Ea;switch(c[Ba+240>>2]&255|0){case 3:{Fa=(R*3|0)>>8;break};case 11:{Fa=R>>5;break};case 12:{Fa=R>>6;break};case 2:case 14:{Fa=R>>6;break};case 6:case 4:case 1:case 10:{Fa=Q>>7;break};case 5:{Fa=1;break};default:{Fa=R>>7}}c[e+2156040>>2]=Fa;c[e+2155356>>2]=1;c[e+2156264>>2]=(c[e+2156260>>2]|0)+12289;Fa=(-g<<J)-13|0;c[e+2156064>>2]=Fa;c[e+2156072>>2]=(-h<<J)-13;R=4-D|0;D=(~g<<J)+13+(E<<R)|0;c[e+2156068>>2]=D;E=(~h<<J)+13+(G<<R)|0;c[e+2156076>>2]=E;R=D<<fa;if((ha|0)>(R|0)){c[ka>>2]=R;Ga=R}else{Ga=ha}ha=E<<fa;if((qa|0)>(ha|0)){c[T>>2]=ha;Ha=ha}else{Ha=qa}if((ia|0)>(R|0)){c[H>>2]=R;Ia=R}else{Ia=ia}if((ra|0)>(ha|0)){c[ua>>2]=ha;Ja=ha}else{Ja=ra}ra=Fa<<fa;if((oa|0)<(ra|0)){c[la>>2]=ra;Ka=ra}else{Ka=oa}if((Ka|0)>(R|0)){c[la>>2]=R;La=R}else{La=Ka}if((wa|0)>(ha|0)){c[xa>>2]=ha;Ma=ha}else{Ma=wa}do{if((Ga|0)>(Ia|0)){if((La|0)<=(Ia|0)){Na=Ia;break}Na=(La|0)>(Ga|0)?Ga:La}else{if((Ia|0)<=(La|0)){Na=Ia;break}Na=(La|0)>(Ga|0)?La:Ga}}while(0);c[s+32>>2]=Na;do{if((Ha|0)>(Ja|0)){if((Ma|0)<=(Ja|0)){Oa=Ja;break}Oa=(Ma|0)>(Ha|0)?Ha:Ma}else{if((Ja|0)<=(Ma|0)){Oa=Ja;break}Oa=(Ma|0)>(Ha|0)?Ma:Ha}}while(0);c[s+36>>2]=Oa;Ma=e+2156080|0;if(N){c[Ma>>2]=Na;c[e+2156084>>2]=Oa}else{c[Ma>>2]=Ga;c[e+2156084>>2]=Ha}Ha=e+7388|0;if((c[Ha>>2]|0)>0){Ga=h<<J;Ma=e+2156216|0;Oa=e+2156220|0;Na=e+2156088|0;N=e+2156152|0;Ja=e+2156092|0;La=e+2156156|0;Ia=e+2156096|0;wa=e+2156160|0;ha=s|0;s=65536>>>(fa>>>0);fa=e+2156268|0;xa=0;Ka=0;R=0;la=0;oa=2147483647;ra=Ba;while(1){Ba=c[e+2544+(R<<2)>>2]|0;Fa=(ba(c[Ma>>2]|0,Ga)|0)+aa|0;ua=(ba(c[Oa>>2]|0,Ga)|0)+aa|0;ia=ua>>c[(c[ra+60>>2]|0)+7480>>2];c[Na>>2]=$;c[N>>2]=(c[Ba>>2]|0)+Fa;c[Ja>>2]=da;c[La>>2]=(c[Ba+4>>2]|0)+ia;c[Ia>>2]=ga;c[wa>>2]=(c[Ba+8>>2]|0)+ia;ia=kmb(Y,u,v,ha,0,0,Aa,s,f,K)|0;Ze[c[fa>>2]&15](Y,u,v,ia,0,0,f,K)|0;ia=imb(Y,c[u>>2]|0,c[v>>2]|0,0,0,f,K,0)|0;Ba=R<<1;Fa=Ba>>>0>65535>>>0;ua=Fa?R>>>15&65535:Ba;Ba=Fa?16:0;if((ua&65280|0)==0){Pa=Ba;Qa=ua}else{Pa=Ba|8;Qa=ua>>>8}ua=(ba(c[Da>>2]<<1,(d[1191992+Qa|0]|0)+Pa|0)|0)+ia|0;ia=c[e+7392+(R<<2)>>2]|0;if((ia|0)!=0){b[ia+(I<<2)>>1]=c[u>>2];b[ia+(I<<2)+2>>1]=c[v>>2];c[(c[e+7424+(R<<2)>>2]|0)+(I<<2)>>2]=ua}if((oa|0)>(ua|0)){Ra=ua;Sa=R;Ta=c[u>>2]|0;Ua=c[v>>2]|0}else{Ra=oa;Sa=la;Ta=Ka;Ua=xa}ua=R+1|0;if((ua|0)>=(c[Ha>>2]|0)){break}xa=Ua;Ka=Ta;R=ua;la=Sa;oa=Ra;ra=c[za>>2]|0}Va=Ua;Wa=Ta;Xa=Sa;Ya=Ra;Za=c[x>>2]|0;_a=c[z>>2]|0}else{Va=0;Wa=0;Xa=0;Ya=2147483647;Za=y;_a=A}Ra=Za-_a|0;_a=c[e+12>>2]|0;Za=_a>>>0>65535>>>0;Sa=Za?_a>>>16:_a;_a=Za?16:0;if((Sa&65280|0)==0){$a=_a;ab=Sa}else{$a=_a|8;ab=Sa>>>8}Sa=(Ra<<3)+((d[1191992+ab|0]|0)+($a-(Ra+(c[e+16>>2]|0)+((c[e+20>>2]|0)>>>31^1)<<3)))|0;Ra=o;$a=w;UGb(Ra|0,$a|0,540)|0;ab=k|0;k=o+532|0;c[k>>2]=ab;_a=o+528|0;c[_a>>2]=ab;Za=m|0;Ta=e+3124|0;UGb(Za|0,Ta|0,4224)|0;if((c[C>>2]|0)!=(f|0)){VYa(o,m+(ta+4)|0,1)}Ua=M+8|0;za=O+8|0;VYa(o,m+((d[Ua]|0)+1+(d[za]|0))|0,0);ra=c[Ha>>2]|0;if((ra|0)>1){ZYa(o,m+(((na<<5)+ja&-32)+ma+1152&-32)|0,Xa,0);bb=c[Ha>>2]|0}else{bb=ra}_Ya(bb,q,r,Xa,M,O,U);bb=((Xa|0)!=0)<<4;ZYa(o,m+((pa+bb<<5)+128)|0,Wa-(c[q>>2]|0)|0,1);ZYa(o,m+((sa+bb<<5)+128)|0,Va-(c[r>>2]|0)|0,1);bb=(c[k>>2]|0)-(c[_a>>2]|0)|0;_a=c[o+4>>2]|0;k=_a>>>0>65535>>>0;sa=k?_a>>>16:_a;_a=k?16:0;if((sa&65280|0)==0){cb=_a;db=sa}else{cb=_a|8;db=sa>>>8}sa=((ba((bb+(c[o+8>>2]|0)+((c[o+12>>2]|0)>>>31^1)<<3)+Sa-cb-(d[1191992+db|0]|0)|0,c[t>>2]|0)|0)>>7)+Ya|0;Ya=K<<J;if((K|0)>0){J=$;db=0;cb=0;while(1){o=J;_a=db;k=0;while(1){eb=(d[o]|0)+_a|0;m=k+1|0;if((m|0)<(K|0)){o=o+1|0;_a=eb;k=m}else{break}}k=cb+1|0;if((k|0)<(K|0)){J=J+Z|0;db=eb;cb=k}else{break}}cb=((Ya|0)/2|0)+eb|0;db=0;J=0;k=$;while(1){$=db;_a=0;o=k;while(1){fb=(c[5398952+((d[o]|256)<<2)>>2]|0)+$|0;m=_a+1|0;if((m|0)<(K|0)){$=fb;_a=m;o=o+1|0}else{break}}o=J+1|0;if((o|0)<(K|0)){db=fb;J=o;k=k+Z|0}else{gb=fb;hb=eb;ib=cb;break}}}else{gb=0;hb=0;ib=(Ya|0)/2|0}cb=(ib|0)/(Ya|0)|0;ib=gb-(ba(cb<<1,hb)|0)+(ba(ba(cb,Ya)|0,cb)|0)|0;hb=e+7544|0;if((c[hb>>2]|0)>2){gb=c[ca>>2]|0;ca=c[ea>>2]|0;ea=Ya>>ca+gb;Ya=K>>gb;gb=K>>ca;ca=(gb|0)>0&(Ya|0)>0;do{if(ca){K=da;eb=0;fb=0;while(1){Z=K;k=eb;J=0;while(1){jb=(d[Z]|0)+k|0;db=J+1|0;if((db|0)<(Ya|0)){Z=Z+1|0;k=jb;J=db}else{break}}J=fb+1|0;if((J|0)<(gb|0)){K=K+_|0;eb=jb;fb=J}else{break}}fb=(ea|0)/2|0;eb=(fb+jb|0)/(ea|0)|0;if(ca){kb=ga;lb=0;mb=0}else{nb=0;ob=fb;pb=eb;break}while(1){K=kb;J=lb;k=0;while(1){qb=(d[K]|0)+J|0;Z=k+1|0;if((Z|0)<(Ya|0)){K=K+1|0;J=qb;k=Z}else{break}}k=mb+1|0;if((k|0)<(gb|0)){kb=kb+_|0;lb=qb;mb=k}else{nb=qb;ob=fb;pb=eb;break}}}else{eb=(ea|0)/2|0;nb=0;ob=eb;pb=(eb|0)/(ea|0)|0}}while(0);rb=(nb+ob|0)/(ea|0)|0;sb=pb}else{rb=0;sb=0}pb=p;UGb(pb|0,$a|0,540)|0;ea=l|0;l=p+532|0;c[l>>2]=ea;ob=p+528|0;c[ob>>2]=ea;nb=n|0;UGb(nb|0,Ta|0,4224)|0;if((c[C>>2]|0)!=(f|0)){VYa(p,n+(ta+4)|0,1)}VYa(p,n+((d[Ua]|0)+1+(d[za]|0))|0,1);ZYa(p,n+32|0,cb-S|0,1);if((c[hb>>2]|0)>2){ZYa(p,n+64|0,sb-V|0,1);ZYa(p,n+96|0,rb-X|0,1)}X=(c[l>>2]|0)-(c[ob>>2]|0)|0;ob=c[p+4>>2]|0;l=ob>>>0>65535>>>0;n=l?ob>>>16:ob;ob=l?16:0;if((n&65280|0)==0){tb=ob;ub=n}else{tb=ob|8;ub=n>>>8}n=ib+((ba((X+(c[p+8>>2]|0)+((c[p+12>>2]|0)>>>31^1)<<3)+Sa-tb-(d[1191992+ub|0]|0)|0,c[t>>2]|0)|0)>>7)|0;do{if((f|0)==0){ub=n>>8;tb=sa>>8;if(!((tb|0)<65|(tb|0)<(ub|0))){Sa=e+2156240|0;c[Sa>>2]=(c[Sa>>2]|0)+(c[e+2153760>>2]|0);break}if(tb>>>0<255>>>0){vb=(d[tb+1135649|0]|0)-1>>4}else{do{if(tb>>>0<4096>>>0){wb=(d[1135648+(tb>>>4)|0]|0)>>>2}else{if(tb>>>0<16384>>>0){wb=(d[1135648+(tb>>>6)|0]|0)>>>1;break}if(tb>>>0<65536>>>0){wb=d[1135648+(tb>>>8)|0]|0;break}else{Sa=tb>>>16;p=(Sa&65280|0)==0;ib=((d[1191992+(p?Sa:tb>>>24)|0]|0)+(p?0:8)|0)>>>1;p=tb>>>((ib+2|0)>>>0);Sa=d[1135648+(p>>>((ib+8|0)>>>0))|0]|0;gHb(p,0,c[1199552+(Sa<<2)>>2]|0,0)|0;wb=F+(Sa<<ib)|0;break}}}while(0);vb=wb-((ba(wb,wb)|0)>>>0>tb>>>0)|0}if(ub>>>0<255>>>0){xb=(d[ub+1135649|0]|0)-1>>4}else{do{if(ub>>>0<4096>>>0){yb=(d[1135648+(ub>>>4)|0]|0)>>>2}else{if(ub>>>0<16384>>>0){yb=(d[1135648+(ub>>>6)|0]|0)>>>1;break}if(ub>>>0<65536>>>0){yb=d[1135648+(ub>>>8)|0]|0;break}else{ib=ub>>>16;Sa=(ib&65280|0)==0;p=((d[1191992+(Sa?ib:ub>>>24)|0]|0)+(Sa?0:8)|0)>>>1;Sa=ub>>>((p+2|0)>>>0);ib=d[1135648+(Sa>>>((p+8|0)>>>0))|0]|0;gHb(Sa,0,c[1199552+(ib<<2)>>2]|0,0)|0;yb=F+(ib<<p)|0;break}}}while(0);xb=yb-((ba(yb,yb)|0)>>>0>ub>>>0)|0}tb=e+2156240|0;c[tb>>2]=vb-xb+(c[tb>>2]|0)}}while(0);do{if((c[C>>2]|0)!=(f|0)){VYa(w,ta+4+(e+3124)|0,0);xb=f+1|0;vb=g<<1;yb=h<<1;wb=YYa(e,xb,vb,yb)|0;tb=vb|1;p=(YYa(e,xb,tb,yb)|0)+wb|0;wb=yb|1;yb=p+(YYa(e,xb,vb,wb)|0)|0;vb=yb+(YYa(e,xb,tb,wb)|0)|0;wb=vb+(c[t>>2]>>7)|0;if((wb|0)<(sa|0)&(wb|0)<(n|0)){va=wb}else{break}i=j;return va|0}}while(0);if((n|0)<(sa|0)){_Ya(c[Ha>>2]|0,q,r,0,M,O,U);UGb(y|0,ea|0,X)|0;UGb($a|0,pb|0,540)|0;c[z>>2]=A;c[x>>2]=y+X;X=c[C>>2]|0;pb=c[B>>2]<<X;ea=X-f|0;X=(ba(pb,h)|0)+g<<ea;U=1<<ea;ea=cb&255;cb=sb&255;sb=rb&255;rb=c[q>>2]&65535;q=c[r>>2]&65535;r=f&255;if((U|0)>0){O=0;do{M=(ba(O,pb)|0)+X|0;Ha=0;do{t=M+Ha|0;e=c[ya>>2]|0;b[e+(t*10|0)>>1]=rb;b[e+(t*10|0)+2>>1]=q;a[e+(t*10|0)+4|0]=0;a[e+(t*10|0)+5|0]=ea;a[e+(t*10|0)+6|0]=cb;a[e+(t*10|0)+7|0]=sb;a[e+(t*10|0)+8|0]=1;a[e+(t*10|0)+9|0]=r;Ha=Ha+1|0;}while((Ha|0)<(U|0));O=O+1|0;}while((O|0)<(U|0))}UGb(Ta|0,nb|0,4224)|0;va=n;i=j;return va|0}else{UGb(y|0,ab|0,bb)|0;UGb($a|0,Ra|0,540)|0;c[z>>2]=A;c[x>>2]=y+bb;bb=c[C>>2]|0;C=c[B>>2]<<bb;B=bb-f|0;bb=(ba(C,h)|0)+g<<B;g=1<<B;B=Wa&65535;Wa=Va&65535;Va=Xa&255;Xa=f&255;if((g|0)>0){f=0;do{h=(ba(f,C)|0)+bb|0;y=0;do{x=h+y|0;A=c[ya>>2]|0;b[A+(x*10|0)>>1]=B;b[A+(x*10|0)+2>>1]=Wa;a[A+(x*10|0)+4|0]=Va;a[A+(x*10|0)+5|0]=P;a[A+(x*10|0)+6|0]=L;a[A+(x*10|0)+7|0]=W;a[A+(x*10|0)+8|0]=0;a[A+(x*10|0)+9|0]=Xa;y=y+1|0;}while((y|0)<(g|0));f=f+1|0;}while((f|0)<(g|0))}UGb(Ta|0,Za|0,4224)|0;va=sa;i=j;return va|0}return 0}function ZYa(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c|0)==0){VYa(a,b,1);return}f=(c|0)>-1?c:-c|0;g=f>>>0>65535>>>0;h=g?f>>>16:f;i=g?16:0;if((h&65280|0)==0){j=i;k=h}else{j=i|8;k=h>>>8}h=(d[1191992+k|0]|0)+j|0;j=(h|0)>10?10:h;VYa(a,b,0);if((j|0)>0){k=(h|0)<10;i=0;do{i=i+1|0;VYa(a,b+i|0,1);}while((i|0)<(j|0));l=k?h:10}else{l=0}if((l|0)<(h|0)){k=b+10|0;i=l;while(1){VYa(a,k,1);g=i+1|0;if((g|0)<(h|0)){i=g}else{m=h;break}}}else{m=l}VYa(a,b+((m|0)>9?10:m+1|0)|0,0);m=h-1|0;if((m|0)<(j|0)){n=m}else{h=b+31|0;l=m;while(1){VYa(a,h,f>>>(l>>>0)&1);m=l-1|0;if((m|0)<(j|0)){n=m;break}else{l=m}}}if((n|0)>-1){l=n;while(1){VYa(a,b+(l+22)|0,f>>>(l>>>0)&1);if((l|0)>0){l=l-1|0}else{break}}}if((e|0)==0){return}VYa(a,b+(j+11)|0,c>>>31);return}function _Ya(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=b[h>>1]|0;l=k<<16>>16;if((a|0)==1){a=b[i>>1]|0;m=a<<16>>16;n=b[j>>1]|0;o=n<<16>>16;do{if(k<<16>>16>a<<16>>16){if(!(n<<16>>16>a<<16>>16)){p=m;break}p=(o|0)>(l|0)?l:o}else{if(!(a<<16>>16>n<<16>>16)){p=m;break}p=(o|0)>(l|0)?o:l}}while(0);c[e>>2]=p;p=b[h+2>>1]|0;o=p<<16>>16;m=b[i+2>>1]|0;n=m<<16>>16;a=b[j+2>>1]|0;k=a<<16>>16;if(p<<16>>16>m<<16>>16){if(!(a<<16>>16>m<<16>>16)){q=n;c[f>>2]=q;return}q=(k|0)>(o|0)?o:k;c[f>>2]=q;return}else{if(!(m<<16>>16>a<<16>>16)){q=n;c[f>>2]=q;return}q=(k|0)>(o|0)?k:o;c[f>>2]=q;return}}else{o=h+4|0;k=(ba(c[5728520+(g<<5)+(d[o]<<2)>>2]|0,l)|0)+128>>8;l=i+4|0;n=(ba(c[5728520+(g<<5)+(d[l]<<2)>>2]|0,b[i>>1]|0)|0)+128>>8;a=j+4|0;m=(ba(c[5728520+(g<<5)+(d[a]<<2)>>2]|0,b[j>>1]|0)|0)+128>>8;do{if((k|0)>(n|0)){if((m|0)<=(n|0)){r=n;break}r=(m|0)>(k|0)?k:m}else{if((n|0)<=(m|0)){r=n;break}r=(m|0)>(k|0)?m:k}}while(0);c[e>>2]=r;r=(ba(c[5728520+(g<<5)+(d[o]<<2)>>2]|0,b[h+2>>1]|0)|0)+128>>8;h=(ba(c[5728520+(g<<5)+(d[l]<<2)>>2]|0,b[i+2>>1]|0)|0)+128>>8;i=(ba(c[5728520+(g<<5)+(d[a]<<2)>>2]|0,b[j+2>>1]|0)|0)+128>>8;if((r|0)>(h|0)){if((i|0)<=(h|0)){q=h;c[f>>2]=q;return}q=(i|0)>(r|0)?r:i;c[f>>2]=q;return}else{if((h|0)<=(i|0)){q=h;c[f>>2]=q;return}q=(i|0)>(r|0)?i:r;c[f>>2]=q;return}}}function $Ya(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;h=e+7536|0;i=c[h>>2]|0;j=16>>>(i>>>0);k=c[1167680+(i<<2)>>2]|0;l=j<<1;m=c[e+2540>>2]|0;n=c[m+32>>2]|0;o=c[m>>2]|0;m=c[c[e+2536>>2]>>2]|0;p=e+7528|0;q=c[p>>2]|0;r=q<<i;s=c[e+7548>>2]|0;t=c[e+7552>>2]|0;u=c[e+7500>>2]|0;switch(c[(c[e+4>>2]|0)+232>>2]&255|0){case 6:case 4:case 1:case 10:{v=c[e+7504>>2]>>7;break};case 11:{v=u>>5;break};case 5:{v=1;break};case 3:{v=(u*3|0)>>8;break};case 12:{v=u>>6;break};case 2:case 14:{v=u>>6;break};default:{v=u>>7}}u=(j|0)/2|0;w=e+7532|0;x=e+2139660|0;y=(n|0)>111?16:n<<4;z=e+2158472|0;A=-l|0;B=y*3|0;C=B+y|0;D=C+y|0;E=e+960+(((j|0)==8)<<2)|0;F=e+2143800|0;G=0;H=0;I=q;q=i;while(1){i=((H|0)%3|0)+f|0;J=i-1|0;K=((H|0)/3|0)+g|0;L=K-1|0;M=(ba(J,j)|0)+u|0;N=(ba(L,j)|0)+u|0;O=I<<q;P=ba(O,L)|0;Q=P+J|0;R=c[x>>2]|0;S=R+(Q*10|0)|0;T=R+((P+i|0)*10|0)|0;P=Q+O|0;Q=R+(P*10|0)|0;U=R+((P+1|0)*10|0)|0;P=c[z>>2]|0;if((J|0)<0){V=U;W=U;X=T;Y=T}else{J=(i|0)<(O|0);V=J?U:Q;W=Q;X=J?T:S;Y=S}if((L|0)<0){Z=V;_=W;$=V;aa=W}else{L=(K|0)<(c[w>>2]<<q|0);Z=L?V:X;_=L?W:Y;$=X;aa=Y}L=(M|0)<0;if(L){ca=k+(-M|0)|0;da=0;ea=M+j|0}else{ca=k;da=M;ea=j}K=(da+ea|0)>(s|0)?s-da|0:ea;S=(N|0)<0;if(S){fa=ca+(ba(N,A)|0)|0;ga=0;ha=N+j|0}else{fa=ca;ga=N;ha=j}T=(ga+ha|0)>(t|0)?t-ga|0:ha;do{if(!((K|0)<1|(T|0)<1)){J=(ba(ga,n)|0)+da|0;Q=P+B|0;U=P+C|0;Iob(e,Q,P,n,da,ga,K,T,aa,0,s,t);O=aa+8|0;i=a[O]|0;R=$+8|0;ia=a[R]|0;do{if((i&1)==0){ja=21}else{if((ia&1)==0){ja=21;break}ka=(d[aa+6|0]|0)-(d[$+6|0]|0)|(d[aa+5|0]|0)-(d[$+5|0]|0)|(d[aa+7|0]|0)-(d[$+7|0]|0)}}while(0);if((ja|0)==21){ja=0;ka=(b[aa>>1]|0)-(b[$>>1]|0)|(ia^i)&1|(b[aa+2>>1]|0)-(b[$+2>>1]|0)|(d[aa+4|0]|0)-(d[$+4|0]|0)}if((ka|0)==0){la=U;ma=Q;na=i}else{Iob(e,U,P,n,da,ga,K,T,$,0,s,t);la=P+D|0;ma=U;na=a[O]|0}oa=_+8|0;pa=a[oa]|0;do{if((na&1)==0){ja=27}else{if((pa&1)==0){ja=27;break}qa=(d[aa+6|0]|0)-(d[_+6|0]|0)|(d[aa+5|0]|0)-(d[_+5|0]|0)|(d[aa+7|0]|0)-(d[_+7|0]|0)}}while(0);if((ja|0)==27){ja=0;qa=(b[aa>>1]|0)-(b[_>>1]|0)|(pa^na)&1|(b[aa+2>>1]|0)-(b[_+2>>1]|0)|(d[aa+4|0]|0)-(d[_+4|0]|0)}do{if((qa|0)==0){ra=la;sa=Q;ta=na}else{U=a[R]|0;do{if((U&1)==0){ja=32}else{if((pa&1)==0){ja=32;break}ua=(d[$+6|0]|0)-(d[_+6|0]|0)|(d[$+5|0]|0)-(d[_+5|0]|0)|(d[$+7|0]|0)-(d[_+7|0]|0)}}while(0);if((ja|0)==32){ja=0;ua=(b[$>>1]|0)-(b[_>>1]|0)|(U^pa)&1|(b[$+2>>1]|0)-(b[_+2>>1]|0)|(d[$+4|0]|0)-(d[_+4|0]|0)}if((ua|0)==0){ra=la;sa=ma;ta=na;break}Iob(e,la,P,n,da,ga,K,T,_,0,s,t);ra=la+y|0;sa=la;ta=a[O]|0}}while(0);O=a[Z+8|0]|0;do{if((ta&1)==0){ja=38}else{if((O&1)==0){ja=38;break}va=(d[aa+6|0]|0)-(d[Z+6|0]|0)|(d[aa+5|0]|0)-(d[Z+5|0]|0)|(d[aa+7|0]|0)-(d[Z+7|0]|0)}}while(0);if((ja|0)==38){ja=0;va=(b[aa>>1]|0)-(b[Z>>1]|0)|(O^ta)&1|(b[aa+2>>1]|0)-(b[Z+2>>1]|0)|(d[aa+4|0]|0)-(d[Z+4|0]|0)}do{if((va|0)==0){wa=Q}else{pa=a[R]|0;do{if((pa&1)==0){ja=43}else{if((O&1)==0){ja=43;break}xa=(d[$+6|0]|0)-(d[Z+6|0]|0)|(d[$+5|0]|0)-(d[Z+5|0]|0)|(d[$+7|0]|0)-(d[Z+7|0]|0)}}while(0);if((ja|0)==43){ja=0;xa=(b[$>>1]|0)-(b[Z>>1]|0)|(pa^O)&1|(b[$+2>>1]|0)-(b[Z+2>>1]|0)|(d[$+4|0]|0)-(d[Z+4|0]|0)}if((xa|0)==0){wa=ma;break}U=a[oa]|0;do{if((U&1)==0){ja=48}else{if((O&1)==0){ja=48;break}ya=(d[_+6|0]|0)-(d[Z+6|0]|0)|(d[_+5|0]|0)-(d[Z+5|0]|0)|(d[_+7|0]|0)-(d[Z+7|0]|0)}}while(0);if((ja|0)==48){ja=0;ya=(b[_>>1]|0)-(b[Z>>1]|0)|(U^O)&1|(b[_+2>>1]|0)-(b[Z+2>>1]|0)|(d[_+4|0]|0)-(d[Z+4|0]|0)}if((ya|0)==0){wa=sa;break}Iob(e,ra,P,n,da,ga,K,T,Z,0,s,t);wa=ra}}while(0);if((T|0)<=0){break}O=(K|0)>0;oa=0;do{R=ba(oa,l)|0;Q=R+j|0;pa=ba(oa+j|0,l)|0;i=pa+j|0;if(O){ia=ba(oa,n)|0;za=0;do{Aa=za+ia|0;Ba=ba(d[wa+Aa|0]|0,d[fa+(za+R)|0]|0)|0;Ca=(ba(d[sa+Aa|0]|0,d[fa+(Q+za)|0]|0)|0)+Ba|0;Ba=Ca+(ba(d[ma+Aa|0]|0,d[fa+(za+pa)|0]|0)|0)|0;Ca=(Ba+(ba(d[P+(Aa+B)|0]|0,d[fa+(i+za)|0]|0)|0)|0)>>>4;Ba=(b[5212984+(za+da<<1)>>1]|0)+8+Ca|0;Ca=Ba>>4;if(Ca>>>0>255>>>0){Da=(Ba>>31^255)&255}else{Da=Ca&255}a[o+(J+Aa)|0]=Da;za=za+1|0;}while((za|0)<(K|0))}oa=oa+1|0;}while((oa|0)<(T|0))}}while(0);if(S){T=N;do{K=(ba(T,n)|0)+M|0;UGb(o+K|0,m+K|0,j)|0;T=T+1|0;}while((T|0)<0)}T=N+j|0;if((t|0)<(T|0)){S=t;do{K=(ba(S,n)|0)+M|0;UGb(o+K|0,m+K|0,j)|0;S=S+1|0;}while((S|0)<(T|0))}if(L&(j|0)>0){S=-M|0;K=N;do{P=(ba(K,n)|0)+M|0;UGb(o+P|0,m+P|0,S)|0;K=K+1|0;}while((K|0)<(T|0))}K=M+j|0;if((K|0)>(s|0)&(j|0)>0){S=K-s|0;K=N;do{L=(ba(K,n)|0)+s|0;UGb(o+L|0,m+L|0,S)|0;K=K+1|0;}while((K|0)<(T|0))}T=(ba(N,n)|0)+M|0;Ea=(Pe[c[E>>2]&255](F,m+T|0,o+T|0,n,j)|0)+G|0;T=H+1|0;if((T|0)>=9){break}G=Ea;H=T;I=c[p>>2]|0;q=c[h>>2]|0}h=(ba(r,g)|0)+f|0;q=c[x>>2]|0;x=q+(h*10|0)|0;p=h+1|0;I=a[q+(h*10|0)+8|0]|0;H=(I&1)==0;G=a[q+(p*10|0)+8|0]|0;do{if(H){ja=74}else{if((G&1)==0){ja=74;break}Fa=(d[q+(h*10|0)+6|0]|0)-(d[q+(p*10|0)+6|0]|0)|(d[q+(h*10|0)+5|0]|0)-(d[q+(p*10|0)+5|0]|0)|(d[q+(h*10|0)+7|0]|0)-(d[q+(p*10|0)+7|0]|0)}}while(0);if((ja|0)==74){Fa=(b[x>>1]|0)-(b[q+(p*10|0)>>1]|0)|(G^I)&1|(b[q+(h*10|0)+2>>1]|0)-(b[q+(p*10|0)+2>>1]|0)|(d[q+(h*10|0)+4|0]|0)-(d[q+(p*10|0)+4|0]|0)}do{if((Fa|0)==0){p=h+r|0;G=a[q+(p*10|0)+8|0]|0;do{if(H){ja=79}else{if((G&1)==0){ja=79;break}Ga=(d[q+(h*10|0)+6|0]|0)-(d[q+(p*10|0)+6|0]|0)|(d[q+(h*10|0)+5|0]|0)-(d[q+(p*10|0)+5|0]|0)|(d[q+(h*10|0)+7|0]|0)-(d[q+(p*10|0)+7|0]|0)}}while(0);if((ja|0)==79){Ga=(b[x>>1]|0)-(b[q+(p*10|0)>>1]|0)|(G^I)&1|(b[q+(h*10|0)+2>>1]|0)-(b[q+(p*10|0)+2>>1]|0)|(d[q+(h*10|0)+4|0]|0)-(d[q+(p*10|0)+4|0]|0)}if((Ga|0)!=0){Ha=0;Ia=0;break}M=p+1|0;N=a[q+(M*10|0)+8|0]|0;do{if(H){ja=84}else{if((N&1)==0){ja=84;break}Ja=(d[q+(h*10|0)+6|0]|0)-(d[q+(M*10|0)+6|0]|0)|(d[q+(h*10|0)+5|0]|0)-(d[q+(M*10|0)+5|0]|0)|(d[q+(h*10|0)+7|0]|0)-(d[q+(M*10|0)+7|0]|0)}}while(0);if((ja|0)==84){Ja=(b[x>>1]|0)-(b[q+(M*10|0)>>1]|0)|(N^I)&1|(b[q+(h*10|0)+2>>1]|0)-(b[q+(M*10|0)+2>>1]|0)|(d[q+(h*10|0)+4|0]|0)-(d[q+(M*10|0)+4|0]|0)}if((Ja|0)!=0){Ha=0;Ia=0;break}Ha=aZa(e,f,g,2)|0;Ia=4}else{Ha=0;Ia=0}}while(0);do{Ha=(aZa(e,(c[986984+(Ia<<3)>>2]|0)+f|0,(c[986988+(Ia<<3)>>2]|0)+g|0,1)|0)+Ha|0;Ia=Ia+1|0;}while((Ia|0)<9);return(ba(Ha,v)|0)+Ea|0}function aZa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=c[e+7536>>2]|0;n=c[e+7528>>2]<<m;o=c[e+7532>>2]<<m;m=(ba(n,g)|0)+f|0;p=c[e+2139660>>2]|0;q=(f|0)!=0;if(q){r=p+((m-1|0)*10|0)|0}else{r=630256}do{if((g|0)==0){s=r;t=630256}else{u=m-n|0;v=p+(u*10|0)|0;if(q){w=p+((u-1|0)*10|0)|0}else{w=r}if((h+f|0)>=(n|0)){s=w;t=v;break}s=p+((h-n+m|0)*10|0)|0;t=v}}while(0);if(!((f|0)>-1&(n|0)>(f|0)&(o|0)>(g|0))){x=0;i=j;return x|0}if((a[p+(m*10|0)+8|0]&1)==0){g=p+(m*10|0)+4|0;_Ya(c[e+7388>>2]|0,k,l,d[g]|0,r,t,s);s=(c[k>>2]|0)-(b[p+(m*10|0)>>1]|0)|0;c[k>>2]=s;k=(c[l>>2]|0)-(b[p+(m*10|0)+2>>1]|0)|0;c[l>>2]=k;l=(s|0)>-1?s:-s|0;s=l<<1;t=s>>>0>65535>>>0;e=t?l>>>15&65535:s;s=t?16:0;if((e&65280|0)==0){y=s;z=e}else{y=s|8;z=e>>>8}e=(k|0)>-1?k:-k|0;k=e<<1;s=k>>>0>65535>>>0;t=s?e>>>15&65535:k;k=s?16:0;if((t&65280|0)==0){A=k;B=t}else{A=k|8;B=t>>>8}t=d[g]|0;g=t<<1;k=g&256;x=y+1+(d[1191992+z|0]|0)+A+(d[1191992+B|0]|0)+(d[1191992+((k|0)==0?g:t>>>7)|0]|0)+(k>>>5)<<1;i=j;return x|0}k=(d[r+5|0]|0)-(d[p+(m*10|0)+5|0]|0)|0;t=(k|0)>-1?k:-k|0;k=t<<1;g=k>>>0>65535>>>0;B=g?t>>>15&65535:k;k=g?16:0;if((B&65280|0)==0){C=k;D=B}else{C=k|8;D=B>>>8}B=(d[r+6|0]|0)-(d[p+(m*10|0)+6|0]|0)|0;k=(B|0)>-1?B:-B|0;B=k<<1;g=B>>>0>65535>>>0;t=g?k>>>15&65535:B;B=g?16:0;if((t&65280|0)==0){E=B;F=t}else{E=B|8;F=t>>>8}t=(d[r+7|0]|0)-(d[p+(m*10|0)+7|0]|0)|0;m=(t|0)>-1?t:-t|0;t=m<<1;p=t>>>0>65535>>>0;r=p?m>>>15&65535:t;t=p?16:0;if((r&65280|0)==0){G=t;H=r}else{G=t|8;H=r>>>8}x=((d[1191992+D|0]|0)+C+E+(d[1191992+F|0]|0)+G+(d[1191992+H|0]|0)<<1)+3|0;i=j;return x|0}function bZa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;e=c[a+60>>2]|0;f=e+32|0;c[f>>2]=c[a+416>>2];g=e+36|0;c[g>>2]=c[a+412>>2];h=c[a+96>>2]|0;if((h|0)==0){yDb(a,16,1913248,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}l=c[a+100>>2]|0;m=l>>>0>268435455>>>0?-8:l<<3;l=m>>>0>2147483639>>>0;n=l?0:h;h=l?8:m+8|0;m=n;l=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>6&3;m=h>>>0>2>>>0?2:h;o=e;c[o>>2]=l;do{if(l>>>0>1>>>0){p=n+(m>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&2)>>>24;p=m+8|0;r=h>>>0>p>>>0?p:h;c[o>>2]=q;p=n+(r>>>3)|0;s=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>24;p=r+8|0;r=h>>>0>p>>>0?p:h;p=e+4|0;c[p>>2]=s;if((q|0)!=2){break}q=n+(r>>>3)|0;s=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>30;q=r+2|0;r=h>>>0>q>>>0?q:h;c[f>>2]=s;q=n+(r>>>3)|0;t=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>28;q=r+4|0;r=h>>>0>q>>>0?q:h;q=c[483128+(t<<2)>>2]|0;c[g>>2]=q;t=a;yDb(t,32,2350488,(j=i,i=i+16|0,c[j>>2]=s,c[j+8>>2]=q,j)|0);i=j;q=c[f>>2]|0;if((q|0)>2){yDb(t,16,2002440,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}s=((r|0)<(h|0))+r|0;u=(d[n+(r>>>3)|0]|0)<<(r&7)>>>7&1;r=e+8|0;c[r>>2]=u;if((u|0)==0){v=s+3|0;w=h>>>0>v>>>0?v:h}else{w=s}s=n+(w>>>3)|0;v=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7)>>>30;s=w+2|0;x=h>>>0>s>>>0?s:h;s=e+12|0;c[s>>2]=v;do{if((v|0)==3){y=q}else{if((q|0)==2){y=2;break}yDb(t,16,2330120,(j=i,i=i+8|0,c[j>>2]=v,j)|0);i=j;k=-1094995529;i=b;return k|0}}while(0);q=n+(x>>>3)|0;z=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(x&7)>>>30;q=x+2|0;A=h>>>0>q>>>0?q:h;q=e+20|0;c[q>>2]=z;if((z|0)==0){yDb(t,16,2305672,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}B=n+(A>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>27;B=A+5|0;A=h>>>0>B>>>0?B:h;B=(C<<5)+32|0;C=e+16|0;c[C>>2]=B;if(((d[n+(A>>>3)|0]|0)&128>>>((A&7)>>>0)|0)==0){D=z;E=y;G=u;H=v;I=B}else{yDb(t,32,2287768,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;D=c[q>>2]|0;E=c[f>>2]|0;G=c[r>>2]|0;H=c[s>>2]|0;I=c[C>>2]|0}q=c[g>>2]|0;B=q;z=D*44100|0;A=eHb(B<<11|0>>>21,((q|0)<0|0?-1:0)<<11|B>>>21,z,(z|0)<0|0?-1:0)|0;z=A;A=e+40|0;c[A>>2]=z;B=ba(ba(E,z)|0,D)|0;q=e+44|0;c[q>>2]=B;J=c[p>>2]|0;yDb(t,32,1936928,(j=i,i=i+64|0,c[j>>2]=c[o>>2],c[j+8>>2]=J,c[j+16>>2]=G,c[j+24>>2]=H,c[j+32>>2]=I,c[j+40>>2]=z,c[j+48>>2]=B,c[j+56>>2]=D,j)|0);i=j;B=dEb(c[C>>2]|0,4)|0;c[e+48>>2]=B;z=c[C>>2]|0;if((z|0)>0){J=0;while(1){K=J+1|0;if(K>>>0<255>>>0){L=(d[J+1135650|0]|0)-1>>4}else{do{if(K>>>0<4096>>>0){M=(d[1135648+(K>>>4)|0]|0)>>>2}else{if(K>>>0<16384>>>0){M=(d[1135648+(K>>>6)|0]|0)>>>1;break}if(K>>>0<65536>>>0){M=d[1135648+(K>>>8)|0]|0;break}else{N=K>>>16;O=(N&65280|0)==0;P=((d[1191992+(O?N:K>>>24)|0]|0)+(O?0:8)|0)>>>1;O=K>>>((P+2|0)>>>0);N=d[1135648+(O>>>((P+8|0)>>>0))|0]|0;gHb(O,0,c[1199552+(N<<2)>>2]|0,0)|0;M=F+(N<<P)|0;break}}}while(0);L=M-((ba(M,M)|0)>>>0>K>>>0)|0}c[B+(J<<2)>>2]=L;P=c[C>>2]|0;if((K|0)<(P|0)){J=K}else{Q=P;break}}}else{Q=z}c[e+80>>2]=dEb(Q,4)|0;J=e+84|0;B=0;while(1){R=c[f>>2]|0;if((B|0)>=(R|0)){break}t=dEb(c[C>>2]|0,4)|0;c[J+(B<<2)>>2]=t;if((t|0)==0){k=-12;S=37;break}else{B=B+1|0}}if((S|0)==37){i=b;return k|0}B=e+56|0;J=0;C=R;while(1){if((J|0)>=(C|0)){break}z=dEb(c[A>>2]|0,4)|0;c[B+(J<<2)>>2]=z;if((z|0)==0){k=-12;S=37;break}J=J+1|0;C=c[f>>2]|0}if((S|0)==37){i=b;return k|0}c[e+52>>2]=dEb(c[q>>2]|0,4)|0;c[a+420>>2]=1;k=0;i=b;return k|0}}while(0);yDb(a,16,1892792,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}function cZa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;j=i;i=i+576|0;k=j|0;l=j+544|0;m=c[h+24>>2]|0;n=c[h+28>>2]|0;h=c[e+60>>2]|0;if((n|0)==0){o=0;i=j;return o|0}p=h+44|0;c[f+76>>2]=(c[p>>2]|0)/(c[e+416>>2]|0)|0;q=_$a(e,f,0)|0;if((q|0)<0){o=q;i=j;return o|0}q=c[f>>2]|0;f=l|0;TGb(f|0,-128|0,32)|0;fUa(k,m,n);gUa(k,214748364,248);m=h+80|0;e=c[m>>2]|0;r=h+16|0;s=c[r>>2]|0;do{if((s|0)>0){t=k+4|0;u=k|0;v=k+532|0;w=k+536|0;x=l+1|0;y=0;z=128;while(1){A=c[t>>2]|0;B=(ba(z,A)|0)>>8;C=A-B|0;c[t>>2]=C;A=c[u>>2]|0;do{if((A|0)<(C|0)){a[f]=a[k+16+z|0]|0;if((C|0)<256){D=C<<8;c[t>>2]=D;E=A<<8;c[u>>2]=E;F=c[v>>2]|0;if(F>>>0<(c[w>>2]|0)>>>0){G=d[F]|0|E;c[u>>2]=G;H=G}else{H=E}c[v>>2]=F+1;I=D;J=H}else{I=C;J=A}D=a[x]|0;F=(ba(D&255,I)|0)>>8;E=I-F|0;c[t>>2]=E;if((J|0)<(E|0)){K=0;L=x;M=D;N=J}else{G=1;O=x;P=F;F=E;E=J;Q=D;while(1){D=E-F|0;c[u>>2]=D;a[O]=a[(Q&255)+(k+272)|0]|0;c[t>>2]=P;if((P|0)<256){R=P<<8;c[t>>2]=R;S=D<<8;c[u>>2]=S;T=c[v>>2]|0;if(T>>>0<(c[w>>2]|0)>>>0){U=d[T]|0|S;c[u>>2]=U;V=U}else{V=S}c[v>>2]=T+1;W=R;X=V}else{W=P;X=D}D=G+1|0;R=l+((G|0)>9?10:D)|0;T=a[R]|0;S=(ba(T&255,W)|0)>>8;U=W-S|0;c[t>>2]=U;if((X|0)<(U|0)){K=G;L=R;M=T;N=X;break}else{G=D;O=R;P=S;F=U;E=X;Q=T}}}a[L]=a[(M&255)+(k+16)|0]|0;Q=c[t>>2]|0;if((Q|0)<256){E=Q<<8;c[t>>2]=E;F=N<<8;c[u>>2]=F;P=c[v>>2]|0;if(P>>>0<(c[w>>2]|0)>>>0){O=d[P]|0|F;c[u>>2]=O;Y=O}else{Y=F}c[v>>2]=P+1;Z=E;_=Y}else{Z=Q;_=N}if((K|0)>0){Q=1;E=K;P=Z;F=_;while(1){O=E-1|0;G=l+((O|0)>9?31:E+21|0)|0;T=d[G]|0;U=(ba(T,P)|0)>>8;S=P-U|0;c[t>>2]=S;do{if((F|0)<(S|0)){a[G]=a[k+16+T|0]|0;if((S|0)>=256){$=0;aa=S;ca=F;break}R=S<<8;c[t>>2]=R;D=F<<8;c[u>>2]=D;da=c[v>>2]|0;if(da>>>0<(c[w>>2]|0)>>>0){ea=d[da]|0|D;c[u>>2]=ea;fa=ea}else{fa=D}c[v>>2]=da+1;$=0;aa=R;ca=fa}else{R=F-S|0;c[u>>2]=R;a[G]=a[k+272+T|0]|0;c[t>>2]=U;if((U|0)>=256){$=1;aa=U;ca=R;break}da=U<<8;c[t>>2]=da;D=R<<8;c[u>>2]=D;R=c[v>>2]|0;if(R>>>0<(c[w>>2]|0)>>>0){ea=d[R]|0|D;c[u>>2]=ea;ga=ea}else{ga=D}c[v>>2]=R+1;$=1;aa=da;ca=ga}}while(0);U=$|Q<<1;if((O|0)>0){Q=U;E=O;P=aa;F=ca}else{ha=U;ia=aa;ja=ca;break}}}else{ha=1;ia=Z;ja=_}F=l+((K|0)>10?21:K+11|0)|0;P=d[F]|0;E=(ba(P,ia)|0)>>8;Q=ia-E|0;c[t>>2]=Q;do{if((ja|0)<(Q|0)){a[F]=a[k+16+P|0]|0;if((Q|0)>=256){ka=0;break}c[t>>2]=Q<<8;U=ja<<8;c[u>>2]=U;T=c[v>>2]|0;if(T>>>0<(c[w>>2]|0)>>>0){c[u>>2]=d[T]|0|U}c[v>>2]=T+1;ka=0}else{T=ja-Q|0;c[u>>2]=T;a[F]=a[k+272+P|0]|0;c[t>>2]=E;if((E|0)>=256){ka=1;break}c[t>>2]=E<<8;U=T<<8;c[u>>2]=U;T=c[v>>2]|0;if(T>>>0<(c[w>>2]|0)>>>0){c[u>>2]=d[T]|0|U}c[v>>2]=T+1;ka=1}}while(0);la=(ha^-ka)+ka|0}else{E=A-C|0;c[u>>2]=E;a[f]=a[k+272+z|0]|0;c[t>>2]=B;if((B|0)>=256){la=0;break}c[t>>2]=B<<8;P=E<<8;c[u>>2]=P;E=c[v>>2]|0;if(E>>>0<(c[w>>2]|0)>>>0){c[u>>2]=d[E]|0|P}c[v>>2]=E+1;la=0}}while(0);c[e+(y<<2)>>2]=la;B=y+1|0;if((B|0)>=(s|0)){break}y=B;z=d[f]|0}if((c[r>>2]|0)<=0){break}z=c[h+48>>2]|0;y=c[m>>2]|0;v=0;do{u=y+(v<<2)|0;c[u>>2]=ba(c[u>>2]|0,c[z+(v<<2)>>2]|0)|0;v=v+1|0;}while((v|0)<(c[r>>2]|0))}}while(0);s=h+8|0;do{if((c[s>>2]|0)==0){la=k+4|0;e=c[la>>2]|0;ka=d[f]|0;ha=(ba(ka,e)|0)>>8;ja=e-ha|0;c[la>>2]=ja;e=k|0;ia=c[e>>2]|0;if((ia|0)>=(ja|0)){K=ia-ja|0;c[e>>2]=K;a[f]=a[k+272+ka|0]|0;c[la>>2]=ha;if((ha|0)>=256){ma=0;break}c[la>>2]=ha<<8;ha=K<<8;c[e>>2]=ha;K=k+532|0;_=c[K>>2]|0;if(_>>>0<(c[k+536>>2]|0)>>>0){c[e>>2]=d[_]|0|ha}c[K>>2]=_+1;ma=0;break}a[f]=a[k+16+ka|0]|0;if((ja|0)<256){ka=ja<<8;c[la>>2]=ka;_=ia<<8;c[e>>2]=_;K=k+532|0;ha=c[K>>2]|0;if(ha>>>0<(c[k+536>>2]|0)>>>0){Z=d[ha]|0|_;c[e>>2]=Z;na=Z}else{na=_}c[K>>2]=ha+1;oa=ka;pa=na}else{oa=ja;pa=ia}ia=l+1|0;ja=a[ia]|0;ka=(ba(ja&255,oa)|0)>>8;ha=oa-ka|0;c[la>>2]=ha;if((pa|0)<(ha|0)){qa=0;ra=ia;sa=ja;ta=pa}else{K=k+532|0;_=k+536|0;Z=1;ca=ia;ia=ka;ka=ha;ha=pa;aa=ja;while(1){ja=ha-ka|0;c[e>>2]=ja;a[ca]=a[(aa&255)+(k+272)|0]|0;c[la>>2]=ia;if((ia|0)<256){$=ia<<8;c[la>>2]=$;ga=ja<<8;c[e>>2]=ga;fa=c[K>>2]|0;if(fa>>>0<(c[_>>2]|0)>>>0){N=d[fa]|0|ga;c[e>>2]=N;ua=N}else{ua=ga}c[K>>2]=fa+1;va=$;wa=ua}else{va=ia;wa=ja}ja=Z+1|0;$=l+((Z|0)>9?10:ja)|0;fa=a[$]|0;ga=(ba(fa&255,va)|0)>>8;N=va-ga|0;c[la>>2]=N;if((wa|0)<(N|0)){qa=Z;ra=$;sa=fa;ta=wa;break}else{Z=ja;ca=$;ia=ga;ka=N;ha=wa;aa=fa}}}a[ra]=a[(sa&255)+(k+16)|0]|0;aa=c[la>>2]|0;if((aa|0)<256){ha=aa<<8;c[la>>2]=ha;ka=ta<<8;c[e>>2]=ka;ia=k+532|0;ca=c[ia>>2]|0;if(ca>>>0<(c[k+536>>2]|0)>>>0){Z=d[ca]|0|ka;c[e>>2]=Z;xa=Z}else{xa=ka}c[ia>>2]=ca+1;ya=ha;za=xa}else{ya=aa;za=ta}if((qa|0)<=0){ma=16;break}aa=k+532|0;ha=k+536|0;ca=1;ia=qa;ka=ya;Z=za;while(1){K=ia-1|0;_=l+((K|0)>9?31:ia+21|0)|0;fa=d[_]|0;N=(ba(fa,ka)|0)>>8;ga=ka-N|0;c[la>>2]=ga;do{if((Z|0)<(ga|0)){a[_]=a[k+16+fa|0]|0;if((ga|0)>=256){Aa=0;Ba=ga;Ca=Z;break}$=ga<<8;c[la>>2]=$;ja=Z<<8;c[e>>2]=ja;Y=c[aa>>2]|0;if(Y>>>0<(c[ha>>2]|0)>>>0){M=d[Y]|0|ja;c[e>>2]=M;Da=M}else{Da=ja}c[aa>>2]=Y+1;Aa=0;Ba=$;Ca=Da}else{$=Z-ga|0;c[e>>2]=$;a[_]=a[k+272+fa|0]|0;c[la>>2]=N;if((N|0)>=256){Aa=1;Ba=N;Ca=$;break}Y=N<<8;c[la>>2]=Y;ja=$<<8;c[e>>2]=ja;$=c[aa>>2]|0;if($>>>0<(c[ha>>2]|0)>>>0){M=d[$]|0|ja;c[e>>2]=M;Ea=M}else{Ea=ja}c[aa>>2]=$+1;Aa=1;Ba=Y;Ca=Ea}}while(0);Fa=Aa|ca<<1;if((K|0)>0){ca=Fa;ia=K;ka=Ba;Z=Ca}else{break}}ma=Fa<<4}else{ma=1}}while(0);Fa=h+32|0;if((c[Fa>>2]|0)>0){Ca=h+84|0;Ba=h+56|0;Aa=h+40|0;Ea=k+4|0;Da=k|0;za=k+532|0;ya=k+536|0;qa=l+1|0;ta=h+52|0;xa=h+20|0;sa=0;ra=c[r>>2]|0;while(1){wa=c[m>>2]|0;va=Ca+(sa<<2)|0;ua=c[va>>2]|0;pa=ra-2|0;if((pa|0)>-1){oa=pa;while(1){pa=oa+1|0;if((pa|0)<(ra|0)){na=0;Z=c[ua+(oa<<2)>>2]|0;ka=pa;while(1){pa=c[wa+(na<<2)>>2]|0;ia=ua+(ka<<2)|0;ca=c[ia>>2]|0;aa=ba(ca,pa)|0;e=ba(pa,Z)|0;c[ia>>2]=(e>>>31)+ca+(e>>10);e=ka+1|0;if((e|0)<(ra|0)){na=na+1|0;Z=(aa>>>31)+Z+(aa>>10)|0;ka=e}else{break}}}if((oa|0)>0){oa=oa-1|0}else{break}}}oa=Ba+(sa<<2)|0;ua=c[oa>>2]|0;wa=c[Aa>>2]|0;a:do{if((wa|0)>0){ka=0;do{Z=c[Ea>>2]|0;na=d[f]|0;K=(ba(na,Z)|0)>>8;e=Z-K|0;c[Ea>>2]=e;Z=c[Da>>2]|0;do{if((Z|0)<(e|0)){a[f]=a[k+16+na|0]|0;if((e|0)<256){aa=e<<8;c[Ea>>2]=aa;ca=Z<<8;c[Da>>2]=ca;ia=c[za>>2]|0;if(ia>>>0<(c[ya>>2]|0)>>>0){pa=d[ia]|0|ca;c[Da>>2]=pa;Ga=pa}else{Ga=ca}c[za>>2]=ia+1;Ha=aa;Ia=Ga}else{Ha=e;Ia=Z}aa=a[qa]|0;ia=(ba(aa&255,Ha)|0)>>8;ca=Ha-ia|0;c[Ea>>2]=ca;if((Ia|0)<(ca|0)){Ja=0;Ka=qa;La=aa;Ma=Ia}else{pa=1;ha=qa;la=ia;ia=ca;ca=Ia;N=aa;while(1){aa=ca-ia|0;c[Da>>2]=aa;a[ha]=a[(N&255)+(k+272)|0]|0;c[Ea>>2]=la;if((la|0)<256){fa=la<<8;c[Ea>>2]=fa;_=aa<<8;c[Da>>2]=_;ga=c[za>>2]|0;if(ga>>>0<(c[ya>>2]|0)>>>0){Y=d[ga]|0|_;c[Da>>2]=Y;Na=Y}else{Na=_}c[za>>2]=ga+1;Oa=fa;Pa=Na}else{Oa=la;Pa=aa}aa=pa+1|0;fa=l+((pa|0)>9?10:aa)|0;ga=a[fa]|0;_=(ba(ga&255,Oa)|0)>>8;Y=Oa-_|0;c[Ea>>2]=Y;if((Pa|0)<(Y|0)){Ja=pa;Ka=fa;La=ga;Ma=Pa;break}else{pa=aa;ha=fa;la=_;ia=Y;ca=Pa;N=ga}}}a[Ka]=a[(La&255)+(k+16)|0]|0;N=c[Ea>>2]|0;if((N|0)<256){ca=N<<8;c[Ea>>2]=ca;ia=Ma<<8;c[Da>>2]=ia;la=c[za>>2]|0;if(la>>>0<(c[ya>>2]|0)>>>0){ha=d[la]|0|ia;c[Da>>2]=ha;Qa=ha}else{Qa=ia}c[za>>2]=la+1;Ra=ca;Sa=Qa}else{Ra=N;Sa=Ma}if((Ja|0)>0){N=1;ca=Ja;la=Ra;ia=Sa;while(1){ha=ca-1|0;pa=l+((ha|0)>9?31:ca+21|0)|0;O=d[pa]|0;ga=(ba(O,la)|0)>>8;Y=la-ga|0;c[Ea>>2]=Y;do{if((ia|0)<(Y|0)){a[pa]=a[k+16+O|0]|0;if((Y|0)>=256){Ta=0;Ua=Y;Va=ia;break}_=Y<<8;c[Ea>>2]=_;fa=ia<<8;c[Da>>2]=fa;aa=c[za>>2]|0;if(aa>>>0<(c[ya>>2]|0)>>>0){$=d[aa]|0|fa;c[Da>>2]=$;Wa=$}else{Wa=fa}c[za>>2]=aa+1;Ta=0;Ua=_;Va=Wa}else{_=ia-Y|0;c[Da>>2]=_;a[pa]=a[k+272+O|0]|0;c[Ea>>2]=ga;if((ga|0)>=256){Ta=1;Ua=ga;Va=_;break}aa=ga<<8;c[Ea>>2]=aa;fa=_<<8;c[Da>>2]=fa;_=c[za>>2]|0;if(_>>>0<(c[ya>>2]|0)>>>0){$=d[_]|0|fa;c[Da>>2]=$;Xa=$}else{Xa=fa}c[za>>2]=_+1;Ta=1;Ua=aa;Va=Xa}}while(0);ga=Ta|N<<1;if((ha|0)>0){N=ga;ca=ha;la=Ua;ia=Va}else{Ya=ga;Za=Ua;_a=Va;break}}}else{Ya=1;Za=Ra;_a=Sa}ia=l+((Ja|0)>10?21:Ja+11|0)|0;la=d[ia]|0;ca=(ba(la,Za)|0)>>8;N=Za-ca|0;c[Ea>>2]=N;do{if((_a|0)<(N|0)){a[ia]=a[k+16+la|0]|0;if((N|0)>=256){$a=0;break}c[Ea>>2]=N<<8;ga=_a<<8;c[Da>>2]=ga;O=c[za>>2]|0;if(O>>>0<(c[ya>>2]|0)>>>0){c[Da>>2]=d[O]|0|ga}c[za>>2]=O+1;$a=0}else{O=_a-N|0;c[Da>>2]=O;a[ia]=a[k+272+la|0]|0;c[Ea>>2]=ca;if((ca|0)>=256){$a=1;break}c[Ea>>2]=ca<<8;ga=O<<8;c[Da>>2]=ga;O=c[za>>2]|0;if(O>>>0<(c[ya>>2]|0)>>>0){c[Da>>2]=d[O]|0|ga}c[za>>2]=O+1;$a=1}}while(0);ab=(Ya^-$a)+$a|0}else{ca=Z-e|0;c[Da>>2]=ca;a[f]=a[k+272+na|0]|0;c[Ea>>2]=K;if((K|0)>=256){ab=0;break}c[Ea>>2]=K<<8;la=ca<<8;c[Da>>2]=la;ca=c[za>>2]|0;if(ca>>>0<(c[ya>>2]|0)>>>0){c[Da>>2]=d[ca]|0|la}c[za>>2]=ca+1;ab=0}}while(0);c[ua+(ka<<2)>>2]=ab;ka=ka+1|0;}while((ka|0)<(wa|0));if((c[Aa>>2]|0)<=0){break}ka=c[m>>2]|0;K=c[va>>2]|0;na=0;e=sa;while(1){Z=c[r>>2]|0;if(((c[xa>>2]|0)-1|0)>0){ca=0;la=e;ia=Z;while(1){N=ia-1|0;O=ba(c[K+(N<<2)>>2]|0,c[ka+(N<<2)>>2]|0)|0;N=(O>>31)-(O>>10)|0;O=ia-2|0;if((O|0)>-1){ga=ka+(O<<2)|0;pa=K+(O<<2)|0;Y=N;aa=O;while(1){O=c[ga>>2]|0;_=c[pa>>2]|0;fa=ba(_,O)|0;$=(fa>>31)+Y-(fa>>10)|0;fa=ba($,O)|0;c[pa+4>>2]=(fa>>>31)+_+(fa>>10);if((aa|0)>0){ga=ga-4|0;pa=pa-4|0;Y=$;aa=aa-1|0}else{bb=$;break}}}else{bb=N}aa=(bb|0)>1048576?1048576:bb;Y=(aa|0)<-1048576?-1048576:aa;c[K>>2]=Y;c[(c[ta>>2]|0)+(la<<2)>>2]=Y;Y=(c[Fa>>2]|0)+la|0;aa=ca+1|0;pa=c[r>>2]|0;if((aa|0)<((c[xa>>2]|0)-1|0)){ca=aa;la=Y;ia=pa}else{cb=Y;db=pa;break}}}else{cb=e;db=Z}ia=ba(c[(c[oa>>2]|0)+(na<<2)>>2]|0,ma)|0;la=db-1|0;ca=ba(c[K+(la<<2)>>2]|0,c[ka+(la<<2)>>2]|0)|0;la=(ca>>31)+ia-(ca>>10)|0;ca=db-2|0;if((ca|0)>-1){ia=ka+(ca<<2)|0;pa=K+(ca<<2)|0;Y=la;aa=ca;while(1){ca=c[ia>>2]|0;ga=c[pa>>2]|0;$=ba(ga,ca)|0;fa=($>>31)+Y-($>>10)|0;$=ba(fa,ca)|0;c[pa+4>>2]=($>>>31)+ga+($>>10);if((aa|0)>0){ia=ia-4|0;pa=pa-4|0;Y=fa;aa=aa-1|0}else{eb=fa;break}}}else{eb=la}aa=(eb|0)>1048576?1048576:eb;Y=(aa|0)<-1048576?-1048576:aa;c[K>>2]=Y;c[(c[ta>>2]|0)+(cb<<2)>>2]=Y;Y=na+1|0;if((Y|0)>=(c[Aa>>2]|0)){break a}na=Y;e=(c[Fa>>2]|0)+cb|0}}}while(0);oa=c[r>>2]|0;if((oa|0)>0){wa=c[va>>2]|0;ua=c[ta>>2]|0;e=0;while(1){na=c[Fa>>2]|0;c[wa+(e<<2)>>2]=c[ua+((c[p>>2]|0)+sa-na-(ba(na,e)|0)<<2)>>2];na=e+1|0;K=c[r>>2]|0;if((na|0)<(K|0)){e=na}else{fb=K;break}}}else{fb=oa}e=sa+1|0;if((e|0)<(c[Fa>>2]|0)){sa=e;ra=fb}else{break}}}fb=c[h+12>>2]|0;do{if((fb|0)==0){if((c[p>>2]|0)<=0){break}ra=c[h+52>>2]|0;sa=0;do{r=ra+(sa<<2)|0;ta=c[r>>2]|0;cb=ra+(sa+1<<2)|0;Aa=(ta+1>>1)+(c[cb>>2]|0)|0;c[cb>>2]=Aa;c[r>>2]=ta-Aa;sa=(c[Fa>>2]|0)+sa|0;}while((sa|0)<(c[p>>2]|0))}else if((fb|0)==2){if((c[p>>2]|0)<=0){break}sa=c[h+52>>2]|0;ra=0;do{oa=sa+(ra<<2)|0;c[oa>>2]=(c[oa>>2]|0)+(c[sa+(ra+1<<2)>>2]|0);ra=(c[Fa>>2]|0)+ra|0;}while((ra|0)<(c[p>>2]|0))}else if((fb|0)==1){if((c[p>>2]|0)<=0){break}ra=c[h+52>>2]|0;sa=0;do{oa=ra+(sa+1<<2)|0;c[oa>>2]=(c[oa>>2]|0)+(c[ra+(sa<<2)>>2]|0);sa=(c[Fa>>2]|0)+sa|0;}while((sa|0)<(c[p>>2]|0))}}while(0);Fa=c[p>>2]|0;do{if((c[s>>2]|0)==0){if((Fa|0)<=0){break}fb=c[h+52>>2]|0;sa=0;while(1){ra=fb+(sa<<2)|0;c[ra>>2]=(c[ra>>2]|0)+8>>4;ra=sa+1|0;oa=c[p>>2]|0;if((ra|0)<(oa|0)){sa=ra}else{gb=oa;hb=162;break}}}else{gb=Fa;hb=162}}while(0);do{if((hb|0)==162){if((gb|0)<=0){break}Fa=c[h+52>>2]|0;p=0;do{s=c[Fa+(p<<2)>>2]|0;if((s+32768|0)>>>0>65535>>>0){ib=(s>>31^32767)&65535}else{ib=s&65535}b[q+(p<<1)>>1]=ib;p=p+1|0;}while((p|0)<(gb|0))}}while(0);c[g>>2]=1;o=n;i=j;return o|0}function dZa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;$Db(b+52|0);$Db(b+48|0);$Db(b+80|0);a=b+32|0;if((c[a>>2]|0)<=0){return 0}d=b+84|0;e=b+56|0;b=0;do{$Db(d+(b<<2)|0);$Db(e+(b<<2)|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function eZa(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;f=c[b+60>>2]|0;g=f;c[g>>2]=2;j=b+416|0;k=c[j>>2]|0;if((k|0)>2){yDb(b,16,2002440,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=e;return m|0}n=f+12|0;c[n>>2]=(k|0)==2?0:3;if((c[(c[b+12>>2]|0)+12>>2]|0)==1397706316){c[f+8>>2]=1;c[f+16>>2]=32;c[f+20>>2]=1;h[f+24>>3]=0.0;o=32}else{c[f+16>>2]=128;c[f+20>>2]=2;h[f+24>>3]=1.0;o=128}k=f+16|0;p=dEb(o,4)|0;c[f+48>>2]=p;o=c[k>>2]|0;if((o|0)>0){q=0;while(1){r=q+1|0;if(r>>>0<255>>>0){s=(d[q+1135650|0]|0)-1>>4}else{do{if(r>>>0<4096>>>0){t=(d[1135648+(r>>>4)|0]|0)>>>2}else{if(r>>>0<16384>>>0){t=(d[1135648+(r>>>6)|0]|0)>>>1;break}if(r>>>0<65536>>>0){t=d[1135648+(r>>>8)|0]|0;break}else{u=r>>>16;v=(u&65280|0)==0;w=((d[1191992+(v?u:r>>>24)|0]|0)+(v?0:8)|0)>>>1;v=r>>>((w+2|0)>>>0);u=d[1135648+(v>>>((w+8|0)>>>0))|0]|0;gHb(v,0,c[1199552+(u<<2)>>2]|0,0)|0;t=F+(u<<w)|0;break}}}while(0);s=t-((ba(t,t)|0)>>>0>r>>>0)|0}c[p+(q<<2)>>2]=s;w=c[k>>2]|0;if((r|0)<(w|0)){q=r}else{y=w;break}}}else{y=o}o=c[j>>2]|0;j=f+32|0;c[j>>2]=o;q=c[b+412>>2]|0;s=f+36|0;c[s>>2]=q;p=q;t=f+20|0;w=c[t>>2]|0;u=w*44100|0;v=eHb(p<<11|0>>>21,((q|0)<0|0?-1:0)<<11|p>>>21,u,(u|0)<0|0?-1:0)|0;u=v;v=f+40|0;c[v>>2]=u;p=f+44|0;c[p>>2]=ba(ba(o,u)|0,w)|0;w=ba(o,y)|0;y=f+68|0;c[y>>2]=w;o=dEb(w,4)|0;c[f+64>>2]=o;if((o|0)==0){m=-12;i=e;return m|0}o=dEb(c[k>>2]|0,4)|0;c[f+80>>2]=o;if((o|0)==0){m=-12;i=e;return m|0}o=f+56|0;w=0;while(1){if((w|0)>=(c[j>>2]|0)){break}u=dEb(c[v>>2]|0,4)|0;c[o+(w<<2)>>2]=u;if((u|0)==0){m=-12;z=62;break}else{w=w+1|0}}if((z|0)==62){i=e;return m|0}c[f+52>>2]=dEb(c[p>>2]|0,4)|0;z=(c[y>>2]<<1)+(c[p>>2]|0)|0;c[f+76>>2]=z;y=dEb(z,4)|0;c[f+72>>2]=y;if((y|0)==0){m=-12;i=e;return m|0}y=cEb(16)|0;c[b+96>>2]=y;if((y|0)==0){m=-12;i=e;return m|0}z=c[g>>2]|0;w=z;if((z|0)>0){if((z|0)>1){o=c[f+4>>2]|(z<<8|z)<<8;w=o;A=8;B=o<<2}else{A=24;B=4}o=B|c[j>>2];w=o;j=c[s>>2]|0;if((j|0)==24e3){C=6}else if((j|0)==32e3){C=5}else if((j|0)==16e3){C=7}else if((j|0)==96e3){C=3}else if((j|0)==48e3){C=4}else if((j|0)==8e3){C=8}else if((j|0)==22050){C=1}else if((j|0)==11025){C=2}else if((j|0)==44100){C=0}else{C=-22}j=o<<4|C;w=j;C=f+8|0;D=A;E=C;G=C;H=j}else{j=f+8|0;D=30;E=j;G=j;H=z}z=H<<1|c[G>>2];G=D-1|0;w=z;if((c[E>>2]|0)==0){if((G|0)>3){I=D-4|0;J=z<<3|4;K=y}else{H=y;x=fe(4>>>((4-D|0)>>>0)|z<<G|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;I=D+28|0;J=4;K=y+4|0}w=J;L=I;M=K;N=J}else{L=G;M=y;N=z}z=c[n>>2]|0;if((L|0)>2){O=L-2|0;P=N<<2|z;Q=M}else{G=M;x=fe(N<<L|z>>>((2-L|0)>>>0)|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;O=L+30|0;P=z;Q=M+4|0}w=P;M=c[t>>2]|0;if((O|0)>2){R=O-2|0;S=M|P<<2;T=Q}else{z=Q;x=fe(M>>>((2-O|0)>>>0)|P<<O|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;R=O+30|0;S=M;T=Q+4|0}w=S;Q=(c[k>>2]>>5)-1|0;if((R|0)>5){U=R-5|0;V=Q|S<<5;W=T}else{M=T;x=fe(Q>>>((5-R|0)>>>0)|S<<R|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;U=R+27|0;V=Q;W=T+4|0}w=V;if((U|0)>1){X=U-1|0;Y=V<<1;Z=W}else{T=W;x=fe(V<<U|0)|0;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;X=U+31|0;Y=0;Z=W+4|0}w=Y;if((X|0)<32){W=Y<<X;w=W;Y=((31-X|0)>>>3)+1|0;U=W>>>24&255;W=X;X=Z;while(1){a[X]=U;T=w;w=T<<8;V=W+8|0;if((V|0)<32){U=T>>>16&255;W=V;X=X+1|0}else{break}}_=Z+Y|0}else{_=Z}w=0;c[b+100>>2]=(_-y<<3|0)/8|0;y=c[f+4>>2]|0;f=c[E>>2]|0;E=c[n>>2]|0;n=c[k>>2]|0;k=c[v>>2]|0;_=c[p>>2]|0;p=c[t>>2]|0;yDb(b,32,1936928,(l=i,i=i+64|0,c[l>>2]=c[g>>2],c[l+8>>2]=y,c[l+16>>2]=f,c[l+24>>2]=E,c[l+32>>2]=n,c[l+40>>2]=k,c[l+48>>2]=_,c[l+56>>2]=p,l)|0);i=l;c[b+424>>2]=ba(c[t>>2]|0,c[v>>2]|0)|0;m=0;i=e;return m|0}function fZa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0.0,K=0,L=0.0,M=0.0,N=0.0,O=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;j=i;i=i+576|0;k=j|0;l=j+544|0;m=c[a+60>>2]|0;n=c[f>>2]|0;f=m+44|0;o=((c[f>>2]|0)*5|0)+1e3|0;p=r0a(a,e,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=j;return q|0}p=e+28|0;eUa(k,c[e+24>>2]|0,c[p>>2]|0);gUa(k,214748364,248);e=l|0;TGb(e|0,-128|0,32)|0;o=c[f>>2]|0;if((o|0)>0){a=c[m+52>>2]|0;r=0;while(1){c[a+(r<<2)>>2]=b[n+(r<<1)>>1]|0;s=r+1|0;t=c[f>>2]|0;if((s|0)<(t|0)){r=s}else{u=t;break}}}else{u=o}o=m+8|0;if((c[o>>2]|0)==0&(u|0)>0){r=c[m+52>>2]|0;n=0;while(1){a=r+(n<<2)|0;c[a>>2]=c[a>>2]<<4;a=n+1|0;t=c[f>>2]|0;if((a|0)<(t|0)){n=a}else{v=t;break}}}else{v=u}u=c[m+12>>2]|0;do{if((u|0)==0){if((v|0)<=0){break}n=c[m+52>>2]|0;r=m+32|0;t=0;do{a=n+(t+1<<2)|0;s=c[a>>2]|0;w=n+(t<<2)|0;x=(c[w>>2]|0)+s|0;c[w>>2]=x;c[a>>2]=s-(x+1>>1);t=(c[r>>2]|0)+t|0;}while((t|0)<(c[f>>2]|0))}else if((u|0)==2){if((v|0)<=0){break}t=c[m+52>>2]|0;r=m+32|0;n=0;do{x=t+(n<<2)|0;c[x>>2]=(c[x>>2]|0)-(c[t+(n+1<<2)>>2]|0);n=(c[r>>2]|0)+n|0;}while((n|0)<(c[f>>2]|0))}else if((u|0)==1){if((v|0)<=0){break}n=c[m+52>>2]|0;r=m+32|0;t=0;do{x=n+(t+1<<2)|0;c[x>>2]=(c[x>>2]|0)-(c[n+(t<<2)>>2]|0);t=(c[r>>2]|0)+t|0;}while((t|0)<(c[f>>2]|0))}}while(0);v=m+72|0;u=m+76|0;TGb(c[v>>2]|0,0,c[u>>2]<<2|0)|0;t=m+68|0;r=c[t>>2]|0;if((r|0)>0){n=c[m+64>>2]|0;x=c[v>>2]|0;s=0;while(1){a=s+1|0;c[x+(s<<2)>>2]=c[n+(s<<2)>>2];w=c[t>>2]|0;if((a|0)<(w|0)){s=a}else{y=a;z=w;break}}}else{y=0;z=r}if((c[f>>2]|0)>0){r=c[m+52>>2]|0;s=c[v>>2]|0;n=y;x=0;while(1){A=n+1|0;c[s+(n<<2)>>2]=c[r+(x<<2)>>2];w=x+1|0;if((w|0)<(c[f>>2]|0)){n=A;x=w}else{break}}B=A;C=c[t>>2]|0}else{B=y;C=z}do{if((C|0)>0){z=c[v>>2]|0;y=B;A=0;while(1){c[z+(y<<2)>>2]=0;x=A+1|0;D=c[t>>2]|0;if((x|0)<(D|0)){y=y+1|0;A=x}else{break}}if((D|0)<=0){break}A=c[m+52>>2]|0;y=c[m+64>>2]|0;z=0;x=D;do{c[y+(z<<2)>>2]=c[A+(z-x+(c[f>>2]|0)<<2)>>2];z=z+1|0;x=c[t>>2]|0;}while((z|0)<(x|0))}}while(0);f=c[v>>2]|0;D=c[u>>2]|0;u=m+80|0;B=c[u>>2]|0;C=m+16|0;x=c[C>>2]|0;z=m+32|0;A=c[z>>2]|0;y=c[m+48>>2]|0;n=dEb(D,4)|0;r=n;UGb(n|0,f|0,D<<2)|0;if((x|0)>0){s=0;while(1){w=s+1|0;a=ba(w,A)|0;E=f+(a<<2)|0;F=D-a|0;a=(F|0)>0;do{if(a){G=0.0;H=E;I=r;J=0.0;K=F;while(1){L=+(c[I>>2]|0);M=J+L*L;N=G+ +(c[H>>2]|0)*L;O=K-1|0;if((O|0)>0){G=N;H=H+4|0;I=I+4|0;J=M;K=O}else{break}}if(M==0.0){S=36;break}K=c[y+(s<<2)>>2]|0;T=~~+P((-0.0-N)/M*1024.0/+(K|0)+.5);U=K}else{S=36}}while(0);if((S|0)==36){S=0;T=0;U=c[y+(s<<2)>>2]|0}K=1024/(U|0)|0;I=(T|0)>(K|0)?K:T;H=(K|0)<(-I|0)?-K|0:I;c[B+(s<<2)>>2]=H;I=ba(H,c[y+(s<<2)>>2]|0)|0;if(a){H=E;K=r;O=F;while(1){V=c[H>>2]|0;W=c[K>>2]|0;X=ba(W,I)|0;c[H>>2]=(X>>>31)+V+(X>>10);X=ba(V,I)|0;c[K>>2]=(X>>>31)+W+(X>>10);X=O-1|0;if((X|0)>0){H=H+4|0;K=K+4|0;O=X}else{break}}}if((w|0)<(x|0)){s=w}else{break}}}ZDb(n);hZa(k,e,c[u>>2]|0,c[C>>2]|0);C=c[z>>2]|0;if((C|0)>0){u=m+40|0;n=m+20|0;s=m+56|0;x=0;r=c[u>>2]|0;y=C;while(1){if((r|0)>0){B=s+(x<<2)|0;T=(c[t>>2]|0)+x|0;U=0;while(1){D=c[n>>2]|0;if((D|0)>0){f=c[v>>2]|0;A=c[z>>2]|0;O=ba(A,(D|0)>1?D:1)|0;K=0;H=T;I=0;while(1){Y=(c[f+(H<<2)>>2]|0)+I|0;F=K+1|0;if((F|0)<(D|0)){K=F;H=A+H|0;I=Y}else{break}}Z=T+O|0;_=Y}else{Z=T;_=0}c[(c[B>>2]|0)+(U<<2)>>2]=_;I=U+1|0;$=c[u>>2]|0;if((I|0)<($|0)){T=Z;U=I}else{break}}aa=$;ca=c[z>>2]|0}else{aa=r;ca=y}U=x+1|0;if((U|0)<(ca|0)){x=U;r=aa;y=ca}else{da=ca;break}}}else{da=C}if((c[o>>2]|0)==0){C=c[m+40>>2]|0;a:do{if((da|0)>0){ca=m+56|0;if((C|0)>0){ea=0;fa=0.0;ga=0.0}else{y=0;while(1){aa=y+1|0;if((aa|0)<(da|0)){y=aa}else{ha=0.0;ia=0.0;break a}}}while(1){y=c[ca+(ea<<2)>>2]|0;aa=0;M=fa;N=ga;do{J=+(c[y+(aa<<2)>>2]|0);N=N+J*J;M=M+ +Q(+J);aa=aa+1|0;}while((aa|0)<(C|0));aa=ea+1|0;if((aa|0)<(da|0)){ea=aa;fa=M;ga=N}else{ha=M;ia=N;break}}}else{ha=0.0;ia=0.0}}while(0);ga=+(ba(C,da)|0);fa=+R(ia/ga);ia=ha*1.4142135623730951/ga;if(fa>ia){ja=fa+(fa-ia)*3.0}else{ja=fa}C=~~(ja*+h[m+24>>3]*.6*.0625);do{if((C|0)<1){ka=1;S=62}else{ea=(C|0)>65534?65534:C;if((ea|0)!=0){ka=ea;S=62;break}iZa(k,e,1);la=0}}while(0);b:do{if((S|0)==62){C=(ka|0)>-1?ka:-ka|0;ea=C>>>0>65535>>>0;ca=ea?C>>>16:C;aa=ea?16:0;if((ca&65280|0)==0){ma=aa;na=ca}else{ma=aa|8;na=ca>>>8}ca=(d[1191992+na|0]|0)+ma|0;iZa(k,e,0);if((ca|0)>=10){aa=0;while(1){ea=aa+1|0;iZa(k,l+((aa|0)>9?10:ea)|0,1);if((ea|0)<(ca|0)){aa=ea}else{break}}iZa(k,l+10|0,0);aa=ca;while(1){ea=aa-1|0;iZa(k,l+((ea|0)>9?31:aa+21|0)|0,C>>>(ea>>>0)&1);if((ea|0)>0){aa=ea}else{la=ka;break b}}}aa=l+1|0;if((ca|0)>0){oa=0;pa=aa}else{iZa(k,aa,0);la=ka;break}while(1){iZa(k,pa,1);aa=oa+1|0;ea=l+(oa+2)|0;if((aa|0)<(ca|0)){oa=aa;pa=ea}else{break}}iZa(k,l+(ca+1)|0,0);ea=ca;while(1){aa=ea-1|0;iZa(k,l+(ea+21)|0,C>>>(aa>>>0)&1);if((aa|0)>0){ea=aa}else{la=ka;break}}}}while(0);qa=la<<4;ra=c[z>>2]|0}else{qa=0;ra=da}if((ra|0)>0){ra=m+56|0;da=m+40|0;m=qa>>1;la=-m|0;ka=0;do{l=c[da>>2]|0;if((c[o>>2]|0)==0&(l|0)>0){pa=c[ra+(ka<<2)>>2]|0;oa=0;while(1){ma=pa+(oa<<2)|0;na=c[ma>>2]|0;c[ma>>2]=(((na|0)>0?m:la)+na|0)/(qa|0)|0;na=oa+1|0;ma=c[da>>2]|0;if((na|0)<(ma|0)){oa=na}else{sa=ma;break}}}else{sa=l}hZa(k,e,c[ra+(ka<<2)>>2]|0,sa);ka=ka+1|0;}while((ka|0)<(c[z>>2]|0))}c[p>>2]=hUa(k)|0;c[g>>2]=1;q=0;i=j;return q|0}function gZa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b+32|0;if((c[a>>2]|0)>0){d=b+56|0;e=0;do{$Db(d+(e<<2)|0);e=e+1|0;}while((e|0)<(c[a>>2]|0))}$Db(b+80|0);$Db(b+64|0);$Db(b+48|0);$Db(b+72|0);$Db(b+52|0);return 0}function hZa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((f|0)<=0){return}g=b+1|0;h=b+10|0;i=b+21|0;j=0;do{k=c[e+(j<<2)>>2]|0;do{if((k|0)==0){iZa(a,b,1)}else{l=(k|0)>-1?k:-k|0;m=l>>>0>65535>>>0;n=m?l>>>16:l;o=m?16:0;if((n&65280|0)==0){p=o;q=n}else{p=o|8;q=n>>>8}n=(d[1191992+q|0]|0)+p|0;iZa(a,b,0);if((n|0)>=10){o=0;while(1){m=o+1|0;iZa(a,b+((o|0)>9?10:m)|0,1);if((m|0)<(n|0)){o=m}else{break}}iZa(a,h,0);o=n;while(1){m=o-1|0;iZa(a,b+((m|0)>9?31:o+21|0)|0,l>>>(m>>>0)&1);if((m|0)>0){o=m}else{break}}iZa(a,i,k>>>31);break}if((n|0)>0){o=0;m=g;while(1){iZa(a,m,1);r=o+1|0;s=b+(o+2)|0;if((r|0)<(n|0)){o=r;m=s}else{break}}iZa(a,b+(n+1)|0,0);m=n;while(1){o=m-1|0;iZa(a,b+(m+21)|0,l>>>(o>>>0)&1);if((o|0)>0){m=o}else{break}}}else{iZa(a,g,0)}iZa(a,b+(n+11)|0,k>>>31)}}while(0);j=j+1|0;}while((j|0)<(f|0));return}function iZa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b+4|0;h=c[g>>2]|0;i=(ba(d[e]|0,h)|0)>>8;j=h-i|0;if((f|0)==0){c[g>>2]=j;k=(d[e]|0)+(b+16)|0}else{f=b|0;c[f>>2]=(c[f>>2]|0)+j;c[g>>2]=i;k=(d[e]|0)+(b+272)|0}a[e]=a[k]|0;if((c[g>>2]|0)>=256){return}k=b+12|0;e=b|0;i=b+532|0;j=b+8|0;b=c[k>>2]|0;f=c[e>>2]|0;while(1){do{if((b|0)<0){h=f>>8;c[k>>2]=h;l=h;m=f}else{if((f|0)<65281){h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=-1;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>8;c[k>>2]=n;l=n;m=h;break}if((f|0)<=65535){c[j>>2]=(c[j>>2]|0)+1;l=b;m=f;break}h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b+1;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=0;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>>8&255;c[k>>2]=n;l=n;m=h}}while(0);h=m<<8&65280;c[e>>2]=h;n=c[g>>2]<<8;c[g>>2]=n;if((n|0)<256){b=l;f=h}else{break}}return}function jZa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;g=i;i=i+80|0;h=g|0;j=c[f+24>>2]|0;k=f+28|0;f=c[k>>2]|0;if((c[b+120>>2]|0)==0){l=-1;i=g;return l|0}if((c[b+124>>2]|0)==0){l=-1;i=g;return l|0}m=cEb(f+1024|0)|0;if((m|0)==0){l=-1;i=g;return l|0}a[m]=-1;a[m+1|0]=-40;UGb(m+2|0,434520,70)|0;UGb(m+7|0,432560,64)|0;UGb(m+72|0,432624,64)|0;UGb(m+136|0,434656,420)|0;UGb(m+556|0,434496,19)|0;n=m+561|0;x=de(c[b+132>>2]&65535|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;n=m+563|0;x=de(c[b+128>>2]&65535|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;UGb(m+575|0,434480,14)|0;do{if((c[b+48>>2]|0)==108){n=f-2|0;o=f+1022|0;if(!((n|0)>2&(o|0)>589)){p=589;break}q=-433-f|0;r=4-f|0;s=q>>>0>r>>>0?q:r;r=2;q=589;while(1){t=q+1|0;a[m+q|0]=a[j+r|0]|0;u=r+1|0;if((u|0)<(n|0)&(t|0)<(o|0)){r=u;q=t}else{break}}p=589-s|0}else{q=f+1021|0;if((f|0)>14&(q|0)>589){v=14;w=589}else{p=589;break}while(1){r=j+v|0;o=w+1|0;a[m+w|0]=a[r]|0;if((a[r]|0)==-1){a[m+o|0]=0;y=w+2|0}else{y=o}o=v+1|0;if((o|0)<(f|0)&(y|0)<(q|0)){v=o;w=y}else{p=y;break}}}}while(0);a[m+p|0]=-1;a[m+(p+1)|0]=-39;vZ(h);c[h+24>>2]=m;c[h+28>>2]=p+2;p=BLa(b,d,e,h)|0;ZDb(m);if((p|0)<0){l=p;i=g;return l|0}l=c[k>>2]|0;i=g;return l|0}function kZa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0;h=i;i=i+10640|0;j=h|0;k=h+8|0;l=h+264|0;m=h+272|0;n=h+8464|0;o=h+8472|0;p=h+8480|0;q=h+8488|0;r=h+8496|0;s=h+8504|0;t=h+8512|0;u=h+8520|0;v=h+8528|0;w=h+8536|0;x=h+8544|0;y=h+8552|0;z=h+8560|0;A=h+8568|0;B=h+10616|0;C=h+10624|0;D=h+10632|0;E=e;c[w>>2]=-1;c[x>>2]=-1;c[y>>2]=-1;c[z>>2]=-1;G=c[g+24>>2]|0;H=g+28|0;I=c[H>>2]|0;J=G+I|0;K=HZ(g,73,B)|0;if((K|0)!=0&(c[B>>2]|0)==16){B=K;c[w>>2]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24;B=K+4|0;c[x>>2]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24;B=K+8|0;c[y>>2]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24;B=K+12|0;c[z>>2]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24}B=c[H>>2]|0;if((B|0)<1){L=B;i=h;return L|0}a:do{if((I|0)>0){B=b+12|0;K=A|0;M=A+2048|0;N=k|0;O=h+136|0;P=m|0;Q=m+128|0;R=m+256|0;S=m+384|0;T=M;U=j|0;V=b;W=j+1|0;X=j+2|0;Y=k+1|0;Z=A+2045|0;_=g+8|0;$=b+104|0;aa=C|0;ba=C+4|0;ca=g+48|0;da=D|0;ea=D+4|0;fa=G;while(1){if((a[fa]|0)==0){break a}if((c[(c[B>>2]|0)+12>>2]|0)==94216){ga=0;ha=fa;while(1){if((ga|0)>=2){ia=0;break}ja=xd(ha|0,2119768,(ka=i,i=i+96|0,c[ka>>2]=o,c[ka+8>>2]=p,c[ka+16>>2]=q,c[ka+24>>2]=u,c[ka+32>>2]=r,c[ka+40>>2]=s,c[ka+48>>2]=t,c[ka+56>>2]=v,c[ka+64>>2]=w,c[ka+72>>2]=y,c[ka+80>>2]=x,c[ka+88>>2]=z,ka)|0)|0;i=ka;la=hc(ha|0,2113784)|0;ma=ha+(((a[ha+la|0]|0)!=0)+la)|0;if((ja|0)>7){na=10;break}else{ga=ga+1|0;ha=ma}}if((na|0)==10){na=0;c[u>>2]=((((((c[o>>2]|0)*60|0)+(c[p>>2]|0)|0)*60|0)+(c[q>>2]|0)|0)*100|0)+((c[u>>2]|0)/10|0);c[v>>2]=((((((c[r>>2]|0)*60|0)+(c[s>>2]|0)|0)*60|0)+(c[t>>2]|0)|0)*100|0)+((c[v>>2]|0)/10|0);ia=ma}if((ia|0)==0){break a}else{oa=ia}}else{ha=c[_>>2]|0;ga=c[_+4>>2]|0;c[aa>>2]=1;c[ba>>2]=100;ja=KDb(ha,ga,$,C)|0;c[u>>2]=ja;ja=c[ca>>2]|0;ga=YGb(ja,(ja|0)<0|0?-1:0,c[_>>2]|0,c[_+4>>2]|0)|0;c[da>>2]=1;c[ea>>2]=100;ja=KDb(ga,F,$,D)|0;c[v>>2]=ja;oa=fa}ja=c[w>>2]|0;ga=c[x>>2]|0;ha=c[y>>2]|0;la=c[z>>2]|0;a[P]=0;a[Q]=a[2048024]|0;a[Q+1|0]=a[2048025]|0;a[Q+2|0]=a[2048026]|0;a[Q+3|0]=a[2048027]|0;a[Q+4|0]=a[2048028]|0;a[Q+5|0]=a[2048029]|0;a[R]=a[2002432]|0;a[R+1|0]=a[2002433]|0;a[R+2|0]=a[2002434]|0;a[R+3|0]=a[2002435]|0;a[R+4|0]=a[2002436]|0;a[S]=a[1965064]|0;a[S+1|0]=a[1965065]|0;a[S+2|0]=a[1965066]|0;a[S+3|0]=a[1965067]|0;a[S+4|0]=a[1965068]|0;a[S+5|0]=a[1965069]|0;if((ga|ja|0)>-1){do{if((la|ha|0)>-1){if((ha|0)==(ja|0)&(la|0)==(ga|0)){na=17;break}Lb(K|0,2048,1936896,(ka=i,i=i+32|0,c[ka>>2]=ja,c[ka+8>>2]=ga,c[ka+16>>2]=ha,c[ka+24>>2]=la,ka)|0)|0;i=ka}else{na=17}}while(0);if((na|0)==17){na=0;Lb(K|0,2048,1913224,(ka=i,i=i+16|0,c[ka>>2]=ja,c[ka+8>>2]=ga,ka)|0)|0;i=ka}la=SGb(K|0)|0;ha=A+la|0;if((la|0)<2048){pa=oa;qa=ha;ra=1;sa=1;ta=0;na=19}else{ua=oa;va=ha}}else{pa=oa;qa=K;ra=1;sa=1;ta=0;na=19}b:do{if((na|0)==19){while(1){na=0;ha=a[pa]|0;if(ha<<24>>24==0){ua=pa;va=qa;break b}c:do{switch(ha<<24>>24|0){case 13:{wa=0;xa=ta;ya=sa;za=ra;Aa=qa;Ba=pa;break};case 123:{c[l>>2]=0;la=xd(pa|0,2350472,(ka=i,i=i+8|0,c[ka>>2]=l,ka)|0)|0;i=ka;if((la|0)>-1){Ca=(c[l>>2]|0)>0|0}else{Ca=0}la=Ca+ta|0;if((la|0)==1){na=31}else{c[l>>2]=0;Da=xd(pa|0,2330104,(ka=i,i=i+8|0,c[ka>>2]=l,ka)|0)|0;i=ka;Ea=c[l>>2]|0;if((Da|0)>-1&(Ea|0)>0){Fa=Ea}else{na=31}}do{if((na|0)==31){na=0;c[l>>2]=0;Ea=xd(pa|0,2305640,(ka=i,i=i+8|0,c[ka>>2]=l,ka)|0)|0;i=ka;Da=c[l>>2]|0;if((Ea|0)>-1&(Da|0)>0){Fa=Da;break}a[qa]=a[pa]|0;wa=0;xa=la;ya=sa;za=ra;Aa=qa+1|0;Ba=pa;break c}}while(0);wa=0;xa=la;ya=sa;za=ra;Aa=qa;Ba=pa+(Fa-1)|0;break};case 32:{if((sa|0)!=0){wa=0;xa=ta;ya=sa;za=ra;Aa=qa;Ba=pa;break c}a[qa]=ha;wa=0;xa=ta;ya=0;za=ra;Aa=qa+1|0;Ba=pa;break};case 10:{if((sa|0)==0){Ga=qa}else{wa=1;xa=ta;ya=sa;za=ra;Aa=qa;Ba=pa;break c}while(1){Da=Ga-1|0;if((a[Da]|0)==32){Ga=Da}else{break}}Lb(Ga|0,T-Ga|0,1892784,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0)|0;i=ka;if(!(Ga>>>0<M>>>0)){wa=0;xa=ta;ya=1;za=ra;Aa=Ga;Ba=pa;break c}wa=0;xa=ta;ya=1;za=ra;Aa=Ga+(SGb(Ga|0)|0)|0;Ba=pa;break};case 60:{la=(a[pa+1|0]|0)==47;Da=la&1;c[l>>2]=0;Ea=xd(pa+(la?2:1)|0,2287752,(ka=i,i=i+16|0,c[ka>>2]=N,c[ka+8>>2]=l,ka)|0)|0;i=ka;if(!((Ea|0)>0&(c[l>>2]|0)>0)){na=76;break c}Ea=Vb(N|0,32)|0;if((Ea|0)==0){Ha=0}else{a[Ea]=0;Ha=Ea+1|0}if(!(ra>>>0<16>>>0&(la^1))){if(!(la&(ra|0)>0)){na=76;break c}if((QGb(m+(ra-1<<9)|0,N)|0)!=0){na=76;break c}}Ea=c[l>>2]|0;Ia=pa+(Ea+Da)|0;if(!la){TGb(m+(ra<<9)|0,0,512)|0}d:do{if((QGb(N,2271672)|0)==0){if(la){Ja=ra-1|0;Ka=ra-2|0;e:do{if((a[m+(Ja<<9)+384|0]|0)==0){La=qa}else{Ma=Ka;while(1){if(!((Ma|0)>-1)){La=qa;break e}Na=m+(Ma<<9)+384|0;if((a[Na]|0)==0){Ma=Ma-1|0}else{break}}Lb(qa|0,T-qa|0,2256304,(ka=i,i=i+8|0,c[ka>>2]=Na,ka)|0)|0;i=ka;if(!(qa>>>0<M>>>0)){La=qa;break}La=qa+(SGb(qa|0)|0)|0}}while(0);f:do{if((a[m+(Ja<<9)+256|0]|0)==0){Oa=La}else{Ma=Ka;while(1){if(!((Ma|0)>-1)){Oa=La;break f}Pa=m+(Ma<<9)+256|0;if((a[Pa]|0)==0){Ma=Ma-1|0}else{break}}Lb(La|0,T-La|0,2256304,(ka=i,i=i+8|0,c[ka>>2]=Pa,ka)|0)|0;i=ka;if(!(La>>>0<M>>>0)){Oa=La;break}Oa=La+(SGb(La|0)|0)|0}}while(0);if((a[m+(Ja<<9)+128|0]|0)==0){Qa=0;Ra=Oa;break}else{Sa=Ka}while(1){if(!((Sa|0)>-1)){Qa=0;Ra=Oa;break d}Ta=m+(Sa<<9)+128|0;if((a[Ta]|0)==0){Sa=Sa-1|0}else{break}}Lb(Oa|0,T-Oa|0,2256304,(ka=i,i=i+8|0,c[ka>>2]=Ta,ka)|0)|0;i=ka;if(!(Oa>>>0<M>>>0)){Qa=0;Ra=Oa;break}Qa=0;Ra=Oa+(SGb(Oa|0)|0)|0;break}Ka=m+(ra<<9)+128|0;if((Ha|0)!=0){Ja=m+(ra<<9)+256|0;Ma=m+(ra<<9)+384|0;Ua=Ha;do{do{if((RGb(Ua,2241912,5)|0)==0){Va=Ua+((a[Ua+5|0]|0)==34?6:5)|0;Wa=xd(Va|0,2229576,(ka=i,i=i+8|0,c[ka>>2]=n,ka)|0)|0;i=ka;if((Wa|0)!=1){Xa=Va;break}Lb(Ka|0,128,2217792,(ka=i,i=i+8|0,c[ka>>2]=c[n>>2],ka)|0)|0;i=ka;Xa=Va}else{if((RGb(Ua,2208472,6)|0)!=0){if((RGb(Ua,2191416,5)|0)!=0){Xa=Ua;break}Va=(a[Ua+5|0]|0)==34?6:5;Wa=Ua+Va|0;Ya=hc(Wa|0,((a[Ua+(Va-1)|0]|0)==34?2174800:2164600)|0)|0;c[l>>2]=Ya;Za=Ya+1|0;sAb(O,Wa,Za>>>0<128>>>0?Za:128)|0;Za=Ua+((c[l>>2]|0)+Va)|0;Lb(Ma|0,128,2157800,(ka=i,i=i+8|0,c[ka>>2]=O,ka)|0)|0;i=ka;Xa=Za;break}Za=Ua+((a[Ua+6|0]|0)==34|6)|0;if((QEb(U,Za,hc(Za|0,2125504)|0,V)|0)<0){_a=-1}else{_a=d[W]<<8|d[U]|d[X]<<16}Lb(Ja|0,128,2200008,(ka=i,i=i+8|0,c[ka>>2]=_a,ka)|0)|0;i=ka;Xa=Za}}while(0);Za=Vb(Xa|0,32)|0;Ua=(Za|0)==0?0:Za+1|0;}while((Ua|0)!=0)}do{if((a[Ka]|0)==0){$a=qa}else{Lb(qa|0,T-qa|0,2256304,(ka=i,i=i+8|0,c[ka>>2]=Ka,ka)|0)|0;i=ka;if(!(qa>>>0<M>>>0)){$a=qa;break}$a=qa+(SGb(qa|0)|0)|0}}while(0);Ka=m+(ra<<9)+256|0;do{if((a[Ka]|0)==0){ab=$a}else{Lb($a|0,T-$a|0,2256304,(ka=i,i=i+8|0,c[ka>>2]=Ka,ka)|0)|0;i=ka;if(!($a>>>0<M>>>0)){ab=$a;break}ab=$a+(SGb($a|0)|0)|0}}while(0);Ka=m+(ra<<9)+384|0;if((a[Ka]|0)==0){Qa=0;Ra=ab;break}Lb(ab|0,T-ab|0,2256304,(ka=i,i=i+8|0,c[ka>>2]=Ka,ka)|0)|0;i=ka;if(!(ab>>>0<M>>>0)){Qa=0;Ra=ab;break}Qa=0;Ra=ab+(SGb(ab|0)|0)|0}else{do{if((a[Y]|0)==0){if((qd(N|0,2151008)|0)!=1){break}Lb(qa|0,T-qa|0,2143968,(ka=i,i=i+16|0,c[ka>>2]=a[N]|0,c[ka+8>>2]=Da^1,ka)|0)|0;i=ka;Qa=0;Ra=qa+(SGb(qa|0)|0)|0;break d}}while(0);Lb(O|0,128,2138416,(ka=i,i=i+8|0,c[ka>>2]=N,ka)|0)|0;i=ka;Qa=1;Ra=qa}}while(0);if(la){wa=0;xa=ta;ya=sa;za=ra-1|0;Aa=Ra;Ba=Ia;break c}do{if((Qa|0)!=0){if((yb(Ia|0,O|0)|0)!=0){break}Da=pa+(Ea-(c[l>>2]|0))|0;a[Ra]=a[Da]|0;wa=0;xa=ta;ya=sa;za=ra;Aa=Ra+1|0;Ba=Da;break c}}while(0);sAb(m+(ra<<9)|0,N,128)|0;wa=0;xa=ta;ya=sa;za=ra+1|0;Aa=Ra;Ba=Ia;break};default:{na=76}}}while(0);if((na|0)==76){na=0;a[qa]=a[pa]|0;wa=0;xa=ta;ya=sa;za=ra;Aa=qa+1|0;Ba=pa}ha=a[Ba]|0;if((ha<<24>>24|0)==32|(ha<<24>>24|0)==13|(ha<<24>>24|0)==10){bb=ya}else{bb=0}ha=Ba+1|0;if(Aa>>>0<M>>>0&(wa|0)==0){pa=ha;qa=Aa;ra=za;sa=bb;ta=xa;na=19}else{ua=ha;va=Aa;break b}}}}while(0);ga=va>>>0>Z>>>0?Z:va;while(1){ja=ga-2|0;if((RGb(ja,1892784,2)|0)==0){ga=ja}else{cb=ga;break}}while(1){ga=cb-1|0;if((a[ga]|0)==32){cb=ga}else{break}}Lb(cb|0,T-cb|0,2131840,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0)|0;i=ka;ga=c[u>>2]|0;shb(E,K,ga,(c[v>>2]|0)-ga|0,0)|0;if(ua>>>0<J>>>0){fa=ua}else{break}}}}while(0);c[f>>2]=(c[e+12>>2]|0)!=0;L=c[H>>2]|0;i=h;return L|0}function lZa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b>>2]=a;d=b+4|0;c[d>>2]=uhb(c[a+860>>2]|0)|0;IAb(b+8|0,0,-1);return((c[d>>2]|0)!=0?0:-1094995529)|0}function mZa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+8|0;g=f|0;h=c[a+60>>2]|0;j=h;k=h+8|0;PAb(k);l=e+12|0;a:do{if((c[l>>2]|0)==0){m=h+12|0}else{n=e+16|0;o=h+4|0;p=a+12|0;q=h+1036|0;r=h+12|0;s=h+1032|0;t=h+1108|0;u=0;while(1){v=c[(c[n>>2]|0)+(u<<2)>>2]|0;if((c[v+84>>2]|0)!=3){break}w=xhb(c[o>>2]|0,c[v+92>>2]|0,0,g)|0;b:do{if((w|0)!=0){v=w;do{x=c[g>>2]|0;c[g>>2]=x-1;if((x|0)==0){break b}if((c[(c[p>>2]|0)+12>>2]|0)==94216){x=(c[v+4>>2]|0)*10|0;y=(c[v+8>>2]|0)*10|0;z=(x|0)/36e5|0;A=(ba(z,-36e5)|0)+x|0;x=(A|0)/6e4|0;B=A+(x*-6e4|0)|0;A=(B|0)/1e3|0;C=(y|0)/36e5|0;D=(ba(C,-36e5)|0)+y|0;y=(D|0)/6e4|0;E=D+(y*-6e4|0)|0;D=(E|0)/1e3|0;F=(c[q>>2]|0)+1|0;c[q>>2]=F;oZa(j,2002360,(G=i,i=i+72|0,c[G>>2]=F,c[G+8>>2]=z,c[G+16>>2]=x,c[G+24>>2]=A,c[G+32>>2]=B+(A*-1e3|0),c[G+40>>2]=C,c[G+48>>2]=y,c[G+56>>2]=D,c[G+64>>2]=E+(D*-1e3|0),G)|0);i=G;c[s>>2]=(c[r>>2]|0)-2}c[t>>2]=0;pZa(j,c[v+12>>2]|0);zhb(431576,h,c[v+16>>2]|0)|0;v=v+20|0;}while((v|0)!=0)}}while(0);w=u+1|0;if(w>>>0<(c[l>>2]|0)>>>0){u=w}else{m=r;break a}}yDb(a,16,2047984,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-38;i=f;return H|0}}while(0);l=c[m>>2]|0;if(!(l>>>0<(c[h+16>>2]|0)>>>0)){H=-12;i=f;return H|0}if((l|0)==0){H=0;i=f;return H|0}if(l>>>0>d>>>0){yDb(a,16,1965008,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-1;i=f;return H|0}else{UGb(b|0,c[k>>2]|0,l)|0;H=c[m>>2]|0;i=f;return H|0}return 0}function nZa(a){a=a|0;var b=0;b=c[a+60>>2]|0;whb(c[b+4>>2]|0);QAb(b+8|0,0)|0;return 0}function oZa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;LAb(a+8|0,b,f|0);i=e;return}function pZa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=Ahb(c[b+4>>2]|0,d)|0;if((f|0)==0){i=e;return}d=c[f+12>>2]|0;g=d&16777215;h=f+4|0;j=c[h>>2]|0;if((j|0)==0){k=4}else{if((QGb(j,2208464)|0)==0){k=4}else{k=5}}if((k|0)==4){if(!((c[f+8>>2]|0)==16&(g|0)==16777215)){k=5}}do{if((k|0)==5){oZa(b,22e5,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=c[h>>2]|0;do{if((j|0)!=0){if((QGb(j,2208464)|0)==0){break}oZa(b,2191400,(l=i,i=i+8|0,c[l>>2]=j,l)|0);i=l}}while(0);j=c[f+8>>2]|0;if((j|0)!=16){oZa(b,2174784,(l=i,i=i+8|0,c[l>>2]=j,l)|0);i=l}if((g|0)!=16777215){oZa(b,2164584,(l=i,i=i+8|0,c[l>>2]=d>>>16&255|d&65280|d<<16&16711680,l)|0);i=l}oZa(b,2157792,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=b+1104|0;m=c[j>>2]|0;if((m|0)>63){break}c[j>>2]=m+1;a[b+1040+m|0]=102}}while(0);do{if((c[f+20>>2]|0)!=0){oZa(b,2151e3,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;d=b+1104|0;g=c[d>>2]|0;if((g|0)>63){break}c[d>>2]=g+1;a[b+1040+g|0]=98}}while(0);do{if((c[f+24>>2]|0)!=0){oZa(b,2143944,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;g=b+1104|0;d=c[g>>2]|0;if((d|0)>63){break}c[g>>2]=d+1;a[b+1040+d|0]=105}}while(0);do{if((c[f+28>>2]|0)!=0){oZa(b,2138408,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;d=b+1104|0;g=c[d>>2]|0;if((g|0)>63){break}c[d>>2]=g+1;a[b+1040+g|0]=117}}while(0);g=c[f+32>>2]|0;if((g|0)==2){i=e;return}oZa(b,2287744,(l=i,i=i+8|0,c[l>>2]=g,l)|0);i=l;c[b+1108>>2]=1;i=e;return}function qZa(a,b,c){a=a|0;b=b|0;c=c|0;NAb(a+8|0,b,c);return}function rZa(a,b){a=a|0;b=b|0;b=i;oZa(a,2217784,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return}function sZa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=a;AZa(f,b,d);if((d|0)!=0){i=e;return}oZa(f,2229568,(f=i,i=i+8|0,c[f>>2]=b<<24>>24,f)|0);i=f;i=e;return}function tZa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;if(e>>>0>1>>>0){i=f;return}e=b;g=(d|0)==-1;h=b+1104|0;j=c[h>>2]|0;do{if(g){k=j;while(1){l=k-1|0;if((k|0)<=0){break}if((a[e+1040+l|0]|0)==102){break}else{k=l}}if((l|0)<0|(j|0)==(l|0)){m=12;break}else{n=j}while(1){if((n|0)<1){o=0}else{k=n-1|0;c[h>>2]=k;o=a[e+1040+k|0]|0}oZa(e,1892776,(p=i,i=i+16|0,c[p>>2]=o<<24>>24,c[p+8>>2]=o<<24>>24==102?2350464:9203624,p)|0);i=p;k=c[h>>2]|0;if((k|0)==(l|0)){m=12;break}else{n=k}}}else{if((j|0)>63){yDb(c[b>>2]|0,16,1913200,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else{c[h>>2]=j+1;a[e+1040+j|0]=102;m=12;break}}}while(0);do{if((m|0)==12){if(!g){break}i=f;return}}while(0);oZa(e,2241888,(p=i,i=i+8|0,c[p>>2]=d>>>16&255|d&65280|d<<16&16711680,p)|0);i=p;i=f;return}function uZa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b;g=(d|0)!=0;h=b+1104|0;j=c[h>>2]|0;do{if(g){if((j|0)>63){yDb(c[b>>2]|0,16,1913200,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;break}else{c[h>>2]=j+1;a[f+1040+j|0]=102;l=11;break}}else{m=j;while(1){n=m-1|0;if((m|0)<=0){break}if((a[f+1040+n|0]|0)==102){break}else{m=n}}if((n|0)<0|(j|0)==(n|0)){l=11;break}else{o=j}while(1){if((o|0)<1){p=0}else{m=o-1|0;c[h>>2]=m;p=a[f+1040+m|0]|0}oZa(f,1892776,(k=i,i=i+16|0,c[k>>2]=p<<24>>24,c[k+8>>2]=p<<24>>24==102?2350464:9203624,k)|0);i=k;m=c[h>>2]|0;if((m|0)==(n|0)){l=11;break}else{o=m}}}}while(0);do{if((l|0)==11){if(g){break}i=e;return}}while(0);oZa(f,2256280,(k=i,i=i+8|0,c[k>>2]=d,k)|0);i=k;i=e;return}function vZa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b;g=(d|0)>-1;h=b+1104|0;j=c[h>>2]|0;do{if(g){if((j|0)>63){yDb(c[b>>2]|0,16,1913200,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;break}else{c[h>>2]=j+1;a[f+1040+j|0]=102;l=11;break}}else{m=j;while(1){n=m-1|0;if((m|0)<=0){break}if((a[f+1040+n|0]|0)==102){break}else{m=n}}if((n|0)<0|(j|0)==(n|0)){l=11;break}else{o=j}while(1){if((o|0)<1){p=0}else{m=o-1|0;c[h>>2]=m;p=a[f+1040+m|0]|0}oZa(f,1892776,(k=i,i=i+16|0,c[k>>2]=p<<24>>24,c[k+8>>2]=p<<24>>24==102?2350464:9203624,k)|0);i=k;m=c[h>>2]|0;if((m|0)==(n|0)){l=11;break}else{o=m}}}}while(0);do{if((l|0)==11){if(g){break}i=e;return}}while(0);oZa(f,2271648,(k=i,i=i+8|0,c[k>>2]=d,k)|0);i=k;i=e;return}function wZa(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a+1108|0;if(!((c[e>>2]|0)==0&(b|0)>-1)){i=d;return}oZa(a,2287744,(a=i,i=i+8|0,c[a>>2]=b,a)|0);i=a;c[e>>2]=1;i=d;return}function xZa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=b;g=b+1104|0;b=c[g>>2]|0;if((b|0)==0){pZa(f,d);i=e;return}else{h=b}do{if((h|0)<1){j=0}else{b=h-1|0;c[g>>2]=b;j=a[f+1040+b|0]|0}oZa(f,1892776,(b=i,i=i+16|0,c[b>>2]=j<<24>>24,c[b+8>>2]=j<<24>>24==102?2350464:9203624,b)|0);i=b;h=c[g>>2]|0;}while((h|0)!=0);pZa(f,d);i=e;return}function yZa(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;h=i;i=i+48|0;g=h+40|0;if((c[(c[(c[a>>2]|0)+12>>2]|0)+12>>2]|0)!=94216){i=h;return}j=h|0;k=Lb(j|0,32,2305600,(l=i,i=i+32|0,c[l>>2]=b,c[l+8>>2]=e,c[l+16>>2]=d,c[l+24>>2]=f,l)|0)|0;i=l;l=a+8|0;OAb(l,k,h+32|0,g);if((c[g>>2]|0)>>>0<k>>>0){m=a+12|0}else{g=l;l=c[g>>2]|0;f=a+1032|0;d=c[f>>2]|0;e=a+12|0;VGb(l+(d+k)|0,l+d|0,1-d+(c[e>>2]|0)|0)|0;UGb((c[g>>2]|0)+(c[f>>2]|0)|0,j|0,k)|0;m=e}c[m>>2]=(c[m>>2]|0)+k;i=h;return}function zZa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=b;f=b+1104|0;g=c[f>>2]|0;if((g|0)!=0){h=g;do{if((h|0)<1){j=0}else{g=h-1|0;c[f>>2]=g;j=a[e+1040+g|0]|0}oZa(e,1892776,(k=i,i=i+16|0,c[k>>2]=j<<24>>24,c[k+8>>2]=j<<24>>24==102?2350464:9203624,k)|0);i=k;h=c[f>>2]|0;}while((h|0)!=0)}if((c[(c[(c[b>>2]|0)+12>>2]|0)+12>>2]|0)!=94216){i=d;return}oZa(e,1936872,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;i=d;return}function AZa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;if((e|0)==0){e=b+1104|0;g=c[e>>2]|0;if((g|0)>63){yDb(c[b>>2]|0,16,1913200,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;i=f;return}else{c[e>>2]=g+1;a[b+1040+g|0]=d;i=f;return}}g=c[b+1104>>2]|0;do{if(d<<24>>24==0){j=0}else{e=g;while(1){k=e-1|0;if((e|0)<=0){break}if((a[b+1040+k|0]|0)==d<<24>>24){break}else{e=k}}if((k|0)>=0){j=k;break}i=f;return}}while(0);k=b+1104|0;if((g|0)==(j|0)){i=f;return}else{l=g}do{if((l|0)<1){m=0}else{g=l-1|0;c[k>>2]=g;m=a[b+1040+g|0]|0}oZa(b,1892776,(h=i,i=i+16|0,c[h>>2]=m<<24>>24,c[h+8>>2]=m<<24>>24==102?2350464:9203624,h)|0);i=h;l=c[k>>2]|0;}while((l|0)!=(j|0));i=f;return}function BZa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1032|0;h=g+8|0;j=d;k=c[f+24>>2]|0;do{if((k|0)==0){IAb(h,0,-1);l=f+28|0}else{m=xd(k|0,2181544,(n=i,i=i+8|0,c[n>>2]=g,n)|0)|0;i=n;if((m|0)==1){yDb(b,16,2104488,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}IAb(h,0,-1);m=f+28|0;if((c[m>>2]|0)<=0){l=m;break}p=a[k]|0;if(!(p<<24>>24==0)){q=k;r=p;while(1){if((RGb(q,2047976,4)|0)==0){KAb(h,2002352,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;s=q+4|0}else{do{if((r<<24>>24|0)==10){if((a[q+1|0]|0)==0){break}KAb(h,2002352,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}else if((r<<24>>24|0)!=13){MAb(h,r,1)}}while(0);s=q+1|0}p=a[s]|0;if(p<<24>>24==0){break}else{q=s;r=p}}}KAb(h,1965e3,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;shb(j,c[h>>2]|0,c[f+8>>2]|0,c[f+48>>2]|0,0)|0;l=m}}while(0);c[e>>2]=(c[d+12>>2]|0)!=0;QAb(h,0)|0;o=c[l>>2]|0;i=g;return o|0}function CZa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=i;i=i+8|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=k+l|0;if((l|0)<32){m=-1094995529;i=h;return m|0}l=k;if(!((d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)==-1788172711)){yDb(b,16,2181488,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}l=k+4|0;o=fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;l=k+8|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=fe(p|0)|0;q=k+12|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=fe(r|0)|0;s=k+20|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=fe(t|0)|0;u=k+24|0;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=fe(v|0)|0;w=k+28|0;x=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=fe(x|0)|0;if((t|0)==-65536){DDb(b,2104416,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1163346256;i=h;return m|0}if(s>>>0>5>>>0){yDb(b,16,2047928,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}if((v|0)==33554432){DDb(b,2002312,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1163346256;i=h;return m|0}if(u>>>0>2>>>0){yDb(b,16,1964976,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}if((s-4|0)>>>0<2>>>0){yDb(b,16,1936840,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1;i=h;return m|0}switch(q|0){case 4:{c[b+140>>2]=(x|0)!=0?11:-1;break};case 32:{c[b+140>>2]=(t|0)==50331648?295:297;break};case 24:{c[b+140>>2]=(t|0)==50331648?2:3;break};case 8:{c[b+140>>2]=(x|0)!=0?11:8;break};case 1:{c[b+140>>2]=(x|0)!=0?11:9;break};default:{yDb(b,16,1913184,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}}s=V$a(b,o,l)|0;if((s|0)<0){m=s;i=h;return m|0}s=_$a(b,e,0)|0;if((s|0)<0){m=s;i=h;return m|0}c[e+88>>2]=1;s=g;if((s-(k+32)|0)>>>0<w>>>0){m=-1094995529;i=h;return m|0}u=(x|0)==0;do{if(q>>>0<9>>>0|u){if(u){y=k+(w+32)|0;z=q>>>0<8>>>0;A=36;break}v=(w>>>0)/3|0;if(((w>>>0)%3|0|0)!=0|w>>>0>768>>>0){yDb(b,24,2350432,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}if(!(w>>>0>2>>>0)){A=33;break}B=v+32|0;C=(v<<1)+32|0;D=0;E=c[e+4>>2]|0;while(1){c[E>>2]=(d[k+(D+32)|0]|0)<<16|(d[k+(B+D)|0]|0)<<8|(d[k+(C+D)|0]|0)|-16777216;F=D+1|0;if(F>>>0<v>>>0){D=F;E=E+4|0}else{A=33;break}}}else{yDb(b,24,1892712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;A=33}}while(0);do{if((A|0)==33){n=k+(w+32)|0;u=q>>>0<8>>>0;if(!((x|0)!=0&u)){y=n;z=u;A=36;break}u=o+15|0;E=WDb(ba(l,u)|0)|0;if((E|0)==0){m=-12;i=h;return m|0}else{G=ba(q,u>>>3)|0;H=E;I=E;J=n;K=1;break}}}while(0);if((A|0)==36){G=c[e+32>>2]|0;H=0;I=c[e>>2]|0;J=y;K=z}z=((ba(q,o)|0)+7|0)>>>3;y=(z&1)+z|0;a:do{if((t|0)==33554432){A=ba(G,l)|0;x=I+A|0;if((A|0)!=0&J>>>0<g>>>0){L=0;M=I;N=J}else{O=J;break}while(1){if((s-N|0)<1){m=-1094995529;break}A=N+1|0;w=a[N]|0;do{if(w<<24>>24==-128){n=N+2|0;E=a[A]|0;u=(E&255)+1|0;if(E<<24>>24==0){P=u;Q=-128;R=n;break}P=u;Q=a[n]|0;R=N+3|0}else{P=1;Q=w;R=A}}while(0);A=P;w=M;n=L;b:while(1){u=A;S=n;while(1){T=u-1|0;if((u|0)==0){break b}if(S>>>0<z>>>0){a[w+S|0]=Q}E=S+1|0;if(E>>>0<y>>>0){u=T;S=E}else{break}}u=w+G|0;if((u|0)==(x|0)){O=R;break a}else{A=T;w=u;n=0}}if((w|0)!=(x|0)&R>>>0<g>>>0){L=S;M=w;N=R}else{O=R;break a}}i=h;return m|0}else{if((p|0)==0){O=J;break}else{U=0;V=I;W=J}while(1){if((s-W|0)>>>0<z>>>0){O=W;break a}UGb(V|0,W|0,z)|0;x=W+y|0;n=U+1|0;if(n>>>0<l>>>0){U=n;V=V+G|0;W=x}else{O=x;break}}}}while(0);if((c[b+140>>2]|0)==11&K){c[j>>2]=H;if((p|0)!=0){p=ba(q,(o+7|0)>>>3)|0;K=(p|0)==0;b=(r|0)==16777216;r=e+32|0;W=ba(q,(o+15|0)>>>3)|0;o=0;q=c[e>>2]|0;e=H;while(1){if(!K){if(b){H=0;do{G=e+H|0;V=H<<3;a[q+V|0]=(d[G]|0)>>>7;a[q+(V|1)|0]=(d[G]|0)>>>6&1;a[q+(V|2)|0]=(d[G]|0)>>>5&1;a[q+(V|3)|0]=(d[G]|0)>>>4&1;a[q+(V|4)|0]=(d[G]|0)>>>3&1;a[q+(V|5)|0]=(d[G]|0)>>>2&1;a[q+(V|6)|0]=(d[G]|0)>>>1&1;a[q+(V|7)|0]=a[G]&1;H=H+1|0;}while(H>>>0<p>>>0)}else{H=0;do{G=e+H|0;V=H<<1;a[q+V|0]=(d[G]|0)>>>4;a[q+(V|1)|0]=a[G]&15;H=H+1|0;}while(H>>>0<p>>>0)}}H=o+1|0;if(H>>>0<l>>>0){o=H;q=q+(c[r>>2]|0)|0;e=e+W|0}else{break}}}$Db(j)}c[f>>2]=1;m=O-k|0;i=h;return m|0}function DZa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+60>>2]|0;e=c[a+568>>2]|0;if((e|0)==2){c[d+24>>2]=1;f=1}else if((e|0)==3){c[d+24>>2]=2;f=2}else{yDb(a,16,2002288,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;g=-22;i=b;return g|0}e=d+28|0;c[e>>2]=0;h=d+32|0;c[h>>2]=0;j=c[a+140>>2]|0;if((j|0)==3){c[d+16>>2]=24;k=24;l=0}else if((j|0)==9){c[d+16>>2]=1;k=1;l=0}else if((j|0)==8){m=0;n=8}else if((j|0)==11){c[e>>2]=1;c[h>>2]=768;m=768;n=8}else{g=-558323010;i=b;return g|0}if((n|0)==8){c[d+16>>2]=8;k=8;l=m}m=ba((ba(k,c[a+120>>2]|0)|0)+15>>3&-2,c[a+124>>2]|0)|0;c[d+20>>2]=m;c[d+36>>2]=l+32+(ba(m,(f|0)==2?2:1)|0);g=0;i=b;return g|0}function EZa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;g=i;h=b+60|0;j=c[h>>2]|0;k=c[j+36>>2]|0;l=r0a(b,d,k,(k|0)<0|0?-1:0)|0;if((l|0)<0){m=l;i=g;return m|0}l=d+24|0;k=c[l>>2]|0;n=d+28|0;o=c[n>>2]|0;if(!((o|0)>-1)){yDb(0,0,2181456,(p=i,i=i+24|0,c[p>>2]=2104400,c[p+8>>2]=2047904,c[p+16>>2]=145,p)|0);i=p;Cd();return 0}p=j;c[p>>2]=k;q=j+8|0;c[q>>2]=k;c[j+4>>2]=k+o;c[j+12>>2]=0;o=c[h>>2]|0;k=o;r=c[k>>2]|0;x=-1788172711;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[k>>2]|0)+4|0;c[k>>2]=r;s=b+120|0;t=r;x=fe(c[s>>2]|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[k>>2]|0)+4|0;c[k>>2]=t;r=b+124|0;b=t;x=fe(c[r>>2]|0)|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=(c[k>>2]|0)+4|0;c[k>>2]=b;t=b;x=fe(c[o+16>>2]|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[k>>2]|0)+4|0;c[k>>2]=t;b=t;x=fe(c[o+20>>2]|0)|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=(c[k>>2]|0)+4|0;c[k>>2]=b;t=b;x=fe(c[o+24>>2]|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[k>>2]|0)+4|0;c[k>>2]=t;b=t;x=fe(c[o+28>>2]|0)|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=(c[k>>2]|0)+4|0;c[k>>2]=b;t=b;x=fe(c[o+32>>2]|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;k=c[e>>2]|0;t=c[e+4>>2]|0;o=c[e+32>>2]|0;e=c[h>>2]|0;h=e+32|0;b=c[h>>2]|0;do{if((b|0)!=0){u=(b|0)/3|0;v=e;w=c[v>>2]|0;y=e+12|0;do{if((c[y>>2]|0)==0){z=c[e+4>>2]|0;A=z-w|0;B=A>>>0>u>>>0?u:A;if((B|0)!=(u|0)){c[y>>2]=1;A=w+B|0;c[v>>2]=A;C=A;break}A=w+u|0;c[v>>2]=A;B=z-A|0;z=B>>>0>u>>>0?u:B;if((z|0)!=(u|0)){c[y>>2]=1}c[v>>2]=w+(z+u);C=A}else{C=w}}while(0);if((b|0)>2){D=w;E=C;F=0}else{break}while(1){y=c[t+(F<<2)>>2]|0;a[D]=y>>>16;a[E]=y>>>8;a[c[v>>2]|0]=y;c[v>>2]=(c[v>>2]|0)+1;y=F+1|0;if((y|0)<(u|0)){D=D+1|0;E=E+1|0;F=y}else{break}}}}while(0);F=(ba(c[s>>2]|0,c[e+16>>2]|0)|0)+7>>3;s=F&1;E=s+F|0;D=c[r>>2]|0;a:do{if((c[e+24>>2]|0)==2){if((D|0)<1){G=c[e>>2]|0}else{t=F-1|0;if((F|0)<1){H=k+t|0}else{H=k}C=e;b=0;u=0;v=k;w=a[H]|0;y=D;while(1){A=u+1|0;if((A|0)<(E|0)){I=v;J=A;K=b}else{I=v+o|0;J=0;K=b+1|0}if((K|0)<(y|0)){L=a[I+((J|0)<(F|0)?J:t)|0]|0}else{L=0}A=w&255;b:do{if(L<<24>>24==w<<24>>24){z=K;B=J;M=I;N=1;while(1){if((z|0)>=(y|0)){O=z;P=B;Q=M;R=w;S=N;break b}T=B+1|0;U=N+1|0;if((T|0)<(E|0)){V=M;W=T;X=z}else{V=M+o|0;W=0;X=z+1|0}if((X|0)<(y|0)){Y=a[V+((W|0)<(F|0)?W:t)|0]|0}else{Y=0}if(Y<<24>>24==w<<24>>24&(U|0)<256){z=X;B=W;M=V;N=U}else{O=X;P=W;Q=V;R=Y;S=U;break}}}else{O=K;P=J;Q=I;R=L;S=1}}while(0);do{if((S|0)>2|w<<24>>24==-128){a[c[C>>2]|0]=-128;N=(c[C>>2]|0)+1|0;c[C>>2]=N;a[N]=S+255;N=(c[C>>2]|0)+1|0;c[C>>2]=N;if((S|0)<=1){Z=N;break}a[N]=w;N=(c[C>>2]|0)+1|0;c[C>>2]=N;Z=N}else{if((S|0)==1){a[c[C>>2]|0]=w;N=(c[C>>2]|0)+1|0;c[C>>2]=N;Z=N;break}else{N=de((A<<8|A)&65535|0)|0;M=c[C>>2]|0;x=N;a[M]=x;x=x>>8;a[M+1|0]=x;M=(c[C>>2]|0)+2|0;c[C>>2]=M;Z=M;break}}}while(0);A=c[r>>2]|0;if((O|0)<(A|0)){b=O;u=P;v=Q;w=R;y=A}else{G=Z;break}}}c[e+20>>2]=G-32-(c[e+8>>2]|0)-(c[h>>2]|0)}else{if((D|0)<=0){break}y=e+12|0;w=e+4|0;v=e;if((s|0)==0){u=1;b=k;C=D;while(1){if((c[y>>2]|0)==0){t=c[v>>2]|0;A=(c[w>>2]|0)-t|0;M=A>>>0>F>>>0?F:A;if((M|0)!=(F|0)){c[y>>2]=1}UGb(t|0,b|0,M)|0;c[v>>2]=(c[v>>2]|0)+M;_=c[r>>2]|0}else{_=C}if((u|0)>=(_|0)){break a}u=u+1|0;b=b+o|0;C=_}}else{$=1;aa=k}while(1){if((c[y>>2]|0)==0){C=c[v>>2]|0;b=(c[w>>2]|0)-C|0;u=b>>>0>F>>>0?F:b;if((u|0)!=(F|0)){c[y>>2]=1}UGb(C|0,aa|0,u)|0;C=(c[v>>2]|0)+u|0;c[v>>2]=C;ca=C}else{ca=c[v>>2]|0}a[ca]=0;c[v>>2]=(c[v>>2]|0)+1;if(($|0)>=(c[r>>2]|0)){break a}$=$+1|0;aa=aa+o|0}}}while(0);if((c[j+24>>2]|0)==2){o=fe(c[j+20>>2]|0)|0;j=(c[l>>2]|0)+16|0;x=o;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x}c[f>>2]=1;f=d+36|0;c[f>>2]=c[f>>2]|1;c[n>>2]=(c[p>>2]|0)-(c[q>>2]|0);m=0;i=g;return m|0}function FZa(a){a=a|0;JCb(a+804|0);return 0}function GZa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;e=ICb()|0;c[b+228>>2]=e;if((e|0)==0){f=-12;return f|0}c[b+232>>2]=(c[a+120>>2]|0)+3&-4;c[b+236>>2]=(c[a+124>>2]|0)+3&-4;c[a+140>>2]=6;BFa(b,c[a+88>>2]|0);c[1071071]=4284256;c[1071073]=6;N_(4284280,2,4,1134073,2,1,1134072,2,1,0,0,0,4)|0;c[1068577]=4283552;c[1068579]=176;N_(4274304,7,33,1172137,2,1,1172136,2,1,0,0,0,4)|0;a=0;b=0;while(1){c[4274332+(a*20|0)>>2]=4282880+(b<<2);e=d[429176+a|0]|0;c[4274340+(a*20|0)>>2]=e;g=e+b|0;N_(4274328+(a*20|0)|0,3,8,1130521+(a<<4)|0,2,1,1130520+(a<<4)|0,2,1,0,0,0,4)|0;c[4274476+(a*20|0)>>2]=4282880+(g<<2);e=d[429182+a|0]|0;c[4274484+(a*20|0)>>2]=e;N_(4274472+(a*20|0)|0,3,8,1131665+(a<<4)|0,2,1,1131664+(a<<4)|0,2,1,0,0,0,4)|0;h=a+1|0;if((h|0)<6){a=h;b=e+g|0}else{break}}c[1068613]=4280352;c[1068615]=632;N_(4274448,8,256,1130618,4,2,1130616,4,2,0,0,0,4)|0;c[1068649]=4274616;c[1068651]=1434;N_(4274592,9,512,1131762,4,2,1131760,4,2,0,0,0,4)|0;f=0;return f|0}function HZa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;k=i;i=i+304|0;l=k|0;m=k+256|0;n=k+264|0;o=k+280|0;p=k+288|0;q=c[j+24>>2]|0;r=c[j+28>>2]|0;j=f+60|0;s=c[j>>2]|0;t=g;u=s+208|0;v=u;w=r>>>0>268435455>>>0?-8:r<<3;x=w>>>0>2147483639>>>0|(q|0)==0;y=x?0:q;z=x?0:w;w=u;c[w>>2]=y;c[s+220>>2]=z;u=z+8|0;x=s+224|0;c[x>>2]=u;c[s+212>>2]=y+(z>>3);z=s+216|0;c[z>>2]=0;A=y;y=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)>>>10;c[z>>2]=u>>>0>22>>>0?22:u;c[s+240>>2]=y;if((y&4194191|0)!=0|(y&96|0)==0){B=-1094995529;i=k;return B|0}do{if((y|0)!=32){u=q+4|0;if((r|0)<36){B=-1094995529;i=k;return B|0}else{A=c[u>>2]|0;c[u>>2]=(A<<16|A>>>16)^c[q+32>>2];A=q+8|0;u=c[A>>2]|0;c[A>>2]=(u<<16|u>>>16)^c[q+28>>2];u=q+12|0;A=c[u>>2]|0;c[u>>2]=(A<<16|A>>>16)^c[q+24>>2];A=q+16|0;u=c[A>>2]|0;c[A>>2]=(u<<16|u>>>16)^c[q+20>>2];break}}}while(0);q=l|0;y=c[j>>2]|0;j=y+232|0;u=c[j>>2]|0;A=y+236|0;C=c[A>>2]|0;D=y+216|0;E=y+224|0;F=c[E>>2]|0;G=(c[D>>2]|0)+8|0;H=F>>>0>G>>>0?G:F;c[D>>2]=H;G=y+244|0;c[G>>2]=0;I=y+208|0;J=c[I>>2]|0;K=J+(H>>>3)|0;L=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(H&7)>>>30;K=H+2|0;H=F>>>0>K>>>0?K:F;c[D>>2]=H;do{if((L|0)==2){c[G>>2]=1;M=8}else if((L|0)==0){c[g+88>>2]=1;K=y+240|0;N=c[K>>2]|0;if((N|0)==80|(N|0)==96){O=J+(H>>>3)|0;P=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(H&7)>>>16;O=H+16|0;c[D>>2]=F>>>0>O>>>0?O:F;Xob(J,c[y+220>>2]>>3,P)|0;Q=c[K>>2]|0}else{Q=N}if((Q^16|0)>79){N=c[D>>2]|0;K=c[E>>2]|0;P=(c[I>>2]|0)+(N>>>3)|0;O=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(N&7)>>>24;P=N+8|0;c[D>>2]=K>>>0>P>>>0?P:K;a[q]=O;if((O|0)!=0){K=O;O=1;do{P=a[429816+K|0]|0;N=c[D>>2]|0;R=c[E>>2]|0;S=(c[I>>2]|0)+(N>>>3)|0;K=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(N&7)>>>24;S=N+8|0;c[D>>2]=R>>>0>S>>>0?S:R;a[l+O|0]=K^P&255;O=O+1|0;}while((O|0)<=(d[q]|0))}yDb(f,32,2002264,(T=i,i=i+8|0,c[T>>2]=q,T)|0);i=T}O=c[E>>2]|0;K=(c[D>>2]|0)+2|0;P=(O>>>0>K>>>0?K:O)+2|0;K=(O>>>0>P>>>0?P:O)+1|0;P=O>>>0>K>>>0?K:O;c[D>>2]=P;K=c[I>>2]|0;R=K+(P>>>3)|0;S=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(P&7)>>>29;R=P+3|0;P=O>>>0>R>>>0?R:O;c[D>>2]=P;if((S|0)!=7){U=e[1133834+(S<<2)>>1]|0;V=e[1133832+(S<<2)>>1]|0;W=P;X=K;Y=O;break}S=K+(P>>>3)|0;R=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(P&7)>>>20;S=P+12|0;P=O>>>0>S>>>0?S:O;c[D>>2]=P;S=K+(P>>>3)|0;N=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(P&7)>>>20;S=P+12|0;P=O>>>0>S>>>0?S:O;c[D>>2]=P;if((R|0)==0|(N|0)==0){B=-1094995529}else{U=N;V=R;W=P;X=K;Y=O;break}i=k;return B|0}else if((L|0)==1){M=8}else{yDb(f,16,2047880,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;B=-1094995529;i=k;return B|0}}while(0);if((M|0)==8){c[g+88>>2]=2;U=C;V=u;W=H;X=J;Y=F}F=d[X+(W>>>3)|0]|0;J=((W|0)<(Y|0))+W|0;c[D>>2]=J;do{if((F&128>>>((W&7)>>>0)|0)==0){Z=J}else{H=J+1|0;u=(Y>>>0>H>>>0?H:Y)+1|0;H=Y>>>0>u>>>0?u:Y;c[D>>2]=H;u=X+(H>>>3)|0;C=fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=H+2|0;L=Y>>>0>u>>>0?u:Y;c[D>>2]=L;if((C&-1073741824>>>((H&7)>>>0)|0)==0){Z=L;break}else{B=-1094995529}i=k;return B|0}}while(0);J=d[X+(Z>>>3)|0]|0;W=((Z|0)<(Y|0))+Z|0;c[D>>2]=W;a:do{if((J&128>>>((Z&7)>>>0)|0)!=0){F=W+1|0;L=(Y>>>0>F>>>0?F:Y)+4|0;F=(Y>>>0>L>>>0?L:Y)+1|0;L=(Y>>>0>F>>>0?F:Y)+2|0;F=Y>>>0>L>>>0?L:Y;c[D>>2]=F;L=c[y+220>>2]|0;if((L-F|0)<1){B=-1094995529;i=k;return B|0}else{_=F}while(1){F=d[X+(_>>>3)|0]|0;H=((_|0)<(Y|0))+_|0;c[D>>2]=H;if((F&128>>>((_&7)>>>0)|0)==0){break a}F=H+8|0;H=Y>>>0>F>>>0?F:Y;c[D>>2]=H;if((L-H|0)<1){B=-1094995529;break}else{_=H}}i=k;return B|0}}while(0);c[j>>2]=V;c[A>>2]=U;U=s+232|0;A=s+236|0;V=V$a(f,c[U>>2]|0,c[A>>2]|0)|0;if((V|0)<0){B=V;i=k;return B|0}V=c[f+856>>2]|0;j=(c[s+244>>2]|0)==0;do{if((V|0)>7){if(!j){B=r;i=k;return B|0}if((V|0)<=31){$=1;break}if((c[g+88>>2]|0)!=1|(V|0)>47){B=r}else{$=1;break}i=k;return B|0}else{$=j&1}}while(0);j=s+244|0;V=_$a(f,t,$)|0;if((V|0)<0){B=V;i=k;return B|0}V=WDb(((((c[U>>2]|0)+15&-16|0)/8|0)<<3)+24|0)|0;$=V;if((V|0)==0){B=-12;i=k;return B|0}_=g+32|0;D=g;Y=g+88|0;g=s+228|0;X=V+4|0;y=V;W=s;s=p|0;Z=p+8|0;J=p+4|0;p=o|0;L=o+4|0;H=n|0;F=n+8|0;C=n+4|0;u=n+12|0;I=f+88|0;E=0;b:while(1){q=c[_+(E<<2)>>2]|0;if((E|0)==0){l=c[U>>2]|0;Q=c[A>>2]|0;aa=Q;ca=l;da=l;ea=Q}else{if((c[I>>2]&8192|0)!=0){M=92;break}Q=c[U>>2]|0;l=c[A>>2]|0;aa=(l|0)/4|0;ca=(Q|0)/4|0;da=Q;ea=l}l=aa+15&-16;Q=ca+15&-16;G=c[D+(E<<2)>>2]|0;do{if((c[Y>>2]|0)==1){if((l|0)<=0){break}O=q<<4;K=0;P=G;while(1){R=0;while(1){if((R|0)>=(Q|0)){break}fa=KZa(v,P+R|0,q)|0;if((fa|0)==0){R=R+16|0}else{M=43;break b}}R=K+16|0;if((R|0)<(l|0)){K=R;P=P+O|0}else{break}}}else{O=c[g>>2]|0;P=c[O+(E<<2)>>2]|0;if((P|0)==0){M=48;break b}if((c[O+68>>2]|0)!=(da|0)){M=48;break b}if((c[O+72>>2]|0)!=(ea|0)){M=48;break b}TGb(V|0,0,(((Q|0)/8|0)<<3)+24|0)|0;if((l|0)<=0){break}O=(Q|0)>0;K=q<<4;R=q<<1;N=R+q|0;S=N+q|0;ga=S+q|0;ha=ga+q|0;ia=ha+q|0;ja=ia+q|0;ka=ja+q|0;la=ka+q|0;ma=la+q|0;na=ma+q|0;oa=na+q|0;pa=oa+q|0;qa=pa+q|0;ra=(q<<3)-8|0;sa=0;ta=G;while(1){if(O){ua=ba(sa,q)|0;va=(sa|0)==0;wa=sa*-2|0;xa=l-sa<<1;ya=xa-32|0;za=xa-16|0;xa=0;do{Aa=ta+xa|0;Ba=c[1071071]|0;Ca=c[z>>2]|0;Da=c[x>>2]|0;Ea=c[w>>2]|0;Fa=Ea+(Ca>>>3)|0;Ga=(fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ca&7)>>>30;Fa=b[Ba+(Ga<<2)>>1]|0;Ha=b[Ba+(Ga<<2)+2>>1]|0;Ga=Ha<<16>>16;if(Ha<<16>>16<0){Ha=Ca+2|0;Ia=Da>>>0>Ha>>>0?Ha:Da;Ha=Ea+(Ia>>>3)|0;Ea=((fe(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ia&7)>>>((Ga+32|0)>>>0))+Fa|0;Ja=b[Ba+(Ea<<2)+2>>1]|0;Ka=b[Ba+(Ea<<2)>>1]|0;La=Ia}else{Ja=Ga;Ka=Fa;La=Ca}Ca=Ja+La|0;c[z>>2]=Da>>>0>Ca>>>0?Ca:Da;do{if((Ka|0)==1){M=58}else if((Ka|0)==3|(Ka|0)==0){Da=(xa|0)/8|0;Ca=Da+3|0;c[$+(Ca<<3)+4>>2]=0;c[$+(Ca<<3)>>2]=0;Ca=Da+2|0;c[$+(Ca<<3)+4>>2]=0;c[$+(Ca<<3)>>2]=0;c[X>>2]=0;c[y>>2]=0;if((Ka|0)==1){M=58;break}else if((Ka|0)==0){Ca=xa+ua|0;UGb(Aa|0,P+Ca|0,16)|0;Da=Ca+q|0;UGb(ta+(xa+q)|0,P+Da|0,16)|0;Ca=Da+q|0;UGb(ta+(xa+R)|0,P+Ca|0,16)|0;Da=Ca+q|0;UGb(ta+(xa+N)|0,P+Da|0,16)|0;Ca=Da+q|0;UGb(ta+(xa+S)|0,P+Ca|0,16)|0;Da=Ca+q|0;UGb(ta+(xa+ga)|0,P+Da|0,16)|0;Ca=Da+q|0;UGb(ta+(xa+ha)|0,P+Ca|0,16)|0;Da=Ca+q|0;UGb(ta+(xa+ia)|0,P+Da|0,16)|0;Ca=Da+q|0;UGb(ta+(xa+ja)|0,P+Ca|0,16)|0;Da=Ca+q|0;UGb(ta+(xa+ka)|0,P+Da|0,16)|0;Ca=Da+q|0;UGb(ta+(xa+la)|0,P+Ca|0,16)|0;Da=Ca+q|0;UGb(ta+(xa+ma)|0,P+Da|0,16)|0;Ca=Da+q|0;UGb(ta+(xa+na)|0,P+Ca|0,16)|0;Da=Ca+q|0;UGb(ta+(xa+oa)|0,P+Da|0,16)|0;Ca=Da+q|0;UGb(ta+(xa+pa)|0,P+Ca|0,16)|0;UGb(ta+(qa+xa)|0,P+(Ca+q)|0,16)|0;break}else if((Ka|0)==2){M=67;break}else if((Ka|0)==3){Ma=KZa(v,Aa,q)|0;M=88;break}else{break}}else if((Ka|0)==2){M=67}}while(0);if((M|0)==58){M=0;c[s>>2]=$;if(va){c[Z>>2]=$;c[J>>2]=$}else{Ca=(xa|0)/8|0;c[J>>2]=$+(Ca+2<<3);c[Z>>2]=$+(Ca+4<<3)}Ca=MZa(v,o,s)|0;if((Ca|0)!=0){Na=Ca;break b}Ca=c[p>>2]|0;Da=(xa|0)/8|0;Fa=Da+3|0;c[$+(Fa<<3)>>2]=Ca;Ga=Da+2|0;c[$+(Ga<<3)>>2]=Ca;c[y>>2]=Ca;Da=c[L>>2]|0;c[$+(Fa<<3)+4>>2]=Da;c[$+(Ga<<3)+4>>2]=Da;c[X>>2]=Da;Ga=xa*-2|0;Fa=(Q-xa<<1)-32|0;if((Ca|0)<(Ga|0)){Oa=Ga}else{Oa=(Ca|0)>(Fa|0)?Fa:Ca}c[p>>2]=Oa;if((Da|0)<(wa|0)){Pa=wa}else{Pa=(Da|0)>(ya|0)?ya:Da}c[L>>2]=Pa;Da=P+((Oa>>1)+xa+(ba((Pa>>1)+sa|0,q)|0))|0;cf[c[W+((Pa<<1&2|Oa&1)<<2)>>2]&1023](Aa,Da,q,16);Ma=LZa(v,Aa,q)|0;M=88}else if((M|0)==67){M=0;c[H>>2]=$;if(va){c[F>>2]=$;c[C>>2]=$}else{Da=(xa|0)/8|0;c[C>>2]=$+(Da+2<<3);c[F>>2]=$+(Da+4<<3)}Da=MZa(v,m,H)|0;if((Da|0)!=0){Na=Da;break b}c[H>>2]=m;if(va){c[F>>2]=m;Qa=m}else{Qa=$+(((xa|0)/8|0)+3<<3)|0}c[C>>2]=Qa;Da=MZa(v,$,H)|0;if((Da|0)!=0){Na=Da;break b}c[C>>2]=$;Da=(xa|0)/8|0;c[F>>2]=$+(Da+1<<3);Ca=$+(Da+2<<3)|0;Fa=MZa(v,Ca,H)|0;if((Fa|0)!=0){Na=Fa;break b}c[F>>2]=Ca;Ca=$+(Da+3<<3)|0;c[u>>2]=Ca;Da=MZa(v,Ca,H)|0;if((Da|0)!=0){Na=Da;break b}Da=xa*-2|0;Ca=(Q-xa<<1)-16|0;Fa=0;Ga=Aa;while(1){Ia=c[n+(Fa<<2)>>2]|0;Ea=Fa&1;Ba=(c[Ia>>2]|0)+(Ea<<4)|0;Ha=(c[Ia+4>>2]|0)+(Fa>>1<<4)|0;if((Ba|0)<(Da|0)){Ra=Da}else{Ra=(Ba|0)>(Ca|0)?Ca:Ba}if((Ha|0)<(wa|0)){Sa=wa}else{Sa=(Ha|0)>(za|0)?za:Ha}Ha=P+((Ra>>1)+xa+(ba((Sa>>1)+sa|0,q)|0))|0;cf[c[W+16+((Sa<<1&2|Ra&1)<<2)>>2]&1023](Ga,Ha,q,8);if((Ea|0)==0){Ta=Ga+8|0}else{Ta=Ga+ra|0}Ea=Fa+1|0;if((Ea|0)<4){Fa=Ea;Ga=Ta}else{break}}Ma=LZa(v,Aa,q)|0;M=88}if((M|0)==88){M=0;if((Ma|0)!=0){Na=Ma;break b}}xa=xa+16|0;}while((xa|0)<(Q|0))}c[X>>2]=0;c[y>>2]=0;xa=sa+16|0;if((xa|0)<(l|0)){sa=xa;ta=ta+K|0}else{break}}}}while(0);l=E+1|0;if((l|0)<3){E=l}else{M=92;break}}do{if((M|0)==43){yDb(f,16,2181400,(T=i,i=i+8|0,c[T>>2]=fa,T)|0);i=T;Na=fa}else if((M|0)==48){yDb(f,16,2104328,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;Na=-1094995529}else if((M|0)==92){if((c[j>>2]|0)==0){KCb(c[g>>2]|0);E=MCb(c[g>>2]|0,t)|0;if((E|0)<0){Na=E;break}}c[h>>2]=1;Na=r}}while(0);ZDb(V);B=Na;i=k;return B|0}function IZa(a){a=a|0;JCb((c[a+60>>2]|0)+228|0);return 0}function JZa(a){a=a|0;KCb(c[(c[a+60>>2]|0)+228>>2]|0);return}function KZa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;g=i;i=i+280|0;h=g|0;j=g+256|0;c[h>>2]=e;e=a+8|0;k=a+16|0;l=a|0;a=(f|0)/4|0;m=0;n=1;o=1;p=5;a:while(1){b:do{if((p|0)==0){q=0;r=n;s=m;t=o}else{u=m;v=n;w=o;x=p;while(1){if((u|0)==(v|0)){y=x-1|0;if((y|0)==0){q=0;r=w;s=v;t=w;break b}else{z=y;A=w}}else{z=x;A=v}y=c[e>>2]|0;B=d[(c[l>>2]|0)+(y>>>3)|0]|0;c[e>>2]=((y|0)<(c[k>>2]|0))+y;if((B&128>>>((y&7)>>>0)|0)==0){q=z;r=A;s=u;t=w;break b}y=h+(u<<2)|0;c[h+(w<<2)>>2]=c[y>>2];B=w+2|0;c[h+(w+1<<2)>>2]=(c[y>>2]|0)+(((z&1|0)!=0?f:1)<<(z>>>1)+1);y=u+1|0;if((z|0)==0){q=0;r=A;s=y;t=B;break}else{u=y;v=A;w=B;x=z}}}}while(0);x=c[h+(s<<2)>>2]|0;w=1<<((q+4|0)>>>1);v=1<<((q+3|0)>>>1);u=c[4274332+(q*20|0)>>2]|0;B=c[e>>2]|0;y=c[k>>2]|0;C=c[l>>2]|0;D=C+(B>>>3)|0;E=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7)>>>29;D=b[u+(E<<2)>>1]|0;F=b[u+(E<<2)+2>>1]|0;E=F<<16>>16;do{if(F<<16>>16<0){G=B+3|0;H=y>>>0>G>>>0?G:y;G=C+(H>>>3)|0;I=((fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>((E+32|0)>>>0))+D|0;G=b[u+(I<<2)>>1]|0;J=b[u+(I<<2)+2>>1]|0;I=J<<16>>16;if(!(J<<16>>16<0)){K=I;L=G;M=H;break}J=H-E|0;H=y>>>0>J>>>0?J:y;J=C+(H>>>3)|0;N=((fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>((I+32|0)>>>0))+G|0;K=b[u+(N<<2)+2>>1]|0;L=b[u+(N<<2)>>1]|0;M=H}else{K=E;L=D;M=B}}while(0);B=K+M|0;D=y>>>0>B>>>0?B:y;c[e>>2]=D;B=L-1|0;c:do{if((L|0)==0){E=0;do{TGb(x+((ba(a,E)|0)<<2)|0,0,w|0)|0;E=E+1|0;}while(E>>>0<v>>>0)}else{E=(B|0)>0;if(E&q>>>0>3>>>0){O=-1094995529;P=38;break a}u=c[1068613]|0;F=C+(D>>>3)|0;H=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(D&7)>>>24;F=b[u+(H<<2)>>1]|0;N=b[u+(H<<2)+2>>1]|0;H=N<<16>>16;do{if(N<<16>>16<0){G=D+8|0;I=y>>>0>G>>>0?G:y;G=C+(I>>>3)|0;J=((fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(I&7)>>>((H+32|0)>>>0))+F|0;G=b[u+(J<<2)>>1]|0;Q=b[u+(J<<2)+2>>1]|0;J=Q<<16>>16;if(!(Q<<16>>16<0)){R=J;S=G;T=I;break}Q=I-H|0;I=y>>>0>Q>>>0?Q:y;Q=C+(I>>>3)|0;U=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(I&7)>>>((J+32|0)>>>0))+G|0;R=b[u+(U<<2)+2>>1]|0;S=b[u+(U<<2)>>1]|0;T=I}else{R=H;S=F;T=D}}while(0);F=R+T|0;H=y>>>0>F>>>0?F:y;c[e>>2]=H;if((B|0)==0){F=S&255;u=0;while(1){TGb(x+((ba(a,u)|0)<<2)|0,F|0,w|0)|0;u=u+1|0;if(!(u>>>0<v>>>0)){break c}}}u=c[1131640+(q<<2)>>2]|0;if(E){F=B<<2;N=C+(H>>>3)|0;I=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(H&7)>>>((32-F|0)>>>0);N=H+F|0;c[e>>2]=y>>>0>N>>>0?N:y;N=q+1|0;F=0;do{c[j+(F<<2)>>2]=(I>>>(((B-F<<2)-4|0)>>>0)&15|F<<4)<<N;F=F+1|0;}while((F|0)<(B|0))}F=(S-(B<<7)|0)*65537|0;N=w>>>2;I=(N|0)==0;H=u;U=0;G=x;while(1){if(I){V=H}else{if(E){J=H;Q=0;while(1){W=0;X=F;Y=F;do{Z=c[J+(c[j+(W<<2)>>2]<<2)>>2]^-2139062144;X=(Z>>>8&16711935)+X|0;Y=(Z&16711935)+Y|0;W=W+1|0;}while((W|0)<(B|0));if((X&-16711936|0)==0){_=X}else{_=(X>>>15&65537|256)+16711679&16711935&(((-2130738945-X|0)>>>15&65537|256)+16711679|X+32512)}if((Y&-16711936|0)==0){$=Y}else{$=(Y>>>15&65537|256)+16711679&16711935&(((-2130738945-Y|0)>>>15&65537|256)+16711679|Y+32512)}c[G+(Q<<2)>>2]=$|_<<8;W=Q+1|0;if(W>>>0<N>>>0){J=J+4|0;Q=W}else{break}}}else{Q=0;do{if((F&-16711936|0)==0){aa=F;ca=F}else{aa=(F>>>15&65537|256)+16711679&16711935&(((-2130738945-F|0)>>>15&65537|256)+16711679|F+32512);ca=(F>>>15&65537|256)+16711679&16711935&(((-2130738945-F|0)>>>15&65537|256)+16711679|F+32512)}c[G+(Q<<2)>>2]=aa|ca<<8;Q=Q+1|0;}while(Q>>>0<N>>>0)}V=H+(N<<2)|0}Q=U+1|0;if(Q>>>0<v>>>0){H=V;U=Q;G=G+(a<<2)|0}else{break}}}}while(0);v=s+1|0;if((v|0)<(t|0)){m=v;n=r;o=t;p=q}else{O=0;P=38;break}}if((P|0)==38){i=g;return O|0}return 0}function LZa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;g=i;i=i+280|0;h=g|0;j=g+256|0;c[h>>2]=e;e=a+8|0;k=a|0;l=a+16|0;a=(f|0)/4|0;m=0;n=1;o=1;p=5;a:while(1){b:do{if((p|0)>0){q=m;r=n;s=o;t=p;while(1){if((q|0)==(r|0)){u=t-1|0;if((u|0)==0){v=0;w=s;x=r;y=s;break b}else{z=u;A=s}}else{z=t;A=r}u=c[e>>2]|0;B=d[(c[k>>2]|0)+(u>>>3)|0]|0;c[e>>2]=((u|0)<(c[l>>2]|0))+u;if((B&128>>>((u&7)>>>0)|0)==0){v=z;w=A;x=q;y=s;break b}u=h+(q<<2)|0;c[h+(s<<2)>>2]=c[u>>2];B=s+2|0;c[h+(s+1<<2)>>2]=(c[u>>2]|0)+(((z&1|0)!=0?f:1)<<(z>>1)+1);u=q+1|0;if((z|0)>0){q=u;r=A;s=B;t=z}else{v=z;w=A;x=u;y=B;break}}}else{v=p;w=n;x=m;y=o}}while(0);t=c[h+(x<<2)>>2]|0;s=1<<((v+4|0)/2|0);r=1<<((v+3|0)/2|0);q=c[4274476+(v*20|0)>>2]|0;B=c[e>>2]|0;u=c[l>>2]|0;C=c[k>>2]|0;D=C+(B>>>3)|0;E=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7)>>>29;D=b[q+(E<<2)>>1]|0;F=b[q+(E<<2)+2>>1]|0;E=F<<16>>16;if(F<<16>>16<0){F=B+3|0;G=u>>>0>F>>>0?F:u;F=C+(G>>>3)|0;H=((fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(G&7)>>>((E+32|0)>>>0))+D|0;I=b[q+(H<<2)+2>>1]|0;J=b[q+(H<<2)>>1]|0;K=G}else{I=E;J=D;K=B}B=I+K|0;D=u>>>0>B>>>0?B:u;c[e>>2]=D;B=J-1|0;do{if((J|0)!=0){E=(B|0)>0;if(E&(v|0)>3){L=-1094995529;M=36;break a}G=c[1068649]|0;H=C+(D>>>3)|0;q=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(D&7)>>>23;H=b[G+(q<<2)>>1]|0;F=b[G+(q<<2)+2>>1]|0;q=F<<16>>16;do{if(F<<16>>16<0){N=D+9|0;O=u>>>0>N>>>0?N:u;N=C+(O>>>3)|0;P=((fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(O&7)>>>((q+32|0)>>>0))+H|0;N=b[G+(P<<2)>>1]|0;Q=b[G+(P<<2)+2>>1]|0;P=Q<<16>>16;if(!(Q<<16>>16<0)){R=P;S=N;T=O;break}Q=O-q|0;O=u>>>0>Q>>>0?Q:u;Q=C+(O>>>3)|0;U=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>((P+32|0)>>>0))+N|0;R=b[G+(U<<2)+2>>1]|0;S=b[G+(U<<2)>>1]|0;T=O}else{R=q;S=H;T=D}}while(0);H=R+T|0;q=u>>>0>H>>>0?H:u;c[e>>2]=q;H=c[1133808+(v<<2)>>2]|0;if(E){G=B<<2;F=C+(q>>>3)|0;O=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(q&7)>>>((32-G|0)>>>0);F=q+G|0;c[e>>2]=u>>>0>F>>>0?F:u;F=v+1|0;G=0;do{c[j+(G<<2)>>2]=(O>>>(((B-G<<2)-4|0)>>>0)&15|G<<4)<<F;G=G+1|0;}while((G|0)<(B|0))}G=(-256-(B<<7)+S|0)*65537|0;if((r|0)<=0){break}F=(s|0)/4|0;O=(s|0)>3;q=(F|0)>1?F:1;U=H;N=0;P=t;while(1){if(O){if(E){Q=U;V=0;while(1){W=P+(V<<2)|0;X=c[W>>2]|0;Y=0;Z=(X>>>8&16711935)+G|0;_=(X&16711935)+G|0;do{X=c[Q+(c[j+(Y<<2)>>2]<<2)>>2]^-2139062144;Z=(X>>>8&16711935)+Z|0;_=(X&16711935)+_|0;Y=Y+1|0;}while((Y|0)<(B|0));if((Z&-16711936|0)==0){$=Z}else{$=(Z>>>15&65537|256)+16711679&16711935&(((-2130738945-Z|0)>>>15&65537|256)+16711679|Z+32512)}if((_&-16711936|0)==0){aa=_}else{aa=(_>>>15&65537|256)+16711679&16711935&(((-2130738945-_|0)>>>15&65537|256)+16711679|_+32512)}c[W>>2]=aa|$<<8;Y=V+1|0;if((Y|0)<(F|0)){Q=Q+4|0;V=Y}else{break}}}else{V=0;do{Q=P+(V<<2)|0;Y=c[Q>>2]|0;X=(Y>>>8&16711935)+G|0;ba=(Y&16711935)+G|0;if((X&-16711936|0)==0){ca=X}else{ca=(X>>>15&65537|256)+16711679&16711935&(((-2130738945-X|0)>>>15&65537|256)+16711679|X+32512)}if((ba&-16711936|0)==0){da=ba}else{da=(ba>>>15&65537|256)+16711679&16711935&(((-2130738945-ba|0)>>>15&65537|256)+16711679|ba+32512)}c[Q>>2]=da|ca<<8;V=V+1|0;}while((V|0)<(F|0))}ea=U+(q<<2)|0}else{ea=U}V=N+1|0;if((V|0)<(r|0)){U=ea;N=V;P=P+(a<<2)|0}else{break}}}}while(0);r=x+1|0;if((r|0)<(y|0)){m=r;n=w;o=y;p=v}else{L=0;M=36;break}}if((M|0)==36){i=g;return L|0}return 0}function MZa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=a+8|0;h=a+16|0;i=f+4|0;j=f+8|0;k=e+4|0;l=e|0;e=c[1068577]|0;m=c[a>>2]|0;a=0;while(1){n=c[g>>2]|0;o=c[h>>2]|0;p=m+(n>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(n&7)>>>25;p=b[e+(q<<2)>>1]|0;r=b[e+(q<<2)+2>>1]|0;q=r<<16>>16;if(r<<16>>16<0){r=n+7|0;s=o>>>0>r>>>0?r:o;r=m+(s>>>3)|0;t=((fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((q+32|0)>>>0))+p|0;u=b[e+(t<<2)+2>>1]|0;v=b[e+(t<<2)>>1]|0;w=s}else{u=q;v=p;w=n}n=u+w|0;p=o>>>0>n>>>0?n:o;c[g>>2]=p;if((v|0)<0){x=-1094995529;y=21;break}if((v|0)==0){z=0}else{n=d[m+(p>>>3)|0]|0;c[g>>2]=((p|0)<(o|0))+p;z=(n&128>>>((p&7)>>>0)|0)==0?v:-v|0}p=c[f>>2]|0;if((a|0)==1){n=c[p+4>>2]|0;o=c[(c[i>>2]|0)+4>>2]|0;q=c[(c[j>>2]|0)+4>>2]|0;do{if((n|0)>(o|0)){if((q|0)<=(o|0)){A=o;break}A=(q|0)>(n|0)?n:q}else{if((o|0)<=(q|0)){A=o;break}A=(q|0)>(n|0)?q:n}}while(0);c[k>>2]=A+z<<26>>26}else{n=c[p>>2]|0;q=c[c[i>>2]>>2]|0;o=c[c[j>>2]>>2]|0;do{if((n|0)>(q|0)){if((o|0)<=(q|0)){B=q;break}B=(o|0)>(n|0)?n:o}else{if((q|0)<=(o|0)){B=q;break}B=(o|0)>(n|0)?o:n}}while(0);c[l>>2]=B+z<<26>>26}n=a+1|0;if((n|0)<2){a=n}else{x=0;y=21;break}}if((y|0)==21){return x|0}return 0}function NZa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+60>>2]|0;Z3(b+14676|0,a);BFa(b+15920|0,c[a+88>>2]|0);d=a+804|0;c[d>>2]=ICb()|0;e=b+16128|0;c[e>>2]=ICb()|0;f=ICb()|0;c[b+16132>>2]=f;do{if((c[d>>2]|0)!=0){if((c[e>>2]|0)==0|(f|0)==0){break}g=a+120|0;h=c[g>>2]|0;c[b+16324>>2]=h;i=c[a+124>>2]|0;c[b+16328>>2]=i;j=b+16332|0;c[j>>2]=(h+15|0)/16|0;k=b+16336|0;c[k>>2]=(i+15|0)/16|0;c[b+16340>>2]=(((h|0)/4|0)+15|0)/16|0;c[b+16344>>2]=(((i|0)/4|0)+15|0)/16|0;c[b+14672>>2]=a;c[b+4>>2]=a;c[b+14172>>2]=3;i=cEb((c[g>>2]<<6)+4096|0)|0;c[b+12192>>2]=i;c[b+12208>>2]=i;c[b+12216>>2]=cEb(256)|0;c[b+12220>>2]=cEb(256)|0;c[b+16348>>2]=cEb(ba(c[k>>2]<<1,(c[j>>2]|0)+1|0)|0)|0;c[b+16352>>2]=cEb(ba(c[k>>2]<<2,(c[j>>2]|0)+1|0)|0)|0;Olb(b);l=0;return l|0}}while(0);PZa(a)|0;l=-12;return l|0}function OZa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0;j=i;i=i+4136|0;k=j|0;l=j+4032|0;m=j+4104|0;n=j+4120|0;o=j+4128|0;p=c[e+60>>2]|0;q=p;r=c[e+804>>2]|0;s=(ba((c[p+16332>>2]|0)*9e3|0,c[p+16336>>2]|0)|0)+16384|0;t=r0a(e,f,s,(s|0)<0|0?-1:0)|0;if((t|0)<0){u=t;i=j;return u|0}if((c[e+140>>2]|0)!=6){yDb(e,16,2104288,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1;i=j;return u|0}t=p+16128|0;s=c[t>>2]|0;do{if((c[s>>2]|0)==0){w=_$a(e,s,0)|0;if((w|0)<0){u=w;i=j;return u|0}w=p+16132|0;y=_$a(e,c[w>>2]|0,0)|0;if((y|0)<0){u=y;i=j;return u|0}else{c[p+16392>>2]=WDb(c[(c[t>>2]|0)+32>>2]<<5)|0;z=c[t>>2]|0;A=w;break}}else{z=s;A=p+16132|0}}while(0);s=c[A>>2]|0;c[A>>2]=z;c[t>>2]=s;s=p+16136|0;z=f+28|0;w=c[z>>2]|0;y=(w|0)<0;B=y?0:c[f+24>>2]|0;C=y?0:w;c[p+16156>>2]=C<<3;w=p+16144|0;c[w>>2]=B;y=p+16152|0;c[y>>2]=B+C;C=p+16148|0;c[C>>2]=B;D=p+16140|0;c[D>>2]=32;E=s;c[E>>2]=0;G=c[e+136>>2]|0;if((G|0)==0){H=1}else{H=((c[e+428>>2]|0)%(G|0)|0|0)!=0?2:1}G=r+88|0;c[G>>2]=H;e=(H|0)==1;c[r+84>>2]=e&1;c[r+168>>2]=c[g+168>>2];r=c[E>>2]|0;I=c[D>>2]|0;if((I|0)>22){J=I-22|0;K=r<<22|32;L=B}else{M=B;x=fe(32>>>((22-I|0)>>>0)|r<<I|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;M=(c[C>>2]|0)+4|0;c[C>>2]=M;J=I+10|0;K=32;L=M}c[E>>2]=K;c[D>>2]=J;if((J|0)>8){N=J-8|0;O=K<<8;P=L}else{M=L;x=fe(K<<J|0)|0;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;M=(c[C>>2]|0)+4|0;c[C>>2]=M;N=J+24|0;O=0;P=M}c[E>>2]=O;c[D>>2]=N;M=H-1|0;if((N|0)>2){Q=N-2|0;R=O<<2|M;S=P}else{H=P;x=fe(M>>>((2-N|0)>>>0)|O<<N|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=(c[C>>2]|0)+4|0;c[C>>2]=H;Q=N+30|0;R=M;S=H}c[E>>2]=R;c[D>>2]=Q;do{if(e){if((Q|0)>5){T=Q-5|0;U=R<<5|2}else{H=S;x=fe(2>>>((5-Q|0)>>>0)|R<<Q|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;T=Q+27|0;U=2}c[E>>2]=U;c[D>>2]=T;H=p+16324|0;M=p+16328|0;N=Q0a(1133832,7,c[H>>2]|0,c[M>>2]|0)|0;O=c[E>>2]|0;P=c[D>>2]|0;if((P|0)>3){V=P-3|0;W=O<<3|N}else{J=fe(N>>>((3-P|0)>>>0)|O<<P|0)|0;O=c[C>>2]|0;x=J;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;V=P+29|0;W=N}c[E>>2]=W;c[D>>2]=V;if((N|0)!=7){X=V;Y=W;break}N=c[H>>2]|0;if((V|0)>12){Z=V-12|0;_=N|W<<12}else{H=fe(N>>>((12-V|0)>>>0)|W<<V|0)|0;P=c[C>>2]|0;x=H;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;Z=V+20|0;_=N}c[E>>2]=_;c[D>>2]=Z;N=c[M>>2]|0;if((Z|0)>12){$=Z-12|0;aa=N|_<<12}else{M=fe(N>>>((12-Z|0)>>>0)|_<<Z|0)|0;P=c[C>>2]|0;x=M;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;$=Z+20|0;aa=N}c[E>>2]=aa;c[D>>2]=$;X=$;Y=aa}else{X=Q;Y=R}}while(0);if((X|0)>2){ca=X-2|0;da=Y<<2}else{R=fe(Y<<X|0)|0;Y=c[C>>2]|0;x=R;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;ca=X+30|0;da=0}c[E>>2]=da;c[D>>2]=ca;ca=p+16324|0;da=p+16328|0;X=k|0;Y=m;R=p+14672|0;Q=p+16392|0;aa=p;$=p+4|0;Z=p+7624|0;_=p+9856|0;V=p+952|0;W=V;T=p+9848|0;U=V;V=p+7656|0;S=p+5432|0;e=p+984|0;N=p+148|0;P=p+8|0;M=p+12|0;H=p+116|0;O=p+120|0;J=p+124|0;K=p+128|0;L=p+11556|0;I=p+9992|0;r=p+11732|0;B=p+12440|0;ea=p+60|0;fa=p+9968|0;ga=p+9960|0;ha=p+9972|0;ia=p+16348|0;ja=p+12492|0;ka=p+16352|0;la=p+9216|0;ma=p+9192|0;na=p+9200|0;oa=p+9160|0;pa=p+9148|0;qa=p+11636|0;ra=p+10056|0;sa=p+14676|0;ta=p+12260|0;ua=p+14084|0;va=p+5400|0;wa=p+12480|0;xa=p+12476|0;ya=p+12496|0;za=p+12500|0;Aa=p+12504|0;Ba=p+12508|0;Ca=p+12512|0;Da=p+12516|0;Ea=p+12544|0;Fa=p+12548|0;Ga=p+12552|0;Ha=s;s=p+16300|0;Ia=a[1134075]|0;Ja=d[1134074]|0;Ka=s;La=p+16304|0;Ma=p+784|0;Na=p+16308|0;Oa=p+16312|0;Pa=m+4|0;Qa=m|0;Ra=p+14752|0;Sa=m+8|0;Ta=d[1134073]|0;Ua=p+15920|0;Va=d[1134072]|0;Wa=32-Ta|0;Xa=32-(Ia&255)|0;Ya=p+16384|0;Za=a[1134079]|0;_a=Za&255;$a=d[1134078]|0;ab=32-_a|0;bb=l+48|0;cb=p+16200|0;db=p+16188|0;eb=k+224|0;fb=p+16196|0;gb=p+16192|0;hb=p+16184|0;ib=p+16180|0;jb=k+224|0;kb=p+16224|0;lb=p+16212|0;mb=k+448|0;nb=p+16220|0;ob=p+16216|0;pb=p+16208|0;qb=p+16204|0;rb=k+448|0;sb=p+16248|0;tb=p+16236|0;ub=k+672|0;vb=p+16244|0;wb=p+16240|0;xb=p+16232|0;yb=p+16228|0;zb=k+672|0;Ab=p+16272|0;Bb=p+16260|0;Cb=k+896|0;Db=p+16268|0;Eb=p+16264|0;Fb=p+16256|0;Gb=p+16252|0;Hb=k+896|0;Ib=p+16296|0;Jb=p+16284|0;Kb=k+1120|0;Lb=p+16292|0;Mb=p+16288|0;Nb=p+16280|0;Ob=p+16276|0;Pb=k+1120|0;Qb=p+16320|0;Rb=k+1344|0;Sb=p+16316|0;p=(Za&255)>>>0<32>>>0;Za=Pb;Tb=k+1124|0;Ub=ab+32|0;Vb=k+1344|0;Wb=k+1568|0;Xb=k+1568|0;Yb=k+1792|0;Zb=k+1792|0;_b=k+2016|0;$b=k+2016|0;ac=k+2240|0;bc=k+2240|0;cc=k+2464|0;dc=k+2464|0;ec=k+2688|0;fc=(Ia&255)>>>0<32>>>0;Ia=dc;gc=k+2468|0;hc=Xa+32|0;ic=0;a:do{jc=c[g+(ic<<2)>>2]|0;kc=c[(c[A>>2]|0)+(ic<<2)>>2]|0;lc=c[t>>2]|0;mc=c[lc+(ic<<2)>>2]|0;nc=(ic|0)!=0?4:1;oc=(c[ca>>2]|0)/(nc|0)|0;pc=(c[da>>2]|0)/(nc|0)|0;nc=c[g+32+(ic<<2)>>2]|0;qc=c[lc+32+(ic<<2)>>2]|0;lc=c[R>>2]|0;rc=c[lc+804>>2]|0;sc=c[Q>>2]|0;tc=rc+168|0;uc=c[tc>>2]|0;vc=qc<<4;wc=(ba(uc,uc)|0)>>>14;uc=(oc+15|0)/16|0;xc=(pc+15|0)/16|0;yc=rc+88|0;if((c[yc>>2]|0)==2){c[$>>2]=lc;c[_>>2]=Z;c[T>>2]=W;c[U>>2]=kc;c[V>>2]=qc;c[S>>2]=qc;c[e>>2]=qc;c[N>>2]=qc;c[P>>2]=oc;c[M>>2]=pc;c[H>>2]=uc;c[O>>2]=xc;rc=uc+1|0;c[J>>2]=rc;zc=uc<<1|1;c[K>>2]=zc;c[L>>2]=1;c[I>>2]=2;c[r>>2]=c[lc+144>>2];c[B>>2]=0;c[ea>>2]=c[lc+88>>2];lc=c[tc>>2]|0;c[fa>>2]=lc;c[ga>>2]=((lc*139|0)+8192|0)>>>14;c[ha>>2]=((ba(lc,lc)|0)+64|0)>>>7;lc=q+16356+(ic<<2)|0;if((c[lc>>2]|0)==0){c[lc>>2]=cEb((ba(xc<<3,zc)|0)+8|0)|0;zc=q+16368+(ic<<2)|0;c[zc>>2]=cEb((ba(c[J>>2]|0,(xc<<2)+8|0)|0)+4|0)|0;Ac=c[J>>2]|0;Bc=zc}else{Ac=rc;Bc=q+16368+(ic<<2)|0}c[ja>>2]=c[ia>>2];rc=c[ka>>2]|0;c[la>>2]=rc;zc=rc;c[ma>>2]=zc;c[na>>2]=zc;c[oa>>2]=rc;c[pa>>2]=(c[lc>>2]|0)+8;c[qa>>2]=(c[Bc>>2]|0)+(Ac+1<<2);UGb(ra|0,sa|0,1244)|0;lmb(aa)|0;c[ta>>2]=c[(c[R>>2]|0)+248>>2];c[ua>>2]=1;if((pc|0)>0){lc=uc<<4;rc=(lc|0)>(oc|0);zc=vc-1|0;tc=(oc|0)>0;Cc=xc<<4;Dc=0;do{Ec=Dc<<4;c[va>>2]=sc+(vc-(ba(Ec,qc)|0));c[wa>>2]=Dc;Fc=0;while(1){Gc=Fc+Ec|0;if((Gc|0)>=(pc|0)){Hc=52;break}Ic=ba(Fc,qc)|0;UGb(sc+(Ic+vc)|0,jc+(ba(Gc,nc)|0)|0,oc)|0;if(rc){Gc=oc;do{Jc=Gc+Ic|0;a[sc+(Jc+vc)|0]=a[sc+(zc+Jc)|0]|0;Gc=Gc+1|0;}while((Gc|0)<(lc|0))}Gc=Fc+1|0;if((Gc|0)<16){Fc=Gc}else{break}}b:do{if((Hc|0)==52){Hc=0;if((Fc|0)<16){Kc=Fc}else{break}do{if((Kc+Ec|0)>=(Cc|0)){break b}UGb(sc+((ba(Kc,qc)|0)+vc)|0,sc+((ba(Kc-1|0,qc)|0)+vc)|0,lc)|0;Kc=Kc+1|0;}while((Kc|0)<16)}}while(0);if(tc){Ec=0;do{c[xa>>2]=Ec;$Oa(aa);Fc=8>>>((c[(c[$>>2]|0)+800>>2]|0)>>>0);c[ya>>2]=(c[ya>>2]|0)+2;c[za>>2]=(c[za>>2]|0)+2;c[Aa>>2]=(c[Aa>>2]|0)+2;c[Ba>>2]=(c[Ba>>2]|0)+2;c[Ca>>2]=(c[Ca>>2]|0)+1;c[Da>>2]=(c[Da>>2]|0)+1;c[Ea>>2]=(c[Ea>>2]|0)+(Fc<<1);c[Fa>>2]=(c[Fa>>2]|0)+Fc;c[Ga>>2]=(c[Ga>>2]|0)+Fc;smb(aa,Ec,Dc);Ec=Ec+1|0;}while((Ec|0)<(uc|0))}c[ua>>2]=0;Dc=Dc+1|0;}while((Dc|0)<(xc|0))}Bmb(aa);Cmb(aa,0,0,c[qa>>2]|0,c[L>>2]|0,2,0)}c[ua>>2]=1;if((pc|0)>0){Dc=uc<<4;tc=(Dc|0)>(oc|0);lc=vc-1|0;Cc=(oc|0)>0;zc=ba(Ta,wc)|0;rc=ba(_a,wc)|0;Ec=xc<<4;Fc=0;do{Gc=Fc<<4;c:do{if(tc){Ic=0;do{Jc=Ic+Gc|0;if((Jc|0)>=(pc|0)){Lc=Ic;Hc=68;break c}Mc=ba(Ic,qc)|0;UGb(sc+(Mc+vc)|0,jc+(ba(Jc,nc)|0)|0,oc)|0;Jc=oc;do{Nc=Jc+Mc|0;a[sc+(Nc+vc)|0]=a[sc+(lc+Nc)|0]|0;Jc=Jc+1|0;}while((Jc|0)<(Dc|0));Ic=Ic+1|0;}while((Ic|0)<16)}else{Ic=0;do{Jc=Ic+Gc|0;if((Jc|0)>=(pc|0)){Lc=Ic;Hc=68;break c}UGb(sc+((ba(Ic,qc)|0)+vc)|0,jc+(ba(Jc,nc)|0)|0,oc)|0;Ic=Ic+1|0;}while((Ic|0)<16)}}while(0);d:do{if((Hc|0)==68){Hc=0;if((Lc|0)<16){Oc=Lc}else{break}do{if((Oc+Gc|0)>=(Ec|0)){break d}UGb(sc+((ba(Oc,qc)|0)+vc)|0,sc+((ba(Oc-1|0,qc)|0)+vc)|0,Dc)|0;Oc=Oc+1|0;}while((Oc|0)<16)}}while(0);c[wa>>2]=Fc;if(Cc){Gc=ba(Fc,vc)|0;Ic=0;do{Jc=Ic<<4;Mc=Jc+Gc|0;Nc=mc+Mc|0;Pc=kc+Mc|0;TGb(Y|0,0,16)|0;Qc=c[Q>>2]|0;Rc=c[w>>2]|0;if(((c[y>>2]|0)-Rc-(32-(c[D>>2]|0)+((c[C>>2]|0)-Rc<<3)>>3)|0)<3e3){Hc=74;break a}c[xa>>2]=Ic;$Oa(aa);Rc=8>>>((c[(c[$>>2]|0)+800>>2]|0)>>>0);c[ya>>2]=(c[ya>>2]|0)+2;c[za>>2]=(c[za>>2]|0)+2;c[Aa>>2]=(c[Aa>>2]|0)+2;c[Ba>>2]=(c[Ba>>2]|0)+2;c[Ca>>2]=(c[Ca>>2]|0)+1;c[Da>>2]=(c[Da>>2]|0)+1;c[Ea>>2]=(c[Ea>>2]|0)+(Rc<<1);c[Fa>>2]=(c[Fa>>2]|0)+Rc;c[Ga>>2]=(c[Ga>>2]|0)+Rc;Rc=c[yc>>2]|0;do{if((Rc|0)==1){Hc=77}else{Sc=(ba(c[J>>2]|0,Fc)|0)+Ic|0;if(!((b[(c[ja>>2]|0)+(Sc<<1)>>1]&1)==0)){Hc=77;break}c[Qa>>2]=2147483647;Tc=Rc;Uc=2147483647}}while(0);if((Hc|0)==77){Hc=0;c[cb>>2]=1792;c[db>>2]=X;c[fb>>2]=eb;c[gb>>2]=X;c[hb>>2]=32;c[ib>>2]=0;c[kb>>2]=1792;c[lb>>2]=jb;c[nb>>2]=mb;c[ob>>2]=jb;c[pb>>2]=32;c[qb>>2]=0;c[sb>>2]=1792;c[tb>>2]=rb;c[vb>>2]=ub;c[wb>>2]=rb;c[xb>>2]=32;c[yb>>2]=0;c[Ab>>2]=1792;c[Bb>>2]=zb;c[Db>>2]=Cb;c[Eb>>2]=zb;c[Fb>>2]=32;c[Gb>>2]=0;c[Ib>>2]=1792;c[Jb>>2]=Hb;c[Lb>>2]=Kb;c[Mb>>2]=Hb;c[Nb>>2]=32;c[Ob>>2]=0;c[Qb>>2]=1792;c[Na>>2]=Pb;c[Sb>>2]=Rb;c[Oa>>2]=Pb;c[La>>2]=32;c[Ka>>2]=0;if((Rc|0)==2){if(p){Vc=ab}else{x=-1;a[Za]=x;x=x>>8;a[Za+1|0]=x;x=x>>8;a[Za+2|0]=x;x=x>>8;a[Za+3|0]=x;c[Oa>>2]=Tb;Vc=Ub}c[Ka>>2]=$a;c[La>>2]=Vc;c[Qa>>2]=rc;Wc=rc}else{Wc=0}Sc=(QZa(q,sc+(Jc+vc)|0,0,Qc,qc,5,64,wc,1)|0)+Wc|0;c[Qa>>2]=Sc;Xc=0;do{Yc=q+16180+(Xc*24|0)+4|0;Zc=c[Yc>>2]|0;_c=q+16180+(Xc*24|0)+12|0;$c=c[_c>>2]|0;c[l+(Xc<<2)>>2]=32-Zc+($c-(c[q+16180+(Xc*24|0)+8>>2]|0)<<3);ad=q+16180+(Xc*24|0)|0;do{if((Zc|0)<32){bd=c[ad>>2]<<Zc;c[ad>>2]=bd;c[_c>>2]=$c+1;a[$c]=bd>>>24;bd=c[ad>>2]|0;c[ad>>2]=bd<<8;cd=(c[Yc>>2]|0)+8|0;c[Yc>>2]=cd;if((cd|0)>=32){break}cd=bd>>>16&255;while(1){bd=c[_c>>2]|0;c[_c>>2]=bd+1;a[bd]=cd;bd=c[ad>>2]|0;c[ad>>2]=bd<<8;dd=(c[Yc>>2]|0)+8|0;c[Yc>>2]=dd;if((dd|0)<32){cd=bd>>>16&255}else{break}}}}while(0);c[Yc>>2]=32;c[ad>>2]=0;Xc=Xc+1|0;}while((Xc|0)<6);Tc=c[yc>>2]|0;Uc=Sc}e:do{if((Tc|0)==2){Xc=Bca(aa,0,0,n,o)|0;Rc=(ba(c[J>>2]|0,Fc)|0)+Ic|0;do{if((b[(c[ja>>2]|0)+(Rc<<1)>>1]&2)==0){ed=0;fd=Uc;gd=Xc+2|0}else{c[cb>>2]=1792;c[db>>2]=Vb;c[fb>>2]=Wb;c[gb>>2]=Vb;c[hb>>2]=32;c[ib>>2]=0;c[kb>>2]=1792;c[lb>>2]=Xb;c[nb>>2]=Yb;c[ob>>2]=Xb;c[pb>>2]=32;c[qb>>2]=0;c[sb>>2]=1792;c[tb>>2]=Zb;c[vb>>2]=_b;c[wb>>2]=Zb;c[xb>>2]=32;c[yb>>2]=0;c[Ab>>2]=1792;c[Bb>>2]=$b;c[Db>>2]=ac;c[Eb>>2]=$b;c[Fb>>2]=32;c[Gb>>2]=0;c[Ib>>2]=1792;c[Jb>>2]=bc;c[Lb>>2]=cc;c[Mb>>2]=bc;c[Nb>>2]=32;c[Ob>>2]=0;c[Qb>>2]=1792;c[Na>>2]=dc;c[Sb>>2]=ec;c[Oa>>2]=dc;c[La>>2]=32;c[Ka>>2]=0;if(fc){hd=Xa}else{x=-1;a[Ia]=x;x=x>>8;a[Ia+1|0]=x;x=x>>8;a[Ia+2|0]=x;x=x>>8;a[Ia+3|0]=x;c[Oa>>2]=gc;hd=hc}c[Ka>>2]=Ja;c[La>>2]=hd;c[Ma>>2]=c[s>>2];c[Ma+4>>2]=c[s+4>>2];c[Ma+8>>2]=c[s+8>>2];c[Ma+12>>2]=c[s+12>>2];c[Ma+16>>2]=c[s+16>>2];c[Ma+20>>2]=c[s+20>>2];_c=b[Xc>>1]|0;$c=_c<<16>>16;Zc=Xc+2|0;cd=b[Zc>>1]|0;bd=cd<<16>>16;Nlb(aa,$c-(c[n>>2]|0)|0,1);Nlb(aa,bd-(c[o>>2]|0)|0,1);c[s>>2]=c[Ma>>2];c[s+4>>2]=c[Ma+4>>2];c[s+8>>2]=c[Ma+8>>2];c[s+12>>2]=c[Ma+12>>2];c[s+16>>2]=c[Ma+16>>2];c[s+20>>2]=c[Ma+20>>2];dd=ba(32-(c[La>>2]|0)+((c[Oa>>2]|0)-(c[Na>>2]|0)<<3)|0,wc)|0;id=Qc+16|0;jd=kc+(($c>>1)+Mc+(ba(bd>>1,qc)|0))|0;cf[c[q+15920+((bd<<1&2|$c&1)<<2)>>2]&1023](id,jd,qc,16);jd=sc+(Jc+vc)|0;$c=dd+(QZa(q,jd,id,Nc,qc,5,64,wc,0)|0)|0;c[Pa>>2]=$c;id=($c|0)<=(Uc|0);$c=id&1;dd=(Pe[c[Ra>>2]&255](0,jd,Pc,qc,16)|0)+zc|0;c[Sa>>2]=dd;jd=c[m+($c<<2)>>2]|0;if((dd|0)<(jd|0)&_c<<16>>16==0&cd<<16>>16==0){cf[c[Ua>>2]&1023](Nc,Pc,qc,16);TGb(bb|0,0,24)|0;cd=c[E>>2]|0;_c=c[D>>2]|0;if((_c|0)>(Ta|0)){kd=_c-Ta|0;ld=cd<<Ta|Va}else{bd=fe(Va>>>((Ta-_c|0)>>>0)|cd<<_c|0)|0;cd=c[C>>2]|0;x=bd;a[cd]=x;x=x>>8;a[cd+1|0]=x;x=x>>8;a[cd+2|0]=x;x=x>>8;a[cd+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;kd=Wa+_c|0;ld=Va}c[E>>2]=ld;c[D>>2]=kd;ed=2;fd=dd;gd=Zc;break}if(id){md=0}else{ed=$c;fd=jd;gd=Zc;break}while(1){Zc=q+16180+(md*24|0)+4|0;id=c[Zc>>2]|0;dd=q+16180+(md*24|0)+12|0;_c=c[dd>>2]|0;c[l+24+(md<<2)>>2]=32-id+(_c-(c[q+16180+(md*24|0)+8>>2]|0)<<3);cd=q+16180+(md*24|0)|0;do{if((id|0)<32){bd=c[cd>>2]<<id;c[cd>>2]=bd;c[dd>>2]=_c+1;a[_c]=bd>>>24;bd=c[cd>>2]|0;c[cd>>2]=bd<<8;nd=(c[Zc>>2]|0)+8|0;c[Zc>>2]=nd;if((nd|0)>=32){break}nd=bd>>>16&255;while(1){bd=c[dd>>2]|0;c[dd>>2]=bd+1;a[bd]=nd;bd=c[cd>>2]|0;c[cd>>2]=bd<<8;od=(c[Zc>>2]|0)+8|0;c[Zc>>2]=od;if((od|0)<32){nd=bd>>>16&255}else{break}}}}while(0);c[Zc>>2]=32;c[cd>>2]=0;dd=md+1|0;if((dd|0)<6){md=dd}else{pd=$c;qd=jd;break e}}}}while(0);Rc=c[K>>2]<<1;b[Xc+(Rc+3<<1)>>1]=0;b[Xc+(Rc+2<<1)>>1]=0;b[Xc+((Rc|1)<<1)>>1]=0;b[Xc+(Rc<<1)>>1]=0;b[Xc+6>>1]=0;b[Xc+4>>1]=0;b[gd>>1]=0;b[Xc>>1]=0;pd=ed;qd=fd}else{pd=0;qd=Uc}}while(0);Pc=YGb(c[Ya>>2]|0,c[Ya+4>>2]|0,qd,(qd|0)<0|0?-1:0)|0;c[Ya>>2]=Pc;c[Ya+4>>2]=F;M_(Ha,k+(pd*1344|0)+1120|0,c[l+(pd*24|0)+20>>2]|0);M_(Ha,k+(pd*1344|0)+896|0,c[l+(pd*24|0)+16>>2]|0);M_(Ha,k+(pd*1344|0)+672|0,c[l+(pd*24|0)+12>>2]|0);M_(Ha,k+(pd*1344|0)+448|0,c[l+(pd*24|0)+8>>2]|0);M_(Ha,k+(pd*1344|0)+224|0,c[l+(pd*24|0)+4>>2]|0);M_(Ha,k+(pd*1344|0)|0,c[l+(pd*24|0)>>2]|0);if((pd|0)==0){cf[c[Ua>>2]&1023](Nc,Qc,qc,16)}Ic=Ic+1|0;}while((Ic|0)<(uc|0))}c[ua>>2]=0;Fc=Fc+1|0;}while((Fc|0)<(xc|0))}ic=ic+1|0;}while((ic|0)<3);if((Hc|0)==74){yDb(c[R>>2]|0,16,2047832,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1;i=j;return u|0}v=c[D>>2]|0;R=c[w>>2]|0;Hc=c[C>>2]|0;if((32-v+(Hc-R<<3)&31|0)==0){rd=v;sd=R;td=Hc}else{ic=c[E>>2]|0;ua=v;v=R;R=Hc;while(1){if((ua|0)>1){ud=ua-1|0;vd=ic<<1;wd=v;xd=R}else{Hc=R;x=fe(ic<<ua|0)|0;a[Hc]=x;x=x>>8;a[Hc+1|0]=x;x=x>>8;a[Hc+2|0]=x;x=x>>8;a[Hc+3|0]=x;Hc=(c[C>>2]|0)+4|0;c[C>>2]=Hc;ud=ua+31|0;vd=0;wd=c[w>>2]|0;xd=Hc}c[E>>2]=vd;c[D>>2]=ud;if((32-ud+(xd-wd<<3)&31|0)==0){rd=ud;sd=wd;td=xd;break}else{ic=vd;ua=ud;v=wd;R=xd}}}if((rd|0)<32){xd=c[E>>2]<<rd;c[E>>2]=xd;rd=xd>>>24&255;xd=td;while(1){c[C>>2]=xd+1;a[xd]=rd;R=c[E>>2]|0;c[E>>2]=R<<8;wd=(c[D>>2]|0)+8|0;c[D>>2]=wd;if((wd|0)>=32){break}rd=R>>>16&255;xd=c[C>>2]|0}yd=c[w>>2]|0;zd=c[C>>2]|0}else{yd=sd;zd=td}c[D>>2]=32;c[E>>2]=0;c[z>>2]=(zd-yd<<3|0)/8|0;if((c[G>>2]|0)==1){G=f+36|0;c[G>>2]=c[G>>2]|1}c[h>>2]=1;u=0;i=j;return u|0}function PZa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0;b=i;d=c[a+60>>2]|0;e=d+16384|0;f=ba(c[a+124>>2]|0,c[a+120>>2]|0)|0;g=(+((c[e>>2]|0)>>>0)+ +(c[e+4>>2]|0)*4294967296.0)/+(ba(f,c[a+428>>2]|0)|0);yDb(a,48,2181392,(f=i,i=i+8|0,h[f>>3]=g,f)|0);i=f;$Db(d+12192|0);$Db(d+12216|0);$Db(d+12220|0);$Db(d+16348|0);$Db(d+16352|0);$Db(d+16392|0);$Db(d+16356|0);$Db(d+16368|0);$Db(d+16360|0);$Db(d+16372|0);$Db(d+16364|0);$Db(d+16376|0);JCb(d+16128|0);JCb(d+16132|0);JCb(a+804|0);i=b;return 0}function QZa(f,g,h,j,k,l,m,n,o){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;p=i;i=i+3752|0;q=p|0;r=p+24|0;s=p+3608|0;t=2<<(l+2>>1);u=2<<(l+1>>1);v=ba(t,u)|0;w=(o|0)!=0;do{if(w){y=c[1131640+(l<<2)>>2]|0;if((u|0)>0&(t|0)>0){z=0;A=0;B=0}else{C=0;D=1130520;E=1130616;G=y;H=405368;I=0;break}while(1){J=ba(A,k)|0;K=ba(A,t)|0;L=z;M=0;N=B;do{O=a[g+(M+J)|0]|0;P=O&255;b[r+(M+K<<1)>>1]=O&255;L=(ba(P,P)|0)+L|0;N=N+P|0;M=M+1|0;}while((M|0)<(t|0));M=A+1|0;if((M|0)<(u|0)){z=L;A=M;B=N}else{C=L;D=1130520;E=1130616;G=y;H=405368;I=N;break}}}else{y=c[1133808+(l<<2)>>2]|0;if((u|0)>0&(t|0)>0){Q=0;R=0;S=0}else{C=0;D=1131664;E=1132784;G=y;H=417272;I=0;break}while(1){M=ba(R,k)|0;K=ba(R,t)|0;J=Q;P=0;O=S;do{T=P+M|0;U=(d[g+T|0]|0)-(d[h+T|0]|0)|0;b[r+(P+K<<1)>>1]=U;J=(ba(U,U)|0)+J|0;O=U+O|0;P=P+1|0;}while((P|0)<(t|0));P=R+1|0;if((P|0)<(u|0)){Q=J;R=P;S=O}else{C=J;D=1131664;E=1132784;G=y;H=417272;I=O;break}}}}while(0);S=l+3|0;R=C-((ba(I,I)|0)>>>(S>>>0))|0;C=v>>1;Q=I+C>>S;a:do{if((l|0)<4){B=f+15208|0;A=S;z=w?0:-256;y=(v|0)>0;P=0;K=R;M=Q;N=1;L=I;while(1){U=N-1|0;T=U<<4;V=r+(U<<9)|0;W=q+(U<<2)|0;X=2147483647;Y=-999;Z=-999;_=0;while(1){$=_+T|0;aa=a[H+(l*96|0)+$|0]|0;ca=G+(ba($,v)|0)|0;$=L-aa|0;da=ze[c[B>>2]&511](ca,V,v)|0;ca=$;ea=($|0)<0|0?-1:0;fa=gHb(ca,ea,ca,ea)|0;ea=$Gb(fa|0,F|0,A|0)|0;fa=ZGb(da,0,ea,F)|0;ea=fa;if((ea|0)<(X|0)){fa=$+C>>S;if((fa|0)<(z|0)){ga=z}else{ga=(fa|0)>255?255:fa}c[W>>2]=_;ha=ga;ia=aa;ja=ea}else{ha=Z;ia=Y;ja=X}ea=_+1|0;if((ea|0)<16){X=ja;Y=ia;Z=ha;_=ea}else{break}}if((ha|0)==-999){break}if(y){_=ba((c[W>>2]|0)+T|0,v)|0;Z=0;do{b[r+(N<<9)+(Z<<1)>>1]=(b[r+(U<<9)+(Z<<1)>>1]|0)-(a[G+(_+Z)|0]|0);Z=Z+1|0;}while((Z|0)<(v|0))}Z=N+1|0;_=(ba((d[D+(l<<4)+(Z<<1)+1|0]|0)+(N<<2|1)+(e[E+(ha<<2)+2>>1]|0)|0,n)|0)+ja|0;U=(_|0)<(K|0);T=U?N:P;W=U?_:K;_=U?ha:M;if((Z|0)<7){P=T;K=W;M=_;N=Z;L=L-ia|0}else{ka=_;la=W;ma=T;break a}}yDb(0,0,2002232,(L=i,i=i+24|0,c[L>>2]=1964936,c[L+8>>2]=1936808,c[L+16>>2]=189,L)|0);i=L;Cd();return 0}else{ka=Q;la=R;ma=0}}while(0);do{if((la|0)<=(m|0)|(l|0)==0){na=0;oa=la;pa=32}else{if((l&1|0)==0){qa=t}else{qa=ba(u,k)|0}R=(qa|0)/2|0;Q=l-1|0;ia=(l|0)>0;if(ia){ha=Q;while(1){ja=s+(ha*24|0)|0;v=f+16180+(ha*24|0)|0;c[ja>>2]=c[v>>2];c[ja+4>>2]=c[v+4>>2];c[ja+8>>2]=c[v+8>>2];c[ja+12>>2]=c[v+12>>2];c[ja+16>>2]=c[v+16>>2];c[ja+20>>2]=c[v+20>>2];if((ha|0)>0){ha=ha-1|0}else{break}}}ha=m>>1;v=QZa(f,g,h,j,k,Q,ha,n,o)|0;ja=v+n+(QZa(f,g+R|0,h+R|0,j+R|0,k,Q,ha,n,o)|0)|0;if((ja|0)<(la|0)){na=1;oa=ja;pa=32;break}if(ia){ra=Q}else{sa=la;break}while(1){ja=f+16180+(ra*24|0)|0;ha=s+(ra*24|0)|0;c[ja>>2]=c[ha>>2];c[ja+4>>2]=c[ha+4>>2];c[ja+8>>2]=c[ha+8>>2];c[ja+12>>2]=c[ha+12>>2];c[ja+16>>2]=c[ha+16>>2];c[ja+20>>2]=c[ha+20>>2];if((ra|0)>0){ra=ra-1|0}else{na=0;oa=la;pa=32;break}}}}while(0);do{if((pa|0)==32){if((l|0)>0){la=f+16180+(l*24|0)|0;ra=c[la>>2]|0;s=f+16180+(l*24|0)+4|0;o=c[s>>2]|0;if((o|0)>1){ta=o-1|0;ua=ra<<1|na}else{n=fe(na>>>((1-o|0)>>>0)|ra<<o|0)|0;ra=f+16180+(l*24|0)+12|0;h=c[ra>>2]|0;x=n;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[ra>>2]=(c[ra>>2]|0)+4;ta=o+31|0;ua=na}c[la>>2]=ua;c[s>>2]=ta}if((na|0)==0){sa=oa;break}else{va=oa}i=p;return va|0}}while(0);oa=ma+1|0;na=d[D+(l<<4)+(oa<<1)+1|0]|0;ta=d[D+(l<<4)+(oa<<1)|0]|0;oa=f+16180+(l*24|0)|0;D=c[oa>>2]|0;ua=f+16180+(l*24|0)+4|0;pa=c[ua>>2]|0;if((pa|0)>(na|0)){wa=pa-na|0;xa=D<<na|ta}else{s=fe(ta>>>((na-pa|0)>>>0)|D<<pa|0)|0;D=f+16180+(l*24|0)+12|0;la=c[D>>2]|0;x=s;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;wa=32-na+pa|0;xa=ta}c[oa>>2]=xa;c[ua>>2]=wa;ta=e[E+(ka<<2)+2>>1]|0;pa=e[E+(ka<<2)>>1]|0;if((wa|0)>(ta|0)){ya=wa;za=xa<<ta|pa}else{E=fe(pa>>>((ta-wa|0)>>>0)|xa<<wa|0)|0;xa=f+16180+(l*24|0)+12|0;na=c[xa>>2]|0;x=E;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[xa>>2]=(c[xa>>2]|0)+4;ya=wa+32|0;za=pa}pa=ya-ta|0;c[oa>>2]=za;c[ua>>2]=pa;if((ma|0)>0){ta=f+16180+(l*24|0)+12|0;l=0;f=za;za=pa;while(1){pa=c[q+(l<<2)>>2]|0;if((za|0)>4){Aa=za-4|0;Ba=f<<4|pa}else{ya=fe(pa>>>((4-za|0)>>>0)|f<<za|0)|0;wa=c[ta>>2]|0;x=ya;a[wa]=x;x=x>>8;a[wa+1|0]=x;x=x>>8;a[wa+2|0]=x;x=x>>8;a[wa+3|0]=x;c[ta>>2]=(c[ta>>2]|0)+4;Aa=za+28|0;Ba=pa}c[oa>>2]=Ba;c[ua>>2]=Aa;pa=l+1|0;if((pa|0)<(ma|0)){l=pa;f=Ba;za=Aa}else{break}}}if((u|0)>0&(t|0)>0){Ca=0}else{va=sa;i=p;return va|0}while(1){Aa=ba(Ca,k)|0;za=ba(Ca,t)|0;Ba=0;do{f=Ba+Aa|0;a[j+f|0]=(d[g+f|0]|0)+ka-(e[r+(ma<<9)+(Ba+za<<1)>>1]|0);Ba=Ba+1|0;}while((Ba|0)<(t|0));Ba=Ca+1|0;if((Ba|0)<(u|0)){Ca=Ba}else{va=sa;break}}i=p;return va|0}function RZa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+64|0;h=g|0;j=c[405160+(f<<2)>>2]|0;f=0;while(1){k=f<<2;l=b[e+(k<<1)>>1]|0;m=k|2;n=b[e+(m<<1)>>1]|0;o=(n+l|0)*13|0;p=(l-n|0)*13|0;n=k|1;l=b[e+(n<<1)>>1]|0;q=k|3;r=b[e+(q<<1)>>1]|0;s=(r*-17|0)+(l*7|0)|0;t=(r*7|0)+(l*17|0)|0;c[h+(k<<2)>>2]=t+o;c[h+(n<<2)>>2]=s+p;c[h+(m<<2)>>2]=p-s;c[h+(q<<2)>>2]=o-t;t=f+1|0;if((t|0)<4){f=t}else{u=0;break}}do{f=d[1130408+u|0]|0;e=c[h+(u<<2)>>2]|0;t=c[h+(u+8<<2)>>2]|0;o=(t+e|0)*13|0;q=(e-t|0)*13|0;t=c[h+(u+4<<2)>>2]|0;e=c[h+(u+12<<2)>>2]|0;s=(e*-17|0)+(t*7|0)|0;p=(e*7|0)+(t*17|0)|0;b[a+(f<<1)>>1]=(ba(p+o|0,j)|0)+524288>>20;b[a+(f+32<<1)>>1]=(ba(s+q|0,j)|0)+524288>>20;b[a+(f+128<<1)>>1]=(ba(q-s|0,j)|0)+524288>>20;b[a+(f+160<<1)>>1]=(ba(o-p|0,j)|0)+524288>>20;u=u+1|0;}while((u|0)<4);i=g;return}function SZa(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=c[405160+(h<<2)>>2]|0;if((i|0)==0){k=524288}else if((i|0)==1){l=(b[f>>1]|0)*1538|0;m=4}else{l=(ba(b[f>>1]>>3,j)|0)/2|0;m=4}if((m|0)==4){b[f>>1]=0;k=(l*169|0)+524288|0}l=0;do{m=l<<2;i=f+(m<<1)|0;h=b[i>>1]|0;n=f+((m|2)<<1)|0;o=b[n>>1]|0;p=(o+h|0)*13|0;q=(h-o|0)*13|0;o=f+((m|1)<<1)|0;h=b[o>>1]|0;r=f+((m|3)<<1)|0;m=b[r>>1]|0;s=(m*-17|0)+(h*7|0)|0;t=(m*7|0)+(h*17|0)|0;b[i>>1]=t+p;b[o>>1]=s+q;b[n>>1]=q-s;b[r>>1]=p-t;l=l+1|0;}while((l|0)<4);l=g<<1;t=g*3|0;p=0;do{r=b[f+(p<<1)>>1]|0;s=b[f+(p+8<<1)>>1]|0;q=(s+r|0)*13|0;n=(r-s|0)*13|0;s=b[f+(p+4<<1)>>1]|0;r=b[f+(p+12<<1)>>1]|0;o=(r*-17|0)+(s*7|0)|0;i=(r*7|0)+(s*17|0)|0;s=e+p|0;r=((ba(i+q|0,j)|0)+k>>20)+(d[s]|0)|0;if(r>>>0>255>>>0){u=-r>>31&255}else{u=r&255}a[s]=u;s=e+(p+g)|0;r=(d[s]|0)+((ba(o+n|0,j)|0)+k>>20)|0;if(r>>>0>255>>>0){v=-r>>31&255}else{v=r&255}a[s]=v;s=e+(p+l)|0;r=(d[s]|0)+((ba(n-o|0,j)|0)+k>>20)|0;if(r>>>0>255>>>0){w=-r>>31&255}else{w=r&255}a[s]=w;s=e+(p+t)|0;r=(d[s]|0)+((ba(q-i|0,j)|0)+k>>20)|0;if(r>>>0>255>>>0){x=-r>>31&255}else{x=r&255}a[s]=x;p=p+1|0;}while((p|0)<4);TGb(f|0,0,32)|0;return}



function cza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;lza(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;mza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=ZGb(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=ZGb(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function dza(a,f,g){a=a|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+72|0;j=h|0;k=j|0;l=j+16|0;m=g<<1;n=f+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=n;n=j+8|0;k=g-m|0;o=f+k|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=f;n=o|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=p;c[l+4>>2]=o;o=j+24|0;n=f+g|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=n;n=j+32|0;o=m+g+g|0;q=f+(o-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=j+40|0;n=o+g|0;o=f+(n-m)|0;r=o|0;s=o+4|0;o=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=o;o=j+48|0;q=n+g|0;n=f+(q-m)|0;r=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=n;n=j+56|0;o=q+g|0;q=f+(o-m)|0;m=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=q;q=j+64|0;j=f+(k+o)|0;o=j|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=j;j=g>>1;g=j<<1;q=j*3|0;o=l;l=a;a=1;k=p&65535;while(1){p=e[o-8>>1]|0;f=k&65535;n=e[o+8>>1]|0;m=e[o+16>>1]|0;r=e[o+24>>1]|0;s=e[o+32>>1]|0;t=e[o+40>>1]|0;u=e[o+48>>1]|0;v=(e[o-16>>1]|0)+16+((n+f|0)*20|0)+r+((m+p|0)*-5|0)>>5;if(v>>>0<16384>>>0){w=v}else{w=-v>>31&16383}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;v=l+(j<<1)|0;x=p+16+((m+n|0)*20|0)+s+((r+f|0)*-5|0)>>5;if(x>>>0<16384>>>0){y=x}else{y=-x>>31&16383}b[v>>1]=((e[v>>1]|0)+1+y|0)>>>1;v=l+(g<<1)|0;x=f+16+((r+m|0)*20|0)+t+((s+n|0)*-5|0)>>5;if(x>>>0<16384>>>0){z=x}else{z=-x>>31&16383}b[v>>1]=((e[v>>1]|0)+1+z|0)>>>1;v=l+(q<<1)|0;x=n+16+((s+r|0)*20|0)+u+((t+m|0)*-5|0)>>5;if(x>>>0<16384>>>0){A=x}else{A=-x>>31&16383}b[v>>1]=((e[v>>1]|0)+1+A|0)>>>1;v=o+2|0;if((a|0)>=4){break}o=v;l=l+2|0;a=a+1|0;k=b[v>>1]|0}i=h;return}function eza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;mza(k,o,8);nza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;s=c[n+4>>2]|0;r=o^j;h=ZGb(l|b,o|j,((l^b)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;b=r^s;l=ZGb(h|g,r|s,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;s=c[n>>2]|0;r=c[n+4>>2]|0;j=h^b;o=ZGb(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^r;g=ZGb(o|s,j|r,((o^s)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;s=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;r=c[n+4>>2]|0;j=o^l;b=ZGb(s|g,o|l,((s^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;g=j^r;s=ZGb(b|p,j|r,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=s;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;s=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^s;b=ZGb(m|k,g|s,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;k=p^a;m=ZGb(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;i=f;return}function fza(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+288|0;h=g|0;j=f>>1;f=j<<1;k=d+(-f<<1)|0;d=0;l=h|0;while(1){m=e[k>>1]|0;n=e[k+2>>1]|0;o=e[k-2>>1]|0;p=e[k+4>>1]|0;q=e[k+6>>1]|0;c[l>>2]=(e[k-4>>1]|0)+((n+m|0)*20|0)+((p+o|0)*-5|0)+q;r=e[k+8>>1]|0;c[l+4>>2]=((p+n|0)*20|0)+o+r+((q+m|0)*-5|0);o=e[k+10>>1]|0;c[l+8>>2]=((q+p|0)*20|0)+m+o+((r+n|0)*-5|0);c[l+12>>2]=((r+q|0)*20|0)+n+(e[k+12>>1]|0)+((o+p|0)*-5|0);p=d+1|0;if((p|0)<9){k=k+(j<<1)|0;d=p;l=l+32|0}else{break}}l=j*3|0;d=a;a=0;k=h+64|0;while(1){h=c[k-32>>2]|0;p=c[k>>2]|0;o=c[k+32>>2]|0;n=c[k+64>>2]|0;q=c[k+96>>2]|0;r=c[k+128>>2]|0;m=c[k+160>>2]|0;s=c[k+192>>2]|0;t=(c[k-64>>2]|0)+512+((o+p|0)*20|0)+q+((n+h|0)*-5|0)>>10;if(t>>>0<16384>>>0){u=t}else{u=-t>>31&16383}b[d>>1]=((e[d>>1]|0)+1+u|0)>>>1;t=d+(j<<1)|0;v=h+512+((n+o|0)*20|0)+r+((q+p|0)*-5|0)>>10;if(v>>>0<16384>>>0){w=v}else{w=-v>>31&16383}b[t>>1]=((e[t>>1]|0)+1+w|0)>>>1;t=d+(f<<1)|0;v=p+512+((q+n|0)*20|0)+m+((r+o|0)*-5|0)>>10;if(v>>>0<16384>>>0){x=v}else{x=-v>>31&16383}b[t>>1]=((e[t>>1]|0)+1+x|0)>>>1;t=d+(l<<1)|0;v=o+512+((r+q|0)*20|0)+s+((m+n|0)*-5|0)>>10;if(v>>>0<16384>>>0){y=v}else{y=-v>>31&16383}b[t>>1]=((e[t>>1]|0)+1+y|0)>>>1;t=a+1|0;if((t|0)<4){d=d+2|0;a=t;k=k+4|0}else{break}}i=g;return}function gza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;mza(k,o,8);nza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;t=c[n+4>>2]|0;s=o^j;h=ZGb(l|b,o|j,((l^b)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;b=s^t;l=ZGb(h|g,s|t,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;t=c[n>>2]|0;s=c[n+4>>2]|0;j=h^b;o=ZGb(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^s;g=ZGb(o|t,j|s,((o^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;t=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;s=c[n+4>>2]|0;j=o^l;b=ZGb(t|g,o|l,((t^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;g=j^s;t=ZGb(b|p,j|s,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=t;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^t;b=ZGb(m|k,g|t,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;k=p^a;m=ZGb(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;i=f;return}function hza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;mza(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=a;t=c[k>>2]|0;h=c[k+4>>2]|0;b=s^g;r=ZGb(o|l,s|g,((o^l)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;l=b^h;o=ZGb(r|t,b|h,((r^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=o;c[k+4>>2]=F;k=c[n>>2]|0;o=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;t=c[n+4>>2]|0;n=a+e|0;r=c[n>>2]|0;h=c[n+4>>2]|0;b=t^o;g=ZGb(l|k,t|o,((l^k)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;k=b^h;l=ZGb(g|r,b|h,((g^r)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=c[q>>2]|0;l=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;r=c[q+4>>2]|0;q=a+m|0;m=c[q>>2]|0;g=c[q+4>>2]|0;h=r^l;b=ZGb(k|n,r|l,((k^n)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;n=h^g;k=ZGb(b|m,h|g,((b^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=k;c[q+4>>2]=F;q=c[p>>2]|0;k=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;n=c[p+4>>2]|0;p=a+(e*3|0)|0;e=c[p>>2]|0;a=c[p+4>>2]|0;m=n^k;b=ZGb(j|q,n|k,((j^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;q=m^a;j=ZGb(b|e,m|a,((b^e)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[p>>2]=j;c[p+4>>2]=F;i=f;return}function iza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;lza(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;mza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=o^g;q=ZGb(k|n,o|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;o=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(o|h,g|b,((o^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;o=c[m+4>>2]|0;m=a+p|0;p=c[m>>2]|0;b=c[m+4>>2]|0;g=o^k;n=ZGb(h|r,o|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|p,g|b,((n^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;p=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;j=p^a;l=ZGb(n|e,p|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function jza(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;lza(f,b+d|0,8,d);nza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=ZGb(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;b=o^n;g=ZGb(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=F;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=ZGb(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;g=k^o;m=ZGb(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=F;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=ZGb(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;m=b^k;n=ZGb(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=ZGb(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;f=o^a;h=ZGb(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=F;i=e;return}function kza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;lza(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;mza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=ZGb(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=ZGb(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function lza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<16384>>>0){m=l&65535}else{m=-l>>31&16383}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<16384>>>0){o=n&65535}else{o=-n>>31&16383}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<16384>>>0){p=i&65535}else{p=-i>>31&16383}b[h+4>>1]=p;i=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(i>>>0<16384>>>0){q=i&65535}else{q=-i>>31&16383}b[h+6>>1]=q;i=f+1|0;if((i|0)<4){f=i;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function mza(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d>>1;d=f<<1;g=f*3|0;h=c;c=a;a=0;while(1){i=e[h-8>>1]|0;j=e[h>>1]|0;k=e[h+8>>1]|0;l=e[h+16>>1]|0;m=e[h+24>>1]|0;n=e[h+32>>1]|0;o=e[h+40>>1]|0;p=e[h+48>>1]|0;q=(e[h-16>>1]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0<16384>>>0){r=q&65535}else{r=-q>>31&16383}b[c>>1]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0<16384>>>0){s=q&65535}else{s=-q>>31&16383}b[c+(f<<1)>>1]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0<16384>>>0){t=q&65535}else{t=-q>>31&16383}b[c+(d<<1)>>1]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0<16384>>>0){u=q&65535}else{u=-q>>31&16383}b[c+(g<<1)>>1]=u;q=a+1|0;if((q|0)<4){h=h+2|0;c=c+2|0;a=q}else{break}}return}function nza(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=h>>1;h=f+(-(i<<1)<<1)|0;f=0;j=d;while(1){k=e[h>>1]|0;l=e[h+2>>1]|0;m=e[h-2>>1]|0;n=e[h+4>>1]|0;o=e[h+6>>1]|0;c[j>>2]=(e[h-4>>1]|0)+((l+k|0)*20|0)+((n+m|0)*-5|0)+o;p=e[h+8>>1]|0;c[j+4>>2]=m+((n+l|0)*20|0)+((o+k|0)*-5|0)+p;m=e[h+10>>1]|0;c[j+8>>2]=k+((o+n|0)*20|0)+((p+l|0)*-5|0)+m;c[j+12>>2]=l+((p+o|0)*20|0)+((m+n|0)*-5|0)+(e[h+12>>1]|0);n=f+1|0;if((n|0)<9){h=h+(i<<1)|0;f=n;j=j+32|0}else{break}}j=g>>1;g=j<<1;f=j*3|0;i=a;a=0;h=d+64|0;while(1){d=c[h-32>>2]|0;n=c[h>>2]|0;m=c[h+32>>2]|0;o=c[h+64>>2]|0;p=c[h+96>>2]|0;l=c[h+128>>2]|0;k=c[h+160>>2]|0;q=c[h+192>>2]|0;r=(c[h-64>>2]|0)+512+((m+n|0)*20|0)+p+((o+d|0)*-5|0)>>10;if(r>>>0<16384>>>0){s=r&65535}else{s=-r>>31&16383}b[i>>1]=s;r=d+512+((o+m|0)*20|0)+l+((p+n|0)*-5|0)>>10;if(r>>>0<16384>>>0){t=r&65535}else{t=-r>>31&16383}b[i+(j<<1)>>1]=t;r=n+512+((p+o|0)*20|0)+k+((l+m|0)*-5|0)>>10;if(r>>>0<16384>>>0){u=r&65535}else{u=-r>>31&16383}b[i+(g<<1)>>1]=u;r=m+512+((l+p|0)*20|0)+q+((k+o|0)*-5|0)>>10;if(r>>>0<16384>>>0){v=r&65535}else{v=-r>>31&16383}b[i+(f<<1)>>1]=v;r=a+1|0;if((r|0)<4){i=i+2|0;a=r;h=h+4|0}else{break}}return}function oza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<16384>>>0){m=l&65535}else{m=-l>>31&16383}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<16384>>>0){o=n&65535}else{o=-n>>31&16383}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<16384>>>0){p=i&65535}else{p=-i>>31&16383}b[h+4>>1]=p;i=a+12|0;q=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(q>>>0<16384>>>0){r=q&65535}else{r=-q>>31&16383}b[h+6>>1]=r;q=a+14|0;c=(((e[n>>1]|0)+(e[l>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[q>>1]|0)>>5;if(c>>>0<16384>>>0){s=c&65535}else{s=-c>>31&16383}b[h+8>>1]=s;c=a+16|0;j=(((e[i>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[q>>1]|0)+(e[l>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<16384>>>0){t=j&65535}else{t=-j>>31&16383}b[h+10>>1]=t;j=a+18|0;k=(((e[q>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[l>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<16384>>>0){u=k&65535}else{u=-k>>31&16383}b[h+12>>1]=u;k=(((e[c>>1]|0)+(e[q>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<16384>>>0){v=k&65535}else{v=-k>>31&16383}b[h+14>>1]=v;k=f+1|0;if((k|0)<8){f=k;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function pza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<16384>>>0){L=K&65535}else{L=-K>>31&16383}b[c>>1]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0<16384>>>0){M=K&65535}else{M=-K>>31&16383}b[c+(g<<1)>>1]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0<16384>>>0){N=K&65535}else{N=-K>>31&16383}b[c+(r<<1)>>1]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0<16384>>>0){O=K&65535}else{O=-K>>31&16383}b[c+(s<<1)>>1]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0<16384>>>0){P=K&65535}else{P=-K>>31&16383}b[c+(t<<1)>>1]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0<16384>>>0){Q=K&65535}else{Q=-K>>31&16383}b[c+(u<<1)>>1]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0<16384>>>0){R=K&65535}else{R=-K>>31&16383}b[c+(v<<1)>>1]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0<16384>>>0){S=K&65535}else{S=-K>>31&16383}b[c+(w<<1)>>1]=S;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function qza(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=i>>1;i=f+(-(j<<1)<<1)|0;f=0;k=d;while(1){l=e[i>>1]|0;m=e[i+2>>1]|0;n=e[i-2>>1]|0;o=e[i+4>>1]|0;p=e[i+6>>1]|0;c[k>>2]=(e[i-4>>1]|0)+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;q=e[i+8>>1]|0;c[k+4>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+q;n=e[i+10>>1]|0;c[k+8>>2]=l+((p+o|0)*20|0)+((q+m|0)*-5|0)+n;l=e[i+12>>1]|0;c[k+12>>2]=m+((q+p|0)*20|0)+((n+o|0)*-5|0)+l;m=e[i+14>>1]|0;c[k+16>>2]=o+((n+q|0)*20|0)+((l+p|0)*-5|0)+m;o=e[i+16>>1]|0;c[k+20>>2]=p+((l+n|0)*20|0)+((m+q|0)*-5|0)+o;p=e[i+18>>1]|0;c[k+24>>2]=q+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;c[k+28>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+(e[i+20>>1]|0);l=f+1|0;if((l|0)<13){i=i+(j<<1)|0;f=l;k=k+(h<<2)|0}else{break}}k=g>>1;g=h*-2|0;f=-h|0;j=h<<1;i=h*3|0;l=h<<2;p=h*5|0;m=h*6|0;o=h*7|0;n=h<<3;q=h*9|0;r=h*10|0;s=k<<1;t=k*3|0;u=k<<2;v=k*5|0;w=k*6|0;x=k*7|0;y=a;a=0;z=d+(h<<1<<2)|0;while(1){d=c[z+(f<<2)>>2]|0;A=c[z>>2]|0;B=c[z+(h<<2)>>2]|0;C=c[z+(j<<2)>>2]|0;D=c[z+(i<<2)>>2]|0;E=c[z+(l<<2)>>2]|0;F=c[z+(p<<2)>>2]|0;G=c[z+(m<<2)>>2]|0;H=c[z+(o<<2)>>2]|0;I=c[z+(n<<2)>>2]|0;J=c[z+(q<<2)>>2]|0;K=c[z+(r<<2)>>2]|0;L=(c[z+(g<<2)>>2]|0)+512+((B+A|0)*20|0)+D+((C+d|0)*-5|0)>>10;if(L>>>0<16384>>>0){M=L&65535}else{M=-L>>31&16383}b[y>>1]=M;L=d+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(L>>>0<16384>>>0){N=L&65535}else{N=-L>>31&16383}b[y+(k<<1)>>1]=N;L=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(L>>>0<16384>>>0){O=L&65535}else{O=-L>>31&16383}b[y+(s<<1)>>1]=O;L=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(L>>>0<16384>>>0){P=L&65535}else{P=-L>>31&16383}b[y+(t<<1)>>1]=P;L=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(L>>>0<16384>>>0){Q=L&65535}else{Q=-L>>31&16383}b[y+(u<<1)>>1]=Q;L=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(L>>>0<16384>>>0){R=L&65535}else{R=-L>>31&16383}b[y+(v<<1)>>1]=R;L=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(L>>>0<16384>>>0){S=L&65535}else{S=-L>>31&16383}b[y+(w<<1)>>1]=S;L=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(L>>>0<16384>>>0){T=L&65535}else{T=-L>>31&16383}b[y+(x<<1)>>1]=T;L=a+1|0;if((L|0)<8){y=y+2|0;a=L;z=z+4|0}else{break}}return}function rza(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;j=i>>1;i=f+(-(j<<1)<<1)|0;f=0;k=d;while(1){l=e[i>>1]|0;m=e[i+2>>1]|0;n=e[i-2>>1]|0;o=e[i+4>>1]|0;p=e[i+6>>1]|0;c[k>>2]=(e[i-4>>1]|0)+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;q=e[i+8>>1]|0;c[k+4>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+q;n=e[i+10>>1]|0;c[k+8>>2]=l+((p+o|0)*20|0)+((q+m|0)*-5|0)+n;l=e[i+12>>1]|0;c[k+12>>2]=m+((q+p|0)*20|0)+((n+o|0)*-5|0)+l;m=e[i+14>>1]|0;c[k+16>>2]=o+((n+q|0)*20|0)+((l+p|0)*-5|0)+m;o=e[i+16>>1]|0;c[k+20>>2]=p+((l+n|0)*20|0)+((m+q|0)*-5|0)+o;p=e[i+18>>1]|0;c[k+24>>2]=q+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;c[k+28>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+(e[i+20>>1]|0);l=f+1|0;if((l|0)<13){i=i+(j<<1)|0;f=l;k=k+(h<<2)|0}else{break}}k=g>>1;g=h*-2|0;f=-h|0;j=h<<1;i=h*3|0;l=h<<2;p=h*5|0;m=h*6|0;o=h*7|0;n=h<<3;q=h*9|0;r=h*10|0;s=k<<1;t=k*3|0;u=k<<2;v=k*5|0;w=k*6|0;x=k*7|0;y=a;a=0;z=d+(h<<1<<2)|0;while(1){d=c[z+(f<<2)>>2]|0;A=c[z>>2]|0;B=c[z+(h<<2)>>2]|0;C=c[z+(j<<2)>>2]|0;D=c[z+(i<<2)>>2]|0;E=c[z+(l<<2)>>2]|0;F=c[z+(p<<2)>>2]|0;G=c[z+(m<<2)>>2]|0;H=c[z+(o<<2)>>2]|0;I=c[z+(n<<2)>>2]|0;J=c[z+(q<<2)>>2]|0;K=c[z+(r<<2)>>2]|0;L=(c[z+(g<<2)>>2]|0)+512+((B+A|0)*20|0)+D+((C+d|0)*-5|0)>>10;if(L>>>0<16384>>>0){M=L}else{M=-L>>31&16383}b[y>>1]=((e[y>>1]|0)+1+M|0)>>>1;L=y+(k<<1)|0;N=d+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(N>>>0<16384>>>0){O=N}else{O=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+O|0)>>>1;L=y+(s<<1)|0;N=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(N>>>0<16384>>>0){P=N}else{P=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+P|0)>>>1;L=y+(t<<1)|0;N=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(N>>>0<16384>>>0){Q=N}else{Q=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+Q|0)>>>1;L=y+(u<<1)|0;N=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(N>>>0<16384>>>0){R=N}else{R=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+R|0)>>>1;L=y+(v<<1)|0;N=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(N>>>0<16384>>>0){S=N}else{S=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+S|0)>>>1;L=y+(w<<1)|0;N=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(N>>>0<16384>>>0){T=N}else{T=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+T|0)>>>1;L=y+(x<<1)|0;N=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(N>>>0<16384>>>0){U=N}else{U=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+U|0)>>>1;L=a+1|0;if((L|0)<8){y=y+2|0;a=L;z=z+4|0}else{break}}return}function sza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<16384>>>0){L=K}else{L=-K>>31&16383}b[c>>1]=((e[c>>1]|0)+1+L|0)>>>1;K=c+(g<<1)|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0<16384>>>0){N=M}else{N=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=c+(r<<1)|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0<16384>>>0){O=M}else{O=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=c+(s<<1)|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0<16384>>>0){P=M}else{P=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=c+(t<<1)|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0<16384>>>0){Q=M}else{Q=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=c+(u<<1)|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0<16384>>>0){R=M}else{R=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=c+(v<<1)|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0<16384>>>0){S=M}else{S=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=c+(w<<1)|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0<16384>>>0){T=M}else{T=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function tza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<16384>>>0){m=l}else{m=-l>>31&16383}b[h>>1]=((e[h>>1]|0)+1+m|0)>>>1;l=h+2|0;n=a+8|0;o=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(o>>>0<16384>>>0){p=o}else{p=-o>>31&16383}b[l>>1]=((e[l>>1]|0)+1+p|0)>>>1;l=h+4|0;o=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[n>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[o>>1]|0)>>5;if(i>>>0<16384>>>0){q=i}else{q=-i>>31&16383}b[l>>1]=((e[l>>1]|0)+1+q|0)>>>1;l=h+6|0;i=a+12|0;r=(((e[n>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[o>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(r>>>0<16384>>>0){s=r}else{s=-r>>31&16383}b[l>>1]=((e[l>>1]|0)+1+s|0)>>>1;l=h+8|0;r=a+14|0;c=(((e[o>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[r>>1]|0)>>5;if(c>>>0<16384>>>0){t=c}else{t=-c>>31&16383}b[l>>1]=((e[l>>1]|0)+1+t|0)>>>1;l=h+10|0;c=a+16|0;j=(((e[i>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[r>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<16384>>>0){u=j}else{u=-j>>31&16383}b[l>>1]=((e[l>>1]|0)+1+u|0)>>>1;l=h+12|0;j=a+18|0;k=(((e[r>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[c>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<16384>>>0){v=k}else{v=-k>>31&16383}b[l>>1]=((e[l>>1]|0)+1+v|0)>>>1;l=h+14|0;k=(((e[c>>1]|0)+(e[r>>1]|0)|0)*20|0)+16+(e[o>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<16384>>>0){w=k}else{w=-k>>31&16383}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;l=f+1|0;if((l|0)<8){f=l;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function uza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a;h=c;i=d>>1;d=f>>1;f=c+2|0;j=c-2|0;k=c+4|0;l=c+6|0;m=(((e[f>>1]|0)+(e[h>>1]|0)|0)*20|0)+16+(e[c-4>>1]|0)+(((e[k>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[g>>1]=n;n=(((e[k>>1]|0)+(e[f>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[l>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[c+8>>1]|0)>>5;if(n>>>0<16384>>>0){o=n&65535}else{o=-n>>31&16383}b[a+2>>1]=o;o=h+(d<<1)|0;a=h+(d+1<<1)|0;n=h+(d-1<<1)|0;c=h+(d+2<<1)|0;l=h+(d+3<<1)|0;j=(((e[a>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[h+(d-2<<1)>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(j>>>0<16384>>>0){p=j&65535}else{p=-j>>31&16383}b[g+(i<<1)>>1]=p;p=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[l>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[h+(d+4<<1)>>1]|0)>>5;if(p>>>0<16384>>>0){q=p&65535;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}q=-p>>31&16383;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}function vza(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a;g=d>>1;d=e[c-4>>1]|0;h=e[c>>1]|0;i=e[c+4>>1]|0;j=e[c+8>>1]|0;k=e[c+12>>1]|0;l=e[c+16>>1]|0;m=(e[c-8>>1]|0)+16+((i+h|0)*20|0)+k+((j+d|0)*-5|0)>>5;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[f>>1]=n;n=d+16+((j+i|0)*20|0)+l+((k+h|0)*-5|0)>>5;if(n>>>0<16384>>>0){o=n&65535}else{o=-n>>31&16383}b[f+(g<<1)>>1]=o;o=a+2|0;a=e[c-2>>1]|0;f=e[c+2>>1]|0;n=e[c+6>>1]|0;h=e[c+10>>1]|0;k=e[c+14>>1]|0;l=e[c+18>>1]|0;i=(e[c-6>>1]|0)+16+((n+f|0)*20|0)+k+((h+a|0)*-5|0)>>5;if(i>>>0<16384>>>0){p=i&65535}else{p=-i>>31&16383}b[o>>1]=p;p=a+16+((h+n|0)*20|0)+l+((k+f|0)*-5|0)>>5;if(p>>>0<16384>>>0){q=p&65535;r=o+(g<<1)|0;b[r>>1]=q;return}q=-p>>31&16383;r=o+(g<<1)|0;b[r>>1]=q;return}function wza(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=h>>1;h=f+(-(i<<1)<<1)|0;f=0;j=d;while(1){k=e[h>>1]|0;l=e[h+2>>1]|0;m=e[h-2>>1]|0;n=e[h+4>>1]|0;o=e[h+6>>1]|0;c[j>>2]=(e[h-4>>1]|0)+((l+k|0)*20|0)+((n+m|0)*-5|0)+o;c[j+4>>2]=m+((n+l|0)*20|0)+((o+k|0)*-5|0)+(e[h+8>>1]|0);k=f+1|0;if((k|0)<7){h=h+(i<<1)|0;f=k;j=j+16|0}else{break}}j=a;f=g>>1;g=c[d+16>>2]|0;i=c[d+32>>2]|0;h=c[d+48>>2]|0;k=c[d+64>>2]|0;o=c[d+80>>2]|0;l=c[d+96>>2]|0;n=(c[d>>2]|0)+512+((h+i|0)*20|0)+o+((k+g|0)*-5|0)>>10;if(n>>>0<16384>>>0){p=n&65535}else{p=-n>>31&16383}b[j>>1]=p;p=g+512+((k+h|0)*20|0)+l+((o+i|0)*-5|0)>>10;if(p>>>0<16384>>>0){q=p&65535}else{q=-p>>31&16383}b[j+(f<<1)>>1]=q;q=a+2|0;a=c[d+20>>2]|0;j=c[d+36>>2]|0;p=c[d+52>>2]|0;i=c[d+68>>2]|0;o=c[d+84>>2]|0;l=c[d+100>>2]|0;h=(c[d+4>>2]|0)+512+((p+j|0)*20|0)+o+((i+a|0)*-5|0)>>10;if(h>>>0<16384>>>0){r=h&65535}else{r=-h>>31&16383}b[q>>1]=r;r=a+512+((i+p|0)*20|0)+l+((o+j|0)*-5|0)>>10;if(r>>>0<16384>>>0){s=r&65535;t=q+(f<<1)|0;b[t>>1]=s;return}s=-r>>31&16383;t=q+(f<<1)|0;b[t>>1]=s;return}function xza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<4096>>>0){m=l&65535}else{m=-l>>31&4095}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<4096>>>0){o=n&65535}else{o=-n>>31&4095}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<4096>>>0){p=i&65535}else{p=-i>>31&4095}b[h+4>>1]=p;i=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(i>>>0<4096>>>0){q=i&65535}else{q=-i>>31&4095}b[h+6>>1]=q;i=f+1|0;if((i|0)<4){f=i;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function yza(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d>>1;d=f<<1;g=f*3|0;h=c;c=a;a=0;while(1){i=e[h-8>>1]|0;j=e[h>>1]|0;k=e[h+8>>1]|0;l=e[h+16>>1]|0;m=e[h+24>>1]|0;n=e[h+32>>1]|0;o=e[h+40>>1]|0;p=e[h+48>>1]|0;q=(e[h-16>>1]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0<4096>>>0){r=q&65535}else{r=-q>>31&4095}b[c>>1]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0<4096>>>0){s=q&65535}else{s=-q>>31&4095}b[c+(f<<1)>>1]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0<4096>>>0){t=q&65535}else{t=-q>>31&4095}b[c+(d<<1)>>1]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0<4096>>>0){u=q&65535}else{u=-q>>31&4095}b[c+(g<<1)>>1]=u;q=a+1|0;if((q|0)<4){h=h+2|0;c=c+2|0;a=q}else{break}}return}function zza(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=h>>1;h=f+(-(i<<1)<<1)|0;f=0;j=d;while(1){k=e[h>>1]|0;l=e[h+2>>1]|0;m=e[h-2>>1]|0;n=e[h+4>>1]|0;o=e[h+6>>1]|0;c[j>>2]=(e[h-4>>1]|0)+((l+k|0)*20|0)+((n+m|0)*-5|0)+o;p=e[h+8>>1]|0;c[j+4>>2]=m+((n+l|0)*20|0)+((o+k|0)*-5|0)+p;m=e[h+10>>1]|0;c[j+8>>2]=k+((o+n|0)*20|0)+((p+l|0)*-5|0)+m;c[j+12>>2]=l+((p+o|0)*20|0)+((m+n|0)*-5|0)+(e[h+12>>1]|0);n=f+1|0;if((n|0)<9){h=h+(i<<1)|0;f=n;j=j+32|0}else{break}}j=g>>1;g=j<<1;f=j*3|0;i=a;a=0;h=d+64|0;while(1){d=c[h-32>>2]|0;n=c[h>>2]|0;m=c[h+32>>2]|0;o=c[h+64>>2]|0;p=c[h+96>>2]|0;l=c[h+128>>2]|0;k=c[h+160>>2]|0;q=c[h+192>>2]|0;r=(c[h-64>>2]|0)+512+((m+n|0)*20|0)+p+((o+d|0)*-5|0)>>10;if(r>>>0<4096>>>0){s=r&65535}else{s=-r>>31&4095}b[i>>1]=s;r=d+512+((o+m|0)*20|0)+l+((p+n|0)*-5|0)>>10;if(r>>>0<4096>>>0){t=r&65535}else{t=-r>>31&4095}b[i+(j<<1)>>1]=t;r=n+512+((p+o|0)*20|0)+k+((l+m|0)*-5|0)>>10;if(r>>>0<4096>>>0){u=r&65535}else{u=-r>>31&4095}b[i+(g<<1)>>1]=u;r=m+512+((l+p|0)*20|0)+q+((k+o|0)*-5|0)>>10;if(r>>>0<4096>>>0){v=r&65535}else{v=-r>>31&4095}b[i+(f<<1)>>1]=v;r=a+1|0;if((r|0)<4){i=i+2|0;a=r;h=h+4|0}else{break}}return}function Aza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<4096>>>0){m=l&65535}else{m=-l>>31&4095}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<4096>>>0){o=n&65535}else{o=-n>>31&4095}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<4096>>>0){p=i&65535}else{p=-i>>31&4095}b[h+4>>1]=p;i=a+12|0;q=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(q>>>0<4096>>>0){r=q&65535}else{r=-q>>31&4095}b[h+6>>1]=r;q=a+14|0;c=(((e[n>>1]|0)+(e[l>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[q>>1]|0)>>5;if(c>>>0<4096>>>0){s=c&65535}else{s=-c>>31&4095}b[h+8>>1]=s;c=a+16|0;j=(((e[i>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[q>>1]|0)+(e[l>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<4096>>>0){t=j&65535}else{t=-j>>31&4095}b[h+10>>1]=t;j=a+18|0;k=(((e[q>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[l>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<4096>>>0){u=k&65535}else{u=-k>>31&4095}b[h+12>>1]=u;k=(((e[c>>1]|0)+(e[q>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<4096>>>0){v=k&65535}else{v=-k>>31&4095}b[h+14>>1]=v;k=f+1|0;if((k|0)<8){f=k;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function Bza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<4096>>>0){L=K&65535}else{L=-K>>31&4095}b[c>>1]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0<4096>>>0){M=K&65535}else{M=-K>>31&4095}b[c+(g<<1)>>1]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0<4096>>>0){N=K&65535}else{N=-K>>31&4095}b[c+(r<<1)>>1]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0<4096>>>0){O=K&65535}else{O=-K>>31&4095}b[c+(s<<1)>>1]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0<4096>>>0){P=K&65535}else{P=-K>>31&4095}b[c+(t<<1)>>1]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0<4096>>>0){Q=K&65535}else{Q=-K>>31&4095}b[c+(u<<1)>>1]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0<4096>>>0){R=K&65535}else{R=-K>>31&4095}b[c+(v<<1)>>1]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0<4096>>>0){S=K&65535}else{S=-K>>31&4095}b[c+(w<<1)>>1]=S;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function Cza(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=i>>1;i=f+(-(j<<1)<<1)|0;f=0;k=d;while(1){l=e[i>>1]|0;m=e[i+2>>1]|0;n=e[i-2>>1]|0;o=e[i+4>>1]|0;p=e[i+6>>1]|0;c[k>>2]=(e[i-4>>1]|0)+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;q=e[i+8>>1]|0;c[k+4>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+q;n=e[i+10>>1]|0;c[k+8>>2]=l+((p+o|0)*20|0)+((q+m|0)*-5|0)+n;l=e[i+12>>1]|0;c[k+12>>2]=m+((q+p|0)*20|0)+((n+o|0)*-5|0)+l;m=e[i+14>>1]|0;c[k+16>>2]=o+((n+q|0)*20|0)+((l+p|0)*-5|0)+m;o=e[i+16>>1]|0;c[k+20>>2]=p+((l+n|0)*20|0)+((m+q|0)*-5|0)+o;p=e[i+18>>1]|0;c[k+24>>2]=q+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;c[k+28>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+(e[i+20>>1]|0);l=f+1|0;if((l|0)<13){i=i+(j<<1)|0;f=l;k=k+(h<<2)|0}else{break}}k=g>>1;g=h*-2|0;f=-h|0;j=h<<1;i=h*3|0;l=h<<2;p=h*5|0;m=h*6|0;o=h*7|0;n=h<<3;q=h*9|0;r=h*10|0;s=k<<1;t=k*3|0;u=k<<2;v=k*5|0;w=k*6|0;x=k*7|0;y=a;a=0;z=d+(h<<1<<2)|0;while(1){d=c[z+(f<<2)>>2]|0;A=c[z>>2]|0;B=c[z+(h<<2)>>2]|0;C=c[z+(j<<2)>>2]|0;D=c[z+(i<<2)>>2]|0;E=c[z+(l<<2)>>2]|0;F=c[z+(p<<2)>>2]|0;G=c[z+(m<<2)>>2]|0;H=c[z+(o<<2)>>2]|0;I=c[z+(n<<2)>>2]|0;J=c[z+(q<<2)>>2]|0;K=c[z+(r<<2)>>2]|0;L=(c[z+(g<<2)>>2]|0)+512+((B+A|0)*20|0)+D+((C+d|0)*-5|0)>>10;if(L>>>0<4096>>>0){M=L&65535}else{M=-L>>31&4095}b[y>>1]=M;L=d+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(L>>>0<4096>>>0){N=L&65535}else{N=-L>>31&4095}b[y+(k<<1)>>1]=N;L=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(L>>>0<4096>>>0){O=L&65535}else{O=-L>>31&4095}b[y+(s<<1)>>1]=O;L=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(L>>>0<4096>>>0){P=L&65535}else{P=-L>>31&4095}b[y+(t<<1)>>1]=P;L=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(L>>>0<4096>>>0){Q=L&65535}else{Q=-L>>31&4095}b[y+(u<<1)>>1]=Q;L=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(L>>>0<4096>>>0){R=L&65535}else{R=-L>>31&4095}b[y+(v<<1)>>1]=R;L=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(L>>>0<4096>>>0){S=L&65535}else{S=-L>>31&4095}b[y+(w<<1)>>1]=S;L=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(L>>>0<4096>>>0){T=L&65535}else{T=-L>>31&4095}b[y+(x<<1)>>1]=T;L=a+1|0;if((L|0)<8){y=y+2|0;a=L;z=z+4|0}else{break}}return}function Dza(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;j=i>>1;i=f+(-(j<<1)<<1)|0;f=0;k=d;while(1){l=e[i>>1]|0;m=e[i+2>>1]|0;n=e[i-2>>1]|0;o=e[i+4>>1]|0;p=e[i+6>>1]|0;c[k>>2]=(e[i-4>>1]|0)+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;q=e[i+8>>1]|0;c[k+4>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+q;n=e[i+10>>1]|0;c[k+8>>2]=l+((p+o|0)*20|0)+((q+m|0)*-5|0)+n;l=e[i+12>>1]|0;c[k+12>>2]=m+((q+p|0)*20|0)+((n+o|0)*-5|0)+l;m=e[i+14>>1]|0;c[k+16>>2]=o+((n+q|0)*20|0)+((l+p|0)*-5|0)+m;o=e[i+16>>1]|0;c[k+20>>2]=p+((l+n|0)*20|0)+((m+q|0)*-5|0)+o;p=e[i+18>>1]|0;c[k+24>>2]=q+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;c[k+28>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+(e[i+20>>1]|0);l=f+1|0;if((l|0)<13){i=i+(j<<1)|0;f=l;k=k+(h<<2)|0}else{break}}k=g>>1;g=h*-2|0;f=-h|0;j=h<<1;i=h*3|0;l=h<<2;p=h*5|0;m=h*6|0;o=h*7|0;n=h<<3;q=h*9|0;r=h*10|0;s=k<<1;t=k*3|0;u=k<<2;v=k*5|0;w=k*6|0;x=k*7|0;y=a;a=0;z=d+(h<<1<<2)|0;while(1){d=c[z+(f<<2)>>2]|0;A=c[z>>2]|0;B=c[z+(h<<2)>>2]|0;C=c[z+(j<<2)>>2]|0;D=c[z+(i<<2)>>2]|0;E=c[z+(l<<2)>>2]|0;F=c[z+(p<<2)>>2]|0;G=c[z+(m<<2)>>2]|0;H=c[z+(o<<2)>>2]|0;I=c[z+(n<<2)>>2]|0;J=c[z+(q<<2)>>2]|0;K=c[z+(r<<2)>>2]|0;L=(c[z+(g<<2)>>2]|0)+512+((B+A|0)*20|0)+D+((C+d|0)*-5|0)>>10;if(L>>>0<4096>>>0){M=L}else{M=-L>>31&4095}b[y>>1]=((e[y>>1]|0)+1+M|0)>>>1;L=y+(k<<1)|0;N=d+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(N>>>0<4096>>>0){O=N}else{O=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+O|0)>>>1;L=y+(s<<1)|0;N=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(N>>>0<4096>>>0){P=N}else{P=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+P|0)>>>1;L=y+(t<<1)|0;N=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(N>>>0<4096>>>0){Q=N}else{Q=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+Q|0)>>>1;L=y+(u<<1)|0;N=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(N>>>0<4096>>>0){R=N}else{R=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+R|0)>>>1;L=y+(v<<1)|0;N=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(N>>>0<4096>>>0){S=N}else{S=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+S|0)>>>1;L=y+(w<<1)|0;N=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(N>>>0<4096>>>0){T=N}else{T=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+T|0)>>>1;L=y+(x<<1)|0;N=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(N>>>0<4096>>>0){U=N}else{U=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+U|0)>>>1;L=a+1|0;if((L|0)<8){y=y+2|0;a=L;z=z+4|0}else{break}}return}function Eza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<4096>>>0){L=K}else{L=-K>>31&4095}b[c>>1]=((e[c>>1]|0)+1+L|0)>>>1;K=c+(g<<1)|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0<4096>>>0){N=M}else{N=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=c+(r<<1)|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0<4096>>>0){O=M}else{O=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=c+(s<<1)|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0<4096>>>0){P=M}else{P=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=c+(t<<1)|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0<4096>>>0){Q=M}else{Q=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=c+(u<<1)|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0<4096>>>0){R=M}else{R=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=c+(v<<1)|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0<4096>>>0){S=M}else{S=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=c+(w<<1)|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0<4096>>>0){T=M}else{T=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function Fza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<4096>>>0){m=l}else{m=-l>>31&4095}b[h>>1]=((e[h>>1]|0)+1+m|0)>>>1;l=h+2|0;n=a+8|0;o=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(o>>>0<4096>>>0){p=o}else{p=-o>>31&4095}b[l>>1]=((e[l>>1]|0)+1+p|0)>>>1;l=h+4|0;o=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[n>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[o>>1]|0)>>5;if(i>>>0<4096>>>0){q=i}else{q=-i>>31&4095}b[l>>1]=((e[l>>1]|0)+1+q|0)>>>1;l=h+6|0;i=a+12|0;r=(((e[n>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[o>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(r>>>0<4096>>>0){s=r}else{s=-r>>31&4095}b[l>>1]=((e[l>>1]|0)+1+s|0)>>>1;l=h+8|0;r=a+14|0;c=(((e[o>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[r>>1]|0)>>5;if(c>>>0<4096>>>0){t=c}else{t=-c>>31&4095}b[l>>1]=((e[l>>1]|0)+1+t|0)>>>1;l=h+10|0;c=a+16|0;j=(((e[i>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[r>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<4096>>>0){u=j}else{u=-j>>31&4095}b[l>>1]=((e[l>>1]|0)+1+u|0)>>>1;l=h+12|0;j=a+18|0;k=(((e[r>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[c>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<4096>>>0){v=k}else{v=-k>>31&4095}b[l>>1]=((e[l>>1]|0)+1+v|0)>>>1;l=h+14|0;k=(((e[c>>1]|0)+(e[r>>1]|0)|0)*20|0)+16+(e[o>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<4096>>>0){w=k}else{w=-k>>31&4095}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;l=f+1|0;if((l|0)<8){f=l;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function Gza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a;h=c;i=d>>1;d=f>>1;f=c+2|0;j=c-2|0;k=c+4|0;l=c+6|0;m=(((e[f>>1]|0)+(e[h>>1]|0)|0)*20|0)+16+(e[c-4>>1]|0)+(((e[k>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[g>>1]=n;n=(((e[k>>1]|0)+(e[f>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[l>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[c+8>>1]|0)>>5;if(n>>>0<4096>>>0){o=n&65535}else{o=-n>>31&4095}b[a+2>>1]=o;o=h+(d<<1)|0;a=h+(d+1<<1)|0;n=h+(d-1<<1)|0;c=h+(d+2<<1)|0;l=h+(d+3<<1)|0;j=(((e[a>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[h+(d-2<<1)>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(j>>>0<4096>>>0){p=j&65535}else{p=-j>>31&4095}b[g+(i<<1)>>1]=p;p=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[l>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[h+(d+4<<1)>>1]|0)>>5;if(p>>>0<4096>>>0){q=p&65535;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}q=-p>>31&4095;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}function Hza(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a;g=d>>1;d=e[c-4>>1]|0;h=e[c>>1]|0;i=e[c+4>>1]|0;j=e[c+8>>1]|0;k=e[c+12>>1]|0;l=e[c+16>>1]|0;m=(e[c-8>>1]|0)+16+((i+h|0)*20|0)+k+((j+d|0)*-5|0)>>5;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[f>>1]=n;n=d+16+((j+i|0)*20|0)+l+((k+h|0)*-5|0)>>5;if(n>>>0<4096>>>0){o=n&65535}else{o=-n>>31&4095}b[f+(g<<1)>>1]=o;o=a+2|0;a=e[c-2>>1]|0;f=e[c+2>>1]|0;n=e[c+6>>1]|0;h=e[c+10>>1]|0;k=e[c+14>>1]|0;l=e[c+18>>1]|0;i=(e[c-6>>1]|0)+16+((n+f|0)*20|0)+k+((h+a|0)*-5|0)>>5;if(i>>>0<4096>>>0){p=i&65535}else{p=-i>>31&4095}b[o>>1]=p;p=a+16+((h+n|0)*20|0)+l+((k+f|0)*-5|0)>>5;if(p>>>0<4096>>>0){q=p&65535;r=o+(g<<1)|0;b[r>>1]=q;return}q=-p>>31&4095;r=o+(g<<1)|0;b[r>>1]=q;return}function Iza(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=h>>1;h=f+(-(i<<1)<<1)|0;f=0;j=d;while(1){k=e[h>>1]|0;l=e[h+2>>1]|0;m=e[h-2>>1]|0;n=e[h+4>>1]|0;o=e[h+6>>1]|0;c[j>>2]=(e[h-4>>1]|0)+((l+k|0)*20|0)+((n+m|0)*-5|0)+o;c[j+4>>2]=m+((n+l|0)*20|0)+((o+k|0)*-5|0)+(e[h+8>>1]|0);k=f+1|0;if((k|0)<7){h=h+(i<<1)|0;f=k;j=j+16|0}else{break}}j=a;f=g>>1;g=c[d+16>>2]|0;i=c[d+32>>2]|0;h=c[d+48>>2]|0;k=c[d+64>>2]|0;o=c[d+80>>2]|0;l=c[d+96>>2]|0;n=(c[d>>2]|0)+512+((h+i|0)*20|0)+o+((k+g|0)*-5|0)>>10;if(n>>>0<4096>>>0){p=n&65535}else{p=-n>>31&4095}b[j>>1]=p;p=g+512+((k+h|0)*20|0)+l+((o+i|0)*-5|0)>>10;if(p>>>0<4096>>>0){q=p&65535}else{q=-p>>31&4095}b[j+(f<<1)>>1]=q;q=a+2|0;a=c[d+20>>2]|0;j=c[d+36>>2]|0;p=c[d+52>>2]|0;i=c[d+68>>2]|0;o=c[d+84>>2]|0;l=c[d+100>>2]|0;h=(c[d+4>>2]|0)+512+((p+j|0)*20|0)+o+((i+a|0)*-5|0)>>10;if(h>>>0<4096>>>0){r=h&65535}else{r=-h>>31&4095}b[q>>1]=r;r=a+512+((i+p|0)*20|0)+l+((o+j|0)*-5|0)>>10;if(r>>>0<4096>>>0){s=r&65535;t=q+(f<<1)|0;b[t>>1]=s;return}s=-r>>31&4095;t=q+(f<<1)|0;b[t>>1]=s;return}function Jza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<1024>>>0){m=l&65535}else{m=-l>>31&1023}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<1024>>>0){o=n&65535}else{o=-n>>31&1023}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<1024>>>0){p=i&65535}else{p=-i>>31&1023}b[h+4>>1]=p;i=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(i>>>0<1024>>>0){q=i&65535}else{q=-i>>31&1023}b[h+6>>1]=q;i=f+1|0;if((i|0)<4){f=i;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function Kza(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d>>1;d=f<<1;g=f*3|0;h=c;c=a;a=0;while(1){i=e[h-8>>1]|0;j=e[h>>1]|0;k=e[h+8>>1]|0;l=e[h+16>>1]|0;m=e[h+24>>1]|0;n=e[h+32>>1]|0;o=e[h+40>>1]|0;p=e[h+48>>1]|0;q=(e[h-16>>1]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0<1024>>>0){r=q&65535}else{r=-q>>31&1023}b[c>>1]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0<1024>>>0){s=q&65535}else{s=-q>>31&1023}b[c+(f<<1)>>1]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0<1024>>>0){t=q&65535}else{t=-q>>31&1023}b[c+(d<<1)>>1]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0<1024>>>0){u=q&65535}else{u=-q>>31&1023}b[c+(g<<1)>>1]=u;q=a+1|0;if((q|0)<4){h=h+2|0;c=c+2|0;a=q}else{break}}return}function Lza(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f>>1;f=d+(-(g<<1)<<1)|0;d=0;h=c;while(1){i=f+2|0;j=f-2|0;k=f+4|0;l=f+6|0;b[h>>1]=((((((b[i>>1]|0)+(b[f>>1]|0)&65535)*20&65535)-10230&65535)+(b[f-4>>1]|0)&65535)+(((b[k>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);m=f+8|0;b[h+2>>1]=((((((b[k>>1]|0)+(b[i>>1]|0)&65535)*20&65535)-10230&65535)+(b[j>>1]|0)&65535)+(((b[l>>1]|0)+(b[f>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);j=f+10|0;b[h+4>>1]=((((((b[l>>1]|0)+(b[k>>1]|0)&65535)*20&65535)-10230&65535)+(b[f>>1]|0)&65535)+(((b[m>>1]|0)+(b[i>>1]|0)&65535)*-5&65535)&65535)+(b[j>>1]|0);b[h+6>>1]=((((((b[m>>1]|0)+(b[l>>1]|0)&65535)*20&65535)-10230&65535)+(b[i>>1]|0)&65535)+(((b[j>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[f+12>>1]|0);k=d+1|0;if((k|0)<9){f=f+(g<<1)|0;d=k;h=h+16|0}else{break}}h=e>>1;e=h<<1;d=h*3|0;g=a;a=0;f=c+32|0;while(1){c=b[f-16>>1]|0;k=b[f>>1]|0;j=k+10230|0;i=b[f+16>>1]|0;l=i+10230|0;m=(b[f+32>>1]|0)+10230|0;n=(b[f+48>>1]|0)+10230|0;o=(b[f+64>>1]|0)+10230|0;p=(b[f+80>>1]|0)+10230|0;q=b[f+96>>1]|0;r=(b[f-32>>1]|0)+10742+((l+j|0)*20|0)+n+((m+(c+10230)|0)*-5|0)>>10;if(r>>>0<1024>>>0){s=r&65535}else{s=-r>>31&1023}b[g>>1]=s;r=c+10742+((m+l|0)*20|0)+o+((n+j|0)*-5|0)>>10;if(r>>>0<1024>>>0){t=r&65535}else{t=-r>>31&1023}b[g+(h<<1)>>1]=t;r=k+10742+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>10;if(r>>>0<1024>>>0){u=r&65535}else{u=-r>>31&1023}b[g+(e<<1)>>1]=u;r=i+20972+q+((o+n|0)*20|0)+((p+m|0)*-5|0)>>10;if(r>>>0<1024>>>0){v=r&65535}else{v=-r>>31&1023}b[g+(d<<1)>>1]=v;r=a+1|0;if((r|0)<4){g=g+2|0;a=r;f=f+2|0}else{break}}return}function Mza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<1024>>>0){m=l&65535}else{m=-l>>31&1023}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<1024>>>0){o=n&65535}else{o=-n>>31&1023}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<1024>>>0){p=i&65535}else{p=-i>>31&1023}b[h+4>>1]=p;i=a+12|0;q=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(q>>>0<1024>>>0){r=q&65535}else{r=-q>>31&1023}b[h+6>>1]=r;q=a+14|0;c=(((e[n>>1]|0)+(e[l>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[q>>1]|0)>>5;if(c>>>0<1024>>>0){s=c&65535}else{s=-c>>31&1023}b[h+8>>1]=s;c=a+16|0;j=(((e[i>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[q>>1]|0)+(e[l>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<1024>>>0){t=j&65535}else{t=-j>>31&1023}b[h+10>>1]=t;j=a+18|0;k=(((e[q>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[l>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<1024>>>0){u=k&65535}else{u=-k>>31&1023}b[h+12>>1]=u;k=(((e[c>>1]|0)+(e[q>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<1024>>>0){v=k&65535}else{v=-k>>31&1023}b[h+14>>1]=v;k=f+1|0;if((k|0)<8){f=k;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function Nza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<1024>>>0){L=K&65535}else{L=-K>>31&1023}b[c>>1]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0<1024>>>0){M=K&65535}else{M=-K>>31&1023}b[c+(g<<1)>>1]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0<1024>>>0){N=K&65535}else{N=-K>>31&1023}b[c+(r<<1)>>1]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0<1024>>>0){O=K&65535}else{O=-K>>31&1023}b[c+(s<<1)>>1]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0<1024>>>0){P=K&65535}else{P=-K>>31&1023}b[c+(t<<1)>>1]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0<1024>>>0){Q=K&65535}else{Q=-K>>31&1023}b[c+(u<<1)>>1]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0<1024>>>0){R=K&65535}else{R=-K>>31&1023}b[c+(v<<1)>>1]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0<1024>>>0){S=K&65535}else{S=-K>>31&1023}b[c+(w<<1)>>1]=S;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function Oza(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;h=g>>1;g=d+(-(h<<1)<<1)|0;d=0;i=c;while(1){j=g+2|0;k=g-2|0;l=g+4|0;m=g+6|0;b[i>>1]=((((((b[j>>1]|0)+(b[g>>1]|0)&65535)*20&65535)-10230&65535)+(b[g-4>>1]|0)&65535)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);n=g+8|0;b[i+2>>1]=((((((b[l>>1]|0)+(b[j>>1]|0)&65535)*20&65535)-10230&65535)+(b[k>>1]|0)&65535)+(((b[m>>1]|0)+(b[g>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);k=g+10|0;b[i+4>>1]=((((((b[m>>1]|0)+(b[l>>1]|0)&65535)*20&65535)-10230&65535)+(b[g>>1]|0)&65535)+(((b[n>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[k>>1]|0);o=g+12|0;b[i+6>>1]=((((((b[n>>1]|0)+(b[m>>1]|0)&65535)*20&65535)-10230&65535)+(b[j>>1]|0)&65535)+(((b[k>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[o>>1]|0);j=g+14|0;b[i+8>>1]=((((((b[k>>1]|0)+(b[n>>1]|0)&65535)*20&65535)-10230&65535)+(b[l>>1]|0)&65535)+(((b[o>>1]|0)+(b[m>>1]|0)&65535)*-5&65535)&65535)+(b[j>>1]|0);l=g+16|0;b[i+10>>1]=((((((b[o>>1]|0)+(b[k>>1]|0)&65535)*20&65535)-10230&65535)+(b[m>>1]|0)&65535)+(((b[j>>1]|0)+(b[n>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);m=g+18|0;b[i+12>>1]=((((((b[j>>1]|0)+(b[o>>1]|0)&65535)*20&65535)-10230&65535)+(b[n>>1]|0)&65535)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);b[i+14>>1]=((((((b[l>>1]|0)+(b[j>>1]|0)&65535)*20&65535)-10230&65535)+(b[k>>1]|0)&65535)+(((b[m>>1]|0)+(b[o>>1]|0)&65535)*-5&65535)&65535)+(b[g+20>>1]|0);o=d+1|0;if((o|0)<13){g=g+(h<<1)|0;d=o;i=i+(f<<1)|0}else{break}}i=e>>1;e=f*-2|0;d=-f|0;h=f<<1;g=f*3|0;o=f<<2;m=f*5|0;k=f*6|0;j=f*7|0;l=f<<3;n=f*9|0;p=f*10|0;q=i<<1;r=i*3|0;s=i<<2;t=i*5|0;u=i*6|0;v=i*7|0;w=a;a=0;x=c+(f<<1<<1)|0;while(1){c=b[x+(d<<1)>>1]|0;y=b[x>>1]|0;z=y+10230|0;A=b[x+(f<<1)>>1]|0;B=A+10230|0;C=b[x+(h<<1)>>1]|0;D=C+10230|0;E=b[x+(g<<1)>>1]|0;F=E+10230|0;G=b[x+(o<<1)>>1]|0;H=G+10230|0;I=b[x+(m<<1)>>1]|0;J=I+10230|0;K=(b[x+(k<<1)>>1]|0)+10230|0;L=(b[x+(j<<1)>>1]|0)+10230|0;M=(b[x+(l<<1)>>1]|0)+10230|0;N=(b[x+(n<<1)>>1]|0)+10230|0;O=b[x+(p<<1)>>1]|0;P=(b[x+(e<<1)>>1]|0)+10742+((B+z|0)*20|0)+F+((D+(c+10230)|0)*-5|0)>>10;if(P>>>0<1024>>>0){Q=P&65535}else{Q=-P>>31&1023}b[w>>1]=Q;P=c+10742+((D+B|0)*20|0)+H+((F+z|0)*-5|0)>>10;if(P>>>0<1024>>>0){R=P&65535}else{R=-P>>31&1023}b[w+(i<<1)>>1]=R;P=y+10742+((F+D|0)*20|0)+J+((H+B|0)*-5|0)>>10;if(P>>>0<1024>>>0){S=P&65535}else{S=-P>>31&1023}b[w+(q<<1)>>1]=S;P=A+10742+((H+F|0)*20|0)+K+((J+D|0)*-5|0)>>10;if(P>>>0<1024>>>0){T=P&65535}else{T=-P>>31&1023}b[w+(r<<1)>>1]=T;P=C+10742+((J+H|0)*20|0)+L+((K+F|0)*-5|0)>>10;if(P>>>0<1024>>>0){U=P&65535}else{U=-P>>31&1023}b[w+(s<<1)>>1]=U;P=E+10742+((K+J|0)*20|0)+M+((L+H|0)*-5|0)>>10;if(P>>>0<1024>>>0){V=P&65535}else{V=-P>>31&1023}b[w+(t<<1)>>1]=V;P=G+10742+((L+K|0)*20|0)+N+((M+J|0)*-5|0)>>10;if(P>>>0<1024>>>0){W=P&65535}else{W=-P>>31&1023}b[w+(u<<1)>>1]=W;P=I+20972+O+((M+L|0)*20|0)+((N+K|0)*-5|0)>>10;if(P>>>0<1024>>>0){X=P&65535}else{X=-P>>31&1023}b[w+(v<<1)>>1]=X;P=a+1|0;if((P|0)<8){w=w+2|0;a=P;x=x+2|0}else{break}}return}function Pza(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;i=h>>1;h=d+(-(i<<1)<<1)|0;d=0;j=c;while(1){k=h+2|0;l=h-2|0;m=h+4|0;n=h+6|0;b[j>>1]=((((((b[k>>1]|0)+(b[h>>1]|0)&65535)*20&65535)-10230&65535)+(b[h-4>>1]|0)&65535)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);o=h+8|0;b[j+2>>1]=((((((b[m>>1]|0)+(b[k>>1]|0)&65535)*20&65535)-10230&65535)+(b[l>>1]|0)&65535)+(((b[n>>1]|0)+(b[h>>1]|0)&65535)*-5&65535)&65535)+(b[o>>1]|0);l=h+10|0;b[j+4>>1]=((((((b[n>>1]|0)+(b[m>>1]|0)&65535)*20&65535)-10230&65535)+(b[h>>1]|0)&65535)+(((b[o>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);p=h+12|0;b[j+6>>1]=((((((b[o>>1]|0)+(b[n>>1]|0)&65535)*20&65535)-10230&65535)+(b[k>>1]|0)&65535)+(((b[l>>1]|0)+(b[m>>1]|0)&65535)*-5&65535)&65535)+(b[p>>1]|0);k=h+14|0;b[j+8>>1]=((((((b[l>>1]|0)+(b[o>>1]|0)&65535)*20&65535)-10230&65535)+(b[m>>1]|0)&65535)+(((b[p>>1]|0)+(b[n>>1]|0)&65535)*-5&65535)&65535)+(b[k>>1]|0);m=h+16|0;b[j+10>>1]=((((((b[p>>1]|0)+(b[l>>1]|0)&65535)*20&65535)-10230&65535)+(b[n>>1]|0)&65535)+(((b[k>>1]|0)+(b[o>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);n=h+18|0;b[j+12>>1]=((((((b[k>>1]|0)+(b[p>>1]|0)&65535)*20&65535)-10230&65535)+(b[o>>1]|0)&65535)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);b[j+14>>1]=((((((b[m>>1]|0)+(b[k>>1]|0)&65535)*20&65535)-10230&65535)+(b[l>>1]|0)&65535)+(((b[n>>1]|0)+(b[p>>1]|0)&65535)*-5&65535)&65535)+(b[h+20>>1]|0);p=d+1|0;if((p|0)<13){h=h+(i<<1)|0;d=p;j=j+(g<<1)|0}else{break}}j=f>>1;f=g*-2|0;d=-g|0;i=g<<1;h=g*3|0;p=g<<2;n=g*5|0;l=g*6|0;k=g*7|0;m=g<<3;o=g*9|0;q=g*10|0;r=j<<1;s=j*3|0;t=j<<2;u=j*5|0;v=j*6|0;w=j*7|0;x=a;a=0;y=c+(g<<1<<1)|0;while(1){c=b[y+(d<<1)>>1]|0;z=b[y>>1]|0;A=z+10230|0;B=b[y+(g<<1)>>1]|0;C=B+10230|0;D=b[y+(i<<1)>>1]|0;E=D+10230|0;F=b[y+(h<<1)>>1]|0;G=F+10230|0;H=b[y+(p<<1)>>1]|0;I=H+10230|0;J=b[y+(n<<1)>>1]|0;K=J+10230|0;L=(b[y+(l<<1)>>1]|0)+10230|0;M=(b[y+(k<<1)>>1]|0)+10230|0;N=(b[y+(m<<1)>>1]|0)+10230|0;O=(b[y+(o<<1)>>1]|0)+10230|0;P=b[y+(q<<1)>>1]|0;Q=(b[y+(f<<1)>>1]|0)+10742+((C+A|0)*20|0)+G+((E+(c+10230)|0)*-5|0)>>10;if(Q>>>0<1024>>>0){R=Q}else{R=-Q>>31&1023}b[x>>1]=((e[x>>1]|0)+1+R|0)>>>1;Q=x+(j<<1)|0;S=c+10742+((E+C|0)*20|0)+I+((G+A|0)*-5|0)>>10;if(S>>>0<1024>>>0){T=S}else{T=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+T|0)>>>1;Q=x+(r<<1)|0;S=z+10742+((G+E|0)*20|0)+K+((I+C|0)*-5|0)>>10;if(S>>>0<1024>>>0){U=S}else{U=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+U|0)>>>1;Q=x+(s<<1)|0;S=B+10742+((I+G|0)*20|0)+L+((K+E|0)*-5|0)>>10;if(S>>>0<1024>>>0){V=S}else{V=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+V|0)>>>1;Q=x+(t<<1)|0;S=D+10742+((K+I|0)*20|0)+M+((L+G|0)*-5|0)>>10;if(S>>>0<1024>>>0){W=S}else{W=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+W|0)>>>1;Q=x+(u<<1)|0;S=F+10742+((L+K|0)*20|0)+N+((M+I|0)*-5|0)>>10;if(S>>>0<1024>>>0){X=S}else{X=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+X|0)>>>1;Q=x+(v<<1)|0;S=H+10742+((M+L|0)*20|0)+O+((N+K|0)*-5|0)>>10;if(S>>>0<1024>>>0){Y=S}else{Y=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+Y|0)>>>1;Q=x+(w<<1)|0;S=J+20972+P+((N+M|0)*20|0)+((O+L|0)*-5|0)>>10;if(S>>>0<1024>>>0){Z=S}else{Z=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+Z|0)>>>1;Q=a+1|0;if((Q|0)<8){x=x+2|0;a=Q;y=y+2|0}else{break}}return}function Qza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<1024>>>0){L=K}else{L=-K>>31&1023}b[c>>1]=((e[c>>1]|0)+1+L|0)>>>1;K=c+(g<<1)|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0<1024>>>0){N=M}else{N=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=c+(r<<1)|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0<1024>>>0){O=M}else{O=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=c+(s<<1)|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0<1024>>>0){P=M}else{P=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=c+(t<<1)|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0<1024>>>0){Q=M}else{Q=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=c+(u<<1)|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0<1024>>>0){R=M}else{R=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=c+(v<<1)|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0<1024>>>0){S=M}else{S=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=c+(w<<1)|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0<1024>>>0){T=M}else{T=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function Rza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<1024>>>0){m=l}else{m=-l>>31&1023}b[h>>1]=((e[h>>1]|0)+1+m|0)>>>1;l=h+2|0;n=a+8|0;o=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(o>>>0<1024>>>0){p=o}else{p=-o>>31&1023}b[l>>1]=((e[l>>1]|0)+1+p|0)>>>1;l=h+4|0;o=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[n>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[o>>1]|0)>>5;if(i>>>0<1024>>>0){q=i}else{q=-i>>31&1023}b[l>>1]=((e[l>>1]|0)+1+q|0)>>>1;l=h+6|0;i=a+12|0;r=(((e[n>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[o>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(r>>>0<1024>>>0){s=r}else{s=-r>>31&1023}b[l>>1]=((e[l>>1]|0)+1+s|0)>>>1;l=h+8|0;r=a+14|0;c=(((e[o>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[r>>1]|0)>>5;if(c>>>0<1024>>>0){t=c}else{t=-c>>31&1023}b[l>>1]=((e[l>>1]|0)+1+t|0)>>>1;l=h+10|0;c=a+16|0;j=(((e[i>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[r>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<1024>>>0){u=j}else{u=-j>>31&1023}b[l>>1]=((e[l>>1]|0)+1+u|0)>>>1;l=h+12|0;j=a+18|0;k=(((e[r>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[c>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<1024>>>0){v=k}else{v=-k>>31&1023}b[l>>1]=((e[l>>1]|0)+1+v|0)>>>1;l=h+14|0;k=(((e[c>>1]|0)+(e[r>>1]|0)|0)*20|0)+16+(e[o>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<1024>>>0){w=k}else{w=-k>>31&1023}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;l=f+1|0;if((l|0)<8){f=l;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function Sza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a;h=c;i=d>>1;d=f>>1;f=c+2|0;j=c-2|0;k=c+4|0;l=c+6|0;m=(((e[f>>1]|0)+(e[h>>1]|0)|0)*20|0)+16+(e[c-4>>1]|0)+(((e[k>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[g>>1]=n;n=(((e[k>>1]|0)+(e[f>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[l>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[c+8>>1]|0)>>5;if(n>>>0<1024>>>0){o=n&65535}else{o=-n>>31&1023}b[a+2>>1]=o;o=h+(d<<1)|0;a=h+(d+1<<1)|0;n=h+(d-1<<1)|0;c=h+(d+2<<1)|0;l=h+(d+3<<1)|0;j=(((e[a>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[h+(d-2<<1)>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(j>>>0<1024>>>0){p=j&65535}else{p=-j>>31&1023}b[g+(i<<1)>>1]=p;p=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[l>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[h+(d+4<<1)>>1]|0)>>5;if(p>>>0<1024>>>0){q=p&65535;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}q=-p>>31&1023;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}function Tza(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a;g=d>>1;d=e[c-4>>1]|0;h=e[c>>1]|0;i=e[c+4>>1]|0;j=e[c+8>>1]|0;k=e[c+12>>1]|0;l=e[c+16>>1]|0;m=(e[c-8>>1]|0)+16+((i+h|0)*20|0)+k+((j+d|0)*-5|0)>>5;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[f>>1]=n;n=d+16+((j+i|0)*20|0)+l+((k+h|0)*-5|0)>>5;if(n>>>0<1024>>>0){o=n&65535}else{o=-n>>31&1023}b[f+(g<<1)>>1]=o;o=a+2|0;a=e[c-2>>1]|0;f=e[c+2>>1]|0;n=e[c+6>>1]|0;h=e[c+10>>1]|0;k=e[c+14>>1]|0;l=e[c+18>>1]|0;i=(e[c-6>>1]|0)+16+((n+f|0)*20|0)+k+((h+a|0)*-5|0)>>5;if(i>>>0<1024>>>0){p=i&65535}else{p=-i>>31&1023}b[o>>1]=p;p=a+16+((h+n|0)*20|0)+l+((k+f|0)*-5|0)>>5;if(p>>>0<1024>>>0){q=p&65535;r=o+(g<<1)|0;b[r>>1]=q;return}q=-p>>31&1023;r=o+(g<<1)|0;b[r>>1]=q;return}function Uza(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=d+(-(g<<1)<<1)|0;d=0;h=c;while(1){i=f+2|0;j=f-2|0;k=f+4|0;l=f+6|0;b[h>>1]=((((((b[i>>1]|0)+(b[f>>1]|0)&65535)*20&65535)-10230&65535)+(b[f-4>>1]|0)&65535)+(((b[k>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);b[h+2>>1]=((((((b[k>>1]|0)+(b[i>>1]|0)&65535)*20&65535)-10230&65535)+(b[j>>1]|0)&65535)+(((b[l>>1]|0)+(b[f>>1]|0)&65535)*-5&65535)&65535)+(b[f+8>>1]|0);l=d+1|0;if((l|0)<7){f=f+(g<<1)|0;d=l;h=h+8|0}else{break}}h=a;d=e>>1;e=b[c+8>>1]|0;g=(b[c+16>>1]|0)+10230|0;f=(b[c+24>>1]|0)+10230|0;l=(b[c+32>>1]|0)+10230|0;j=(b[c+40>>1]|0)+10230|0;i=b[c+48>>1]|0;k=(b[c>>1]|0)+10742+((f+g|0)*20|0)+j+((l+(e+10230)|0)*-5|0)>>10;if(k>>>0<1024>>>0){m=k&65535}else{m=-k>>31&1023}b[h>>1]=m;m=e+20972+i+((l+f|0)*20|0)+((j+g|0)*-5|0)>>10;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[h+(d<<1)>>1]=n;n=a+2|0;a=b[c+10>>1]|0;h=(b[c+18>>1]|0)+10230|0;m=(b[c+26>>1]|0)+10230|0;g=(b[c+34>>1]|0)+10230|0;j=(b[c+42>>1]|0)+10230|0;f=b[c+50>>1]|0;l=(b[c+2>>1]|0)+10742+((m+h|0)*20|0)+j+((g+(a+10230)|0)*-5|0)>>10;if(l>>>0<1024>>>0){o=l&65535}else{o=-l>>31&1023}b[n>>1]=o;o=a+20972+f+((g+m|0)*20|0)+((j+h|0)*-5|0)>>10;if(o>>>0<1024>>>0){p=o&65535;q=n+(d<<1)|0;b[q>>1]=p;return}p=-o>>31&1023;q=n+(d<<1)|0;b[q>>1]=p;return}function Vza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<512>>>0){m=l&65535}else{m=-l>>31&511}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<512>>>0){o=n&65535}else{o=-n>>31&511}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<512>>>0){p=i&65535}else{p=-i>>31&511}b[h+4>>1]=p;i=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(i>>>0<512>>>0){q=i&65535}else{q=-i>>31&511}b[h+6>>1]=q;i=f+1|0;if((i|0)<4){f=i;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function Wza(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d>>1;d=f<<1;g=f*3|0;h=c;c=a;a=0;while(1){i=e[h-8>>1]|0;j=e[h>>1]|0;k=e[h+8>>1]|0;l=e[h+16>>1]|0;m=e[h+24>>1]|0;n=e[h+32>>1]|0;o=e[h+40>>1]|0;p=e[h+48>>1]|0;q=(e[h-16>>1]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0<512>>>0){r=q&65535}else{r=-q>>31&511}b[c>>1]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0<512>>>0){s=q&65535}else{s=-q>>31&511}b[c+(f<<1)>>1]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0<512>>>0){t=q&65535}else{t=-q>>31&511}b[c+(d<<1)>>1]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0<512>>>0){u=q&65535}else{u=-q>>31&511}b[c+(g<<1)>>1]=u;q=a+1|0;if((q|0)<4){h=h+2|0;c=c+2|0;a=q}else{break}}return}function Xza(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=f>>1;f=d+(-(g<<1)<<1)|0;d=0;h=c;while(1){i=f+2|0;j=f-2|0;k=f+4|0;l=f+6|0;b[h>>1]=(((b[f-4>>1]|0)+(((b[i>>1]|0)+(b[f>>1]|0)&65535)*20&65535)&65535)+(((b[k>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);m=f+8|0;b[h+2>>1]=(((b[j>>1]|0)+(((b[k>>1]|0)+(b[i>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[f>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);j=f+10|0;b[h+4>>1]=(((b[f>>1]|0)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[i>>1]|0)&65535)*-5&65535)&65535)+(b[j>>1]|0);b[h+6>>1]=(((b[i>>1]|0)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*20&65535)&65535)+(((b[j>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[f+12>>1]|0);k=d+1|0;if((k|0)<9){f=f+(g<<1)|0;d=k;h=h+16|0}else{break}}h=e>>1;e=h<<1;d=h*3|0;g=a;a=0;f=c+32|0;while(1){c=b[f-16>>1]|0;k=b[f>>1]|0;j=b[f+16>>1]|0;l=b[f+32>>1]|0;m=b[f+48>>1]|0;i=b[f+64>>1]|0;n=b[f+80>>1]|0;o=b[f+96>>1]|0;p=(b[f-32>>1]|0)+512+((j+k|0)*20|0)+m+((l+c|0)*-5|0)>>10;if(p>>>0<512>>>0){q=p&65535}else{q=-p>>31&511}b[g>>1]=q;p=c+512+((l+j|0)*20|0)+i+((m+k|0)*-5|0)>>10;if(p>>>0<512>>>0){r=p&65535}else{r=-p>>31&511}b[g+(h<<1)>>1]=r;p=k+512+((m+l|0)*20|0)+n+((i+j|0)*-5|0)>>10;if(p>>>0<512>>>0){s=p&65535}else{s=-p>>31&511}b[g+(e<<1)>>1]=s;p=j+512+((i+m|0)*20|0)+o+((n+l|0)*-5|0)>>10;if(p>>>0<512>>>0){t=p&65535}else{t=-p>>31&511}b[g+(d<<1)>>1]=t;p=a+1|0;if((p|0)<4){g=g+2|0;a=p;f=f+2|0}else{break}}return}function Yza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<512>>>0){m=l&65535}else{m=-l>>31&511}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<512>>>0){o=n&65535}else{o=-n>>31&511}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<512>>>0){p=i&65535}else{p=-i>>31&511}b[h+4>>1]=p;i=a+12|0;q=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(q>>>0<512>>>0){r=q&65535}else{r=-q>>31&511}b[h+6>>1]=r;q=a+14|0;c=(((e[n>>1]|0)+(e[l>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[q>>1]|0)>>5;if(c>>>0<512>>>0){s=c&65535}else{s=-c>>31&511}b[h+8>>1]=s;c=a+16|0;j=(((e[i>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[q>>1]|0)+(e[l>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<512>>>0){t=j&65535}else{t=-j>>31&511}b[h+10>>1]=t;j=a+18|0;k=(((e[q>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[l>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<512>>>0){u=k&65535}else{u=-k>>31&511}b[h+12>>1]=u;k=(((e[c>>1]|0)+(e[q>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<512>>>0){v=k&65535}else{v=-k>>31&511}b[h+14>>1]=v;k=f+1|0;if((k|0)<8){f=k;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function Zza(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<512>>>0){L=K&65535}else{L=-K>>31&511}b[c>>1]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0<512>>>0){M=K&65535}else{M=-K>>31&511}b[c+(g<<1)>>1]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0<512>>>0){N=K&65535}else{N=-K>>31&511}b[c+(r<<1)>>1]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0<512>>>0){O=K&65535}else{O=-K>>31&511}b[c+(s<<1)>>1]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0<512>>>0){P=K&65535}else{P=-K>>31&511}b[c+(t<<1)>>1]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0<512>>>0){Q=K&65535}else{Q=-K>>31&511}b[c+(u<<1)>>1]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0<512>>>0){R=K&65535}else{R=-K>>31&511}b[c+(v<<1)>>1]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0<512>>>0){S=K&65535}else{S=-K>>31&511}b[c+(w<<1)>>1]=S;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function _za(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;h=g>>1;g=d+(-(h<<1)<<1)|0;d=0;i=c;while(1){j=g+2|0;k=g-2|0;l=g+4|0;m=g+6|0;b[i>>1]=(((b[g-4>>1]|0)+(((b[j>>1]|0)+(b[g>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);n=g+8|0;b[i+2>>1]=(((b[k>>1]|0)+(((b[l>>1]|0)+(b[j>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[g>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);k=g+10|0;b[i+4>>1]=(((b[g>>1]|0)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*20&65535)&65535)+(((b[n>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[k>>1]|0);o=g+12|0;b[i+6>>1]=(((b[j>>1]|0)+(((b[n>>1]|0)+(b[m>>1]|0)&65535)*20&65535)&65535)+(((b[k>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[o>>1]|0);j=g+14|0;b[i+8>>1]=(((b[l>>1]|0)+(((b[k>>1]|0)+(b[n>>1]|0)&65535)*20&65535)&65535)+(((b[o>>1]|0)+(b[m>>1]|0)&65535)*-5&65535)&65535)+(b[j>>1]|0);l=g+16|0;b[i+10>>1]=(((b[m>>1]|0)+(((b[o>>1]|0)+(b[k>>1]|0)&65535)*20&65535)&65535)+(((b[j>>1]|0)+(b[n>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);m=g+18|0;b[i+12>>1]=(((b[n>>1]|0)+(((b[j>>1]|0)+(b[o>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);b[i+14>>1]=(((b[k>>1]|0)+(((b[l>>1]|0)+(b[j>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[o>>1]|0)&65535)*-5&65535)&65535)+(b[g+20>>1]|0);o=d+1|0;if((o|0)<13){g=g+(h<<1)|0;d=o;i=i+(f<<1)|0}else{break}}i=e>>1;e=f*-2|0;d=-f|0;h=f<<1;g=f*3|0;o=f<<2;m=f*5|0;j=f*6|0;l=f*7|0;k=f<<3;n=f*9|0;p=f*10|0;q=i<<1;r=i*3|0;s=i<<2;t=i*5|0;u=i*6|0;v=i*7|0;w=a;a=0;x=c+(f<<1<<1)|0;while(1){c=b[x+(d<<1)>>1]|0;y=b[x>>1]|0;z=b[x+(f<<1)>>1]|0;A=b[x+(h<<1)>>1]|0;B=b[x+(g<<1)>>1]|0;C=b[x+(o<<1)>>1]|0;D=b[x+(m<<1)>>1]|0;E=b[x+(j<<1)>>1]|0;F=b[x+(l<<1)>>1]|0;G=b[x+(k<<1)>>1]|0;H=b[x+(n<<1)>>1]|0;I=b[x+(p<<1)>>1]|0;J=(b[x+(e<<1)>>1]|0)+512+((z+y|0)*20|0)+B+((A+c|0)*-5|0)>>10;if(J>>>0<512>>>0){K=J&65535}else{K=-J>>31&511}b[w>>1]=K;J=c+512+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>10;if(J>>>0<512>>>0){L=J&65535}else{L=-J>>31&511}b[w+(i<<1)>>1]=L;J=y+512+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>10;if(J>>>0<512>>>0){M=J&65535}else{M=-J>>31&511}b[w+(q<<1)>>1]=M;J=z+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(J>>>0<512>>>0){N=J&65535}else{N=-J>>31&511}b[w+(r<<1)>>1]=N;J=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(J>>>0<512>>>0){O=J&65535}else{O=-J>>31&511}b[w+(s<<1)>>1]=O;J=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(J>>>0<512>>>0){P=J&65535}else{P=-J>>31&511}b[w+(t<<1)>>1]=P;J=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(J>>>0<512>>>0){Q=J&65535}else{Q=-J>>31&511}b[w+(u<<1)>>1]=Q;J=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(J>>>0<512>>>0){R=J&65535}else{R=-J>>31&511}b[w+(v<<1)>>1]=R;J=a+1|0;if((J|0)<8){w=w+2|0;a=J;x=x+2|0}else{break}}return}function $za(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;i=h>>1;h=d+(-(i<<1)<<1)|0;d=0;j=c;while(1){k=h+2|0;l=h-2|0;m=h+4|0;n=h+6|0;b[j>>1]=(((b[h-4>>1]|0)+(((b[k>>1]|0)+(b[h>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);o=h+8|0;b[j+2>>1]=(((b[l>>1]|0)+(((b[m>>1]|0)+(b[k>>1]|0)&65535)*20&65535)&65535)+(((b[n>>1]|0)+(b[h>>1]|0)&65535)*-5&65535)&65535)+(b[o>>1]|0);l=h+10|0;b[j+4>>1]=(((b[h>>1]|0)+(((b[n>>1]|0)+(b[m>>1]|0)&65535)*20&65535)&65535)+(((b[o>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);p=h+12|0;b[j+6>>1]=(((b[k>>1]|0)+(((b[o>>1]|0)+(b[n>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[m>>1]|0)&65535)*-5&65535)&65535)+(b[p>>1]|0);k=h+14|0;b[j+8>>1]=(((b[m>>1]|0)+(((b[l>>1]|0)+(b[o>>1]|0)&65535)*20&65535)&65535)+(((b[p>>1]|0)+(b[n>>1]|0)&65535)*-5&65535)&65535)+(b[k>>1]|0);m=h+16|0;b[j+10>>1]=(((b[n>>1]|0)+(((b[p>>1]|0)+(b[l>>1]|0)&65535)*20&65535)&65535)+(((b[k>>1]|0)+(b[o>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);n=h+18|0;b[j+12>>1]=(((b[o>>1]|0)+(((b[k>>1]|0)+(b[p>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);b[j+14>>1]=(((b[l>>1]|0)+(((b[m>>1]|0)+(b[k>>1]|0)&65535)*20&65535)&65535)+(((b[n>>1]|0)+(b[p>>1]|0)&65535)*-5&65535)&65535)+(b[h+20>>1]|0);p=d+1|0;if((p|0)<13){h=h+(i<<1)|0;d=p;j=j+(g<<1)|0}else{break}}j=f>>1;f=g*-2|0;d=-g|0;i=g<<1;h=g*3|0;p=g<<2;n=g*5|0;k=g*6|0;m=g*7|0;l=g<<3;o=g*9|0;q=g*10|0;r=j<<1;s=j*3|0;t=j<<2;u=j*5|0;v=j*6|0;w=j*7|0;x=a;a=0;y=c+(g<<1<<1)|0;while(1){c=b[y+(d<<1)>>1]|0;z=b[y>>1]|0;A=b[y+(g<<1)>>1]|0;B=b[y+(i<<1)>>1]|0;C=b[y+(h<<1)>>1]|0;D=b[y+(p<<1)>>1]|0;E=b[y+(n<<1)>>1]|0;F=b[y+(k<<1)>>1]|0;G=b[y+(m<<1)>>1]|0;H=b[y+(l<<1)>>1]|0;I=b[y+(o<<1)>>1]|0;J=b[y+(q<<1)>>1]|0;K=(b[y+(f<<1)>>1]|0)+512+((A+z|0)*20|0)+C+((B+c|0)*-5|0)>>10;if(K>>>0<512>>>0){L=K}else{L=-K>>31&511}b[x>>1]=((e[x>>1]|0)+1+L|0)>>>1;K=x+(j<<1)|0;M=c+512+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>10;if(M>>>0<512>>>0){N=M}else{N=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=x+(r<<1)|0;M=z+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(M>>>0<512>>>0){O=M}else{O=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=x+(s<<1)|0;M=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(M>>>0<512>>>0){P=M}else{P=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=x+(t<<1)|0;M=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(M>>>0<512>>>0){Q=M}else{Q=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=x+(u<<1)|0;M=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(M>>>0<512>>>0){R=M}else{R=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=x+(v<<1)|0;M=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(M>>>0<512>>>0){S=M}else{S=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=x+(w<<1)|0;M=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(M>>>0<512>>>0){T=M}else{T=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;a=K;y=y+2|0}else{break}}return}function aAa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<512>>>0){L=K}else{L=-K>>31&511}b[c>>1]=((e[c>>1]|0)+1+L|0)>>>1;K=c+(g<<1)|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0<512>>>0){N=M}else{N=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=c+(r<<1)|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0<512>>>0){O=M}else{O=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=c+(s<<1)|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0<512>>>0){P=M}else{P=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=c+(t<<1)|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0<512>>>0){Q=M}else{Q=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=c+(u<<1)|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0<512>>>0){R=M}else{R=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=c+(v<<1)|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0<512>>>0){S=M}else{S=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=c+(w<<1)|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0<512>>>0){T=M}else{T=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function bAa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<512>>>0){m=l}else{m=-l>>31&511}b[h>>1]=((e[h>>1]|0)+1+m|0)>>>1;l=h+2|0;n=a+8|0;o=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(o>>>0<512>>>0){p=o}else{p=-o>>31&511}b[l>>1]=((e[l>>1]|0)+1+p|0)>>>1;l=h+4|0;o=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[n>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[o>>1]|0)>>5;if(i>>>0<512>>>0){q=i}else{q=-i>>31&511}b[l>>1]=((e[l>>1]|0)+1+q|0)>>>1;l=h+6|0;i=a+12|0;r=(((e[n>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[o>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(r>>>0<512>>>0){s=r}else{s=-r>>31&511}b[l>>1]=((e[l>>1]|0)+1+s|0)>>>1;l=h+8|0;r=a+14|0;c=(((e[o>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[r>>1]|0)>>5;if(c>>>0<512>>>0){t=c}else{t=-c>>31&511}b[l>>1]=((e[l>>1]|0)+1+t|0)>>>1;l=h+10|0;c=a+16|0;j=(((e[i>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[r>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<512>>>0){u=j}else{u=-j>>31&511}b[l>>1]=((e[l>>1]|0)+1+u|0)>>>1;l=h+12|0;j=a+18|0;k=(((e[r>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[c>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<512>>>0){v=k}else{v=-k>>31&511}b[l>>1]=((e[l>>1]|0)+1+v|0)>>>1;l=h+14|0;k=(((e[c>>1]|0)+(e[r>>1]|0)|0)*20|0)+16+(e[o>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<512>>>0){w=k}else{w=-k>>31&511}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;l=f+1|0;if((l|0)<8){f=l;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function cAa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a;h=c;i=d>>1;d=f>>1;f=c+2|0;j=c-2|0;k=c+4|0;l=c+6|0;m=(((e[f>>1]|0)+(e[h>>1]|0)|0)*20|0)+16+(e[c-4>>1]|0)+(((e[k>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[g>>1]=n;n=(((e[k>>1]|0)+(e[f>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[l>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[c+8>>1]|0)>>5;if(n>>>0<512>>>0){o=n&65535}else{o=-n>>31&511}b[a+2>>1]=o;o=h+(d<<1)|0;a=h+(d+1<<1)|0;n=h+(d-1<<1)|0;c=h+(d+2<<1)|0;l=h+(d+3<<1)|0;j=(((e[a>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[h+(d-2<<1)>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(j>>>0<512>>>0){p=j&65535}else{p=-j>>31&511}b[g+(i<<1)>>1]=p;p=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[l>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[h+(d+4<<1)>>1]|0)>>5;if(p>>>0<512>>>0){q=p&65535;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}q=-p>>31&511;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}function dAa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a;g=d>>1;d=e[c-4>>1]|0;h=e[c>>1]|0;i=e[c+4>>1]|0;j=e[c+8>>1]|0;k=e[c+12>>1]|0;l=e[c+16>>1]|0;m=(e[c-8>>1]|0)+16+((i+h|0)*20|0)+k+((j+d|0)*-5|0)>>5;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[f>>1]=n;n=d+16+((j+i|0)*20|0)+l+((k+h|0)*-5|0)>>5;if(n>>>0<512>>>0){o=n&65535}else{o=-n>>31&511}b[f+(g<<1)>>1]=o;o=a+2|0;a=e[c-2>>1]|0;f=e[c+2>>1]|0;n=e[c+6>>1]|0;h=e[c+10>>1]|0;k=e[c+14>>1]|0;l=e[c+18>>1]|0;i=(e[c-6>>1]|0)+16+((n+f|0)*20|0)+k+((h+a|0)*-5|0)>>5;if(i>>>0<512>>>0){p=i&65535}else{p=-i>>31&511}b[o>>1]=p;p=a+16+((h+n|0)*20|0)+l+((k+f|0)*-5|0)>>5;if(p>>>0<512>>>0){q=p&65535;r=o+(g<<1)|0;b[r>>1]=q;return}q=-p>>31&511;r=o+(g<<1)|0;b[r>>1]=q;return}function eAa(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=d+(-(g<<1)<<1)|0;d=0;h=c;while(1){i=f+2|0;j=f-2|0;k=f+4|0;l=f+6|0;b[h>>1]=(((b[f-4>>1]|0)+(((b[i>>1]|0)+(b[f>>1]|0)&65535)*20&65535)&65535)+(((b[k>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);b[h+2>>1]=(((b[j>>1]|0)+(((b[k>>1]|0)+(b[i>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[f>>1]|0)&65535)*-5&65535)&65535)+(b[f+8>>1]|0);l=d+1|0;if((l|0)<7){f=f+(g<<1)|0;d=l;h=h+8|0}else{break}}h=a;d=e>>1;e=b[c+8>>1]|0;g=b[c+16>>1]|0;f=b[c+24>>1]|0;l=b[c+32>>1]|0;i=b[c+40>>1]|0;k=b[c+48>>1]|0;j=(b[c>>1]|0)+512+((f+g|0)*20|0)+i+((l+e|0)*-5|0)>>10;if(j>>>0<512>>>0){m=j&65535}else{m=-j>>31&511}b[h>>1]=m;m=e+512+((l+f|0)*20|0)+k+((i+g|0)*-5|0)>>10;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[h+(d<<1)>>1]=n;n=a+2|0;a=b[c+10>>1]|0;h=b[c+18>>1]|0;m=b[c+26>>1]|0;g=b[c+34>>1]|0;i=b[c+42>>1]|0;k=b[c+50>>1]|0;f=(b[c+2>>1]|0)+512+((m+h|0)*20|0)+i+((g+a|0)*-5|0)>>10;if(f>>>0<512>>>0){o=f&65535}else{o=-f>>31&511}b[n>>1]=o;o=a+512+((g+m|0)*20|0)+k+((i+h|0)*-5|0)>>10;if(o>>>0<512>>>0){p=o&65535;q=n+(d<<1)|0;b[q>>1]=p;return}p=-o>>31&511;q=n+(d<<1)|0;b[q>>1]=p;return}function fAa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=0;h=b;b=c;while(1){c=b+1|0;i=b-1|0;j=b+2|0;k=b+3|0;l=(((d[c]|0)+(d[b]|0)|0)*20|0)+16+(d[b-2|0]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[k]|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[h]=m;l=b+4|0;n=(((d[j]|0)+(d[c]|0)|0)*20|0)+16+(d[i]|0)+(((d[k]|0)+(d[b]|0)|0)*-5|0)+(d[l]|0)>>5;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[h+1|0]=o;n=b+5|0;i=(((d[k]|0)+(d[j]|0)|0)*20|0)+16+(d[b]|0)+(((d[l]|0)+(d[c]|0)|0)*-5|0)+(d[n]|0)>>5;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[h+2|0]=p;i=(((d[l]|0)+(d[k]|0)|0)*20|0)+16+(d[c]|0)+(((d[n]|0)+(d[j]|0)|0)*-5|0)+(d[b+6|0]|0)>>5;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[h+3|0]=q;i=g+1|0;if((i|0)<4){g=i;h=h+e|0;b=b+f|0}else{break}}return}function gAa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=e<<1;g=e*3|0;h=c;c=b;b=0;while(1){i=d[h-4|0]|0;j=d[h]|0;k=d[h+4|0]|0;l=d[h+8|0]|0;m=d[h+12|0]|0;n=d[h+16|0]|0;o=d[h+20|0]|0;p=d[h+24|0]|0;q=(d[h-8|0]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[c]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0>255>>>0){s=-q>>31&255}else{s=q&255}a[c+e|0]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0>255>>>0){t=-q>>31&255}else{t=q&255}a[c+f|0]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[c+g|0]=u;q=b+1|0;if((q|0)<4){h=h+1|0;c=c+1|0;b=q}else{break}}return}function hAa(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=f+(-(h<<1)|0)|0;f=0;j=e;while(1){k=i+1|0;l=i-1|0;m=i+2|0;n=i+3|0;b[j>>1]=(((d[i-2|0]|0)+(((d[k]|0)+(d[i]|0)&65535)*20&65535)&65535)+(((d[m]|0)+(d[l]|0)&65535)*-5&65535)&65535)+(d[n]|0);o=i+4|0;b[j+2>>1]=(((d[l]|0)+(((d[m]|0)+(d[k]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[i]|0)&65535)*-5&65535)&65535)+(d[o]|0);l=i+5|0;b[j+4>>1]=(((d[i]|0)+(((d[n]|0)+(d[m]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[k]|0)&65535)*-5&65535)&65535)+(d[l]|0);b[j+6>>1]=(((d[k]|0)+(((d[o]|0)+(d[n]|0)&65535)*20&65535)&65535)+(((d[l]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[i+6|0]|0);m=f+1|0;if((m|0)<9){i=i+h|0;f=m;j=j+8|0}else{break}}j=g<<1;f=g*3|0;h=c;c=0;i=e+16|0;while(1){e=b[i-8>>1]|0;m=b[i>>1]|0;l=b[i+8>>1]|0;n=b[i+16>>1]|0;o=b[i+24>>1]|0;k=b[i+32>>1]|0;p=b[i+40>>1]|0;q=b[i+48>>1]|0;r=(b[i-16>>1]|0)+512+((l+m|0)*20|0)+o+((n+e|0)*-5|0)>>10;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[h]=s;r=e+512+((n+l|0)*20|0)+k+((o+m|0)*-5|0)>>10;if(r>>>0>255>>>0){t=-r>>31&255}else{t=r&255}a[h+g|0]=t;r=m+512+((o+n|0)*20|0)+p+((k+l|0)*-5|0)>>10;if(r>>>0>255>>>0){u=-r>>31&255}else{u=r&255}a[h+j|0]=u;r=l+512+((k+o|0)*20|0)+q+((p+n|0)*-5|0)>>10;if(r>>>0>255>>>0){v=-r>>31&255}else{v=r&255}a[h+f|0]=v;r=c+1|0;if((r|0)<4){h=h+1|0;c=r;i=i+2|0}else{break}}return}function iAa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=0;h=b;b=c;while(1){c=b+1|0;i=b-1|0;j=b+2|0;k=b+3|0;l=(((d[c]|0)+(d[b]|0)|0)*20|0)+16+(d[b-2|0]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[k]|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[h]=m;l=b+4|0;n=(((d[j]|0)+(d[c]|0)|0)*20|0)+16+(d[i]|0)+(((d[k]|0)+(d[b]|0)|0)*-5|0)+(d[l]|0)>>5;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[h+1|0]=o;n=b+5|0;i=(((d[k]|0)+(d[j]|0)|0)*20|0)+16+(d[b]|0)+(((d[l]|0)+(d[c]|0)|0)*-5|0)+(d[n]|0)>>5;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[h+2|0]=p;i=b+6|0;q=(((d[l]|0)+(d[k]|0)|0)*20|0)+16+(d[c]|0)+(((d[n]|0)+(d[j]|0)|0)*-5|0)+(d[i]|0)>>5;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[h+3|0]=r;q=b+7|0;c=(((d[n]|0)+(d[l]|0)|0)*20|0)+16+(d[j]|0)+(((d[i]|0)+(d[k]|0)|0)*-5|0)+(d[q]|0)>>5;if(c>>>0>255>>>0){s=-c>>31&255}else{s=c&255}a[h+4|0]=s;c=b+8|0;j=(((d[i]|0)+(d[n]|0)|0)*20|0)+16+(d[k]|0)+(((d[q]|0)+(d[l]|0)|0)*-5|0)+(d[c]|0)>>5;if(j>>>0>255>>>0){t=-j>>31&255}else{t=j&255}a[h+5|0]=t;j=b+9|0;k=(((d[q]|0)+(d[i]|0)|0)*20|0)+16+(d[l]|0)+(((d[c]|0)+(d[n]|0)|0)*-5|0)+(d[j]|0)>>5;if(k>>>0>255>>>0){u=-k>>31&255}else{u=k&255}a[h+6|0]=u;k=(((d[c]|0)+(d[q]|0)|0)*20|0)+16+(d[n]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[b+10|0]|0)>>5;if(k>>>0>255>>>0){v=-k>>31&255}else{v=k&255}a[h+7|0]=v;k=g+1|0;if((k|0)<8){g=k;h=h+e|0;b=b+f|0}else{break}}return}function jAa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=f*-2|0;h=-f|0;i=f<<1;j=f*3|0;k=f<<2;l=f*5|0;m=f*6|0;n=f*7|0;o=f<<3;p=f*9|0;q=f*10|0;r=e<<1;s=e*3|0;t=e<<2;u=e*5|0;v=e*6|0;w=e*7|0;x=c;c=b;b=0;while(1){y=d[x+h|0]|0;z=d[x]|0;A=d[x+f|0]|0;B=d[x+i|0]|0;C=d[x+j|0]|0;D=d[x+k|0]|0;E=d[x+l|0]|0;F=d[x+m|0]|0;G=d[x+n|0]|0;H=d[x+o|0]|0;I=d[x+p|0]|0;J=d[x+q|0]|0;K=(d[x+g|0]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0>255>>>0){L=-K>>31&255}else{L=K&255}a[c]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0>255>>>0){M=-K>>31&255}else{M=K&255}a[c+e|0]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0>255>>>0){N=-K>>31&255}else{N=K&255}a[c+r|0]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0>255>>>0){O=-K>>31&255}else{O=K&255}a[c+s|0]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0>255>>>0){P=-K>>31&255}else{P=K&255}a[c+t|0]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0>255>>>0){Q=-K>>31&255}else{Q=K&255}a[c+u|0]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0>255>>>0){R=-K>>31&255}else{R=K&255}a[c+v|0]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0>255>>>0){S=-K>>31&255}else{S=K&255}a[c+w|0]=S;K=b+1|0;if((K|0)<8){x=x+1|0;c=c+1|0;b=K}else{break}}return}function kAa(c,e,f,g,h,i){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=f+(-(i<<1)|0)|0;f=0;k=e;while(1){l=j+1|0;m=j-1|0;n=j+2|0;o=j+3|0;b[k>>1]=(((d[j-2|0]|0)+(((d[l]|0)+(d[j]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[o]|0);p=j+4|0;b[k+2>>1]=(((d[m]|0)+(((d[n]|0)+(d[l]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[j]|0)&65535)*-5&65535)&65535)+(d[p]|0);m=j+5|0;b[k+4>>1]=(((d[j]|0)+(((d[o]|0)+(d[n]|0)&65535)*20&65535)&65535)+(((d[p]|0)+(d[l]|0)&65535)*-5&65535)&65535)+(d[m]|0);q=j+6|0;b[k+6>>1]=(((d[l]|0)+(((d[p]|0)+(d[o]|0)&65535)*20&65535)&65535)+(((d[m]|0)+(d[n]|0)&65535)*-5&65535)&65535)+(d[q]|0);l=j+7|0;b[k+8>>1]=(((d[n]|0)+(((d[m]|0)+(d[p]|0)&65535)*20&65535)&65535)+(((d[q]|0)+(d[o]|0)&65535)*-5&65535)&65535)+(d[l]|0);n=j+8|0;b[k+10>>1]=(((d[o]|0)+(((d[q]|0)+(d[m]|0)&65535)*20&65535)&65535)+(((d[l]|0)+(d[p]|0)&65535)*-5&65535)&65535)+(d[n]|0);o=j+9|0;b[k+12>>1]=(((d[p]|0)+(((d[l]|0)+(d[q]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[o]|0);b[k+14>>1]=(((d[m]|0)+(((d[n]|0)+(d[l]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[q]|0)&65535)*-5&65535)&65535)+(d[j+10|0]|0);q=f+1|0;if((q|0)<13){j=j+i|0;f=q;k=k+(h<<1)|0}else{break}}k=h*-2|0;f=-h|0;i=h<<1;j=h*3|0;q=h<<2;o=h*5|0;l=h*6|0;n=h*7|0;m=h<<3;p=h*9|0;r=h*10|0;s=g<<1;t=g*3|0;u=g<<2;v=g*5|0;w=g*6|0;x=g*7|0;y=c;c=0;z=e+(h<<1<<1)|0;while(1){e=b[z+(f<<1)>>1]|0;A=b[z>>1]|0;B=b[z+(h<<1)>>1]|0;C=b[z+(i<<1)>>1]|0;D=b[z+(j<<1)>>1]|0;E=b[z+(q<<1)>>1]|0;F=b[z+(o<<1)>>1]|0;G=b[z+(l<<1)>>1]|0;H=b[z+(n<<1)>>1]|0;I=b[z+(m<<1)>>1]|0;J=b[z+(p<<1)>>1]|0;K=b[z+(r<<1)>>1]|0;L=(b[z+(k<<1)>>1]|0)+512+((B+A|0)*20|0)+D+((C+e|0)*-5|0)>>10;if(L>>>0>255>>>0){M=-L>>31&255}else{M=L&255}a[y]=M;L=e+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(L>>>0>255>>>0){N=-L>>31&255}else{N=L&255}a[y+g|0]=N;L=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(L>>>0>255>>>0){O=-L>>31&255}else{O=L&255}a[y+s|0]=O;L=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(L>>>0>255>>>0){P=-L>>31&255}else{P=L&255}a[y+t|0]=P;L=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(L>>>0>255>>>0){Q=-L>>31&255}else{Q=L&255}a[y+u|0]=Q;L=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(L>>>0>255>>>0){R=-L>>31&255}else{R=L&255}a[y+v|0]=R;L=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(L>>>0>255>>>0){S=-L>>31&255}else{S=L&255}a[y+w|0]=S;L=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(L>>>0>255>>>0){T=-L>>31&255}else{T=L&255}a[y+x|0]=T;L=c+1|0;if((L|0)<8){y=y+1|0;c=L;z=z+2|0}else{break}}return}function lAa(c,e,f,g,h,i){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;j=f+(-(i<<1)|0)|0;f=0;k=e;while(1){l=j+1|0;m=j-1|0;n=j+2|0;o=j+3|0;b[k>>1]=(((d[j-2|0]|0)+(((d[l]|0)+(d[j]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[o]|0);p=j+4|0;b[k+2>>1]=(((d[m]|0)+(((d[n]|0)+(d[l]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[j]|0)&65535)*-5&65535)&65535)+(d[p]|0);m=j+5|0;b[k+4>>1]=(((d[j]|0)+(((d[o]|0)+(d[n]|0)&65535)*20&65535)&65535)+(((d[p]|0)+(d[l]|0)&65535)*-5&65535)&65535)+(d[m]|0);q=j+6|0;b[k+6>>1]=(((d[l]|0)+(((d[p]|0)+(d[o]|0)&65535)*20&65535)&65535)+(((d[m]|0)+(d[n]|0)&65535)*-5&65535)&65535)+(d[q]|0);l=j+7|0;b[k+8>>1]=(((d[n]|0)+(((d[m]|0)+(d[p]|0)&65535)*20&65535)&65535)+(((d[q]|0)+(d[o]|0)&65535)*-5&65535)&65535)+(d[l]|0);n=j+8|0;b[k+10>>1]=(((d[o]|0)+(((d[q]|0)+(d[m]|0)&65535)*20&65535)&65535)+(((d[l]|0)+(d[p]|0)&65535)*-5&65535)&65535)+(d[n]|0);o=j+9|0;b[k+12>>1]=(((d[p]|0)+(((d[l]|0)+(d[q]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[o]|0);b[k+14>>1]=(((d[m]|0)+(((d[n]|0)+(d[l]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[q]|0)&65535)*-5&65535)&65535)+(d[j+10|0]|0);q=f+1|0;if((q|0)<13){j=j+i|0;f=q;k=k+(h<<1)|0}else{break}}k=h*-2|0;f=-h|0;i=h<<1;j=h*3|0;q=h<<2;o=h*5|0;l=h*6|0;n=h*7|0;m=h<<3;p=h*9|0;r=h*10|0;s=g<<1;t=g*3|0;u=g<<2;v=g*5|0;w=g*6|0;x=g*7|0;y=c;c=0;z=e+(h<<1<<1)|0;while(1){e=b[z+(f<<1)>>1]|0;A=b[z>>1]|0;B=b[z+(h<<1)>>1]|0;C=b[z+(i<<1)>>1]|0;D=b[z+(j<<1)>>1]|0;E=b[z+(q<<1)>>1]|0;F=b[z+(o<<1)>>1]|0;G=b[z+(l<<1)>>1]|0;H=b[z+(n<<1)>>1]|0;I=b[z+(m<<1)>>1]|0;J=b[z+(p<<1)>>1]|0;K=b[z+(r<<1)>>1]|0;L=(b[z+(k<<1)>>1]|0)+512+((B+A|0)*20|0)+D+((C+e|0)*-5|0)>>10;if(L>>>0>255>>>0){M=-L>>31&255}else{M=L&255}a[y]=((d[y]|0)+1+(M&255)|0)>>>1;L=y+g|0;N=e+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}a[L]=((d[L]|0)+1+(O&255)|0)>>>1;L=y+s|0;N=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(N>>>0>255>>>0){P=-N>>31&255}else{P=N&255}a[L]=((d[L]|0)+1+(P&255)|0)>>>1;L=y+t|0;N=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(N>>>0>255>>>0){Q=-N>>31&255}else{Q=N&255}a[L]=((d[L]|0)+1+(Q&255)|0)>>>1;L=y+u|0;N=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(N>>>0>255>>>0){R=-N>>31&255}else{R=N&255}a[L]=((d[L]|0)+1+(R&255)|0)>>>1;L=y+v|0;N=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(N>>>0>255>>>0){S=-N>>31&255}else{S=N&255}a[L]=((d[L]|0)+1+(S&255)|0)>>>1;L=y+w|0;N=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(N>>>0>255>>>0){T=-N>>31&255}else{T=N&255}a[L]=((d[L]|0)+1+(T&255)|0)>>>1;L=y+x|0;N=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(N>>>0>255>>>0){U=-N>>31&255}else{U=N&255}a[L]=((d[L]|0)+1+(U&255)|0)>>>1;L=c+1|0;if((L|0)<8){y=y+1|0;c=L;z=z+2|0}else{break}}return}function mAa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=f*-2|0;h=-f|0;i=f<<1;j=f*3|0;k=f<<2;l=f*5|0;m=f*6|0;n=f*7|0;o=f<<3;p=f*9|0;q=f*10|0;r=e<<1;s=e*3|0;t=e<<2;u=e*5|0;v=e*6|0;w=e*7|0;x=c;c=b;b=0;while(1){y=d[x+h|0]|0;z=d[x]|0;A=d[x+f|0]|0;B=d[x+i|0]|0;C=d[x+j|0]|0;D=d[x+k|0]|0;E=d[x+l|0]|0;F=d[x+m|0]|0;G=d[x+n|0]|0;H=d[x+o|0]|0;I=d[x+p|0]|0;J=d[x+q|0]|0;K=(d[x+g|0]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0>255>>>0){L=-K>>31&255}else{L=K&255}a[c]=((d[c]|0)+1+(L&255)|0)>>>1;K=c+e|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0>255>>>0){N=-M>>31&255}else{N=M&255}a[K]=((d[K]|0)+1+(N&255)|0)>>>1;K=c+r|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0>255>>>0){O=-M>>31&255}else{O=M&255}a[K]=((d[K]|0)+1+(O&255)|0)>>>1;K=c+s|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0>255>>>0){P=-M>>31&255}else{P=M&255}a[K]=((d[K]|0)+1+(P&255)|0)>>>1;K=c+t|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0>255>>>0){Q=-M>>31&255}else{Q=M&255}a[K]=((d[K]|0)+1+(Q&255)|0)>>>1;K=c+u|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0>255>>>0){R=-M>>31&255}else{R=M&255}a[K]=((d[K]|0)+1+(R&255)|0)>>>1;K=c+v|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0>255>>>0){S=-M>>31&255}else{S=M&255}a[K]=((d[K]|0)+1+(S&255)|0)>>>1;K=c+w|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0>255>>>0){T=-M>>31&255}else{T=M&255}a[K]=((d[K]|0)+1+(T&255)|0)>>>1;K=b+1|0;if((K|0)<8){x=x+1|0;c=c+1|0;b=K}else{break}}return}function nAa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=0;h=b;b=c;while(1){c=b+1|0;i=b-1|0;j=b+2|0;k=b+3|0;l=(((d[c]|0)+(d[b]|0)|0)*20|0)+16+(d[b-2|0]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[k]|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[h]=((d[h]|0)+1+(m&255)|0)>>>1;l=h+1|0;n=b+4|0;o=(((d[j]|0)+(d[c]|0)|0)*20|0)+16+(d[i]|0)+(((d[k]|0)+(d[b]|0)|0)*-5|0)+(d[n]|0)>>5;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[l]=((d[l]|0)+1+(p&255)|0)>>>1;l=h+2|0;o=b+5|0;i=(((d[k]|0)+(d[j]|0)|0)*20|0)+16+(d[b]|0)+(((d[n]|0)+(d[c]|0)|0)*-5|0)+(d[o]|0)>>5;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[l]=((d[l]|0)+1+(q&255)|0)>>>1;l=h+3|0;i=b+6|0;r=(((d[n]|0)+(d[k]|0)|0)*20|0)+16+(d[c]|0)+(((d[o]|0)+(d[j]|0)|0)*-5|0)+(d[i]|0)>>5;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;l=h+4|0;r=b+7|0;c=(((d[o]|0)+(d[n]|0)|0)*20|0)+16+(d[j]|0)+(((d[i]|0)+(d[k]|0)|0)*-5|0)+(d[r]|0)>>5;if(c>>>0>255>>>0){t=-c>>31&255}else{t=c&255}a[l]=((d[l]|0)+1+(t&255)|0)>>>1;l=h+5|0;c=b+8|0;j=(((d[i]|0)+(d[o]|0)|0)*20|0)+16+(d[k]|0)+(((d[r]|0)+(d[n]|0)|0)*-5|0)+(d[c]|0)>>5;if(j>>>0>255>>>0){u=-j>>31&255}else{u=j&255}a[l]=((d[l]|0)+1+(u&255)|0)>>>1;l=h+6|0;j=b+9|0;k=(((d[r]|0)+(d[i]|0)|0)*20|0)+16+(d[n]|0)+(((d[c]|0)+(d[o]|0)|0)*-5|0)+(d[j]|0)>>5;if(k>>>0>255>>>0){v=-k>>31&255}else{v=k&255}a[l]=((d[l]|0)+1+(v&255)|0)>>>1;l=h+7|0;k=(((d[c]|0)+(d[r]|0)|0)*20|0)+16+(d[o]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[b+10|0]|0)>>5;if(k>>>0>255>>>0){w=-k>>31&255}else{w=k&255}a[l]=((d[l]|0)+1+(w&255)|0)>>>1;l=g+1|0;if((l|0)<8){g=l;h=h+e|0;b=b+f|0}else{break}}return}function oAa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=c+1|0;h=c-1|0;i=c+2|0;j=c+3|0;k=(((d[g]|0)+(d[c]|0)|0)*20|0)+16+(d[c-2|0]|0)+(((d[i]|0)+(d[h]|0)|0)*-5|0)+(d[j]|0)>>5;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[b]=l;l=(((d[i]|0)+(d[g]|0)|0)*20|0)+16+(d[h]|0)+(((d[j]|0)+(d[c]|0)|0)*-5|0)+(d[c+4|0]|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[b+1|0]=m;m=c+f|0;l=c+(f+1)|0;j=c+(f-1)|0;h=c+(f+2)|0;g=c+(f+3)|0;i=(((d[l]|0)+(d[m]|0)|0)*20|0)+16+(d[c+(f-2)|0]|0)+(((d[h]|0)+(d[j]|0)|0)*-5|0)+(d[g]|0)>>5;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b+e|0]=n;n=(((d[h]|0)+(d[l]|0)|0)*20|0)+16+(d[j]|0)+(((d[g]|0)+(d[m]|0)|0)*-5|0)+(d[c+(f+4)|0]|0)>>5;if(!(n>>>0>255>>>0)){o=n&255;p=e+1|0;q=b+p|0;a[q]=o;return}o=-n>>31&255;p=e+1|0;q=b+p|0;a[q]=o;return}function pAa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d[c-2|0]|0;g=d[c]|0;h=d[c+2|0]|0;i=d[c+4|0]|0;j=d[c+6|0]|0;k=d[c+8|0]|0;l=(d[c-4|0]|0)+16+((h+g|0)*20|0)+j+((i+f|0)*-5|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[b]=m;m=f+16+((i+h|0)*20|0)+k+((j+g|0)*-5|0)>>5;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[b+e|0]=n;n=d[c-1|0]|0;m=d[c+1|0]|0;g=d[c+3|0]|0;j=d[c+5|0]|0;k=d[c+7|0]|0;h=d[c+9|0]|0;i=(d[c-3|0]|0)+16+((g+m|0)*20|0)+k+((j+n|0)*-5|0)>>5;if(i>>>0>255>>>0){o=-i>>31&255}else{o=i&255}a[b+1|0]=o;o=n+16+((j+g|0)*20|0)+h+((k+m|0)*-5|0)>>5;if(!(o>>>0>255>>>0)){p=o&255;q=e+1|0;r=b+q|0;a[r]=p;return}p=-o>>31&255;q=e+1|0;r=b+q|0;a[r]=p;return}function qAa(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=f+(-(h<<1)|0)|0;f=0;j=e;while(1){k=i+1|0;l=i-1|0;m=i+2|0;n=i+3|0;b[j>>1]=(((d[i-2|0]|0)+(((d[k]|0)+(d[i]|0)&65535)*20&65535)&65535)+(((d[m]|0)+(d[l]|0)&65535)*-5&65535)&65535)+(d[n]|0);b[j+2>>1]=(((d[l]|0)+(((d[m]|0)+(d[k]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[i]|0)&65535)*-5&65535)&65535)+(d[i+4|0]|0);n=f+1|0;if((n|0)<7){i=i+h|0;f=n;j=j+4|0}else{break}}j=b[e+4>>1]|0;f=b[e+8>>1]|0;h=b[e+12>>1]|0;i=b[e+16>>1]|0;n=b[e+20>>1]|0;k=b[e+24>>1]|0;m=(b[e>>1]|0)+512+((h+f|0)*20|0)+n+((i+j|0)*-5|0)>>10;if(m>>>0>255>>>0){o=-m>>31&255}else{o=m&255}a[c]=o;o=j+512+((i+h|0)*20|0)+k+((n+f|0)*-5|0)>>10;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c+g|0]=p;p=b[e+6>>1]|0;o=b[e+10>>1]|0;f=b[e+14>>1]|0;n=b[e+18>>1]|0;k=b[e+22>>1]|0;h=b[e+26>>1]|0;i=(b[e+2>>1]|0)+512+((f+o|0)*20|0)+k+((n+p|0)*-5|0)>>10;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[c+1|0]=q;q=p+512+((n+f|0)*20|0)+h+((k+o|0)*-5|0)>>10;if(!(q>>>0>255>>>0)){r=q&255;s=g+1|0;t=c+s|0;a[t]=r;return}r=-q>>31&255;s=g+1|0;t=c+s|0;a[t]=r;return}function rAa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=b+7380|0;c[g>>2]=0;a:do{if((e|0)>1){h=0;b:while(1){do{if((a[d+h|0]|0)==0){if((h|0)>0){i=h-1|0;j=(a[d+i|0]|0)==0?i:h}else{j=h}i=j+2|0;if((i|0)>=(e|0)){k=j;break}if((a[d+(j+1)|0]|0)!=0){k=j;break}l=a[d+i|0]|0;if((l&255)>>>0<4>>>0){break b}else{k=j}}else{k=h}}while(0);i=k+2|0;if((k+3|0)<(e|0)){h=i}else{m=i;n=e;break a}}m=j;n=l<<24>>24==3?e:j}else{m=0;n=e}}while(0);if((m|0)>=(n-1|0)){c[f+12>>2]=d;c[f+8>>2]=n;o=n;return o|0}kEb(f,f+4|0,n+16|0);e=c[f>>2]|0;if((e|0)==0){o=-12;return o|0}UGb(e|0,d|0,m)|0;j=m+2|0;c:do{if((j|0)<(n|0)){l=b+7388|0;k=b+7384|0;h=k;i=m;p=m;q=j;d:while(1){r=d+q|0;s=a[r]|0;do{if((s&255)>>>0>3>>>0){a[e+p|0]=a[d+i|0]|0;a[e+(p+1)|0]=a[d+(i+1)|0]|0;t=p+2|0;u=q;v=a[r]|0;w=26}else{x=a[d+i|0]|0;if(!(x<<24>>24==0)){t=p;u=i;v=x;w=26;break}if((a[d+(i+1)|0]|0)!=0){t=p;u=i;v=0;w=26;break}if(!(s<<24>>24==3)){y=p;z=i;break c}x=p+1|0;a[e+p|0]=0;A=p+2|0;a[e+x|0]=0;B=i+3|0;C=(c[g>>2]|0)+1|0;c[g>>2]=C;D=c[l>>2]|0;if((D|0)<(C|0)){C=D<<1;c[l>>2]=C;bEb(h,C,4)|0;C=c[k>>2]|0;if((C|0)==0){o=-12;break d}else{E=C}}else{C=c[k>>2]|0;if((C|0)==0){F=A;G=B;break}else{E=C}}c[E+((c[g>>2]|0)-1<<2)>>2]=x;F=A;G=B}}while(0);if((w|0)==26){w=0;a[e+t|0]=v;F=t+1|0;G=u+1|0}s=G+2|0;if((s|0)<(n|0)){i=G;p=F;q=s}else{H=G;I=F;w=15;break c}}return o|0}else{H=m;I=m;w=15}}while(0);do{if((w|0)==15){if((H|0)>=(n|0)){y=I;z=H;break}m=n+I|0;F=H;G=I;while(1){u=F+1|0;a[e+G|0]=a[d+F|0]|0;if((u|0)<(n|0)){F=u;G=G+1|0}else{break}}y=m-H|0;z=n}}while(0);TGb(e+y|0,0,16)|0;c[f+12>>2]=e;c[f+8>>2]=y;o=z;return o|0}function sAa(a){a=a|0;var b=0;TGb(c[a+60>>2]|0,0,7516)|0;b=MAa(a)|0;return((b|0)<0?b:0)|0}function tAa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c[d+60>>2]|0;g=f;h=c[e+60>>2]|0;do{if((a[f+7477|0]|0)==0){e=MAa(d)|0;if((e|0)<0){i=e}else{break}return i|0}}while(0);d=f+3484|0;e=h+3484|0;j=0;while(1){k=d+(j*72|0)|0;QBa(g,k,-1);if((c[(c[e+(j*72|0)>>2]|0)+360>>2]|0)!=0){l=T0a(d+(j*72|0)+4|0,e+(j*72|0)+4|0)|0;if((l|0)<0){i=l;m=28;break}l=WAb(c[e+(j*72|0)+56>>2]|0)|0;c[d+(j*72|0)+56>>2]=l;if((l|0)==0){m=10;break}c[d+(j*72|0)+16>>2]=c[e+(j*72|0)+16>>2];l=WAb(c[e+(j*72|0)+60>>2]|0)|0;c[d+(j*72|0)+60>>2]=l;if((l|0)==0){m=10;break}c[d+(j*72|0)+24>>2]=c[e+(j*72|0)+24>>2];l=WAb(c[e+(j*72|0)+64>>2]|0)|0;c[d+(j*72|0)+64>>2]=l;if((l|0)==0){m=10;break}c[d+(j*72|0)+32>>2]=c[e+(j*72|0)+32>>2];c[d+(j*72|0)+28>>2]=c[e+(j*72|0)+28>>2];l=d+(j*72|0)+40|0;n=e+(j*72|0)+40|0;c[l>>2]=c[n>>2];c[l+4>>2]=c[n+4>>2];c[l+8>>2]=c[n+8>>2];c[l+12>>2]=c[n+12>>2];a[d+(j*72|0)+70|0]=a[e+(j*72|0)+70|0]|0;b[d+(j*72|0)+68>>1]=b[e+(j*72|0)+68>>1]|0}n=j+1|0;if(n>>>0<32>>>0){j=n}else{m=4;break}}if((m|0)==4){j=f+188|0;e=h+188|0;d=0;do{n=j+(d<<2)|0;XAb(n);l=c[e+(d<<2)>>2]|0;if((l|0)!=0){o=WAb(l)|0;c[n>>2]=o;if((o|0)==0){i=-12;m=28;break}}d=d+1|0;}while(d>>>0<16>>>0);if((m|0)==28){return i|0}d=f+252|0;e=h+252|0;j=0;do{o=d+(j<<2)|0;XAb(o);n=c[e+(j<<2)>>2]|0;if((n|0)!=0){l=WAb(n)|0;c[o>>2]=l;if((l|0)==0){i=-12;m=28;break}}j=j+1|0;}while(j>>>0<32>>>0);if((m|0)==28){return i|0}j=f+380|0;e=h+380|0;d=0;do{l=j+(d<<2)|0;XAb(l);o=c[e+(d<<2)>>2]|0;if((o|0)!=0){n=WAb(o)|0;c[l>>2]=n;if((n|0)==0){i=-12;m=28;break}}d=d+1|0;}while(d>>>0<256>>>0);if((m|0)==28){return i|0}d=c[h+180>>2]|0;if((c[f+180>>2]|0)!=(d|0)){LAa(g,d)|0}d=b[h+7368>>1]|0;e=f+7368|0;b[e>>1]=d;b[f+7370>>1]=b[h+7370>>1]|0;c[f+5792>>2]=c[h+5792>>2];j=f+5804|0;c[j>>2]=c[h+5804>>2];a[f+7478|0]=a[h+7478|0]|0;c[f+7488>>2]=c[h+7488>>2];a[f+141|0]=a[h+141|0]|0;a[f+140|0]=a[h+140|0]|0;if((c[h+5800>>2]|0)==0){i=0;return i|0}b[e>>1]=d+1&255;c[j>>2]=2147483647;i=0;return i|0}else if((m|0)==10){QBa(g,k,-1);i=-12;return i|0}else if((m|0)==28){return i|0}return 0}function uAa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=i;f=c[b+60>>2]|0;g=f;Vhb();c[(c[b+64>>2]|0)+4>>2]=1;h=MAa(b)|0;if((h|0)<0){j=h;i=e;return j|0}c[f+7372>>2]=0;c[f+7512>>2]=0;h=b+816|0;if((c[h>>2]&2|0)==0){a[f+141|0]=1}else{a[f+141|0]=c[b+808>>2]}a:do{if((c[b+100>>2]|0)>0){if((c[b+96>>2]|0)==0){break}k=f+4|0;l=c[k>>2]|0;m=l+96|0;n=c[m>>2]|0;o=l+100|0;p=c[o>>2]|0;if(!((p|0)>-1)){yDb(0,0,2055664,(q=i,i=i+24|0,c[q>>2]=2044904,c[q+8>>2]=2039920,c[q+16>>2]=135,q)|0);i=q;Cd();return 0}r=n+p|0;b:do{if((p|0)>3){do{if((a[n]|0)==0){if((a[n+1|0]|0)!=0){break}if(!((d[n+2|0]|0)>>>0>1>>>0)){s=32;break b}}}while(0);a[f+7478|0]=1;t=r;u=p>>>0>21>>>0?21:p;v=n+u|0;if((p-u|0)<1){w=1;x=v}else{w=(a[v]&3)+1|0;x=n+(u+1)|0}c:do{if((t-x|0)<1){u=f+7488|0;c[u>>2]=2;y=u}else{u=a[x]|0;v=u&255;z=f+7488|0;c[z>>2]=2;if(u<<24>>24==0){y=z;break}u=x+1|0;A=0;d:while(1){if((t-u|0)<1){B=0;C=u}else{B=a[u]&63;C=u+1|0}do{if((t-C|0)<2){D=C}else{E=C+2|0;F=C;G=(d[F]|d[F+1|0]<<8)<<16>>16;F=(de(G|0)|0)&65535;if(G<<16>>16==0){D=E;break}else{H=E;I=0}while(1){E=t-H|0;if((E|0)<2){J=2}else{G=H;J=((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)+2|0}if(E>>>0<J>>>0){s=26;break d}K=zAa(g,H,J)|0;if((K|0)<0){s=28;break d}G=H+(E>>>0>J>>>0?J:E)|0;E=I+1|0;if((E|0)<(F|0)){H=G;I=E}else{D=G;break}}}}while(0);F=A+1|0;if((F|0)<(v|0)){u=D;A=F}else{y=z;break c}}if((s|0)==26){yDb(c[k>>2]|0,16,2064320,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;L=-1094995529;break b}else if((s|0)==28){yDb(l,16,2060408,(q=i,i=i+16|0,c[q>>2]=B,c[q+8>>2]=A,q)|0);i=q;L=K;break b}}}while(0);c[y>>2]=w;break a}else{s=32}}while(0);if((s|0)==32){a[f+7478|0]=0;l=zAa(g,c[m>>2]|0,c[o>>2]|0)|0;if((l|0)<0){L=l}else{break}}wAa(b)|0;j=L;i=e;return j|0}}while(0);do{if((c[h>>2]&1|0)!=0){if((c[b+808>>2]|0)<=1){break}a[f+140|0]=1;j=0;i=e;return j|0}}while(0);a[f+140|0]=2;j=0;i=e;return j|0}function vAa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;j=i;i=i+16|0;k=j|0;l=c[e+60>>2]|0;m=l;n=h+28|0;o=c[n>>2]|0;if((o|0)==0){p=WBa(m,f,1)|0;if((p|0)<0){q=p;i=j;return q|0}c[g>>2]=p;q=0;i=j;return q|0}p=l+3480|0;c[p>>2]=0;r=zAa(m,c[h+24>>2]|0,o)|0;if((r|0)<0){q=r;i=j;return q|0}r=e+696|0;o=l+5816|0;a:do{if((c[r>>2]&1|0)!=0){if((c[o>>2]|0)==0){break}if((a[l+7476|0]|0)==0){break}h=c[c[p>>2]>>2]|0;s=k|0;t=bFb(c[h+80>>2]|0)|0;b:do{if((t|0)==0){u=-22}else{v=(b[t+8>>1]&16384)>>>0>14336>>>0|0;w=l+4|0;yDb(c[w>>2]|0,48,2110184,(x=i,i=i+8|0,c[x>>2]=c[l+5788>>2],x)|0);i=x;y=h|0;z=c[w>>2]|0;c:do{if((c[y>>2]|0)==0){A=z}else{B=t+5|0;C=t+6|0;D=l+7424|0;E=0;F=y;G=z;while(1){H=c[G+128>>2]|0;I=c[G+132>>2]|0;if((E-1|0)>>>0<2>>>0){J=I>>d[C];K=H>>d[B]}else{J=I;K=H}QDb(c[D>>2]|0);if((J|0)>0){H=h+32+(E<<2)|0;I=K<<v;L=0;do{M=(c[F>>2]|0)+(ba(c[H>>2]|0,L)|0)|0;RDb(c[D>>2]|0,M,I);L=L+1|0;}while((L|0)<(J|0))}TDb(c[D>>2]|0,s);L=(PGb(s,m+7428+(E<<4)|0,16)|0)==0;N=c[w>>2]|0;if(!L){break}yDb(N,48,2051952,(x=i,i=i+8|0,c[x>>2]=E,x)|0);i=x;L=c[w>>2]|0;I=0;do{yDb(L,48,1895400,(x=i,i=i+8|0,c[x>>2]=d[k+I|0]|0,x)|0);i=x;I=I+1|0;}while((I|0)<16);yDb(c[w>>2]|0,48,2006560,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;I=E+1|0;L=h+(I<<2)|0;H=c[w>>2]|0;if((c[L>>2]|0)==0){A=H;break c}else{E=I;F=L;G=H}}yDb(N,16,1968680,(x=i,i=i+8|0,c[x>>2]=E,x)|0);i=x;G=c[w>>2]|0;F=0;do{yDb(G,16,1895400,(x=i,i=i+8|0,c[x>>2]=d[k+F|0]|0,x)|0);i=x;F=F+1|0;}while((F|0)<16);yDb(c[w>>2]|0,16,1940200,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;F=c[w>>2]|0;G=0;do{yDb(F,16,1895400,(x=i,i=i+8|0,c[x>>2]=d[m+7428+(E<<4)+G|0]|0,x)|0);i=x;G=G+1|0;}while((G|0)<16);yDb(c[w>>2]|0,16,1915992,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;u=-1094995529;break b}}while(0);yDb(A,48,1915992,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;break a}}while(0);if((c[r>>2]&8|0)==0){break}QBa(m,c[p>>2]|0,-1);q=u;i=j;return q|0}}while(0);a[l+7476|0]=0;if((c[o>>2]|0)!=0){yDb(e,48,2187416,(x=i,i=i+8|0,c[x>>2]=c[l+5788>>2],x)|0);i=x;c[o>>2]=0}o=c[l+172>>2]|0;if((c[o+360>>2]|0)!=0){QCb(f,o);c[g>>2]=1}q=c[n>>2]|0;i=j;return q|0}function wAa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[b+60>>2]|0;b=d;e=d+136|0;yAa(b);$Db(d+7424|0);f=d+7416|0;g=d+7396|0;if((c[f>>2]|0)>0){h=g;i=0;do{$Db((c[h>>2]|0)+(i<<2)|0);i=i+1|0;}while((i|0)<(c[f>>2]|0))}$Db(d+7400|0);$Db(d+7392|0);$Db(g);$Db(d+152|0);JCb(d+168|0);JCb(d+172|0);g=d+3484|0;i=0;do{h=g+(i*72|0)|0;QBa(b,h,-1);JCb(h|0);i=i+1|0;}while(i>>>0<32>>>0);XAb(d+188|0);XAb(d+192|0);XAb(d+196|0);XAb(d+200|0);XAb(d+204|0);XAb(d+208|0);XAb(d+212|0);XAb(d+216|0);XAb(d+220|0);XAb(d+224|0);XAb(d+228|0);XAb(d+232|0);XAb(d+236|0);XAb(d+240|0);XAb(d+244|0);XAb(d+248|0);i=d+252|0;b=0;do{XAb(i+(b<<2)|0);b=b+1|0;}while(b>>>0<32>>>0);b=d+380|0;i=0;do{XAb(b+(i<<2)|0);i=i+1|0;}while(i>>>0<256>>>0);$Db(d+3056|0);$Db(d+3060|0);$Db(d+3064|0);i=d+141|0;b=a[i]|0;g=d+72|0;if((b&255)>>>0>1>>>0){h=g;j=d+8|0;k=1;l=b;while(1){b=h+(k<<2)|0;if((c[b>>2]|0)==0){m=l}else{$Db(b);$Db(j+(k<<2)|0);m=a[i]|0}b=k+1|0;if((b|0)<(m&255|0)){k=b;l=m}else{break}}}if((c[e>>2]|0)==(c[g>>2]|0)){c[e>>2]=0}$Db(g);g=d+7408|0;if((c[f>>2]|0)<=0){$Db(g);c[f>>2]=0;return 0}d=g;e=0;do{$Db((c[d>>2]|0)+(e<<4)|0);e=e+1|0;}while((e|0)<(c[f>>2]|0));$Db(g);c[f>>2]=0;return 0}function xAa(a){a=a|0;var b=0;b=c[a+60>>2]|0;TBa(b);c[b+5804>>2]=2147483647;return}function yAa(a){a=a|0;$Db(a+3464|0);$Db(a+3468|0);$Db(a+7320|0);$Db(a+7336|0);$Db(a+7340|0);$Db(a+7344|0);$Db(a+7348|0);$Db(a+7352|0);$Db(a+7316|0);$Db(a+7332|0);$Db(a+7356|0);$Db(a+7324|0);$Db(a+7328|0);$Db(a+3056|0);$Db(a+3064|0);$Db(a+3060|0);bBb(a+1404|0);bBb(a+1408|0);return}function zAa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;g=i;h=b+3480|0;c[h>>2]=0;j=b+5800|0;c[j>>2]=0;k=b+7412|0;c[k>>2]=0;a:do{if((f|0)>3){l=b+7478|0;m=b+7416|0;n=b+7408|0;o=b+7392|0;p=o;q=b+7400|0;r=q;s=b+7396|0;t=s;u=b+7388|0;v=b+7384|0;w=b+7380|0;x=b+136|0;y=b+3472|0;z=b+3476|0;A=b+4|0;B=b+7488|0;C=f;D=e;b:while(1){E=(a[l]|0)==0;if(E){F=D;G=C;c:while(1){H=F+1|0;do{if((a[F]|0)==0){if((a[H]|0)!=0){break}if((a[F+2|0]|0)==1){break c}}}while(0);I=G-1|0;if((I|0)<4){J=15;break b}else{F=H;G=I}}K=F+3|0;L=G-3|0;M=0}else{I=c[B>>2]|0;if((I|0)>0){N=0;O=0;while(1){P=d[D+O|0]|N<<8;Q=O+1|0;if((Q|0)<(I|0)){N=P;O=Q}else{R=P;break}}}else{R=0}O=C-I|0;if((R|0)>(O|0)){J=10;break}K=D+I|0;L=O;M=R}O=E?L:M;N=c[m>>2]|0;G=c[k>>2]|0;if((N|0)<(G+1|0)){F=N+1|0;N=aEb(c[n>>2]|0,F,16)|0;P=N;if((N|0)==0){S=-12;break a}c[n>>2]=P;N=c[m>>2]|0;TGb(P+(N<<4)|0,0,F-N<<4|0)|0;bEb(p,F,4)|0;bEb(r,F,4)|0;bEb(t,F,4)|0;N=c[q>>2]|0;c[N+(c[m>>2]<<2)>>2]=1024;P=c[m>>2]|0;Q=c[N+(P<<2)>>2]|0;if(Q>>>0>536870910>>>0){T=0;U=P}else{P=WDb(Q<<2)|0;T=P;U=c[m>>2]|0}c[(c[s>>2]|0)+(U<<2)>>2]=T;c[m>>2]=F;V=c[k>>2]|0}else{V=G}c[u>>2]=c[(c[q>>2]|0)+(V<<2)>>2];c[v>>2]=c[(c[s>>2]|0)+(V<<2)>>2];G=c[n>>2]|0;F=rAa(b,K,O,G+(V<<4)|0)|0;c[(c[o>>2]|0)+(c[k>>2]<<2)>>2]=c[w>>2];c[(c[q>>2]|0)+(c[k>>2]<<2)>>2]=c[u>>2];O=c[v>>2]|0;P=c[k>>2]|0;c[k>>2]=P+1;c[(c[s>>2]|0)+(P<<2)>>2]=O;if((F|0)<0){S=F;break a}O=c[x>>2]|0;P=c[G+(V<<4)+12>>2]|0;Q=c[G+(V<<4)+8>>2]|0;G=Q>>>0>268435455>>>0?-8:Q<<3;Q=G>>>0>2147483639>>>0|(P|0)==0;N=Q?0:P;P=Q?0:G;G=Q?-1094995529:0;c[O+9272>>2]=N;c[O+9284>>2]=P;c[O+9288>>2]=P+8;c[O+9276>>2]=N+(P>>3);c[O+9280>>2]=0;if(Q){S=G;break a}Q=c[x>>2]|0;O=Q+9280|0;P=c[O>>2]|0;N=c[Q+9272>>2]|0;W=d[N+(P>>>3)|0]|0;X=c[Q+9288>>2]|0;Q=((P|0)<(X|0))+P|0;c[O>>2]=Q;do{if((W&128>>>((P&7)>>>0)|0)==0){Y=N+(Q>>>3)|0;Z=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(Q&7)>>>26;Y=Q+6|0;_=X>>>0>Y>>>0?Y:X;c[O>>2]=_;c[y>>2]=Z;Y=N+(_>>>3)|0;$=d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0;Y=_+6|0;aa=X>>>0>Y>>>0?Y:X;c[O>>2]=aa;Y=N+(aa>>>3)|0;ba=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(aa&7)>>>29;Y=aa+3|0;c[O>>2]=X>>>0>Y>>>0?Y:X;Y=ba-1|0;c[z>>2]=Y;if((Y|0)<0){break}ba=(fe($|0)|0)<<(_&7)>>>26;yDb(c[A>>2]|0,48,2068888,(ca=i,i=i+24|0,c[ca>>2]=Z,c[ca+8>>2]=ba,c[ca+16>>2]=Y,ca)|0);i=ca}}while(0);if(((c[y>>2]|0)-36|0)>>>0<2>>>0){c[j>>2]=1}X=L-F|0;if((X|0)>3){C=X;D=K+F|0}else{da=G;ea=o;fa=w;ga=s;ha=v;ia=n;J=4;break a}}if((J|0)==10){yDb(c[A>>2]|0,16,2352632,(ca=i,i=i+1|0,i=i+7&-8,c[ca>>2]=0,ca)|0);i=ca;S=-1094995529;break}else if((J|0)==15){yDb(c[A>>2]|0,16,2332424,(ca=i,i=i+1|0,i=i+7&-8,c[ca>>2]=0,ca)|0);i=ca;S=-1094995529;break}}else{da=0;ea=b+7392|0;fa=b+7380|0;ga=b+7396|0;ha=b+7384|0;ia=b+7408|0;J=4}}while(0);d:do{if((J|0)==4){K=0;while(1){if((K|0)>=(c[k>>2]|0)){S=da;break d}c[fa>>2]=c[(c[ea>>2]|0)+(K<<2)>>2];c[ha>>2]=c[(c[ga>>2]|0)+(K<<2)>>2];L=c[ia>>2]|0;if((AAa(b,c[L+(K<<4)+12>>2]|0,c[L+(K<<4)+8>>2]|0)|0)<0){break}K=K+1|0}yDb(c[b+4>>2]|0,24,2308088,(ca=i,i=i+8|0,c[ca>>2]=K,ca)|0);i=ca;S=da}}while(0);da=c[h>>2]|0;if((da|0)==0){i=g;return S|0}if((a[b+140|0]|0)!=1){i=g;return S|0}Y0a(da+4|0,2147483647,0);i=g;return S|0}function AAa(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0;j=i;i=i+80|0;k=j|0;l=j+16|0;m=j+32|0;n=j+48|0;o=j+64|0;p=j+72|0;q=f+136|0;r=c[q>>2]|0;s=h>>>0>268435455>>>0?-8:h<<3;t=s>>>0>2147483639>>>0|(g|0)==0;u=t?0:g;v=t?0:s;c[r+9272>>2]=u;c[r+9284>>2]=v;c[r+9288>>2]=v+8;c[r+9276>>2]=u+(v>>3);c[r+9280>>2]=0;if(t){w=t?-1094995529:0;i=j;return w|0}t=c[q>>2]|0;r=t+9280|0;v=c[r>>2]|0;u=c[t+9272>>2]|0;s=d[u+(v>>>3)|0]|0;x=c[t+9288>>2]|0;t=((v|0)<(x|0))+v|0;c[r>>2]=t;a:do{if((s&128>>>((v&7)>>>0)|0)==0){y=u+(t>>>3)|0;z=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(t&7)>>>26;y=t+6|0;A=x>>>0>y>>>0?y:x;c[r>>2]=A;y=f+3472|0;c[y>>2]=z;B=u+(A>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>26;B=A+6|0;A=x>>>0>B>>>0?B:x;c[r>>2]=A;B=u+(A>>>3)|0;D=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>29;B=A+3|0;c[r>>2]=x>>>0>B>>>0?B:x;B=D-1|0;D=f+3476|0;c[D>>2]=B;if((B|0)<0){E=z;F=6;break}A=f+4|0;yDb(c[A>>2]|0,48,2068888,(G=i,i=i+24|0,c[G>>2]=z,c[G+8>>2]=C,c[G+16>>2]=B,G)|0);i=G;if((C|0)!=0){w=0;i=j;return w|0}C=c[y>>2]|0;switch(C|0){case 32:{B=HBa(f)|0;if((B|0)<0){H=B;break a}else{w=0}i=j;return w|0};case 36:case 37:{B=f+7368|0;b[B>>1]=(b[B>>1]|0)+1&255;c[f+5804>>2]=2147483647;w=0;i=j;return w|0};case 1:case 0:case 2:case 3:case 4:case 5:case 16:case 17:case 18:case 19:case 20:case 21:case 6:case 7:case 8:case 9:{B=c[q>>2]|0;z=B+9272|0;I=B+9280|0;J=c[I>>2]|0;K=z|0;L=d[(c[K>>2]|0)+(J>>>3)|0]<<(J&7)>>>7;M=B+9288|0;c[I>>2]=((J|0)<(c[M>>2]|0))+J;J=L&1;L=f+2412|0;a[L]=J;do{if((C-16|0)>>>0>4>>>0|J<<24>>24==0){N=C}else{B=f+7368|0;b[B>>1]=(b[B>>1]|0)+1&255;c[f+5804>>2]=2147483647;if(!((C-19|0)>>>0<2>>>0)){N=C;break}SBa(f);N=c[y>>2]|0}}while(0);if((N-16|0)>>>0<8>>>0){J=c[I>>2]|0;B=d[(c[K>>2]|0)+(J>>>3)|0]<<(J&7)>>>7;c[I>>2]=((J|0)<(c[M>>2]|0))+J;a[f+3010|0]=B&1}B=KAa(z)|0;c[f+2392>>2]=B;do{if(!(B>>>0>255>>>0)){J=c[f+380+(B<<2)>>2]|0;if((J|0)==0){break}do{if((a[L]|0)==0){O=f+184|0;P=c[J+4>>2]|0;if((c[O>>2]|0)==(P|0)){Q=P;R=O;break}yDb(c[A>>2]|0,16,2165624,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}else{Q=c[J+4>>2]|0;R=f+184|0}}while(0);c[R>>2]=Q;J=f+180|0;O=c[J>>2]|0;P=c[(c[f+252+(c[Q>>2]<<2)>>2]|0)+4>>2]|0;do{if((O|0)==(P|0)){S=O}else{c[J>>2]=P;SBa(f);T=LAa(f,c[J>>2]|0)|0;if((T|0)<0){w=T;i=j;return w|0}else{T=f+7368|0;b[T>>1]=(b[T>>1]|0)+1&255;c[f+5804>>2]=2147483647;S=c[J>>2]|0;break}}}while(0);P=c[A>>2]|0;c[P+840>>2]=d[S+302|0]|0;c[P+844>>2]=d[S+335|0]|0;O=f+2413|0;a[O]=0;do{if((a[L]|0)==0){if((a[(c[R>>2]|0)+41|0]|0)!=0){T=c[I>>2]|0;U=d[(c[K>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[I>>2]=((T|0)<(c[M>>2]|0))+T;a[O]=U&1}U=S+13104|0;T=S+13108|0;V=(ba(c[U>>2]<<1,c[T>>2]|0)|0)-2|0;W=V>>>0>65535>>>0;X=W?V>>>16:V;V=W?16:0;if((X&65280|0)==0){Y=V;Z=X}else{Y=V|8;Z=X>>>8}X=(d[1191992+Z|0]|0)+Y|0;V=c[I>>2]|0;W=c[M>>2]|0;_=(c[K>>2]|0)+(V>>>3)|0;$=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(V&7)>>>((32-X|0)>>>0);_=X+V|0;c[I>>2]=W>>>0>_>>>0?_:W;c[f+2396>>2]=$;if(!($>>>0<(ba(c[T>>2]|0,c[U>>2]|0)|0)>>>0)){yDb(P,16,2159032,(G=i,i=i+8|0,c[G>>2]=$,G)|0);i=G;w=-1094995529;i=j;return w|0}if((a[O]|0)==0){c[f+2400>>2]=$;$=f+5796|0;c[$>>2]=(c[$>>2]|0)+1;aa=f+156|0;F=37;break}$=f+156|0;if((a[$]|0)!=0){ca=$;da=c[R>>2]|0;break}yDb(P,16,2088552,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}else{c[f+2400>>2]=0;c[f+2396>>2]=0;c[f+5796>>2]=0;$=f+156|0;a[$]=0;aa=$;F=37}}while(0);b:do{if((F|0)==37){a[aa]=0;P=(c[R>>2]|0)+1624|0;if((c[P>>2]|0)>0){$=c[M>>2]|0;U=0;T=c[I>>2]|0;do{W=T+1|0;T=$>>>0>W>>>0?W:$;c[I>>2]=T;U=U+1|0;}while((U|0)<(c[P>>2]|0))}P=KAa(z)|0;U=f+2404|0;c[U>>2]=P;if(!(P>>>0<3>>>0)){yDb(c[A>>2]|0,16,2151944,(G=i,i=i+8|0,c[G>>2]=P,G)|0);i=G;w=-1094995529;i=j;return w|0}T=c[y>>2]|0;if(!((T-16|0)>>>0>7>>>0|(P|0)==2)){yDb(c[A>>2]|0,16,2144912,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}if((a[(c[R>>2]|0)+39|0]|0)!=0){P=c[I>>2]|0;$=d[(c[K>>2]|0)+(P>>>3)|0]<<(P&7)>>>7;c[I>>2]=((P|0)<(c[M>>2]|0))+P;a[f+2414|0]=$&1}$=c[J>>2]|0;if((a[$+8|0]|0)!=0){P=c[I>>2]|0;W=c[M>>2]|0;_=(c[K>>2]|0)+(P>>>3)|0;V=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(P&7)>>>30;_=P+2|0;c[I>>2]=W>>>0>_>>>0?_:W;a[f+2415|0]=V}do{if((T-19|0)>>>0<2>>>0){c[f+2584>>2]=0;c[f+5788>>2]=0;ea=$}else{V=c[$+64>>2]|0;W=c[I>>2]|0;_=c[M>>2]|0;P=(c[K>>2]|0)+(W>>>3)|0;X=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(W&7)>>>((32-V|0)>>>0);P=W+V|0;c[I>>2]=_>>>0>P>>>0?P:_;_=f+2408|0;c[_>>2]=X;P=_Ba(f,X)|0;X=f+5788|0;do{if((a[L]|0)==0){V=c[X>>2]|0;if((P|0)==(V|0)){fa=P;break}yDb(c[A>>2]|0,24,2139280,(G=i,i=i+16|0,c[G>>2]=V,c[G+8>>2]=P,G)|0);i=G;if((c[(c[A>>2]|0)+696>>2]&8|0)==0){fa=c[X>>2]|0;break}else{w=-1094995529;i=j;return w|0}}else{fa=P}}while(0);c[X>>2]=fa;P=c[I>>2]|0;V=c[K>>2]|0;W=d[V+(P>>>3)|0]|0;ga=c[M>>2]|0;ha=((P|0)<(ga|0))+P|0;c[I>>2]=ha;do{if((W&128>>>((P&7)>>>0)|0)==0){ia=f+2416|0;ja=FBa(f,ia,c[J>>2]|0,1)|0;if((ja|0)<0){w=ja;i=j;return w|0}else{c[f+2584>>2]=ia;ka=c[J>>2]|0;break}}else{ia=c[J>>2]|0;ja=c[ia+2184>>2]|0;if((ja|0)==0){yDb(c[A>>2]|0,16,2133008,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}la=(ja<<1)-2|0;ja=la>>>0>65535>>>0;ma=ja?la>>>16:la;la=ja?16:0;if((ma&65280|0)==0){na=la;oa=ma}else{na=la|8;oa=ma>>>8}ma=(d[1191992+oa|0]|0)+na|0;if((ma|0)>0){la=V+(ha>>>3)|0;ja=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ha&7)>>>((32-ma|0)>>>0);la=ma+ha|0;c[I>>2]=ga>>>0>la>>>0?la:ga;pa=ja}else{pa=0}c[f+2584>>2]=ia+2188+(pa*168|0);ka=ia}}while(0);ga=ka+64|0;ha=c[ga>>2]|0;V=f+2748|0;a[V]=0;do{if((a[ka+12942|0]|0)!=0){P=ka+13040|0;if((a[P]|0)==0){qa=0}else{qa=KAa(z)|0}W=(KAa(z)|0)+qa|0;if(W>>>0>32>>>0){yDb(c[A>>2]|0,24,2126592,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;if((c[(c[A>>2]|0)+696>>2]&8|0)==0){break}else{w=-1094995529}i=j;return w|0}a[V]=W;if((W&255|0)==0){break}else{ra=0;sa=0}while(1){if(sa>>>0<qa>>>0){W=a[P]|0;if((W&255)>>>0>1>>>0){ia=((W&255)<<1)-2|0;W=ia>>>0>65535>>>0;ja=W?ia>>>16:ia;ia=W?16:0;if((ja&65280|0)==0){ta=ia;ua=ja}else{ta=ia|8;ua=ja>>>8}ja=(d[1191992+ua|0]|0)+ta|0;ia=c[I>>2]|0;W=c[M>>2]|0;la=(c[K>>2]|0)+(ia>>>3)|0;ma=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ia&7)>>>((32-ja|0)>>>0);la=ja+ia|0;c[I>>2]=W>>>0>la>>>0?la:W;va=ma&255}else{va=0}c[f+2588+(sa<<2)>>2]=e[ka+12944+(va<<1)>>1]|0;a[f+2716+sa|0]=a[ka+13008+va|0]|0}else{ma=c[ga>>2]|0;W=c[I>>2]|0;la=c[M>>2]|0;ia=c[K>>2]|0;ja=ia+(W>>>3)|0;wa=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(W&7)>>>((32-ma|0)>>>0);ja=W+ma|0;c[I>>2]=la>>>0>ja>>>0?ja:la;c[f+2588+(sa<<2)>>2]=wa;wa=c[I>>2]|0;la=d[ia+(wa>>>3)|0]<<(wa&7)>>>7;c[I>>2]=((wa|0)<(c[M>>2]|0))+wa;a[f+2716+sa|0]=la&1}la=c[I>>2]|0;wa=d[(c[K>>2]|0)+(la>>>3)|0]|0;c[I>>2]=((la|0)<(c[M>>2]|0))+la;if((wa&128>>>((la&7)>>>0)|0)==0){xa=ra}else{la=KAa(z)|0;wa=la+((sa|0)==0|(sa|0)==(qa|0)?0:ra)|0;la=f+2588+(sa<<2)|0;c[la>>2]=(c[X>>2]|0)-(wa<<ha)-(c[_>>2]|0)+(c[la>>2]|0);xa=wa}wa=sa+1|0;if((wa|0)<(d[V]|0)){ra=xa;sa=wa}else{break}}}}while(0);V=c[J>>2]|0;if((a[V+13060|0]|0)==0){a[f+3011|0]=0;ea=V;break}else{_=c[I>>2]|0;ha=d[(c[K>>2]|0)+(_>>>3)|0]<<(_&7)>>>7;c[I>>2]=((_|0)<(c[M>>2]|0))+_;a[f+3011|0]=ha&1;ea=V;break}}}while(0);c:do{if((c[D>>2]|0)==0){switch(c[y>>2]|0){case 0:case 2:case 4:case 6:case 7:case 8:case 9:{break c;break};default:{}}c[f+5792>>2]=c[f+5788>>2]}}while(0);if((a[ea+12941|0]|0)==0){a[f+3020|0]=0;a[f+3021|0]=0;a[f+3022|0]=0}else{$=c[I>>2]|0;T=d[(c[K>>2]|0)+($>>>3)|0]<<($&7)>>>7;c[I>>2]=(($|0)<(c[M>>2]|0))+$;a[f+3020|0]=T&1;T=c[I>>2]|0;$=d[(c[K>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[I>>2]=((T|0)<(c[M>>2]|0))+T;T=$&1;a[f+3022|0]=T;a[f+3021|0]=T}T=f+3016|0;c[T>>2]=0;$=f+3012|0;c[$>>2]=0;V=c[U>>2]|0;do{if(V>>>0<2>>>0){ha=c[R>>2]|0;c[$>>2]=c[ha+8>>2];if((V|0)==0){c[T>>2]=c[ha+12>>2]}ha=c[I>>2]|0;_=d[(c[K>>2]|0)+(ha>>>3)|0]|0;c[I>>2]=((ha|0)<(c[M>>2]|0))+ha;do{if((_&128>>>((ha&7)>>>0)|0)==0){F=95}else{X=(KAa(z)|0)+1|0;c[$>>2]=X;if((c[U>>2]|0)!=0){ya=X;break}c[T>>2]=(KAa(z)|0)+1;F=95}}while(0);if((F|0)==95){ya=c[$>>2]|0}ha=c[T>>2]|0;if(ya>>>0>16>>>0|ha>>>0>16>>>0){yDb(c[A>>2]|0,16,2120776,(G=i,i=i+16|0,c[G>>2]=ya,c[G+8>>2]=ha,G)|0);i=G;w=-1094995529;i=j;return w|0}ha=f+3008|0;a[ha]=0;_=f+3009|0;a[_]=0;X=$Ba(f)|0;if((X|0)==0){yDb(c[A>>2]|0,16,2114600,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}do{if((a[(c[R>>2]|0)+1617|0]|0)!=0&(X|0)>1){ga=c[I>>2]|0;P=d[(c[K>>2]|0)+(ga>>>3)|0]<<(ga&7)>>>7;c[I>>2]=((ga|0)<(c[M>>2]|0))+ga;ga=P&1;a[ha]=ga;do{if(!(ga<<24>>24==0)){if((c[$>>2]|0)==0){break}P=(X<<1)-2|0;wa=P>>>0>65535>>>0;la=wa?P>>>16:P;P=wa?16:0;if((la&65280|0)==0){wa=(d[1191992+la|0]|0)+P|0;ia=32-wa|0;ja=c[K>>2]|0;ma=0;do{W=c[I>>2]|0;za=c[M>>2]|0;Aa=ja+(W>>>3)|0;Ba=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(W&7)>>>(ia>>>0);Aa=wa+W|0;c[I>>2]=za>>>0>Aa>>>0?Aa:za;c[f+2752+(ma<<2)>>2]=Ba;ma=ma+1|0;}while(ma>>>0<(c[$>>2]|0)>>>0)}else{ma=(d[1191992+(la>>>8)|0]|0)+(P|8)|0;wa=32-ma|0;ia=c[K>>2]|0;ja=0;do{Ba=c[I>>2]|0;za=c[M>>2]|0;Aa=ia+(Ba>>>3)|0;W=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Ba&7)>>>(wa>>>0);Aa=ma+Ba|0;c[I>>2]=za>>>0>Aa>>>0?Aa:za;c[f+2752+(ja<<2)>>2]=W;ja=ja+1|0;}while(ja>>>0<(c[$>>2]|0)>>>0)}}}while(0);ga=c[U>>2]|0;if((ga|0)!=0){Ca=ga;break}ga=c[I>>2]|0;ja=d[(c[K>>2]|0)+(ga>>>3)|0]<<(ga&7)>>>7;c[I>>2]=((ga|0)<(c[M>>2]|0))+ga;ga=ja&1;a[_]=ga;if((ga|0)==0){F=116;break}if((c[T>>2]|0)==0){F=116;break}ga=(X<<1)-2|0;ja=ga>>>0>65535>>>0;ma=ja?ga>>>16:ga;ga=ja?16:0;if((ma&65280|0)==0){ja=(d[1191992+ma|0]|0)+ga|0;wa=32-ja|0;ia=c[K>>2]|0;P=0;while(1){la=c[I>>2]|0;W=c[M>>2]|0;za=ia+(la>>>3)|0;Aa=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(la&7)>>>(wa>>>0);za=ja+la|0;c[I>>2]=W>>>0>za>>>0?za:W;c[f+2880+(P<<2)>>2]=Aa;Aa=P+1|0;if(Aa>>>0<(c[T>>2]|0)>>>0){P=Aa}else{F=116;break}}}else{P=(d[1191992+(ma>>>8)|0]|0)+(ga|8)|0;ja=32-P|0;wa=c[K>>2]|0;ia=0;while(1){Aa=c[I>>2]|0;W=c[M>>2]|0;za=wa+(Aa>>>3)|0;la=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Aa&7)>>>(ja>>>0);za=P+Aa|0;c[I>>2]=W>>>0>za>>>0?za:W;c[f+2880+(ia<<2)>>2]=la;la=ia+1|0;if(la>>>0<(c[T>>2]|0)>>>0){ia=la}else{F=116;break}}}}else{F=116}}while(0);do{if((F|0)==116){X=c[U>>2]|0;if((X|0)!=0){Ca=X;break}X=c[I>>2]|0;_=d[(c[K>>2]|0)+(X>>>3)|0]<<(X&7)>>>7;c[I>>2]=((X|0)<(c[M>>2]|0))+X;a[f+3023|0]=_&1;Ca=0}}while(0);_=c[R>>2]|0;if((a[_+5|0]|0)==0){a[f+3024|0]=0}else{X=c[I>>2]|0;ha=d[(c[K>>2]|0)+(X>>>3)|0]<<(X&7)>>>7;c[I>>2]=((X|0)<(c[M>>2]|0))+X;a[f+3024|0]=ha&1}ha=f+3028|0;c[ha>>2]=0;do{if((a[f+3011|0]|0)==0){Da=_}else{X=f+3027|0;a[X]=0;if((Ca|0)==0){ia=c[I>>2]|0;P=d[(c[K>>2]|0)+(ia>>>3)|0]<<(ia&7);c[I>>2]=((ia|0)<(c[M>>2]|0))+ia;ia=P>>>7&1^1;a[X]=ia;Ea=ia}else{Ea=0}if(!((c[f+3012+(Ea<<2)>>2]|0)>>>0>1>>>0)){Da=_;break}ia=KAa(z)|0;c[ha>>2]=ia;if(ia>>>0<(c[f+3012+(d[X]<<2)>>2]|0)>>>0){Da=c[R>>2]|0;break}yDb(c[A>>2]|0,16,2100424,(G=i,i=i+8|0,c[G>>2]=ia,G)|0);i=G;w=-1094995529;i=j;return w|0}}while(0);if((a[Da+37|0]|0)==0){F=130}else{if((c[U>>2]|0)==1){F=132}else{F=130}}do{if((F|0)==130){if((a[Da+38|0]|0)==0){break}if((c[U>>2]|0)==0){F=132}}}while(0);do{if((F|0)==132){ha=l|0;_=n|0;ia=f+3073|0;a[ia]=KAa(z)|0;X=c[J>>2]|0;if((c[X+4>>2]|0)!=0){P=c[I>>2]|0;ja=c[M>>2]|0;wa=c[K>>2]|0;ga=wa+(P>>>3)|0;ma=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(P&7);if(ma>>>0>134217727>>>0){ga=ma>>>23;la=(d[1213744+ga|0]|0)+P|0;c[I>>2]=ja>>>0>la>>>0?la:ja;Fa=a[1139096+ga|0]|0}else{ga=ma>>>0>65535>>>0;la=ga?ma>>>16:ma;ma=ga?16:0;if((la&65280|0)==0){Ga=ma;Ha=la}else{Ga=ma|8;Ha=la>>>8}la=(d[1191992+Ha|0]|0)+Ga|0;ma=31-la+P|0;P=ja>>>0>ma>>>0?ma:ja;ma=wa+(P>>>3)|0;wa=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(P&7)>>>(la>>>0);ma=P+(32-la)|0;c[I>>2]=ja>>>0>ma>>>0?ma:ja;ja=wa>>>1;Fa=(wa&1|0)==0?ja:-ja|0}ja=(d[ia]|0)+Fa|0;if((ja|0)<0){Ia=0}else{Ia=(ja|0)>7?7:ja&65535}b[f+3074>>1]=Ia}if((c[$>>2]|0)==0){Ja=X;Ka=0}else{X=c[K>>2]|0;ja=c[M>>2]|0;wa=0;ma=c[I>>2]|0;do{la=d[X+(ma>>>3)|0]<<(ma&7)>>>7;ma=((ma|0)<(ja|0))+ma|0;c[I>>2]=ma;P=la&1;a[k+wa|0]=P;if(P<<24>>24==0){b[f+3076+(wa<<1)>>1]=1<<d[ia];b[f+3268+(wa<<1)>>1]=0}wa=wa+1|0;La=c[$>>2]|0;}while(wa>>>0<La>>>0);Ja=c[J>>2]|0;Ka=La}wa=(Ka|0)==0;do{if((c[Ja+4>>2]|0)==0){if(wa){break}TGb(ha|0,0,(Ka>>>0>1>>>0?Ka:1)|0)|0;Ma=Ka;F=152}else{if(wa){break}ma=c[K>>2]|0;ja=c[M>>2]|0;X=0;P=c[I>>2]|0;while(1){la=d[ma+(P>>>3)|0]<<(P&7)>>>7;ga=((P|0)<(ja|0))+P|0;c[I>>2]=ga;a[l+X|0]=la&1;la=X+1|0;W=c[$>>2]|0;if(la>>>0<W>>>0){X=la;P=ga}else{Ma=W;F=152;break}}}}while(0);do{if((F|0)==152){if((Ma|0)==0){break}wa=f+3074|0;ha=0;do{if((a[k+ha|0]|0)!=0){P=c[I>>2]|0;X=c[M>>2]|0;ja=c[K>>2]|0;ma=ja+(P>>>3)|0;W=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(P&7);if(W>>>0>134217727>>>0){ma=W>>>23;ga=(d[1213744+ma|0]|0)+P|0;la=X>>>0>ga>>>0?ga:X;c[I>>2]=la;Na=a[1139096+ma|0]|0;Oa=la}else{la=W>>>0>65535>>>0;ma=la?W>>>16:W;W=la?16:0;if((ma&65280|0)==0){Pa=W;Qa=ma}else{Pa=W|8;Qa=ma>>>8}ma=(d[1191992+Qa|0]|0)+Pa|0;W=31-ma+P|0;P=X>>>0>W>>>0?W:X;W=ja+(P>>>3)|0;la=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(P&7)>>>(ma>>>0);W=P+(32-ma)|0;ma=X>>>0>W>>>0?W:X;c[I>>2]=ma;W=la>>>1;Na=(la&1|0)==0?W:-W|0;Oa=ma}b[f+3076+(ha<<1)>>1]=(1<<d[ia])+Na;ma=ja+(Oa>>>3)|0;W=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(Oa&7);if(W>>>0>134217727>>>0){ma=W>>>23;la=(d[1213744+ma|0]|0)+Oa|0;c[I>>2]=X>>>0>la>>>0?la:X;Ra=a[1139096+ma|0]|0}else{ma=W>>>0>65535>>>0;la=ma?W>>>16:W;W=ma?16:0;if((la&65280|0)==0){Sa=W;Ta=la}else{Sa=W|8;Ta=la>>>8}la=(d[1191992+Ta|0]|0)+Sa|0;W=31-la+Oa|0;ma=X>>>0>W>>>0?W:X;W=ja+(ma>>>3)|0;ja=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(ma&7)>>>(la>>>0);W=ma+(32-la)|0;c[I>>2]=X>>>0>W>>>0?W:X;X=ja>>>1;Ra=((ja&1|0)==0?X:-X|0)&65535}b[f+3268+(ha<<1)>>1]=Ra}if((a[l+ha|0]|0)==0){X=1<<b[wa>>1]&65535;b[f+3108+(ha<<2)>>1]=X;b[f+3300+(ha<<2)>>1]=0;b[f+3108+(ha<<2)+2>>1]=X;b[f+3300+(ha<<2)+2>>1]=0}else{X=c[M>>2]|0;ja=c[K>>2]|0;W=0;la=c[I>>2]|0;while(1){ma=ja+(la>>>3)|0;P=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7);if(P>>>0>134217727>>>0){ma=P>>>23;ga=(d[1213744+ma|0]|0)+la|0;za=X>>>0>ga>>>0?ga:X;c[I>>2]=za;Ua=a[1139096+ma|0]|0;Va=za}else{za=P>>>0>65535>>>0;ma=za?P>>>16:P;P=za?16:0;if((ma&65280|0)==0){Wa=P;Xa=ma}else{Wa=P|8;Xa=ma>>>8}ma=(d[1191992+Xa|0]|0)+Wa|0;P=31-ma+la|0;za=X>>>0>P>>>0?P:X;P=ja+(za>>>3)|0;ga=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(za&7)>>>(ma>>>0);P=za+(32-ma)|0;ma=X>>>0>P>>>0?P:X;c[I>>2]=ma;P=ga>>>1;Ua=(ga&1|0)==0?P:-P|0;Va=ma}ma=ja+(Va>>>3)|0;P=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(Va&7);if(P>>>0>134217727>>>0){ma=P>>>23;ga=(d[1213744+ma|0]|0)+Va|0;za=X>>>0>ga>>>0?ga:X;c[I>>2]=za;Ya=a[1139096+ma|0]|0;Za=za}else{za=P>>>0>65535>>>0;ma=za?P>>>16:P;P=za?16:0;if((ma&65280|0)==0){_a=P;$a=ma}else{_a=P|8;$a=ma>>>8}ma=(d[1191992+$a|0]|0)+_a|0;P=31-ma+Va|0;za=X>>>0>P>>>0?P:X;P=ja+(za>>>3)|0;ga=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(za&7)>>>(ma>>>0);P=za+(32-ma)|0;ma=X>>>0>P>>>0?P:X;c[I>>2]=ma;P=ga>>>1;Ya=(ga&1|0)==0?P:-P|0;Za=ma}ma=(1<<b[wa>>1])+Ua&65535;b[f+3108+(ha<<2)+(W<<1)>>1]=ma;P=Ya-(ma<<16>>16<<7>>b[wa>>1])+128|0;if((P|0)<-128){ab=-128}else{ab=(P|0)>127?127:P&65535}b[f+3300+(ha<<2)+(W<<1)>>1]=ab;P=W+1|0;if((P|0)<2){W=P;la=Za}else{break}}}ha=ha+1|0;}while(ha>>>0<(c[$>>2]|0)>>>0)}}while(0);if((c[U>>2]|0)!=0){break}if((c[T>>2]|0)==0){bb=0}else{ha=c[K>>2]|0;wa=c[M>>2]|0;la=0;W=c[I>>2]|0;while(1){X=d[ha+(W>>>3)|0]<<(W&7)>>>7;ja=((W|0)<(wa|0))+W|0;c[I>>2]=ja;P=X&1;a[m+la|0]=P;if(P<<24>>24==0){b[f+3236+(la<<1)>>1]=1<<d[ia];b[f+3364+(la<<1)>>1]=0}P=la+1|0;X=c[T>>2]|0;if(P>>>0<X>>>0){la=P;W=ja}else{bb=X;break}}}W=(bb|0)==0;if((c[(c[J>>2]|0)+4>>2]|0)==0){if(W){break}TGb(_|0,0,(bb>>>0>1>>>0?bb:1)|0)|0;cb=bb}else{if(W){break}W=c[K>>2]|0;la=c[M>>2]|0;wa=0;ha=c[I>>2]|0;while(1){X=d[W+(ha>>>3)|0]<<(ha&7)>>>7;ja=((ha|0)<(la|0))+ha|0;c[I>>2]=ja;a[n+wa|0]=X&1;X=wa+1|0;P=c[T>>2]|0;if(X>>>0<P>>>0){wa=X;ha=ja}else{cb=P;break}}}if((cb|0)==0){break}ha=f+3074|0;wa=0;do{if((a[m+wa|0]|0)!=0){la=c[I>>2]|0;W=c[M>>2]|0;_=c[K>>2]|0;P=_+(la>>>3)|0;ja=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(la&7);if(ja>>>0>134217727>>>0){P=ja>>>23;X=(d[1213744+P|0]|0)+la|0;ma=W>>>0>X>>>0?X:W;c[I>>2]=ma;db=a[1139096+P|0]|0;eb=ma}else{ma=ja>>>0>65535>>>0;P=ma?ja>>>16:ja;ja=ma?16:0;if((P&65280|0)==0){fb=ja;gb=P}else{fb=ja|8;gb=P>>>8}P=(d[1191992+gb|0]|0)+fb|0;ja=31-P+la|0;la=W>>>0>ja>>>0?ja:W;ja=_+(la>>>3)|0;ma=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(la&7)>>>(P>>>0);ja=la+(32-P)|0;P=W>>>0>ja>>>0?ja:W;c[I>>2]=P;ja=ma>>>1;db=(ma&1|0)==0?ja:-ja|0;eb=P}b[f+3236+(wa<<1)>>1]=(1<<d[ia])+db;P=_+(eb>>>3)|0;ja=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(eb&7);if(ja>>>0>134217727>>>0){P=ja>>>23;ma=(d[1213744+P|0]|0)+eb|0;c[I>>2]=W>>>0>ma>>>0?ma:W;hb=a[1139096+P|0]|0}else{P=ja>>>0>65535>>>0;ma=P?ja>>>16:ja;ja=P?16:0;if((ma&65280|0)==0){ib=ja;jb=ma}else{ib=ja|8;jb=ma>>>8}ma=(d[1191992+jb|0]|0)+ib|0;ja=31-ma+eb|0;P=W>>>0>ja>>>0?ja:W;ja=_+(P>>>3)|0;_=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(P&7)>>>(ma>>>0);ja=P+(32-ma)|0;c[I>>2]=W>>>0>ja>>>0?ja:W;W=_>>>1;hb=((_&1|0)==0?W:-W|0)&65535}b[f+3364+(wa<<1)>>1]=hb}if((a[n+wa|0]|0)==0){W=1<<b[ha>>1]&65535;b[f+3172+(wa<<2)>>1]=W;b[f+3396+(wa<<2)>>1]=0;b[f+3172+(wa<<2)+2>>1]=W;b[f+3396+(wa<<2)+2>>1]=0}else{W=c[M>>2]|0;_=c[K>>2]|0;ja=0;ma=c[I>>2]|0;while(1){P=_+(ma>>>3)|0;la=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(ma&7);if(la>>>0>134217727>>>0){P=la>>>23;X=(d[1213744+P|0]|0)+ma|0;ga=W>>>0>X>>>0?X:W;c[I>>2]=ga;kb=a[1139096+P|0]|0;lb=ga}else{ga=la>>>0>65535>>>0;P=ga?la>>>16:la;la=ga?16:0;if((P&65280|0)==0){mb=la;nb=P}else{mb=la|8;nb=P>>>8}P=(d[1191992+nb|0]|0)+mb|0;la=31-P+ma|0;ga=W>>>0>la>>>0?la:W;la=_+(ga>>>3)|0;X=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ga&7)>>>(P>>>0);la=ga+(32-P)|0;P=W>>>0>la>>>0?la:W;c[I>>2]=P;la=X>>>1;kb=(X&1|0)==0?la:-la|0;lb=P}P=_+(lb>>>3)|0;la=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(lb&7);if(la>>>0>134217727>>>0){P=la>>>23;X=(d[1213744+P|0]|0)+lb|0;ga=W>>>0>X>>>0?X:W;c[I>>2]=ga;ob=a[1139096+P|0]|0;pb=ga}else{ga=la>>>0>65535>>>0;P=ga?la>>>16:la;la=ga?16:0;if((P&65280|0)==0){qb=la;rb=P}else{qb=la|8;rb=P>>>8}P=(d[1191992+rb|0]|0)+qb|0;la=31-P+lb|0;ga=W>>>0>la>>>0?la:W;la=_+(ga>>>3)|0;X=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ga&7)>>>(P>>>0);la=ga+(32-P)|0;P=W>>>0>la>>>0?la:W;c[I>>2]=P;la=X>>>1;ob=(X&1|0)==0?la:-la|0;pb=P}P=(1<<b[ha>>1])+kb&65535;b[f+3172+(wa<<2)+(ja<<1)>>1]=P;la=ob-(P<<16>>16<<7>>b[ha>>1])+128|0;if((la|0)<-128){sb=-128}else{sb=(la|0)>127?127:la&65535}b[f+3396+(wa<<2)+(ja<<1)>>1]=sb;la=ja+1|0;if((la|0)<2){ja=la;ma=pb}else{break}}}wa=wa+1|0;}while(wa>>>0<(c[T>>2]|0)>>>0)}}while(0);wa=KAa(z)|0;ha=5-wa|0;c[f+3052>>2]=ha;if(!((wa|0)==5|ha>>>0>5>>>0)){break}yDb(c[A>>2]|0,16,2093752,(G=i,i=i+8|0,c[G>>2]=ha,G)|0);i=G;w=-1094995529;i=j;return w|0}}while(0);T=c[I>>2]|0;U=c[M>>2]|0;$=c[K>>2]|0;V=$+(T>>>3)|0;ha=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7);if(ha>>>0>134217727>>>0){V=ha>>>23;wa=(d[1213744+V|0]|0)+T|0;c[I>>2]=U>>>0>wa>>>0?wa:U;tb=a[1139096+V|0]|0}else{V=ha>>>0>65535>>>0;wa=V?ha>>>16:ha;ha=V?16:0;if((wa&65280|0)==0){ub=ha;vb=wa}else{ub=ha|8;vb=wa>>>8}wa=(d[1191992+vb|0]|0)+ub|0;ha=31-wa+T|0;T=U>>>0>ha>>>0?ha:U;ha=$+(T>>>3)|0;V=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(T&7)>>>(wa>>>0);ha=T+(32-wa)|0;c[I>>2]=U>>>0>ha>>>0?ha:U;U=V>>>1;tb=(V&1|0)==0?U:-U|0}c[f+3032>>2]=tb;U=c[R>>2]|0;if((a[U+36|0]|0)==0){c[f+3036>>2]=0;c[f+3040>>2]=0}else{V=c[I>>2]|0;ha=c[M>>2]|0;wa=$+(V>>>3)|0;T=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(V&7);if(T>>>0>134217727>>>0){wa=T>>>23;ia=(d[1213744+wa|0]|0)+V|0;c[I>>2]=ha>>>0>ia>>>0?ia:ha;wb=a[1139096+wa|0]|0}else{wa=T>>>0>65535>>>0;ia=wa?T>>>16:T;T=wa?16:0;if((ia&65280|0)==0){xb=T;yb=ia}else{xb=T|8;yb=ia>>>8}ia=(d[1191992+yb|0]|0)+xb|0;T=31-ia+V|0;V=ha>>>0>T>>>0?T:ha;T=$+(V>>>3)|0;wa=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(V&7)>>>(ia>>>0);T=V+(32-ia)|0;c[I>>2]=ha>>>0>T>>>0?T:ha;ha=wa>>>1;wb=(wa&1|0)==0?ha:-ha|0}c[f+3036>>2]=wb;ha=c[I>>2]|0;wa=c[M>>2]|0;T=$+(ha>>>3)|0;ia=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(ha&7);if(ia>>>0>134217727>>>0){T=ia>>>23;V=(d[1213744+T|0]|0)+ha|0;c[I>>2]=wa>>>0>V>>>0?V:wa;zb=a[1139096+T|0]|0}else{T=ia>>>0>65535>>>0;V=T?ia>>>16:ia;ia=T?16:0;if((V&65280|0)==0){Ab=ia;Bb=V}else{Ab=ia|8;Bb=V>>>8}V=(d[1191992+Bb|0]|0)+Ab|0;ia=31-V+ha|0;ha=wa>>>0>ia>>>0?ia:wa;ia=$+(ha>>>3)|0;T=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(ha&7)>>>(V>>>0);ia=ha+(32-V)|0;c[I>>2]=wa>>>0>ia>>>0?ia:wa;wa=T>>>1;zb=(T&1|0)==0?wa:-wa|0}c[f+3040>>2]=zb}d:do{if((a[U+55|0]|0)==0){a[f+3025|0]=0;c[f+3044>>2]=0;c[f+3048>>2]=0}else{do{if((a[U+56|0]|0)!=0){wa=c[I>>2]|0;T=d[$+(wa>>>3)|0]|0;ia=c[M>>2]|0;V=((wa|0)<(ia|0))+wa|0;c[I>>2]=V;if((T&128>>>((wa&7)>>>0)|0)==0){break}wa=d[$+(V>>>3)|0]<<(V&7)>>>7;c[I>>2]=((V|0)<(ia|0))+V;V=wa&1;a[f+3025|0]=V;if(!(V<<24>>24==0)){break d}V=c[I>>2]|0;wa=c[M>>2]|0;ia=c[K>>2]|0;T=ia+(V>>>3)|0;ha=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(V&7);if(ha>>>0>134217727>>>0){T=ha>>>23;ma=(d[1213744+T|0]|0)+V|0;c[I>>2]=wa>>>0>ma>>>0?ma:wa;Cb=a[1139096+T|0]|0}else{T=ha>>>0>65535>>>0;ma=T?ha>>>16:ha;ha=T?16:0;if((ma&65280|0)==0){Db=ha;Eb=ma}else{Db=ha|8;Eb=ma>>>8}ma=(d[1191992+Eb|0]|0)+Db|0;ha=31-ma+V|0;V=wa>>>0>ha>>>0?ha:wa;ha=ia+(V>>>3)|0;T=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(V&7)>>>(ma>>>0);ha=V+(32-ma)|0;c[I>>2]=wa>>>0>ha>>>0?ha:wa;wa=T>>>1;Cb=(T&1|0)==0?wa:-wa|0}c[f+3044>>2]=Cb<<1;wa=c[I>>2]|0;T=c[M>>2]|0;ha=ia+(wa>>>3)|0;ma=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(wa&7);if(ma>>>0>134217727>>>0){ha=ma>>>23;V=(d[1213744+ha|0]|0)+wa|0;c[I>>2]=T>>>0>V>>>0?V:T;Fb=a[1139096+ha|0]|0}else{ha=ma>>>0>65535>>>0;V=ha?ma>>>16:ma;ma=ha?16:0;if((V&65280|0)==0){Gb=ma;Hb=V}else{Gb=ma|8;Hb=V>>>8}V=(d[1191992+Hb|0]|0)+Gb|0;ma=31-V+wa|0;wa=T>>>0>ma>>>0?ma:T;ma=ia+(wa>>>3)|0;ia=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(wa&7)>>>(V>>>0);ma=wa+(32-V)|0;c[I>>2]=T>>>0>ma>>>0?ma:T;T=ia>>>1;Fb=(ia&1|0)==0?T:-T|0}c[f+3048>>2]=Fb<<1;break d}}while(0);a[f+3025|0]=a[U+57|0]|0;c[f+3044>>2]=c[U+60>>2];c[f+3048>>2]=c[U+64>>2]}}while(0);$=a[U+54|0]|0;e:do{if(!($<<24>>24==0)){do{if((a[f+3020|0]|0)==0){if((a[f+3021|0]|0)!=0){break}if((a[f+3025|0]|0)!=0){break e}}}while(0);T=c[I>>2]|0;ia=d[(c[K>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[I>>2]=((T|0)<(c[M>>2]|0))+T;a[f+3026|0]=ia&1;ca=aa;da=U;break b}}while(0);a[f+3026|0]=$;ca=aa;da=U}}while(0);ia=f+3068|0;c[ia>>2]=0;if((a[da+42|0]|0)==0){if((a[da+43|0]|0)!=0){F=275}}else{F=275}f:do{if((F|0)==275){T=KAa(z)|0;c[ia>>2]=T;if((T|0)<=0){c[f+7372>>2]=0;break}T=(KAa(z)|0)+1|0;ma=T>>4;V=T&15;T=f+3056|0;$Db(T);wa=f+3060|0;$Db(wa);ha=f+3064|0;$Db(ha);c[T>>2]=WDb(c[ia>>2]<<2)|0;c[wa>>2]=WDb(c[ia>>2]<<2)|0;ja=WDb(c[ia>>2]<<2)|0;c[ha>>2]=ja;ha=c[T>>2]|0;do{if((ha|0)!=0){if((c[wa>>2]|0)==0|(ja|0)==0){break}g:do{if((c[ia>>2]|0)>0){T=(V|0)==0;W=32-V|0;if((ma|0)<=0){if(T){_=0;while(1){c[ha+(_<<2)>>2]=1;_=_+1|0;if((_|0)>=(c[ia>>2]|0)){break g}}}_=c[K>>2]|0;la=0;while(1){P=c[I>>2]|0;X=c[M>>2]|0;ga=_+(P>>>3)|0;za=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(P&7)>>>(W>>>0);ga=P+V|0;c[I>>2]=X>>>0>ga>>>0?ga:X;c[ha+(la<<2)>>2]=za+1;la=la+1|0;if((la|0)>=(c[ia>>2]|0)){break g}}}la=(ma|0)>1;_=c[K>>2]|0;za=0;do{X=c[I>>2]|0;ga=c[M>>2]|0;P=_+(X>>>3)|0;Aa=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(X&7)>>>16;P=X+16|0;X=ga>>>0>P>>>0?P:ga;c[I>>2]=X;if(la){P=1;Ba=Aa;Ib=X;while(1){Jb=P+1|0;Kb=_+(Ib>>>3)|0;Lb=(fe(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(Ib&7)>>>16;Kb=Ib+16|0;Mb=ga>>>0>Kb>>>0?Kb:ga;c[I>>2]=Mb;if((Jb|0)<(ma|0)){P=Jb;Ba=Lb;Ib=Mb}else{break}}Nb=Ba<<16;Ob=Lb;Pb=Mb}else{Nb=0;Ob=Aa;Pb=X}Ib=Ob|Nb;if(T){Qb=Ib}else{P=_+(Pb>>>3)|0;Jb=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Pb&7)>>>(W>>>0);P=Pb+V|0;c[I>>2]=ga>>>0>P>>>0?P:ga;Qb=Jb+(Ib<<V)|0}c[ha+(za<<2)>>2]=Qb+1;za=za+1|0;}while((za|0)<(c[ia>>2]|0))}}while(0);za=f+141|0;do{if((d[za]|0)>>>0>1>>>0){W=c[R>>2]|0;if((c[W+48>>2]|0)<=1){if((c[W+44>>2]|0)<=1){break}}c[f+7372>>2]=0;a[za]=1;break f}}while(0);c[f+7372>>2]=0;break f}}while(0);c[ia>>2]=0;yDb(c[A>>2]|0,16,2083824,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-12;i=j;return w|0}}while(0);ha=c[R>>2]|0;if((a[ha+1628|0]|0)==0){Rb=ha}else{ha=KAa(z)|0;if((ha|0)!=0){V=c[M>>2]|0;ma=0;ja=c[I>>2]|0;do{wa=ja+8|0;ja=V>>>0>wa>>>0?wa:V;ma=ma+1|0;}while(ma>>>0<ha>>>0);c[I>>2]=ja}Rb=c[R>>2]|0}ha=(c[Rb+16>>2]|0)+26+(c[f+3032>>2]|0)&255;ma=f+3072|0;a[ma]=ha;do{if(ha<<24>>24>51){Sb=c[(c[J>>2]|0)+13164>>2]|0;Tb=ha<<24>>24}else{V=ha<<24>>24;wa=c[(c[J>>2]|0)+13164>>2]|0;if((V|0)<(-wa|0)){Sb=wa;Tb=V;break}V=c[f+2396>>2]|0;c[f+3460>>2]=V;wa=(a[O]|0)==0;do{if((V|0)==0){if(wa){Ub=1;break}yDb(c[A>>2]|0,16,2073416,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}else{Ub=wa&1}}while(0);a[(c[q>>2]|0)+9271|0]=Ub;if((a[(c[R>>2]|0)+22|0]|0)==0){a[(c[q>>2]|0)+173182|0]=a[ma]|0}a[ca]=1;wa=f+5804|0;V=c[wa>>2]|0;U=c[y>>2]|0;h:do{if((V|0)==2147483647){switch(U|0){case 21:case 17:case 16:case 18:{$=c[f+5788>>2]|0;c[wa>>2]=$;Vb=$;break h;break};case 19:case 20:{c[wa>>2]=-2147483648;Vb=-2147483648;break h;break};default:{Vb=2147483647;break h}}}else{Vb=V}}while(0);do{if((U-8|0)>>>0<2>>>0){if((c[f+5788>>2]|0)>(Vb|0)){if((U|0)!=9){break}c[wa>>2]=-2147483648;break}else{c[f+5816>>2]=0;w=0;i=j;return w|0}}}while(0);i:do{if((a[L]|0)==0){if((c[f+3480>>2]|0)==0){yDb(c[A>>2]|0,16,2273568,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=0;break a}else{Wb=f+7420|0;break}}else{wa=c[q>>2]|0;U=c[J>>2]|0;V=c[U+13064>>2]|0;$=c[U+13096>>2]>>V;za=(c[U+13100>>2]>>V)+1|0;V=f+5808|0;U=f+5812|0;TGb(c[f+7324>>2]|0,0,ba(c[V>>2]<<1,(c[U>>2]|0)+1|0)|0)|0;TGb(c[f+7328>>2]|0,0,ba(c[V>>2]<<1,(c[U>>2]|0)+1|0)|0)|0;U=c[J>>2]|0;TGb(c[f+7348>>2]|0,0,ba(c[U+13128>>2]|0,c[U+13124>>2]|0)|0)|0;U=c[J>>2]|0;TGb(c[f+7352>>2]|0,0,ba(c[U+13136>>2]|0,c[U+13132>>2]|0)|0)|0;TGb(c[f+7332>>2]|0,-1|0,ba(($<<2)+4|0,za)|0)|0;c[f+5816>>2]=0;za=f+7420|0;c[za>>2]=c[y>>2];$=c[f+184>>2]|0;if((a[$+42|0]|0)==0){Xb=c[J>>2]|0}else{U=c[J>>2]|0;c[wa+173204>>2]=c[c[$+1632>>2]>>2]<<c[U+13080>>2];Xb=U}U=UBa(f,(a[Xb+12941|0]|0)!=0?f+164|0:f+160|0,c[f+5788>>2]|0)|0;j:do{if((U|0)<0){Yb=U}else{$=YBa(f)|0;if(($|0)<0){yDb(c[A>>2]|0,16,2192512,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Yb=$;break}$=c[c[f+3480>>2]>>2]|0;do{if((c[f+7496>>2]|0)!=0){wa=f+7500|0;if(!(((c[wa>>2]|0)-3|0)>>>0<3>>>0)){break}V=f+7504|0;if(!(((c[V>>2]|0)-1|0)>>>0<2>>>0)){break}W=VFb($)|0;if((W|0)==0){Yb=-12;break j}_=c[wa>>2]|0;do{if((_|0)==3){wa=W|0;if((c[f+7508>>2]|0)==0){c[wa>>2]=1;break}else{c[wa>>2]=5;break}}else if((_|0)==4){c[W>>2]=2}else if((_|0)==5){c[W>>2]=3}}while(0);if((c[V>>2]|0)!=2){break}c[W+4>>2]=1}}while(0);$=f+172|0;KCb(c[$>>2]|0);_=WBa(f,c[$>>2]|0,0)|0;if((_|0)<0){Yb=_;break}X0a(c[A>>2]|0);Wb=za;break i}}while(0);U=f+3480|0;_=c[U>>2]|0;do{if((_|0)!=0){if((a[f+140|0]|0)!=1){break}Y0a(_+4|0,2147483647,0)}}while(0);c[U>>2]=0;if((Yb|0)<0){w=Yb}else{Wb=za;break}i=j;return w|0}}while(0);_=c[y>>2]|0;$=c[Wb>>2]|0;if((_|0)!=($|0)){yDb(c[A>>2]|0,16,2257960,(G=i,i=i+16|0,c[G>>2]=$,c[G+8>>2]=_,G)|0);i=G;w=-1094995529;i=j;return w|0}do{if((a[O]|0)==0){if((c[f+2404>>2]|0)==2){break}_=XBa(f)|0;if((_|0)>=0){break}yDb(c[A>>2]|0,24,2243656,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=_;break a}}while(0);_=f+141|0;do{if((d[_]|0)>>>0>1>>>0){$=c[ia>>2]|0;if(($|0)<=0){F=390;break}ga=c[q>>2]|0;X=WDb(($<<2)+4|0)|0;$=X;Aa=WDb((c[ia>>2]<<2)+4|0)|0;Ba=Aa;do{if((c[f+12>>2]|0)==0){$0a(c[A>>2]|0,(c[ia>>2]|0)+1|0)|0;if(!((d[_]|0)>>>0>1>>>0)){break}wa=f;T=1;do{la=WDb(7516)|0;Ib=f+8+(T<<2)|0;c[Ib>>2]=la;UGb(la|0,wa|0,7516)|0;la=WDb(184672)|0;c[f+72+(T<<2)>>2]=la;c[(c[Ib>>2]|0)+136>>2]=la;T=T+1|0;}while((T|0)<(d[_]|0))}}while(0);za=c[ga+9280>>2]>>3;U=f+3056|0;T=f+7380|0;wa=c[T>>2]|0;if((wa|0)>0){la=c[f+7384>>2]|0;Ib=(c[c[U>>2]>>2]|0)+za|0;Jb=0;P=0;while(1){Kb=c[la+(P<<2)>>2]|0;if((Kb|0)>=(za|0)&(Kb|0)<(Ib|0)){Zb=Jb+1|0;_b=Ib-1|0}else{Zb=Jb;_b=Ib}Kb=P+1|0;if((Kb|0)<(wa|0)){Ib=_b;Jb=Zb;P=Kb}else{$b=Zb;break}}}else{$b=0}P=c[ia>>2]|0;k:do{if((P|0)>1){Jb=c[U>>2]|0;Ib=c[f+3064>>2]|0;la=c[f+3060>>2]|0;ga=f+7384|0;Kb=za;ac=$b;bc=1;cc=wa;while(1){dc=bc-1|0;ec=(c[Jb+(dc<<2)>>2]|0)-ac+Kb|0;fc=c[Jb+(bc<<2)>>2]|0;if((cc|0)>0){gc=c[ga>>2]|0;hc=ec+fc|0;ic=0;jc=0;while(1){kc=c[gc+(jc<<2)>>2]|0;if((kc|0)>=(ec|0)&(kc|0)<(hc|0)){lc=ic+1|0;mc=hc-1|0}else{lc=ic;mc=hc}kc=jc+1|0;if((kc|0)<(cc|0)){hc=mc;ic=lc;jc=kc}else{nc=lc;break}}}else{nc=0}c[Ib+(dc<<2)>>2]=fc-nc;c[la+(dc<<2)>>2]=ec;jc=bc+1|0;ic=c[ia>>2]|0;if((jc|0)>=(ic|0)){oc=ec;pc=nc;qc=ic;break k}Kb=ec;ac=nc;bc=jc;cc=c[T>>2]|0}}else{oc=za;pc=$b;qc=P}}while(0);if((qc|0)!=0){P=qc-1|0;za=(c[(c[U>>2]|0)+(P<<2)>>2]|0)-pc+oc|0;c[(c[f+3064>>2]|0)+(P<<2)>>2]=h-za;c[(c[f+3060>>2]|0)+((c[ia>>2]|0)-1<<2)>>2]=za}c[f+7404>>2]=g;if((d[_]|0)>>>0>1>>>0){za=f+8|0;P=f;T=1;do{wa=f+8+(T<<2)|0;a[(c[(c[wa>>2]|0)+136>>2]|0)+9271|0]=1;a[(c[(c[wa>>2]|0)+136>>2]|0)+173182|0]=a[(c[(c[za>>2]|0)+136>>2]|0)+173182|0]|0;UGb(c[wa>>2]|0,P|0,7516)|0;c[(c[wa>>2]|0)+136>>2]=c[f+72+(T<<2)>>2];T=T+1|0;}while((T|0)<(d[_]|0))}c[f+7376>>2]=0;a1a(c[A>>2]|0);T=c[ia>>2]|0;if((T|0)>=0){TGb(X|0,0,((T|0)>0?(T<<2)+4|0:4)|0)|0;P=0;do{c[Ba+(P<<2)>>2]=P;P=P+1|0;}while((P|0)<=(T|0))}if((a[(c[f+184>>2]|0)+43|0]|0)==0){rc=T}else{P=c[A>>2]|0;Pe[c[P+828>>2]&255](P,384,Aa,$,T+1|0)|0;rc=c[ia>>2]|0}if((rc|0)<0){sc=0}else{P=0;Ba=0;while(1){za=(c[$+(P<<2)>>2]|0)+Ba|0;U=P+1|0;if((U|0)>(rc|0)){sc=za;break}else{P=U;Ba=za}}}ZDb(X);ZDb(Aa);tc=sc}else{F=390}}while(0);if((F|0)==390){_=c[A>>2]|0;c[o>>2]=0;c[o+4>>2]=1;Ba=p|0;oe[c[_+824>>2]&63](_,126,o,Ba,1,4)|0;tc=c[Ba>>2]|0}Ba=c[J>>2]|0;do{if((tc|0)>=(ba(c[Ba+13108>>2]|0,c[Ba+13104>>2]|0)|0)){c[f+5816>>2]=1;if((a[(c[f+184>>2]|0)+40|0]|0)==0){if((a[Ba+13056|0]|0)==0){break}if((c[Ba+68>>2]|0)==0){break}}if((a[Ba+12941|0]|0)==0){break}_=1<<c[Ba+13084>>2];P=f+160|0;$=f+7352|0;T=f+164|0;za=0;U=Ba;while(1){wa=c[(c[P>>2]|0)+32+(za<<2)>>2]|0;cc=c[U+13140+(za<<2)>>2]|0;bc=c[U+13152+(za<<2)>>2]|0;if((c[U+13136>>2]|0)>0){ac=_>>cc;Kb=_>>bc;la=(Kb|0)>0;Ib=0;ga=U;while(1){Jb=c[ga+13132>>2]|0;if((Jb|0)>0){jc=0;ic=ga;hc=Jb;while(1){Jb=jc+(ba(hc,Ib)|0)|0;do{if((a[(c[$>>2]|0)+Jb|0]|0)==0){uc=ic}else{gc=c[ic+13084>>2]|0;W=ba(Ib<<gc>>bc,wa)|0;V=W+(jc<<gc>>cc<<c[ic+56>>2])|0;if(!la){uc=ic;break}gc=0;W=(c[(c[P>>2]|0)+(za<<2)>>2]|0)+V|0;kc=(c[(c[T>>2]|0)+(za<<2)>>2]|0)+V|0;while(1){UGb(kc|0,W|0,ac)|0;V=gc+1|0;if((V|0)<(Kb|0)){gc=V;W=W+wa|0;kc=kc+wa|0}else{break}}uc=c[J>>2]|0}}while(0);Jb=jc+1|0;kc=c[uc+13132>>2]|0;if((Jb|0)<(kc|0)){jc=Jb;ic=uc;hc=kc}else{vc=uc;break}}}else{vc=ga}hc=Ib+1|0;if((hc|0)<(c[vc+13136>>2]|0)){Ib=hc;ga=vc}else{wc=vc;break}}}else{wc=U}ga=za+1|0;if((ga|0)<3){za=ga;U=wc}else{break}}}}while(0);if((tc|0)<0){H=tc;break a}else{w=0}i=j;return w|0}}while(0);yDb(c[A>>2]|0,16,2078328,(G=i,i=i+16|0,c[G>>2]=Tb,c[G+8>>2]=-Sb,G)|0);i=G;w=-1094995529;i=j;return w|0}}while(0);yDb(c[A>>2]|0,16,2176216,(G=i,i=i+8|0,c[G>>2]=B,G)|0);i=G;w=-1094995529;i=j;return w|0};case 33:{y=KBa(f)|0;if((y|0)<0){H=y;break a}else{w=0}i=j;return w|0};case 39:case 40:{y=aCa(f)|0;if((y|0)<0){H=y;break a}else{w=0}i=j;return w|0};case 35:case 38:{w=0;i=j;return w|0};case 34:{y=MBa(f)|0;if((y|0)<0){H=y;break a}else{w=0}i=j;return w|0};default:{yDb(c[A>>2]|0,32,2231176,(G=i,i=i+8|0,c[G>>2]=C,G)|0);i=G;w=0;i=j;return w|0}}}else{E=c[f+3472>>2]|0;F=6}}while(0);if((F|0)==6){yDb(c[f+4>>2]|0,16,2289560,(G=i,i=i+8|0,c[G>>2]=E,G)|0);i=G;H=-1094995529}w=(c[(c[f+4>>2]|0)+696>>2]&8|0)==0?0:H;i=j;return w|0}function BAa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;e=c[b+60>>2]|0;b=e;f=e+180|0;g=c[f>>2]|0;h=1<<c[g+13080>>2];j=e+184|0;k=c[j>>2]|0;l=c[(c[k+1652>>2]|0)+(c[e+3460>>2]<<2)>>2]|0;m=(a[e+2413|0]|0)==0;do{if((l|0)==0){if(m){break}yDb(c[e+4>>2]|0,16,2219088,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=d;return o|0}else{if(m){break}if((c[(c[e+7332>>2]|0)+(c[(c[k+1656>>2]|0)+(l-1<<2)>>2]<<2)>>2]|0)==(c[e+2400>>2]|0)){break}yDb(c[e+4>>2]|0,16,2209728,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=d;return o|0}}while(0);n=h-1|0;k=e+3044|0;m=e+3468|0;p=e+3048|0;q=e+3026|0;r=e+7356|0;s=0;t=0;u=l;l=g;while(1){if((u|0)>=(c[l+13112>>2]|0)){v=s;w=t;x=u;y=l;break}z=c[(c[(c[j>>2]|0)+1656>>2]|0)+(u<<2)>>2]|0;g=c[l+13080>>2]|0;A=n+(c[l+13096>>2]|0)>>g;B=((z|0)%(A|0)|0)<<g;C=((z|0)/(A|0)|0)<<g;CAa(b,B,C,u);OAa(b,u);g=c[(c[f>>2]|0)+13080>>2]|0;DAa(b,B>>g,C>>g);g=c[m>>2]|0;c[g+(z<<3)>>2]=c[k>>2];c[g+(z<<3)+4>>2]=c[p>>2];a[(c[r>>2]|0)+z|0]=a[q]|0;D=EAa(b,B,C,c[(c[f>>2]|0)+13080>>2]|0,0)|0;if((D|0)<0){E=10;break}g=u+1|0;NAa(b,g);wBa(b,B,C,h);A=c[f>>2]|0;if((D|0)==0){v=B;w=C;x=g;y=A;break}else{s=B;t=C;u=g;l=A}}if((E|0)==10){c[(c[e+7332>>2]|0)+(z<<2)>>2]=-1;o=D;i=d;return o|0}if((v+h|0)<(c[y+13096>>2]|0)){o=x;i=d;return o|0}if((w+h|0)<(c[y+13100>>2]|0)){o=x;i=d;return o|0}vBa(b,v,w);o=x;i=d;return o|0}function CAa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=c[b+136>>2]|0;h=b+180|0;i=c[h>>2]|0;j=i+13080|0;k=1<<c[j>>2];l=b+184|0;m=c[l>>2]|0;n=c[(c[m+1656>>2]|0)+(f<<2)>>2]|0;o=c[b+2400>>2]|0;p=n-o|0;q=b+7332|0;c[(c[q>>2]|0)+(n<<2)>>2]=o;do{if((a[m+43|0]|0)==0){if((a[m+42|0]|0)==0){c[g+173204>>2]=c[i+13096>>2];r=i;break}if((f|0)==0){r=i;break}o=c[m+1660>>2]|0;if((c[o+(f<<2)>>2]|0)==(c[o+(f-1<<2)>>2]|0)){r=i;break}o=c[j>>2]|0;c[g+173204>>2]=(c[(c[m+1632>>2]|0)+(c[(c[m+1648>>2]|0)+(d>>o<<2)>>2]<<2)>>2]<<o)+d;a[g+9271|0]=1;r=c[h>>2]|0}else{do{if((d|0)==0){if((k-1&e|0)!=0){s=i;break}a[g+9271|0]=1;s=c[h>>2]|0}else{s=i}}while(0);c[g+173204>>2]=c[s+13096>>2];r=s}}while(0);s=k+e|0;k=c[r+13100>>2]|0;c[g+173208>>2]=(s|0)>(k|0)?k:s;s=c[l>>2]|0;do{if((a[s+42|0]|0)==0){t=0;u=(p|0)<(c[r+13104>>2]|0);v=(p|0)<1;w=0}else{if((d|0)>0){k=c[s+1660>>2]|0;i=n-1|0;m=c[q>>2]|0;x=(c[m+(n<<2)>>2]|0)!=(c[m+(i<<2)>>2]|0);y=(c[k+(f<<2)>>2]|0)!=(c[k+(c[(c[s+1652>>2]|0)+(i<<2)>>2]<<2)>>2]|0)|0}else{x=0;y=0}if((e|0)<=0){t=y;u=0;v=x;w=0;break}i=c[s+1660>>2]|0;k=n-(c[r+13104>>2]|0)|0;m=c[q>>2]|0;t=y;u=(c[m+(n<<2)>>2]|0)!=(c[m+(k<<2)>>2]|0);v=x;w=(c[i+(f<<2)>>2]|0)!=(c[i+(c[(c[s+1652>>2]|0)+(k<<2)>>2]<<2)>>2]|0)|0}}while(0);a[g+184648|0]=t<<1|v&1;a[g+184649|0]=u&1|w<<1;u=(d|0)>0;if(u&(p|0)>0){z=(t^1)&255}else{z=0}a[g+173200|0]=z;if((e|0)<=0){a[g+173201|0]=0;a[g+173202|0]=0;A=0;B=g+173203|0;a[B]=A;return}if((p|0)<(c[(c[h>>2]|0)+13104>>2]|0)){C=0}else{C=(w^1)&255}a[g+173201|0]=C;C=c[(c[h>>2]|0)+13104>>2]|0;if((p+1|0)<(C|0)){D=0}else{w=c[l>>2]|0;e=c[w+1660>>2]|0;D=(c[e+(f<<2)>>2]|0)==(c[e+(c[(c[w+1652>>2]|0)+(n+1-C<<2)>>2]<<2)>>2]|0)|0}a[g+173202|0]=D;if(!u){A=0;B=g+173203|0;a[B]=A;return}u=c[(c[h>>2]|0)+13104>>2]|0;if((p-1|0)<(u|0)){A=0;B=g+173203|0;a[B]=A;return}p=c[l>>2]|0;l=c[p+1660>>2]|0;A=(c[l+(f<<2)>>2]|0)==(c[l+(c[(c[p+1652>>2]|0)+(n-1-u<<2)>>2]<<2)>>2]|0)|0;B=g+173203|0;a[B]=A;return}function DAa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=c[b+136>>2]|0;g=b+180|0;h=c[g>>2]|0;i=c[h+52>>2]|0;j=i-((i|0)>10?10:i)|0;i=(ba(c[h+13104>>2]|0,e)|0)+d|0;h=b+3464|0;k=c[h>>2]|0;if((a[b+3020|0]|0)==0){if((a[b+3021|0]|0)==0){l=0;m=0}else{n=3}}else{n=3}do{if((n|0)==3){do{if((d|0)>0){if((a[f+173200|0]|0)==0){o=0;break}o=PAa(b)|0}else{o=0}}while(0);if(!((e|0)>0&(o|0)==0)){l=o;m=0;break}if((a[f+173201|0]|0)==0){l=0;m=0;break}l=0;m=(PAa(b)|0)!=0}}while(0);f=k+(i*184|0)+181|0;o=k+(i*184|0)+182|0;p=k+(i*184|0)+112|0;q=k+(i*184|0)+116|0;r=(l|0)==0;l=r&(m^1);s=e-1|0;t=d-1|0;u=0;do{a:do{if((a[b+3020+u|0]|0)==0){a[k+(i*184|0)+180+u|0]=0}else{v=(u|0)==2;do{if(v){w=a[f]|0;a[o]=w;c[q>>2]=c[p>>2];x=w;y=k+(i*184|0)+182|0}else{if(l){w=(RAa(b)|0)&255;z=k+(i*184|0)+180+u|0;a[z]=w;x=w;y=z;break}if(!r){z=t+(ba(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;w=a[(c[h>>2]|0)+(z*184|0)+180+u|0]|0;z=k+(i*184|0)+180+u|0;a[z]=w;x=w;y=z;break}if(m){z=(ba(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;w=a[(c[h>>2]|0)+(z*184|0)+180+u|0]|0;z=k+(i*184|0)+180+u|0;a[z]=w;x=w;y=z;break}else{a[k+(i*184|0)+180+u|0]=0;break a}}}while(0);if(x<<24>>24==0){break}do{if(l){c[k+(i*184|0)+(u<<4)>>2]=TAa(b)|0;n=66}else{do{if(r){if(m){z=(ba(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+(u<<4)>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)>>2];break}else{c[k+(i*184|0)+(u<<4)>>2]=0;n=29;break}}else{z=t+(ba(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+(u<<4)>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)>>2];n=29}}while(0);if((n|0)==29){n=0;if(l){n=66;break}}if(!r){z=t+(ba(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+(u<<4)+4>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+4>>2];break}if(m){z=(ba(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+(u<<4)+4>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+4>>2];break}else{c[k+(i*184|0)+(u<<4)+4>>2]=0;break}}}while(0);if((n|0)==66){n=0;c[k+(i*184|0)+(u<<4)+4>>2]=TAa(b)|0}b:do{if(l){c[k+(i*184|0)+(u<<4)+8>>2]=TAa(b)|0;n=80}else{do{if(r){if(m){z=(ba(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+(u<<4)+8>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+8>>2]}else{c[k+(i*184|0)+(u<<4)+8>>2]=0}if(l){n=80;break b}if(!r){break}if(m){z=(ba(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+(u<<4)+12>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+12>>2];break b}else{c[k+(i*184|0)+(u<<4)+12>>2]=0;break b}}else{z=t+(ba(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+(u<<4)+8>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+8>>2]}}while(0);z=t+(ba(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+(u<<4)+12>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+12>>2]}}while(0);if((n|0)==80){n=0;c[k+(i*184|0)+(u<<4)+12>>2]=TAa(b)|0}do{if((a[y]|0)==1){z=0;do{do{if((c[k+(i*184|0)+(u<<4)+(z<<2)>>2]|0)==0){c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=0}else{if(l){c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=UAa(b)|0;break}if(!r){w=t+(ba(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=c[(c[h>>2]|0)+(w*184|0)+48+(u<<4)+(z<<2)>>2];break}if(m){w=(ba(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=c[(c[h>>2]|0)+(w*184|0)+48+(u<<4)+(z<<2)>>2];break}else{c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=0;break}}}while(0);z=z+1|0;}while((z|0)<4);if(l){c[k+(i*184|0)+96+(u<<2)>>2]=SAa(b)|0;break}if(!r){z=t+(ba(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+96+(u<<2)>>2]=c[(c[h>>2]|0)+(z*184|0)+96+(u<<2)>>2];break}if(m){z=(ba(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+96+(u<<2)>>2]=c[(c[h>>2]|0)+(z*184|0)+96+(u<<2)>>2];break}else{c[k+(i*184|0)+96+(u<<2)>>2]=0;break}}else{if(v){break}if(l){c[k+(i*184|0)+108+(u<<2)>>2]=VAa(b)|0;break}if(!r){z=t+(ba(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+108+(u<<2)>>2]=c[(c[h>>2]|0)+(z*184|0)+108+(u<<2)>>2];break}if(m){z=(ba(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+108+(u<<2)>>2]=c[(c[h>>2]|0)+(z*184|0)+108+(u<<2)>>2];break}else{c[k+(i*184|0)+108+(u<<2)>>2]=0;break}}}while(0);c[k+(i*184|0)+120+(u*20|0)>>2]=0;v=c[k+(i*184|0)+(u<<4)>>2]<<j;z=k+(i*184|0)+120+(u*20|0)+4|0;c[z>>2]=v;do{if((a[y]|0)!=2){if((c[k+(i*184|0)+48+(u<<4)>>2]|0)==0){break}c[z>>2]=-v}}while(0);v=c[k+(i*184|0)+(u<<4)+4>>2]<<j;z=k+(i*184|0)+120+(u*20|0)+8|0;c[z>>2]=v;do{if((a[y]|0)!=2){if((c[k+(i*184|0)+48+(u<<4)+4>>2]|0)==0){break}c[z>>2]=-v}}while(0);v=c[k+(i*184|0)+(u<<4)+8>>2]<<j;z=k+(i*184|0)+120+(u*20|0)+12|0;c[z>>2]=v;do{if((a[y]|0)==2){c[z>>2]=-v}else{if((c[k+(i*184|0)+48+(u<<4)+8>>2]|0)==0){break}c[z>>2]=-v}}while(0);v=c[k+(i*184|0)+(u<<4)+12>>2]<<j;z=k+(i*184|0)+120+(u*20|0)+16|0;c[z>>2]=v;if((a[y]|0)==2){c[z>>2]=-v;break}if((c[k+(i*184|0)+48+(u<<4)+12>>2]|0)==0){break}c[z>>2]=-v}}while(0);u=u+1|0;}while((u|0)<3);return}function EAa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;j=i;i=i+48|0;k=j|0;l=j+16|0;m=j+24|0;n=b+136|0;o=c[n>>2]|0;p=1<<g;q=b+180|0;r=c[q>>2]|0;s=b+184|0;t=(1<<(c[r+13080>>2]|0)-(c[(c[s>>2]|0)+24>>2]|0))-1|0;c[o+184576>>2]=h;u=p+e|0;v=c[r+13096>>2]|0;do{if((u|0)>(v|0)){w=5}else{if((p+f|0)>(c[r+13100>>2]|0)){w=5;break}if(!((c[r+13064>>2]|0)>>>0<g>>>0)){w=5;break}y=(aBa(b,h,e,f)|0)&255;z=(ba(c[(c[q>>2]|0)+13096>>2]|0,f)|0)+e|0;a[(c[b+7320>>2]|0)+z|0]=y}}while(0);if((w|0)==5){y=(ba(v,f)|0)+e|0;a[(c[b+7320>>2]|0)+y|0]=(c[r+13064>>2]|0)>>>0<g>>>0|0}r=c[s>>2]|0;do{if((a[r+22|0]|0)!=0){if(((c[(c[q>>2]|0)+13080>>2]|0)-(c[r+24>>2]|0)|0)>>>0>g>>>0){break}a[o+173196|0]=0;c[o+173188>>2]=0}}while(0);r=c[q>>2]|0;y=(ba(c[r+13096>>2]|0,f)|0)+e|0;if((a[(c[b+7320>>2]|0)+y|0]|0)!=0){y=p>>1;v=y+e|0;z=y+f|0;A=g-1|0;B=h+1|0;h=EAa(b,e,f,A,B)|0;if((h|0)<0){C=h;i=j;return C|0}do{if((h|0)==0){D=0}else{do{if((v|0)<(c[(c[q>>2]|0)+13096>>2]|0)){E=EAa(b,v,f,A,B)|0;if((E|0)<0){C=E}else{F=E;break}i=j;return C|0}else{F=h}}while(0);if((F|0)==0){D=0;break}do{if((z|0)<(c[(c[q>>2]|0)+13100>>2]|0)){E=EAa(b,e,z,A,B)|0;if((E|0)<0){C=E}else{G=E;break}i=j;return C|0}else{G=F}}while(0);if((G|0)==0){D=0;break}E=c[q>>2]|0;if((v|0)>=(c[E+13096>>2]|0)){D=G;break}if((z|0)>=(c[E+13100>>2]|0)){D=G;break}E=EAa(b,v,z,A,B)|0;if((E|0)<0){C=E}else{D=E;break}i=j;return C|0}}while(0);do{if((t&u|0)==0){if((t&p+f|0)!=0){break}c[o+173184>>2]=a[o+173182|0]|0}}while(0);if((D|0)==0){C=0;i=j;return C|0}D=c[q>>2]|0;if((v+y|0)<(c[D+13096>>2]|0)){C=1;i=j;return C|0}C=(z+y|0)<(c[D+13100>>2]|0)|0;i=j;return C|0}D=c[n>>2]|0;y=c[r+13064>>2]|0;z=c[r+13116>>2]|0;v=e>>y;o=f>>y;t=1<<(c[r+13080>>2]|0)-(c[(c[s>>2]|0)+24>>2]|0);c[D+184580>>2]=e;c[D+184584>>2]=f;r=D+184596|0;a[r]=1;B=D+184588|0;c[B>>2]=1;A=D+184592|0;c[A>>2]=0;G=D+184598|0;a[G]=0;F=D+184597|0;a[F]=0;h=(ba(o,z)|0)+v|0;E=b+7336|0;a[(c[E>>2]|0)+h|0]=0;H=D+184612|0;x=16843009;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=p>>y;y=t-1|0;do{if((a[(c[s>>2]|0)+40|0]|0)==0){a[D+184600|0]=0}else{t=(XAa(b)|0)&255;a[D+184600|0]=t;if(t<<24>>24==0){break}t=c[q>>2]|0;I=c[t+13084>>2]|0;J=c[t+13132>>2]|0;K=c[t+13096>>2]|0;L=p+f|0;M=c[t+13100>>2]|0;t=f>>I;N=((L|0)>(M|0)?M:L)>>I;if((t|0)>=(N|0)){break}L=e>>I;M=((u|0)>(K|0)?K:u)>>I;I=(L|0)<(M|0);K=b+7352|0;O=t;do{if(I){t=ba(O,J)|0;P=L;do{a[(c[K>>2]|0)+(P+t)|0]=2;P=P+1|0;}while((P|0)<(M|0))}O=O+1|0;}while((O|0)<(N|0))}}while(0);N=b+2404|0;if((c[N>>2]|0)!=2){O=YAa(b,e,f,v,o)|0;o=O&255;c[B>>2]=2;if((H|0)>0){v=0;M=h;while(1){TGb((c[E>>2]|0)+M|0,o|0,H|0)|0;K=v+1|0;if((K|0)<(H|0)){v=K;M=M+z|0}else{break}}}c[B>>2]=(O&255|0)!=0?2:0}do{if((a[(c[E>>2]|0)+h|0]|0)==0){if((c[N>>2]|0)==2){Q=c[B>>2]|0}else{O=$Aa(b)|0;c[B>>2]=O;Q=O}do{if((Q|0)==1){if((c[(c[q>>2]|0)+13064>>2]|0)==(g|0)){w=54;break}R=c[A>>2]|0;w=57}else{w=54}}while(0);a:do{if((w|0)==54){O=bBa(b,g)|0;c[A>>2]=O;M=c[B>>2]|0;if((O|0)==3){S=(M|0)==1|0}else{S=0}a[G]=S;if((M|0)==1){R=O;w=57;break}M=c[q>>2]|0;v=c[M+13084>>2]|0;o=p>>v;K=c[M+13132>>2]|0;M=c[(c[b+3480>>2]|0)+16>>2]|0;L=e>>v;J=f>>v;v=(o|0)==0?1:o;if((v|0)>0){o=b+7344|0;I=(c[n>>2]|0)+184588|0;P=0;do{t=(ba(P+J|0,K)|0)+L|0;TGb((c[o>>2]|0)+t|0,1,v|0)|0;T=0;do{a[M+((T+t|0)*14|0)+12|0]=(c[I>>2]|0)==1|0;T=T+1|0;}while((T|0)<(v|0));P=P+1|0;}while((P|0)<(v|0));U=c[A>>2]|0}else{U=O}switch(U|0){case 0:{FAa(b,e,f,p,p,g,0);break a;break};case 1:{v=(p|0)/2|0;FAa(b,e,f,p,v,g,0);FAa(b,e,v+f|0,p,v,g,1);break a;break};case 4:{v=(p|0)/4|0;FAa(b,e,f,p,v,g,0);FAa(b,e,v+f|0,p,(3<<g|0)/4|0,g,1);break a;break};case 5:{v=(3<<g|0)/4|0;FAa(b,e,f,p,v,g,0);FAa(b,e,v+f|0,p,(p|0)/4|0,g,1);break a;break};case 3:{v=(p|0)/2|0;FAa(b,e,f,v,v,g,0);P=v+e|0;FAa(b,P,f,v,v,g,1);I=v+f|0;FAa(b,e,I,v,v,g,2);FAa(b,P,I,v,v,g,3);break a;break};case 2:{v=(p|0)/2|0;FAa(b,e,f,v,p,g,0);FAa(b,v+e|0,f,v,p,g,1);break a;break};case 7:{v=(3<<g|0)/4|0;FAa(b,e,f,v,p,g,0);FAa(b,v+e|0,f,(p|0)/4|0,p,g,1);break a;break};case 6:{v=(p|0)/4|0;FAa(b,e,f,v,p,g,0);FAa(b,v+e|0,f,(3<<g|0)/4|0,p,g,1);break a;break};default:{break a}}}}while(0);do{if((w|0)==57){do{if((R|0)==0){v=c[q>>2]|0;if((c[v+68>>2]|0)==0){w=62;break}if((c[v+13048>>2]|0)>>>0>g>>>0){w=62;break}if((c[v+13052>>2]|0)>>>0<g>>>0){w=62;break}v=(cBa(b)|0)&255;a[F]=v;V=v}else{w=62}}while(0);if((w|0)==62){V=a[F]|0}if(!(V<<24>>24==0)){O=c[q>>2]|0;v=c[O+13084>>2]|0;I=p>>v;P=c[O+13132>>2]|0;M=c[(c[b+3480>>2]|0)+16>>2]|0;o=e>>v;L=f>>v;v=(I|0)==0?1:I;if((v|0)>0){I=b+7344|0;K=(c[n>>2]|0)+184588|0;J=0;do{T=(ba(J+L|0,P)|0)+o|0;TGb((c[I>>2]|0)+T|0,1,v|0)|0;t=0;do{a[M+((t+T|0)*14|0)+12|0]=(c[K>>2]|0)==1|0;t=t+1|0;}while((t|0)<(v|0));J=J+1|0;}while((J|0)<(v|0));W=c[q>>2]|0}else{W=O}v=c[n>>2]|0;J=c[b+160>>2]|0;K=c[J+32>>2]|0;M=c[W+56>>2]|0;I=c[J>>2]|0;o=c[J+36>>2]|0;P=c[W+13156>>2]|0;L=c[W+13144>>2]|0;t=c[J+4>>2]|0;T=c[J+40>>2]|0;X=c[W+13160>>2]|0;Y=c[W+13148>>2]|0;Z=c[J+8>>2]|0;J=p<<g;_=ba(d[W+13044|0]|0,J)|0;$=(ba(d[W+13045|0]|0,J>>1)|0)+_|0;_=v+9292|0;J=$+7>>3;aa=c[v+9308>>2]|0;ca=c[_>>2]|0;da=(ca&1|0)==0?aa:aa-1|0;aa=(ca&511|0)==0?da:da-1|0;da=(c[v+9312>>2]|0)-aa|0;if((da|0)<(J|0)){ea=0}else{Uhb(_,aa+J|0,da-J|0);ea=aa}tBa(b,e,f,g,d[v+184649|0]|0,d[v+184648|0]|0);v=$>>>0>2147483639>>>0|(ea|0)==0;aa=v?0:ea;J=v?0:$;c[m>>2]=aa;c[m+12>>2]=J;c[m+16>>2]=J+8;c[m+4>>2]=aa+(J+7>>3);c[m+8>>2]=0;if(v){fa=v?-1094995529:0}else{v=Z+((e>>Y<<M)+(ba(f>>X,T)|0))|0;X=t+((e>>L<<M)+(ba(f>>P,o)|0))|0;P=I+((e<<M)+(ba(K,f)|0))|0;M=b+5860|0;le[c[M>>2]&1023](P,K,p,m,d[(c[q>>2]|0)+13044|0]|0);K=(p|0)/2|0;le[c[M>>2]&1023](X,o,K,m,d[(c[q>>2]|0)+13045|0]|0);le[c[M>>2]&1023](v,T,K,m,d[(c[q>>2]|0)+13045|0]|0);fa=0}K=c[q>>2]|0;do{if((a[K+13056|0]|0)!=0){T=c[K+13084>>2]|0;v=c[K+13132>>2]|0;M=c[K+13096>>2]|0;o=p+f|0;X=c[K+13100>>2]|0;P=f>>T;I=((o|0)>(X|0)?X:o)>>T;if((P|0)>=(I|0)){break}o=e>>T;X=((u|0)>(M|0)?M:u)>>T;T=(o|0)<(X|0);M=b+7352|0;L=P;do{if(T){P=ba(L,v)|0;t=o;do{a[(c[M>>2]|0)+(t+P)|0]=2;t=t+1|0;}while((t|0)<(X|0))}L=L+1|0;}while((L|0)<(I|0))}}while(0);if((fa|0)<0){C=fa}else{break}i=j;return C|0}K=c[n>>2]|0;O=(c[K+184592>>2]|0)==3;I=O?2:1;L=0;do{X=L<<1;M=0;do{a[l+(M+X)|0]=dBa(b)|0;M=M+1|0;}while((M|0)<(I|0));L=L+1|0;}while((L|0)<(I|0));L=p>>(O&1);M=K+184608|0;X=b+3480|0;o=k|0;v=k+4|0;T=k+8|0;t=b+7344|0;P=K+184604|0;Y=0;do{Z=Y<<1;J=(ba(Y,L)|0)+f|0;aa=J-1|0;$=0;do{da=$+Z|0;_=(a[l+da|0]|0)==0;if(_){c[M>>2]=fBa(b)|0}else{c[P>>2]=eBa(b)|0}ca=(ba($,L)|0)+e|0;ga=c[n>>2]|0;ha=c[q>>2]|0;ia=c[ha+13084>>2]|0;ja=ca>>ia;ka=J>>ia;la=c[ha+13132>>2]|0;ma=L>>ia;ia=c[ha+13080>>2]|0;ha=(1<<ia)-1|0;na=ha&ca;if((a[ga+173201|0]|0)==0){if((ha&J|0)==0){oa=1}else{w=93}}else{w=93}if((w|0)==93){w=0;ha=(ba(ka-1|0,la)|0)+ja|0;oa=d[(c[t>>2]|0)+ha|0]|0}if((a[ga+173200|0]|0)==0&(na|0)==0){pa=1}else{na=ja-1+(ba(ka,la)|0)|0;pa=d[(c[t>>2]|0)+na|0]|0}na=c[(c[X>>2]|0)+16>>2]|0;ha=(aa|0)<(J>>ia<<ia|0)?1:oa;do{if((pa|0)==(ha|0)){if(pa>>>0<2>>>0){c[o>>2]=0;c[v>>2]=1;c[T>>2]=26;qa=0;ra=1;sa=26;break}else{c[o>>2]=pa;ia=(pa+29&31)+2|0;c[v>>2]=ia;ca=(pa+31&31)+2|0;c[T>>2]=ca;qa=pa;ra=ia;sa=ca;break}}else{c[o>>2]=pa;c[v>>2]=ha;if(!((pa|0)==0|(ha|0)==0)){c[T>>2]=0;qa=pa;ra=ha;sa=0;break}if((pa|0)==1|(ha|0)==1){c[T>>2]=26;qa=pa;ra=ha;sa=26;break}else{c[T>>2]=1;qa=pa;ra=ha;sa=1;break}}}while(0);if(_){if((qa|0)>(ra|0)){c[v>>2]=qa;ha=ra&255;c[o>>2]=ha;ta=ha;ua=qa}else{ta=qa;ua=ra}if((ta|0)>(sa|0)){c[T>>2]=ta;ha=sa&255;c[o>>2]=ha;va=ta;wa=ha}else{va=sa;wa=ta}if((ua|0)>(va|0)){c[T>>2]=ua;ha=va&255;c[v>>2]=ha;xa=ha;ya=ua}else{xa=ua;ya=va}ha=c[ga+184608>>2]|0;ca=((ha|0)>=(wa|0))+ha|0;ha=((ca|0)>=(xa|0))+ca|0;za=((ha|0)>=(ya|0))+ha&255}else{za=c[k+(c[ga+184604>>2]<<2)>>2]&255}ha=(ma|0)==0?1:ma;if((ha|0)>0){ca=0;do{ia=(ba(ca+ka|0,la)|0)+ja|0;TGb((c[t>>2]|0)+ia|0,za|0,ha|0)|0;ia=ca+ja|0;Aa=0;do{Ba=ia+(ba(Aa+ka|0,la)|0)|0;a[na+(Ba*14|0)+12|0]=1;Aa=Aa+1|0;TGb(na+(Ba*14|0)|0,0,12)|0}while((Aa|0)<(ha|0));ca=ca+1|0;}while((ca|0)<(ha|0))}a[K+184612+da|0]=za;$=$+1|0;}while(($|0)<(I|0));Y=Y+1|0;}while((Y|0)<(I|0));I=gBa(b)|0;Y=a[K+184612|0]|0;if((I|0)==4){a[K+184621|0]=Y;break}t=a[906608+I|0]|0;I=K+184621|0;if(Y<<24>>24==t<<24>>24){a[I]=34;break}else{a[I]=t;break}}}while(0);if((a[F]|0)!=0){break}do{if((c[B>>2]|0)==1){w=145}else{if((c[A>>2]|0)==0){if((a[D+184620|0]|0)!=0){w=145;break}}t=(mBa(b)|0)&255;a[r]=t;Ca=t}}while(0);if((w|0)==145){Ca=a[r]|0}if(Ca<<24>>24==0){if((a[b+3025|0]|0)!=0){break}tBa(b,e,f,g,d[D+184649|0]|0,d[D+184648|0]|0);break}t=c[q>>2]|0;if((c[B>>2]|0)==1){Da=(d[G]|0)+(c[t+13092>>2]|0)&255}else{Da=c[t+13088>>2]&255}a[D+184599|0]=Da;t=GAa(b,e,f,e,f,e,f,g,g,0,0)|0;if((t|0)<0){C=t}else{break}i=j;return C|0}else{FAa(b,e,f,p,p,g,0);t=c[q>>2]|0;I=c[t+13084>>2]|0;Y=p>>I;v=c[t+13132>>2]|0;t=c[(c[b+3480>>2]|0)+16>>2]|0;T=e>>I;o=f>>I;I=(Y|0)==0?1:Y;if((I|0)>0){Y=b+7344|0;X=(c[n>>2]|0)+184588|0;L=0;do{P=(ba(L+o|0,v)|0)+T|0;TGb((c[Y>>2]|0)+P|0,1,I|0)|0;M=0;do{a[t+((M+P|0)*14|0)+12|0]=(c[X>>2]|0)==1|0;M=M+1|0;}while((M|0)<(I|0));L=L+1|0;}while((L|0)<(I|0))}if((a[b+3025|0]|0)!=0){break}tBa(b,e,f,g,d[D+184649|0]|0,d[D+184648|0]|0)}}while(0);do{if((a[(c[s>>2]|0)+22|0]|0)!=0){if((a[D+173196|0]|0)!=0){break}sBa(b,e,f,e,f,g)}}while(0);if((H|0)>0){g=b+7316|0;s=D+173182|0;n=0;Da=h;while(1){TGb((c[g>>2]|0)+Da|0,a[s]|0,H|0)|0;h=n+1|0;if((h|0)<(H|0)){n=h;Da=Da+z|0}else{break}}}do{if((y&u|0)==0){if((y&p+f|0)!=0){break}c[D+173184>>2]=a[D+173182|0]|0}}while(0);y=c[q>>2]|0;z=c[y+13064>>2]|0;Da=p>>z;n=e>>z;e=f>>z;do{if((Da|0)>0){z=b+7340|0;H=c[D+184576>>2]&255;s=(ba(c[y+13116>>2]|0,e)|0)+n|0;TGb((c[z>>2]|0)+s|0,H|0,Da|0)|0;if((Da|0)>1){Ea=1}else{break}do{s=(ba(c[(c[q>>2]|0)+13116>>2]|0,Ea+e|0)|0)+n|0;TGb((c[z>>2]|0)+s|0,H|0,Da|0)|0;Ea=Ea+1|0;}while((Ea|0)<(Da|0))}}while(0);Da=c[q>>2]|0;q=1<<c[Da+13080>>2];do{if(((u|0)%(q|0)|0|0)!=0){if((u|0)<(c[Da+13096>>2]|0)){C=1}else{break}i=j;return C|0}}while(0);u=p+f|0;do{if(((u|0)%(q|0)|0|0)!=0){if((u|0)<(c[Da+13100>>2]|0)){C=1}else{break}i=j;return C|0}}while(0);C=(WAa(b)|0)==0|0;i=j;return C|0}function FAa(d,e,f,g,h,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;l=i;i=i+65552|0;m=l|0;n=l+16|0;o=l+8208|0;p=l+16400|0;q=l+24592|0;r=l+32784|0;s=l+40976|0;t=l+49168|0;u=l+57360|0;v=c[d+136>>2]|0;w=m;b[w>>1]=b[465820]|0;b[w+2>>1]=b[465821]|0;b[w+4>>1]=b[465822]|0;b[w+6>>1]=b[465823]|0;b[w+8>>1]=b[465824]|0;b[w+10>>1]=b[465825]|0;b[w+12>>1]=b[465826]|0;x=d+180|0;y=c[x>>2]|0;z=c[y+13132>>2]|0;A=c[d+3480>>2]|0;B=c[A+16>>2]|0;C=c[A+20>>2]|0;A=d+160|0;D=c[A>>2]|0;E=ba(c[D+32>>2]|0,f>>c[y+13152>>2])|0;F=c[y+56>>2]|0;G=(c[D>>2]|0)+((e>>c[y+13140>>2]<<F)+E)|0;E=ba(f>>c[y+13156>>2],c[D+36>>2]|0)|0;H=(c[D+4>>2]|0)+((e>>c[y+13144>>2]<<F)+E)|0;E=ba(f>>c[y+13160>>2],c[D+40>>2]|0)|0;I=(c[D+8>>2]|0)+((e>>c[y+13148>>2]<<F)+E)|0;E=c[y+13064>>2]|0;F=(ba(f>>E,c[y+13116>>2]|0)|0)+(e>>E)|0;a:do{if((a[(c[d+7336>>2]|0)+F|0]|0)==0){E=(iBa(d)|0)&255;a[v+184620|0]=E;if(!(E<<24>>24==0)){if((c[d+3052>>2]|0)>>>0>1>>>0){J=hBa(d)|0}else{J=0}yBa(d,e,f,g,h,j,k,J,m);E=c[(c[x>>2]|0)+13084>>2]|0;y=e>>E;D=f>>E;if((g>>E|0)>0){K=0;L=E}else{break}while(1){if((h>>L|0)>0){E=K+y|0;M=0;while(1){N=B+((E+(ba(M+D|0,z)|0)|0)*14|0)|0;b[N>>1]=b[w>>1]|0;b[N+2>>1]=b[w+2>>1]|0;b[N+4>>1]=b[w+4>>1]|0;b[N+6>>1]=b[w+6>>1]|0;b[N+8>>1]=b[w+8>>1]|0;b[N+10>>1]=b[w+10>>1]|0;b[N+12>>1]=b[w+12>>1]|0;N=M+1|0;O=c[(c[x>>2]|0)+13084>>2]|0;if((N|0)<(h>>O|0)){M=N}else{P=O;break}}}else{P=L}M=K+1|0;if((M|0)<(g>>P|0)){K=M;L=P}else{break a}}}xBa(d,e,f,g,h);if((c[d+2404>>2]|0)==0){D=jBa(d,g,h)|0;if((D|0)==1){Q=1;R=22}else{S=D;R=19}}else{S=0;R=19}if((R|0)==19){D=c[d+3012>>2]|0;if((D|0)!=0){a[m+8|0]=kBa(d,D)|0}a[m+10|0]=1;rBa(d,e,f,0);zBa(d,e,f,g,h,j,k,0,m,lBa(d)|0,0);D=m|0;b[D>>1]=(b[D>>1]|0)+(b[v+184616>>1]|0);D=m+2|0;b[D>>1]=(b[D>>1]|0)+(b[v+184618>>1]|0);if((S|0)!=0){Q=S;R=22}}if((R|0)==22){D=c[d+3016>>2]|0;if((D|0)!=0){a[m+9|0]=kBa(d,D)|0}if((a[d+3023|0]|0)==1&(Q|0)==2){D=v+184616|0;b[D>>1]=0;y=v+184618|0;b[y>>1]=0;T=D;U=y}else{rBa(d,e,f,1);T=v+184616|0;U=v+184618|0}a[m+11|0]=1;zBa(d,e,f,g,h,j,k,0,m,lBa(d)|0,1);y=m+4|0;b[y>>1]=(b[y>>1]|0)+(b[T>>1]|0);y=m+6|0;b[y>>1]=(b[y>>1]|0)+(b[U>>1]|0)}y=c[(c[x>>2]|0)+13084>>2]|0;D=e>>y;M=f>>y;if((g>>y|0)>0){V=0;W=y}else{break}while(1){if((h>>W|0)>0){y=V+D|0;E=0;while(1){O=B+((y+(ba(E+M|0,z)|0)|0)*14|0)|0;b[O>>1]=b[w>>1]|0;b[O+2>>1]=b[w+2>>1]|0;b[O+4>>1]=b[w+4>>1]|0;b[O+6>>1]=b[w+6>>1]|0;b[O+8>>1]=b[w+8>>1]|0;b[O+10>>1]=b[w+10>>1]|0;b[O+12>>1]=b[w+12>>1]|0;O=E+1|0;N=c[(c[x>>2]|0)+13084>>2]|0;if((O|0)<(h>>N|0)){E=O}else{X=N;break}}}else{X=W}E=V+1|0;if((E|0)<(g>>X|0)){V=E;W=X}else{break}}}else{if((c[d+3052>>2]|0)>>>0>1>>>0){Y=hBa(d)|0}else{Y=0}M=1<<j;yBa(d,e,f,M,M,j,k,Y,m);M=c[(c[x>>2]|0)+13084>>2]|0;D=e>>M;E=f>>M;if((g>>M|0)>0){Z=0;_=M}else{break}while(1){if((h>>_|0)>0){M=Z+D|0;y=0;while(1){N=B+((M+(ba(y+E|0,z)|0)|0)*14|0)|0;b[N>>1]=b[w>>1]|0;b[N+2>>1]=b[w+2>>1]|0;b[N+4>>1]=b[w+4>>1]|0;b[N+6>>1]=b[w+6>>1]|0;b[N+8>>1]=b[w+8>>1]|0;b[N+10>>1]=b[w+10>>1]|0;b[N+12>>1]=b[w+12>>1]|0;N=y+1|0;O=c[(c[x>>2]|0)+13084>>2]|0;if((N|0)<(h>>O|0)){y=N}else{$=O;break}}}else{$=_}y=Z+1|0;if((y|0)<(g>>$|0)){Z=y;_=$}else{break}}}}while(0);$=m+10|0;do{if((a[$]|0)==0){aa=0}else{_=c[C+(a[m+8|0]<<2)>>2]|0;if((_|0)==0){i=l;return}if((a[d+140|0]|0)!=1){aa=_;break}Z0a(_+4|0,f+9+h+(b[m+2>>1]>>2)|0,0);aa=_}}while(0);_=m+11|0;do{if((a[_]|0)==0){ca=0}else{Z=c[C+196+(a[m+9|0]<<2)>>2]|0;if((Z|0)==0){i=l;return}if((a[d+140|0]|0)!=1){ca=Z;break}Z0a(Z+4|0,f+9+h+(b[m+6>>1]>>2)|0,0);ca=Z}}while(0);Z=(a[_]|0)==0;if((a[$]|0)==0){if(Z|(ca|0)==0){i=l;return}$=p|0;p=ca|0;ca=c[p>>2]|0;_=m+4|0;x=m+6|0;HAa(d,$,c[ca>>2]|0,c[ca+32>>2]|0,b[_>>1]|0,b[x>>1]|0,e,f,g,h);ca=d+2404|0;w=c[ca>>2]|0;if((w|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=58}else{R=57}}else if((w|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=58}else{R=57}}else{R=58}if((R|0)==57){w=a[m+9|0]|0;Le[c[d+6024>>2]&255](a[d+3073|0]|0,b[d+3236+(w<<1)>>1]|0,b[d+3364+(w<<1)>>1]|0,G,c[(c[A>>2]|0)+32>>2]|0,$,64,g,h)}else if((R|0)==58){Se[c[d+6016>>2]&511](G,c[(c[A>>2]|0)+32>>2]|0,$,64,g,h)}w=q|0;q=(g|0)/2|0;z=(h|0)/2|0;IAa(d,$,w,c[p>>2]|0,b[_>>1]|0,b[x>>1]|0,(e|0)/2|0,(f|0)/2|0,q,z);x=c[ca>>2]|0;if((x|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=63}else{R=62}}else if((x|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=63}else{R=62}}else{R=63}if((R|0)==62){x=d+6024|0;ca=d+3074|0;_=m+9|0;p=a[_]|0;Le[c[x>>2]&255](b[ca>>1]&255,b[d+3172+(p<<2)>>1]|0,b[d+3396+(p<<2)>>1]|0,H,c[(c[A>>2]|0)+36>>2]|0,$,64,q,z);p=a[_]|0;Le[c[x>>2]&255](b[ca>>1]&255,b[d+3172+(p<<2)+2>>1]|0,b[d+3396+(p<<2)+2>>1]|0,I,c[(c[A>>2]|0)+40>>2]|0,w,64,q,z);i=l;return}else if((R|0)==63){p=d+6016|0;Se[c[p>>2]&511](H,c[(c[A>>2]|0)+36>>2]|0,$,64,q,z);Se[c[p>>2]&511](I,c[(c[A>>2]|0)+40>>2]|0,w,64,q,z);i=l;return}}if(Z){Z=n|0;n=aa|0;aa=c[n>>2]|0;z=m|0;q=m+2|0;HAa(d,Z,c[aa>>2]|0,c[aa+32>>2]|0,b[z>>1]|0,b[q>>1]|0,e,f,g,h);aa=d+2404|0;w=c[aa>>2]|0;if((w|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=47}else{R=46}}else if((w|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=47}else{R=46}}else{R=47}if((R|0)==46){w=a[m+8|0]|0;Le[c[d+6024>>2]&255](a[d+3073|0]|0,b[d+3076+(w<<1)>>1]|0,b[d+3268+(w<<1)>>1]|0,G,c[(c[A>>2]|0)+32>>2]|0,Z,64,g,h)}else if((R|0)==47){Se[c[d+6016>>2]&511](G,c[(c[A>>2]|0)+32>>2]|0,Z,64,g,h)}w=o|0;o=(g|0)/2|0;p=(h|0)/2|0;IAa(d,Z,w,c[n>>2]|0,b[z>>1]|0,b[q>>1]|0,(e|0)/2|0,(f|0)/2|0,o,p);q=c[aa>>2]|0;if((q|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=52}else{R=51}}else if((q|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=52}else{R=51}}else{R=52}if((R|0)==51){q=d+6024|0;aa=d+3074|0;z=m+8|0;n=a[z]|0;Le[c[q>>2]&255](b[aa>>1]&255,b[d+3108+(n<<2)>>1]|0,b[d+3300+(n<<2)>>1]|0,H,c[(c[A>>2]|0)+36>>2]|0,Z,64,o,p);n=a[z]|0;Le[c[q>>2]&255](b[aa>>1]&255,b[d+3108+(n<<2)+2>>1]|0,b[d+3300+(n<<2)+2>>1]|0,I,c[(c[A>>2]|0)+40>>2]|0,w,64,o,p);i=l;return}else if((R|0)==52){n=d+6016|0;Se[c[n>>2]&511](H,c[(c[A>>2]|0)+36>>2]|0,Z,64,o,p);Se[c[n>>2]&511](I,c[(c[A>>2]|0)+40>>2]|0,w,64,o,p);i=l;return}}p=m+8|0;o=c[C+(a[p]<<2)>>2]|0;w=m+9|0;n=c[C+196+(a[w]<<2)>>2]|0;if((o|0)==0|(n|0)==0){i=l;return}C=r|0;r=o|0;o=c[r>>2]|0;Z=m|0;aa=m+2|0;HAa(d,C,c[o>>2]|0,c[o+32>>2]|0,b[Z>>1]|0,b[aa>>1]|0,e,f,g,h);o=s|0;s=n|0;n=c[s>>2]|0;q=m+4|0;z=m+6|0;HAa(d,o,c[n>>2]|0,c[n+32>>2]|0,b[q>>1]|0,b[z>>1]|0,e,f,g,h);n=d+2404|0;m=c[n>>2]|0;if((m|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=69}else{R=68}}else if((m|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=69}else{R=68}}else{R=69}if((R|0)==68){m=a[p]|0;$=a[w]|0;Ue[c[d+6028>>2]&127](a[d+3073|0]|0,b[d+3076+(m<<1)>>1]|0,b[d+3236+($<<1)>>1]|0,b[d+3268+(m<<1)>>1]|0,b[d+3364+($<<1)>>1]|0,G,c[(c[A>>2]|0)+32>>2]|0,C,o,64,g,h)}else if((R|0)==69){Ke[c[d+6020>>2]&1023](G,c[(c[A>>2]|0)+32>>2]|0,C,o,64,g,h)}G=(e|0)/2|0;e=(f|0)/2|0;f=(g|0)/2|0;g=(h|0)/2|0;IAa(d,C,o,c[r>>2]|0,b[Z>>1]|0,b[aa>>1]|0,G,e,f,g);aa=t|0;t=u|0;IAa(d,aa,t,c[s>>2]|0,b[q>>1]|0,b[z>>1]|0,G,e,f,g);e=c[n>>2]|0;if((e|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=74}else{R=73}}else if((e|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=74}else{R=73}}else{R=74}if((R|0)==73){e=d+6028|0;n=d+3074|0;G=a[p]|0;z=a[w]|0;Ue[c[e>>2]&127](b[n>>1]&255,b[d+3108+(G<<2)>>1]|0,b[d+3172+(z<<2)>>1]|0,b[d+3300+(G<<2)>>1]|0,b[d+3396+(z<<2)>>1]|0,H,c[(c[A>>2]|0)+36>>2]|0,C,aa,64,f,g);z=a[p]|0;p=a[w]|0;Ue[c[e>>2]&127](b[n>>1]&255,b[d+3108+(z<<2)+2>>1]|0,b[d+3172+(p<<2)+2>>1]|0,b[d+3300+(z<<2)+2>>1]|0,b[d+3396+(p<<2)+2>>1]|0,I,c[(c[A>>2]|0)+40>>2]|0,o,t,64,f,g);i=l;return}else if((R|0)==74){R=d+6020|0;Ke[c[R>>2]&1023](H,c[(c[A>>2]|0)+36>>2]|0,C,aa,64,f,g);Ke[c[R>>2]&1023](I,c[(c[A>>2]|0)+40>>2]|0,o,t,64,f,g);i=l;return}}function GAa(b,e,f,g,h,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;p=i;q=b+136|0;r=c[q>>2]|0;s=1<<m;t=s-1|0;if((n|0)>0&(m|0)==2){u=((t&h)<<7)+(t&g)|0;v=n-1|0;w=((t&f)<<7)+(t&e)|0;a[r+9340+(n<<14)+w|0]=a[r+9340+(v<<14)+u|0]|0;a[r+91260+(n<<14)+w|0]=a[r+91260+(v<<14)+u|0]|0}else{u=((t&f)<<7)+(t&e)|0;a[r+91260+(n<<14)+u|0]=0;a[r+9340+(n<<14)+u|0]=0}u=a[r+184598|0]|0;do{if(u<<24>>24==0){c[r+173192>>2]=d[r+184612|0]|0}else{if((n|0)!=1){break}c[r+173192>>2]=d[r+184612+o|0]|0}}while(0);v=r+173180|0;a[v]=1;w=b+180|0;do{if((c[(c[w>>2]|0)+13088>>2]|0)==0){if((c[r+184588>>2]|0)!=0){x=0;break}if((c[r+184592>>2]|0)==0){x=0;break}x=(n|0)==0|0}else{x=0}}while(0);a[r+173181|0]=x;y=c[w>>2]|0;z=(c[y+13076>>2]|0)>>>0<m>>>0;a:do{if(z){A=1}else{if((c[y+13072>>2]|0)>>>0<m>>>0){do{if((d[r+184599|0]|0)>(n|0)){if(u<<24>>24!=0&(n|0)==0){break}A=(nBa(b,m)|0)&255;break a}}while(0);if(z){A=1;break}}A=u<<24>>24!=0&(n|0)==0?1:x}}while(0);x=(m|0)>2;do{if(x){if((n|0)==0){u=((t&f)<<7)+(t&e)|0;a[r+9340+u|0]=oBa(b,0)|0;B=u}else{u=((t&h)<<7)+(t&g)|0;z=n-1|0;if((a[r+9340+(z<<14)+u|0]|0)!=0){a[((t&f)<<7)+(t&e)+(r+9340+(n<<14))|0]=oBa(b,n)|0}if((a[r+91260+(z<<14)+u|0]|0)==0){break}B=((t&f)<<7)+(t&e)|0}a[r+91260+(n<<14)+B|0]=oBa(b,n)|0}}while(0);do{if(A<<24>>24==0){B=c[w>>2]|0;u=c[B+13072>>2]|0;z=1<<u;y=c[B+13124>>2]|0;do{if((c[r+184588>>2]|0)!=1&(n|0)==0){B=((t&f)<<7)+(t&e)|0;if((a[r+9340+B|0]|0)!=0){C=35;break}if((a[r+91260+B|0]|0)!=0){C=35}}else{C=35}}while(0);if((C|0)==35){a[v]=pBa(b,n)|0}B=c[q>>2]|0;D=B+184588|0;do{if((c[D>>2]|0)==1){xBa(b,e,f,s,s);E=b+5820|0;le[c[E>>2]&1023](b,e,f,m,0);if(x){F=s<<(c[(c[w>>2]|0)+13144>>2]|0)-1;xBa(b,e,f,F,F);F=m-1|0;le[c[E>>2]&1023](b,e,f,F,1);le[c[E>>2]&1023](b,e,f,F,2);break}if((o|0)!=3){break}F=s<<c[(c[w>>2]|0)+13144>>2];xBa(b,g,h,F,F);le[c[E>>2]&1023](b,g,h,m,1);le[c[E>>2]&1023](b,g,h,m,2)}}while(0);E=B+173180|0;do{if((a[E]|0)==0){F=((t&f)<<7)+(t&e)|0;if((a[B+9340+(n<<14)+F|0]|0)!=0){C=44;break}if((a[B+91260+(n<<14)+F|0]|0)!=0){C=44}}else{C=44}}while(0);do{if((C|0)==44){do{if((a[(c[b+184>>2]|0)+22|0]|0)!=0){F=B+173196|0;if((a[F]|0)!=0){break}G=ZAa(b)|0;H=B+173188|0;c[H>>2]=G;do{if((G|0)==0){I=0}else{J=(_Aa(b)|0)==1;K=c[H>>2]|0;if(!J){I=K;break}J=-K|0;c[H>>2]=J;I=J}}while(0);a[F]=1;H=(c[(c[w>>2]|0)+13164>>2]|0)/2|0;G=-26-H|0;J=H+25|0;if(!((I|0)<(G|0)|(I|0)>(J|0))){sBa(b,e,f,j,k,l);break}yDb(c[b+4>>2]|0,16,2201024,(H=i,i=i+24|0,c[H>>2]=I,c[H+8>>2]=G,c[H+16>>2]=J,H)|0);i=H;L=-1094995529;i=p;return L|0}}while(0);do{if((c[D>>2]|0)==1&(m|0)<4){H=c[B+173192>>2]|0;if((H-6|0)>>>0<9>>>0){M=2}else{M=(H-22|0)>>>0<9>>>0|0}H=a[B+184621|0]|0;if((H-6&255)>>>0<9>>>0){N=2;O=M;break}N=(H-22&255)>>>0<9>>>0|0;O=M}else{N=0;O=0}}while(0);if((a[E]|0)!=0){qBa(b,e,f,m,O,0)}if(x){H=((t&f)<<7)+(t&e)|0;if((a[B+9340+(n<<14)+H|0]|0)!=0){qBa(b,e,f,m-1|0,N,1)}if((a[B+91260+(n<<14)+H|0]|0)==0){break}qBa(b,e,f,m-1|0,N,2);break}if((o|0)!=3){break}H=((t&h)<<7)+(t&g)|0;if((a[B+9340+(n<<14)+H|0]|0)!=0){qBa(b,g,h,m,N,1)}if((a[B+91260+(n<<14)+H|0]|0)==0){break}qBa(b,g,h,m,N,2)}}while(0);if((a[v]|0)!=0&(s|0)>0){B=b+7348|0;E=0;do{D=ba(E+f>>u,y)|0;H=0;do{a[(c[B>>2]|0)+((H+e>>u)+D)|0]=1;H=H+z|0;}while((H|0)<(s|0));E=E+z|0;}while((E|0)<(s|0))}if((a[b+3025|0]|0)!=0){break}tBa(b,e,f,m,d[r+184649|0]|0,d[r+184648|0]|0);if((a[(c[b+184>>2]|0)+40|0]|0)==0){break}if((a[r+184600|0]|0)==0){break}E=c[w>>2]|0;z=c[E+13084>>2]|0;u=c[E+13132>>2]|0;B=s+e|0;y=c[E+13096>>2]|0;H=s+f|0;D=c[E+13100>>2]|0;E=f>>z;J=((H|0)>(D|0)?D:H)>>z;if((E|0)>=(J|0)){break}H=e>>z;D=((B|0)>(y|0)?y:B)>>z;z=(H|0)<(D|0);B=b+7352|0;y=E;do{if(z){E=ba(y,u)|0;G=H;do{a[(c[B>>2]|0)+(G+E)|0]=2;G=G+1|0;}while((G|0)<(D|0))}y=y+1|0;}while((y|0)<(J|0))}else{J=s>>1;y=J+e|0;D=J+f|0;J=m-1|0;B=n+1|0;H=GAa(b,e,f,e,f,j,k,l,J,B,0)|0;if((H|0)<0){L=H;i=p;return L|0}H=GAa(b,y,f,e,f,j,k,l,J,B,1)|0;if((H|0)<0){L=H;i=p;return L|0}H=GAa(b,e,D,e,f,j,k,l,J,B,2)|0;if((H|0)<0){L=H;i=p;return L|0}H=GAa(b,y,D,e,f,j,k,l,J,B,3)|0;if((H|0)<0){L=H}else{break}i=p;return L|0}}while(0);L=0;i=p;return L|0}function HAa(a,b,e,f,g,h,i,j,k,l){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=c[a+136>>2]|0;n=c[a+180>>2]|0;o=c[n+13096>>2]|0;p=c[n+13100>>2]|0;q=g<<16>>16;g=q&3;r=h<<16>>16;h=r&3;s=d[1206616+g|0]|0;t=d[1206616+h|0]|0;u=(q>>2)+i|0;i=(r>>2)+j|0;j=ba(i,f)|0;r=c[n+56>>2]|0;n=(u<<r)+j|0;j=e+n|0;do{if(!((u|0)<(s|0)|(i|0)<(t|0))){if((u|0)>=(o-k-(d[1206624+g|0]|0)|0)){break}if((i|0)<(p-l-(d[1206624+h|0]|0)|0)){v=j;w=f}else{break}x=a+5936+(h<<4)+(g<<2)|0;y=c[x>>2]|0;z=m|0;Ke[y&1023](b,64,v,w,k,l,z);return}}while(0);j=80<<r;q=ba(t,f)|0;A=s<<r;r=(ba(j,t)|0)+A|0;Ne[c[a+6064>>2]&127](m+173216|0,e+(n-q-A)|0,j,f,(d[1206632+g|0]|0)+k|0,(d[1206632+h|0]|0)+l|0,u-s|0,i-t|0,o,p);v=m+173216+r|0;w=j;x=a+5936+(h<<4)+(g<<2)|0;y=c[x>>2]|0;z=m|0;Ke[y&1023](b,64,v,w,k,l,z);return}function IAa(a,b,d,e,f,g,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;l=c[a+136>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+36>>2]|0;p=c[e+40>>2]|0;e=c[a+180>>2]|0;q=c[e+13096>>2]>>1;r=c[e+13100>>2]>>1;s=f<<16>>16;f=s&7;t=g<<16>>16;g=t&7;u=(s>>3)+h|0;h=(t>>3)+i|0;i=ba(o,h)|0;t=c[e+56>>2]|0;e=u<<t;s=e+i|0;i=m+s|0;v=e+(ba(p,h)|0)|0;e=n+v|0;do{if(!((u|0)<1|(h|0)<2)){if((u|0)>=(-2-j+q|0)){break}if((h|0)>=(-2-k+r|0)){break}w=a+6e3+(((g|0)!=0)<<3)+(((f|0)!=0)<<2)|0;x=l|0;Le[c[w>>2]&255](b,64,i,o,j,k,f,g,x);Le[c[w>>2]&255](d,64,e,p,j,k,f,g,x);return}}while(0);e=80<<t;i=1<<t;t=a+6064|0;x=l+173216|0;w=j+3|0;y=k+3|0;z=u-1|0;u=h-1|0;Ne[c[t>>2]&127](x,m+(s-o-i)|0,e,o,w,y,z,u,q,r);o=e+i+(l+173216)|0;s=a+6e3+(((g|0)!=0)<<3)+(((f|0)!=0)<<2)|0;a=l|0;Le[c[s>>2]&255](b,64,o,e,j,k,f,g,a);Ne[c[t>>2]&127](x,n+(v-p-i)|0,e,p,w,y,z,u,q,r);Le[c[s>>2]&255](d,64,o,e,j,k,f,g,a);return}function JAa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c[a+60>>2]|0;a=c[g+180>>2]|0;h=c[a+13080>>2]|0;i=1<<h;j=c[b+(e<<2)>>2]|0;e=(ba(i-1+(c[a+13096>>2]|0)>>h,j)|0)+(c[g+3460>>2]|0)|0;h=c[(c[(c[g+184>>2]|0)+1652>>2]|0)+(e<<2)>>2]|0;a=(j|0)%(d[g+141|0]|0|0)|0;b=c[g+8+(f<<2)>>2]|0;f=c[b+136>>2]|0;do{if((j|0)!=0){k=b+7404|0;l=j-1|0;m=b+3060|0;n=(c[k>>2]|0)+(c[(c[m>>2]|0)+(l<<2)>>2]|0)|0;o=b+3064|0;p=c[(c[o>>2]|0)+(l<<2)>>2]|0;q=p>>>0>268435455>>>0?-8:p<<3;p=q>>>0>2147483639>>>0|(n|0)==0;r=p?0:n;n=p?0:q;c[f+9272>>2]=r;c[f+9284>>2]=n;c[f+9288>>2]=n+8;c[f+9276>>2]=r+(n>>3);c[f+9280>>2]=0;if(p){s=p?-1094995529:0;return s|0}else{Uhb(f+9292|0,(c[k>>2]|0)+(c[(c[m>>2]|0)+(l<<2)>>2]|0)|0,c[(c[o>>2]|0)+(l<<2)>>2]|0);break}}}while(0);f=b+180|0;l=b+4|0;o=g+7376|0;g=b+3068|0;m=b+184|0;k=0;p=e;e=h;a:while(1){if(k){break}h=c[f>>2]|0;if((e|0)>=(c[h+13112>>2]|0)){break}n=c[h+13104>>2]|0;r=c[h+13080>>2]|0;t=((p|0)%(n|0)|0)<<r;u=((p|0)/(n|0)|0)<<r;CAa(b,t,u,e);b1a(c[l>>2]|0,j,a,2);if((c[o>>2]|0)!=0){v=8;break}OAa(b,e);r=c[(c[f>>2]|0)+13080>>2]|0;DAa(b,t>>r,u>>r);w=EAa(b,t,u,c[(c[f>>2]|0)+13080>>2]|0,0)|0;if((w|0)<0){v=10;break}x=e+1|0;NAa(b,x);c1a(c[l>>2]|0,j,a,1);wBa(b,t,u,i);do{if((w|0)==0){r=t+i|0;n=c[f>>2]|0;h=c[n+13096>>2]|0;if((r|0)>=(h|0)){y=n;z=h;A=r;break}if((j|0)==(c[g>>2]|0)){y=n;z=h;A=r}else{v=15;break a}}else{r=c[f>>2]|0;y=r;z=c[r+13096>>2]|0;A=t+i|0}}while(0);if((A|0)>=(z|0)){v=18;break}k=(w|0)==0;p=c[(c[(c[m>>2]|0)+1656>>2]|0)+(x<<2)>>2]|0;e=x}do{if((v|0)==8){c1a(c[l>>2]|0,j,a,2);s=0;return s|0}else if((v|0)==10){c[(c[b+7332>>2]|0)+(p<<2)>>2]=-1;s=w;return s|0}else if((v|0)==15){c[o>>2]=1;c1a(c[l>>2]|0,j,a,2);s=0;return s|0}else if((v|0)==18){if((u+i|0)<(c[y+13100>>2]|0)){break}vBa(b,t,u);c1a(c[l>>2]|0,j,a,2);s=x;return s|0}}while(0);c1a(c[l>>2]|0,j,a,2);s=0;return s|0}function KAa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a>>2]|0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;a=b+(f>>>3)|0;h=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7);a=f+16|0;i=g>>>0>a>>>0?a:g;a=b+(i>>>3)|0;j=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>16|h&-65536;i=j>>>0>65535>>>0;a=i?h>>>16:j;j=i?16:0;if((a&65280|0)==0){k=j;l=a}else{k=j|8;l=a>>>8}a=(d[1191992+l|0]|0)+k|0;k=31-a|0;l=-f|0;j=g-f|0;if((k|0)<(l|0)){m=l}else{m=(j|0)<(k|0)?j:k}j=m+f|0;c[e>>2]=j;f=k+1|0;if((f|0)==0){n=0;o=n-1|0;return o|0}m=b+(j>>>3)|0;l=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7);if((f|0)<26){m=j+f|0;c[e>>2]=g>>>0>m>>>0?m:g;n=l>>>(a>>>0);o=n-1|0;return o|0}else{a=j+16|0;j=g>>>0>a>>>0?a:g;c[e>>2]=j;a=k-15|0;m=b+(j>>>3)|0;b=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>((47-k|0)>>>0);k=j+a|0;c[e>>2]=g>>>0>k>>>0?k:g;n=b|l>>>16<<a;o=n-1|0;return o|0}return 0}function LAa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;yAa(b);f=c[e+13064>>2]|0;g=e+13096|0;h=c[g>>2]|0;i=e+13100|0;j=c[i>>2]|0;k=ba(j,h)|0;l=ba((j>>f)+1|0,(h>>f)+1|0)|0;f=ba(c[e+13108>>2]|0,c[e+13104>>2]|0)|0;m=ba(c[e+13136>>2]|0,c[e+13132>>2]|0)|0;n=b+5808|0;c[n>>2]=h>>3;h=b+5812|0;c[h>>2]=j>>3;if(f>>>0<11671106>>>0){j=b+3464|0;c[j>>2]=cEb(f*184|0)|0;o=j;p=4}else{j=b+3464|0;c[j>>2]=0;if(f>>>0<268435455>>>0){o=j;p=4}else{q=0;r=j}}if((p|0)==4){q=cEb(f<<3)|0;r=o}o=b+3468|0;c[o>>2]=q;q=WDb(k)|0;c[b+7320>>2]=q;do{if((c[r>>2]|0)==0){p=15}else{if((c[o>>2]|0)==0|(q|0)==0){p=15;break}k=b+7336|0;c[k>>2]=WDb(l)|0;j=WDb(ba(c[e+13116>>2]|0,c[e+13120>>2]|0)|0)|0;c[b+7340>>2]=j;if((c[k>>2]|0)==0|(j|0)==0){p=15;break}j=b+7348|0;c[j>>2]=WDb(ba(c[e+13128>>2]|0,c[e+13124>>2]|0)|0)|0;k=b+7344|0;c[k>>2]=cEb(m)|0;s=WDb(m)|0;c[b+7352>>2]=s;if((c[k>>2]|0)==0){p=15;break}if((c[j>>2]|0)==0|(s|0)==0){p=15;break}s=b+7356|0;c[s>>2]=WDb(f)|0;j=b+7332|0;c[j>>2]=WDb(l<<2)|0;k=WDb(l)|0;c[b+7316>>2]=k;if((k|0)==0){p=15;break}if((c[s>>2]|0)==0){p=15;break}if((c[j>>2]|0)==0){p=15;break}j=b+7324|0;c[j>>2]=cEb(ba(c[n>>2]<<1,(c[h>>2]|0)+1|0)|0)|0;s=cEb(ba(c[n>>2]<<1,(c[h>>2]|0)+1|0)|0)|0;c[b+7328>>2]=s;if((c[j>>2]|0)==0|(s|0)==0){p=15;break}s=b+1404|0;c[s>>2]=aBb(m*14|0,1636)|0;j=aBb(f*392|0,728)|0;c[b+1408>>2]=j;if((c[s>>2]|0)==0|(j|0)==0){p=15;break}j=b+4|0;s=c[j>>2]|0;c[s+128>>2]=c[g>>2];c[s+132>>2]=c[i>>2];c[s+120>>2]=c[e+12>>2];c[s+124>>2]=c[e+16>>2];c[s+140>>2]=c[e+60>>2];k=e+160|0;t=s+224|0;s=c[k+4>>2]|0;c[t>>2]=c[k>>2];c[t+4>>2]=s;s=c[j>>2]|0;c[s+176>>2]=c[e+76+(((c[e+72>>2]|0)-1|0)*12|0)+4>>2];if((c[e+176>>2]|0)==0){c[s+396>>2]=1}else{c[s+396>>2]=(c[e+184>>2]|0)!=0?2:1}if((c[e+188>>2]|0)==0){c[s+384>>2]=2;c[s+388>>2]=2;c[s+392>>2]=2}else{c[s+384>>2]=d[e+192|0]|0;c[s+388>>2]=d[e+193|0]|0;c[s+392>>2]=d[e+194|0]|0}s=e+52|0;VEa(b+5820|0,c[s>>2]|0);eCa(b+5860|0,c[s>>2]|0);T3a(b+6064|0,c[s>>2]|0);if((a[e+12941|0]|0)!=0){s=b+168|0;KCb(c[s>>2]|0);t=_$a(c[j>>2]|0,c[s>>2]|0,1)|0;if((t|0)<0){u=t;break}c[b+160>>2]=c[s>>2]}c[b+180>>2]=e;s=c[(c[b+188+(c[e>>2]<<2)>>2]|0)+4>>2]|0;c[b+176>>2]=s;do{if((a[s+444|0]|0)==0){if((c[e+240>>2]|0)==0){v=0;return v|0}else{w=e+248|0;x=e+244|0;break}}else{w=s+452|0;x=s+448|0}}while(0);s=c[w>>2]|0;t=c[x>>2]|0;if((t|0)==0|(s|0)==0){v=0;return v|0}k=c[j>>2]|0;iFb(k+104|0,k+108|0,t,0,s,0,1073741824,0)|0;v=0;return v|0}}while(0);if((p|0)==15){yAa(b);u=-12}yAa(b);c[b+180>>2]=0;v=u;return v|0}function MAa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[b+60>>2]|0;c[d+4>>2]=b;e=cEb(184672)|0;f=e;c[d+136>>2]=f;a:do{if((e|0)!=0){c[d+72>>2]=f;c[d+8>>2]=d;g=WDb(183)|0;c[d+152>>2]=g;if((g|0)==0){break}g=ICb()|0;c[d+168>>2]=g;if((g|0)==0){break}g=ICb()|0;c[d+172>>2]=g;if((g|0)==0){break}g=d+3484|0;h=0;do{i=ICb()|0;c[g+(h*72|0)>>2]=i;if((i|0)==0){break a}c[g+(h*72|0)+4>>2]=i;h=h+1|0;}while(h>>>0<32>>>0);c[d+5804>>2]=2147483647;h=PDb()|0;c[d+7424>>2]=h;if((h|0)==0){break}Z3(d+6072|0,b);a[d+7477|0]=1;j=0;return j|0}}while(0);wAa(b)|0;j=-12;return j|0}function NAa(b,d){b=b|0;d=d|0;var e=0,f=0;if((a[(c[b+184>>2]|0)+43|0]|0)==0){return}e=c[(c[b+180>>2]|0)+13104>>2]|0;f=(d|0)%(e|0)|0;do{if((f|0)!=2){if((e|0)==2&(f|0)==0){break}return}}while(0);UGb(c[b+152>>2]|0,(c[b+136>>2]|0)+9088|0,183)|0;return}function OAa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=b+184|0;g=c[f>>2]|0;if((c[(c[g+1652>>2]|0)+(c[b+3460>>2]<<2)>>2]|0)==(e|0)){h=b+136|0;i=c[h>>2]|0;j=i+9280|0;k=c[i+9288>>2]|0;l=(c[j>>2]|0)+1|0;m=k>>>0>l>>>0?l:k;l=-m&7;if((l|0)==0){n=m}else{o=l+m|0;n=k>>>0>o>>>0?o:k}c[j>>2]=n;Uhb(i+9292|0,(c[i+9272>>2]|0)+((n|0)/8|0)|0,(7-n+(c[i+9284>>2]|0)|0)/8|0);i=b+2413|0;do{if((a[i]|0)==0){p=7}else{n=c[f>>2]|0;if((a[n+42|0]|0)==0){break}j=c[n+1660>>2]|0;if((c[j+(e<<2)>>2]|0)!=(c[j+(e-1<<2)>>2]|0)){p=7}}}while(0);if((p|0)==7){p=c[b+2404>>2]|0;j=2-p|0;n=(a[b+3024|0]|0)==0|(p|0)==2?j:j^3;j=b+3072|0;p=0;do{k=d[912760+(n*183|0)+p|0]|0;o=a[j]|0;m=o<<24>>24;if(o<<24>>24<0){q=0}else{q=(m|0)>51?51:m}m=((k<<3&120)-16+((ba(q,((k>>>4)*5|0)-45|0)|0)>>4)<<1)-127|0;k=m>>31^m;if((k|0)>124){r=(k&1|124)&255}else{r=k&255}a[(c[h>>2]|0)+9088+p|0]=r;p=p+1|0;}while((p|0)<183)}if((a[b+2412|0]|0)!=0){return}if((a[(c[f>>2]|0)+43|0]|0)==0){return}p=c[(c[b+180>>2]|0)+13104>>2]|0;if(((e|0)%(p|0)|0|0)!=0){return}if((p|0)!=1){if((a[i]|0)!=1){return}UGb((c[h>>2]|0)+9088|0,c[b+152>>2]|0,183)|0;return}i=c[b+2404>>2]|0;p=2-i|0;r=(a[b+3024|0]|0)==0|(i|0)==2?p:p^3;p=b+3072|0;i=0;do{q=d[912760+(r*183|0)+i|0]|0;j=a[p]|0;n=j<<24>>24;if(j<<24>>24<0){s=0}else{s=(n|0)>51?51:n}n=((q<<3&120)-16+((ba(s,((q>>>4)*5|0)-45|0)|0)>>4)<<1)-127|0;q=n>>31^n;if((q|0)>124){t=(q&1|124)&255}else{t=q&255}a[(c[h>>2]|0)+9088+i|0]=t;i=i+1|0;}while((i|0)<183);return}do{if((a[g+42|0]|0)==0){u=g}else{i=c[g+1660>>2]|0;if((c[i+(e<<2)>>2]|0)==(c[i+(e-1<<2)>>2]|0)){u=g;break}i=b+136|0;t=c[i>>2]|0;do{if((a[b+141|0]|0)==1){h=t+9292|0;s=c[t+9308>>2]|0;p=c[h>>2]|0;r=(p&1|0)==0?s:s-1|0;s=(p&511|0)==0?r:r-1|0;r=(c[t+9312>>2]|0)-s|0;if((r|0)<0){break}Uhb(h,s,r)}else{r=t+9280|0;s=c[t+9288>>2]|0;h=(c[r>>2]|0)+1|0;p=s>>>0>h>>>0?h:s;h=-p&7;if((h|0)==0){v=p}else{q=h+p|0;v=s>>>0>q>>>0?q:s}c[r>>2]=v;Uhb(t+9292|0,(c[t+9272>>2]|0)+((v|0)/8|0)|0,(7-v+(c[t+9284>>2]|0)|0)/8|0)}}while(0);t=c[b+2404>>2]|0;r=2-t|0;s=(a[b+3024|0]|0)==0|(t|0)==2?r:r^3;r=b+3072|0;t=0;do{q=d[912760+(s*183|0)+t|0]|0;p=a[r]|0;h=p<<24>>24;if(p<<24>>24<0){w=0}else{w=(h|0)>51?51:h}h=((q<<3&120)-16+((ba(w,((q>>>4)*5|0)-45|0)|0)>>4)<<1)-127|0;q=h>>31^h;if((q|0)>124){x=(q&1|124)&255}else{x=q&255}a[(c[i>>2]|0)+9088+t|0]=x;t=t+1|0;}while((t|0)<183);u=c[f>>2]|0}}while(0);if((a[u+43|0]|0)==0){return}u=b+180|0;if(((e|0)%(c[(c[u>>2]|0)+13104>>2]|0)|0|0)!=0){return}e=b+136|0;f=c[e>>2]|0;x=f+9296|0;w=c[x>>2]|0;v=w-2|0;c[x>>2]=v;g=f+9292|0;t=c[g>>2]|0;do{if((t|0)<(v<<17|0)){i=(w-258|0)>>>31;c[x>>2]=v<<i;r=t<<i;c[g>>2]=r;if((r&65535|0)!=0){break}i=f+9308|0;s=c[i>>2]|0;c[g>>2]=r-65535+(d[s+1|0]<<1|d[s]<<9);if(!(s>>>0<(c[f+9312>>2]|0)>>>0)){break}c[i>>2]=s+2}}while(0);f=c[e>>2]|0;do{if((a[b+141|0]|0)==1){g=f+9292|0;t=c[f+9308>>2]|0;v=c[g>>2]|0;x=(v&1|0)==0?t:t-1|0;t=(v&511|0)==0?x:x-1|0;x=(c[f+9312>>2]|0)-t|0;if((x|0)<0){break}Uhb(g,t,x)}else{x=f+9280|0;t=c[f+9288>>2]|0;g=(c[x>>2]|0)+1|0;v=t>>>0>g>>>0?g:t;g=-v&7;if((g|0)==0){y=v}else{w=g+v|0;y=t>>>0>w>>>0?w:t}c[x>>2]=y;Uhb(f+9292|0,(c[f+9272>>2]|0)+((y|0)/8|0)|0,(7-y+(c[f+9284>>2]|0)|0)/8|0)}}while(0);if((c[(c[u>>2]|0)+13104>>2]|0)!=1){UGb((c[e>>2]|0)+9088|0,c[b+152>>2]|0,183)|0;return}u=c[b+2404>>2]|0;f=2-u|0;y=(a[b+3024|0]|0)==0|(u|0)==2?f:f^3;f=b+3072|0;b=0;do{u=d[912760+(y*183|0)+b|0]|0;x=a[f]|0;t=x<<24>>24;if(x<<24>>24<0){z=0}else{z=(t|0)>51?51:t}t=((u<<3&120)-16+((ba(z,((u>>>4)*5|0)-45|0)|0)>>4)<<1)-127|0;u=t>>31^t;if((u|0)>124){A=(u&1|124)&255}else{A=u&255}a[(c[e>>2]|0)+9088+b|0]=A;b=b+1|0;}while((b|0)<183);return}function PAa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return QAa(b+9292|0,b+9088|0)|0}function QAa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d[e]|0;g=b+4|0;h=c[g>>2]|0;i=d[1208480+((h<<1&384)+(f|512))|0]|0;j=h-i|0;h=j<<17;k=b|0;l=c[k>>2]|0;m=h-l>>31;c[k>>2]=l-(m&h);c[g>>2]=(m&i-j)+j;j=m^f;a[e]=a[j+1209632|0]|0;e=j&1;j=c[g>>2]|0;f=d[1208480+j|0]|0;c[g>>2]=j<<f;j=c[k>>2]<<f;c[k>>2]=j;if((j&65535|0)!=0){return e|0}f=b+16|0;g=c[f>>2]|0;c[k>>2]=(((d[g+1|0]|0)<<1|(d[g]|0)<<9)-65535<<7-(d[1208480+((j-1^j)>>15)|0]|0))+j;if(!(g>>>0<(c[b+20>>2]|0)>>>0)){return e|0}c[f>>2]=g+2;return e|0}function RAa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+136|0;a=c[b>>2]|0;if((QAa(a+9292|0,a+9089|0)|0)==0){e=0;return e|0}a=c[b>>2]|0;b=a+9292|0;f=c[b>>2]<<1;c[b>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[b>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){e=1;return e|0}c[b>>2]=j-f;e=2;return e|0}function SAa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=a+136|0;a=c[b>>2]|0;e=a+9292|0;f=c[e>>2]<<1;c[e>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[e>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){k=0}else{c[e>>2]=j-f;k=16}f=c[b>>2]|0;j=f+9292|0;e=c[j>>2]<<1;c[j>>2]=e;do{if((e&65534|0)==0){a=f+9308|0;i=c[a>>2]|0;h=e-65535+((d[i+1|0]|0)<<1|(d[i]|0)<<9)|0;c[j>>2]=h;if(!(i>>>0<(c[f+9312>>2]|0)>>>0)){l=h;break}c[a>>2]=i+2;l=h}else{l=e}}while(0);e=c[f+9296>>2]<<17;if((l|0)<(e|0)){m=0}else{c[j>>2]=l-e;m=8}e=m|k;k=c[b>>2]|0;m=k+9292|0;l=c[m>>2]<<1;c[m>>2]=l;do{if((l&65534|0)==0){j=k+9308|0;f=c[j>>2]|0;h=l-65535+((d[f+1|0]|0)<<1|(d[f]|0)<<9)|0;c[m>>2]=h;if(!(f>>>0<(c[k+9312>>2]|0)>>>0)){n=h;break}c[j>>2]=f+2;n=h}else{n=l}}while(0);l=c[k+9296>>2]<<17;if((n|0)<(l|0)){o=0}else{c[m>>2]=n-l;o=4}l=o|e;e=c[b>>2]|0;o=e+9292|0;n=c[o>>2]<<1;c[o>>2]=n;do{if((n&65534|0)==0){m=e+9308|0;k=c[m>>2]|0;h=n-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[o>>2]=h;if(!(k>>>0<(c[e+9312>>2]|0)>>>0)){p=h;break}c[m>>2]=k+2;p=h}else{p=n}}while(0);n=c[e+9296>>2]<<17;if((p|0)<(n|0)){q=0}else{c[o>>2]=p-n;q=2}n=q|l;l=c[b>>2]|0;b=l+9292|0;q=c[b>>2]<<1;c[b>>2]=q;do{if((q&65534|0)==0){p=l+9308|0;o=c[p>>2]|0;e=q-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9)|0;c[b>>2]=e;if(!(o>>>0<(c[l+9312>>2]|0)>>>0)){r=e;break}c[p>>2]=o+2;r=e}else{r=q}}while(0);q=c[l+9296>>2]<<17;if((r|0)<(q|0)){s=0;t=s|n;return t|0}c[b>>2]=r-q;s=1;t=s|n;return t|0}function TAa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[(c[a+180>>2]|0)+52>>2]|0;e=(b|0)>10?31:(1<<b-5)-1|0;if((e|0)<=0){f=0;return f|0}b=a+136|0;a=0;while(1){g=c[b>>2]|0;h=g+9292|0;i=c[h>>2]<<1;c[h>>2]=i;do{if((i&65534|0)==0){j=g+9308|0;k=c[j>>2]|0;l=i-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[h>>2]=l;if(!(k>>>0<(c[g+9312>>2]|0)>>>0)){m=l;break}c[j>>2]=k+2;m=l}else{m=i}}while(0);i=c[g+9296>>2]<<17;if((m|0)<(i|0)){f=a;n=8;break}c[h>>2]=m-i;i=a+1|0;if((i|0)<(e|0)){a=i}else{f=i;n=8;break}}if((n|0)==8){return f|0}return 0}function UAa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+136>>2]|0;a=b+9292|0;e=c[a>>2]<<1;c[a>>2]=e;do{if((e&65534|0)==0){f=b+9308|0;g=c[f>>2]|0;h=e-65535+((d[g+1|0]|0)<<1|(d[g]|0)<<9)|0;c[a>>2]=h;if(!(g>>>0<(c[b+9312>>2]|0)>>>0)){i=h;break}c[f>>2]=g+2;i=h}else{i=e}}while(0);e=c[b+9296>>2]<<17;if((i|0)<(e|0)){j=0;return j|0}c[a>>2]=i-e;j=1;return j|0}function VAa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+136|0;a=c[b>>2]|0;e=a+9292|0;f=c[e>>2]<<1;c[e>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[e>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){k=0}else{c[e>>2]=j-f;k=2}f=c[b>>2]|0;b=f+9292|0;j=c[b>>2]<<1;c[b>>2]=j;do{if((j&65534|0)==0){e=f+9308|0;a=c[e>>2]|0;i=j-65535+((d[a+1|0]|0)<<1|(d[a]|0)<<9)|0;c[b>>2]=i;if(!(a>>>0<(c[f+9312>>2]|0)>>>0)){l=i;break}c[e>>2]=a+2;l=i}else{l=j}}while(0);j=c[f+9296>>2]<<17;if((l|0)<(j|0)){m=0;n=m|k;return n|0}c[b>>2]=l-j;m=1;n=m|k;return n|0}function WAa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+136>>2]|0;a=b+9296|0;e=c[a>>2]|0;f=e-2|0;c[a>>2]=f;g=b+9292|0;h=c[g>>2]|0;if((h|0)>=(f<<17|0)){i=(c[b+9308>>2]|0)-(c[b+9304>>2]|0)|0;return i|0}j=(e-258|0)>>>31;c[a>>2]=f<<j;f=h<<j;c[g>>2]=f;if((f&65535|0)!=0){i=0;return i|0}j=b+9308|0;h=c[j>>2]|0;c[g>>2]=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9);if(!(h>>>0<(c[b+9312>>2]|0)>>>0)){i=0;return i|0}c[j>>2]=h+2;i=0;return i|0}function XAa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return QAa(b+9292|0,b+9093|0)|0}function YAa(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=c[b+180>>2]|0;i=c[h+13116>>2]|0;j=(1<<c[h+13080>>2])-1|0;h=j&e;e=c[b+136>>2]|0;if((a[e+173200|0]|0)==0){if((j&d|0)==0){k=0}else{l=3}}else{l=3}if((l|0)==3){l=f-1+(ba(i,g)|0)|0;k=(a[(c[b+7336>>2]|0)+l|0]|0)!=0|0}if((a[e+173201|0]|0)==0&(h|0)==0){m=k;n=e+9292|0;o=m+6|0;p=e+9088+o|0;q=QAa(n,p)|0;return q|0}h=(ba(i,g-1|0)|0)+f|0;m=((a[(c[b+7336>>2]|0)+h|0]|0)!=0)+k|0;n=e+9292|0;o=m+6|0;p=e+9088+o|0;q=QAa(n,p)|0;return q|0}function ZAa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;e=a+136|0;f=9;g=0;while(1){if((g|0)>=5){h=0;j=0;break}k=c[e>>2]|0;if((QAa(k+9292|0,k+9088+f|0)|0)==0){l=0;m=17;break}else{f=10;g=g+1|0}}if((m|0)==17){n=l+g|0;i=b;return n|0}while(1){m=c[e>>2]|0;f=m+9292|0;k=c[f>>2]<<1;c[f>>2]=k;do{if((k&65534|0)==0){o=m+9308|0;p=c[o>>2]|0;q=k-65535+((d[p+1|0]|0)<<1|(d[p]|0)<<9)|0;c[f>>2]=q;if(!(p>>>0<(c[m+9312>>2]|0)>>>0)){r=q;break}c[o>>2]=p+2;r=q}else{r=k}}while(0);k=c[m+9296>>2]<<17;if((r|0)<(k|0)){s=h;t=j;break}c[f>>2]=r-k;k=(1<<j)+h|0;q=j+1|0;if((q|0)<100){h=k;j=q}else{s=k;t=q;break}}if((t|0)==0){l=s;n=l+g|0;i=b;return n|0}else if((t|0)==100){yDb(c[a+4>>2]|0,16,2279400,(a=i,i=i+8|0,c[a>>2]=100,a)|0);i=a;u=s;v=100}else{u=s;v=t}while(1){t=v-1|0;s=c[e>>2]|0;a=s+9292|0;j=c[a>>2]<<1;c[a>>2]=j;do{if((j&65534|0)==0){h=s+9308|0;r=c[h>>2]|0;q=j-65535+((d[r+1|0]|0)<<1|(d[r]|0)<<9)|0;c[a>>2]=q;if(!(r>>>0<(c[s+9312>>2]|0)>>>0)){w=q;break}c[h>>2]=r+2;w=q}else{w=j}}while(0);j=c[s+9296>>2]<<17;if((w|0)<(j|0)){x=0}else{c[a>>2]=w-j;x=1}j=(x<<t)+u|0;if((t|0)==0){l=j;break}else{u=j;v=t}}n=l+g|0;i=b;return n|0}function _Aa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+136>>2]|0;a=b+9292|0;e=c[a>>2]<<1;c[a>>2]=e;do{if((e&65534|0)==0){f=b+9308|0;g=c[f>>2]|0;h=e-65535+((d[g+1|0]|0)<<1|(d[g]|0)<<9)|0;c[a>>2]=h;if(!(g>>>0<(c[b+9312>>2]|0)>>>0)){i=h;break}c[f>>2]=g+2;i=h}else{i=e}}while(0);e=c[b+9296>>2]<<17;if((i|0)<(e|0)){j=0;return j|0}c[a>>2]=i-e;j=1;return j|0}function $Aa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return QAa(b+9292|0,b+9100|0)|0}function aBa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=c[b+180>>2]|0;i=(1<<c[h+13080>>2])-1|0;j=i&g;k=c[h+13064>>2]|0;l=f>>k;m=g>>k;k=c[b+136>>2]|0;if((a[k+173200|0]|0)==0){if((i&f|0)==0){n=0}else{o=3}}else{o=3}if((o|0)==3){o=l-1+(ba(c[h+13116>>2]|0,m)|0)|0;n=d[(c[b+7340>>2]|0)+o|0]|0}if((a[k+173201|0]|0)==0&(j|0)==0){p=0}else{j=(ba(c[h+13116>>2]|0,m-1|0)|0)+l|0;p=d[(c[b+7340>>2]|0)+j|0]|0}return QAa(k+9292|0,((n|0)>(e|0)|2)+((p|0)>(e|0))+(k+9088)|0)|0}function bBa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+136|0;g=c[f>>2]|0;if((QAa(g+9292|0,g+9101|0)|0)!=0){h=0;return h|0}g=c[b+180>>2]|0;if((c[g+13064>>2]|0)==(e|0)){b=c[f>>2]|0;if((c[b+184588>>2]|0)==1){h=3;return h|0}if((QAa(b+9292|0,b+9102|0)|0)!=0){h=1;return h|0}if((e|0)==3){h=2;return h|0}e=c[f>>2]|0;b=(QAa(e+9292|0,e+9103|0)|0)==0;h=b?3:2;return h|0}b=(a[g+12940|0]|0)==0;g=c[f>>2]|0;e=(QAa(g+9292|0,g+9102|0)|0)!=0;if(b){h=e?1:2;return h|0}b=c[f>>2]|0;g=(QAa(b+9292|0,b+9104|0)|0)!=0;if(e){if(g){h=1;return h|0}e=c[f>>2]|0;b=e+9292|0;i=c[b>>2]<<1;c[b>>2]=i;do{if((i&65534|0)==0){j=e+9308|0;k=c[j>>2]|0;l=i-65535+(d[k+1|0]<<1|d[k]<<9)|0;c[b>>2]=l;if(!(k>>>0<(c[e+9312>>2]|0)>>>0)){m=l;break}c[j>>2]=k+2;m=l}else{m=i}}while(0);i=c[e+9296>>2]<<17;if((m|0)<(i|0)){h=4;return h|0}c[b>>2]=m-i;h=5;return h|0}else{if(g){h=2;return h|0}g=c[f>>2]|0;f=g+9292|0;i=c[f>>2]<<1;c[f>>2]=i;do{if((i&65534|0)==0){m=g+9308|0;b=c[m>>2]|0;e=i-65535+(d[b+1|0]<<1|d[b]<<9)|0;c[f>>2]=e;if(!(b>>>0<(c[g+9312>>2]|0)>>>0)){n=e;break}c[m>>2]=b+2;n=e}else{n=i}}while(0);i=c[g+9296>>2]<<17;if((n|0)<(i|0)){h=6;return h|0}c[f>>2]=n-i;h=7;return h|0}return 0}function cBa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+136>>2]|0;a=b+9296|0;e=c[a>>2]|0;f=e-2|0;c[a>>2]=f;g=b+9292|0;h=c[g>>2]|0;if((h|0)>=(f<<17|0)){i=(c[b+9308>>2]|0)-(c[b+9304>>2]|0)|0;return i|0}j=(e-258|0)>>>31;c[a>>2]=f<<j;f=h<<j;c[g>>2]=f;if((f&65535|0)!=0){i=0;return i|0}j=b+9308|0;h=c[j>>2]|0;c[g>>2]=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9);if(!(h>>>0<(c[b+9312>>2]|0)>>>0)){i=0;return i|0}c[j>>2]=h+2;i=0;return i|0}function dBa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return QAa(b+9292|0,b+9105|0)|0}function eBa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+136|0;a=c[b>>2]|0;e=a+9292|0;f=c[e>>2]<<1;c[e>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[e>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){k=0;return k|0}c[e>>2]=j-f;f=c[b>>2]|0;b=f+9292|0;j=c[b>>2]<<1;c[b>>2]=j;do{if((j&65534|0)==0){e=f+9308|0;a=c[e>>2]|0;i=j-65535+((d[a+1|0]|0)<<1|(d[a]|0)<<9)|0;c[b>>2]=i;if(!(a>>>0<(c[f+9312>>2]|0)>>>0)){l=i;break}c[e>>2]=a+2;l=i}else{l=j}}while(0);j=c[f+9296>>2]<<17;if((l|0)<(j|0)){k=1;return k|0}c[b>>2]=l-j;k=2;return k|0}function fBa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=a+136|0;a=c[b>>2]|0;e=a+9292|0;f=c[e>>2]<<1;c[e>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[e>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){k=0}else{c[e>>2]=j-f;k=16}f=c[b>>2]|0;j=f+9292|0;e=c[j>>2]<<1;c[j>>2]=e;do{if((e&65534|0)==0){a=f+9308|0;i=c[a>>2]|0;h=e-65535+((d[i+1|0]|0)<<1|(d[i]|0)<<9)|0;c[j>>2]=h;if(!(i>>>0<(c[f+9312>>2]|0)>>>0)){l=h;break}c[a>>2]=i+2;l=h}else{l=e}}while(0);e=c[f+9296>>2]<<17;if((l|0)<(e|0)){m=0}else{c[j>>2]=l-e;m=8}e=m|k;k=c[b>>2]|0;m=k+9292|0;l=c[m>>2]<<1;c[m>>2]=l;do{if((l&65534|0)==0){j=k+9308|0;f=c[j>>2]|0;h=l-65535+((d[f+1|0]|0)<<1|(d[f]|0)<<9)|0;c[m>>2]=h;if(!(f>>>0<(c[k+9312>>2]|0)>>>0)){n=h;break}c[j>>2]=f+2;n=h}else{n=l}}while(0);l=c[k+9296>>2]<<17;if((n|0)<(l|0)){o=0}else{c[m>>2]=n-l;o=4}l=o|e;e=c[b>>2]|0;o=e+9292|0;n=c[o>>2]<<1;c[o>>2]=n;do{if((n&65534|0)==0){m=e+9308|0;k=c[m>>2]|0;h=n-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[o>>2]=h;if(!(k>>>0<(c[e+9312>>2]|0)>>>0)){p=h;break}c[m>>2]=k+2;p=h}else{p=n}}while(0);n=c[e+9296>>2]<<17;if((p|0)<(n|0)){q=0}else{c[o>>2]=p-n;q=2}n=q|l;l=c[b>>2]|0;b=l+9292|0;q=c[b>>2]<<1;c[b>>2]=q;do{if((q&65534|0)==0){p=l+9308|0;o=c[p>>2]|0;e=q-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9)|0;c[b>>2]=e;if(!(o>>>0<(c[l+9312>>2]|0)>>>0)){r=e;break}c[p>>2]=o+2;r=e}else{r=q}}while(0);q=c[l+9296>>2]<<17;if((r|0)<(q|0)){s=0;t=s|n;return t|0}c[b>>2]=r-q;s=1;t=s|n;return t|0}function gBa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+136|0;a=c[b>>2]|0;if((QAa(a+9292|0,a+9106|0)|0)==0){e=4;return e|0}a=c[b>>2]|0;f=a+9292|0;g=c[f>>2]<<1;c[f>>2]=g;do{if((g&65534|0)==0){h=a+9308|0;i=c[h>>2]|0;j=g-65535+((d[i+1|0]|0)<<1|(d[i]|0)<<9)|0;c[f>>2]=j;if(!(i>>>0<(c[a+9312>>2]|0)>>>0)){k=j;break}c[h>>2]=i+2;k=j}else{k=g}}while(0);g=c[a+9296>>2]<<17;if((k|0)<(g|0)){l=0}else{c[f>>2]=k-g;l=2}g=c[b>>2]|0;b=g+9292|0;k=c[b>>2]<<1;c[b>>2]=k;do{if((k&65534|0)==0){f=g+9308|0;a=c[f>>2]|0;j=k-65535+((d[a+1|0]|0)<<1|(d[a]|0)<<9)|0;c[b>>2]=j;if(!(a>>>0<(c[g+9312>>2]|0)>>>0)){m=j;break}c[f>>2]=a+2;m=j}else{m=k}}while(0);k=c[g+9296>>2]<<17;if((m|0)<(k|0)){n=0}else{c[b>>2]=m-k;n=1}e=n|l;return e|0}function hBa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+136|0;e=c[b>>2]|0;f=QAa(e+9292|0,e+9109|0)|0;if((f|0)==0){g=0;return g|0}e=a+3052|0;if(f>>>0<((c[e>>2]|0)-1|0)>>>0){h=f}else{g=f;return g|0}while(1){f=c[b>>2]|0;a=f+9292|0;i=c[a>>2]<<1;c[a>>2]=i;do{if((i&65534|0)==0){j=f+9308|0;k=c[j>>2]|0;l=i-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[a>>2]=l;if(!(k>>>0<(c[f+9312>>2]|0)>>>0)){m=l;break}c[j>>2]=k+2;m=l}else{m=i}}while(0);i=c[f+9296>>2]<<17;if((m|0)<(i|0)){g=h;n=8;break}c[a>>2]=m-i;i=h+1|0;if(i>>>0<((c[e>>2]|0)-1|0)>>>0){h=i}else{g=i;n=8;break}}if((n|0)==8){return g|0}return 0}function iBa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return QAa(b+9292|0,b+9108|0)|0}function jBa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=a+136|0;a=c[e>>2]|0;f=a+9292|0;if((d+b|0)==12){g=QAa(f,a+9114|0)|0;return g|0}if((QAa(f,(c[a+184576>>2]|0)+22+(a+9088)|0)|0)!=0){g=2;return g|0}a=c[e>>2]|0;g=QAa(a+9292|0,a+9114|0)|0;return g|0}function kBa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b-1|0;b=(e|0)>2;f=b?2:e;g=a+136|0;a=0;while(1){if((a|0)>=(f|0)){break}h=c[g>>2]|0;if((QAa(h+9292|0,a+27+(h+9088)|0)|0)==0){break}else{a=a+1|0}}if((a|0)!=2|b^1){i=a;return i|0}else{j=2}while(1){a=c[g>>2]|0;b=a+9292|0;f=c[b>>2]<<1;c[b>>2]=f;do{if((f&65534|0)==0){h=a+9308|0;k=c[h>>2]|0;l=f-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[b>>2]=l;if(!(k>>>0<(c[a+9312>>2]|0)>>>0)){m=l;break}c[h>>2]=k+2;m=l}else{m=f}}while(0);f=c[a+9296>>2]<<17;if((m|0)<(f|0)){i=j;n=10;break}c[b>>2]=m-f;f=j+1|0;if((f|0)<(e|0)){j=f}else{i=f;n=10;break}}if((n|0)==10){return i|0}return 0}function lBa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return QAa(b+9292|0,b+9123|0)|0}function mBa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return QAa(b+9292|0,b+9124|0)|0}function nBa(a,b){a=a|0;b=b|0;var d=0;d=c[a+136>>2]|0;return QAa(d+9292|0,42-b+(d+9088)|0)|0}function oBa(a,b){a=a|0;b=b|0;var d=0;d=c[a+136>>2]|0;return QAa(d+9292|0,b+42+(d+9088)|0)|0}function pBa(a,b){a=a|0;b=b|0;var d=0;d=c[a+136>>2]|0;return QAa(d+9292|0,((b|0)==0|40)+(d+9088)|0)|0}function qBa(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0;l=i;i=i+2144|0;m=l|0;n=l+2048|0;o=l+2112|0;p=l+2128|0;q=e+136|0;r=c[q>>2]|0;s=c[e+160>>2]|0;t=c[s+32+(k<<2)>>2]|0;u=e+180|0;v=c[u>>2]|0;w=ba(g>>c[v+13152+(k<<2)>>2],t)|0;g=(c[s+(k<<2)>>2]|0)+(w+(f>>c[v+13140+(k<<2)>>2]<<c[v+56>>2]))|0;TGb(m|0,0,2048)|0;TGb(n|0,0,64)|0;f=1<<h;w=r+184600|0;s=(a[w]|0)==0;do{if(s){x=a[r+173182|0]|0;if((k|0)==0){y=(c[v+13164>>2]|0)+x|0}else{z=c[e+184>>2]|0;if((k|0)==1){A=(c[e+3036>>2]|0)+(c[z+28>>2]|0)|0}else{A=(c[e+3040>>2]|0)+(c[z+32>>2]|0)|0}z=A+x|0;x=c[v+13164>>2]|0;B=-x|0;if((z|0)<(B|0)){C=B}else{C=(z|0)>57?57:z}do{if((C|0)<30){D=C}else{if((C|0)>43){D=C-6|0;break}else{D=c[1206792+(C-30<<2)>>2]|0;break}}}while(0);y=x+D|0}z=(c[v+52>>2]|0)+h|0;B=z-5|0;E=1<<z-6;z=d[1206848+(d[1206728+y|0]|0)|0]<<d[1206856+y|0];if((a[v+634|0]|0)==0){G=B;H=E;I=z;J=16;K=0;break}L=c[e+184>>2]|0;M=(a[L+68|0]|0)==0?v+635|0:L+69|0;L=(c[r+184588>>2]|0)!=1|0;if((h|0)==5){N=L;O=M+1152+(L<<6)|0}else{P=(-L&3)+k|0;L=M+((h-2|0)*384|0)+(P<<6)|0;if((h|0)>3){N=P;O=L}else{G=B;H=E;I=z;J=16;K=L;break}}G=B;H=E;I=z;J=d[M+1536+((h-4|0)*6|0)+N|0]|0;K=O}else{G=0;H=0;I=0;J=0;K=0}}while(0);O=e+184|0;do{if((a[(c[O>>2]|0)+21|0]|0)==0){Q=0}else{if(!(s&(h|0)==2)){Q=0;break}Q=QAa(r+9292|0,((k|0)!=0|46)+(r+9088)|0)|0}}while(0);s=(h<<1)-1|0;N=(k|0)==0;if(N){R=h+1>>2;S=(h*3|0)+42+(h-1>>2)|0}else{R=h-2|0;S=63}v=0;while(1){if((v|0)>=(s|0)){break}y=c[q>>2]|0;if((QAa(y+9292|0,(v>>R)+S+(y+9088)|0)|0)==0){break}else{v=v+1|0}}if(N){T=h+1>>2;U=(h*3|0)+60+(h-1>>2)|0}else{T=h-2|0;U=81}S=0;while(1){if((S|0)>=(s|0)){break}R=c[q>>2]|0;if((QAa(R+9292|0,(S>>T)+U+(R+9088)|0)|0)==0){break}else{S=S+1|0}}if((v|0)>3){U=(v>>1)-1|0;T=c[q>>2]|0;s=T+9292|0;R=c[s>>2]<<1;c[s>>2]=R;do{if((R&65534|0)==0){y=T+9308|0;D=c[y>>2]|0;C=R-65535+(d[D+1|0]<<1|d[D]<<9)|0;c[s>>2]=C;if(!(D>>>0<(c[T+9312>>2]|0)>>>0)){V=C;break}c[y>>2]=D+2;V=C}else{V=R}}while(0);R=c[T+9296>>2]<<17;if((V|0)<(R|0)){W=0}else{c[s>>2]=V-R;W=1}a:do{if((U|0)>1){R=2;V=W;while(1){s=V<<1;T=c[q>>2]|0;C=T+9292|0;D=c[C>>2]<<1;c[C>>2]=D;do{if((D&65534|0)==0){y=T+9308|0;A=c[y>>2]|0;M=D-65535+(d[A+1|0]<<1|d[A]<<9)|0;c[C>>2]=M;if(!(A>>>0<(c[T+9312>>2]|0)>>>0)){X=M;break}c[y>>2]=A+2;X=M}else{X=D}}while(0);D=c[T+9296>>2]<<17;if((X|0)<(D|0)){Y=0}else{c[C>>2]=X-D;Y=1}D=Y|s;if((R|0)>=(U|0)){Z=D;break a}R=R+1|0;V=D}}else{Z=W}}while(0);_=Z+((v&1|2)<<U)|0}else{_=v}if((S|0)>3){v=(S>>1)-1|0;U=c[q>>2]|0;Z=U+9292|0;W=c[Z>>2]<<1;c[Z>>2]=W;do{if((W&65534|0)==0){Y=U+9308|0;X=c[Y>>2]|0;V=W-65535+(d[X+1|0]<<1|d[X]<<9)|0;c[Z>>2]=V;if(!(X>>>0<(c[U+9312>>2]|0)>>>0)){$=V;break}c[Y>>2]=X+2;$=V}else{$=W}}while(0);W=c[U+9296>>2]<<17;if(($|0)<(W|0)){aa=0}else{c[Z>>2]=$-W;aa=1}b:do{if((v|0)>1){W=2;$=aa;while(1){Z=$<<1;U=c[q>>2]|0;V=U+9292|0;X=c[V>>2]<<1;c[V>>2]=X;do{if((X&65534|0)==0){Y=U+9308|0;R=c[Y>>2]|0;x=X-65535+(d[R+1|0]<<1|d[R]<<9)|0;c[V>>2]=x;if(!(R>>>0<(c[U+9312>>2]|0)>>>0)){ca=x;break}c[Y>>2]=R+2;ca=x}else{ca=X}}while(0);X=c[U+9296>>2]<<17;if((ca|0)<(X|0)){da=0}else{c[V>>2]=ca-X;da=1}X=da|Z;if((W|0)>=(v|0)){ea=X;break b}W=W+1|0;$=X}}else{ea=aa}}while(0);fa=ea+((S&1|2)<<v)|0}else{fa=S}S=(j|0)==2;v=S?_:fa;ea=S?fa:_;_=ea>>2;fa=v>>2;do{if((j|0)==0){S=d[(ea&3)+(1376248+((v&3)<<2))|0]|0;if((f|0)==4){ga=S;ha=4312600;ia=4312600;ja=1207176;ka=1207160;break}else if((f|0)==8){ga=(d[1376264+(fa<<1)+_|0]<<4)+S|0;ha=931624;ia=931632;ja=1207176;ka=1207160;break}else if((f|0)==16){ga=(d[1376248+(fa<<2)+_|0]<<4)+S|0;ha=1207176;ia=1207160;ja=1207176;ka=1207160;break}else{ga=(d[1376184+(fa<<3)+_|0]<<4)+S|0;ha=1207096;ia=1207032;ja=1207176;ka=1207160;break}}else if((j|0)==1){ga=d[931528+(v<<3)+ea|0]|0;ha=931632;ia=931624;ja=931608;ka=931592}else{ga=d[931528+(ea<<3)+v|0]|0;ha=931624;ia=931632;ja=931592;ka=931608}}while(0);v=ga+1|0;ea=ga>>4;if((ea|0)>-1){ga=(1<<h-2)-1|0;S=(k|0)>0;aa=S?86:84;da=o|0;ca=f-1>>2;f=(h|0)==2;$=(h|0)==3;W=(j|0)==0?9:15;j=(k|0)!=0?12:21;k=p|0;X=N?2:0;s=I;C=(I|0)<0|0?-1:0;I=H;T=(H|0)<0|0?-1:0;H=G;G=(h|0)<4;x=e+4|0;R=16;Y=ea;D=1;while(1){M=Y<<4;A=a[ha+Y|0]|0;y=A&255;z=a[ia+Y|0]|0;E=z&255;B=(Y|0)>0;if((Y|0)<(ea|0)&B){if((y|0)<(ga|0)){la=d[n+(y+1<<3)+E|0]|0}else{la=0}if((E|0)<(ga|0)){ma=(d[E+1+(n+(y<<3))|0]|0)+la|0}else{ma=la}L=c[q>>2]|0;P=(QAa(L+9292|0,((ma|0)>1?1:ma)+aa+(L+9088)|0)|0)&255;a[n+(y<<3)+E|0]=P;na=1;oa=P}else{do{if((y|0)==(_|0)&(E|0)==(fa|0)){pa=1}else{if(!(A<<24>>24==0)){pa=0;break}pa=z<<24>>24==0|0}}while(0);a[n+(y<<3)+E|0]=pa;na=0;oa=pa}z=v-M|0;A=(Y|0)==(ea|0);if(A){a[da]=z+255;qa=z-2|0;ra=1}else{qa=15;ra=0}if((y|0)<(ca|0)){sa=d[n+(y+1<<3)+E|0]|0}else{sa=0}if((E|0)<(ca|0)){ta=(d[E+1+(n+(y<<3))|0]<<1)+sa|0}else{ta=sa}c:do{if((qa|0)>-1){z=M>>4;P=d[ha+z|0]<<2;L=d[ia+z|0]<<2;z=y<<2;ua=E<<2;if(oa<<24>>24==0){va=qa;while(1){if((va|0)>0){va=va-1|0}else{wa=ra;break c}}}else{xa=qa;ya=na;za=ra;Aa=oa}while(1){va=P+(d[ja+xa|0]|0)|0;Z=L+(d[ka+xa|0]|0)|0;do{if((xa|0)>0|(ya|0)==0){do{if((va|0)==(-Z|0)){Ba=0}else{if(f){Ba=d[437544+((Z<<2)+va)|0]|0;break}do{if((ta|0)==1){V=Z&3;Ca=(V|0)==3?0:2-V|0}else if((ta|0)==0){V=(Z&3)+(va&3)|0;if((V|0)==0){Ca=2;break}Ca=(V|0)<3|0}else if((ta|0)==2){V=va&3;Ca=(V|0)==3?0:2-V|0}else{Ca=2}}while(0);if(N){Da=((Z|va)&2147483644|0)!=0?Ca+3|0:Ca}else{Da=Ca}if($){Ba=Da+W|0;break}else{Ba=Da+j|0;break}}}while(0);V=c[q>>2]|0;if((QAa(V+9292|0,(N?Ba:Ba+27|0)+88+(V+9088)|0)|0)!=1){Ea=za;Fa=ya;Ga=Aa;break}a[o+(za&255)|0]=xa;Ea=za+1&255;Fa=0;Ga=Aa}else{if((va|0)!=(z|0)){Ea=za;Fa=ya;Ga=Aa;break}if((Z|0)!=(ua|0)|(ya|0)==0){Ea=za;Fa=ya;Ga=Aa;break}if(Aa<<24>>24==0){Ea=za;Fa=ya;Ga=0;break}a[o+(za&255)|0]=xa;Ea=za+1&255;Fa=ya;Ga=Aa}}while(0);if((xa|0)>0){xa=xa-1|0;ya=Fa;za=Ea;Aa=Ga}else{wa=Ea;break}}}else{wa=ra}}while(0);E=wa&255;d:do{if(wa<<24>>24==0){Ha=D;Ia=R}else{TGb(k|0,0,16)|0;y=(B?X:0)|(D|0)==0&(A^1)&1;ua=a[da]|0;z=ua&255;L=E>>>0>8>>>0?8:E;e:do{if((L|0)==0){Ja=1;Ka=-1}else{P=y<<2;Z=1;va=1;V=-1;U=ua;while(1){La=U&255;Ma=va+P|0;Na=c[q>>2]|0;Oa=(QAa(Na+9292|0,(S?Ma+16|0:Ma)+130+(Na+9088)|0)|0)&255;a[p+La|0]=Oa;if(Oa<<24>>24==0){Pa=((va-1|0)>>>0<2>>>0)+va|0}else{Pa=0}Na=Oa<<24>>24!=0&(V|0)==-1?La:V;if((Z|0)>=(L|0)){Ja=Pa;Ka=Na;break e}La=a[o+Z|0]|0;Z=Z+1|0;va=Pa;V=Na;U=La}}}while(0);L=E-1|0;U=a[o+L|0]|0;if((z-(U&255)|0)>3){Qa=(a[w]|0)!=0}else{Qa=1}if(!((Ka|0)==-1)){V=c[q>>2]|0;va=QAa(V+9292|0,(S?y|4:y)+154+(V+9088)|0)|0;V=p+Ka|0;a[V]=(d[V]|0)+va}if((a[(c[O>>2]|0)+4|0]|0)==0|Qa){va=1;V=0;while(1){Z=c[q>>2]|0;P=Z+9292|0;La=c[P>>2]<<1;c[P>>2]=La;do{if((La&65534|0)==0){Na=Z+9308|0;Oa=c[Na>>2]|0;Ma=La-65535+(d[Oa+1|0]<<1|d[Oa]<<9)|0;c[P>>2]=Ma;if(!(Oa>>>0<(c[Z+9312>>2]|0)>>>0)){Ra=Ma;break}c[Na>>2]=Oa+2;Ra=Ma}else{Ra=La}}while(0);La=c[Z+9296>>2]<<17;if((Ra|0)<(La|0)){Sa=0}else{c[P>>2]=Ra-La;Sa=1}Ta=Sa|V;if((va|0)>=(E|0)){break}va=va+1|0;V=Ta<<1}Ua=Ta<<16-E&65535}else{V=L&255;f:do{if((L&255)<<24>>24==0){Va=0}else{va=1;y=0;while(1){z=c[q>>2]|0;La=z+9292|0;Ma=c[La>>2]<<1;c[La>>2]=Ma;do{if((Ma&65534|0)==0){Oa=z+9308|0;Na=c[Oa>>2]|0;Wa=Ma-65535+(d[Na+1|0]<<1|d[Na]<<9)|0;c[La>>2]=Wa;if(!(Na>>>0<(c[z+9312>>2]|0)>>>0)){Xa=Wa;break}c[Oa>>2]=Na+2;Xa=Wa}else{Xa=Ma}}while(0);Ma=c[z+9296>>2]<<17;if((Xa|0)<(Ma|0)){Ya=0}else{c[La>>2]=Xa-Ma;Ya=1}Ma=Ya|y;if((va|0)>=(V|0)){Va=Ma;break f}va=va+1|0;y=Ma<<1}}}while(0);Ua=Va<<17-E&65535}V=M>>4;L=d[ha+V|0]<<2;y=d[ia+V|0]<<2;V=R;va=0;P=0;Z=Ua;Ma=0;Wa=ua;while(1){Na=Wa&255;Oa=L+(d[ja+Na|0]|0)|0;Za=y+(d[ka+Na|0]|0)|0;_a=(d[p+Na|0]|0)+1|0;$a=0;if((va|0)<8){ab=(Na|0)==(Ka|0);bb=ab?0:0;cb=ab?3:2}else{bb=0;cb=1}do{if((_a|0)==(cb|0)&($a|0)==(bb|0)){ab=0;while(1){Na=c[q>>2]|0;db=Na+9292|0;eb=c[db>>2]<<1;c[db>>2]=eb;do{if((eb&65534|0)==0){fb=Na+9308|0;gb=c[fb>>2]|0;hb=eb-65535+(d[gb+1|0]<<1|d[gb]<<9)|0;c[db>>2]=hb;if(!(gb>>>0<(c[Na+9312>>2]|0)>>>0)){ib=hb;break}c[fb>>2]=gb+2;ib=hb}else{ib=eb}}while(0);eb=c[Na+9296>>2]<<17;if((ib|0)<(eb|0)){jb=ab;break}c[db>>2]=ib-eb;eb=ab+1|0;if((eb|0)<100){ab=eb}else{jb=eb;break}}do{if((jb|0)==100){yDb(c[x>>2]|0,16,2279400,(ab=i,i=i+8|0,c[ab>>2]=100,ab)|0);i=ab;kb=163}else{if((jb|0)>=3){kb=163;break}g:do{if((P|0)>0){ab=0;La=1;while(1){z=c[q>>2]|0;eb=z+9292|0;hb=c[eb>>2]<<1;c[eb>>2]=hb;do{if((hb&65534|0)==0){gb=z+9308|0;fb=c[gb>>2]|0;lb=hb-65535+(d[fb+1|0]<<1|d[fb]<<9)|0;c[eb>>2]=lb;if(!(fb>>>0<(c[z+9312>>2]|0)>>>0)){mb=lb;break}c[gb>>2]=fb+2;mb=lb}else{mb=hb}}while(0);hb=c[z+9296>>2]<<17;if((mb|0)<(hb|0)){nb=0}else{c[eb>>2]=mb-hb;nb=1}hb=nb|ab;if((La|0)>=(P|0)){ob=hb;break g}ab=hb<<1;La=La+1|0}}else{ob=0}}while(0);pb=ob+(jb<<P)|0}}while(0);if((kb|0)==163){kb=0;db=jb-3|0;Na=db+P|0;h:do{if((Na|0)>0){La=0;ab=1;while(1){hb=c[q>>2]|0;lb=hb+9292|0;fb=c[lb>>2]<<1;c[lb>>2]=fb;do{if((fb&65534|0)==0){gb=hb+9308|0;qb=c[gb>>2]|0;rb=fb-65535+(d[qb+1|0]<<1|d[qb]<<9)|0;c[lb>>2]=rb;if(!(qb>>>0<(c[hb+9312>>2]|0)>>>0)){sb=rb;break}c[gb>>2]=qb+2;sb=rb}else{sb=fb}}while(0);fb=c[hb+9296>>2]<<17;if((sb|0)<(fb|0)){tb=0}else{c[lb>>2]=sb-fb;tb=1}fb=tb|La;if((ab|0)>=(Na|0)){ub=fb;break h}La=fb<<1;ab=ab+1|0}}else{ub=0}}while(0);pb=ub+((1<<db)+2<<P)|0}Na=YGb(pb,(pb|0)<0|0?-1:0,_a,$a)|0;ab=F;La=3<<P;fb=(La|0)<0|0?-1:0;if(!((ab|0)>(fb|0)|(ab|0)==(fb|0)&Na>>>0>La>>>0)){vb=P;wb=ab;xb=Na;break}La=P+1|0;vb=(La|0)>4?4:La;wb=ab;xb=Na}else{vb=P;wb=$a;xb=_a}}while(0);do{if((a[(c[O>>2]|0)+4|0]|0)==0|Qa){yb=Ma;zb=wb;Ab=xb}else{_a=YGb(xb,wb,Ma,0)|0;$a=_a;if(!(Wa<<24>>24==U<<24>>24)){yb=$a;zb=wb;Ab=xb;break}_a=($a&1|0)==0;Na=ZGb(0,0,xb,wb)|0;yb=$a;zb=_a?wb:F;Ab=_a?xb:Na}}while(0);Na=Z<<16>>16>-1;_a=ZGb(0,0,Ab,zb)|0;$a=Na?Ab:_a;_a=Na?zb:F;Na=Z<<1;ab=$a&65535;do{if((a[w]|0)==0){do{if((a[(c[u>>2]|0)+634|0]|0)==0){Bb=V}else{if(!((Za|Oa|0)!=0|G)){Bb=J;break}if((h|0)==3){Cb=(Za<<3)+Oa|0}else if((h|0)==4){Cb=(Za>>>1<<3)+(Oa>>>1)|0}else if((h|0)==5){Cb=(Za>>>2<<3)+(Oa>>>2)|0}else{Cb=(Za<<2)+Oa|0}Bb=d[K+Cb|0]|0}}while(0);db=gHb($a,_a,s,C)|0;La=gHb(db,F,Bb,(Bb|0)<0|0?-1:0)|0;db=YGb(La,F,I,T)|0;La=aHb(db|0,F|0,H|0)|0;db=F;fb=0;if((db|0)<(fb|0)|(db|0)==(fb|0)&La>>>0<0>>>0){Db=(La&-32768|0)==(-32768|0)&(db&268435455|0)==268435455?La&65535:-32768;Eb=Bb;break}else{fb=0;Db=db>>>0>fb>>>0|db>>>0==fb>>>0&La>>>0>32767>>>0?32767:La&65535;Eb=Bb;break}}else{Db=ab;Eb=V}}while(0);b[m+((Za<<h)+Oa<<1)>>1]=Db;ab=va+1|0;if((ab|0)>=(E|0)){Ha=Ja;Ia=Eb;break d}V=Eb;va=ab;P=vb;Z=Na;Ma=yb;Wa=a[o+ab|0]|0}}}while(0);if(B){R=Ia;Y=Y-1|0;D=Ha}else{break}}}if((a[w]|0)!=0){Xe[c[e+5864+(h-2<<2)>>2]&4095](g,m|0,t);i=l;return}if((Q|0)!=0){Xe[c[e+5880>>2]&4095](g,m|0,t);i=l;return}if((c[r+184588>>2]|0)==1&N&(h|0)==2){Xe[c[e+5884>>2]&4095](g,m|0,t);i=l;return}else{Xe[c[e+5888+(h-2<<2)>>2]&4095](g,m|0,t);i=l;return}}function rBa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;f=a+136|0;e=c[f>>2]|0;h=QAa(e+9292|0,e+9119|0)|0;j=c[f>>2]|0;k=QAa(j+9292|0,j+9119|0)|0;if((h|0)==0){l=0}else{j=c[f>>2]|0;l=(QAa(j+9292|0,j+9122|0)|0)+h|0}if((k|0)==0){m=0}else{h=c[f>>2]|0;m=(QAa(h+9292|0,h+9122|0)|0)+k|0}if((l|0)==1){k=c[f>>2]|0;h=k+9292|0;j=c[h>>2]<<1;c[h>>2]=j;do{if((j&65534|0)==0){n=k+9308|0;o=c[n>>2]|0;p=j-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9)|0;c[h>>2]=p;if(!(o>>>0<(c[k+9312>>2]|0)>>>0)){q=p;break}c[n>>2]=o+2;q=p}else{q=j}}while(0);j=c[k+9296>>2]<<17;k=q-j|0;q=k>>31;c[h>>2]=(q&j)+k;b[e+184616>>1]=(q^65535)-q}else if((l|0)==0){b[e+184616>>1]=0}else if((l|0)==2){l=2;q=1;while(1){k=c[f>>2]|0;j=k+9292|0;h=c[j>>2]<<1;c[j>>2]=h;do{if((h&65534|0)==0){p=k+9308|0;o=c[p>>2]|0;n=h-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9)|0;c[j>>2]=n;if(!(o>>>0<(c[k+9312>>2]|0)>>>0)){r=n;break}c[p>>2]=o+2;r=n}else{r=h}}while(0);h=c[k+9296>>2]<<17;if((r|0)<(h|0)){s=l;t=q;break}c[j>>2]=r-h;h=(1<<q)+l|0;n=q+1|0;if((n|0)<100){l=h;q=n}else{s=h;t=n;break}}if((t|0)==100){yDb(c[a+4>>2]|0,16,2279400,(u=i,i=i+8|0,c[u>>2]=100,u)|0);i=u;q=c[f>>2]|0;v=s;w=100;x=q;y=q+9292|0;z=14}else{q=c[f>>2]|0;l=q+9292|0;if((t|0)==0){A=s;B=q;C=l}else{v=s;w=t;x=q;y=l;z=14}}if((z|0)==14){while(1){z=0;l=w-1|0;q=y|0;t=c[q>>2]<<1;c[q>>2]=t;do{if((t&65534|0)==0){s=x+9308|0;r=c[s>>2]|0;n=t-65535+((d[r+1|0]|0)<<1|(d[r]|0)<<9)|0;c[q>>2]=n;if(!(r>>>0<(c[x+9312>>2]|0)>>>0)){D=n;break}c[s>>2]=r+2;D=n}else{D=t}}while(0);t=c[x+9296>>2]<<17;if((D|0)<(t|0)){E=0}else{c[q>>2]=D-t;E=1}t=(E<<l)+v|0;j=c[f>>2]|0;k=j+9292|0;if((l|0)==0){A=t;B=j;C=k;break}else{v=t;w=l;x=j;y=k;z=14}}}y=-A|0;A=C|0;C=c[A>>2]<<1;c[A>>2]=C;do{if((C&65534|0)==0){x=B+9308|0;w=c[x>>2]|0;v=C-65535+((d[w+1|0]|0)<<1|(d[w]|0)<<9)|0;c[A>>2]=v;if(!(w>>>0<(c[B+9312>>2]|0)>>>0)){F=v;break}c[x>>2]=w+2;F=v}else{F=C}}while(0);C=c[B+9296>>2]<<17;B=F-C|0;F=B>>31;c[A>>2]=(F&C)+B;b[e+184616>>1]=(F^y)-F}if((m|0)==1){F=c[f>>2]|0;y=F+9292|0;B=c[y>>2]<<1;c[y>>2]=B;do{if((B&65534|0)==0){C=F+9308|0;A=c[C>>2]|0;v=B-65535+((d[A+1|0]|0)<<1|(d[A]|0)<<9)|0;c[y>>2]=v;if(!(A>>>0<(c[F+9312>>2]|0)>>>0)){G=v;break}c[C>>2]=A+2;G=v}else{G=B}}while(0);B=c[F+9296>>2]<<17;F=G-B|0;G=F>>31;c[y>>2]=(G&B)+F;b[e+184618>>1]=(G^65535)-G;i=g;return}else if((m|0)==2){G=2;F=1;while(1){B=c[f>>2]|0;y=B+9292|0;v=c[y>>2]<<1;c[y>>2]=v;do{if((v&65534|0)==0){A=B+9308|0;C=c[A>>2]|0;w=v-65535+((d[C+1|0]|0)<<1|(d[C]|0)<<9)|0;c[y>>2]=w;if(!(C>>>0<(c[B+9312>>2]|0)>>>0)){H=w;break}c[A>>2]=C+2;H=w}else{H=v}}while(0);v=c[B+9296>>2]<<17;if((H|0)<(v|0)){I=G;J=F;break}c[y>>2]=H-v;v=(1<<F)+G|0;l=F+1|0;if((l|0)<100){G=v;F=l}else{I=v;J=l;break}}if((J|0)==100){yDb(c[a+4>>2]|0,16,2279400,(u=i,i=i+8|0,c[u>>2]=100,u)|0);i=u;u=c[f>>2]|0;K=I;L=100;M=u;N=u+9292|0;z=38}else{u=c[f>>2]|0;a=u+9292|0;if((J|0)==0){O=I;P=u;Q=a}else{K=I;L=J;M=u;N=a;z=38}}if((z|0)==38){while(1){z=0;a=L-1|0;u=N|0;J=c[u>>2]<<1;c[u>>2]=J;do{if((J&65534|0)==0){I=M+9308|0;F=c[I>>2]|0;G=J-65535+((d[F+1|0]|0)<<1|(d[F]|0)<<9)|0;c[u>>2]=G;if(!(F>>>0<(c[M+9312>>2]|0)>>>0)){R=G;break}c[I>>2]=F+2;R=G}else{R=J}}while(0);J=c[M+9296>>2]<<17;if((R|0)<(J|0)){S=0}else{c[u>>2]=R-J;S=1}J=(S<<a)+K|0;y=c[f>>2]|0;B=y+9292|0;if((a|0)==0){O=J;P=y;Q=B;break}else{K=J;L=a;M=y;N=B;z=38}}}z=-O|0;O=Q|0;Q=c[O>>2]<<1;c[O>>2]=Q;do{if((Q&65534|0)==0){N=P+9308|0;M=c[N>>2]|0;L=Q-65535+((d[M+1|0]|0)<<1|(d[M]|0)<<9)|0;c[O>>2]=L;if(!(M>>>0<(c[P+9312>>2]|0)>>>0)){T=L;break}c[N>>2]=M+2;T=L}else{T=Q}}while(0);Q=c[P+9296>>2]<<17;P=T-Q|0;T=P>>31;c[O>>2]=(T&Q)+P;b[e+184618>>1]=(T^z)-T;i=g;return}else if((m|0)==0){b[e+184618>>1]=0;i=g;return}else{i=g;return}}function sBa(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=b+136|0;e=c[h>>2]|0;d=b+180|0;i=c[d>>2]|0;j=c[i+13080>>2]|0;k=(1<<j)-1|0;l=-1<<j-(c[(c[b+184>>2]|0)+24>>2]|0);j=l&f;m=l&g;n=c[i+13116>>2]|0;o=c[i+13064>>2]|0;i=j>>o;p=m>>o;if((k&f|0)==0){q=0}else{q=(j&k|0)!=0|0}if((k&g|0)==0){r=0}else{r=(m&k|0)!=0|0}k=e+9271|0;do{if((a[k]|0)==0){if((l&(g|f)|0)==0){s=7;break}t=c[e+173184>>2]|0}else{s=7}}while(0);if((s|0)==7){a[k]=(a[e+173196|0]|0)==0|0;t=a[b+3072|0]|0}if((q|0)==0){u=t}else{q=i-1+(ba(p,n)|0)|0;u=a[(c[b+7316>>2]|0)+q|0]|0}if((r|0)==0){v=t}else{t=(ba(p-1|0,n)|0)+i|0;v=a[(c[b+7316>>2]|0)+t|0]|0}t=u+1+v>>1;v=c[h>>2]|0;h=c[v+173188>>2]|0;if((h|0)==0){a[v+173182|0]=t;return}u=c[(c[d>>2]|0)+13164>>2]|0;d=h+52+t+(u<<1)|0;if((d|0)>0){w=d}else{w=-52-u+1+d|0}a[v+173182|0]=d-u-w+((w|0)%(u+52|0)|0);return}function tBa(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=b+3480|0;j=c[i>>2]|0;k=c[j+16>>2]|0;l=b+180|0;m=c[l>>2]|0;n=c[m+13084>>2]|0;o=c[m+13072>>2]|0;p=c[m+13132>>2]|0;q=c[m+13124>>2]|0;m=ba(p,e>>n)|0;r=d>>n;s=a[k+((m+r|0)*14|0)+12|0]|0;do{if((e|0)>0&(e&7|0)==0){t=e-1|0;u=1<<f;if((u|0)<=0){v=n;break}w=ba(p,t>>n)|0;x=ba(q,t>>o)|0;y=b+7348|0;z=ba(q,e>>o)|0;A=b+3026|0;B=(g&1|0)==0;C=b+184|0;D=(g&2|0)==0;E=(e|0)==0;F=b+3025|0;G=b+5808|0;H=b+7324|0;I=0;J=j;while(1){K=I+d|0;L=K>>n;M=K>>o;N=c[y>>2]|0;O=a[N+(M+x)|0]|0;P=a[N+(M+z)|0]|0;M=uBa(b,k+((L+m|0)*14|0)|0,P,k+((L+w|0)*14|0)|0,O,RBa(b,J,K,t)|0,1)|0;if((a[A]|0)!=0|B){Q=6}else{if(((e|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0){R=0}else{Q=6}}do{if((Q|0)==6){Q=0;if((a[(c[C>>2]|0)+53|0]|0)!=0|D){R=M;break}R=((e|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0?0:M}}while(0);do{if(!E){if((a[F]|0)==1|(R|0)==0){break}M=(ba(c[G>>2]|0,e)|0)+K>>2;a[(c[H>>2]|0)+M|0]=R}}while(0);K=I+4|0;if((K|0)>=(u|0)){break}I=K;J=c[i>>2]|0}v=c[(c[l>>2]|0)+13084>>2]|0}else{v=n}}while(0);R=s<<24>>24==0;do{if(v>>>0<f>>>0&R){s=1<<f;if((s|0)<=8){break}m=b+7348|0;j=b+3025|0;g=b+5808|0;J=b+7324|0;I=8;do{u=I+e|0;H=u-1|0;G=ba(H>>n,p)|0;F=ba(u>>n,p)|0;E=ba(H>>o,q)|0;D=ba(u>>o,q)|0;C=0;do{B=C+d|0;A=B>>n;t=B>>o;w=c[m>>2]|0;z=a[w+(t+E)|0]|0;x=a[w+(t+D)|0]|0;t=uBa(b,k+((A+F|0)*14|0)|0,x,k+((A+G|0)*14|0)|0,z,RBa(b,c[i>>2]|0,B,H)|0,0)|0;z=(a[j]|0)==1?0:t;if((z|0)!=0){t=(ba(c[g>>2]|0,u)|0)+B>>2;a[(c[J>>2]|0)+t|0]=z}C=C+4|0;}while((C|0)<(s|0));I=I+8|0;}while((I|0)<(s|0))}}while(0);a:do{if((d|0)>0&(d&7|0)==0){v=d-1|0;s=v>>n;I=v>>o;J=d>>o;g=1<<f;if((g|0)<=0){break}j=b+7348|0;m=b+3026|0;C=b+184|0;u=(h&2|0)==0;H=(d|0)==0;G=b+3025|0;F=d>>3;D=b+5808|0;E=b+7328|0;if((h&1|0)==0){z=0;while(1){t=z+e|0;B=ba(t>>n,p)|0;A=ba(t>>o,q)|0;x=c[j>>2]|0;w=a[x+(A+I)|0]|0;y=a[x+(A+J)|0]|0;A=uBa(b,k+((B+r|0)*14|0)|0,y,k+((B+s|0)*14|0)|0,w,RBa(b,c[i>>2]|0,v,t)|0,1)|0;if((a[(c[C>>2]|0)+53|0]|0)!=0|u){S=A}else{S=((d|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0?0:A}do{if(!H){if((a[G]|0)==1|(S|0)==0){break}A=(ba(c[D>>2]|0,t>>2)|0)+F|0;a[(c[E>>2]|0)+A|0]=S}}while(0);z=z+4|0;if((z|0)>=(g|0)){break a}}}else{T=0}do{z=T+e|0;t=ba(z>>n,p)|0;A=ba(z>>o,q)|0;w=c[j>>2]|0;B=a[w+(A+I)|0]|0;y=a[w+(A+J)|0]|0;A=uBa(b,k+((t+r|0)*14|0)|0,y,k+((t+s|0)*14|0)|0,B,RBa(b,c[i>>2]|0,v,z)|0,1)|0;if((a[m]|0)==0){if(((d|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0){U=0}else{Q=33}}else{Q=33}do{if((Q|0)==33){Q=0;if((a[(c[C>>2]|0)+53|0]|0)!=0|u){U=A;break}U=((d|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0?0:A}}while(0);do{if(!H){if((a[G]|0)==1|(U|0)==0){break}A=(ba(c[D>>2]|0,z>>2)|0)+F|0;a[(c[E>>2]|0)+A|0]=U}}while(0);T=T+4|0;}while((T|0)<(g|0))}}while(0);if(!((n|0)<(f|0)&R)){return}R=1<<f;if((R|0)<=0){return}f=b+7348|0;T=b+3025|0;U=b+5808|0;l=b+7328|0;if((R|0)>8){V=0}else{Q=0;do{Q=Q+4|0;}while((Q|0)<(R|0));return}do{Q=V+e|0;r=ba(Q>>n,p)|0;S=ba(Q>>o,q)|0;h=Q>>2;g=8;do{E=g+d|0;F=E-1|0;D=c[f>>2]|0;G=a[D+((F>>o)+S)|0]|0;H=a[D+((E>>o)+S)|0]|0;D=uBa(b,k+(((E>>n)+r|0)*14|0)|0,H,k+(((F>>n)+r|0)*14|0)|0,G,RBa(b,c[i>>2]|0,F,Q)|0,0)|0;F=(a[T]|0)==1?0:D;if((F|0)!=0){D=(ba(c[U>>2]|0,h)|0)+(E>>3)|0;a[(c[l>>2]|0)+D|0]=F}g=g+8|0;}while((g|0)<(R|0));V=V+4|0;}while((V|0)<(R|0));return}function uBa(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=a[e+10|0]|0;l=(a[e+11|0]|0)+(k<<24>>24)|0;do{if((j|0)!=0){if((a[e+12|0]|0)!=0){m=2;return m|0}if((a[g+12|0]|0)!=0){m=2;return m|0}if((h|f)<<24>>24==0){break}else{m=1}return m|0}}while(0);f=a[g+10|0]|0;if((l|0)!=((a[g+11|0]|0)+(f<<24>>24)|0)){m=1;return m|0}if((l|0)!=2){if(k<<24>>24==0){n=(c[(c[d+3480>>2]|0)+20>>2]|0)+260+(a[e+9|0]<<2)|0;o=e+4|0;p=e+6|0}else{n=(c[(c[d+3480>>2]|0)+20>>2]|0)+64+(a[e+8|0]<<2)|0;o=e|0;p=e+2|0}if(f<<24>>24==0){q=i+260+(a[g+9|0]<<2)|0;r=g+4|0;s=g+6|0}else{q=i+64+(a[g+8|0]<<2)|0;r=g|0;s=g+2|0}if((c[n>>2]|0)!=(c[q>>2]|0)){m=1;return m|0}q=(b[o>>1]|0)-(b[r>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){m=1;return m|0}q=(b[p>>1]|0)-(b[s>>1]|0)|0;m=(((q|0)>-1?q:-q|0)|0)>3|0;return m|0}q=c[(c[d+3480>>2]|0)+20>>2]|0;d=c[q+64+(a[e+8|0]<<2)>>2]|0;s=c[i+64+(a[g+8|0]<<2)>>2]|0;p=(d|0)==(s|0);a:do{if(p){do{if((d|0)==(c[q+260+(a[e+9|0]<<2)>>2]|0)){if((d|0)!=(c[i+260+(a[g+9|0]<<2)>>2]|0)){if(p){break}else{t=20;break a}}r=b[g>>1]|0;o=b[e>>1]|0;n=r-o|0;do{if((((n|0)>-1?n:-n|0)|0)>3){t=14}else{f=(b[g+2>>1]|0)-(b[e+2>>1]|0)|0;if((((f|0)>-1?f:-f|0)|0)>3){t=14;break}f=(b[g+4>>1]|0)-(b[e+4>>1]|0)|0;if((((f|0)>-1?f:-f|0)|0)>3){t=14;break}f=(b[g+6>>1]|0)-(b[e+6>>1]|0)|0;if((((f|0)>-1?f:-f|0)|0)>3){t=14}}}while(0);do{if((t|0)==14){n=(b[g+4>>1]|0)-o|0;if((((n|0)>-1?n:-n|0)|0)>3){m=1;return m|0}n=(b[g+6>>1]|0)-(b[e+2>>1]|0)|0;if((((n|0)>-1?n:-n|0)|0)>3){m=1;return m|0}n=r-(b[e+4>>1]|0)|0;if((((n|0)>-1?n:-n|0)|0)>3){m=1;return m|0}n=(b[g+2>>1]|0)-(b[e+6>>1]|0)|0;if((((n|0)>-1?n:-n|0)|0)>3){m=1}else{break}return m|0}}while(0);m=0;return m|0}}while(0);r=c[i+260+(a[g+9|0]<<2)>>2]|0;if((r|0)!=(c[q+260+(a[e+9|0]<<2)>>2]|0)){u=r;break}r=(b[g>>1]|0)-(b[e>>1]|0)|0;if((((r|0)>-1?r:-r|0)|0)>3){m=1;return m|0}r=(b[g+2>>1]|0)-(b[e+2>>1]|0)|0;if((((r|0)>-1?r:-r|0)|0)>3){m=1;return m|0}r=(b[g+4>>1]|0)-(b[e+4>>1]|0)|0;if((((r|0)>-1?r:-r|0)|0)>3){m=1;return m|0}else{r=(b[g+6>>1]|0)-(b[e+6>>1]|0)|0;return(((r|0)>-1?r:-r|0)|0)>3|0}}else{t=20}}while(0);if((t|0)==20){u=c[i+260+(a[g+9|0]<<2)>>2]|0}if((u|0)!=(d|0)){m=1;return m|0}if((s|0)!=(c[q+260+(a[e+9|0]<<2)>>2]|0)){m=1;return m|0}q=(b[g+4>>1]|0)-(b[e>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){m=1;return m|0}q=(b[g+6>>1]|0)-(b[e+2>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){m=1;return m|0}q=(b[g>>1]|0)-(b[e+4>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){m=1;return m|0}q=(b[g+2>>1]|0)-(b[e+6>>1]|0)|0;m=(((q|0)>-1?q:-q|0)|0)>3|0;return m|0}function vBa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0;h=i;i=i+112|0;j=h|0;k=h+16|0;l=h+32|0;m=h+48|0;n=h+56|0;o=h+64|0;p=h+72|0;q=h+80|0;r=h+88|0;s=h+96|0;t=h+104|0;u=s;v=t;w=s;x=t;b[s>>1]=0;b[t>>1]=0;t=e+180|0;s=c[t>>2]|0;y=c[s+13080>>2]|0;z=1<<y;A=(ba(g>>y,c[s+13104>>2]|0)|0)+(f>>y)|0;y=c[e+3468>>2]|0;B=c[y+(A<<3)+4>>2]|0;C=c[y+(A<<3)>>2]|0;if((c[s+68>>2]|0)==0){D=3}else{if((a[s+13056|0]|0)==0){D=3}else{E=1}}if((D|0)==3){E=(a[(c[e+184>>2]|0)+40|0]|0)!=0}F=(f|0)!=0;if(F){G=A-1|0;H=c[y+(G<<3)+4>>2]|0;I=c[y+(G<<3)>>2]|0}else{H=0;I=0}G=z+f|0;y=c[s+13096>>2]|0;A=(G|0)>(y|0)?y:G;G=z+g|0;z=c[s+13100>>2]|0;s=(G|0)>(z|0)?z:G;G=(s|0)>(g|0);if(G){z=F?f:8;y=(z|0)<(A|0);J=e+5808|0;K=e+7328|0;L=e+7316|0;M=q|0;N=q+4|0;O=B-2&-2;P=r|0;Q=r+4|0;R=e+160|0;S=w+1|0;T=x+1|0;U=e+6052|0;V=e+7352|0;W=e+6036|0;X=g;while(1){if(y){Y=X>>2;Z=X+4|0;_=Z>>2;$=z;do{aa=$>>3;ca=c[J>>2]|0;da=(ba(ca,Y)|0)+aa|0;ea=c[K>>2]|0;fa=a[ea+da|0]|0;da=fa&255;ga=a[ea+((ba(ca,_)|0)+aa)|0]|0;aa=ga&255;ca=fa<<24>>24!=0;fa=ga<<24>>24==0;do{if(!(fa&(ca^1))){ga=$-1|0;ea=c[t>>2]|0;ha=c[L>>2]|0;ia=c[ea+13064>>2]|0;ja=c[ea+13116>>2]|0;ka=ga>>ia;la=ba(X>>ia,ja)|0;ma=$>>ia;na=(a[ha+(la+ka)|0]|0)+1+(a[ha+(la+ma)|0]|0)>>1;la=ba(Z>>ia,ja)|0;ja=(a[ha+(la+ka)|0]|0)+1+(a[ha+(la+ma)|0]|0)>>1;ma=na+C|0;if((ma|0)<0){oa=0}else{oa=(ma|0)>51?51:ma}c[M>>2]=d[1732712+oa|0]|0;ma=ja+C|0;if((ma|0)<0){pa=0}else{pa=(ma|0)>51?51:ma}c[N>>2]=d[1732712+pa|0]|0;if(ca){ma=(da<<1)+O+na|0;if((ma|0)<0){qa=0}else{qa=(ma|0)>53?53:ma}ra=d[189048+qa|0]|0}else{ra=0}c[P>>2]=ra;if(fa){sa=0}else{ma=(aa<<1)+O+ja|0;if((ma|0)<0){ta=0}else{ta=(ma|0)>53?53:ma}sa=d[189048+ta|0]|0}c[Q>>2]=sa;ma=c[R>>2]|0;ja=c[ma+32>>2]|0;na=ba(ja,X)|0;la=(c[ma>>2]|0)+(($<<c[ea+56>>2])+na)|0;if(!E){Se[c[W>>2]&511](la,ja,M,P,u,v);break}na=c[ea+13084>>2]|0;do{if((ga|X|0)<0){ua=2}else{ma=ga>>na;ha=X>>na;ka=c[ea+13132>>2]|0;if((ma|0)>=(ka|0)){ua=2;break}if((ha|0)>=(c[ea+13136>>2]|0)){ua=2;break}ia=(ba(ka,ha)|0)+ma|0;ua=a[(c[V>>2]|0)+ia|0]|0}}while(0);a[u]=ua;do{if((ga|Z|0)<0){va=2}else{ia=ga>>na;ma=Z>>na;ha=c[ea+13132>>2]|0;if((ia|0)>=(ha|0)){va=2;break}if((ma|0)>=(c[ea+13136>>2]|0)){va=2;break}ka=(ba(ha,ma)|0)+ia|0;va=a[(c[V>>2]|0)+ka|0]|0}}while(0);a[S]=va;do{if(($|X|0)<0){wa=2}else{ga=$>>na;ka=X>>na;ia=c[ea+13132>>2]|0;if((ga|0)>=(ia|0)){wa=2;break}if((ka|0)>=(c[ea+13136>>2]|0)){wa=2;break}ma=(ba(ia,ka)|0)+ga|0;wa=a[(c[V>>2]|0)+ma|0]|0}}while(0);a[v]=wa;do{if(($|Z|0)<0){xa=2}else{ma=$>>na;ga=Z>>na;ka=c[ea+13132>>2]|0;if((ma|0)>=(ka|0)){xa=2;break}if((ga|0)>=(c[ea+13136>>2]|0)){xa=2;break}ia=(ba(ka,ga)|0)+ma|0;xa=a[(c[V>>2]|0)+ia|0]|0}}while(0);a[T]=xa;Se[c[U>>2]&511](la,ja,M,P,u,v)}}while(0);$=$+8|0;}while(($|0)<(A|0))}$=X+8|0;if(($|0)<(s|0)){X=$}else{ya=J;za=K;Aa=L;Ba=R;Ca=S;Da=T;Ea=V;break}}}else{ya=e+5808|0;za=e+7328|0;Aa=e+7316|0;Ba=e+160|0;Ca=w+1|0;Da=x+1|0;Ea=e+7352|0}x=F?f:16;w=(x|0)<(A|0);V=e+184|0;T=B+2|0;S=p|0;R=p+4|0;p=e+6060|0;L=e+6044|0;K=1;do{if(G){J=(K|0)==1;X=g;do{if(w){P=X>>2;M=X+8|0;U=M>>2;xa=(X|0)/2|0;wa=x;do{va=wa>>3;ua=c[ya>>2]|0;W=(ba(ua,P)|0)+va|0;sa=c[za>>2]|0;Q=(a[sa+W|0]|0)==2;W=(a[sa+((ba(ua,U)|0)+va)|0]|0)==2;do{if(Q|W){va=wa-1|0;ua=c[t>>2]|0;sa=c[Aa>>2]|0;ta=c[ua+13064>>2]|0;O=c[ua+13116>>2]|0;ra=va>>ta;qa=ba(X>>ta,O)|0;pa=wa>>ta;N=ba(M>>ta,O)|0;O=(a[sa+(N+ra)|0]|0)+1+(a[sa+(N+pa)|0]|0)>>1;if(Q){N=c[V>>2]|0;ta=((a[sa+(qa+pa)|0]|0)+1+(a[sa+(qa+ra)|0]|0)>>1)+(c[(J?N+28|0:N+32|0)>>2]|0)|0;do{if((ta|0)<0){Fa=0}else{N=(ta|0)>57?57:ta;if((N|0)<30){Fa=N;break}if((N|0)>43){Fa=N-6|0;break}else{Fa=c[1485888+(N-30<<2)>>2]|0;break}}}while(0);ta=Fa+T|0;if((ta|0)<0){Ga=0}else{Ga=(ta|0)>53?53:ta}Ha=d[189048+Ga|0]|0}else{Ha=0}c[S>>2]=Ha;if(W){ta=c[V>>2]|0;N=(c[(J?ta+28|0:ta+32|0)>>2]|0)+O|0;do{if((N|0)<0){Ia=0}else{ta=(N|0)>57?57:N;if((ta|0)<30){Ia=ta;break}if((ta|0)>43){Ia=ta-6|0;break}else{Ia=c[1485888+(ta-30<<2)>>2]|0;break}}}while(0);N=Ia+T|0;if((N|0)<0){Ja=0}else{Ja=(N|0)>53?53:N}Ka=d[189048+Ja|0]|0}else{Ka=0}c[R>>2]=Ka;N=c[Ba>>2]|0;O=c[N+32+(K<<2)>>2]|0;ta=ba(O,xa)|0;ra=(c[N+(K<<2)>>2]|0)+((((wa|0)/2|0)<<c[ua+56>>2])+ta)|0;if(!E){le[c[L>>2]&1023](ra,O,S,u,v);break}ta=c[ua+13084>>2]|0;do{if((va|X|0)<0){La=2}else{N=va>>ta;qa=X>>ta;sa=c[ua+13132>>2]|0;if((N|0)>=(sa|0)){La=2;break}if((qa|0)>=(c[ua+13136>>2]|0)){La=2;break}pa=(ba(sa,qa)|0)+N|0;La=a[(c[Ea>>2]|0)+pa|0]|0}}while(0);a[u]=La;do{if((va|M|0)<0){Ma=2}else{pa=va>>ta;N=M>>ta;qa=c[ua+13132>>2]|0;if((pa|0)>=(qa|0)){Ma=2;break}if((N|0)>=(c[ua+13136>>2]|0)){Ma=2;break}sa=(ba(qa,N)|0)+pa|0;Ma=a[(c[Ea>>2]|0)+sa|0]|0}}while(0);a[Ca]=Ma;do{if((wa|X|0)<0){Na=2}else{va=wa>>ta;sa=X>>ta;pa=c[ua+13132>>2]|0;if((va|0)>=(pa|0)){Na=2;break}if((sa|0)>=(c[ua+13136>>2]|0)){Na=2;break}N=(ba(pa,sa)|0)+va|0;Na=a[(c[Ea>>2]|0)+N|0]|0}}while(0);a[v]=Na;do{if((wa|M|0)<0){Oa=2}else{N=wa>>ta;va=M>>ta;sa=c[ua+13132>>2]|0;if((N|0)>=(sa|0)){Oa=2;break}if((va|0)>=(c[ua+13136>>2]|0)){Oa=2;break}pa=(ba(sa,va)|0)+N|0;Oa=a[(c[Ea>>2]|0)+pa|0]|0}}while(0);a[Da]=Oa;le[c[p>>2]&1023](ra,O,S,u,v)}}while(0);wa=wa+16|0;}while((wa|0)<(A|0))}X=X+16|0;}while((X|0)<(s|0))}K=K+1|0;}while((K|0)<3);K=(A|0)==(c[(c[t>>2]|0)+13096>>2]|0)?A:A-8|0;A=(g|0)!=0;p=A?g:8;Oa=f-8|0;if((p|0)<(s|0)){Na=F?Oa:0;F=(Na|0)<(K|0);Ma=e+7324|0;La=q|0;L=q+4|0;q=r|0;Ka=r+4|0;r=e+6048|0;Ja=e+6032|0;Ia=p;while(1){if(F){p=Ia-1|0;Ha=Na;do{Ga=ba(c[ya>>2]|0,Ia)|0;Fa=c[Ma>>2]|0;za=a[Fa+(Ga+Ha>>2)|0]|0;x=za&255;w=Ha+4|0;G=a[Fa+(Ga+w>>2)|0]|0;Ga=G&255;Fa=za<<24>>24!=0;za=G<<24>>24==0;do{if(!(za&(Fa^1))){G=c[t>>2]|0;X=c[Aa>>2]|0;J=c[G+13064>>2]|0;wa=c[G+13116>>2]|0;M=Ha>>J;xa=ba(p>>J,wa)|0;U=ba(Ia>>J,wa)|0;wa=(a[X+(xa+M)|0]|0)+1+(a[X+(U+M)|0]|0)>>1;M=w>>J;J=(a[X+(xa+M)|0]|0)+1+(a[X+(U+M)|0]|0)>>1;M=(Ha|0)>=(f|0);U=M?B:H;X=M?C:I;M=wa+X|0;if((M|0)<0){Pa=0}else{Pa=(M|0)>51?51:M}c[La>>2]=d[1732712+Pa|0]|0;M=J+X|0;if((M|0)<0){Qa=0}else{Qa=(M|0)>51?51:M}c[L>>2]=d[1732712+Qa|0]|0;if(Fa){M=(x<<1)+(U-2&-2)+wa|0;if((M|0)<0){Ra=0}else{Ra=(M|0)>53?53:M}Sa=d[189048+Ra|0]|0}else{Sa=0}c[q>>2]=Sa;if(za){Ta=0}else{M=(Ga<<1)+(U-2&-2)+J|0;if((M|0)<0){Ua=0}else{Ua=(M|0)>53?53:M}Ta=d[189048+Ua|0]|0}c[Ka>>2]=Ta;M=c[Ba>>2]|0;J=c[M+32>>2]|0;U=ba(J,Ia)|0;wa=(c[M>>2]|0)+((Ha<<c[G+56>>2])+U)|0;if(!E){Se[c[Ja>>2]&511](wa,J,La,q,u,v);break}U=c[G+13084>>2]|0;do{if((Ha|p|0)<0){Va=2}else{M=Ha>>U;X=p>>U;xa=c[G+13132>>2]|0;if((M|0)>=(xa|0)){Va=2;break}if((X|0)>=(c[G+13136>>2]|0)){Va=2;break}P=(ba(xa,X)|0)+M|0;Va=a[(c[Ea>>2]|0)+P|0]|0}}while(0);a[u]=Va;do{if((w|p|0)<0){Wa=2}else{P=w>>U;M=p>>U;X=c[G+13132>>2]|0;if((P|0)>=(X|0)){Wa=2;break}if((M|0)>=(c[G+13136>>2]|0)){Wa=2;break}xa=(ba(X,M)|0)+P|0;Wa=a[(c[Ea>>2]|0)+xa|0]|0}}while(0);a[Ca]=Wa;do{if((Ha|Ia|0)<0){Xa=2}else{xa=Ha>>U;P=Ia>>U;M=c[G+13132>>2]|0;if((xa|0)>=(M|0)){Xa=2;break}if((P|0)>=(c[G+13136>>2]|0)){Xa=2;break}X=(ba(M,P)|0)+xa|0;Xa=a[(c[Ea>>2]|0)+X|0]|0}}while(0);a[v]=Xa;do{if((w|Ia|0)<0){Ya=2}else{X=w>>U;xa=Ia>>U;P=c[G+13132>>2]|0;if((X|0)>=(P|0)){Ya=2;break}if((xa|0)>=(c[G+13136>>2]|0)){Ya=2;break}M=(ba(P,xa)|0)+X|0;Ya=a[(c[Ea>>2]|0)+M|0]|0}}while(0);a[Da]=Ya;Se[c[r>>2]&511](wa,J,La,q,u,v)}}while(0);Ha=Ha+8|0;}while((Ha|0)<(K|0))}Ha=Ia+8|0;if((Ha|0)<(s|0)){Ia=Ha}else{Za=Ma;break}}}else{Za=e+7324|0}Ma=A?g:16;A=(Ma|0)<(s|0);Ia=(Oa|0)<(K|0);q=e+6056|0;La=e+6040|0;r=K-8|0;Ya=1;do{if(A){Xa=(Ya|0)==1;Wa=Ma;do{if(Ia){Va=Wa-1|0;Ja=(Wa|0)/2|0;Ta=Oa;do{do{if((Ta|0)<0){Ka=Ta+8+(ba(c[ya>>2]|0,Wa)|0)>>2;_a=d[(c[Za>>2]|0)+Ka|0]|0;$a=0}else{Ka=ba(c[ya>>2]|0,Wa)|0;Ua=c[Za>>2]|0;Sa=d[Ua+(Ka+Ta>>2)|0]|0;if((Ta|0)>=(r|0)){_a=0;$a=Sa;break}_a=d[Ua+(Ta+8+Ka>>2)|0]|0;$a=Sa}}while(0);J=($a|0)==2;wa=(_a|0)==2;do{if(J|wa){if(J){Sa=c[t>>2]|0;Ka=c[Aa>>2]|0;Ua=c[Sa+13064>>2]|0;Ra=c[Sa+13116>>2]|0;Sa=Ta>>Ua;Qa=a[Ka+((ba(Va>>Ua,Ra)|0)+Sa)|0]|0;ab=Qa+1+(a[Ka+((ba(Wa>>Ua,Ra)|0)+Sa)|0]|0)>>1}else{ab=0}if(wa){Sa=c[t>>2]|0;Ra=c[Aa>>2]|0;Ua=c[Sa+13064>>2]|0;Ka=c[Sa+13116>>2]|0;Sa=Ta+8>>Ua;Qa=a[Ra+((ba(Va>>Ua,Ka)|0)+Sa)|0]|0;bb=Qa+1+(a[Ra+((ba(Wa>>Ua,Ka)|0)+Sa)|0]|0)>>1}else{bb=0}if(J){Sa=(Ta|0)>=(f|0)?B:H;Ka=c[V>>2]|0;Ua=(c[(Xa?Ka+28|0:Ka+32|0)>>2]|0)+ab|0;do{if((Ua|0)<0){cb=0}else{Ka=(Ua|0)>57?57:Ua;if((Ka|0)<30){cb=Ka;break}if((Ka|0)>43){cb=Ka-6|0;break}else{cb=c[1485888+(Ka-30<<2)>>2]|0;break}}}while(0);Ua=Sa+2+cb|0;if((Ua|0)<0){db=0}else{db=(Ua|0)>53?53:Ua}eb=d[189048+db|0]|0}else{eb=0}c[S>>2]=eb;if(wa){Ua=c[V>>2]|0;O=(c[(Xa?Ua+28|0:Ua+32|0)>>2]|0)+bb|0;do{if((O|0)<0){fb=0}else{Ua=(O|0)>57?57:O;if((Ua|0)<30){fb=Ua;break}if((Ua|0)>43){fb=Ua-6|0;break}else{fb=c[1485888+(Ua-30<<2)>>2]|0;break}}}while(0);O=fb+T|0;if((O|0)<0){gb=0}else{gb=(O|0)>53?53:O}hb=d[189048+gb|0]|0}else{hb=0}c[R>>2]=hb;O=c[Ba>>2]|0;Sa=c[O+32+(Ya<<2)>>2]|0;Ua=ba(Sa,Ja)|0;ra=c[t>>2]|0;Ka=(c[O+(Ya<<2)>>2]|0)+((((Ta|0)/2|0)<<c[ra+56>>2])+Ua)|0;if(!E){le[c[La>>2]&1023](Ka,Sa,S,u,v);break}Ua=c[ra+13084>>2]|0;do{if((Ta|Va|0)<0){ib=2}else{O=Ta>>Ua;Ra=Va>>Ua;Qa=c[ra+13132>>2]|0;if((O|0)>=(Qa|0)){ib=2;break}if((Ra|0)>=(c[ra+13136>>2]|0)){ib=2;break}L=(ba(Qa,Ra)|0)+O|0;ib=a[(c[Ea>>2]|0)+L|0]|0}}while(0);a[u]=ib;L=Ta+8|0;do{if((L|Va|0)<0){jb=2}else{O=L>>Ua;Ra=Va>>Ua;Qa=c[ra+13132>>2]|0;if((O|0)>=(Qa|0)){jb=2;break}if((Ra|0)>=(c[ra+13136>>2]|0)){jb=2;break}Pa=(ba(Qa,Ra)|0)+O|0;jb=a[(c[Ea>>2]|0)+Pa|0]|0}}while(0);a[Ca]=jb;do{if((Ta|Wa|0)<0){kb=2}else{Pa=Ta>>Ua;O=Wa>>Ua;Ra=c[ra+13132>>2]|0;if((Pa|0)>=(Ra|0)){kb=2;break}if((O|0)>=(c[ra+13136>>2]|0)){kb=2;break}Qa=(ba(Ra,O)|0)+Pa|0;kb=a[(c[Ea>>2]|0)+Qa|0]|0}}while(0);a[v]=kb;do{if((L|Wa|0)<0){lb=2}else{Qa=L>>Ua;Pa=Wa>>Ua;O=c[ra+13132>>2]|0;if((Qa|0)>=(O|0)){lb=2;break}if((Pa|0)>=(c[ra+13136>>2]|0)){lb=2;break}Ra=(ba(O,Pa)|0)+Qa|0;lb=a[(c[Ea>>2]|0)+Ra|0]|0}}while(0);a[Da]=lb;le[c[q>>2]&1023](Ka,Sa,S,u,v)}}while(0);Ta=Ta+16|0;}while((Ta|0)<(K|0))}Wa=Wa+16|0;}while((Wa|0)<(s|0))}Ya=Ya+1|0;}while((Ya|0)<3);Ya=c[t>>2]|0;if((a[Ya+12941|0]|0)==0){i=h;return}s=m;K=n;v=o;u=m;S=n;q=o;lb=c[Ya+13080>>2]|0;Da=f>>lb;Ea=g>>lb;lb=Ya+13104|0;kb=(ba(Ea,c[lb>>2]|0)|0)+Da|0;jb=c[V>>2]|0;V=c[jb+1652>>2]|0;Ca=c[V+(kb<<2)>>2]|0;c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;if((a[jb+42|0]|0)==0){mb=0}else{mb=(a[jb+53|0]|0)==0|0}o=c[e+3464>>2]|0;c[k>>2]=o+(kb*184|0);n=(Da|0)==0;m=j|0;c[m>>2]=n&1;ib=(Ea|0)==0;c[j+4>>2]=ib&1;La=(Da|0)==((c[lb>>2]|0)-1|0)|0;E=j+8|0;c[E>>2]=La;Ba=(Ea|0)==((c[Ya+13108>>2]|0)-1|0)|0;hb=j+12|0;c[hb>>2]=Ba;j=c[lb>>2]|0;lb=ba(j,Ea)|0;R=lb+Da|0;gb=c[e+7356>>2]|0;T=a[gb+R|0]|0;c[l>>2]=0;if(n){nb=1;ob=0;pb=0;qb=0}else{if((mb|0)==0){rb=0}else{fb=c[jb+1660>>2]|0;rb=(c[fb+(Ca<<2)>>2]|0)!=(c[fb+(c[V+(kb-1<<2)>>2]<<2)>>2]|0)|0}fb=Da-1+lb|0;c[k+4>>2]=o+(fb*184|0);if(T<<24>>24==0){bb=c[e+7332>>2]|0;if((c[bb+(R<<2)>>2]|0)==(c[bb+(fb<<2)>>2]|0)){D=192}else{sb=1}}else{D=192}if((D|0)==192){sb=rb}a[s]=sb;a[u+2|0]=sb;sb=a[gb+fb|0]|0;c[l+4>>2]=2;nb=2;ob=8;pb=sb;qb=rb}do{if(ib){tb=nb;ub=0}else{if((mb|0)==0){vb=0}else{rb=c[jb+1660>>2]|0;vb=(c[rb+(Ca<<2)>>2]|0)!=(c[rb+(c[V+(kb-j<<2)>>2]<<2)>>2]|0)|0}rb=ba(j,Ea-1|0)|0;sb=rb+Da|0;c[k+(nb<<2)>>2]=o+(sb*184|0);fb=T<<24>>24!=0;if(fb){D=199}else{s=c[e+7332>>2]|0;if((c[s+(R<<2)>>2]|0)==(c[s+(sb<<2)>>2]|0)){D=199}else{wb=1}}if((D|0)==199){wb=vb}a[K]=wb;a[S+1|0]=wb;s=a[gb+sb|0]|0;c[l+(nb<<2)>>2]=1;bb=nb+1|0;if(n){tb=bb;ub=4;break}c[l+(bb<<2)>>2]=3;eb=Da-1|0;db=rb+eb|0;c[k+(bb<<2)>>2]=o+(db*184|0);bb=nb+2|0;rb=s<<24>>24!=0;if(rb){D=203}else{s=c[e+7332>>2]|0;if((c[s+(sb<<2)>>2]|0)==(c[s+(db<<2)>>2]|0)){D=203}else{xb=1}}if((D|0)==203){xb=qb<<24>>24!=0|0}a[u+1|0]=xb;a[u+3|0]=xb;s=pb<<24>>24!=0;if(s){D=206}else{cb=c[e+7332>>2]|0;if((c[cb+(lb+eb<<2)>>2]|0)==(c[cb+(db<<2)>>2]|0)){D=206}else{yb=1}}if((D|0)==206){yb=vb}a[S+2|0]=yb;a[S+3|0]=yb;if(fb){if(qb<<24>>24==0){D=210}else{zb=1}}else{fb=c[e+7332>>2]|0;if((c[fb+(R<<2)>>2]|0)==(c[fb+(db<<2)>>2]|0)&qb<<24>>24==0){D=210}else{zb=1}}if((D|0)==210){zb=vb}a[v]=zb;a[q+3|0]=zb;db=c[e+7332>>2]|0;fb=c[db+(lb+eb<<2)>>2]|0;eb=c[db+(sb<<2)>>2]|0;if((fb|0)>(eb|0)){sb=s&qb<<24>>24==0?vb:1;a[q+2|0]=sb;a[q+1|0]=sb;tb=bb;ub=4;break}sb=qb<<24>>24==0;if((fb|0)<(eb|0)){eb=rb&sb?vb:1;a[q+1|0]=eb;a[q+2|0]=eb;tb=bb;ub=4;break}else{eb=sb?vb:1;a[q+2|0]=eb;a[q+1|0]=eb;tb=bb;ub=4;break}}}while(0);vb=e+160|0;qb=e+164|0;lb=0;zb=Ya;Ya=La;La=Ba;while(1){Ba=(lb|0)!=0|0;v=f>>Ba;D=g>>Ba;R=c[vb>>2]|0;yb=c[R+32+(lb<<2)>>2]|0;pb=c[zb+13140+(lb<<2)>>2]|0;xb=1<<c[zb+13080>>2]>>pb;nb=(c[zb+13096>>2]>>pb)-v|0;pb=(xb|0)>(nb|0)?nb:xb;nb=(c[zb+13100>>2]>>c[zb+13152+(lb<<2)>>2])-D|0;o=(xb|0)>(nb|0)?nb:xb;xb=ba(D,yb)|0;D=c[zb+56>>2]|0;nb=(v<<D)+xb|0;xb=c[R+(lb<<2)>>2]|0;R=xb+nb|0;v=c[(c[qb>>2]|0)+(lb<<2)>>2]|0;Da=v+nb|0;n=ub>>>(Ba>>>0);gb=ob>>>(Ba>>>0);Ba=nb-((gb<<D)+(ba(n,yb)|0))|0;nb=pb+((Ya|0)==0?0:gb)<<D;D=o+((La|0)==0?0:n)|0;if((D|0)>0){n=xb+Ba|0;xb=v+Ba|0;Ba=0;while(1){UGb(xb|0,n|0,nb)|0;v=Ba+1|0;if((v|0)<(D|0)){n=n+yb|0;xb=xb+yb|0;Ba=v}else{Ab=0;break}}}else{Ab=0}do{Ba=c[k+(Ab<<2)>>2]|0;xb=d[Ba+180+lb|0]|0;if((xb|0)==2){n=c[l+(Ab<<2)>>2]|0;se[c[e+5920+(n<<2)>>2]&127](Da,R,yb,Ba,m,pb,o,lb,a[u+n|0]|0,a[S+n|0]|0,a[q+n|0]|0)}else if((xb|0)==1){Be[c[e+5904+(c[l+(Ab<<2)>>2]<<2)>>2]&127](Da,R,yb,Ba,m,pb,o,lb)}Ab=Ab+1|0;}while((Ab|0)<(tb|0));o=lb+1|0;if((o|0)>=3){break}lb=o;zb=c[t>>2]|0;Ya=c[E>>2]|0;La=c[hb>>2]|0}i=h;return}function wBa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=(e|0)!=0;h=(d|0)==0;if(!(h|g^1)){vBa(b,d-f|0,e-f|0)}do{if(g){if(((c[(c[b+180>>2]|0)+13096>>2]|0)-f|0)>(d|0)){break}i=e-f|0;vBa(b,d,i);if((a[b+140|0]|0)!=1){break}Y0a((c[b+3480>>2]|0)+4|0,i,0)}}while(0);if(h){return}if(((c[(c[b+180>>2]|0)+13100>>2]|0)-f|0)>(e|0)){return}vBa(b,d-f|0,e);return}function xBa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=c[b+136>>2]|0;j=(c[b+180>>2]|0)+13080|0;b=(1<<c[j>>2])-1|0;k=b&e;l=b&f;if((a[i+173201|0]|0)==0){m=(l|0)!=0|0}else{m=1}c[i+184632>>2]=m;if((a[i+173200|0]|0)==0){n=(k|0)!=0|0}else{n=1}c[i+184628>>2]=n;o=(l|0)==0;if((b&(f|e)|0)==0){p=d[i+173203|0]|0}else{p=(n|0)==0?0:m}c[i+184636>>2]=p;p=k+g|0;if((p|0)==(1<<c[j>>2]|0)){q=(a[i+173202|0]|0)==0?0:o&1}else{q=m}c[i+184644>>2]=q;if((p|0)==(1<<c[j>>2]|0)){if((a[i+173202|0]|0)!=0&o){r=13}else{s=0}}else{if((m|0)==0){s=0}else{r=13}}if((r|0)==13){s=(g+e|0)<(c[i+173204>>2]|0)|0}c[i+184640>>2]=s;c[i+184624>>2]=(h+f|0)<(c[i+173208>>2]|0)?n:0;return}function yBa(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;o=i;i=i+88|0;p=o|0;q=o+8|0;r=o+16|0;s=1<<k;k=r;TGb(k|0,0,70)|0;t=e+136|0;u=c[t>>2]|0;v=e+184|0;if((c[(c[v>>2]|0)+1620>>2]|0)>2&(s|0)==8){w=c[u+184580>>2]|0;y=c[u+184584>>2]|0;z=8;A=8;B=1;C=0}else{w=f;y=g;z=h;A=j;B=0;C=l}xBa(e,w,y,z,A);l=p;g=q;f=c[t>>2]|0;t=c[e+3480>>2]|0;u=c[t+20>>2]|0;D=c[t+16>>2]|0;t=c[e+180>>2]|0;E=c[t+13132>>2]|0;F=c[f+184624>>2]|0;G=c[f+184636>>2]|0;H=c[f+184632>>2]|0;I=c[f+184644>>2]|0;J=w-1|0;K=y+A|0;L=K-1|0;M=c[t+13084>>2]|0;N=J>>M;O=L>>M;P=w+z|0;Q=P-1|0;R=y-1|0;S=Q>>M;T=R>>M;U=P>>M;V=K>>M;M=e+2404|0;W=c[e+3012>>2]|0;if((c[M>>2]|0)==1){X=W}else{Y=c[e+3016>>2]|0;X=W>>>0>Y>>>0?Y:W}if((c[f+184628>>2]|0)==0){Z=0}else{Z=(a[D+(((ba(O,E)|0)+N|0)*14|0)+12|0]|0)==0|0}W=(C|0)==1;C=(B|0)==0&W;if(C){B=c[f+184592>>2]|0;if((B|0)==2|(B|0)==6|(B|0)==7){_=0;$=1}else{aa=9}}else{aa=9}do{if((aa|0)==9){B=c[(c[v>>2]|0)+1620>>2]&255;if((J>>B|0)==(w>>B|0)){if(!((Z|0)!=0&(L>>B|0)!=(y>>B|0))){_=0;$=1;break}}else{if((Z|0)==0){_=0;$=1;break}}B=D+(((ba(O,E)|0)+N|0)*14|0)|0;b[k>>1]=b[B>>1]|0;b[k+2>>1]=b[B+2>>1]|0;b[k+4>>1]=b[B+4>>1]|0;b[k+6>>1]=b[B+6>>1]|0;b[k+8>>1]=b[B+8>>1]|0;b[k+10>>1]=b[B+10>>1]|0;b[k+12>>1]=b[B+12>>1]|0;_=1;$=0}}while(0);if((H|0)==0){ca=0}else{ca=(a[D+(((ba(T,E)|0)+S|0)*14|0)+12|0]|0)==0|0}if(C){C=c[f+184592>>2]|0;if((C|0)==1|(C|0)==4|(C|0)==5){da=_;ea=1}else{aa=17}}else{aa=17}do{if((aa|0)==17){C=c[(c[v>>2]|0)+1620>>2]&255;if((Q>>C|0)==(w>>C|0)){if((R>>C|0)==(y>>C|0)){da=_;ea=1;break}}C=(ca|0)==0;if($|C){fa=0}else{fa=(EBa(D+(((ba(T,E)|0)+S|0)*14|0)|0,D+(((ba(O,E)|0)+N|0)*14|0)|0)|0)!=0}if(C|fa){da=_;ea=C;break}C=r+(_*14|0)|0;H=D+(((ba(T,E)|0)+S|0)*14|0)|0;b[C>>1]=b[H>>1]|0;b[C+2>>1]=b[H+2>>1]|0;b[C+4>>1]=b[H+4>>1]|0;b[C+6>>1]=b[H+6>>1]|0;b[C+8>>1]=b[H+8>>1]|0;b[C+10>>1]=b[H+10>>1]|0;b[C+12>>1]=b[H+12>>1]|0;da=_+1|0;ea=0}}while(0);_=f+184580|0;fa=c[_>>2]|0;do{if((fa|0)<(P|0)){ca=c[f+184584>>2]|0;if((ca|0)>=(R|0)){aa=31;break}if((fa+s|0)<=(P|0)){aa=31;break}if((ca+s|0)<=(R|0)){aa=31;break}if((z<<1|0)!=(s|0)){ga=1;aa=35;break}if(!((A<<1|0)==(s|0)&W)){ga=1;aa=35;break}if((fa+z|0)<=(P|0)){ga=1;aa=35;break}ga=(ca+A|0)>(R|0)|0;aa=35}else{aa=31}}while(0);do{if((aa|0)==31){ca=c[(c[v>>2]|0)+1672>>2]|0;Q=c[t+13072>>2]|0;H=c[t+13124>>2]|0;C=c[ca+((ba(y>>Q,H)|0)+(w>>Q)<<2)>>2]|0;if((P|R|0)<0){ha=0;break}if((c[t+13096>>2]|0)<=(P|0)){ha=0;break}if((c[t+13100>>2]|0)<=(R|0)){ha=0;break}ga=(c[ca+((ba(R>>Q,H)|0)+(P>>Q)<<2)>>2]|0)<=(C|0)|0;aa=35}}while(0);do{if((aa|0)==35){if((ga|0)==0|(I|0)==0){ha=0;break}ha=(a[D+(((ba(T,E)|0)+U|0)*14|0)+12|0]|0)==0|0}}while(0);I=c[v>>2]|0;v=I+1620|0;ga=c[v>>2]&255;if((P>>ga|0)==(w>>ga|0)){ia=(R>>ga|0)==(y>>ga|0)?0:ha}else{ia=ha}ha=(ia|0)==0;if(ea|ha){ja=0}else{ia=ba(T,E)|0;ja=(EBa(D+((ia+U|0)*14|0)|0,D+((ia+S|0)*14|0)|0)|0)!=0}if(ha|ja){ka=da;la=fa}else{fa=r+(da*14|0)|0;ja=D+(((ba(T,E)|0)+U|0)*14|0)|0;b[fa>>1]=b[ja>>1]|0;b[fa+2>>1]=b[ja+2>>1]|0;b[fa+4>>1]=b[ja+4>>1]|0;b[fa+6>>1]=b[ja+6>>1]|0;b[fa+8>>1]=b[ja+8>>1]|0;b[fa+10>>1]=b[ja+10>>1]|0;b[fa+12>>1]=b[ja+12>>1]|0;ka=da+1|0;la=c[_>>2]|0}do{if((la|0)<(J|0)){_=c[f+184584>>2]|0;if((_|0)>=(K|0)){aa=51;break}if((la+s|0)<=(J|0)){aa=51;break}if((_+s|0)<=(K|0)){aa=51;break}if((z<<1|0)!=(s|0)){ma=1;aa=55;break}if(!((A<<1|0)==(s|0)&W)){ma=1;aa=55;break}if((la+z|0)<=(J|0)){ma=1;aa=55;break}ma=(_+A|0)>(K|0)|0;aa=55}else{aa=51}}while(0);do{if((aa|0)==51){la=c[I+1672>>2]|0;W=c[t+13072>>2]|0;s=c[t+13124>>2]|0;f=c[la+((ba(y>>W,s)|0)+(w>>W)<<2)>>2]|0;if((J|K|0)<0){na=0;break}if((c[t+13096>>2]|0)<=(J|0)){na=0;break}if((c[t+13100>>2]|0)<=(K|0)){na=0;break}ma=(c[la+((ba(K>>W,s)|0)+(J>>W)<<2)>>2]|0)<=(f|0)|0;aa=55}}while(0);do{if((aa|0)==55){if((ma|0)==0|(F|0)==0){na=0;break}na=(a[D+(((ba(V,E)|0)+N|0)*14|0)+12|0]|0)==0|0}}while(0);F=c[v>>2]&255;if((J>>F|0)==(w>>F|0)){oa=(K>>F|0)==(y>>F|0)?0:na}else{oa=na}na=(oa|0)==0;if($|na){pa=0}else{pa=(EBa(D+(((ba(V,E)|0)+N|0)*14|0)|0,D+(((ba(O,E)|0)+N|0)*14|0)|0)|0)!=0}if(na|pa){qa=ka}else{pa=r+(ka*14|0)|0;na=D+(((ba(V,E)|0)+N|0)*14|0)|0;b[pa>>1]=b[na>>1]|0;b[pa+2>>1]=b[na+2>>1]|0;b[pa+4>>1]=b[na+4>>1]|0;b[pa+6>>1]=b[na+6>>1]|0;b[pa+8>>1]=b[na+8>>1]|0;b[pa+10>>1]=b[na+10>>1]|0;b[pa+12>>1]=b[na+12>>1]|0;qa=ka+1|0}if((G|0)==0){ra=0}else{ra=(a[D+(((ba(T,E)|0)+N|0)*14|0)+12|0]|0)==0|0}G=c[v>>2]&255;if((J>>G|0)==(w>>G|0)){sa=(R>>G|0)==(y>>G|0)?0:ra}else{sa=ra}ra=(sa|0)==0;if($|ra){ta=1}else{ta=(EBa(D+(((ba(T,E)|0)+N|0)*14|0)|0,D+(((ba(O,E)|0)+N|0)*14|0)|0)|0)==0|0}if(ea|ra){ua=0}else{ea=ba(T,E)|0;ua=(EBa(D+((ea+N|0)*14|0)|0,D+((ea+S|0)*14|0)|0)|0)!=0}if(ra|(ta|0)==0|ua|(qa|0)==4){va=qa}else{ua=r+(qa*14|0)|0;ta=D+(((ba(T,E)|0)+N|0)*14|0)|0;b[ua>>1]=b[ta>>1]|0;b[ua+2>>1]=b[ta+2>>1]|0;b[ua+4>>1]=b[ta+4>>1]|0;b[ua+6>>1]=b[ta+6>>1]|0;b[ua+8>>1]=b[ta+8>>1]|0;b[ua+10>>1]=b[ta+10>>1]|0;b[ua+12>>1]=b[ta+12>>1]|0;va=qa+1|0}qa=e+3052|0;do{if((a[e+3011|0]|0)==0){wa=va}else{if(!(va>>>0<(c[qa>>2]|0)>>>0)){wa=va;break}ta=BBa(e,w,y,z,A,0,l,0)|0;if((c[M>>2]|0)==0){xa=BBa(e,w,y,z,A,0,g,1)|0}else{xa=0}ua=(ta|0)!=0;N=(xa|0)==0;if(N&(ua^1)){wa=va;break}a[r+(va*14|0)+12|0]=0;a[r+(va*14|0)+10|0]=ta;a[r+(va*14|0)+11|0]=xa;if(ua){ua=r+(va*14|0)|0;x=c[p>>2]|0;b[ua>>1]=x;b[ua+2>>1]=x>>16;a[r+(va*14|0)+8|0]=0}if(!N){N=r+(va*14|0)+4|0;x=c[q>>2]|0;b[N>>1]=x;b[N+2>>1]=x>>16;a[r+(va*14|0)+9|0]=0}wa=va+1|0}}while(0);va=(c[M>>2]|0)==0;M=c[qa>>2]|0;do{if(va&(wa|0)>1&wa>>>0<M>>>0){qa=ba(wa-1|0,wa)|0;if((qa|0)>0){ya=0;za=wa}else{Aa=wa;break}while(1){q=d[862352+(ya<<1)|0]|0;p=d[862353+(ya<<1)|0]|0;xa=b[r+(q*14|0)>>1]|0;g=b[r+(q*14|0)+2>>1]|0;A=a[r+(q*14|0)+8|0]|0;z=b[r+(p*14|0)+4>>1]|0;y=b[r+(p*14|0)+6>>1]|0;w=a[r+(p*14|0)+9|0]|0;do{if((a[r+(q*14|0)+10|0]|0)==0){Ba=za}else{if((a[r+(p*14|0)+11|0]|0)==0){Ba=za;break}if((c[u+64+(A<<24>>24<<2)>>2]|0)==(c[u+260+(w<<24>>24<<2)>>2]|0)&xa<<16>>16==z<<16>>16&g<<16>>16==y<<16>>16){Ba=za;break}a[r+(za*14|0)+8|0]=A;a[r+(za*14|0)+9|0]=w;a[r+(za*14|0)+10|0]=1;a[r+(za*14|0)+11|0]=1;b[r+(za*14|0)>>1]=xa;b[r+(za*14|0)+2>>1]=g;b[r+(za*14|0)+4>>1]=z;b[r+(za*14|0)+6>>1]=y;a[r+(za*14|0)+12|0]=0;Ba=za+1|0}}while(0);y=ya+1|0;if(Ba>>>0<M>>>0&(y|0)<(qa|0)){ya=y;za=Ba}else{Aa=Ba;break}}}else{Aa=wa}}while(0);if(Aa>>>0<M>>>0){wa=va&1;va=Aa;Aa=0;while(1){a[r+(va*14|0)+10|0]=1;a[r+(va*14|0)+11|0]=wa;a[r+(va*14|0)+12|0]=0;Ba=(Aa|0)<(X|0)?Aa&255:0;za=r+(va*14|0)|0;ya=za|0;x=0;b[ya>>1]=x;b[ya+2>>1]=x>>16;ya=za+4|0;x=0;b[ya>>1]=x;b[ya+2>>1]=x>>16;a[r+(va*14|0)+8|0]=Ba;a[r+(va*14|0)+9|0]=Ba;Ba=va+1|0;if(Ba>>>0<M>>>0){va=Ba;Aa=Aa+1|0}else{break}}}Aa=r+(m*14|0)|0;if((a[r+(m*14|0)+10|0]|0)!=1){Ca=n;Da=Aa;b[Ca>>1]=b[Da>>1]|0;b[Ca+2>>1]=b[Da+2>>1]|0;b[Ca+4>>1]=b[Da+4>>1]|0;b[Ca+6>>1]=b[Da+6>>1]|0;b[Ca+8>>1]=b[Da+8>>1]|0;b[Ca+10>>1]=b[Da+10>>1]|0;b[Ca+12>>1]=b[Da+12>>1]|0;i=o;return}va=r+(m*14|0)+11|0;if((a[va]|0)!=1){Ca=n;Da=Aa;b[Ca>>1]=b[Da>>1]|0;b[Ca+2>>1]=b[Da+2>>1]|0;b[Ca+4>>1]=b[Da+4>>1]|0;b[Ca+6>>1]=b[Da+6>>1]|0;b[Ca+8>>1]=b[Da+8>>1]|0;b[Ca+10>>1]=b[Da+10>>1]|0;b[Ca+12>>1]=b[Da+12>>1]|0;i=o;return}if((j+h|0)!=12){Ca=n;Da=Aa;b[Ca>>1]=b[Da>>1]|0;b[Ca+2>>1]=b[Da+2>>1]|0;b[Ca+4>>1]=b[Da+4>>1]|0;b[Ca+6>>1]=b[Da+6>>1]|0;b[Ca+8>>1]=b[Da+8>>1]|0;b[Ca+10>>1]=b[Da+10>>1]|0;b[Ca+12>>1]=b[Da+12>>1]|0;i=o;return}a[r+(m*14|0)+9|0]=-1;a[va]=0;Ca=n;Da=Aa;b[Ca>>1]=b[Da>>1]|0;b[Ca+2>>1]=b[Da+2>>1]|0;b[Ca+4>>1]=b[Da+4>>1]|0;b[Ca+6>>1]=b[Da+6>>1]|0;b[Ca+8>>1]=b[Da+8>>1]|0;b[Ca+10>>1]=b[Da+10>>1]|0;b[Ca+12>>1]=b[Da+12>>1]|0;i=o;return}function zBa(f,g,h,j,k,l,m,n,o,p,q){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;n=i;i=i+8|0;r=n|0;s=r;t=i;i=i+4|0;i=i+7&-8;u=t;v=i;i=i+4|0;i=i+7&-8;w=v;x=i;i=i+4|0;i=i+7&-8;y=x;z=f+136|0;A=c[z>>2]|0;B=f+3480|0;C=c[B>>2]|0;D=c[C+16>>2]|0;E=f+180|0;F=c[E>>2]|0;G=c[F+13132>>2]|0;c[r>>2]=0;c[r+4>>2]=0;c[t>>2]=0;c[v>>2]=0;H=1<<c[F+13080>>2];I=H-1|0;J=I&g;K=I&h;L=(K|0)!=0|(a[A+173201|0]|0)!=0;M=(J|0)!=0|(a[A+173200|0]|0)!=0;N=(K|0)==0;if((I&(h|g)|0)==0){O=d[A+173203|0]|0}else{O=M&L&1}if((J+j|0)==(H|0)){P=6}else{if((j+g|0)<(c[A+173204>>2]|0)){Q=L}else{P=6}}if((P|0)==6){Q=N&(a[A+173202|0]|0)!=0}N=k+h|0;H=c[A+173208>>2]|0;J=a[o+8+q|0]|0;I=(q|0)==0|0;K=g-1|0;R=c[F+13084>>2]|0;S=K>>R;T=N>>R;U=c[A+184580>>2]|0;do{if((U|0)<(K|0)){V=c[A+184584>>2]|0;if((V|0)>=(N|0)){P=15;break}W=1<<l;if((U+W|0)<=(K|0)){P=15;break}if((V+W|0)<=(N|0)){P=15;break}if((j<<1|0)!=(W|0)){P=19;break}if(!((k<<1|0)==(W|0)&(m|0)==1)){P=19;break}if((U+j|0)<=(K|0)){P=19;break}if((V+k|0)>(N|0)){P=19}else{X=0}}else{P=15}}while(0);do{if((P|0)==15){U=c[(c[f+184>>2]|0)+1672>>2]|0;A=c[F+13072>>2]|0;V=c[F+13124>>2]|0;W=c[U+((ba(h>>A,V)|0)+(g>>A)<<2)>>2]|0;if((N|K|0)<0){X=0;break}if((c[F+13096>>2]|0)<=(K|0)){X=0;break}if((c[F+13100>>2]|0)<=(N|0)){X=0;break}if((c[U+((ba(N>>A,V)|0)+(K>>A)<<2)>>2]|0)>(W|0)){X=0}else{P=19}}}while(0);do{if((P|0)==19){if(!(M&(N|0)<(H|0))){X=0;break}X=(a[D+(((ba(T,G)|0)+S|0)*14|0)+12|0]|0)==0}}while(0);H=N-1>>R;if(M){Y=(a[D+(((ba(H,G)|0)+S|0)*14|0)+12|0]|0)==0}else{Y=0}M=X|Y;a:do{if(X){R=c[C+20>>2]|0;N=(ba(G,T)|0)+S|0;do{if((a[D+(N*14|0)+10+q|0]|0)==1){if((c[R+(q*196|0)+64+(a[D+(N*14|0)+8+q|0]<<2)>>2]|0)!=(c[R+(q*196|0)+64+(J<<2)>>2]|0)){break}F=D+(N*14|0)+(q<<2)|0;c[t>>2]=e[F>>1]|e[F+2>>1]<<16;Z=1;break a}}while(0);if((a[D+(N*14|0)+10+I|0]|0)!=1){P=30;break}if((c[R+(I*196|0)+64+(a[D+(N*14|0)+8+I|0]<<2)>>2]|0)!=(c[R+(q*196|0)+64+(J<<2)>>2]|0)){P=30;break}F=D+(N*14|0)+(I<<2)|0;c[t>>2]=e[F>>1]|e[F+2>>1]<<16;Z=1}else{P=30}}while(0);b:do{if((P|0)==30){do{if(Y){F=c[C+20>>2]|0;W=(ba(G,H)|0)+S|0;do{if((a[D+(W*14|0)+10+q|0]|0)==1){if((c[F+(q*196|0)+64+(a[D+(W*14|0)+8+q|0]<<2)>>2]|0)!=(c[F+(q*196|0)+64+(J<<2)>>2]|0)){break}A=D+(W*14|0)+(q<<2)|0;c[t>>2]=e[A>>1]|e[A+2>>1]<<16;Z=1;break b}}while(0);if((a[D+(W*14|0)+10+I|0]|0)!=1){break}if((c[F+(I*196|0)+64+(a[D+(W*14|0)+8+I|0]<<2)>>2]|0)!=(c[F+(q*196|0)+64+(J<<2)>>2]|0)){break}A=D+(W*14|0)+(I<<2)|0;c[t>>2]=e[A>>1]|e[A+2>>1]<<16;Z=1;break b}}while(0);if(X){N=ABa(f,S,T,q,u,q,J)|0;if((N|0)!=0){Z=N;break}_=ABa(f,S,T,I,u,q,J)|0}else{_=0}if(!(Y&(_|0)==0)){Z=_;break}N=ABa(f,S,H,q,u,q,J)|0;if((N|0)!=0){Z=N;break}Z=ABa(f,S,H,I,u,q,J)|0}}while(0);H=j+g|0;S=h-1|0;_=c[E>>2]|0;E=c[_+13084>>2]|0;Y=H>>E;T=S>>E;X=c[z>>2]|0;z=c[X+184580>>2]|0;do{if((z|0)<(H|0)){C=c[X+184584>>2]|0;if((C|0)>=(S|0)){P=51;break}N=1<<l;if((z+N|0)<=(H|0)){P=51;break}if((C+N|0)<=(S|0)){P=51;break}if((j<<1|0)!=(N|0)){$=1;P=55;break}if(!((k<<1|0)==(N|0)&(m|0)==1)){$=1;P=55;break}if((z+j|0)<=(H|0)){$=1;P=55;break}$=(C+k|0)>(S|0)|0;P=55}else{P=51}}while(0);do{if((P|0)==51){z=c[(c[f+184>>2]|0)+1672>>2]|0;m=c[_+13072>>2]|0;l=c[_+13124>>2]|0;X=c[z+((ba(h>>m,l)|0)+(g>>m)<<2)>>2]|0;if((H|S|0)<0){aa=0;P=63;break}if((c[_+13096>>2]|0)<=(H|0)){aa=0;P=63;break}if((c[_+13100>>2]|0)<=(S|0)){aa=0;P=63;break}$=(c[z+((ba(S>>m,l)|0)+(H>>m)<<2)>>2]|0)<=(X|0)|0;P=55}}while(0);c:do{if((P|0)==55){if(($|0)==0|Q^1){aa=0;P=63;break}if((a[D+(((ba(T,G)|0)+Y|0)*14|0)+12|0]|0)!=0){aa=0;P=63;break}S=c[B>>2]|0;X=c[S+16>>2]|0;m=c[S+20>>2]|0;S=(ba(c[_+13132>>2]|0,T)|0)+Y|0;do{if((a[X+(S*14|0)+10+q|0]|0)==1){if((c[m+(q*196|0)+64+(a[X+(S*14|0)+8+q|0]<<2)>>2]|0)!=(c[m+(q*196|0)+64+(J<<2)>>2]|0)){break}l=X+(S*14|0)+(q<<2)|0;z=e[l>>1]|e[l+2>>1]<<16;c[v>>2]=z;ca=1;da=0;ea=0;fa=0;ga=1;ha=0;ia=0;ja=0;ka=z;break c}}while(0);if((a[X+(S*14|0)+10+I|0]|0)!=1){aa=1;P=63;break}if((c[m+(I*196|0)+64+(a[X+(S*14|0)+8+I|0]<<2)>>2]|0)!=(c[m+(q*196|0)+64+(J<<2)>>2]|0)){aa=1;P=63;break}z=X+(S*14|0)+(I<<2)|0;l=e[z>>1]|e[z+2>>1]<<16;c[v>>2]=l;ca=1;da=0;ea=0;fa=0;ga=1;ha=0;ia=0;ja=0;ka=l}}while(0);d:do{if((P|0)==63){Q=H-1>>E;do{if(L){$=(a[D+(((ba(T,G)|0)+Q|0)*14|0)+12|0]|0)==0;l=$&1;if(!$){la=l;break}$=c[B>>2]|0;z=c[$+16>>2]|0;C=c[$+20>>2]|0;$=(ba(c[_+13132>>2]|0,T)|0)+Q|0;do{if((a[z+($*14|0)+10+q|0]|0)==1){if((c[C+(q*196|0)+64+(a[z+($*14|0)+8+q|0]<<2)>>2]|0)!=(c[C+(q*196|0)+64+(J<<2)>>2]|0)){break}N=z+($*14|0)+(q<<2)|0;R=e[N>>1]|e[N+2>>1]<<16;c[v>>2]=R;ca=1;da=0;ea=0;fa=0;ga=aa;ha=l;ia=T;ja=Q;ka=R;break d}}while(0);if((a[z+($*14|0)+10+I|0]|0)!=1){la=l;break}if((c[C+(I*196|0)+64+(a[z+($*14|0)+8+I|0]<<2)>>2]|0)!=(c[C+(q*196|0)+64+(J<<2)>>2]|0)){la=l;break}W=z+($*14|0)+(I<<2)|0;F=e[W>>1]|e[W+2>>1]<<16;c[v>>2]=F;ca=1;da=0;ea=0;fa=0;ga=aa;ha=l;ia=T;ja=Q;ka=F;break d}else{la=0}}while(0);S=K>>E;if((O|0)==0){ca=0;da=S;ea=T;fa=0;ga=aa;ha=la;ia=T;ja=Q;ka=0;break}X=(a[D+(((ba(T,G)|0)+S|0)*14|0)+12|0]|0)==0;m=X&1;if(!X){ca=0;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=0;break}X=c[B>>2]|0;F=c[X+16>>2]|0;W=c[X+20>>2]|0;X=(ba(c[_+13132>>2]|0,T)|0)+S|0;do{if((a[F+(X*14|0)+10+q|0]|0)==1){if((c[W+(q*196|0)+64+(a[F+(X*14|0)+8+q|0]<<2)>>2]|0)!=(c[W+(q*196|0)+64+(J<<2)>>2]|0)){break}R=F+(X*14|0)+(q<<2)|0;N=e[R>>1]|e[R+2>>1]<<16;c[v>>2]=N;ca=1;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=N;break d}}while(0);if((a[F+(X*14|0)+10+I|0]|0)!=1){ca=0;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=0;break}if((c[W+(I*196|0)+64+(a[F+(X*14|0)+8+I|0]<<2)>>2]|0)!=(c[W+(q*196|0)+64+(J<<2)>>2]|0)){ca=0;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=0;break}N=F+(X*14|0)+(I<<2)|0;R=e[N>>1]|e[N+2>>1]<<16;c[v>>2]=R;ca=1;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=R}}while(0);do{if(M){ma=Z;na=ca}else{if((ca|0)==0){oa=Z}else{c[t>>2]=ka;oa=1}if(ga){la=ABa(f,Y,T,q,w,q,J)|0;if((la|0)!=0){ma=oa;na=la;break}pa=ABa(f,Y,T,I,w,q,J)|0}else{pa=0}if((ha|0)!=0&(pa|0)==0){la=ABa(f,ja,ia,q,w,q,J)|0;if((la|0)!=0){ma=oa;na=la;break}qa=ABa(f,ja,ia,I,w,q,J)|0}else{qa=pa}if(!((fa|0)!=0&(qa|0)==0)){ma=oa;na=qa;break}la=ABa(f,da,ea,q,w,q,J)|0;if((la|0)!=0){ma=oa;na=la;break}ma=oa;na=ABa(f,da,ea,I,w,q,J)|0}}while(0);I=(ma|0)!=0;if(I){c[r>>2]=c[t>>2];ra=1}else{ra=0}e:do{if((na|0)==0){sa=ra;P=98}else{do{if(I){if((b[t>>1]|0)!=(b[v>>1]|0)){break}if((b[u+2>>1]|0)==(b[w+2>>1]|0)){sa=ra;P=98;break e}}}while(0);Q=ra+1|0;c[s+(ra<<2)>>2]=c[v>>2];if(Q>>>0<2>>>0){sa=Q;P=98}else{ta=Q}}}while(0);do{if((P|0)==98){if((a[f+3011|0]|0)==0){ta=sa;break}if((BBa(f,g,h,j,k,J,y,q)|0)==0){ta=sa;break}c[s+(sa<<2)>>2]=c[x>>2];ta=sa+1|0}}while(0);if((ta|0)<2){ua=ta}else{va=s+(p<<2)|0;wa=b[va>>1]|0;xa=o+(q<<2)|0;b[xa>>1]=wa;ya=s+(p<<2)+2|0;za=b[ya>>1]|0;Aa=o+(q<<2)+2|0;b[Aa>>1]=za;i=n;return}while(1){ta=ua+1|0;b[s+(ua<<2)>>1]=0;b[s+(ua<<2)+2>>1]=0;if((ta|0)<2){ua=ta}else{break}}va=s+(p<<2)|0;wa=b[va>>1]|0;xa=o+(q<<2)|0;b[xa>>1]=wa;ya=s+(p<<2)+2|0;za=b[ya>>1]|0;Aa=o+(q<<2)+2|0;b[Aa>>1]=za;i=n;return}function ABa(d,f,g,h,i,j,k){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=d+3480|0;m=c[l>>2]|0;n=c[m+16>>2]|0;o=c[m+20>>2]|0;m=c[o+(j*196|0)+128+(k<<2)>>2]|0;p=(ba(c[(c[d+180>>2]|0)+13132>>2]|0,g)|0)+f|0;if((a[n+(p*14|0)+10+h|0]|0)==0){q=0;return q|0}if((c[o+(h*196|0)+128+(a[n+(p*14|0)+8+h|0]<<2)>>2]|0)!=(m|0)){q=0;return q|0}o=n+(p*14|0)+(h<<2)|0;n=i;f=e[o>>1]|e[o+2>>1]<<16;x=f;b[n>>1]=x;b[n+2>>1]=x>>16;if((m|0)!=0){q=1;return q|0}m=c[l>>2]|0;l=c[m+20>>2]|0;n=c[l+(h*196|0)+64+(a[(c[m+16>>2]|0)+(p*14|0)+8+h|0]<<2)>>2]|0;h=c[l+(j*196|0)+64+(k<<2)>>2]|0;if((n|0)==(h|0)){q=1;return q|0}k=c[d+5788>>2]|0;d=(k|0)==(n|0)?1:k-n|0;n=k-h|0;if((d+128|0)>>>0>255>>>0){r=(d>>31^127)&255}else{r=d&255}d=r<<24>>24;if((n+128|0)>>>0>255>>>0){s=(n>>31^127)&255}else{s=n&255}n=(d|0)/2|0;h=(ba(((r<<24>>24>-2?n:-n|0)+16384|0)/(d|0)|0,s<<24>>24)|0)+32>>6;if((h|0)<-4096){t=-4096}else{t=(h|0)>4095?4095:h}h=ba(f<<16>>16,t)|0;s=h+127+(h>>>31)|0;h=s>>8;if((h+32768|0)>>>0>65535>>>0){u=(s>>31^32767)&65535}else{u=h&65535}b[i>>1]=u;u=ba(f>>16,t)|0;t=u+127+(u>>>31)|0;u=t>>8;if((u+32768|0)>>>0>65535>>>0){v=(t>>31^32767)&65535}else{v=u&65535}b[i+2>>1]=v;q=1;return q|0}function BBa(d,e,f,g,h,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=i;i=i+16|0;n=m|0;o=d+180|0;p=c[(c[o>>2]|0)+13132>>2]|0;q=c[(c[d+3480>>2]|0)+36>>2]|0;if((q|0)==0){r=0;i=m;return r|0}s=c[q+16>>2]|0;t=c[q+32>>2]|0;u=g+e|0;v=h+f|0;if((a[d+140|0]|0)==1){Z0a(q+4|0,v,0)}if((s|0)==0){r=0;i=m;return r|0}w=c[o>>2]|0;x=c[w+13080>>2]|0;do{if((f>>x|0)==(v>>x|0)){if((v|0)>=(c[w+13100>>2]|0)){break}if((u|0)>=(c[w+13096>>2]|0)){break}y=u&-16;z=v&-16;A=c[w+13084>>2]|0;B=n;C=s+(((ba(z>>A,p)|0)+(y>>A)|0)*14|0)|0;b[B>>1]=b[C>>1]|0;b[B+2>>1]=b[C+2>>1]|0;b[B+4>>1]=b[C+4>>1]|0;b[B+6>>1]=b[C+6>>1]|0;b[B+8>>1]=b[C+8>>1]|0;b[B+10>>1]=b[C+10>>1]|0;b[B+12>>1]=b[C+12>>1]|0;C=CBa(d,n,j,k,l,t,RBa(d,q,y,z)|0)|0;if((C|0)==0){break}else{r=C}i=m;return r|0}}while(0);w=(g>>1)+e&-16;e=(h>>1)+f&-16;f=c[(c[o>>2]|0)+13084>>2]|0;o=n;h=s+(((ba(e>>f,p)|0)+(w>>f)|0)*14|0)|0;b[o>>1]=b[h>>1]|0;b[o+2>>1]=b[h+2>>1]|0;b[o+4>>1]=b[h+4>>1]|0;b[o+6>>1]=b[h+6>>1]|0;b[o+8>>1]=b[h+8>>1]|0;b[o+10>>1]=b[h+10>>1]|0;b[o+12>>1]=b[h+12>>1]|0;r=CBa(d,n,j,k,l,t,RBa(d,q,w,e)|0)|0;i=m;return r|0}function CBa(d,e,f,g,h,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;l=i;m=e;e=i;i=i+14|0;i=i+7&-8;c[e>>2]=c[m>>2];c[e+4>>2]=c[m+4>>2];c[e+8>>2]=c[m+8>>2];b[e+12>>1]=b[m+12>>1]|0;m=c[(c[d+3480>>2]|0)+20>>2]|0;if((a[e+12|0]|0)!=0){b[g>>1]=0;b[g+2>>1]=0;n=0;i=l;return n|0}o=a[e+10|0]|0;if((o<<24>>24|0)==1){p=a[e+11|0]|0;if((p<<24>>24|0)==0){n=DBa(g,e|0,j,c[d+5788>>2]|0,m,h,f,k,0,a[e+8|0]|0)|0;i=l;return n|0}else if((p<<24>>24|0)==1){p=c[m+192>>2]|0;if((p|0)>0){q=c[d+5788>>2]|0;r=0;s=0;while(1){t=((c[m+64+(s<<2)>>2]|0)>(q|0))+r|0;u=s+1|0;if((u|0)<(p|0)){r=t;s=u}else{v=t;break}}}else{v=0}s=c[m+388>>2]|0;if((s|0)>0){r=c[d+5788>>2]|0;p=v;q=0;while(1){t=((c[m+260+(q<<2)>>2]|0)>(r|0))+p|0;u=q+1|0;if((u|0)<(s|0)){p=t;q=u}else{w=t;break}}}else{w=v}if((w|h|0)==0){n=DBa(g,e|0,j,c[d+5788>>2]|0,m,h,f,k,0,a[e+8|0]|0)|0;i=l;return n|0}if((w|0)==0&(h|0)==1){n=DBa(g,e+4|0,j,c[d+5788>>2]|0,m,1,f,k,1,a[e+9|0]|0)|0;i=l;return n|0}if((a[d+3027|0]|0)==1){n=DBa(g,e|0,j,c[d+5788>>2]|0,m,h,f,k,0,a[e+8|0]|0)|0;i=l;return n|0}else{n=DBa(g,e+4|0,j,c[d+5788>>2]|0,m,h,f,k,1,a[e+9|0]|0)|0;i=l;return n|0}}else{n=0;i=l;return n|0}}else if((o<<24>>24|0)==0){n=DBa(g,e+4|0,j,c[d+5788>>2]|0,m,h,f,k,1,a[e+9|0]|0)|0;i=l;return n|0}else{n=0;i=l;return n|0}return 0}function DBa(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;m=c[g+(h*196|0)+128+(i<<2)>>2]|0;if((m|0)!=(c[j+(k*196|0)+128+(l<<2)>>2]|0)){b[a>>1]=0;b[a+2>>1]=0;n=0;return n|0}o=c[j+(k*196|0)+64+(l<<2)>>2]|0;l=f-(c[g+(h*196|0)+64+(i<<2)>>2]|0)|0;i=(o|0)==(e|0)?1:e-o|0;if((m|0)!=0|(i|0)==(l|0)){b[a>>1]=b[d>>1]|0;b[a+2>>1]=b[d+2>>1]|0;n=1;return n|0}if((i+128|0)>>>0>255>>>0){p=(i>>31^127)&255}else{p=i&255}i=p<<24>>24;if((l+128|0)>>>0>255>>>0){q=(l>>31^127)&255}else{q=l&255}l=(i|0)/2|0;m=(ba(((p<<24>>24>-2?l:-l|0)+16384|0)/(i|0)|0,q<<24>>24)|0)+32>>6;if((m|0)<-4096){r=-4096}else{r=(m|0)>4095?4095:m}m=ba(b[d>>1]|0,r)|0;q=m+127+(m>>>31)|0;m=q>>8;if((m+32768|0)>>>0>65535>>>0){s=(q>>31^32767)&65535}else{s=m&65535}b[a>>1]=s;s=ba(b[d+2>>1]|0,r)|0;r=s+127+(s>>>31)|0;s=r>>8;if((s+32768|0)>>>0>65535>>>0){t=(r>>31^32767)&65535}else{t=s&65535}b[a+2>>1]=t;n=1;return n|0}function EBa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=d;d=i;i=i+14|0;i=i+7&-8;c[d>>2]=c[g>>2];c[d+4>>2]=c[g+4>>2];c[d+8>>2]=c[g+8>>2];b[d+12>>1]=b[g+12>>1]|0;g=e;e=i;i=i+14|0;i=i+7&-8;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];b[e+12>>1]=b[g+12>>1]|0;g=(a[d+11|0]|0)==0;do{if((a[d+10|0]|0)==0){if(g){h=0;break}if((a[e+10|0]|0)!=0){h=0;break}if((a[e+11|0]|0)==0){h=0;break}if((a[d+9|0]|0)!=(a[e+9|0]|0)){h=0;break}if((b[d+4>>1]|0)!=(b[e+4>>1]|0)){h=0;break}h=(b[d+6>>1]|0)==(b[e+6>>1]|0)|0}else{j=(a[e+10|0]|0)==0;if(g){if(j){h=0;break}if((a[e+11|0]|0)!=0){h=0;break}if((a[d+8|0]|0)!=(a[e+8|0]|0)){h=0;break}if((b[d>>1]|0)!=(b[e>>1]|0)){h=0;break}h=(b[d+2>>1]|0)==(b[e+2>>1]|0)|0;break}if(j){h=0;break}if((a[e+11|0]|0)==0){h=0;break}if((a[d+8|0]|0)!=(a[e+8|0]|0)){h=0;break}if((b[d>>1]|0)!=(b[e>>1]|0)){h=0;break}if((b[d+2>>1]|0)!=(b[e+2>>1]|0)){h=0;break}if((a[d+9|0]|0)!=(a[e+9|0]|0)){h=0;break}if((b[d+4>>1]|0)!=(b[e+4>>1]|0)){h=0;break}h=(b[d+6>>1]|0)==(b[e+6>>1]|0)|0}}while(0);i=f;return h|0}function FBa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;j=c[b+136>>2]|0;k=j+9272|0;l=f+2188|0;do{if((l|0)!=(e|0)){m=f+2184|0;if((c[m>>2]|0)==0){break}n=j+9280|0;o=c[n>>2]|0;p=k|0;q=c[p>>2]|0;r=d[q+(o>>>3)|0]|0;s=j+9288|0;t=c[s>>2]|0;u=((o|0)<(t|0))+o|0;c[n>>2]=u;if((r&128>>>((o&7)>>>0)|0)==0){break}do{if((g|0)==0){v=((e-l|0)/168|0)-1|0;w=u;x=q;y=t}else{o=(GBa(k)|0)+1|0;r=c[m>>2]|0;if(!(o>>>0>r>>>0)){v=r-o|0;w=c[n>>2]|0;x=c[p>>2]|0;y=c[s>>2]|0;break}yDb(c[b+4>>2]|0,16,2278520,(z=i,i=i+16|0,c[z>>2]=o,c[z+8>>2]=r,z)|0);i=z;A=-1094995529;i=h;return A|0}}while(0);m=(d[x+(w>>>3)|0]|0)<<(w&7)>>>7;c[n>>2]=((w|0)<(y|0))+w;t=ba(1-(m<<1&2)|0,(GBa(k)|0)+1|0)|0;m=f+2188+(v*168|0)+4|0;if((c[m>>2]|0)<0){c[e+4>>2]=0;c[e>>2]=0;A=0;i=h;return A|0}else{B=0;C=0;D=0}while(1){q=c[n>>2]|0;u=(d[(c[p>>2]|0)+(q>>>3)|0]|0)<<(q&7)>>>7;c[n>>2]=((q|0)<(c[s>>2]|0))+q;q=u&1;a[e+136+C|0]=q;if((q|0)==0){q=c[n>>2]|0;u=d[(c[p>>2]|0)+(q>>>3)|0]|0;c[n>>2]=((q|0)<(c[s>>2]|0))+q;if((u&128>>>((q&7)>>>0)|0)==0){E=D;F=C}else{G=13}}else{G=13}if((G|0)==13){G=0;if((B|0)<(c[m>>2]|0)){H=(c[f+2188+(v*168|0)+8+(B<<2)>>2]|0)+t|0}else{H=t}c[e+8+(C<<2)>>2]=H;E=(H>>>31)+D|0;F=C+1|0}q=B+1|0;if((q|0)>(c[m>>2]|0)){break}else{B=q;C=F;D=E}}m=e+4|0;c[m>>2]=F;t=e|0;c[t>>2]=E;if((F|0)>1){s=1;n=F;while(1){p=c[e+8+(s<<2)>>2]|0;q=a[e+136+s|0]|0;if((s|0)>0){u=s;while(1){r=u-1|0;o=e+8+(r<<2)|0;I=c[o>>2]|0;if((p|0)<(I|0)){c[e+8+(u<<2)>>2]=I;I=e+136+r|0;a[e+136+u|0]=a[I]|0;c[o>>2]=p;a[I]=q}if((r|0)>0){u=r}else{break}}J=c[m>>2]|0}else{J=n}u=s+1|0;if((u|0)<(J|0)){s=u;n=J}else{break}}K=c[t>>2]|0}else{K=E}if(K>>>0>1>>>0){L=0;M=K}else{A=0;i=h;return A|0}while(1){n=M-1|0;s=e+8+(L<<2)|0;m=c[s>>2]|0;u=e+136+L|0;q=a[u]|0;p=e+8+(n<<2)|0;c[s>>2]=c[p>>2];s=e+136+n|0;a[u]=a[s]|0;c[p>>2]=m;a[s]=q;q=L+1|0;if(q>>>0<(c[t>>2]|0)>>>1>>>0){L=q;M=n}else{A=0;break}}i=h;return A|0}}while(0);M=e|0;c[M>>2]=GBa(k)|0;L=GBa(k)|0;K=c[M>>2]|0;if(K>>>0>15>>>0|L>>>0>15>>>0){yDb(c[b+4>>2]|0,16,2323728,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=h;return A|0}z=K+L|0;c[e+4>>2]=z;if((z|0)==0){A=0;i=h;return A|0}if((K|0)!=0){K=j+9280|0;z=k|0;b=j+9288|0;E=0;J=0;do{J=J-1-(GBa(k)|0)|0;c[e+8+(E<<2)>>2]=J;F=c[K>>2]|0;D=(d[(c[z>>2]|0)+(F>>>3)|0]|0)<<(F&7)>>>7;c[K>>2]=((F|0)<(c[b>>2]|0))+F;a[e+136+E|0]=D&1;E=E+1|0;}while(E>>>0<(c[M>>2]|0)>>>0)}if((L|0)==0){A=0;i=h;return A|0}E=j+9280|0;b=k|0;K=j+9288|0;j=0;z=0;while(1){J=z+1+(GBa(k)|0)|0;c[e+8+((c[M>>2]|0)+j<<2)>>2]=J;D=c[E>>2]|0;F=(d[(c[b>>2]|0)+(D>>>3)|0]|0)<<(D&7)>>>7;c[E>>2]=((D|0)<(c[K>>2]|0))+D;a[(c[M>>2]|0)+j+(e+136)|0]=F&1;F=j+1|0;if(F>>>0<L>>>0){j=F;z=J}else{A=0;break}}i=h;return A|0}function GBa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a>>2]|0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;a=b+(f>>>3)|0;h=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7);a=f+16|0;i=g>>>0>a>>>0?a:g;a=b+(i>>>3)|0;j=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>16|h&-65536;i=j>>>0>65535>>>0;a=i?h>>>16:j;j=i?16:0;if((a&65280|0)==0){k=j;l=a}else{k=j|8;l=a>>>8}a=(d[1191992+l|0]|0)+k|0;k=31-a|0;l=-f|0;j=g-f|0;if((k|0)<(l|0)){m=l}else{m=(j|0)<(k|0)?j:k}j=m+f|0;c[e>>2]=j;f=k+1|0;if((f|0)==0){n=0;o=n-1|0;return o|0}m=b+(j>>>3)|0;l=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7);if((f|0)<26){m=j+f|0;c[e>>2]=g>>>0>m>>>0?m:g;n=l>>>(a>>>0);o=n-1|0;return o|0}else{a=j+16|0;j=g>>>0>a>>>0?a:g;c[e>>2]=j;a=k-15|0;m=b+(j>>>3)|0;b=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>((47-k|0)>>>0);k=j+a|0;c[e>>2]=g>>>0>k>>>0?k:g;n=b|l>>>16<<a;o=n-1|0;return o|0}return 0}function HBa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+8|0;f=e|0;g=c[b+136>>2]|0;h=g+9272|0;j=VAb(468)|0;c[f>>2]=j;if((j|0)==0){k=-12;i=e;return k|0}l=c[j+4>>2]|0;j=b+4|0;yDb(c[j>>2]|0,48,2187360,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=g+9280|0;o=c[n>>2]|0;p=g+9288|0;g=c[p>>2]|0;q=h|0;r=c[q>>2]|0;s=r+(o>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(o&7)>>>28;s=o+4|0;o=g>>>0>s>>>0?s:g;c[n>>2]=o;s=r+(o>>>3)|0;u=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(o&7);s=o+2|0;o=g>>>0>s>>>0?s:g;c[n>>2]=o;do{if((u&-1073741824|0)==-1073741824){s=r+(o>>>3)|0;v=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(o&7)>>>26;s=o+6|0;c[n>>2]=g>>>0>s>>>0?s:g;c[l+4>>2]=v+1;v=c[n>>2]|0;s=c[p>>2]|0;w=r+(v>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)>>>29;w=v+3|0;c[n>>2]=s>>>0>w>>>0?w:s;s=l+8|0;c[s>>2]=x+1;x=c[n>>2]|0;w=(d[r+(x>>>3)|0]|0)<<(x&7)>>>7;c[n>>2]=((x|0)<(c[p>>2]|0))+x;a[l]=w&1;w=c[n>>2]|0;x=c[p>>2]|0;v=(c[q>>2]|0)+(w>>>3)|0;y=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(w&7);v=w+16|0;c[n>>2]=x>>>0>v>>>0?v:x;if(!((y&-65536|0)==-65536)){yDb(c[j>>2]|0,16,2006488,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;break}y=c[s>>2]|0;if((y|0)>7){yDb(c[j>>2]|0,16,1968640,(m=i,i=i+8|0,c[m>>2]=y,m)|0);i=m;break}IBa(b,l+12|0,y);y=c[n>>2]|0;x=(d[(c[q>>2]|0)+(y>>>3)|0]|0)<<(y&7)>>>7;c[n>>2]=((y|0)<(c[p>>2]|0))+y;y=x&1;c[l+348>>2]=y;if((y|0)==0){z=(c[s>>2]|0)-1|0}else{z=0}y=l+352|0;x=l+380|0;v=l+408|0;w=z;while(1){if((w|0)>=(c[s>>2]|0)){A=17;break}B=y+(w<<2)|0;c[B>>2]=(GBa(h)|0)+1;C=x+(w<<2)|0;c[C>>2]=GBa(h)|0;c[v+(w<<2)>>2]=(GBa(h)|0)-1;D=c[B>>2]|0;if(D>>>0>16>>>0){A=13;break}E=c[C>>2]|0;if(E>>>0>(D-1|0)>>>0){A=16;break}w=w+1|0}if((A|0)==13){yDb(c[j>>2]|0,16,1940144,(m=i,i=i+8|0,c[m>>2]=D-1,m)|0);i=m;break}else if((A|0)==16){yDb(c[j>>2]|0,16,1915944,(m=i,i=i+8|0,c[m>>2]=E,m)|0);i=m;break}else if((A|0)==17){w=c[n>>2]|0;v=c[p>>2]|0;x=(c[q>>2]|0)+(w>>>3)|0;y=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(w&7)>>>26;x=w+6|0;c[n>>2]=v>>>0>x>>>0?x:v;v=l+436|0;c[v>>2]=y;y=(GBa(h)|0)+1|0;x=l+440|0;c[x>>2]=y;if((y|0)>1){w=1;C=c[v>>2]|0;B=y;while(1){if((C|0)<0){F=C;G=B}else{y=c[p>>2]|0;H=0;I=c[n>>2]|0;do{J=I+1|0;I=y>>>0>J>>>0?J:y;c[n>>2]=I;H=H+1|0;K=c[v>>2]|0;}while((H|0)<=(K|0));F=K;G=c[x>>2]|0}H=w+1|0;if((H|0)<(G|0)){w=H;C=F;B=G}else{break}}}B=c[n>>2]|0;C=(d[(c[q>>2]|0)+(B>>>3)|0]|0)<<(B&7)>>>7;c[n>>2]=((B|0)<(c[p>>2]|0))+B;B=C&1;a[l+444|0]=B;do{if(!(B<<24>>24==0)){C=c[n>>2]|0;w=c[p>>2]|0;x=c[q>>2]|0;v=x+(C>>>3)|0;H=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(C&7)&-65536;v=C+16|0;C=w>>>0>v>>>0?v:w;c[n>>2]=C;v=x+(C>>>3)|0;I=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(C&7)>>>16;v=C+16|0;c[n>>2]=w>>>0>v>>>0?v:w;c[l+448>>2]=I|H;H=c[n>>2]|0;I=c[p>>2]|0;w=x+(H>>>3)|0;v=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(H&7)&-65536;w=H+16|0;H=I>>>0>w>>>0?w:I;c[n>>2]=H;w=x+(H>>>3)|0;C=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(H&7)>>>16;w=H+16|0;c[n>>2]=I>>>0>w>>>0?w:I;c[l+452>>2]=C|v;v=c[n>>2]|0;C=(d[x+(v>>>3)|0]|0)<<(v&7)>>>7;c[n>>2]=((v|0)<(c[p>>2]|0))+v;v=C&1;a[l+456|0]=v;if(!(v<<24>>24==0)){c[l+460>>2]=(GBa(h)|0)+1}v=GBa(h)|0;C=l+464|0;c[C>>2]=v;if((v|0)>0){L=0}else{break}do{GBa(h)|0;if((L|0)==0){M=1}else{v=c[n>>2]|0;x=(d[(c[q>>2]|0)+(v>>>3)|0]|0)<<(v&7)>>>7;c[n>>2]=((v|0)<(c[p>>2]|0))+v;M=x&1}JBa(b,M,c[s>>2]|0);L=L+1|0;}while((L|0)<(c[C>>2]|0))}}while(0);s=c[n>>2]|0;c[n>>2]=((s|0)<(c[p>>2]|0))+s;s=b+188+(t<<2)|0;XAb(s);c[s>>2]=c[f>>2];k=0;i=e;return k|0}}else{yDb(c[j>>2]|0,16,2051872,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}}while(0);XAb(f);k=-1094995529;i=e;return k|0}function IBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b+136>>2]|0;PBa(b,e|0);h=g+9280|0;i=c[h>>2]|0;j=g+9288|0;k=c[j>>2]|0;l=g+9272|0;g=(c[l>>2]|0)+(i>>>3)|0;m=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(i&7)>>>24;g=i+8|0;c[h>>2]=k>>>0>g>>>0?g:k;a[e+35|0]=m;m=f-1|0;f=(m|0)>0;if(f){n=0}else{return}do{k=c[h>>2]|0;g=d[(c[l>>2]|0)+(k>>>3)|0]<<(k&7)>>>7;c[h>>2]=((k|0)<(c[j>>2]|0))+k;a[e+320+n|0]=g&1;g=c[h>>2]|0;k=d[(c[l>>2]|0)+(g>>>3)|0]<<(g&7)>>>7;c[h>>2]=((g|0)<(c[j>>2]|0))+g;a[e+327+n|0]=k&1;n=n+1|0;}while((n|0)<(m|0));if(!f){return}do{if((m|0)<8){n=c[j>>2]|0;k=m;g=c[h>>2]|0;do{i=g+2|0;g=n>>>0>i>>>0?i:n;k=k+1|0;}while((k|0)<8);c[h>>2]=g;if(f){o=0;break}return}else{o=0}}while(0);do{if((a[e+320+o|0]|0)!=0){PBa(b,e+40+(o*40|0)|0)}if((a[e+327+o|0]|0)!=0){f=c[h>>2]|0;k=c[j>>2]|0;n=(c[l>>2]|0)+(f>>>3)|0;i=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(f&7)>>>24;n=f+8|0;c[h>>2]=k>>>0>n>>>0?n:k;a[e+40+(o*40|0)+35|0]=i}o=o+1|0;}while((o|0)<(m|0));return}function JBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a+136|0;a=c[f>>2]|0;g=a+9272|0;do{if((b|0)==0){h=0;i=0;j=0}else{k=a+9280|0;l=c[k>>2]|0;m=c[g>>2]|0;n=(d[m+(l>>>3)|0]|0)<<(l&7)>>>7;o=c[a+9288>>2]|0;p=((l|0)<(o|0))+l|0;c[k>>2]=p;l=n&1;q=(d[m+(p>>>3)|0]|0)<<(p&7)>>>7;r=((p|0)<(o|0))+p|0;c[k>>2]=r;p=q&1;if(((q|n)&1|0)==0){h=0;i=p;j=l;break}n=(d[m+(r>>>3)|0]|0)<<(r&7)>>>7;m=((r|0)<(o|0))+r|0;c[k>>2]=m;r=n&1;if((r|0)==0){n=m+4|0;q=o>>>0>n>>>0?n:o;c[k>>2]=q;n=q+4|0;s=o>>>0>n>>>0?n:o}else{n=m+8|0;m=(o>>>0>n>>>0?n:o)+5|0;n=(o>>>0>m>>>0?m:o)+1|0;m=(o>>>0>n>>>0?n:o)+5|0;n=(o>>>0>m>>>0?m:o)+4|0;m=(o>>>0>n>>>0?n:o)+4|0;n=o>>>0>m>>>0?m:o;c[k>>2]=n;m=n+4|0;s=o>>>0>m>>>0?m:o}m=s+5|0;n=(o>>>0>m>>>0?m:o)+5|0;m=(o>>>0>n>>>0?n:o)+5|0;c[k>>2]=o>>>0>m>>>0?m:o;h=r;i=p;j=l}}while(0);if((e|0)<=0){return}s=a+9280|0;b=g|0;l=a+9288|0;a=(i|0)==0;if((j|0)==0){j=1;while(1){i=c[s>>2]|0;p=c[b>>2]|0;r=d[p+(i>>>3)|0]|0;o=c[l>>2]|0;m=((i|0)<(o|0))+i|0;c[s>>2]=m;do{if((r&128>>>((i&7)>>>0)|0)==0){k=d[p+(m>>>3)|0]|0;n=((m|0)<(o|0))+m|0;c[s>>2]=n;if((k&128>>>((m&7)>>>0)|0)!=0){t=11;break}k=d[p+(n>>>3)|0]|0;c[s>>2]=((n|0)<(o|0))+n;if((k&128>>>((n&7)>>>0)|0)==0){t=13}else{u=1}}else{t=11}}while(0);if((t|0)==11){t=0;GBa(g)|0;t=13}if((t|0)==13){t=0;u=(GBa(g)|0)+1|0}if(!a){OBa(c[f>>2]|0,u,h)}if((j|0)>=(e|0)){break}j=j+1|0}return}else{j=1;while(1){u=c[s>>2]|0;o=c[b>>2]|0;p=d[o+(u>>>3)|0]|0;m=c[l>>2]|0;i=((u|0)<(m|0))+u|0;c[s>>2]=i;do{if((p&128>>>((u&7)>>>0)|0)==0){r=d[o+(i>>>3)|0]|0;n=((i|0)<(m|0))+i|0;c[s>>2]=n;if((r&128>>>((i&7)>>>0)|0)!=0){t=20;break}r=d[o+(n>>>3)|0]|0;c[s>>2]=((n|0)<(m|0))+n;if((r&128>>>((n&7)>>>0)|0)==0){t=22}else{v=1}}else{t=20}}while(0);if((t|0)==20){t=0;GBa(g)|0;t=22}if((t|0)==22){t=0;v=(GBa(g)|0)+1|0}OBa(c[f>>2]|0,v,h);if(!a){OBa(c[f>>2]|0,v,h)}if((j|0)>=(e|0)){break}j=j+1|0}return}}function KBa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;f=i;i=i+8|0;g=f|0;h=e+136|0;j=c[h>>2]|0;k=j+9272|0;l=VAb(13168)|0;c[g>>2]=l;if((l|0)==0){m=-12;i=f;return m|0}n=c[l+4>>2]|0;l=n;o=e+4|0;yDb(c[o>>2]|0,48,1895384,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=j+9280|0;r=c[q>>2]|0;s=j+9288|0;j=c[s>>2]|0;t=k|0;u=c[t>>2]|0;v=u+(r>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(r&7)>>>28;v=r+4|0;c[q>>2]=j>>>0>v>>>0?v:j;c[n>>2]=w;a:do{if((c[e+188+(w<<2)>>2]|0)==0){yDb(c[o>>2]|0,16,2352608,(p=i,i=i+8|0,c[p>>2]=w,p)|0);i=p;x=-1094995529}else{j=c[q>>2]|0;v=c[s>>2]|0;r=u+(j>>>3)|0;y=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(j&7)>>>29;r=j+3|0;c[q>>2]=v>>>0>r>>>0?r:v;v=y+1|0;y=n+72|0;c[y>>2]=v;if(v>>>0>7>>>0){yDb(c[o>>2]|0,16,2332384,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;x=-1094995529;break}v=c[s>>2]|0;r=(c[q>>2]|0)+1|0;c[q>>2]=v>>>0>r>>>0?r:v;IBa(e,n+300|0,c[y>>2]|0);v=GBa(k)|0;if(v>>>0>31>>>0){yDb(c[o>>2]|0,16,2308056,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;x=-1094995529;break}r=GBa(k)|0;j=n+4|0;c[j>>2]=r;if((r|0)!=1){EDb(c[o>>2]|0,2289528,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;x=-1163346256;break}r=n+13096|0;c[r>>2]=GBa(k)|0;z=GBa(k)|0;A=n+13100|0;c[A>>2]=z;B=hDb(c[r>>2]|0,z,0,c[o>>2]|0)|0;if((B|0)<0){x=B;break}z=c[q>>2]|0;C=d[(c[t>>2]|0)+(z>>>3)|0]|0;c[q>>2]=((z|0)<(c[s>>2]|0))+z;if((C&128>>>((z&7)>>>0)|0)!=0){z=n+36|0;C=z;c[C>>2]=(GBa(k)|0)<<1;D=n+40|0;c[D>>2]=(GBa(k)|0)<<1;E=n+44|0;c[E>>2]=(GBa(k)|0)<<1;F=(GBa(k)|0)<<1;c[n+48>>2]=F;G=c[o>>2]|0;if((c[G+92>>2]&65536|0)!=0){H=c[D>>2]|0;D=c[E>>2]|0;yDb(G,48,2273488,(p=i,i=i+32|0,c[p>>2]=c[C>>2],c[p+8>>2]=H,c[p+16>>2]=D,c[p+24>>2]=F,p)|0);i=p;TGb(z|0,0,16)|0}F=n+20|0;c[F>>2]=c[z>>2];c[F+4>>2]=c[z+4>>2];c[F+8>>2]=c[z+8>>2];c[F+12>>2]=c[z+12>>2]}z=n+52|0;c[z>>2]=(GBa(k)|0)+8;F=GBa(k)|0;D=F+8|0;H=c[z>>2]|0;if((D|0)!=(H|0)){yDb(c[o>>2]|0,16,2257872,(p=i,i=i+16|0,c[p>>2]=H,c[p+8>>2]=D,p)|0);i=p;x=-1094995529;break}if((c[j>>2]|0)!=1){yDb(c[o>>2]|0,16,2231128,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;m=-1163346256;i=f;return m|0}if((F|0)==1){c[n+60>>2]=70;I=70}else if((F|0)==0){c[n+60>>2]=0;I=0}else if((F|0)==2){c[n+60>>2]=72;I=72}else{yDb(c[o>>2]|0,16,2243624,(p=i,i=i+8|0,c[p>>2]=D,p)|0);i=p;x=-1163346256;break}D=n+60|0;F=bFb(I)|0;if((F|0)==0){x=-22;break}c[n+13152>>2]=0;c[n+13140>>2]=0;j=d[F+5|0]|0;c[n+13144>>2]=j;c[n+13148>>2]=j;j=d[F+6|0]|0;c[n+13156>>2]=j;c[n+13160>>2]=j;j=n+56|0;c[j>>2]=(c[z>>2]|0)>8;F=GBa(k)|0;H=F+4|0;C=n+64|0;c[C>>2]=H;if(H>>>0>16>>>0){yDb(c[o>>2]|0,16,2219032,(p=i,i=i+8|0,c[p>>2]=F,p)|0);i=p;x=-1094995529;break}F=c[q>>2]|0;H=d[(c[t>>2]|0)+(F>>>3)|0]|0;c[q>>2]=((F|0)<(c[s>>2]|0))+F;G=(H&128>>>((F&7)>>>0)|0)!=0;F=c[y>>2]|0;if(G){if((F|0)>0){J=0;K=30}}else{J=F-1|0;K=30}do{if((K|0)==30){F=n+76|0;H=J;do{E=F+(H*12|0)|0;c[E>>2]=(GBa(k)|0)+1;L=F+(H*12|0)+4|0;c[L>>2]=GBa(k)|0;c[F+(H*12|0)+8>>2]=(GBa(k)|0)-1;M=c[E>>2]|0;if((M|0)>16){K=32;break}N=c[L>>2]|0;if((N|0)>(M-1|0)){yDb(c[o>>2]|0,16,2200976,(p=i,i=i+8|0,c[p>>2]=N,p)|0);i=p;N=c[L>>2]|0;if((N|0)>15){x=-1094995529;break a}c[E>>2]=N+1}H=H+1|0;}while((H|0)<(c[y>>2]|0));if((K|0)==32){yDb(c[o>>2]|0,16,2209672,(p=i,i=i+8|0,c[p>>2]=M-1,p)|0);i=p;x=-1094995529;break a}if(!((J|0)>0&(G^1))){break}H=n+76|0;F=H+(J*12|0)|0;N=H+(J*12|0)+4|0;E=H+(J*12|0)+8|0;L=0;do{c[H+(L*12|0)>>2]=c[F>>2];c[H+(L*12|0)+4>>2]=c[N>>2];c[H+(L*12|0)+8>>2]=c[E>>2];L=L+1|0;}while((L|0)<(J|0))}}while(0);G=n+13064|0;c[G>>2]=(GBa(k)|0)+3;L=n+13068|0;c[L>>2]=GBa(k)|0;E=n+13072|0;c[E>>2]=(GBa(k)|0)+2;H=GBa(k)|0;N=c[E>>2]|0;F=n+13076|0;c[F>>2]=N+H;if(!(N>>>0<(c[G>>2]|0)>>>0)){yDb(c[o>>2]|0,16,2192472,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;x=-1094995529;break}N=n+13088|0;c[N>>2]=GBa(k)|0;H=n+13092|0;c[H>>2]=GBa(k)|0;O=c[q>>2]|0;P=(d[(c[t>>2]|0)+(O>>>3)|0]|0)<<(O&7)>>>7;c[q>>2]=((O|0)<(c[s>>2]|0))+O;O=P&1;a[n+634|0]=O;do{if(O<<24>>24==0){Q=B}else{P=n+635|0;TGb(P|0,16,16)|0;TGb(n+699|0,16,16)|0;TGb(n+763|0,16,16)|0;TGb(n+827|0,16,16)|0;TGb(n+891|0,16,16)|0;TGb(n+955|0,16,16)|0;TGb(n+2171|0,16,12)|0;UGb(n+1019|0,1401872,64)|0;UGb(n+1083|0,1401872,64)|0;UGb(n+1147|0,1401872,64)|0;UGb(n+1211|0,1401936,64)|0;UGb(n+1275|0,1401936,64)|0;UGb(n+1339|0,1401936,64)|0;UGb(n+1403|0,1401872,64)|0;UGb(n+1467|0,1401872,64)|0;UGb(n+1531|0,1401872,64)|0;UGb(n+1595|0,1401936,64)|0;UGb(n+1659|0,1401936,64)|0;UGb(n+1723|0,1401936,64)|0;UGb(n+1787|0,1401872,64)|0;UGb(n+1851|0,1401936,64)|0;R=c[q>>2]|0;S=d[(c[t>>2]|0)+(R>>>3)|0]|0;c[q>>2]=((R|0)<(c[s>>2]|0))+R;if((S&128>>>((R&7)>>>0)|0)==0){Q=B;break}R=LBa(e,P)|0;if((R|0)<0){x=R;break a}else{Q=R}}}while(0);B=c[q>>2]|0;O=(d[(c[t>>2]|0)+(B>>>3)|0]|0)<<(B&7)>>>7;c[q>>2]=((B|0)<(c[s>>2]|0))+B;a[n+12940|0]=O&1;O=c[q>>2]|0;B=(d[(c[t>>2]|0)+(O>>>3)|0]|0)<<(O&7)>>>7;c[q>>2]=((O|0)<(c[s>>2]|0))+O;a[n+12941|0]=B&1;B=c[q>>2]|0;O=c[t>>2]|0;R=(d[O+(B>>>3)|0]|0)<<(B&7)>>>7;c[q>>2]=((B|0)<(c[s>>2]|0))+B;B=R&1;c[n+68>>2]=B;do{if((B|0)!=0){R=c[q>>2]|0;P=c[s>>2]|0;S=O+(R>>>3)|0;T=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(R&7)>>>28;S=R+4|0;c[q>>2]=P>>>0>S>>>0?S:P;P=n+13044|0;a[P]=T+1;T=c[q>>2]|0;S=c[s>>2]|0;R=(c[t>>2]|0)+(T>>>3)|0;U=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(T&7)>>>28;R=T+4|0;c[q>>2]=S>>>0>R>>>0?R:S;a[n+13045|0]=U+1;U=(GBa(k)|0)+3|0;c[n+13048>>2]=U;c[n+13052>>2]=U+(GBa(k)|0);U=d[P]|0;P=c[z>>2]|0;if((U|0)>(P|0)){yDb(c[o>>2]|0,16,2176152,(p=i,i=i+16|0,c[p>>2]=U,c[p+8>>2]=P,p)|0);i=p;x=-1094995529;break a}else{P=c[q>>2]|0;U=(d[(c[t>>2]|0)+(P>>>3)|0]|0)<<(P&7)>>>7;c[q>>2]=((P|0)<(c[s>>2]|0))+P;a[n+13056|0]=U&1;break}}}while(0);O=GBa(k)|0;B=n+2184|0;c[B>>2]=O;if(O>>>0>64>>>0){yDb(c[o>>2]|0,16,2165592,(p=i,i=i+8|0,c[p>>2]=O,p)|0);i=p;x=-1094995529;break}U=n+2188|0;P=Q;S=0;R=O;while(1){if(!(S>>>0<R>>>0)){break}O=FBa(e,U+(S*168|0)|0,l,0)|0;if((O|0)<0){x=O;break a}P=O;S=S+1|0;R=c[B>>2]|0}B=c[q>>2]|0;R=(d[(c[t>>2]|0)+(B>>>3)|0]|0)<<(B&7)>>>7;c[q>>2]=((B|0)<(c[s>>2]|0))+B;B=R&1;a[n+12942|0]=B;do{if(!(B<<24>>24==0)){R=GBa(k)|0;S=n+13040|0;a[S]=R;if((R&255|0)==0){break}R=n+12944|0;U=0;do{O=c[C>>2]|0;T=c[q>>2]|0;V=c[s>>2]|0;W=c[t>>2]|0;X=W+(T>>>3)|0;Y=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(T&7)>>>((32-O|0)>>>0);X=T+O|0;O=V>>>0>X>>>0?X:V;c[q>>2]=O;b[R+(U<<1)>>1]=Y;Y=(d[W+(O>>>3)|0]|0)<<(O&7)>>>7;c[q>>2]=((O|0)<(V|0))+O;a[n+(U+13008)|0]=Y&1;U=U+1|0;}while((U|0)<(d[S]|0|0))}}while(0);C=c[q>>2]|0;B=(d[(c[t>>2]|0)+(C>>>3)|0]|0)<<(C&7)>>>7;c[q>>2]=((C|0)<(c[s>>2]|0))+C;a[n+13060|0]=B&1;B=c[q>>2]|0;C=(d[(c[t>>2]|0)+(B>>>3)|0]|0)<<(B&7)>>>7;c[q>>2]=((B|0)<(c[s>>2]|0))+B;a[n+13061|0]=C&1;C=n+160|0;B=C;c[B>>2]=0;S=n+164|0;c[S>>2]=1;U=c[q>>2]|0;R=d[(c[t>>2]|0)+(U>>>3)|0]|0;c[q>>2]=((U|0)<(c[s>>2]|0))+U;do{if((R&128>>>((U&7)>>>0)|0)!=0){Y=c[h>>2]|0;O=Y+9272|0;yDb(c[o>>2]|0,48,2032880,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;V=Y+9280|0;W=c[V>>2]|0;X=O|0;T=c[X>>2]|0;Z=d[T+(W>>>3)|0]|0;_=Y+9288|0;Y=c[_>>2]|0;$=((W|0)<(Y|0))+W|0;c[V>>2]=$;do{if((Z&128>>>((W&7)>>>0)|0)!=0){aa=T+($>>>3)|0;ca=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<($&7);aa=ca>>>24;da=$+8|0;ea=Y>>>0>da>>>0?da:Y;c[V>>2]=ea;if(ca>>>0<285212672>>>0){ca=91784+(aa<<3)|0;da=C;fa=c[ca+4>>2]|0;c[da>>2]=c[ca>>2];c[da+4>>2]=fa;break}if((aa|0)==255){fa=T+(ea>>>3)|0;da=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ea&7)>>>16;fa=ea+16|0;c[V>>2]=Y>>>0>fa>>>0?fa:Y;c[B>>2]=da;da=c[V>>2]|0;fa=c[_>>2]|0;ea=T+(da>>>3)|0;ca=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(da&7)>>>16;ea=da+16|0;c[V>>2]=fa>>>0>ea>>>0?ea:fa;c[S>>2]=ca;break}else{yDb(c[o>>2]|0,24,2028664,(p=i,i=i+8|0,c[p>>2]=aa,p)|0);i=p;break}}}while(0);T=c[V>>2]|0;Y=c[X>>2]|0;$=(d[Y+(T>>>3)|0]|0)<<(T&7)>>>7;c[V>>2]=((T|0)<(c[_>>2]|0))+T;T=$&1;c[n+168>>2]=T;if((T|0)!=0){T=c[V>>2]|0;$=(d[Y+(T>>>3)|0]|0)<<(T&7)>>>7;c[V>>2]=((T|0)<(c[_>>2]|0))+T;c[n+172>>2]=$&1}$=c[V>>2]|0;T=(d[Y+($>>>3)|0]|0)<<($&7)>>>7;c[V>>2]=(($|0)<(c[_>>2]|0))+$;$=T&1;c[n+176>>2]=$;do{if(($|0)!=0){T=c[V>>2]|0;W=c[_>>2]|0;Z=Y+(T>>>3)|0;aa=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(T&7)>>>29;Z=T+3|0;c[V>>2]=W>>>0>Z>>>0?Z:W;c[n+180>>2]=aa;aa=c[V>>2]|0;W=(d[Y+(aa>>>3)|0]|0)<<(aa&7)>>>7;c[V>>2]=((aa|0)<(c[_>>2]|0))+aa;aa=n+184|0;c[aa>>2]=W&1;W=c[V>>2]|0;Z=(d[Y+(W>>>3)|0]|0)<<(W&7)>>>7;c[V>>2]=((W|0)<(c[_>>2]|0))+W;W=Z&1;c[n+188>>2]=W;do{if((c[aa>>2]|0)!=0){if((c[D>>2]|0)!=0){break}c[D>>2]=12}}while(0);if((W|0)==0){break}aa=c[V>>2]|0;Z=c[_>>2]|0;T=Y+(aa>>>3)|0;ca=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(aa&7)>>>24;T=aa+8|0;c[V>>2]=Z>>>0>T>>>0?T:Z;Z=n+192|0;a[Z]=ca;ca=c[V>>2]|0;T=c[_>>2]|0;aa=(c[X>>2]|0)+(ca>>>3)|0;fa=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ca&7)>>>24;aa=ca+8|0;c[V>>2]=T>>>0>aa>>>0?aa:T;T=n+193|0;a[T]=fa;fa=c[V>>2]|0;aa=c[_>>2]|0;ca=(c[X>>2]|0)+(fa>>>3)|0;ea=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(fa&7)>>>24;ca=fa+8|0;c[V>>2]=aa>>>0>ca>>>0?ca:aa;aa=ea&255;ea=n+194|0;a[ea]=aa;if((d[Z]|0)>>>0>9>>>0){a[Z]=2}if((d[T]|0)>>>0>15>>>0){a[T]=2}if(!((aa&255)>>>0>10>>>0)){break}a[ea]=2}}while(0);Y=c[V>>2]|0;$=c[X>>2]|0;ea=(d[$+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[V>>2]=((Y|0)<(c[_>>2]|0))+Y;Y=ea&1;c[n+196>>2]=Y;if((Y|0)==0){ga=$}else{c[n+200>>2]=GBa(O)|0;c[n+204>>2]=GBa(O)|0;ga=c[X>>2]|0}$=c[V>>2]|0;Y=(d[ga+($>>>3)|0]|0)<<($&7)>>>7;c[V>>2]=(($|0)<(c[_>>2]|0))+$;c[n+208>>2]=Y&1;Y=c[V>>2]|0;$=(d[ga+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[V>>2]=((Y|0)<(c[_>>2]|0))+Y;c[n+212>>2]=$&1;$=c[V>>2]|0;Y=(d[ga+($>>>3)|0]|0)<<($&7)>>>7;c[V>>2]=(($|0)<(c[_>>2]|0))+$;c[n+216>>2]=Y&1;Y=c[V>>2]|0;$=(d[ga+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[V>>2]=((Y|0)<(c[_>>2]|0))+Y;Y=$&1;c[n+220>>2]=Y;do{if((Y|0)!=0){$=n+224|0;ea=$;c[ea>>2]=(GBa(O)|0)<<1;aa=n+228|0;c[aa>>2]=(GBa(O)|0)<<1;T=n+232|0;c[T>>2]=(GBa(O)|0)<<1;Z=(GBa(O)|0)<<1;c[n+236>>2]=Z;if((c[e+7480>>2]|0)==0){break}ca=c[o>>2]|0;if((c[ca+92>>2]&65536|0)==0){break}fa=c[aa>>2]|0;aa=c[T>>2]|0;yDb(ca,48,2025e3,(p=i,i=i+32|0,c[p>>2]=c[ea>>2],c[p+8>>2]=fa,c[p+16>>2]=aa,c[p+24>>2]=Z,p)|0);i=p;TGb($|0,0,16)|0}}while(0);Y=c[V>>2]|0;$=c[X>>2]|0;Z=(d[$+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[V>>2]=((Y|0)<(c[_>>2]|0))+Y;Y=Z&1;c[n+240>>2]=Y;do{if((Y|0)==0){ha=$}else{Z=c[V>>2]|0;aa=c[_>>2]|0;fa=$+(Z>>>3)|0;ea=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Z&7)&-65536;fa=Z+16|0;Z=aa>>>0>fa>>>0?fa:aa;c[V>>2]=Z;fa=$+(Z>>>3)|0;ca=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Z&7)>>>16;fa=Z+16|0;c[V>>2]=aa>>>0>fa>>>0?fa:aa;c[n+244>>2]=ca|ea;ea=c[V>>2]|0;ca=c[_>>2]|0;aa=$+(ea>>>3)|0;fa=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ea&7)&-65536;aa=ea+16|0;ea=ca>>>0>aa>>>0?aa:ca;c[V>>2]=ea;aa=$+(ea>>>3)|0;Z=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ea&7)>>>16;aa=ea+16|0;c[V>>2]=ca>>>0>aa>>>0?aa:ca;c[n+248>>2]=Z|fa;fa=c[V>>2]|0;Z=(d[$+(fa>>>3)|0]|0)<<(fa&7)>>>7;c[V>>2]=((fa|0)<(c[_>>2]|0))+fa;fa=Z&1;c[n+252>>2]=fa;if((fa|0)==0){ia=$}else{c[n+256>>2]=GBa(O)|0;ia=c[X>>2]|0}fa=c[V>>2]|0;Z=(d[ia+(fa>>>3)|0]|0)<<(fa&7)>>>7;c[V>>2]=((fa|0)<(c[_>>2]|0))+fa;fa=Z&1;c[n+260>>2]=fa;if((fa|0)==0){ha=ia;break}JBa(e,1,c[y>>2]|0);ha=c[X>>2]|0}}while(0);X=c[V>>2]|0;$=(d[ha+(X>>>3)|0]|0)<<(X&7)>>>7;c[V>>2]=((X|0)<(c[_>>2]|0))+X;X=$&1;c[n+264>>2]=X;if((X|0)==0){break}X=c[V>>2]|0;$=(d[ha+(X>>>3)|0]|0)<<(X&7)>>>7;c[V>>2]=((X|0)<(c[_>>2]|0))+X;c[n+268>>2]=$&1;$=c[V>>2]|0;X=(d[ha+($>>>3)|0]|0)<<($&7)>>>7;c[V>>2]=(($|0)<(c[_>>2]|0))+$;c[n+272>>2]=X&1;X=c[V>>2]|0;$=(d[ha+(X>>>3)|0]|0)<<(X&7)>>>7;c[V>>2]=((X|0)<(c[_>>2]|0))+X;c[n+276>>2]=$&1;c[n+280>>2]=GBa(O)|0;c[n+284>>2]=GBa(O)|0;c[n+288>>2]=GBa(O)|0;c[n+292>>2]=GBa(O)|0;c[n+296>>2]=GBa(O)|0}}while(0);y=c[s>>2]|0;S=(c[q>>2]|0)+1|0;c[q>>2]=y>>>0>S>>>0?S:y;if((c[e+7480>>2]|0)==0){ja=c[n+20>>2]|0}else{y=n+20|0;S=(c[y>>2]|0)+(c[n+224>>2]|0)|0;c[y>>2]=S;y=n+24|0;c[y>>2]=(c[y>>2]|0)+(c[n+228>>2]|0);y=n+28|0;c[y>>2]=(c[y>>2]|0)+(c[n+232>>2]|0);y=n+32|0;c[y>>2]=(c[y>>2]|0)+(c[n+236>>2]|0);ja=S}S=n+20|0;y=31>>>((c[j>>2]|0)>>>0);do{if((y&ja|0)==0){ka=ja}else{B=c[o>>2]|0;if((c[B+88>>2]&1|0)!=0){ka=ja;break}C=ja&~y;c[S>>2]=C;yDb(B,24,2158952,(p=i,i=i+8|0,c[p>>2]=C,p)|0);i=p;ka=c[S>>2]|0}}while(0);S=c[r>>2]|0;y=S-ka-(c[n+24>>2]|0)|0;j=n+12|0;c[j>>2]=y;C=c[A>>2]|0;B=C-(c[n+28>>2]|0)-(c[n+32>>2]|0)|0;U=n+16|0;c[U>>2]=B;if((y|0)<1|(B|0)<1){yDb(c[o>>2]|0,24,2151896,(p=i,i=i+16|0,c[p>>2]=y,c[p+8>>2]=B,p)|0);i=p;R=c[o>>2]|0;if((c[R+696>>2]&8|0)!=0){x=-1094995529;break}yDb(R,24,2144872,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;TGb(n+36|0,0,16)|0;R=c[r>>2]|0;c[j>>2]=R;j=c[A>>2]|0;c[U>>2]=j;la=R;ma=j;na=R;oa=j}else{la=S;ma=C;na=y;oa=B}B=c[G>>2]|0;y=(c[L>>2]|0)+B|0;c[n+13080>>2]=y;C=B-1|0;c[n+13084>>2]=C;S=1<<y;j=la-1+S>>y;c[n+13104>>2]=j;R=ma-1+S>>y;c[n+13108>>2]=R;c[n+13112>>2]=ba(R,j)|0;c[n+13116>>2]=la>>B;c[n+13120>>2]=ma>>B;j=c[E>>2]|0;c[n+13124>>2]=la>>j;c[n+13128>>2]=ma>>j;c[n+13132>>2]=la>>C;c[n+13136>>2]=ma>>C;c[n+13164>>2]=((c[z>>2]|0)*6|0)-48;C=(1<<B)-1|0;do{if((C&la|0)==0){if((ma&C|0)!=0){break}if(y>>>0>6>>>0){yDb(c[o>>2]|0,16,2132976,(p=i,i=i+8|0,c[p>>2]=y,p)|0);i=p;x=P;break a}B=c[N>>2]|0;R=y-j|0;if(B>>>0>R>>>0){yDb(c[o>>2]|0,16,2126536,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;x=P;break a}B=c[H>>2]|0;if(B>>>0>R>>>0){yDb(c[o>>2]|0,16,2120720,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;x=P;break a}B=c[F>>2]|0;R=c[o>>2]|0;if(B>>>0>(y>>>0>5>>>0?5:y)>>>0){yDb(R,16,2114552,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;x=P;break a}if((c[R+688>>2]&4|0)!=0){B=ZEb(c[D>>2]|0)|0;yDb(R,48,2100352,(p=i,i=i+48|0,c[p>>2]=v,c[p+8>>2]=la,c[p+16>>2]=ma,c[p+24>>2]=na,c[p+32>>2]=oa,c[p+40>>2]=B,p)|0);i=p}B=e+252+(v<<2)|0;R=c[B>>2]|0;do{if((R|0)==0){pa=0}else{S=c[g>>2]|0;if((PGb(c[R+4>>2]|0,c[S+4>>2]|0,c[S+8>>2]|0)|0)!=0){pa=0;break}XAb(g);m=0;i=f;return m|0}}while(0);do{R=e+380+(pa<<2)|0;O=c[R>>2]|0;do{if((O|0)!=0){if((c[c[O+4>>2]>>2]|0)!=(v|0)){break}XAb(R)}}while(0);pa=pa+1|0;}while(pa>>>0<256>>>0);XAb(B);c[B>>2]=c[g>>2];m=0;i=f;return m|0}}while(0);yDb(c[o>>2]|0,16,2139240,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;x=P}}while(0);XAb(g);m=x;i=f;return m|0}function LBa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;f=i;g=c[b+136>>2]|0;h=g+9272|0;j=g+9280|0;k=h|0;l=g+9288|0;g=0;a:while(1){m=(g|0)==3?2:6;n=(g|0)>0?64:16;o=(g|0)>1;p=g-2|0;q=1<<(g<<1)+4;r=(q|0)<64?q:64;q=(r|0)>0;s=(g|0)==0;t=0;do{u=c[j>>2]|0;v=c[k>>2]|0;w=d[v+(u>>>3)|0]|0;x=c[l>>2]|0;y=((u|0)<(x|0))+u|0;c[j>>2]=y;do{if((w&128>>>((u&7)>>>0)|0)==0){z=GBa(h)|0;if((z|0)==0){break}if(t>>>0<z>>>0){break a}A=t-z|0;UGb(e+(g*384|0)+(t<<6)|0,e+(g*384|0)+(A<<6)|0,n)|0;if(!o){break}a[e+1536+(p*6|0)+t|0]=a[e+1536+(p*6|0)+A|0]|0}else{if(o){A=v+(y>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7);if(B>>>0>134217727>>>0){A=B>>>23;C=(d[1213744+A|0]|0)+y|0;c[j>>2]=x>>>0>C>>>0?C:x;D=a[1139096+A|0]|0}else{A=B>>>0>65535>>>0;C=A?B>>>16:B;B=A?16:0;if((C&65280|0)==0){E=B;F=C}else{E=B|8;F=C>>>8}C=(d[1191992+F|0]|0)+E|0;B=31-C+y|0;A=x>>>0>B>>>0?B:x;B=v+(A>>>3)|0;G=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>(C>>>0);B=A+(32-C)|0;c[j>>2]=x>>>0>B>>>0?B:x;B=G>>>1;D=(G&1|0)==0?B:-B|0}B=D+8|0;a[e+1536+(p*6|0)+t|0]=B;H=B}else{H=8}if(q){I=0;J=H}else{break}do{if(s){K=(d[1207160+I|0]<<2)+(d[1207176+I|0]|0)|0}else{K=(d[1207032+I|0]<<3)+(d[1207096+I|0]|0)|0}B=c[j>>2]|0;G=c[l>>2]|0;C=c[k>>2]|0;A=C+(B>>>3)|0;L=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(B&7);if(L>>>0>134217727>>>0){A=L>>>23;M=(d[1213744+A|0]|0)+B|0;c[j>>2]=G>>>0>M>>>0?M:G;N=a[1139096+A|0]|0}else{A=L>>>0>65535>>>0;M=A?L>>>16:L;L=A?16:0;if((M&65280|0)==0){O=L;P=M}else{O=L|8;P=M>>>8}M=(d[1191992+P|0]|0)+O|0;L=31-M+B|0;B=G>>>0>L>>>0?L:G;L=C+(B>>>3)|0;C=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(B&7)>>>(M>>>0);L=B+(32-M)|0;c[j>>2]=G>>>0>L>>>0?L:G;G=C>>>1;N=(C&1|0)==0?G:-G|0}J=(J+256+N|0)%256|0;a[e+(g*384|0)+(t<<6)+K|0]=J;I=I+1|0;}while((I|0)<(r|0))}}while(0);t=t+1|0;}while((t|0)<(m|0));m=g+1|0;if((m|0)<4){g=m}else{Q=0;R=28;break}}if((R|0)==28){i=f;return Q|0}yDb(c[b+4>>2]|0,16,2021616,(b=i,i=i+8|0,c[b>>2]=z,b)|0);i=b;Q=-1094995529;i=f;return Q|0}function MBa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=c[b+136>>2]|0;j=h+9272|0;k=cEb(1676)|0;c[g>>2]=k;if((k|0)==0){l=-12;i=e;return l|0}m=SAb(k,1676,128,0,0)|0;c[f>>2]=m;if((m|0)==0){$Db(g);l=-12;i=e;return l|0}m=b+4|0;yDb(c[m>>2]|0,48,2093736,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;a[(c[g>>2]|0)+53|0]=1;n=c[g>>2]|0;c[n+44>>2]=1;c[n+48>>2]=1;a[n+52|0]=1;a[(c[g>>2]|0)+57|0]=0;n=c[g>>2]|0;c[n+60>>2]=0;c[n+64>>2]=0;n=GBa(j)|0;a:do{if(n>>>0>255>>>0){yDb(c[m>>2]|0,16,2088520,(k=i,i=i+8|0,c[k>>2]=n,k)|0);i=k;o=-1094995529}else{p=GBa(j)|0;q=c[g>>2]|0;c[q>>2]=p;if(p>>>0>31>>>0){yDb(c[m>>2]|0,16,2308056,(k=i,i=i+8|0,c[k>>2]=p,k)|0);i=k;o=-1094995529;break}r=c[b+252+(p<<2)>>2]|0;if((r|0)==0){yDb(c[m>>2]|0,16,2083800,(k=i,i=i+8|0,c[k>>2]=p,k)|0);i=k;o=-1094995529;break}p=c[r+4>>2]|0;r=h+9280|0;s=c[r>>2]|0;t=j|0;u=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;v=h+9288|0;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[q+41|0]=u&1;u=c[r>>2]|0;q=d[(c[t>>2]|0)+(u>>>3)|0]<<(u&7)>>>7;c[r>>2]=((u|0)<(c[v>>2]|0))+u;a[(c[g>>2]|0)+39|0]=q&1;q=c[r>>2]|0;u=c[v>>2]|0;s=c[t>>2]|0;w=s+(q>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(q&7)>>>29;w=q+3|0;c[r>>2]=u>>>0>w>>>0?w:u;u=c[g>>2]|0;c[u+1624>>2]=x;x=c[r>>2]|0;w=d[s+(x>>>3)|0]<<(x&7)>>>7;c[r>>2]=((x|0)<(c[v>>2]|0))+x;a[u+4|0]=w&1;w=c[r>>2]|0;u=d[(c[t>>2]|0)+(w>>>3)|0]<<(w&7)>>>7;c[r>>2]=((w|0)<(c[v>>2]|0))+w;a[(c[g>>2]|0)+5|0]=u&1;u=(GBa(j)|0)+1|0;c[(c[g>>2]|0)+8>>2]=u;u=(GBa(j)|0)+1|0;w=c[g>>2]|0;c[w+12>>2]=u;u=c[r>>2]|0;x=c[v>>2]|0;s=c[t>>2]|0;q=s+(u>>>3)|0;y=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(u&7);if(y>>>0>134217727>>>0){q=y>>>23;z=(d[1213744+q|0]|0)+u|0;c[r>>2]=x>>>0>z>>>0?z:x;A=a[1139096+q|0]|0}else{q=y>>>0>65535>>>0;z=q?y>>>16:y;y=q?16:0;if((z&65280|0)==0){B=y;C=z}else{B=y|8;C=z>>>8}z=(d[1191992+C|0]|0)+B|0;y=31-z+u|0;u=x>>>0>y>>>0?y:x;y=s+(u>>>3)|0;q=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(u&7)>>>(z>>>0);y=u+(32-z)|0;c[r>>2]=x>>>0>y>>>0?y:x;x=q>>>1;A=(q&1|0)==0?x:-x|0}c[w+16>>2]=A;x=c[r>>2]|0;q=d[s+(x>>>3)|0]<<(x&7)>>>7;c[r>>2]=((x|0)<(c[v>>2]|0))+x;a[w+20|0]=q&1;q=c[r>>2]|0;w=d[(c[t>>2]|0)+(q>>>3)|0]<<(q&7)>>>7;c[r>>2]=((q|0)<(c[v>>2]|0))+q;a[(c[g>>2]|0)+21|0]=w&1;w=c[r>>2]|0;q=d[(c[t>>2]|0)+(w>>>3)|0]<<(w&7)>>>7;c[r>>2]=((w|0)<(c[v>>2]|0))+w;a[(c[g>>2]|0)+22|0]=q&1;q=c[g>>2]|0;c[q+24>>2]=0;if((a[q+22|0]|0)==0){D=q}else{q=GBa(j)|0;w=c[g>>2]|0;c[w+24>>2]=q;D=w}w=c[r>>2]|0;q=c[v>>2]|0;x=c[t>>2]|0;s=x+(w>>>3)|0;y=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7);if(y>>>0>134217727>>>0){s=y>>>23;z=(d[1213744+s|0]|0)+w|0;c[r>>2]=q>>>0>z>>>0?z:q;E=a[1139096+s|0]|0}else{s=y>>>0>65535>>>0;z=s?y>>>16:y;y=s?16:0;if((z&65280|0)==0){G=y;H=z}else{G=y|8;H=z>>>8}z=(d[1191992+H|0]|0)+G|0;y=31-z+w|0;w=q>>>0>y>>>0?y:q;y=x+(w>>>3)|0;s=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>(z>>>0);y=w+(32-z)|0;c[r>>2]=q>>>0>y>>>0?y:q;q=s>>>1;E=(s&1|0)==0?q:-q|0}c[D+28>>2]=E;if((E+12|0)>>>0>24>>>0){yDb(c[m>>2]|0,16,2078288,(k=i,i=i+8|0,c[k>>2]=E,k)|0);i=k;o=-1094995529;break}q=c[r>>2]|0;s=c[v>>2]|0;y=x+(q>>>3)|0;z=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7);if(z>>>0>134217727>>>0){y=z>>>23;w=(d[1213744+y|0]|0)+q|0;c[r>>2]=s>>>0>w>>>0?w:s;I=a[1139096+y|0]|0}else{y=z>>>0>65535>>>0;w=y?z>>>16:z;z=y?16:0;if((w&65280|0)==0){J=z;K=w}else{J=z|8;K=w>>>8}w=(d[1191992+K|0]|0)+J|0;z=31-w+q|0;q=s>>>0>z>>>0?z:s;z=x+(q>>>3)|0;y=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(q&7)>>>(w>>>0);z=q+(32-w)|0;c[r>>2]=s>>>0>z>>>0?z:s;s=y>>>1;I=(y&1|0)==0?s:-s|0}c[D+32>>2]=I;if((I+12|0)>>>0>24>>>0){yDb(c[m>>2]|0,16,2073360,(k=i,i=i+8|0,c[k>>2]=I,k)|0);i=k;o=-1094995529;break}s=c[r>>2]|0;y=d[x+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[D+36|0]=y&1;y=c[r>>2]|0;s=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[(c[g>>2]|0)+37|0]=s&1;s=c[r>>2]|0;y=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[(c[g>>2]|0)+38|0]=y&1;y=c[r>>2]|0;s=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[(c[g>>2]|0)+40|0]=s&1;s=c[r>>2]|0;y=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[(c[g>>2]|0)+42|0]=y&1;y=c[r>>2]|0;s=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[(c[g>>2]|0)+43|0]=s&1;s=c[g>>2]|0;b:do{if((a[s+42|0]|0)==0){L=s}else{y=(GBa(j)|0)+1|0;c[(c[g>>2]|0)+44>>2]=y;y=GBa(j)|0;x=y+1|0;z=c[g>>2]|0;c[z+48>>2]=x;w=c[z+44>>2]|0;do{if((w|0)!=0){if((w|0)>=(c[p+13096>>2]|0)){break}do{if((x|0)!=0){if((x|0)>=(c[p+13100>>2]|0)){break}if(w>>>0>536870910>>>0){M=0;N=z}else{q=WDb(w<<2)|0;M=q;N=c[g>>2]|0}c[N+1632>>2]=M;q=c[g>>2]|0;u=c[q+48>>2]|0;if(u>>>0>536870910>>>0){O=0;P=q}else{q=WDb(u<<2)|0;O=q;P=c[g>>2]|0}c[P+1636>>2]=O;q=c[g>>2]|0;if((c[q+1632>>2]|0)==0){o=-12;break a}if((c[q+1636>>2]|0)==0){o=-12;break a}u=c[r>>2]|0;Q=d[(c[t>>2]|0)+(u>>>3)|0]<<(u&7)>>>7;c[r>>2]=((u|0)<(c[v>>2]|0))+u;a[q+52|0]=Q&1;Q=c[g>>2]|0;do{if((a[Q+52|0]|0)==0){q=(c[Q+44>>2]|0)-1|0;if((q|0)>0){u=0;R=0;S=0;while(1){T=(GBa(j)|0)+1|0;U=c[g>>2]|0;c[(c[U+1632>>2]|0)+(S<<2)>>2]=T;V=YGb(T,0,R,u)|0;T=F;W=S+1|0;X=(c[U+44>>2]|0)-1|0;if((W|0)<(X|0)){u=T;R=V;S=W}else{Y=T;Z=V;_=X;$=U;break}}}else{Y=0;Z=0;_=q;$=Q}S=c[p+13104>>2]|0;R=S;u=(S|0)<0|0?-1:0;if(!(Y>>>0<u>>>0|Y>>>0==u>>>0&Z>>>0<R>>>0)){yDb(c[m>>2]|0,16,2060368,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;o=-1094995529;break a}S=ZGb(R,u,Z,Y)|0;c[(c[$+1632>>2]|0)+(_<<2)>>2]=S;S=(c[$+48>>2]|0)-1|0;if((S|0)>0){u=0;R=0;U=0;while(1){X=(GBa(j)|0)+1|0;V=c[g>>2]|0;c[(c[V+1636>>2]|0)+(U<<2)>>2]=X;T=YGb(X,0,R,u)|0;X=F;W=U+1|0;aa=(c[V+48>>2]|0)-1|0;if((W|0)<(aa|0)){u=X;R=T;U=W}else{ca=X;da=T;ea=aa;fa=V;break}}}else{ca=0;da=0;ea=S;fa=$}U=c[p+13108>>2]|0;R=U;u=(U|0)<0|0?-1:0;if(ca>>>0<u>>>0|ca>>>0==u>>>0&da>>>0<R>>>0){U=ZGb(R,u,da,ca)|0;c[(c[fa+1636>>2]|0)+(ea<<2)>>2]=U;ga=fa;break}else{yDb(c[m>>2]|0,16,2055624,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;o=-1094995529;break a}}else{ga=Q}}while(0);Q=c[r>>2]|0;U=d[(c[t>>2]|0)+(Q>>>3)|0]<<(Q&7)>>>7;c[r>>2]=((Q|0)<(c[v>>2]|0))+Q;a[ga+53|0]=U&1;L=c[g>>2]|0;break b}}while(0);yDb(c[m>>2]|0,16,2064272,(k=i,i=i+8|0,c[k>>2]=y,k)|0);i=k;o=-1094995529;break a}}while(0);yDb(c[m>>2]|0,16,2068824,(k=i,i=i+8|0,c[k>>2]=w-1,k)|0);i=k;o=-1094995529;break a}}while(0);s=c[r>>2]|0;y=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[L+54|0]=y&1;y=c[r>>2]|0;s=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[(c[g>>2]|0)+55|0]=s&1;s=c[g>>2]|0;do{if((a[s+55|0]|0)==0){ha=s}else{y=c[r>>2]|0;z=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[s+56|0]=z&1;z=c[r>>2]|0;y=d[(c[t>>2]|0)+(z>>>3)|0]<<(z&7)>>>7;c[r>>2]=((z|0)<(c[v>>2]|0))+z;a[(c[g>>2]|0)+57|0]=y&1;y=c[g>>2]|0;if((a[y+57|0]|0)!=0){ha=y;break}z=c[r>>2]|0;x=c[v>>2]|0;U=c[t>>2]|0;Q=U+(z>>>3)|0;u=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(z&7);if(u>>>0>134217727>>>0){Q=u>>>23;R=(d[1213744+Q|0]|0)+z|0;c[r>>2]=x>>>0>R>>>0?R:x;ia=a[1139096+Q|0]|0}else{Q=u>>>0>65535>>>0;R=Q?u>>>16:u;u=Q?16:0;if((R&65280|0)==0){ja=u;ka=R}else{ja=u|8;ka=R>>>8}R=(d[1191992+ka|0]|0)+ja|0;u=31-R+z|0;z=x>>>0>u>>>0?u:x;u=U+(z>>>3)|0;Q=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(z&7)>>>(R>>>0);u=z+(32-R)|0;c[r>>2]=x>>>0>u>>>0?u:x;x=Q>>>1;ia=(Q&1|0)==0?x:-x|0}x=y+60|0;c[x>>2]=ia<<1;Q=c[r>>2]|0;u=c[v>>2]|0;R=U+(Q>>>3)|0;z=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Q&7);if(z>>>0>134217727>>>0){R=z>>>23;q=(d[1213744+R|0]|0)+Q|0;c[r>>2]=u>>>0>q>>>0?q:u;la=a[1139096+R|0]|0}else{R=z>>>0>65535>>>0;q=R?z>>>16:z;z=R?16:0;if((q&65280|0)==0){ma=z;na=q}else{ma=z|8;na=q>>>8}q=(d[1191992+na|0]|0)+ma|0;z=31-q+Q|0;Q=u>>>0>z>>>0?z:u;z=U+(Q>>>3)|0;U=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(Q&7)>>>(q>>>0);z=Q+(32-q)|0;c[r>>2]=u>>>0>z>>>0?z:u;u=U>>>1;la=(U&1|0)==0?u:-u|0}u=la<<1;c[y+64>>2]=u;U=c[x>>2]|0;if((U+13|0)>>>0>26>>>0){yDb(c[m>>2]|0,16,2044856,(k=i,i=i+8|0,c[k>>2]=(U|0)/2|0,k)|0);i=k;o=-1094995529;break a}if(!((u+13|0)>>>0>26>>>0)){ha=y;break}yDb(c[m>>2]|0,16,2039872,(k=i,i=i+8|0,c[k>>2]=(u|0)/2|0,k)|0);i=k;o=-1094995529;break a}}while(0);s=c[r>>2]|0;u=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[ha+68|0]=u&1;u=c[g>>2]|0;if((a[u+68|0]|0)==0){oa=u}else{TGb(u+69|0,16,16)|0;TGb(u+133|0,16,16)|0;TGb(u+197|0,16,16)|0;TGb(u+261|0,16,16)|0;TGb(u+325|0,16,16)|0;TGb(u+389|0,16,16)|0;TGb(u+1605|0,16,12)|0;UGb(u+453|0,1401872,64)|0;UGb(u+517|0,1401872,64)|0;UGb(u+581|0,1401872,64)|0;UGb(u+645|0,1401936,64)|0;UGb(u+709|0,1401936,64)|0;UGb(u+773|0,1401936,64)|0;UGb(u+837|0,1401872,64)|0;UGb(u+901|0,1401872,64)|0;UGb(u+965|0,1401872,64)|0;UGb(u+1029|0,1401936,64)|0;UGb(u+1093|0,1401936,64)|0;UGb(u+1157|0,1401936,64)|0;UGb(u+1221|0,1401872,64)|0;UGb(u+1285|0,1401936,64)|0;s=LBa(b,u+69|0)|0;if((s|0)<0){o=s;break}oa=c[g>>2]|0}s=c[r>>2]|0;u=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[oa+1617|0]=u&1;u=GBa(j)|0;s=u+2|0;y=c[g>>2]|0;c[y+1620>>2]=s;U=p+13080|0;if(s>>>0>(c[U>>2]|0)>>>0){yDb(c[m>>2]|0,16,2036512,(k=i,i=i+8|0,c[k>>2]=u,k)|0);i=k;o=-1094995529;break}u=c[r>>2]|0;s=d[(c[t>>2]|0)+(u>>>3)|0]<<(u&7)>>>7;c[r>>2]=((u|0)<(c[v>>2]|0))+u;a[y+1628|0]=s&1;s=c[v>>2]|0;y=(c[r>>2]|0)+1|0;c[r>>2]=s>>>0>y>>>0?y:s;s=c[g>>2]|0;y=(c[s+44>>2]|0)+1|0;if(y>>>0>536870910>>>0){pa=0;qa=s}else{s=WDb(y<<2)|0;pa=s;qa=c[g>>2]|0}c[qa+1640>>2]=pa;s=c[g>>2]|0;y=(c[s+48>>2]|0)+1|0;if(y>>>0>536870910>>>0){ra=0;sa=s}else{s=WDb(y<<2)|0;ra=s;sa=c[g>>2]|0}c[sa+1644>>2]=ra;s=p+13104|0;y=c[s>>2]|0;if(y>>>0>536870910>>>0){ta=0}else{ta=WDb(y<<2)|0}c[(c[g>>2]|0)+1648>>2]=ta;y=c[g>>2]|0;u=c[y+1640>>2]|0;if((u|0)==0){o=-12;break}if((c[y+1644>>2]|0)==0){o=-12;break}if((c[y+1648>>2]|0)==0){o=-12;break}if((a[y+52|0]|0)==0){ua=y;va=u}else{u=c[y+1632>>2]|0;if((u|0)==0){x=c[y+44>>2]|0;if(x>>>0>536870910>>>0){wa=0;xa=y}else{z=WDb(x<<2)|0;wa=z;xa=c[g>>2]|0}c[xa+1632>>2]=wa;z=c[g>>2]|0;x=c[z+48>>2]|0;if(x>>>0>536870910>>>0){ya=0;za=z}else{z=WDb(x<<2)|0;ya=z;za=c[g>>2]|0}c[za+1636>>2]=ya;z=c[g>>2]|0;x=c[z+1632>>2]|0;if((x|0)==0){o=-12;break}else{Aa=x;Ba=z}}else{Aa=u;Ba=y}y=c[Ba+1636>>2]|0;if((y|0)==0){o=-12;break}u=Ba+44|0;z=c[u>>2]|0;if((z|0)>0){x=0;q=z;while(1){z=x+1|0;Q=c[s>>2]|0;c[Aa+(x<<2)>>2]=((ba(Q,z)|0)/(q|0)|0)-((ba(Q,x)|0)/(q|0)|0);Q=c[u>>2]|0;if((z|0)<(Q|0)){x=z;q=Q}else{break}}}q=Ba+48|0;x=c[q>>2]|0;if((x|0)>0){u=p+13108|0;r=0;v=x;while(1){x=r+1|0;t=c[u>>2]|0;c[y+(r<<2)>>2]=((ba(t,x)|0)/(v|0)|0)-((ba(t,r)|0)/(v|0)|0);t=c[q>>2]|0;if((x|0)<(t|0)){r=x;v=t}else{break}}}ua=Ba;va=c[Ba+1640>>2]|0}c[va>>2]=0;v=ua+44|0;if((c[v>>2]|0)>0){r=c[ua+1632>>2]|0;q=0;y=0;do{y=(c[r+(q<<2)>>2]|0)+y|0;q=q+1|0;c[va+(q<<2)>>2]=y;}while((q|0)<(c[v>>2]|0))}v=c[ua+1644>>2]|0;c[v>>2]=0;q=ua+48|0;if((c[q>>2]|0)>0){y=c[ua+1636>>2]|0;r=0;u=0;do{u=(c[y+(r<<2)>>2]|0)+u|0;r=r+1|0;c[v+(r<<2)>>2]=u;}while((r|0)<(c[q>>2]|0))}q=c[s>>2]|0;if((q|0)>0){r=c[ua+1648>>2]|0;u=0;v=0;while(1){y=(v>>>0>(c[va+(u<<2)>>2]|0)>>>0)+u|0;c[r+(v<<2)>>2]=y;t=v+1|0;x=c[s>>2]|0;if((t|0)<(x|0)){u=y;v=t}else{Ca=x;break}}}else{Ca=q}v=ba(c[p+13108>>2]|0,Ca)|0;u=p+13116|0;r=p+13120|0;x=ba(c[r>>2]|0,c[u>>2]|0)|0;t=p+13124|0;y=p+13128|0;Q=ba(c[y>>2]|0,c[t>>2]|0)|0;if(v>>>0>536870910>>>0){c[ua+1652>>2]=0;c[(c[g>>2]|0)+1656>>2]=0;Da=0}else{z=v<<2;R=WDb(z)|0;c[(c[g>>2]|0)+1652>>2]=R;R=WDb(z)|0;c[(c[g>>2]|0)+1656>>2]=R;Da=WDb(z)|0}c[(c[g>>2]|0)+1660>>2]=Da;if(x>>>0>536870910>>>0){Ea=0}else{Ea=WDb(x<<2)|0}c[(c[g>>2]|0)+1668>>2]=Ea;if(Q>>>0>536870910>>>0){Fa=0}else{Fa=WDb(Q<<2)|0}c[(c[g>>2]|0)+1672>>2]=Fa;Q=c[g>>2]|0;x=c[Q+1652>>2]|0;if((x|0)==0){o=-12;break}z=c[Q+1656>>2]|0;if((z|0)==0){o=-12;break}R=c[Q+1660>>2]|0;if((R|0)==0){o=-12;break}if((c[Q+1668>>2]|0)==0){o=-12;break}if((c[Q+1672>>2]|0)==0){o=-12;break}if((v|0)>0){V=Q+44|0;aa=Q+48|0;T=c[Q+1644>>2]|0;X=c[Q+1632>>2]|0;W=c[Q+1640>>2]|0;Ga=Q+1636|0;Ha=0;while(1){Ia=c[s>>2]|0;Ja=(Ha|0)%(Ia|0)|0;Ka=(Ha|0)/(Ia|0)|0;La=c[V>>2]|0;Ma=0;while(1){if((Ma|0)>=(La|0)){Na=0;break}Oa=Ma+1|0;if(Ja>>>0<(c[W+(Oa<<2)>>2]|0)>>>0){Na=Ma;break}else{Ma=Oa}}Ma=c[aa>>2]|0;La=0;while(1){if((La|0)>=(Ma|0)){Pa=0;break}w=La+1|0;if(Ka>>>0<(c[T+(w<<2)>>2]|0)>>>0){Pa=La;break}else{La=w}}if((Na|0)>0){La=c[(c[Ga>>2]|0)+(Pa<<2)>>2]|0;Ma=0;w=0;while(1){Oa=(ba(c[X+(w<<2)>>2]|0,La)|0)+Ma|0;Qa=w+1|0;if((Qa|0)<(Na|0)){Ma=Oa;w=Qa}else{Ra=Oa;break}}}else{Ra=0}if((Pa|0)>0){w=c[Ga>>2]|0;Ma=Ra;La=0;while(1){Oa=(ba(c[w+(La<<2)>>2]|0,Ia)|0)+Ma|0;Qa=La+1|0;if((Qa|0)<(Pa|0)){Ma=Oa;La=Qa}else{Sa=Oa;break}}}else{Sa=Ra}La=ba(c[X+(Na<<2)>>2]|0,Ka-(c[T+(Pa<<2)>>2]|0)|0)|0;Ma=Sa+Ja+La-(c[W+(Na<<2)>>2]|0)|0;c[x+(Ha<<2)>>2]=Ma;c[z+(Ma<<2)>>2]=Ha;Ma=Ha+1|0;if((Ma|0)<(v|0)){Ha=Ma}else{Ta=aa;break}}}else{Ta=Q+48|0}aa=c[Ta>>2]|0;if((aa|0)>0){Ha=Q+44|0;v=Q+1644|0;z=Q+1640|0;W=0;T=0;X=c[Ha>>2]|0;Ga=aa;while(1){aa=T+1|0;if((X|0)>0){V=c[v>>2]|0;q=V+(aa<<2)|0;Ma=W;La=0;Ia=X;w=c[q>>2]|0;while(1){Oa=c[V+(T<<2)>>2]|0;Qa=La+1|0;if(Oa>>>0<w>>>0){Ua=c[z>>2]|0;Va=Ua+(Qa<<2)|0;Wa=Oa;Oa=w;Xa=c[Va>>2]|0;while(1){Ya=c[Ua+(La<<2)>>2]|0;if(Ya>>>0<Xa>>>0){Za=Ya;do{c[R+(c[x+((ba(c[s>>2]|0,Wa)|0)+Za<<2)>>2]<<2)>>2]=Ma;Za=Za+1|0;_a=c[Va>>2]|0;}while(Za>>>0<_a>>>0);$a=c[q>>2]|0;ab=_a}else{$a=Oa;ab=Xa}Za=Wa+1|0;if(Za>>>0<$a>>>0){Wa=Za;Oa=$a;Xa=ab}else{break}}bb=c[Ha>>2]|0;cb=$a}else{bb=Ia;cb=w}db=Ma+1|0;if((Qa|0)<(bb|0)){Ma=db;La=Qa;Ia=bb;w=cb}else{break}}eb=db;fb=bb;gb=c[Ta>>2]|0}else{eb=W;fb=X;gb=Ga}if((aa|0)<(gb|0)){W=eb;T=aa;X=fb;Ga=gb}else{break}}if(eb>>>0>536870910>>>0){hb=0;ib=Q}else{jb=eb;kb=151}}else{jb=0;kb=151}if((kb|0)==151){Ga=WDb(jb<<2)|0;hb=Ga;ib=c[g>>2]|0}c[ib+1664>>2]=hb;Ga=c[g>>2]|0;X=c[Ga+1664>>2]|0;if((X|0)==0){o=-12;break}T=Ga+48|0;W=c[T>>2]|0;if((W|0)>0){Ha=Ga+44|0;x=0;R=c[Ha>>2]|0;z=W;while(1){if((R|0)>0){W=c[Ga+1644>>2]|0;v=c[Ga+1640>>2]|0;w=0;Ia=R;do{La=ba(c[s>>2]|0,c[W+(x<<2)>>2]|0)|0;c[X+((ba(Ia,x)|0)+w<<2)>>2]=(c[v+(w<<2)>>2]|0)+La;w=w+1|0;Ia=c[Ha>>2]|0;}while((w|0)<(Ia|0));lb=Ia;mb=c[T>>2]|0}else{lb=R;mb=z}w=x+1|0;if((w|0)<(mb|0)){x=w;R=lb;z=mb}else{break}}}z=c[r>>2]|0;if((z|0)>0){R=p+13068|0;x=Ga+1652|0;T=Ga+1668|0;Ha=0;X=c[u>>2]|0;Q=z;while(1){if((X|0)>0){z=c[x>>2]|0;w=c[T>>2]|0;v=0;W=X;do{aa=c[R>>2]|0;La=c[z+((ba(c[s>>2]|0,Ha>>aa)|0)+(v>>aa)<<2)>>2]<<(aa<<1);if((aa|0)==0){nb=La}else{Ma=La;La=0;while(1){q=1<<La;if((q&Ha|0)==0){ob=0}else{ob=q<<1<<La}V=((q&v|0)==0?0:q<<La)+Ma+ob|0;q=La+1|0;if(q>>>0<aa>>>0){Ma=V;La=q}else{nb=V;break}}}c[w+((ba(W,Ha)|0)+v<<2)>>2]=nb;v=v+1|0;W=c[u>>2]|0;}while((v|0)<(W|0));pb=W;qb=c[r>>2]|0}else{pb=X;qb=Q}v=Ha+1|0;if((v|0)<(qb|0)){Ha=v;X=pb;Q=qb}else{break}}}Q=(c[U>>2]|0)-(c[p+13072>>2]|0)|0;X=c[y>>2]|0;if((X|0)>0){Ha=Ga+1652|0;r=Q<<1;u=(Q|0)>0;R=Ga+1672|0;T=0;x=c[t>>2]|0;v=X;while(1){if((x|0)>0){X=T>>Q;w=c[Ha>>2]|0;z=c[R>>2]|0;if(u){Ia=0;La=x;while(1){Ma=0;aa=c[w+((ba(c[s>>2]|0,X)|0)+(Ia>>Q)<<2)>>2]<<r;do{Qa=1<<Ma;if((Qa&T|0)==0){rb=0}else{rb=Qa<<1<<Ma}aa=((Qa&Ia|0)==0?0:Qa<<Ma)+aa+rb|0;Ma=Ma+1|0;}while((Ma|0)<(Q|0));c[z+((ba(La,T)|0)+Ia<<2)>>2]=aa;Ma=Ia+1|0;Qa=c[t>>2]|0;if((Ma|0)<(Qa|0)){Ia=Ma;La=Qa}else{sb=Qa;break}}}else{La=0;Ia=x;while(1){c[z+((ba(Ia,T)|0)+La<<2)>>2]=c[w+((ba(c[s>>2]|0,X)|0)+(La>>Q)<<2)>>2]<<r;W=La+1|0;Qa=c[t>>2]|0;if((W|0)<(Qa|0)){La=W;Ia=Qa}else{sb=Qa;break}}}tb=sb;ub=c[y>>2]|0}else{tb=x;ub=v}Ia=T+1|0;if((Ia|0)<(ub|0)){T=Ia;x=tb;v=ub}else{break}}}v=b+380+(n<<2)|0;XAb(v);c[v>>2]=c[f>>2];l=0;i=e;return l|0}}while(0);XAb(f);l=o;i=e;return l|0}function NBa(a,b){a=a|0;b=b|0;var d=0;a=i;i=i+8|0;d=a|0;c[d>>2]=b;$Db(b+1632|0);$Db(b+1636|0);$Db(b+1640|0);$Db(b+1644|0);$Db(b+1648|0);$Db(b+1652|0);$Db(b+1656|0);$Db(b+1664|0);$Db(b+1660|0);$Db(b+1668|0);$Db(b+1672|0);$Db(d);i=a;return}function OBa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+9272|0;if((b|0)==0){return}f=a+9280|0;g=a+9288|0;if((d|0)==0){d=0;do{GBa(e)|0;GBa(e)|0;a=c[g>>2]|0;h=(c[f>>2]|0)+1|0;c[f>>2]=a>>>0>h>>>0?h:a;d=d+1|0;}while(d>>>0<b>>>0);return}else{d=0;do{GBa(e)|0;GBa(e)|0;GBa(e)|0;GBa(e)|0;a=c[g>>2]|0;h=(c[f>>2]|0)+1|0;c[f>>2]=a>>>0>h>>>0?h:a;d=d+1|0;}while(d>>>0<b>>>0);return}}function PBa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;g=c[b+136>>2]|0;h=g+9280|0;j=c[h>>2]|0;k=g+9288|0;l=c[k>>2]|0;m=g+9272|0;g=(c[m>>2]|0)+(j>>>3)|0;n=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(j&7)>>>30;g=j+2|0;c[h>>2]=l>>>0>g>>>0?g:l;a[e|0]=n;n=c[h>>2]|0;l=(d[(c[m>>2]|0)+(n>>>3)|0]|0)<<(n&7)>>>7;c[h>>2]=((n|0)<(c[k>>2]|0))+n;a[e+1|0]=l&1;l=c[h>>2]|0;n=c[k>>2]|0;g=(c[m>>2]|0)+(l>>>3)|0;j=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(l&7)>>>27;g=l+5|0;c[h>>2]=n>>>0>g>>>0?g:n;a[e+2|0]=j;do{if((j|0)==1){yDb(c[b+4>>2]|0,48,2017848,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=0}else if((j|0)==2){yDb(c[b+4>>2]|0,48,2013720,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=0}else{n=c[b+4>>2]|0;if((j|0)==3){yDb(n,48,2009584,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=0;break}else{yDb(n,24,1999224,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;p=0;break}}}while(0);while(1){o=c[h>>2]|0;j=(d[(c[m>>2]|0)+(o>>>3)|0]|0)<<(o&7)>>>7;c[h>>2]=((o|0)<(c[k>>2]|0))+o;q=j&1;if((p|0)>=32){break}a[e+3+p|0]=q;p=p+1|0}a[e+36|0]=q;q=c[h>>2]|0;p=(d[(c[m>>2]|0)+(q>>>3)|0]|0)<<(q&7)>>>7;c[h>>2]=((q|0)<(c[k>>2]|0))+q;a[e+37|0]=p&1;p=c[h>>2]|0;q=(d[(c[m>>2]|0)+(p>>>3)|0]|0)<<(p&7)>>>7;c[h>>2]=((p|0)<(c[k>>2]|0))+p;a[e+38|0]=q&1;q=c[h>>2]|0;p=(d[(c[m>>2]|0)+(q>>>3)|0]|0)<<(q&7)>>>7;c[h>>2]=((q|0)<(c[k>>2]|0))+q;a[e+39|0]=p&1;p=c[k>>2]|0;k=(c[h>>2]|0)+16|0;e=(p>>>0>k>>>0?k:p)+16|0;k=(p>>>0>e>>>0?e:p)+12|0;c[h>>2]=p>>>0>k>>>0?k:p;i=f;return}function QBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0;g=c[e>>2]|0;if((g|0)==0){return}if((c[g+360>>2]|0)==0){return}g=e+70|0;h=(d[g]|0)&(f^255)&255;a[g]=h;if(!(h<<24>>24==0)){return}U0a(c[b+4>>2]|0,e+4|0);XAb(e+56|0);c[e+16>>2]=0;XAb(e+64|0);XAb(e+60|0);c[e+24>>2]=0;c[e+20>>2]=0;c[e+36>>2]=0;return}function RBa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;if((e|d|0)<0){f=c[(c[a+3480>>2]|0)+20>>2]|0;return f|0}else{g=c[a+180>>2]|0;h=c[g+13080>>2]|0;i=(ba((1<<h)-1+(c[g+13096>>2]|0)>>h,e>>h)|0)+(d>>h)|0;f=c[(c[b+24>>2]|0)+(c[(c[(c[a+184>>2]|0)+1652>>2]|0)+(i<<2)>>2]<<2)>>2]|0;return f|0}return 0}function SBa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+4|0;e=0;do{f=c[b+3484+(e*72|0)>>2]|0;do{if((f|0)!=0){if((c[f+360>>2]|0)==0){break}g=b+3484+(e*72|0)+70|0;h=a[g]&-7;a[g]=h;if(!(h<<24>>24==0)){break}U0a(c[d>>2]|0,b+3484+(e*72|0)+4|0);XAb(b+3484+(e*72|0)+56|0);c[b+3484+(e*72|0)+16>>2]=0;XAb(b+3484+(e*72|0)+64|0);XAb(b+3484+(e*72|0)+60|0);c[b+3484+(e*72|0)+24>>2]=0;c[b+3484+(e*72|0)+20>>2]=0;c[b+3484+(e*72|0)+36>>2]=0}}while(0);e=e+1|0;}while(e>>>0<32>>>0);return}function TBa(b){b=b|0;var d=0,e=0,f=0;d=b+4|0;e=0;do{f=c[b+3484+(e*72|0)>>2]|0;do{if((f|0)!=0){if((c[f+360>>2]|0)==0){break}a[b+3484+(e*72|0)+70|0]=0;U0a(c[d>>2]|0,b+3484+(e*72|0)+4|0);XAb(b+3484+(e*72|0)+56|0);c[b+3484+(e*72|0)+16>>2]=0;XAb(b+3484+(e*72|0)+64|0);XAb(b+3484+(e*72|0)+60|0);c[b+3484+(e*72|0)+24>>2]=0;c[b+3484+(e*72|0)+20>>2]=0;c[b+3484+(e*72|0)+36>>2]=0}}while(0);e=e+1|0;}while(e>>>0<32>>>0);return}function UBa(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=d+7368|0;j=0;a:do{do{if((c[(c[d+3484+(j*72|0)>>2]|0)+360>>2]|0)!=0){if((b[d+3484+(j*72|0)+68>>1]|0)!=(b[h>>1]|0)){break}if((c[d+3484+(j*72|0)+32>>2]|0)==(f|0)){k=5;break a}}}while(0);j=j+1|0;}while(j>>>0<32>>>0);if((k|0)==5){yDb(c[d+4>>2]|0,16,2277808,(k=i,i=i+8|0,c[k>>2]=f,k)|0);i=k;l=-1094995529;i=g;return l|0}k=VBa(d)|0;if((k|0)==0){l=-12;i=g;return l|0}c[e>>2]=c[k>>2];c[d+3480>>2]=k;c[k+32>>2]=f;a[k+70|0]=3;b[k+68>>1]=b[h>>1]|0;h=k+40|0;k=(c[d+180>>2]|0)+20|0;c[h>>2]=c[k>>2];c[h+4>>2]=c[k+4>>2];c[h+8>>2]=c[k+8>>2];c[h+12>>2]=c[k+12>>2];l=0;i=g;return l|0}function VBa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=0;while(1){if(!(e>>>0<32>>>0)){f=17;break}g=b+3484+(e*72|0)|0;h=g|0;if((c[(c[h>>2]|0)+360>>2]|0)==0){break}else{e=e+1|0}}if((f|0)==17){yDb(c[b+4>>2]|0,16,2006448,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;j=0;i=d;return j|0}f=b+4|0;k=b+3484+(e*72|0)+4|0;if((W0a(c[f>>2]|0,k,1)|0)<0){j=0;i=d;return j|0}l=VAb((c[b+7412>>2]|0)*392|0)|0;m=b+3484+(e*72|0)+64|0;c[m>>2]=l;do{if((l|0)!=0){n=cBb(c[b+1404>>2]|0)|0;c[b+3484+(e*72|0)+56>>2]=n;if((n|0)==0){break}c[b+3484+(e*72|0)+16>>2]=c[n+4>>2];n=cBb(c[b+1408>>2]|0)|0;c[b+3484+(e*72|0)+60>>2]=n;if((n|0)==0){break}o=c[n+4>>2]|0;n=b+3484+(e*72|0)+24|0;c[n>>2]=o;p=c[b+180>>2]|0;q=ba(c[p+13108>>2]|0,c[p+13104>>2]|0)|0;c[b+3484+(e*72|0)+28>>2]=q;a:do{if((q|0)>0){p=0;r=o;while(1){c[r+(p<<2)>>2]=c[(c[m>>2]|0)+4>>2];s=p+1|0;if((s|0)>=(q|0)){break a}p=s;r=c[n>>2]|0}}}while(0);n=b+7512|0;q=c[h>>2]|0;c[q+300>>2]=(c[n>>2]|0)==1;o=c[n>>2]|0;if((o|0)==1){t=1}else{t=(o|0)==2|0}c[q+296>>2]=t;j=g;i=d;return j|0}}while(0);g=c[h>>2]|0;if((g|0)==0){j=0;i=d;return j|0}if((c[g+360>>2]|0)==0){j=0;i=d;return j|0}a[b+3484+(e*72|0)+70|0]=0;U0a(c[f>>2]|0,k);XAb(b+3484+(e*72|0)+56|0);c[b+3484+(e*72|0)+16>>2]=0;XAb(m);XAb(b+3484+(e*72|0)+60|0);c[b+3484+(e*72|0)+24>>2]=0;c[b+3484+(e*72|0)+20>>2]=0;c[b+3484+(e*72|0)+36>>2]=0;j=0;i=d;return j|0}function WBa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;j=e+7370|0;k=e+7368|0;l=e+180|0;a:do{if((g|0)==0){m=0;n=2147483647;o=0;p=0;b:while(1){if(o>>>0<32>>>0){q=o;r=n;s=m}else{do{if((b[j>>1]|0)==(b[k>>1]|0)){t=c[l>>2]|0;if((t|0)==0){break}if((m|0)<=(c[t+76+(((c[t+72>>2]|0)-1|0)*12|0)+4>>2]|0)){u=0;v=26;break b}}}while(0);if((m|0)!=0){w=p;break a}t=b[j>>1]|0;if(t<<16>>16==(b[k>>1]|0)){u=0;v=26;break}b[j>>1]=t+1&255;q=0;r=2147483647;s=0}do{if((a[e+3484+(q*72|0)+70|0]&1)==0){x=s;y=r;z=p}else{if((b[e+3484+(q*72|0)+68>>1]|0)!=(b[j>>1]|0)){x=s;y=r;z=p;break}t=c[e+3484+(q*72|0)+32>>2]|0;A=(t|0)<(r|0);x=s+1|0;y=A?t:r;z=A?q:p}}while(0);m=x;n=y;o=q+1|0;p=z}if((v|0)==26){i=h;return u|0}}else{p=0;o=2147483647;n=0;m=0;while(1){if(n>>>0<32>>>0){B=n;C=o;D=p}else{if((p|0)!=0){w=m;break a}A=b[j>>1]|0;if(A<<16>>16==(b[k>>1]|0)){u=0;break}b[j>>1]=A+1&255;B=0;C=2147483647;D=0}do{if((a[e+3484+(B*72|0)+70|0]&1)==0){E=D;F=C;G=m}else{if((b[e+3484+(B*72|0)+68>>1]|0)!=(b[j>>1]|0)){E=D;F=C;G=m;break}A=c[e+3484+(B*72|0)+32>>2]|0;t=(A|0)<(C|0);E=D+1|0;F=t?A:C;G=t?B:m}}while(0);p=E;o=F;n=B+1|0;m=G}i=h;return u|0}}while(0);G=e+3484+(w*72|0)|0;B=c[G>>2]|0;F=bFb(c[B+80>>2]|0)|0;E=(b[F+8>>1]&16384)>>>0>14336>>>0|0;C=MCb(f,B)|0;B=c[G>>2]|0;do{if((B|0)!=0){if((c[B+360>>2]|0)==0){break}G=e+3484+(w*72|0)+70|0;D=a[G]&-2;a[G]=D;if(!(D<<24>>24==0)){break}U0a(c[e+4>>2]|0,e+3484+(w*72|0)+4|0);XAb(e+3484+(w*72|0)+56|0);c[e+3484+(w*72|0)+16>>2]=0;XAb(e+3484+(w*72|0)+64|0);XAb(e+3484+(w*72|0)+60|0);c[e+3484+(w*72|0)+24>>2]=0;c[e+3484+(w*72|0)+20>>2]=0;c[e+3484+(w*72|0)+36>>2]=0}}while(0);if((C|0)<0){u=C;i=h;return u|0}C=F+5|0;B=F+6|0;F=c[e+3484+(w*72|0)+40>>2]|0;D=c[e+3484+(w*72|0)+48>>2]|0;G=(ba(D,c[f+32>>2]|0)|0)+(F<<E)|0;j=f|0;c[j>>2]=(c[j>>2]|0)+G;G=(ba(D>>d[B],c[f+36>>2]|0)|0)+(F>>d[C]<<E)|0;j=f+4|0;c[j>>2]=(c[j>>2]|0)+G;G=(ba(D>>d[B],c[f+40>>2]|0)|0)+(F>>d[C]<<E)|0;E=f+8|0;c[E>>2]=(c[E>>2]|0)+G;yDb(c[e+4>>2]|0,48,2323664,(G=i,i=i+8|0,c[G>>2]=c[e+3484+(w*72|0)+32>>2],G)|0);i=G;u=1;i=h;return u|0}function XBa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=i;i=i+200|0;e=d|0;f=(c[b+2404>>2]|0)==0;g=b+3480|0;h=c[g>>2]|0;j=c[h+28>>2]|0;k=c[(c[(c[b+184>>2]|0)+1652>>2]|0)+(c[b+2396>>2]<<2)>>2]|0;l=c[b+5796>>2]|0;m=h+64|0;n=c[m>>2]|0;if(!(l>>>0<(((c[n+8>>2]|0)>>>0)/392|0)>>>0)){o=-1094995529;i=d;return o|0}p=h+24|0;do{if((k|0)<(j|0)){c[(c[p>>2]|0)+(k<<2)>>2]=(c[n+4>>2]|0)+(l*392|0);q=k+1|0;if((q|0)<(j|0)){r=q}else{break}do{c[(c[p>>2]|0)+(r<<2)>>2]=(c[(c[m>>2]|0)+4>>2]|0)+(l*392|0);r=r+1|0;}while((r|0)<(j|0))}}while(0);c[h+20>>2]=c[(c[p>>2]|0)+(k<<2)>>2];k=b+2192|0;if(((c[b+1800>>2]|0)+(c[b+1604>>2]|0)|0)==(-(c[k>>2]|0)|0)){yDb(c[b+4>>2]|0,16,2187280,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;o=-1094995529;i=d;return o|0}p=f?2:1;f=e;h=e+192|0;j=b+3027|0;r=b+3028|0;l=0;m=0;a:while(1){TGb(f|0,0,196)|0;n=c[(c[g>>2]|0)+20>>2]|0;q=n+(m*196|0)|0;t=l<<24>>24!=0|0;u=t^1;v=b+3012+(m<<2)|0;w=c[v>>2]|0;if((w|0)==0){x=0}else{y=c[b+1412+(t*196|0)+192>>2]|0;z=0;while(1){b:do{if((y|0)>0){A=0;B=z;while(1){if((B|0)>=16){C=B;break b}c[e+64+(B<<2)>>2]=c[b+1412+(t*196|0)+64+(A<<2)>>2];c[e+(c[h>>2]<<2)>>2]=c[b+1412+(t*196|0)+(A<<2)>>2];c[e+128+(c[h>>2]<<2)>>2]=0;D=(c[h>>2]|0)+1|0;c[h>>2]=D;E=A+1|0;if((E|0)<(y|0)){A=E;B=D}else{C=D;break}}}else{C=z}}while(0);B=c[b+1412+(u*196|0)+192>>2]|0;c:do{if((B|0)>0){A=0;D=C;while(1){if((D|0)>=16){F=D;break c}c[e+64+(D<<2)>>2]=c[b+1412+(u*196|0)+64+(A<<2)>>2];c[e+(c[h>>2]<<2)>>2]=c[b+1412+(u*196|0)+(A<<2)>>2];c[e+128+(c[h>>2]<<2)>>2]=0;E=(c[h>>2]|0)+1|0;c[h>>2]=E;G=A+1|0;if((G|0)<(B|0)){A=G;D=E}else{F=E;break}}}else{F=C}}while(0);B=c[k>>2]|0;d:do{if((B|0)>0){D=0;A=F;while(1){if((A|0)>=16){H=A;break d}c[e+64+(A<<2)>>2]=c[b+2064+(D<<2)>>2];c[e+(c[h>>2]<<2)>>2]=c[b+2e3+(D<<2)>>2];c[e+128+(c[h>>2]<<2)>>2]=1;E=(c[h>>2]|0)+1|0;c[h>>2]=E;G=D+1|0;if((G|0)<(B|0)){D=G;A=E}else{H=E;break}}}else{H=F}}while(0);if(H>>>0<w>>>0){z=H}else{x=H;break}}}do{if((a[b+3008+m|0]|0)==0){UGb(q|0,f|0,196)|0;z=n+(m*196|0)+192|0;u=c[z>>2]|0;y=c[v>>2]|0;c[z>>2]=u>>>0>y>>>0?y:u}else{if((w|0)==0){break}u=n+(m*196|0)+192|0;y=0;do{z=c[b+2752+(m<<7)+(y<<2)>>2]|0;if((z|0)>=(x|0)){break a}c[n+(m*196|0)+64+(y<<2)>>2]=c[e+64+(z<<2)>>2];c[n+(m*196|0)+(y<<2)>>2]=c[e+(z<<2)>>2];c[n+(m*196|0)+128+(y<<2)>>2]=c[e+128+(z<<2)>>2];c[u>>2]=(c[u>>2]|0)+1;y=y+1|0;}while(y>>>0<(c[v>>2]|0)>>>0)}}while(0);do{if((a[j]|0)==l<<24>>24){v=c[r>>2]|0;if(!(v>>>0<(c[n+(m*196|0)+192>>2]|0)>>>0)){break}c[(c[g>>2]|0)+36>>2]=c[n+(m*196|0)+(v<<2)>>2]}}while(0);n=l+1&255;v=n&255;if(v>>>0<p>>>0){l=n;m=v}else{o=0;I=25;break}}if((I|0)==25){i=d;return o|0}yDb(c[b+4>>2]|0,16,2110080,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;o=-1094995529;i=d;return o|0}function YBa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[b+2584>>2]|0;if((e|0)==0){c[b+1800>>2]=0;c[b+1604>>2]=0;f=0;return f|0}g=b+3480|0;h=0;do{if((b+3484+(h*72|0)|0)!=(c[g>>2]|0)){i=b+3484+(h*72|0)+70|0;a[i]=a[i]&-7}h=h+1|0;}while(h>>>0<32>>>0);c[b+1604>>2]=0;c[b+1800>>2]=0;c[b+1996>>2]=0;c[b+2192>>2]=0;c[b+2388>>2]=0;h=e+4|0;g=b+5788|0;i=e|0;j=0;while(1){if((j|0)>=(c[h>>2]|0)){break}if((a[e+136+j|0]|0)==0){k=2}else{k=j>>>0>=(c[i>>2]|0)>>>0|0}l=ZBa(b,b+1412+(k*196|0)|0,(c[e+8+(j<<2)>>2]|0)+(c[g>>2]|0)|0,2)|0;if((l|0)<0){f=l;m=21;break}else{j=j+1|0}}if((m|0)==21){return f|0}j=b+2748|0;g=0;while(1){if((g|0)>=(d[j]|0)){break}e=ZBa(b,b+1412+(((a[b+2716+g|0]|0)!=0?3:4)*196|0)|0,c[b+2588+(g<<2)>>2]|0,4)|0;if((e|0)<0){f=e;m=21;break}else{g=g+1|0}}if((m|0)==21){return f|0}m=b+4|0;g=0;while(1){j=c[b+3484+(g*72|0)>>2]|0;do{if((j|0)!=0){if((c[j+360>>2]|0)==0){break}if((a[b+3484+(g*72|0)+70|0]|0)!=0){break}U0a(c[m>>2]|0,b+3484+(g*72|0)+4|0);XAb(b+3484+(g*72|0)+56|0);c[b+3484+(g*72|0)+16>>2]=0;XAb(b+3484+(g*72|0)+64|0);XAb(b+3484+(g*72|0)+60|0);c[b+3484+(g*72|0)+24>>2]=0;c[b+3484+(g*72|0)+20>>2]=0;c[b+3484+(g*72|0)+36>>2]=0}}while(0);j=g+1|0;if(j>>>0<32>>>0){g=j}else{f=0;break}}return f|0}function ZBa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;j=d+180|0;k=(1<<c[(c[j>>2]|0)+64>>2])-1|0;l=d+7368|0;m=0;a:while(1){n=d+3484+(m*72|0)|0;do{if((c[(c[n>>2]|0)+360>>2]|0)!=0){if((b[d+3484+(m*72|0)+68>>1]|0)!=(b[l>>1]|0)){break}if((c[d+3484+(m*72|0)+32>>2]&k|0)==(f|0)){o=n;break a}}}while(0);n=m+1|0;if(n>>>0<32>>>0){m=n}else{p=0;q=6;break}}b:do{if((q|0)==6){while(1){q=0;m=d+3484+(p*72|0)|0;do{if((c[(c[m>>2]|0)+360>>2]|0)!=0){if((b[d+3484+(p*72|0)+68>>1]|0)!=(b[l>>1]|0)){break}n=c[d+3484+(p*72|0)+32>>2]|0;if((n|0)==(f|0)){o=m;break b}if((n&k|0)==(f|0)){o=m;break b}}}while(0);m=p+1|0;if(m>>>0<32>>>0){p=m;q=6}else{break}}yDb(c[d+4>>2]|0,16,2051832,(m=i,i=i+8|0,c[m>>2]=f,m)|0);i=m;o=0}}while(0);if((o|0)==(c[d+3480>>2]|0)){r=-1094995529;i=h;return r|0}do{if((o|0)==0){q=VBa(d)|0;if((q|0)==0){r=-12;i=h;return r|0}p=c[j>>2]|0;k=q|0;m=c[k>>2]|0;do{if((c[p+56>>2]|0)==0){n=c[m+360>>2]|0;if((n|0)==0){break}TGb(c[n+4>>2]|0,1<<(c[p+52>>2]|0)-1&255|0,c[n+8>>2]|0)|0;n=c[(c[k>>2]|0)+364>>2]|0;if((n|0)==0){break}else{s=1;t=n}do{s=s+1|0;TGb(c[t+4>>2]|0,1<<(c[(c[j>>2]|0)+52>>2]|0)-1&255|0,c[t+8>>2]|0)|0;t=c[(c[k>>2]|0)+360+(s<<2)>>2]|0;}while((t|0)!=0)}else{if((c[m>>2]|0)==0){break}else{u=0;v=p;w=m}while(1){if((c[v+13100>>2]>>c[v+13152+(u<<2)>>2]|0)>0){n=0;y=v;while(1){if((c[y+13096>>2]>>c[y+13140+(u<<2)>>2]|0)>0){z=0;A=y;while(1){B=c[k>>2]|0;C=(c[B+(u<<2)>>2]|0)+((ba(c[B+32+(u<<2)>>2]|0,n)|0)+(z<<1))|0;x=1<<(c[A+52>>2]|0)-1&65535;a[C]=x;x=x>>8;a[C+1|0]=x;C=z+1|0;B=c[j>>2]|0;if((C|0)<(c[B+13096>>2]>>c[B+13140+(u<<2)>>2]|0)){z=C;A=B}else{D=B;break}}}else{D=y}A=n+1|0;if((A|0)<(c[D+13100>>2]>>c[D+13152+(u<<2)>>2]|0)){n=A;y=D}else{break}}E=D;F=c[k>>2]|0}else{E=v;F=w}y=u+1|0;if((c[F+(y<<2)>>2]|0)==0){break}else{u=y;v=E;w=F}}}}while(0);c[q+32>>2]=f;b[q+68>>1]=b[l>>1]|0;a[q+70|0]=0;if((a[d+140|0]|0)!=1){G=q;break}Y0a(q+4|0,2147483647,0);G=q}else{G=o}}while(0);o=e+192|0;c[e+64+(c[o>>2]<<2)>>2]=c[G+32>>2];c[e+(c[o>>2]<<2)>>2]=G;c[o>>2]=(c[o>>2]|0)+1;o=G+70|0;a[o]=a[o]&-7&255|g;r=0;i=h;return r|0}function _Ba(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=1<<c[(c[a+180>>2]|0)+64>>2];e=c[a+5792>>2]|0;f=(e|0)%(d|0)|0;g=e-f|0;do{if((f|0)>(b|0)){if((f-b|0)<((d|0)/2|0|0)){h=4;break}i=g+d|0}else{h=4}}while(0);do{if((h|0)==4){if((f|0)>=(b|0)){i=g;break}i=g-((b-f|0)>((d|0)/2|0|0)?d:0)|0}}while(0);return(((c[a+3472>>2]|0)-16|0)>>>0<3>>>0?0:i)+b|0}function $Ba(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[b+2584>>2]|0;e=b+2588|0;do{if((d|0)==0){f=0}else{g=c[d>>2]|0;if((g|0)==0){h=0;i=0}else{j=g>>>0>1>>>0;k=0;l=0;do{l=((a[d+136+k|0]|0)!=0)+l|0;k=k+1|0;}while(k>>>0<g>>>0);h=j?g:1;i=l}k=c[d+4>>2]|0;if((h|0)<(k|0)){m=h;n=i}else{f=i;break}while(1){o=((a[d+136+m|0]|0)!=0)+n|0;p=m+1|0;if((p|0)<(k|0)){m=p;n=o}else{f=o;break}}}}while(0);if((e|0)==0){q=f;return q|0}e=a[b+2748|0]|0;if(e<<24>>24==0){q=f;return q|0}n=e&255;e=0;m=f;while(1){f=((a[b+2716+e|0]|0)!=0)+m|0;d=e+1|0;if((d|0)<(n|0)){e=d;m=f}else{q=f;break}}return q|0}function aCa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;b=i;e=a+136|0;f=a+4|0;g=a+3472|0;h=a+7496|0;j=a+7500|0;k=a+7508|0;l=a+7504|0;m=a+7484|0;n=a+7512|0;o=c[e>>2]|0;a:while(1){yDb(c[f>>2]|0,48,2277576,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=o+9280|0;r=o+9288|0;s=c[r>>2]|0;t=c[o+9272>>2]|0;u=0;v=c[q>>2]|0;while(1){w=t+(v>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)>>>24;w=v+8|0;y=s>>>0>w>>>0?w:s;c[q>>2]=y;z=x+u|0;if((x|0)==255){u=z;v=y}else{A=0;B=y;break}}do{v=t+(B>>>3)|0;u=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(B&7)>>>24;v=B+8|0;B=s>>>0>v>>>0?v:s;c[q>>2]=B;A=u+A|0;}while((u|0)==255);do{if((c[g>>2]|0)==39){if((z|0)==129){s=c[e>>2]|0;t=s+9272|0;u=s+9280|0;v=c[s+9288>>2]|0;s=(c[u>>2]|0)+4|0;y=(v>>>0>s>>>0?s:v)+1|0;s=(v>>>0>y>>>0?y:v)+1|0;c[u>>2]=v>>>0>s>>>0?s:v;v=dCa(t)|0;s=dCa(t)|0;do{if(s>>>0>31>>>0){yDb(c[f>>2]|0,16,2110040,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p}else{c[m>>2]=s;if((v|0)<1){break}else{C=1}do{dCa(t)|0;C=C+1|0;}while((C|0)<=(v|0))}}while(0);yDb(c[f>>2]|0,48,2323640,(p=i,i=i+8|0,c[p>>2]=129,p)|0);i=p;break}else if((z|0)==256){cCa(a);break}else if((z|0)==1){v=c[e>>2]|0;t=c[a+252+(c[m>>2]<<2)>>2]|0;if((t|0)==0){D=37;break a}if((c[(c[t+4>>2]|0)+216>>2]|0)!=0){t=v+9280|0;s=c[t>>2]|0;u=v+9288|0;y=c[u>>2]|0;x=(c[v+9272>>2]|0)+(s>>>3)|0;v=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(s&7)>>>28;x=s+4|0;c[t>>2]=y>>>0>x>>>0?x:y;c[n>>2]=0;if((v|0)==1){yDb(c[f>>2]|0,48,2006432,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;c[n>>2]=1}else if((v|0)==2){yDb(c[f>>2]|0,48,2051816,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;c[n>>2]=2}v=c[u>>2]|0;u=(c[t>>2]|0)+2|0;y=(v>>>0>u>>>0?u:v)+1|0;c[t>>2]=v>>>0>y>>>0?y:v}yDb(c[f>>2]|0,48,2323640,(p=i,i=i+8|0,c[p>>2]=1,p)|0);i=p;v=c[r>>2]|0;y=(c[q>>2]|0)+(A<<3)|0;c[q>>2]=v>>>0>y>>>0?y:v;break}else if((z|0)==45){v=c[e>>2]|0;y=v+9280|0;t=c[y>>2]|0;u=v+9288|0;x=c[u>>2]|0;s=c[v+9272>>2]|0;v=s+(t>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(t&7);if(w>>>0>134217727>>>0){v=(d[1213744+(w>>>23)|0]|0)+t|0;E=x>>>0>v>>>0?v:x}else{v=w>>>0>65535>>>0;F=v?w>>>16:w;w=v?16:0;if((F&65280|0)==0){G=w;H=F}else{G=w|8;H=F>>>8}F=63-((d[1191992+H|0]|0)+G<<1)+t|0;E=x>>>0>F>>>0?F:x}c[y>>2]=E;F=(d[s+(E>>>3)|0]|0)<<(E&7);c[y>>2]=((E|0)<(x|0))+E;x=F&128;c[h>>2]=x>>>7^1;F=c[y>>2]|0;t=c[u>>2]|0;if((x|0)==0){x=s+(F>>>3)|0;w=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(F&7)>>>25;x=F+7|0;c[y>>2]=t>>>0>x>>>0?x:t;c[j>>2]=w;w=c[y>>2]|0;x=(d[s+(w>>>3)|0]|0)<<(w&7)>>>7;c[y>>2]=((w|0)<(c[u>>2]|0))+w;c[k>>2]=x&1;x=c[y>>2]|0;w=c[u>>2]|0;v=s+(x>>>3)|0;s=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(x&7)>>>26;v=x+6|0;c[y>>2]=w>>>0>v>>>0?v:w;c[l>>2]=s;s=c[u>>2]|0;u=(c[y>>2]|0)+6|0;w=s>>>0>u>>>0?u:s;c[y>>2]=w;do{if((c[k>>2]|0)==0){if((c[j>>2]|0)==5){I=w;break}u=w+16|0;v=s>>>0>u>>>0?u:s;c[y>>2]=v;I=v}else{I=w}}while(0);w=I+8|0;v=(s>>>0>w>>>0?w:s)+1|0;w=s>>>0>v>>>0?v:s;c[y>>2]=w;J=w;K=s}else{J=F;K=t}w=J+1|0;c[y>>2]=K>>>0>w>>>0?w:K;break}else{yDb(c[f>>2]|0,48,2323640,(p=i,i=i+8|0,c[p>>2]=z,p)|0);i=p;w=c[r>>2]|0;v=(c[q>>2]|0)+(A<<3)|0;c[q>>2]=w>>>0>v>>>0?v:w;break}}else{if((z|0)==132){cCa(a);break}else{yDb(c[f>>2]|0,48,2187256,(p=i,i=i+8|0,c[p>>2]=z,p)|0);i=p;w=c[r>>2]|0;v=(c[q>>2]|0)+(A<<3)|0;c[q>>2]=w>>>0>v>>>0?v:w;break}}}while(0);w=c[e>>2]|0;v=c[w+9280>>2]|0;if(((c[w+9284>>2]|0)-v|0)<=0){L=1;D=38;break}u=(c[w+9272>>2]|0)+(v>>>3)|0;if(((fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(v&7)&-16777216|0)==-2147483648){L=1;D=38;break}else{o=w}}if((D|0)==37){yDb(c[f>>2]|0,48,2323640,(p=i,i=i+8|0,c[p>>2]=1,p)|0);i=p;p=c[r>>2]|0;r=(c[q>>2]|0)+(A<<3)|0;c[q>>2]=p>>>0>r>>>0?r:p;L=-12;i=b;return L|0}else if((D|0)==38){i=b;return L|0}return 0}function bCa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(f>>>3)|0;a=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(f&7)>>>((32-b|0)>>>0);h=f+b|0;c[e>>2]=g>>>0>h>>>0?h:g;return a|0}function cCa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[b+136>>2]|0;f=e+9272|0;g=e+9280|0;h=c[g>>2]|0;i=c[e+9288>>2]|0;e=(c[f>>2]|0)+(h>>>3)|0;j=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(h&7)>>>24;e=h+8|0;h=i>>>0>e>>>0?e:i;c[g>>2]=h;e=b+7476|0;if((j|0)==0){k=0;do{a[e]=1;a[b+7428+(k<<4)|0]=bCa(f,8)|0;a[b+7428+(k<<4)+1|0]=bCa(f,8)|0;a[b+7428+(k<<4)+2|0]=bCa(f,8)|0;a[b+7428+(k<<4)+3|0]=bCa(f,8)|0;a[b+7428+(k<<4)+4|0]=bCa(f,8)|0;a[b+7428+(k<<4)+5|0]=bCa(f,8)|0;a[b+7428+(k<<4)+6|0]=bCa(f,8)|0;a[b+7428+(k<<4)+7|0]=bCa(f,8)|0;a[b+7428+(k<<4)+8|0]=bCa(f,8)|0;a[b+7428+(k<<4)+9|0]=bCa(f,8)|0;a[b+7428+(k<<4)+10|0]=bCa(f,8)|0;a[b+7428+(k<<4)+11|0]=bCa(f,8)|0;a[b+7428+(k<<4)+12|0]=bCa(f,8)|0;a[b+7428+(k<<4)+13|0]=bCa(f,8)|0;a[b+7428+(k<<4)+14|0]=bCa(f,8)|0;a[b+7428+(k<<4)+15|0]=bCa(f,8)|0;k=k+1|0;}while((k|0)<3);return}else if((j|0)==1){k=h+16|0;f=(i>>>0>k>>>0?k:i)+16|0;k=(i>>>0>f>>>0?f:i)+16|0;c[g>>2]=i>>>0>k>>>0?k:i;return}else if((j|0)==2){k=h+32|0;f=(i>>>0>k>>>0?k:i)+32|0;k=i>>>0>f>>>0?f:i;c[g>>2]=k;l=k}else{l=h}if((j|0)!=2){return}j=l+32|0;c[g>>2]=i>>>0>j>>>0?j:i;return}function dCa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a>>2]|0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;a=b+(f>>>3)|0;h=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7);a=f+16|0;i=g>>>0>a>>>0?a:g;a=b+(i>>>3)|0;j=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>16|h&-65536;i=j>>>0>65535>>>0;a=i?h>>>16:j;j=i?16:0;if((a&65280|0)==0){k=j;l=a}else{k=j|8;l=a>>>8}a=(d[1191992+l|0]|0)+k|0;k=31-a|0;l=-f|0;j=g-f|0;if((k|0)<(l|0)){m=l}else{m=(j|0)<(k|0)?j:k}j=m+f|0;c[e>>2]=j;f=k+1|0;if((f|0)==0){n=0;o=n-1|0;return o|0}m=b+(j>>>3)|0;l=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7);if((f|0)<26){m=j+f|0;c[e>>2]=g>>>0>m>>>0?m:g;n=l>>>(a>>>0);o=n-1|0;return o|0}else{a=j+16|0;j=g>>>0>a>>>0?a:g;c[e>>2]=j;a=k-15|0;m=b+(j>>>3)|0;b=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>((47-k|0)>>>0);k=j+a|0;c[e>>2]=g>>>0>k>>>0?k:g;n=b|l>>>16<<a;o=n-1|0;return o|0}return 0}function eCa(a,b){a=a|0;b=b|0;if((b|0)==9){c[a>>2]=492;c[a+4>>2]=492;c[a+8>>2]=168;c[a+12>>2]=2036;c[a+16>>2]=1218;c[a+20>>2]=376;c[a+24>>2]=2144;c[a+28>>2]=1188;c[a+32>>2]=254;c[a+36>>2]=1048;c[a+40>>2]=2282;c[a+44>>2]=32;c[a+48>>2]=100;c[a+52>>2]=70;c[a+56>>2]=126;c[a+60>>2]=10;c[a+64>>2]=36;c[a+68>>2]=74;c[a+72>>2]=6;c[a+76>>2]=86;c[a+80>>2]=206;c[a+84>>2]=594;c[a+88>>2]=50;c[a+92>>2]=292;c[a+96>>2]=374;c[a+100>>2]=216;c[a+104>>2]=408;c[a+108>>2]=364;c[a+112>>2]=272;c[a+116>>2]=600;c[a+120>>2]=306;c[a+124>>2]=460;c[a+128>>2]=522;c[a+132>>2]=54;c[a+136>>2]=226;c[a+140>>2]=32;c[a+144>>2]=134;c[a+148>>2]=100;c[a+152>>2]=88;c[a+156>>2]=56;c[a+160>>2]=402;c[a+164>>2]=126;c[a+168>>2]=18;c[a+172>>2]=40;c[a+176>>2]=250;c[a+180>>2]=150;c[a+184>>2]=234;c[a+188>>2]=40;c[a+192>>2]=250;c[a+196>>2]=150;c[a+200>>2]=234;return}else if((b|0)==10){c[a>>2]=50;c[a+4>>2]=1486;c[a+8>>2]=1712;c[a+12>>2]=410;c[a+16>>2]=2196;c[a+20>>2]=1344;c[a+24>>2]=426;c[a+28>>2]=2096;c[a+32>>2]=878;c[a+36>>2]=2234;c[a+40>>2]=2170;c[a+44>>2]=80;c[a+48>>2]=114;c[a+52>>2]=78;c[a+56>>2]=112;c[a+60>>2]=34;c[a+64>>2]=56;c[a+68>>2]=60;c[a+72>>2]=70;c[a+76>>2]=482;c[a+80>>2]=396;c[a+84>>2]=516;c[a+88>>2]=362;c[a+92>>2]=422;c[a+96>>2]=504;c[a+100>>2]=314;c[a+104>>2]=326;c[a+108>>2]=92;c[a+112>>2]=308;c[a+116>>2]=182;c[a+120>>2]=476;c[a+124>>2]=236;c[a+128>>2]=502;c[a+132>>2]=490;c[a+136>>2]=334;c[a+140>>2]=146;c[a+144>>2]=84;c[a+148>>2]=86;c[a+152>>2]=150;c[a+156>>2]=80;c[a+160>>2]=452;c[a+164>>2]=62;c[a+168>>2]=14;c[a+172>>2]=166;c[a+176>>2]=78;c[a+180>>2]=340;c[a+184>>2]=450;c[a+188>>2]=166;c[a+192>>2]=78;c[a+196>>2]=340;c[a+200>>2]=450;return}else{c[a>>2]=490;c[a+4>>2]=494;c[a+8>>2]=170;c[a+12>>2]=2038;c[a+16>>2]=1220;c[a+20>>2]=2348;c[a+24>>2]=2142;c[a+28>>2]=1792;c[a+32>>2]=256;c[a+36>>2]=208;c[a+40>>2]=2284;c[a+44>>2]=34;c[a+48>>2]=98;c[a+52>>2]=72;c[a+56>>2]=124;c[a+60>>2]=12;c[a+64>>2]=26;c[a+68>>2]=76;c[a+72>>2]=66;c[a+76>>2]=84;c[a+80>>2]=204;c[a+84>>2]=596;c[a+88>>2]=48;c[a+92>>2]=290;c[a+96>>2]=376;c[a+100>>2]=592;c[a+104>>2]=410;c[a+108>>2]=366;c[a+112>>2]=270;c[a+116>>2]=602;c[a+120>>2]=304;c[a+124>>2]=458;c[a+128>>2]=524;c[a+132>>2]=52;c[a+136>>2]=228;c[a+140>>2]=30;c[a+144>>2]=132;c[a+148>>2]=98;c[a+152>>2]=50;c[a+156>>2]=54;c[a+160>>2]=400;c[a+164>>2]=128;c[a+168>>2]=16;c[a+172>>2]=42;c[a+176>>2]=252;c[a+180>>2]=148;c[a+184>>2]=232;c[a+188>>2]=42;c[a+192>>2]=252;c[a+196>>2]=148;c[a+200>>2]=232;return}}function fCa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=e>>>1;if((f|0)<=0){return}e=g+8|0;j=g+16|0;k=g|0;g=32-h|0;l=9-h|0;m=0;n=a;while(1){a=c[j>>2]|0;o=c[k>>2]|0;p=0;q=c[e>>2]|0;do{r=o+(q>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)>>>(g>>>0);r=q+h|0;q=a>>>0>r>>>0?r:a;c[e>>2]=q;b[n+(p<<1)>>1]=s<<l;p=p+1|0;}while((p|0)<(f|0));p=m+1|0;if((p|0)<(f|0)){m=p;n=n+(i<<1)|0}else{break}}return}function gCa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d>>>1;d=c;c=0;g=a;while(1){a=(b[d>>1]|0)+(e[g>>1]|0)|0;if(a>>>0<512>>>0){h=a&65535}else{h=-a>>31&511}b[g>>1]=h;a=g+2|0;i=(b[d+2>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){j=i&65535}else{j=-i>>31&511}b[a>>1]=j;a=g+4|0;i=(b[d+4>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){k=i&65535}else{k=-i>>31&511}b[a>>1]=k;a=g+6|0;i=(b[d+6>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){l=i&65535}else{l=-i>>31&511}b[a>>1]=l;a=c+1|0;if((a|0)<4){d=d+8|0;c=a;g=g+(f<<1)|0}else{break}}return}function hCa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=d>>>1;d=c;c=0;g=a;while(1){a=(b[d>>1]|0)+(e[g>>1]|0)|0;if(a>>>0<512>>>0){h=a&65535}else{h=-a>>31&511}b[g>>1]=h;a=g+2|0;i=(b[d+2>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){j=i&65535}else{j=-i>>31&511}b[a>>1]=j;a=g+4|0;i=(b[d+4>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){k=i&65535}else{k=-i>>31&511}b[a>>1]=k;a=g+6|0;i=(b[d+6>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){l=i&65535}else{l=-i>>31&511}b[a>>1]=l;a=g+8|0;i=(b[d+8>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){m=i&65535}else{m=-i>>31&511}b[a>>1]=m;a=g+10|0;i=(b[d+10>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){n=i&65535}else{n=-i>>31&511}b[a>>1]=n;a=g+12|0;i=(b[d+12>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){o=i&65535}else{o=-i>>31&511}b[a>>1]=o;a=g+14|0;i=(b[d+14>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){p=i&65535}else{p=-i>>31&511}b[a>>1]=p;a=c+1|0;if((a|0)<8){d=d+16|0;c=a;g=g+(f<<1)|0}else{break}}return}function iCa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>>1;d=c;c=0;g=a;while(1){a=d;h=0;while(1){i=g+(h<<1)|0;j=(b[a>>1]|0)+(e[i>>1]|0)|0;if(j>>>0<512>>>0){k=j&65535}else{k=-j>>31&511}b[i>>1]=k;i=h+1|0;if((i|0)<16){a=a+2|0;h=i}else{break}}h=c+1|0;if((h|0)<16){d=d+32|0;c=h;g=g+(f<<1)|0}else{break}}return}function jCa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>>1;d=c;c=0;g=a;while(1){a=d;h=0;while(1){i=g+(h<<1)|0;j=(b[a>>1]|0)+(e[i>>1]|0)|0;if(j>>>0<512>>>0){k=j&65535}else{k=-j>>31&511}b[i>>1]=k;i=h+1|0;if((i|0)<32){a=a+2|0;h=i}else{break}}h=c+1|0;if((h|0)<32){d=d+64|0;c=h;g=g+(f<<1)|0}else{break}}return}function kCa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d>>>1;d=a;a=0;while(1){g=((b[c+(a<<1)>>1]|0)+8>>4)+(e[d>>1]|0)|0;if(g>>>0<512>>>0){h=g&65535}else{h=-g>>31&511}b[d>>1]=h;g=d+2|0;i=((b[c+((a|1)<<1)>>1]|0)+8>>4)+(e[g>>1]|0)|0;if(i>>>0<512>>>0){j=i&65535}else{j=-i>>31&511}b[g>>1]=j;g=d+4|0;i=((b[c+((a|2)<<1)>>1]|0)+8>>4)+(e[g>>1]|0)|0;if(i>>>0<512>>>0){k=i&65535}else{k=-i>>31&511}b[g>>1]=k;g=d+6|0;i=((b[c+((a|3)<<1)>>1]|0)+8>>4)+(e[g>>1]|0)|0;if(i>>>0<512>>>0){l=i&65535}else{l=-i>>31&511}b[g>>1]=l;g=a+4|0;if((g|0)<16){d=d+(f<<1)|0;a=g}else{break}}return}function lCa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=a;a=c;g=0;while(1){h=b[a>>1]|0;i=a+16|0;j=b[i>>1]|0;k=j+h|0;l=a+24|0;m=b[l>>1]|0;n=m+j|0;o=h-m|0;p=a+8|0;q=(b[p>>1]|0)*74|0;r=((h-j+m|0)*74|0)+64|0;m=r>>7;if((m+32768|0)>>>0>65535>>>0){s=(r>>31^32767)&65535}else{s=m&65535}b[i>>1]=s;i=(k*29|0)+64+(n*55|0)+q|0;m=i>>7;if((m+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=m&65535}b[a>>1]=t;m=(n*-29|0)+64+(o*55|0)+q|0;n=m>>7;if((n+32768|0)>>>0>65535>>>0){u=(m>>31^32767)&65535}else{u=n&65535}b[p>>1]=u;p=(k*55|0)+64+(o*29|0)-q|0;q=p>>7;if((q+32768|0)>>>0>65535>>>0){v=(p>>31^32767)&65535}else{v=q&65535}b[l>>1]=v;l=g+1|0;if((l|0)<4){a=a+2|0;g=l}else{break}}g=d>>>1;d=f;f=0;a=c;while(1){c=b[a>>1]|0;v=b[a+4>>1]|0;u=v+c|0;t=b[a+6>>1]|0;s=t+v|0;l=c-t|0;q=(b[a+2>>1]|0)*74|0;p=d+4|0;o=((c-v+t|0)*74|0)+1024|0;t=o>>11;if((t+32768|0)>>>0>65535>>>0){w=(o>>31^32767)&65535}else{w=t&65535}t=(w<<16>>16)+(e[p>>1]|0)|0;if(t>>>0<512>>>0){x=t&65535}else{x=-t>>31&511}b[p>>1]=x;p=(u*29|0)+1024+(s*55|0)+q|0;t=p>>11;if((t+32768|0)>>>0>65535>>>0){y=(p>>31^32767)&65535}else{y=t&65535}t=(y<<16>>16)+(e[d>>1]|0)|0;if(t>>>0<512>>>0){z=t&65535}else{z=-t>>31&511}b[d>>1]=z;t=d+2|0;p=(s*-29|0)+1024+(l*55|0)+q|0;s=p>>11;if((s+32768|0)>>>0>65535>>>0){A=(p>>31^32767)&65535}else{A=s&65535}s=(A<<16>>16)+(e[t>>1]|0)|0;if(s>>>0<512>>>0){B=s&65535}else{B=-s>>31&511}b[t>>1]=B;t=d+6|0;s=(u*55|0)+1024+(l*29|0)-q|0;q=s>>11;if((q+32768|0)>>>0>65535>>>0){C=(s>>31^32767)&65535}else{C=q&65535}q=(C<<16>>16)+(e[t>>1]|0)|0;if(q>>>0<512>>>0){D=q&65535}else{D=-q>>31&511}b[t>>1]=D;t=f+1|0;if((t|0)<4){d=d+(g<<1)|0;f=t;a=a+8|0}else{break}}return}function mCa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=a;a=c;g=0;while(1){h=b[a>>1]<<6;i=a+16|0;j=b[i>>1]|0;k=(j<<6)+h|0;l=(j*-64|0)+h|0;h=a+8|0;j=b[h>>1]|0;m=a+24|0;n=b[m>>1]|0;o=(n*36|0)+(j*83|0)|0;p=(n*-83|0)+(j*36|0)|0;j=k+64+o|0;n=j>>7;if((n+32768|0)>>>0>65535>>>0){q=(j>>31^32767)&65535}else{q=n&65535}b[a>>1]=q;n=l+64+p|0;j=n>>7;if((j+32768|0)>>>0>65535>>>0){r=(n>>31^32767)&65535}else{r=j&65535}b[h>>1]=r;h=l-p+64|0;p=h>>7;if((p+32768|0)>>>0>65535>>>0){s=(h>>31^32767)&65535}else{s=p&65535}b[i>>1]=s;i=k-o+64|0;o=i>>7;if((o+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=o&65535}b[m>>1]=t;m=g+1|0;if((m|0)<4){a=a+2|0;g=m}else{break}}g=d>>>1;d=f;f=0;a=c;while(1){c=b[a>>1]<<6;t=b[a+4>>1]|0;s=(t<<6)+c|0;r=(t*-64|0)+c|0;c=b[a+2>>1]|0;t=b[a+6>>1]|0;q=(t*36|0)+(c*83|0)|0;m=(t*-83|0)+(c*36|0)|0;c=s+1024+q|0;t=c>>11;if((t+32768|0)>>>0>65535>>>0){u=(c>>31^32767)&65535}else{u=t&65535}t=(u<<16>>16)+(e[d>>1]|0)|0;if(t>>>0<512>>>0){v=t&65535}else{v=-t>>31&511}b[d>>1]=v;t=d+2|0;c=r+1024+m|0;o=c>>11;if((o+32768|0)>>>0>65535>>>0){w=(c>>31^32767)&65535}else{w=o&65535}o=(w<<16>>16)+(e[t>>1]|0)|0;if(o>>>0<512>>>0){x=o&65535}else{x=-o>>31&511}b[t>>1]=x;t=d+4|0;o=r-m+1024|0;m=o>>11;if((m+32768|0)>>>0>65535>>>0){y=(o>>31^32767)&65535}else{y=m&65535}m=(y<<16>>16)+(e[t>>1]|0)|0;if(m>>>0<512>>>0){z=m&65535}else{z=-m>>31&511}b[t>>1]=z;t=d+6|0;m=s-q+1024|0;q=m>>11;if((q+32768|0)>>>0>65535>>>0){A=(m>>31^32767)&65535}else{A=q&65535}q=(A<<16>>16)+(e[t>>1]|0)|0;if(q>>>0<512>>>0){B=q&65535}else{B=-q>>31&511}b[t>>1]=B;t=f+1|0;if((t|0)<4){d=d+(g<<1)|0;f=t;a=a+8|0}else{break}}return}function nCa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+64|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=a;a=j;n=h|0;o=h+4|0;p=h+8|0;q=h+12|0;r=d;s=0;while(1){TGb(a|0,0,16)|0;t=r+16|0;u=r+48|0;v=r+80|0;w=r+112|0;x=((b[w>>1]|0)*18|0)+(((b[v>>1]|0)*50|0)+(((b[u>>1]|0)*75|0)+((b[t>>1]|0)*89|0)))|0;c[j>>2]=x;c[j+4>>2]=((b[w>>1]|0)*-50|0)+(((b[v>>1]|0)*-89|0)+(((b[u>>1]|0)*-18|0)+((b[t>>1]|0)*75|0)));c[j+8>>2]=((b[w>>1]|0)*75|0)+(((b[v>>1]|0)*18|0)+(((b[u>>1]|0)*-89|0)+((b[t>>1]|0)*50|0)));c[j+12>>2]=((b[w>>1]|0)*-89|0)+(((b[v>>1]|0)*75|0)+(((b[u>>1]|0)*-50|0)+((b[t>>1]|0)*18|0)));t=b[r>>1]<<6;u=b[r+64>>1]|0;v=(u<<6)+t|0;w=(u*-64|0)+t|0;t=b[r+32>>1]|0;u=b[r+96>>1]|0;y=(u*36|0)+(t*83|0)|0;z=(u*-83|0)+(t*36|0)|0;t=y+v|0;c[n>>2]=t;c[o>>2]=z+w;c[p>>2]=w-z;c[q>>2]=v-y;y=0;v=t;t=x;while(1){x=v+64+t|0;z=x>>7;if((z+32768|0)>>>0>65535>>>0){A=(x>>31^32767)&65535}else{A=z&65535}b[r+(y<<3<<1)>>1]=A;z=v-t+64|0;x=z>>7;if((x+32768|0)>>>0>65535>>>0){B=(z>>31^32767)&65535}else{B=x&65535}b[r+(7-y<<3<<1)>>1]=B;x=y+1|0;if((x|0)>=4){break}y=x;v=c[h+(x<<2)>>2]|0;t=c[j+(x<<2)>>2]|0}t=s+1|0;if((t|0)<8){r=r+2|0;s=t}else{break}}s=f>>>1;f=l;r=k|0;j=k+4|0;h=k+8|0;B=k+12|0;A=m;m=0;q=d;while(1){TGb(f|0,0,16)|0;d=q+2|0;p=q+6|0;o=q+10|0;n=q+14|0;a=((b[n>>1]|0)*18|0)+(((b[o>>1]|0)*50|0)+(((b[p>>1]|0)*75|0)+((b[d>>1]|0)*89|0)))|0;c[l>>2]=a;c[l+4>>2]=((b[n>>1]|0)*-50|0)+(((b[o>>1]|0)*-89|0)+(((b[p>>1]|0)*-18|0)+((b[d>>1]|0)*75|0)));c[l+8>>2]=((b[n>>1]|0)*75|0)+(((b[o>>1]|0)*18|0)+(((b[p>>1]|0)*-89|0)+((b[d>>1]|0)*50|0)));c[l+12>>2]=((b[n>>1]|0)*-89|0)+(((b[o>>1]|0)*75|0)+(((b[p>>1]|0)*-50|0)+((b[d>>1]|0)*18|0)));d=b[q>>1]<<6;p=b[q+8>>1]|0;o=(p<<6)+d|0;n=(p*-64|0)+d|0;d=b[q+4>>1]|0;p=b[q+12>>1]|0;t=(p*36|0)+(d*83|0)|0;v=(p*-83|0)+(d*36|0)|0;d=t+o|0;c[r>>2]=d;c[j>>2]=v+n;c[h>>2]=n-v;c[B>>2]=o-t;t=0;o=d;d=a;while(1){a=A+(t<<1)|0;v=o+1024+d|0;n=v>>11;if((n+32768|0)>>>0>65535>>>0){C=(v>>31^32767)&65535}else{C=n&65535}n=(C<<16>>16)+(e[a>>1]|0)|0;if(n>>>0<512>>>0){D=n&65535}else{D=-n>>31&511}b[a>>1]=D;a=A+(7-t<<1)|0;n=o-d+1024|0;v=n>>11;if((v+32768|0)>>>0>65535>>>0){E=(n>>31^32767)&65535}else{E=v&65535}v=(E<<16>>16)+(e[a>>1]|0)|0;if(v>>>0<512>>>0){F=v&65535}else{F=-v>>31&511}b[a>>1]=F;a=t+1|0;if((a|0)>=4){break}t=a;o=c[k+(a<<2)>>2]|0;d=c[l+(a<<2)>>2]|0}d=m+1|0;if((d|0)<8){A=A+(s<<1)|0;m=d;q=q+16|0}else{break}}i=g;return}function oCa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+128|0;j=h|0;k=h+32|0;l=h+64|0;m=h+96|0;n=d;d=k;o=f;p=0;while(1){TGb(d|0,0,32)|0;q=0;do{r=k+(q<<2)|0;s=(ba(b[o+32>>1]|0,a[184560+q|0]|0)|0)+(c[r>>2]|0)|0;t=(ba(b[o+96>>1]|0,a[184688+q|0]|0)|0)+s|0;s=(ba(b[o+160>>1]|0,a[184816+q|0]|0)|0)+t|0;t=(ba(b[o+224>>1]|0,a[184944+q|0]|0)|0)+s|0;s=(ba(b[o+288>>1]|0,a[185072+q|0]|0)|0)+t|0;t=(ba(b[o+352>>1]|0,a[185200+q|0]|0)|0)+s|0;s=(ba(b[o+416>>1]|0,a[185328+q|0]|0)|0)+t|0;c[r>>2]=(ba(b[o+480>>1]|0,a[185456+q|0]|0)|0)+s;q=q+1|0;}while((q|0)<8);q=o+64|0;s=o+192|0;r=o+320|0;t=o+448|0;u=((b[t>>1]|0)*18|0)+(((b[r>>1]|0)*50|0)+(((b[s>>1]|0)*75|0)+((b[q>>1]|0)*89|0)))|0;v=((b[t>>1]|0)*-50|0)+(((b[r>>1]|0)*-89|0)+(((b[s>>1]|0)*-18|0)+((b[q>>1]|0)*75|0)))|0;w=((b[t>>1]|0)*75|0)+(((b[r>>1]|0)*18|0)+(((b[s>>1]|0)*-89|0)+((b[q>>1]|0)*50|0)))|0;x=((b[t>>1]|0)*-89|0)+(((b[r>>1]|0)*75|0)+(((b[s>>1]|0)*-50|0)+((b[q>>1]|0)*18|0)))|0;q=b[o>>1]<<6;s=b[o+256>>1]|0;r=(s<<6)+q|0;t=(s*-64|0)+q|0;q=b[o+128>>1]|0;s=b[o+384>>1]|0;y=(s*36|0)+(q*83|0)|0;z=(s*-83|0)+(q*36|0)|0;q=y+r|0;s=z+t|0;A=t-z|0;z=r-y|0;y=u+q|0;c[j>>2]=y;c[j+28>>2]=q-u;c[j+4>>2]=v+s;c[j+24>>2]=s-v;c[j+8>>2]=w+A;c[j+20>>2]=A-w;c[j+12>>2]=x+z;c[j+16>>2]=z-x;x=0;z=y;while(1){y=c[k+(x<<2)>>2]|0;w=z+64+y|0;A=w>>7;if((A+32768|0)>>>0>65535>>>0){B=(w>>31^32767)&65535}else{B=A&65535}b[o+(x<<4<<1)>>1]=B;A=z-y+64|0;y=A>>7;if((y+32768|0)>>>0>65535>>>0){C=(A>>31^32767)&65535}else{C=y&65535}b[o+(15-x<<4<<1)>>1]=C;y=x+1|0;if((y|0)>=8){break}x=y;z=c[j+(y<<2)>>2]|0}z=p+1|0;if((z|0)<16){o=o+2|0;p=z}else{break}}p=g>>>1;g=m;o=n;n=0;j=f;while(1){TGb(g|0,0,32)|0;f=0;do{C=m+(f<<2)|0;B=(ba(b[j+2>>1]|0,a[184560+f|0]|0)|0)+(c[C>>2]|0)|0;k=(ba(b[j+6>>1]|0,a[184688+f|0]|0)|0)+B|0;B=(ba(b[j+10>>1]|0,a[184816+f|0]|0)|0)+k|0;k=(ba(b[j+14>>1]|0,a[184944+f|0]|0)|0)+B|0;B=(ba(b[j+18>>1]|0,a[185072+f|0]|0)|0)+k|0;k=(ba(b[j+22>>1]|0,a[185200+f|0]|0)|0)+B|0;B=(ba(b[j+26>>1]|0,a[185328+f|0]|0)|0)+k|0;c[C>>2]=(ba(b[j+30>>1]|0,a[185456+f|0]|0)|0)+B;f=f+1|0;}while((f|0)<8);f=j+4|0;B=j+12|0;C=j+20|0;k=j+28|0;d=((b[k>>1]|0)*18|0)+(((b[C>>1]|0)*50|0)+(((b[B>>1]|0)*75|0)+((b[f>>1]|0)*89|0)))|0;z=((b[k>>1]|0)*-50|0)+(((b[C>>1]|0)*-89|0)+(((b[B>>1]|0)*-18|0)+((b[f>>1]|0)*75|0)))|0;x=((b[k>>1]|0)*75|0)+(((b[C>>1]|0)*18|0)+(((b[B>>1]|0)*-89|0)+((b[f>>1]|0)*50|0)))|0;y=((b[k>>1]|0)*-89|0)+(((b[C>>1]|0)*75|0)+(((b[B>>1]|0)*-50|0)+((b[f>>1]|0)*18|0)))|0;f=b[j>>1]<<6;B=b[j+16>>1]|0;C=(B<<6)+f|0;k=(B*-64|0)+f|0;f=b[j+8>>1]|0;B=b[j+24>>1]|0;A=(B*36|0)+(f*83|0)|0;w=(B*-83|0)+(f*36|0)|0;f=A+C|0;B=w+k|0;v=k-w|0;w=C-A|0;A=d+f|0;c[l>>2]=A;c[l+28>>2]=f-d;c[l+4>>2]=z+B;c[l+24>>2]=B-z;c[l+8>>2]=x+v;c[l+20>>2]=v-x;c[l+12>>2]=y+w;c[l+16>>2]=w-y;y=0;w=A;while(1){A=o+(y<<1)|0;x=c[m+(y<<2)>>2]|0;v=w+1024+x|0;z=v>>11;if((z+32768|0)>>>0>65535>>>0){D=(v>>31^32767)&65535}else{D=z&65535}z=(D<<16>>16)+(e[A>>1]|0)|0;if(z>>>0<512>>>0){E=z&65535}else{E=-z>>31&511}b[A>>1]=E;A=o+(15-y<<1)|0;z=w-x+1024|0;x=z>>11;if((x+32768|0)>>>0>65535>>>0){F=(z>>31^32767)&65535}else{F=x&65535}x=(F<<16>>16)+(e[A>>1]|0)|0;if(x>>>0<512>>>0){G=x&65535}else{G=-x>>31&511}b[A>>1]=G;A=y+1|0;if((A|0)>=8){break}y=A;w=c[l+(A<<2)>>2]|0}w=n+1|0;if((w|0)<16){o=o+(p<<1)|0;n=w;j=j+32|0}else{break}}i=h;return}function pCa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+320|0;j=h|0;k=h+64|0;l=h+128|0;m=h+160|0;n=h+224|0;o=h+288|0;p=d;d=k;q=l;r=f;s=0;while(1){TGb(d|0,0,64)|0;t=0;do{u=k+(t<<2)|0;v=1;w=c[u>>2]|0;do{w=(ba(b[r+(v<<5<<1)>>1]|0,a[184496+(v<<5)+t|0]|0)|0)+w|0;v=v+2|0;}while((v|0)<32);c[u>>2]=w;t=t+1|0;}while((t|0)<16);TGb(q|0,0,32)|0;t=0;v=0;while(1){x=(ba(b[r+128>>1]|0,a[184560+t|0]|0)|0)+v|0;y=(ba(b[r+384>>1]|0,a[184688+t|0]|0)|0)+x|0;x=(ba(b[r+640>>1]|0,a[184816+t|0]|0)|0)+y|0;y=(ba(b[r+896>>1]|0,a[184944+t|0]|0)|0)+x|0;x=(ba(b[r+1152>>1]|0,a[185072+t|0]|0)|0)+y|0;y=(ba(b[r+1408>>1]|0,a[185200+t|0]|0)|0)+x|0;x=(ba(b[r+1664>>1]|0,a[185328+t|0]|0)|0)+y|0;c[l+(t<<2)>>2]=(ba(b[r+1920>>1]|0,a[185456+t|0]|0)|0)+x;x=t+1|0;if((x|0)>=8){break}t=x;v=c[l+(x<<2)>>2]|0}v=r+256|0;t=r+768|0;x=r+1280|0;y=r+1792|0;z=((b[y>>1]|0)*18|0)+(((b[x>>1]|0)*50|0)+(((b[t>>1]|0)*75|0)+((b[v>>1]|0)*89|0)))|0;A=((b[y>>1]|0)*-50|0)+(((b[x>>1]|0)*-89|0)+(((b[t>>1]|0)*-18|0)+((b[v>>1]|0)*75|0)))|0;B=((b[y>>1]|0)*75|0)+(((b[x>>1]|0)*18|0)+(((b[t>>1]|0)*-89|0)+((b[v>>1]|0)*50|0)))|0;C=((b[y>>1]|0)*-89|0)+(((b[x>>1]|0)*75|0)+(((b[t>>1]|0)*-50|0)+((b[v>>1]|0)*18|0)))|0;v=b[r>>1]<<6;t=b[r+1024>>1]|0;x=(t<<6)+v|0;y=(t*-64|0)+v|0;v=b[r+512>>1]|0;t=b[r+1536>>1]|0;D=(t*36|0)+(v*83|0)|0;E=(t*-83|0)+(v*36|0)|0;v=D+x|0;t=E+y|0;F=y-E|0;E=x-D|0;D=z+v|0;x=v-z|0;z=A+t|0;v=t-A|0;A=B+F|0;t=F-B|0;B=C+E|0;F=E-C|0;C=c[l>>2]|0;E=C+D|0;c[j>>2]=E;c[j+60>>2]=D-C;C=c[l+4>>2]|0;c[j+4>>2]=C+z;c[j+56>>2]=z-C;C=c[l+8>>2]|0;c[j+8>>2]=C+A;c[j+52>>2]=A-C;C=c[l+12>>2]|0;c[j+12>>2]=C+B;c[j+48>>2]=B-C;C=c[l+16>>2]|0;c[j+16>>2]=C+F;c[j+44>>2]=F-C;C=c[l+20>>2]|0;c[j+20>>2]=C+t;c[j+40>>2]=t-C;C=c[l+24>>2]|0;c[j+24>>2]=C+v;c[j+36>>2]=v-C;C=c[l+28>>2]|0;c[j+28>>2]=C+x;c[j+32>>2]=x-C;C=0;x=E;while(1){E=c[k+(C<<2)>>2]|0;v=x+64+E|0;t=v>>7;if((t+32768|0)>>>0>65535>>>0){G=(v>>31^32767)&65535}else{G=t&65535}b[r+(C<<5<<1)>>1]=G;t=x-E+64|0;E=t>>7;if((E+32768|0)>>>0>65535>>>0){H=(t>>31^32767)&65535}else{H=E&65535}b[r+(31-C<<5<<1)>>1]=H;E=C+1|0;if((E|0)>=16){break}C=E;x=c[j+(E<<2)>>2]|0}x=s+1|0;if((x|0)<32){r=r+2|0;s=x}else{break}}s=g>>>1;g=n;r=o;j=p;p=0;H=f;while(1){TGb(g|0,0,64)|0;f=0;do{G=n+(f<<2)|0;k=1;l=c[G>>2]|0;do{l=(ba(b[H+(k<<1)>>1]|0,a[184496+(k<<5)+f|0]|0)|0)+l|0;k=k+2|0;}while((k|0)<32);c[G>>2]=l;f=f+1|0;}while((f|0)<16);TGb(r|0,0,32)|0;f=0;k=0;while(1){w=(ba(b[H+4>>1]|0,a[184560+f|0]|0)|0)+k|0;u=(ba(b[H+12>>1]|0,a[184688+f|0]|0)|0)+w|0;w=(ba(b[H+20>>1]|0,a[184816+f|0]|0)|0)+u|0;u=(ba(b[H+28>>1]|0,a[184944+f|0]|0)|0)+w|0;w=(ba(b[H+36>>1]|0,a[185072+f|0]|0)|0)+u|0;u=(ba(b[H+44>>1]|0,a[185200+f|0]|0)|0)+w|0;w=(ba(b[H+52>>1]|0,a[185328+f|0]|0)|0)+u|0;c[o+(f<<2)>>2]=(ba(b[H+60>>1]|0,a[185456+f|0]|0)|0)+w;w=f+1|0;if((w|0)>=8){break}f=w;k=c[o+(w<<2)>>2]|0}k=H+8|0;f=H+24|0;w=H+40|0;u=H+56|0;q=((b[u>>1]|0)*18|0)+(((b[w>>1]|0)*50|0)+(((b[f>>1]|0)*75|0)+((b[k>>1]|0)*89|0)))|0;d=((b[u>>1]|0)*-50|0)+(((b[w>>1]|0)*-89|0)+(((b[f>>1]|0)*-18|0)+((b[k>>1]|0)*75|0)))|0;x=((b[u>>1]|0)*75|0)+(((b[w>>1]|0)*18|0)+(((b[f>>1]|0)*-89|0)+((b[k>>1]|0)*50|0)))|0;C=((b[u>>1]|0)*-89|0)+(((b[w>>1]|0)*75|0)+(((b[f>>1]|0)*-50|0)+((b[k>>1]|0)*18|0)))|0;k=b[H>>1]<<6;f=b[H+32>>1]|0;w=(f<<6)+k|0;u=(f*-64|0)+k|0;k=b[H+16>>1]|0;f=b[H+48>>1]|0;E=(f*36|0)+(k*83|0)|0;t=(f*-83|0)+(k*36|0)|0;k=E+w|0;f=t+u|0;v=u-t|0;t=w-E|0;E=q+k|0;w=k-q|0;q=d+f|0;k=f-d|0;d=x+v|0;f=v-x|0;x=C+t|0;v=t-C|0;C=c[o>>2]|0;t=C+E|0;c[m>>2]=t;c[m+60>>2]=E-C;C=c[o+4>>2]|0;c[m+4>>2]=C+q;c[m+56>>2]=q-C;C=c[o+8>>2]|0;c[m+8>>2]=C+d;c[m+52>>2]=d-C;C=c[o+12>>2]|0;c[m+12>>2]=C+x;c[m+48>>2]=x-C;C=c[o+16>>2]|0;c[m+16>>2]=C+v;c[m+44>>2]=v-C;C=c[o+20>>2]|0;c[m+20>>2]=C+f;c[m+40>>2]=f-C;C=c[o+24>>2]|0;c[m+24>>2]=C+k;c[m+36>>2]=k-C;C=c[o+28>>2]|0;c[m+28>>2]=C+w;c[m+32>>2]=w-C;C=0;w=t;while(1){t=j+(C<<1)|0;k=c[n+(C<<2)>>2]|0;f=w+1024+k|0;v=f>>11;if((v+32768|0)>>>0>65535>>>0){I=(f>>31^32767)&65535}else{I=v&65535}v=(I<<16>>16)+(e[t>>1]|0)|0;if(v>>>0<512>>>0){J=v&65535}else{J=-v>>31&511}b[t>>1]=J;t=j+(31-C<<1)|0;v=w-k+1024|0;k=v>>11;if((k+32768|0)>>>0>65535>>>0){K=(v>>31^32767)&65535}else{K=k&65535}k=(K<<16>>16)+(e[t>>1]|0)|0;if(k>>>0<512>>>0){L=k&65535}else{L=-k>>31&511}b[t>>1]=L;t=C+1|0;if((t|0)>=16){break}C=t;w=c[m+(t<<2)>>2]|0}w=p+1|0;if((w|0)<32){j=j+(s<<1)|0;p=w;H=H+64|0}else{break}}i=h;return}function qCa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;UEa(a,b,c,d,e,f,g,h,0);return}function rCa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;UEa(a,b,c,d,e,f,g,h,1);return}function sCa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;UEa(a,b,c,d,e,f,g,h,2);return}function tCa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;UEa(a,b,c,d,e,f,g,h,3);return}function uCa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;q=f;f=g;g=(m|0)!=0|0;r=i+120+(m*20|0)|0;s=c[i+108+(m<<2)>>2]|0;t=h>>>1;h=(c[j+8>>2]|0)==0;if(h){u=k-2-(8>>>(g>>>0))|0}else{u=k}k=(c[j+12>>2]|0)==0;if(k){v=l-2-(4>>>(g>>>0))|0}else{v=l}l=(s|0)!=1;if(l){do{if((c[j>>2]|0)==0){w=0}else{g=c[r>>2]|0;if((v|0)>0){x=0;y=0}else{w=1;break}while(1){z=(e[f+(x<<1)>>1]|0)+g|0;if(z>>>0<512>>>0){A=z&65535}else{A=-z>>31&511}b[q+(x<<1)>>1]=A;z=y+1|0;if((z|0)<(v|0)){x=x+t|0;y=z}else{w=1;break}}}}while(0);do{if(h){B=u}else{y=c[r>>2]|0;x=u-1|0;if((v|0)>0){C=x;D=0}else{B=x;break}while(1){A=(e[f+(C<<1)>>1]|0)+y|0;if(A>>>0<512>>>0){E=A&65535}else{E=-A>>31&511}b[q+(C<<1)>>1]=E;A=D+1|0;if((A|0)<(v|0)){C=C+t|0;D=A}else{B=x;break}}}}while(0);if((s|0)==0){F=0;G=v;H=B;I=w;J=1}else{K=B;L=w;M=17}}else{K=u;L=0;M=17}do{if((M|0)==17){do{if((c[j+4>>2]|0)==0){N=0}else{u=c[r>>2]|0;if((L|0)<(K|0)){O=L}else{N=1;break}while(1){w=(e[f+(O<<1)>>1]|0)+u|0;if(w>>>0<512>>>0){P=w&65535}else{P=-w>>31&511}b[q+(O<<1)>>1]=P;w=O+1|0;if((w|0)<(K|0)){O=w}else{N=1;break}}}}while(0);if(k){F=N;G=v;H=K;I=L;J=0;break}u=c[r>>2]|0;w=v-1|0;B=ba(w,t)|0;if((L|0)<(K|0)){Q=L}else{F=N;G=w;H=K;I=L;J=0;break}while(1){D=Q+B|0;C=(e[f+(D<<1)>>1]|0)+u|0;if(C>>>0<512>>>0){R=C&65535}else{R=-C>>31&511}b[q+(D<<1)>>1]=R;D=Q+1|0;if((D|0)<(K|0)){Q=D}else{F=N;G=w;H=K;I=L;J=0;break}}}}while(0);L=a[483096+(s<<2)|0]|0;K=a[483098+(s<<2)|0]|0;if((F|0)<(G|0)){N=(I|0)<(H|0);Q=ba(F,t)|0;R=ba((a[483097+(s<<2)|0]|0)+F|0,t)|0;v=ba((a[483099+(s<<2)|0]|0)+F|0,t)|0;r=F;while(1){if(N){k=R+L|0;O=v+K|0;P=I;do{M=P+Q|0;w=b[f+(M<<1)>>1]|0;u=b[f+(k+P<<1)>>1]|0;if((w&65535)>>>0>(u&65535)>>>0){S=3}else{S=((w<<16>>16!=u<<16>>16)<<31>>31)+2|0}u=b[f+(O+P<<1)>>1]|0;if((w&65535)>>>0>(u&65535)>>>0){T=1}else{T=(w<<16>>16!=u<<16>>16)<<31>>31}u=(w&65535)+(c[i+120+(m*20|0)+(d[483112+(T+S)|0]<<2)>>2]|0)|0;if(u>>>0<512>>>0){U=u&65535}else{U=-u>>31&511}b[q+(M<<1)>>1]=U;P=P+1|0;}while((P|0)<(H|0))}P=r+1|0;if((P|0)<(G|0)){Q=Q+t|0;R=R+t|0;v=v+t|0;r=P}else{break}}}r=(s|0)==2;do{if(p<<24>>24==0&r){if((c[j>>2]|0)!=0){V=0;break}V=(c[j+4>>2]|0)==0|0}else{V=0}}while(0);do{if(!(n<<24>>24==0|l^1)){j=V+F|0;if((j|0)<(G|0)){W=j}else{break}do{j=ba(W,t)|0;b[q+(j<<1)>>1]=b[f+(j<<1)>>1]|0;W=W+1|0;}while((W|0)<(G|0))}}while(0);do{if(!(o<<24>>24==0|J)){G=V+I|0;if((G|0)<(H|0)){X=G}else{break}do{b[q+(X<<1)>>1]=b[f+(X<<1)>>1]|0;X=X+1|0;}while((X|0)<(H|0))}}while(0);if(!(p<<24>>24!=0&r)){return}b[q>>1]=b[f>>1]|0;return}function vCa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;l=f;f=g;g=(m|0)!=0|0;q=i+120+(m*20|0)|0;r=c[i+108+(m<<2)>>2]|0;s=h>>>1;h=4>>>(g>>>0);t=-2-h|0;u=(c[j+8>>2]|0)==0;if(u){v=k-2-(8>>>(g>>>0))|0}else{v=k}k=h+2|0;h=ba(t,s)|0;g=(r|0)!=1;do{if(g){do{if((c[j>>2]|0)==0){w=0}else{x=c[q>>2]|0;if((k|0)>0){y=0;z=0}else{w=1;break}while(1){A=y+h|0;B=(e[f+(A<<1)>>1]|0)+x|0;if(B>>>0<512>>>0){C=B&65535}else{C=-B>>31&511}b[l+(A<<1)>>1]=C;A=z+1|0;if((A|0)<(k|0)){y=y+s|0;z=A}else{w=1;break}}}}while(0);if(u){D=w;E=v;F=14;break}x=c[q>>2]|0;A=v-1|0;if((k|0)>0){G=A;H=0}else{I=A;J=w;break}while(1){B=G+h|0;K=(e[f+(B<<1)>>1]|0)+x|0;if(K>>>0<512>>>0){L=K&65535}else{L=-K>>31&511}b[l+(B<<1)>>1]=L;B=H+1|0;if((B|0)<(k|0)){G=G+s|0;H=B}else{D=w;E=A;F=14;break}}}else{D=0;E=v;F=14}}while(0);do{if((F|0)==14){if((k|0)<=0){I=E;J=D;break}v=(D|0)<(E|0);w=(a[483096+(r<<2)|0]|0)+h|0;H=(a[483098+(r<<2)|0]|0)+h|0;G=0;L=ba(a[483097+(r<<2)|0]|0,s)|0;q=ba(a[483099+(r<<2)|0]|0,s)|0;u=0;while(1){if(v){z=G+h|0;y=w+L|0;C=H+q|0;A=D;do{x=z+A|0;B=b[f+(x<<1)>>1]|0;K=b[f+(y+A<<1)>>1]|0;if((B&65535)>>>0>(K&65535)>>>0){M=3}else{M=((B<<16>>16!=K<<16>>16)<<31>>31)+2|0}K=b[f+(C+A<<1)>>1]|0;if((B&65535)>>>0>(K&65535)>>>0){N=1}else{N=(B<<16>>16!=K<<16>>16)<<31>>31}K=(B&65535)+(c[i+120+(m*20|0)+(d[483112+(N+M)|0]<<2)>>2]|0)|0;if(K>>>0<512>>>0){O=K&65535}else{O=-K>>31&511}b[l+(x<<1)>>1]=O;A=A+1|0;}while((A|0)<(E|0))}A=u+1|0;if((A|0)<(k|0)){G=G+s|0;L=L+s|0;q=q+s|0;u=A}else{I=E;J=D;break}}}}while(0);D=(r|0)==3;if(p<<24>>24==0&D){P=(c[j>>2]|0)==0|0}else{P=0}do{if(!(n<<24>>24==0|g^1)){j=k-P|0;if((j|0)>0){Q=0}else{break}do{E=ba(Q+t|0,s)|0;b[l+(E<<1)>>1]=b[f+(E<<1)>>1]|0;Q=Q+1|0;}while((Q|0)<(j|0))}}while(0);do{if(!(o<<24>>24==0|(r|0)==0)){Q=P+J|0;if((Q|0)<(I|0)){R=Q}else{break}do{Q=R-s|0;b[l+(Q<<1)>>1]=b[f+(Q<<1)>>1]|0;R=R+1|0;}while((R|0)<(I|0))}}while(0);if(!(p<<24>>24!=0&D)){return}D=-s|0;b[l+(D<<1)>>1]=b[f+(D<<1)>>1]|0;return}function wCa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=f;q=g;r=(m|0)!=0|0;s=i+120+(m*20|0)|0;t=c[i+108+(m<<2)>>2]|0;u=h>>>1;h=8>>>(r>>>0);v=-2-h|0;w=h+2|0;h=(c[j+12>>2]|0)==0;if(h){x=l-2-(4>>>(r>>>0))|0}else{x=l}l=(t|0)!=0;do{if(l){do{if((c[j+4>>2]|0)==0){y=0}else{r=c[s>>2]|0;if((w|0)>0){z=0}else{y=1;break}while(1){A=z+v|0;B=(e[q+(A<<1)>>1]|0)+r|0;if(B>>>0<512>>>0){C=B&65535}else{C=-B>>31&511}b[k+(A<<1)>>1]=C;A=z+1|0;if((A|0)<(w|0)){z=A}else{y=1;break}}}}while(0);if(h){D=y;E=x;break}r=c[s>>2]|0;A=x-1|0;if((w|0)<=0){D=y;E=A;break}B=(ba(A,u)|0)+v|0;F=0;while(1){G=B+F|0;H=(e[q+(G<<1)>>1]|0)+r|0;if(H>>>0<512>>>0){I=H&65535}else{I=-H>>31&511}b[k+(G<<1)>>1]=I;G=F+1|0;if((G|0)<(w|0)){F=G}else{D=y;E=A;break}}}else{D=0;E=x}}while(0);if((D|0)<(E|0)){x=(w|0)>0;y=(a[483096+(t<<2)|0]|0)+v|0;I=(a[483098+(t<<2)|0]|0)+v|0;s=ba(D,u)|0;h=ba((a[483097+(t<<2)|0]|0)+D|0,u)|0;z=ba((a[483099+(t<<2)|0]|0)+D|0,u)|0;C=D;while(1){if(x){A=s+v|0;F=y+h|0;r=I+z|0;B=0;do{G=A+B|0;H=b[q+(G<<1)>>1]|0;J=b[q+(F+B<<1)>>1]|0;if((H&65535)>>>0>(J&65535)>>>0){K=3}else{K=((H<<16>>16!=J<<16>>16)<<31>>31)+2|0}J=b[q+(r+B<<1)>>1]|0;if((H&65535)>>>0>(J&65535)>>>0){L=1}else{L=(H<<16>>16!=J<<16>>16)<<31>>31}J=(H&65535)+(c[i+120+(m*20|0)+(d[483112+(L+K)|0]<<2)>>2]|0)|0;if(J>>>0<512>>>0){M=J&65535}else{M=-J>>31&511}b[k+(G<<1)>>1]=M;B=B+1|0;}while((B|0)<(w|0))}B=C+1|0;if((B|0)<(E|0)){s=s+u|0;h=h+u|0;z=z+u|0;C=B}else{break}}}C=(t|0)==3;if(p<<24>>24==0&C){N=(c[j+4>>2]|0)==0|0}else{N=0}do{if(!(n<<24>>24==0|(t|0)==1)){j=N+D|0;if((j|0)<(E|0)){O=j}else{break}do{j=(ba(O,u)|0)-1|0;b[k+(j<<1)>>1]=b[q+(j<<1)>>1]|0;O=O+1|0;}while((O|0)<(E|0))}}while(0);do{if(!(o<<24>>24==0|l^1)){E=w-N|0;if((E|0)>0){P=0}else{break}do{O=P+v|0;b[k+(O<<1)>>1]=b[q+(O<<1)>>1]|0;P=P+1|0;}while((P|0)<(E|0))}}while(0);if(!(p<<24>>24!=0&C)){return}b[f-2>>1]=b[g-2>>1]|0;return}function xCa(e,f,g,h,i,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;k=e;e=f;f=(l|0)!=0|0;j=c[h+108+(l<<2)>>2]|0;i=g>>>1;g=4>>>(f>>>0);p=8>>>(f>>>0);f=p+2|0;q=g+2|0;r=ba(-2-g|0,i)|0;s=r+(-2-p)|0;if((q|0)>0){t=(f|0)>0;u=(a[483096+(j<<2)|0]|0)+s|0;v=(a[483098+(j<<2)|0]|0)+s|0;w=0;x=ba(a[483097+(j<<2)|0]|0,i)|0;y=ba(a[483099+(j<<2)|0]|0,i)|0;z=0;while(1){if(t){A=w+s|0;B=u+x|0;C=v+y|0;D=0;do{E=A+D|0;F=b[e+(E<<1)>>1]|0;G=b[e+(B+D<<1)>>1]|0;if((F&65535)>>>0>(G&65535)>>>0){H=3}else{H=((F<<16>>16!=G<<16>>16)<<31>>31)+2|0}G=b[e+(C+D<<1)>>1]|0;if((F&65535)>>>0>(G&65535)>>>0){I=1}else{I=(F<<16>>16!=G<<16>>16)<<31>>31}G=(F&65535)+(c[h+120+(l*20|0)+(d[483112+(I+H)|0]<<2)>>2]|0)|0;if(G>>>0<512>>>0){J=G&65535}else{J=-G>>31&511}b[k+(E<<1)>>1]=J;D=D+1|0;}while((D|0)<(f|0))}D=z+1|0;if((D|0)<(q|0)){w=w+i|0;x=x+i|0;y=y+i|0;z=D}else{break}}}if(o<<24>>24==0){K=(j|0)==2|0}else{K=0}do{if(!(m<<24>>24==0|(j|0)==1)){z=q-K|0;if((z|0)<=0){break}y=r-1|0;x=0;do{w=y+(ba(x,i)|0)|0;b[k+(w<<1)>>1]=b[e+(w<<1)>>1]|0;x=x+1|0;}while((x|0)<(z|0))}}while(0);do{if(!(n<<24>>24==0|(j|0)==0)){r=f-K|0;if((r|0)<=0){break}q=s+(ba(g+1|0,i)|0)|0;m=0;do{z=q+m|0;b[k+(z<<1)>>1]=b[e+(z<<1)>>1]|0;m=m+1|0;}while((m|0)<(r|0))}}while(0);if(!(o<<24>>24!=0&(j|0)==2)){return}j=p+1+(ba(g+1|0,i)|0)+s|0;b[k+(j<<1)>>1]=b[e+(j<<1)>>1]|0;return}function yCa(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;h=e>>>1;if((g|0)>0&(f|0)>0){i=0;j=d;k=a}else{return}while(1){a=0;do{b[k+(a<<1)>>1]=b[j+(a<<1)>>1]<<5;a=a+1|0;}while((a|0)<(f|0));a=i+1|0;if((a|0)<(g|0)){i=a;j=j+(h<<1)|0;k=k+(c<<1)|0}else{break}}return}function zCa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)>0&(g|0)>0){j=0;k=d;l=a}else{return}while(1){a=0;while(1){d=a+1|0;b[l+(a<<1)>>1]=(((e[k+(a-2<<1)>>1]|0)<<2)-(e[k+(a-3<<1)>>1]|0)+((e[k+(a-1<<1)>>1]|0)*-10|0)+((e[k+(a<<1)>>1]|0)*58|0)+((e[k+(d<<1)>>1]|0)*17|0)+((e[k+(a+2<<1)>>1]|0)*-5|0)+(e[k+(a+3<<1)>>1]|0)|0)>>>1;if((d|0)<(g|0)){a=d}else{break}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;l=l+(c<<1)|0}else{break}}return}function ACa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-2<<1)>>1]|0)<<2)-(e[k+(a-3<<1)>>1]|0)+((e[k+(a+3<<1)>>1]|0)<<2)-(e[k+(a+4<<1)>>1]|0)+(((e[k+(l<<1)>>1]|0)+(e[k+(a<<1)>>1]|0)|0)*40|0)+(((e[k+(a+2<<1)>>1]|0)+(e[k+(a-1<<1)>>1]|0)|0)*-11|0)|0)>>>1;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function BCa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-1<<1)>>1]|0)*-5|0)+(e[k+(a-2<<1)>>1]|0)+((e[k+(a<<1)>>1]|0)*17|0)+((e[k+(l<<1)>>1]|0)*58|0)+((e[k+(a+2<<1)>>1]|0)*-10|0)+((e[k+(a+3<<1)>>1]|0)<<2)-(e[k+(a+4<<1)>>1]|0)|0)>>>1;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function CCa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i*3|0;k=i<<1;l=0;m=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[m+(a-k<<1)>>1]|0)<<2)-(e[m+(a-j<<1)>>1]|0)+((e[m+(a-i<<1)>>1]|0)*-10|0)+((e[m+(a<<1)>>1]|0)*58|0)+((e[m+(a+i<<1)>>1]|0)*17|0)+((e[m+(a+k<<1)>>1]|0)*-5|0)+(e[m+(a+j<<1)>>1]|0)|0)>>>1;a=a+1|0;}while((a|0)<(g|0))}a=l+1|0;if((a|0)<(h|0)){l=a;m=m+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function DCa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206633]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206617]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206617]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function ECa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206633]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206617]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>1;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206617]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function FCa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206633]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206617]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206617]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function GCa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i*3|0;k=i<<1;l=i<<2;m=0;n=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[n+(a-k<<1)>>1]|0)<<2)-(e[n+(a-j<<1)>>1]|0)+((e[n+(a+j<<1)>>1]|0)<<2)-(e[n+(a+l<<1)>>1]|0)+(((e[n+(a+i<<1)>>1]|0)+(e[n+(a<<1)>>1]|0)|0)*40|0)+(((e[n+(a+k<<1)>>1]|0)+(e[n+(a-i<<1)>>1]|0)|0)*-11|0)|0)>>>1;a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function HCa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206634]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206618]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206618]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function ICa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206634]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206618]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>1;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206618]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function JCa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206634]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206618]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206618]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function KCa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i<<1;k=i*3|0;l=i<<2;m=0;n=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[n+(a-i<<1)>>1]|0)*-5|0)+(e[n+(a-j<<1)>>1]|0)+((e[n+(a<<1)>>1]|0)*17|0)+((e[n+(a+i<<1)>>1]|0)*58|0)+((e[n+(a+j<<1)>>1]|0)*-10|0)+((e[n+(a+k<<1)>>1]|0)<<2)-(e[n+(a+l<<1)>>1]|0)|0)>>>1;a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function LCa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206635]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206619]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206619]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function MCa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206635]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206619]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>1;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206619]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function NCa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206635]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206619]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206619]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function OCa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;j=e>>>1;if((g|0)<=0){return}e=(f|0)>0;i=0;h=d;d=a;while(1){if(e){a=0;do{b[d+(a<<1)>>1]=b[h+(a<<1)>>1]<<5;a=a+1|0;}while((a|0)<(f|0))}a=i+1|0;if((a|0)<(g|0)){i=a;h=h+(j<<1)|0;d=d+(c<<1)|0}else{break}}return}function PCa(c,d,f,g,h,i,j,k,l){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>>1;g=j-1|0;if((i|0)<=0){return}j=(h|0)>0;k=a[1206920+(g<<4)|0]|0;m=a[1206921+(g<<4)|0]|0;n=a[1206922+(g<<4)|0]|0;o=a[1206923+(g<<4)|0]|0;g=f;f=0;p=c;while(1){if(j){c=0;while(1){q=ba(e[g+(c-1<<1)>>1]|0,k)|0;r=(ba(e[g+(c<<1)>>1]|0,m)|0)+q|0;q=c+1|0;s=r+(ba(e[g+(q<<1)>>1]|0,n)|0)|0;b[p+(c<<1)>>1]=(s+(ba(e[g+(c+2<<1)>>1]|0,o)|0)|0)>>>1;if((q|0)<(h|0)){c=q}else{break}}}c=f+1|0;if((c|0)<(i|0)){g=g+(l<<1)|0;f=c;p=p+(d<<1)|0}else{break}}return}function QCa(c,d,f,g,h,i,j,k,l){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>>1;g=k-1|0;if((i|0)<=0){return}k=(h|0)>0;j=a[1206920+(g<<4)|0]|0;m=a[1206921+(g<<4)|0]|0;n=a[1206922+(g<<4)|0]|0;o=a[1206923+(g<<4)|0]|0;g=l<<1;p=f;f=0;q=c;while(1){if(k){c=0;do{r=ba(e[p+(c-l<<1)>>1]|0,j)|0;s=(ba(e[p+(c<<1)>>1]|0,m)|0)+r|0;r=s+(ba(e[p+(c+l<<1)>>1]|0,n)|0)|0;b[q+(c<<1)>>1]=(r+(ba(e[p+(c+g<<1)>>1]|0,o)|0)|0)>>>1;c=c+1|0;}while((c|0)<(h|0))}c=f+1|0;if((c|0)<(i|0)){p=p+(l<<1)|0;f=c;q=q+(d<<1)|0}else{break}}return}function RCa(c,d,e,f,g,h,j,k,l){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=i;i=i+8576|0;m=l|0;n=f>>>1;f=j-1|0;j=k-1|0;k=1206920+(j<<4)|0;o=h+3|0;if((o|0)>0){p=(g|0)>0;q=a[1206920+(f<<4)|0]|0;r=a[1206921+(f<<4)|0]|0;s=a[1206922+(f<<4)|0]|0;t=a[1206923+(f<<4)|0]|0;f=e+(-n<<1)|0;e=0;u=m|0;while(1){if(p){v=0;w=b[f-2>>1]|0;x=b[f>>1]|0;y=b[f+2>>1]|0;while(1){z=v+1|0;A=(ba(x&65535,r)|0)+(ba(w&65535,q)|0)+(ba(y&65535,s)|0)|0;B=b[f+(v+2<<1)>>1]|0;b[u+(v<<1)>>1]=(A+(ba(B&65535,t)|0)|0)>>>1;if((z|0)<(g|0)){v=z;w=x;x=y;y=B}else{break}}}y=e+1|0;if((y|0)<(o|0)){f=f+(n<<1)|0;e=y;u=u+128|0}else{break}}}if((h|0)<=0){i=l;return}u=(g|0)>0;e=a[k]|0;k=a[1206921+(j<<4)|0]|0;n=a[1206922+(j<<4)|0]|0;f=a[1206923+(j<<4)|0]|0;j=0;o=c;c=m+128|0;while(1){if(u){m=0;do{t=ba(b[c+(m-64<<1)>>1]|0,e)|0;s=(ba(b[c+(m<<1)>>1]|0,k)|0)+t|0;t=s+(ba(b[c+(m+64<<1)>>1]|0,n)|0)|0;b[o+(m<<1)>>1]=(t+(ba(b[c+(m+128<<1)>>1]|0,f)|0)|0)>>>6;m=m+1|0;}while((m|0)<(g|0))}m=j+1|0;if((m|0)<(h|0)){j=m;o=o+(d<<1)|0;c=c+128|0}else{break}}i=l;return}function SCa(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c>>>1;if((g|0)<=0){return}c=(f|0)>0;i=a;a=0;j=d;while(1){if(c){d=0;do{k=(b[j+(d<<1)>>1]|0)+16>>5;if(k>>>0<512>>>0){l=k&65535}else{l=-k>>31&511}b[i+(d<<1)>>1]=l;d=d+1|0;}while((d|0)<(f|0))}d=a+1|0;if((d|0)<(g|0)){i=i+(h<<1)|0;a=d;j=j+(e<<1)|0}else{break}}return}function TCa(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=c>>>1;if((h|0)<=0){return}c=(g|0)>0;j=0;k=a;a=e;e=d;while(1){if(c){d=0;do{l=(b[e+(d<<1)>>1]|0)+32+(b[a+(d<<1)>>1]|0)>>6;if(l>>>0<512>>>0){m=l&65535}else{m=-l>>31&511}b[k+(d<<1)>>1]=m;d=d+1|0;}while((d|0)<(g|0))}d=j+1|0;if((d|0)<(h|0)){j=d;k=k+(i<<1)|0;a=a+(f<<1)|0;e=e+(f<<1)|0}else{break}}return}function UCa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=f>>>1;f=a&255;a=f+5|0;l=1<<f+4;f=c<<16>>16;c=d<<16>>16<<1;if((j|0)<=0){return}d=(i|0)>0;m=0;n=e;e=g;while(1){if(d){g=0;do{o=((ba(b[e+(g<<1)>>1]|0,f)|0)+l>>a)+c|0;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[n+(g<<1)>>1]=p;g=g+1|0;}while((g|0)<(i|0))}g=m+1|0;if((g|0)<(j|0)){m=g;n=n+(k<<1)|0;e=e+(h<<1)|0}else{break}}return}function VCa(a,c,d,e,f,g,h,i,j,k,l,m){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0;n=h>>>1;h=a&255;a=c<<16>>16;c=d<<16>>16;if((m|0)<=0){return}d=(l|0)>0;o=((f<<16>>16)+(e<<16>>16)<<1|1)<<h+5;e=h+6|0;h=j;j=0;f=g;g=i;while(1){if(d){i=0;do{p=ba(b[g+(i<<1)>>1]|0,a)|0;q=p+o+(ba(b[h+(i<<1)>>1]|0,c)|0)>>e;if(q>>>0<512>>>0){r=q&65535}else{r=-q>>31&511}b[f+(i<<1)>>1]=r;i=i+1|0;}while((i|0)<(l|0))}i=j+1|0;if((i|0)<(m|0)){h=h+(k<<1)|0;j=i;f=f+(n<<1)|0;g=g+(k<<1)|0}else{break}}return}function WCa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;TEa(a,b,2,c,d,e,f);return}function XCa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;TEa(a,2,b,c,d,e,f);return}function YCa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;SEa(a,b,2,c,d,e);return}function ZCa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;SEa(a,2,b,c,d,e);return}function _Ca(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=e>>>1;if((f|0)<=0){return}e=g+8|0;j=g+16|0;k=g|0;g=32-h|0;l=10-h|0;m=0;n=a;while(1){a=c[j>>2]|0;o=c[k>>2]|0;p=0;q=c[e>>2]|0;do{r=o+(q>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)>>>(g>>>0);r=q+h|0;q=a>>>0>r>>>0?r:a;c[e>>2]=q;b[n+(p<<1)>>1]=s<<l;p=p+1|0;}while((p|0)<(f|0));p=m+1|0;if((p|0)<(f|0)){m=p;n=n+(i<<1)|0}else{break}}return}function $Ca(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d>>>1;d=c;c=0;g=a;while(1){a=(b[d>>1]|0)+(e[g>>1]|0)|0;if(a>>>0<1024>>>0){h=a&65535}else{h=-a>>31&1023}b[g>>1]=h;a=g+2|0;i=(b[d+2>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){j=i&65535}else{j=-i>>31&1023}b[a>>1]=j;a=g+4|0;i=(b[d+4>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){k=i&65535}else{k=-i>>31&1023}b[a>>1]=k;a=g+6|0;i=(b[d+6>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){l=i&65535}else{l=-i>>31&1023}b[a>>1]=l;a=c+1|0;if((a|0)<4){d=d+8|0;c=a;g=g+(f<<1)|0}else{break}}return}function aDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=d>>>1;d=c;c=0;g=a;while(1){a=(b[d>>1]|0)+(e[g>>1]|0)|0;if(a>>>0<1024>>>0){h=a&65535}else{h=-a>>31&1023}b[g>>1]=h;a=g+2|0;i=(b[d+2>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){j=i&65535}else{j=-i>>31&1023}b[a>>1]=j;a=g+4|0;i=(b[d+4>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){k=i&65535}else{k=-i>>31&1023}b[a>>1]=k;a=g+6|0;i=(b[d+6>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){l=i&65535}else{l=-i>>31&1023}b[a>>1]=l;a=g+8|0;i=(b[d+8>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){m=i&65535}else{m=-i>>31&1023}b[a>>1]=m;a=g+10|0;i=(b[d+10>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){n=i&65535}else{n=-i>>31&1023}b[a>>1]=n;a=g+12|0;i=(b[d+12>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){o=i&65535}else{o=-i>>31&1023}b[a>>1]=o;a=g+14|0;i=(b[d+14>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){p=i&65535}else{p=-i>>31&1023}b[a>>1]=p;a=c+1|0;if((a|0)<8){d=d+16|0;c=a;g=g+(f<<1)|0}else{break}}return}function bDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>>1;d=c;c=0;g=a;while(1){a=d;h=0;while(1){i=g+(h<<1)|0;j=(b[a>>1]|0)+(e[i>>1]|0)|0;if(j>>>0<1024>>>0){k=j&65535}else{k=-j>>31&1023}b[i>>1]=k;i=h+1|0;if((i|0)<16){a=a+2|0;h=i}else{break}}h=c+1|0;if((h|0)<16){d=d+32|0;c=h;g=g+(f<<1)|0}else{break}}return}function cDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>>1;d=c;c=0;g=a;while(1){a=d;h=0;while(1){i=g+(h<<1)|0;j=(b[a>>1]|0)+(e[i>>1]|0)|0;if(j>>>0<1024>>>0){k=j&65535}else{k=-j>>31&1023}b[i>>1]=k;i=h+1|0;if((i|0)<32){a=a+2|0;h=i}else{break}}h=c+1|0;if((h|0)<32){d=d+64|0;c=h;g=g+(f<<1)|0}else{break}}return}function dDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d>>>1;d=a;a=0;while(1){g=((b[c+(a<<1)>>1]|0)+4>>3)+(e[d>>1]|0)|0;if(g>>>0<1024>>>0){h=g&65535}else{h=-g>>31&1023}b[d>>1]=h;g=d+2|0;i=((b[c+((a|1)<<1)>>1]|0)+4>>3)+(e[g>>1]|0)|0;if(i>>>0<1024>>>0){j=i&65535}else{j=-i>>31&1023}b[g>>1]=j;g=d+4|0;i=((b[c+((a|2)<<1)>>1]|0)+4>>3)+(e[g>>1]|0)|0;if(i>>>0<1024>>>0){k=i&65535}else{k=-i>>31&1023}b[g>>1]=k;g=d+6|0;i=((b[c+((a|3)<<1)>>1]|0)+4>>3)+(e[g>>1]|0)|0;if(i>>>0<1024>>>0){l=i&65535}else{l=-i>>31&1023}b[g>>1]=l;g=a+4|0;if((g|0)<16){d=d+(f<<1)|0;a=g}else{break}}return}function eDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=a;a=c;g=0;while(1){h=b[a>>1]|0;i=a+16|0;j=b[i>>1]|0;k=j+h|0;l=a+24|0;m=b[l>>1]|0;n=m+j|0;o=h-m|0;p=a+8|0;q=(b[p>>1]|0)*74|0;r=((h-j+m|0)*74|0)+64|0;m=r>>7;if((m+32768|0)>>>0>65535>>>0){s=(r>>31^32767)&65535}else{s=m&65535}b[i>>1]=s;i=(k*29|0)+64+(n*55|0)+q|0;m=i>>7;if((m+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=m&65535}b[a>>1]=t;m=(n*-29|0)+64+(o*55|0)+q|0;n=m>>7;if((n+32768|0)>>>0>65535>>>0){u=(m>>31^32767)&65535}else{u=n&65535}b[p>>1]=u;p=(k*55|0)+64+(o*29|0)-q|0;q=p>>7;if((q+32768|0)>>>0>65535>>>0){v=(p>>31^32767)&65535}else{v=q&65535}b[l>>1]=v;l=g+1|0;if((l|0)<4){a=a+2|0;g=l}else{break}}g=d>>>1;d=f;f=0;a=c;while(1){c=b[a>>1]|0;v=b[a+4>>1]|0;u=v+c|0;t=b[a+6>>1]|0;s=t+v|0;l=c-t|0;q=(b[a+2>>1]|0)*74|0;p=d+4|0;o=((c-v+t|0)*74|0)+512|0;t=o>>10;if((t+32768|0)>>>0>65535>>>0){w=(o>>31^32767)&65535}else{w=t&65535}t=(w<<16>>16)+(e[p>>1]|0)|0;if(t>>>0<1024>>>0){x=t&65535}else{x=-t>>31&1023}b[p>>1]=x;p=(u*29|0)+512+(s*55|0)+q|0;t=p>>10;if((t+32768|0)>>>0>65535>>>0){y=(p>>31^32767)&65535}else{y=t&65535}t=(y<<16>>16)+(e[d>>1]|0)|0;if(t>>>0<1024>>>0){z=t&65535}else{z=-t>>31&1023}b[d>>1]=z;t=d+2|0;p=(s*-29|0)+512+(l*55|0)+q|0;s=p>>10;if((s+32768|0)>>>0>65535>>>0){A=(p>>31^32767)&65535}else{A=s&65535}s=(A<<16>>16)+(e[t>>1]|0)|0;if(s>>>0<1024>>>0){B=s&65535}else{B=-s>>31&1023}b[t>>1]=B;t=d+6|0;s=(u*55|0)+512+(l*29|0)-q|0;q=s>>10;if((q+32768|0)>>>0>65535>>>0){C=(s>>31^32767)&65535}else{C=q&65535}q=(C<<16>>16)+(e[t>>1]|0)|0;if(q>>>0<1024>>>0){D=q&65535}else{D=-q>>31&1023}b[t>>1]=D;t=f+1|0;if((t|0)<4){d=d+(g<<1)|0;f=t;a=a+8|0}else{break}}return}function fDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=a;a=c;g=0;while(1){h=b[a>>1]<<6;i=a+16|0;j=b[i>>1]|0;k=(j<<6)+h|0;l=(j*-64|0)+h|0;h=a+8|0;j=b[h>>1]|0;m=a+24|0;n=b[m>>1]|0;o=(n*36|0)+(j*83|0)|0;p=(n*-83|0)+(j*36|0)|0;j=k+64+o|0;n=j>>7;if((n+32768|0)>>>0>65535>>>0){q=(j>>31^32767)&65535}else{q=n&65535}b[a>>1]=q;n=l+64+p|0;j=n>>7;if((j+32768|0)>>>0>65535>>>0){r=(n>>31^32767)&65535}else{r=j&65535}b[h>>1]=r;h=l-p+64|0;p=h>>7;if((p+32768|0)>>>0>65535>>>0){s=(h>>31^32767)&65535}else{s=p&65535}b[i>>1]=s;i=k-o+64|0;o=i>>7;if((o+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=o&65535}b[m>>1]=t;m=g+1|0;if((m|0)<4){a=a+2|0;g=m}else{break}}g=d>>>1;d=f;f=0;a=c;while(1){c=b[a>>1]<<6;t=b[a+4>>1]|0;s=(t<<6)+c|0;r=(t*-64|0)+c|0;c=b[a+2>>1]|0;t=b[a+6>>1]|0;q=(t*36|0)+(c*83|0)|0;m=(t*-83|0)+(c*36|0)|0;c=s+512+q|0;t=c>>10;if((t+32768|0)>>>0>65535>>>0){u=(c>>31^32767)&65535}else{u=t&65535}t=(u<<16>>16)+(e[d>>1]|0)|0;if(t>>>0<1024>>>0){v=t&65535}else{v=-t>>31&1023}b[d>>1]=v;t=d+2|0;c=r+512+m|0;o=c>>10;if((o+32768|0)>>>0>65535>>>0){w=(c>>31^32767)&65535}else{w=o&65535}o=(w<<16>>16)+(e[t>>1]|0)|0;if(o>>>0<1024>>>0){x=o&65535}else{x=-o>>31&1023}b[t>>1]=x;t=d+4|0;o=r-m+512|0;m=o>>10;if((m+32768|0)>>>0>65535>>>0){y=(o>>31^32767)&65535}else{y=m&65535}m=(y<<16>>16)+(e[t>>1]|0)|0;if(m>>>0<1024>>>0){z=m&65535}else{z=-m>>31&1023}b[t>>1]=z;t=d+6|0;m=s-q+512|0;q=m>>10;if((q+32768|0)>>>0>65535>>>0){A=(m>>31^32767)&65535}else{A=q&65535}q=(A<<16>>16)+(e[t>>1]|0)|0;if(q>>>0<1024>>>0){B=q&65535}else{B=-q>>31&1023}b[t>>1]=B;t=f+1|0;if((t|0)<4){d=d+(g<<1)|0;f=t;a=a+8|0}else{break}}return}function gDa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+64|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=a;a=j;n=h|0;o=h+4|0;p=h+8|0;q=h+12|0;r=d;s=0;while(1){TGb(a|0,0,16)|0;t=r+16|0;u=r+48|0;v=r+80|0;w=r+112|0;x=((b[w>>1]|0)*18|0)+(((b[v>>1]|0)*50|0)+(((b[u>>1]|0)*75|0)+((b[t>>1]|0)*89|0)))|0;c[j>>2]=x;c[j+4>>2]=((b[w>>1]|0)*-50|0)+(((b[v>>1]|0)*-89|0)+(((b[u>>1]|0)*-18|0)+((b[t>>1]|0)*75|0)));c[j+8>>2]=((b[w>>1]|0)*75|0)+(((b[v>>1]|0)*18|0)+(((b[u>>1]|0)*-89|0)+((b[t>>1]|0)*50|0)));c[j+12>>2]=((b[w>>1]|0)*-89|0)+(((b[v>>1]|0)*75|0)+(((b[u>>1]|0)*-50|0)+((b[t>>1]|0)*18|0)));t=b[r>>1]<<6;u=b[r+64>>1]|0;v=(u<<6)+t|0;w=(u*-64|0)+t|0;t=b[r+32>>1]|0;u=b[r+96>>1]|0;y=(u*36|0)+(t*83|0)|0;z=(u*-83|0)+(t*36|0)|0;t=y+v|0;c[n>>2]=t;c[o>>2]=z+w;c[p>>2]=w-z;c[q>>2]=v-y;y=0;v=t;t=x;while(1){x=v+64+t|0;z=x>>7;if((z+32768|0)>>>0>65535>>>0){A=(x>>31^32767)&65535}else{A=z&65535}b[r+(y<<3<<1)>>1]=A;z=v-t+64|0;x=z>>7;if((x+32768|0)>>>0>65535>>>0){B=(z>>31^32767)&65535}else{B=x&65535}b[r+(7-y<<3<<1)>>1]=B;x=y+1|0;if((x|0)>=4){break}y=x;v=c[h+(x<<2)>>2]|0;t=c[j+(x<<2)>>2]|0}t=s+1|0;if((t|0)<8){r=r+2|0;s=t}else{break}}s=f>>>1;f=l;r=k|0;j=k+4|0;h=k+8|0;B=k+12|0;A=m;m=0;q=d;while(1){TGb(f|0,0,16)|0;d=q+2|0;p=q+6|0;o=q+10|0;n=q+14|0;a=((b[n>>1]|0)*18|0)+(((b[o>>1]|0)*50|0)+(((b[p>>1]|0)*75|0)+((b[d>>1]|0)*89|0)))|0;c[l>>2]=a;c[l+4>>2]=((b[n>>1]|0)*-50|0)+(((b[o>>1]|0)*-89|0)+(((b[p>>1]|0)*-18|0)+((b[d>>1]|0)*75|0)));c[l+8>>2]=((b[n>>1]|0)*75|0)+(((b[o>>1]|0)*18|0)+(((b[p>>1]|0)*-89|0)+((b[d>>1]|0)*50|0)));c[l+12>>2]=((b[n>>1]|0)*-89|0)+(((b[o>>1]|0)*75|0)+(((b[p>>1]|0)*-50|0)+((b[d>>1]|0)*18|0)));d=b[q>>1]<<6;p=b[q+8>>1]|0;o=(p<<6)+d|0;n=(p*-64|0)+d|0;d=b[q+4>>1]|0;p=b[q+12>>1]|0;t=(p*36|0)+(d*83|0)|0;v=(p*-83|0)+(d*36|0)|0;d=t+o|0;c[r>>2]=d;c[j>>2]=v+n;c[h>>2]=n-v;c[B>>2]=o-t;t=0;o=d;d=a;while(1){a=A+(t<<1)|0;v=o+512+d|0;n=v>>10;if((n+32768|0)>>>0>65535>>>0){C=(v>>31^32767)&65535}else{C=n&65535}n=(C<<16>>16)+(e[a>>1]|0)|0;if(n>>>0<1024>>>0){D=n&65535}else{D=-n>>31&1023}b[a>>1]=D;a=A+(7-t<<1)|0;n=o-d+512|0;v=n>>10;if((v+32768|0)>>>0>65535>>>0){E=(n>>31^32767)&65535}else{E=v&65535}v=(E<<16>>16)+(e[a>>1]|0)|0;if(v>>>0<1024>>>0){F=v&65535}else{F=-v>>31&1023}b[a>>1]=F;a=t+1|0;if((a|0)>=4){break}t=a;o=c[k+(a<<2)>>2]|0;d=c[l+(a<<2)>>2]|0}d=m+1|0;if((d|0)<8){A=A+(s<<1)|0;m=d;q=q+16|0}else{break}}i=g;return}function hDa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+128|0;j=h|0;k=h+32|0;l=h+64|0;m=h+96|0;n=d;d=k;o=f;p=0;while(1){TGb(d|0,0,32)|0;q=0;do{r=k+(q<<2)|0;s=(ba(b[o+32>>1]|0,a[184560+q|0]|0)|0)+(c[r>>2]|0)|0;t=(ba(b[o+96>>1]|0,a[184688+q|0]|0)|0)+s|0;s=(ba(b[o+160>>1]|0,a[184816+q|0]|0)|0)+t|0;t=(ba(b[o+224>>1]|0,a[184944+q|0]|0)|0)+s|0;s=(ba(b[o+288>>1]|0,a[185072+q|0]|0)|0)+t|0;t=(ba(b[o+352>>1]|0,a[185200+q|0]|0)|0)+s|0;s=(ba(b[o+416>>1]|0,a[185328+q|0]|0)|0)+t|0;c[r>>2]=(ba(b[o+480>>1]|0,a[185456+q|0]|0)|0)+s;q=q+1|0;}while((q|0)<8);q=o+64|0;s=o+192|0;r=o+320|0;t=o+448|0;u=((b[t>>1]|0)*18|0)+(((b[r>>1]|0)*50|0)+(((b[s>>1]|0)*75|0)+((b[q>>1]|0)*89|0)))|0;v=((b[t>>1]|0)*-50|0)+(((b[r>>1]|0)*-89|0)+(((b[s>>1]|0)*-18|0)+((b[q>>1]|0)*75|0)))|0;w=((b[t>>1]|0)*75|0)+(((b[r>>1]|0)*18|0)+(((b[s>>1]|0)*-89|0)+((b[q>>1]|0)*50|0)))|0;x=((b[t>>1]|0)*-89|0)+(((b[r>>1]|0)*75|0)+(((b[s>>1]|0)*-50|0)+((b[q>>1]|0)*18|0)))|0;q=b[o>>1]<<6;s=b[o+256>>1]|0;r=(s<<6)+q|0;t=(s*-64|0)+q|0;q=b[o+128>>1]|0;s=b[o+384>>1]|0;y=(s*36|0)+(q*83|0)|0;z=(s*-83|0)+(q*36|0)|0;q=y+r|0;s=z+t|0;A=t-z|0;z=r-y|0;y=u+q|0;c[j>>2]=y;c[j+28>>2]=q-u;c[j+4>>2]=v+s;c[j+24>>2]=s-v;c[j+8>>2]=w+A;c[j+20>>2]=A-w;c[j+12>>2]=x+z;c[j+16>>2]=z-x;x=0;z=y;while(1){y=c[k+(x<<2)>>2]|0;w=z+64+y|0;A=w>>7;if((A+32768|0)>>>0>65535>>>0){B=(w>>31^32767)&65535}else{B=A&65535}b[o+(x<<4<<1)>>1]=B;A=z-y+64|0;y=A>>7;if((y+32768|0)>>>0>65535>>>0){C=(A>>31^32767)&65535}else{C=y&65535}b[o+(15-x<<4<<1)>>1]=C;y=x+1|0;if((y|0)>=8){break}x=y;z=c[j+(y<<2)>>2]|0}z=p+1|0;if((z|0)<16){o=o+2|0;p=z}else{break}}p=g>>>1;g=m;o=n;n=0;j=f;while(1){TGb(g|0,0,32)|0;f=0;do{C=m+(f<<2)|0;B=(ba(b[j+2>>1]|0,a[184560+f|0]|0)|0)+(c[C>>2]|0)|0;k=(ba(b[j+6>>1]|0,a[184688+f|0]|0)|0)+B|0;B=(ba(b[j+10>>1]|0,a[184816+f|0]|0)|0)+k|0;k=(ba(b[j+14>>1]|0,a[184944+f|0]|0)|0)+B|0;B=(ba(b[j+18>>1]|0,a[185072+f|0]|0)|0)+k|0;k=(ba(b[j+22>>1]|0,a[185200+f|0]|0)|0)+B|0;B=(ba(b[j+26>>1]|0,a[185328+f|0]|0)|0)+k|0;c[C>>2]=(ba(b[j+30>>1]|0,a[185456+f|0]|0)|0)+B;f=f+1|0;}while((f|0)<8);f=j+4|0;B=j+12|0;C=j+20|0;k=j+28|0;d=((b[k>>1]|0)*18|0)+(((b[C>>1]|0)*50|0)+(((b[B>>1]|0)*75|0)+((b[f>>1]|0)*89|0)))|0;z=((b[k>>1]|0)*-50|0)+(((b[C>>1]|0)*-89|0)+(((b[B>>1]|0)*-18|0)+((b[f>>1]|0)*75|0)))|0;x=((b[k>>1]|0)*75|0)+(((b[C>>1]|0)*18|0)+(((b[B>>1]|0)*-89|0)+((b[f>>1]|0)*50|0)))|0;y=((b[k>>1]|0)*-89|0)+(((b[C>>1]|0)*75|0)+(((b[B>>1]|0)*-50|0)+((b[f>>1]|0)*18|0)))|0;f=b[j>>1]<<6;B=b[j+16>>1]|0;C=(B<<6)+f|0;k=(B*-64|0)+f|0;f=b[j+8>>1]|0;B=b[j+24>>1]|0;A=(B*36|0)+(f*83|0)|0;w=(B*-83|0)+(f*36|0)|0;f=A+C|0;B=w+k|0;v=k-w|0;w=C-A|0;A=d+f|0;c[l>>2]=A;c[l+28>>2]=f-d;c[l+4>>2]=z+B;c[l+24>>2]=B-z;c[l+8>>2]=x+v;c[l+20>>2]=v-x;c[l+12>>2]=y+w;c[l+16>>2]=w-y;y=0;w=A;while(1){A=o+(y<<1)|0;x=c[m+(y<<2)>>2]|0;v=w+512+x|0;z=v>>10;if((z+32768|0)>>>0>65535>>>0){D=(v>>31^32767)&65535}else{D=z&65535}z=(D<<16>>16)+(e[A>>1]|0)|0;if(z>>>0<1024>>>0){E=z&65535}else{E=-z>>31&1023}b[A>>1]=E;A=o+(15-y<<1)|0;z=w-x+512|0;x=z>>10;if((x+32768|0)>>>0>65535>>>0){F=(z>>31^32767)&65535}else{F=x&65535}x=(F<<16>>16)+(e[A>>1]|0)|0;if(x>>>0<1024>>>0){G=x&65535}else{G=-x>>31&1023}b[A>>1]=G;A=y+1|0;if((A|0)>=8){break}y=A;w=c[l+(A<<2)>>2]|0}w=n+1|0;if((w|0)<16){o=o+(p<<1)|0;n=w;j=j+32|0}else{break}}i=h;return}function iDa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+320|0;j=h|0;k=h+64|0;l=h+128|0;m=h+160|0;n=h+224|0;o=h+288|0;p=d;d=k;q=l;r=f;s=0;while(1){TGb(d|0,0,64)|0;t=0;do{u=k+(t<<2)|0;v=1;w=c[u>>2]|0;do{w=(ba(b[r+(v<<5<<1)>>1]|0,a[184496+(v<<5)+t|0]|0)|0)+w|0;v=v+2|0;}while((v|0)<32);c[u>>2]=w;t=t+1|0;}while((t|0)<16);TGb(q|0,0,32)|0;t=0;v=0;while(1){x=(ba(b[r+128>>1]|0,a[184560+t|0]|0)|0)+v|0;y=(ba(b[r+384>>1]|0,a[184688+t|0]|0)|0)+x|0;x=(ba(b[r+640>>1]|0,a[184816+t|0]|0)|0)+y|0;y=(ba(b[r+896>>1]|0,a[184944+t|0]|0)|0)+x|0;x=(ba(b[r+1152>>1]|0,a[185072+t|0]|0)|0)+y|0;y=(ba(b[r+1408>>1]|0,a[185200+t|0]|0)|0)+x|0;x=(ba(b[r+1664>>1]|0,a[185328+t|0]|0)|0)+y|0;c[l+(t<<2)>>2]=(ba(b[r+1920>>1]|0,a[185456+t|0]|0)|0)+x;x=t+1|0;if((x|0)>=8){break}t=x;v=c[l+(x<<2)>>2]|0}v=r+256|0;t=r+768|0;x=r+1280|0;y=r+1792|0;z=((b[y>>1]|0)*18|0)+(((b[x>>1]|0)*50|0)+(((b[t>>1]|0)*75|0)+((b[v>>1]|0)*89|0)))|0;A=((b[y>>1]|0)*-50|0)+(((b[x>>1]|0)*-89|0)+(((b[t>>1]|0)*-18|0)+((b[v>>1]|0)*75|0)))|0;B=((b[y>>1]|0)*75|0)+(((b[x>>1]|0)*18|0)+(((b[t>>1]|0)*-89|0)+((b[v>>1]|0)*50|0)))|0;C=((b[y>>1]|0)*-89|0)+(((b[x>>1]|0)*75|0)+(((b[t>>1]|0)*-50|0)+((b[v>>1]|0)*18|0)))|0;v=b[r>>1]<<6;t=b[r+1024>>1]|0;x=(t<<6)+v|0;y=(t*-64|0)+v|0;v=b[r+512>>1]|0;t=b[r+1536>>1]|0;D=(t*36|0)+(v*83|0)|0;E=(t*-83|0)+(v*36|0)|0;v=D+x|0;t=E+y|0;F=y-E|0;E=x-D|0;D=z+v|0;x=v-z|0;z=A+t|0;v=t-A|0;A=B+F|0;t=F-B|0;B=C+E|0;F=E-C|0;C=c[l>>2]|0;E=C+D|0;c[j>>2]=E;c[j+60>>2]=D-C;C=c[l+4>>2]|0;c[j+4>>2]=C+z;c[j+56>>2]=z-C;C=c[l+8>>2]|0;c[j+8>>2]=C+A;c[j+52>>2]=A-C;C=c[l+12>>2]|0;c[j+12>>2]=C+B;c[j+48>>2]=B-C;C=c[l+16>>2]|0;c[j+16>>2]=C+F;c[j+44>>2]=F-C;C=c[l+20>>2]|0;c[j+20>>2]=C+t;c[j+40>>2]=t-C;C=c[l+24>>2]|0;c[j+24>>2]=C+v;c[j+36>>2]=v-C;C=c[l+28>>2]|0;c[j+28>>2]=C+x;c[j+32>>2]=x-C;C=0;x=E;while(1){E=c[k+(C<<2)>>2]|0;v=x+64+E|0;t=v>>7;if((t+32768|0)>>>0>65535>>>0){G=(v>>31^32767)&65535}else{G=t&65535}b[r+(C<<5<<1)>>1]=G;t=x-E+64|0;E=t>>7;if((E+32768|0)>>>0>65535>>>0){H=(t>>31^32767)&65535}else{H=E&65535}b[r+(31-C<<5<<1)>>1]=H;E=C+1|0;if((E|0)>=16){break}C=E;x=c[j+(E<<2)>>2]|0}x=s+1|0;if((x|0)<32){r=r+2|0;s=x}else{break}}s=g>>>1;g=n;r=o;j=p;p=0;H=f;while(1){TGb(g|0,0,64)|0;f=0;do{G=n+(f<<2)|0;k=1;l=c[G>>2]|0;do{l=(ba(b[H+(k<<1)>>1]|0,a[184496+(k<<5)+f|0]|0)|0)+l|0;k=k+2|0;}while((k|0)<32);c[G>>2]=l;f=f+1|0;}while((f|0)<16);TGb(r|0,0,32)|0;f=0;k=0;while(1){w=(ba(b[H+4>>1]|0,a[184560+f|0]|0)|0)+k|0;u=(ba(b[H+12>>1]|0,a[184688+f|0]|0)|0)+w|0;w=(ba(b[H+20>>1]|0,a[184816+f|0]|0)|0)+u|0;u=(ba(b[H+28>>1]|0,a[184944+f|0]|0)|0)+w|0;w=(ba(b[H+36>>1]|0,a[185072+f|0]|0)|0)+u|0;u=(ba(b[H+44>>1]|0,a[185200+f|0]|0)|0)+w|0;w=(ba(b[H+52>>1]|0,a[185328+f|0]|0)|0)+u|0;c[o+(f<<2)>>2]=(ba(b[H+60>>1]|0,a[185456+f|0]|0)|0)+w;w=f+1|0;if((w|0)>=8){break}f=w;k=c[o+(w<<2)>>2]|0}k=H+8|0;f=H+24|0;w=H+40|0;u=H+56|0;q=((b[u>>1]|0)*18|0)+(((b[w>>1]|0)*50|0)+(((b[f>>1]|0)*75|0)+((b[k>>1]|0)*89|0)))|0;d=((b[u>>1]|0)*-50|0)+(((b[w>>1]|0)*-89|0)+(((b[f>>1]|0)*-18|0)+((b[k>>1]|0)*75|0)))|0;x=((b[u>>1]|0)*75|0)+(((b[w>>1]|0)*18|0)+(((b[f>>1]|0)*-89|0)+((b[k>>1]|0)*50|0)))|0;C=((b[u>>1]|0)*-89|0)+(((b[w>>1]|0)*75|0)+(((b[f>>1]|0)*-50|0)+((b[k>>1]|0)*18|0)))|0;k=b[H>>1]<<6;f=b[H+32>>1]|0;w=(f<<6)+k|0;u=(f*-64|0)+k|0;k=b[H+16>>1]|0;f=b[H+48>>1]|0;E=(f*36|0)+(k*83|0)|0;t=(f*-83|0)+(k*36|0)|0;k=E+w|0;f=t+u|0;v=u-t|0;t=w-E|0;E=q+k|0;w=k-q|0;q=d+f|0;k=f-d|0;d=x+v|0;f=v-x|0;x=C+t|0;v=t-C|0;C=c[o>>2]|0;t=C+E|0;c[m>>2]=t;c[m+60>>2]=E-C;C=c[o+4>>2]|0;c[m+4>>2]=C+q;c[m+56>>2]=q-C;C=c[o+8>>2]|0;c[m+8>>2]=C+d;c[m+52>>2]=d-C;C=c[o+12>>2]|0;c[m+12>>2]=C+x;c[m+48>>2]=x-C;C=c[o+16>>2]|0;c[m+16>>2]=C+v;c[m+44>>2]=v-C;C=c[o+20>>2]|0;c[m+20>>2]=C+f;c[m+40>>2]=f-C;C=c[o+24>>2]|0;c[m+24>>2]=C+k;c[m+36>>2]=k-C;C=c[o+28>>2]|0;c[m+28>>2]=C+w;c[m+32>>2]=w-C;C=0;w=t;while(1){t=j+(C<<1)|0;k=c[n+(C<<2)>>2]|0;f=w+512+k|0;v=f>>10;if((v+32768|0)>>>0>65535>>>0){I=(f>>31^32767)&65535}else{I=v&65535}v=(I<<16>>16)+(e[t>>1]|0)|0;if(v>>>0<1024>>>0){J=v&65535}else{J=-v>>31&1023}b[t>>1]=J;t=j+(31-C<<1)|0;v=w-k+512|0;k=v>>10;if((k+32768|0)>>>0>65535>>>0){K=(v>>31^32767)&65535}else{K=k&65535}k=(K<<16>>16)+(e[t>>1]|0)|0;if(k>>>0<1024>>>0){L=k&65535}else{L=-k>>31&1023}b[t>>1]=L;t=C+1|0;if((t|0)>=16){break}C=t;w=c[m+(t<<2)>>2]|0}w=p+1|0;if((w|0)<32){j=j+(s<<1)|0;p=w;H=H+64|0}else{break}}i=h;return}function jDa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;REa(a,b,c,d,e,f,g,h,0);return}function kDa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;REa(a,b,c,d,e,f,g,h,1);return}function lDa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;REa(a,b,c,d,e,f,g,h,2);return}function mDa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;REa(a,b,c,d,e,f,g,h,3);return}function nDa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;q=f;f=g;g=(m|0)!=0|0;r=i+120+(m*20|0)|0;s=c[i+108+(m<<2)>>2]|0;t=h>>>1;h=(c[j+8>>2]|0)==0;if(h){u=k-2-(8>>>(g>>>0))|0}else{u=k}k=(c[j+12>>2]|0)==0;if(k){v=l-2-(4>>>(g>>>0))|0}else{v=l}l=(s|0)!=1;if(l){do{if((c[j>>2]|0)==0){w=0}else{g=c[r>>2]|0;if((v|0)>0){x=0;y=0}else{w=1;break}while(1){z=(e[f+(x<<1)>>1]|0)+g|0;if(z>>>0<1024>>>0){A=z&65535}else{A=-z>>31&1023}b[q+(x<<1)>>1]=A;z=y+1|0;if((z|0)<(v|0)){x=x+t|0;y=z}else{w=1;break}}}}while(0);do{if(h){B=u}else{y=c[r>>2]|0;x=u-1|0;if((v|0)>0){C=x;D=0}else{B=x;break}while(1){A=(e[f+(C<<1)>>1]|0)+y|0;if(A>>>0<1024>>>0){E=A&65535}else{E=-A>>31&1023}b[q+(C<<1)>>1]=E;A=D+1|0;if((A|0)<(v|0)){C=C+t|0;D=A}else{B=x;break}}}}while(0);if((s|0)==0){F=0;G=v;H=B;I=w;J=1}else{K=B;L=w;M=17}}else{K=u;L=0;M=17}do{if((M|0)==17){do{if((c[j+4>>2]|0)==0){N=0}else{u=c[r>>2]|0;if((L|0)<(K|0)){O=L}else{N=1;break}while(1){w=(e[f+(O<<1)>>1]|0)+u|0;if(w>>>0<1024>>>0){P=w&65535}else{P=-w>>31&1023}b[q+(O<<1)>>1]=P;w=O+1|0;if((w|0)<(K|0)){O=w}else{N=1;break}}}}while(0);if(k){F=N;G=v;H=K;I=L;J=0;break}u=c[r>>2]|0;w=v-1|0;B=ba(w,t)|0;if((L|0)<(K|0)){Q=L}else{F=N;G=w;H=K;I=L;J=0;break}while(1){D=Q+B|0;C=(e[f+(D<<1)>>1]|0)+u|0;if(C>>>0<1024>>>0){R=C&65535}else{R=-C>>31&1023}b[q+(D<<1)>>1]=R;D=Q+1|0;if((D|0)<(K|0)){Q=D}else{F=N;G=w;H=K;I=L;J=0;break}}}}while(0);L=a[483096+(s<<2)|0]|0;K=a[483098+(s<<2)|0]|0;if((F|0)<(G|0)){N=(I|0)<(H|0);Q=ba(F,t)|0;R=ba((a[483097+(s<<2)|0]|0)+F|0,t)|0;v=ba((a[483099+(s<<2)|0]|0)+F|0,t)|0;r=F;while(1){if(N){k=R+L|0;O=v+K|0;P=I;do{M=P+Q|0;w=b[f+(M<<1)>>1]|0;u=b[f+(k+P<<1)>>1]|0;if((w&65535)>>>0>(u&65535)>>>0){S=3}else{S=((w<<16>>16!=u<<16>>16)<<31>>31)+2|0}u=b[f+(O+P<<1)>>1]|0;if((w&65535)>>>0>(u&65535)>>>0){T=1}else{T=(w<<16>>16!=u<<16>>16)<<31>>31}u=(w&65535)+(c[i+120+(m*20|0)+(d[483112+(T+S)|0]<<2)>>2]|0)|0;if(u>>>0<1024>>>0){U=u&65535}else{U=-u>>31&1023}b[q+(M<<1)>>1]=U;P=P+1|0;}while((P|0)<(H|0))}P=r+1|0;if((P|0)<(G|0)){Q=Q+t|0;R=R+t|0;v=v+t|0;r=P}else{break}}}r=(s|0)==2;do{if(p<<24>>24==0&r){if((c[j>>2]|0)!=0){V=0;break}V=(c[j+4>>2]|0)==0|0}else{V=0}}while(0);do{if(!(n<<24>>24==0|l^1)){j=V+F|0;if((j|0)<(G|0)){W=j}else{break}do{j=ba(W,t)|0;b[q+(j<<1)>>1]=b[f+(j<<1)>>1]|0;W=W+1|0;}while((W|0)<(G|0))}}while(0);do{if(!(o<<24>>24==0|J)){G=V+I|0;if((G|0)<(H|0)){X=G}else{break}do{b[q+(X<<1)>>1]=b[f+(X<<1)>>1]|0;X=X+1|0;}while((X|0)<(H|0))}}while(0);if(!(p<<24>>24!=0&r)){return}b[q>>1]=b[f>>1]|0;return}function oDa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;l=f;f=g;g=(m|0)!=0|0;q=i+120+(m*20|0)|0;r=c[i+108+(m<<2)>>2]|0;s=h>>>1;h=4>>>(g>>>0);t=-2-h|0;u=(c[j+8>>2]|0)==0;if(u){v=k-2-(8>>>(g>>>0))|0}else{v=k}k=h+2|0;h=ba(t,s)|0;g=(r|0)!=1;do{if(g){do{if((c[j>>2]|0)==0){w=0}else{x=c[q>>2]|0;if((k|0)>0){y=0;z=0}else{w=1;break}while(1){A=y+h|0;B=(e[f+(A<<1)>>1]|0)+x|0;if(B>>>0<1024>>>0){C=B&65535}else{C=-B>>31&1023}b[l+(A<<1)>>1]=C;A=z+1|0;if((A|0)<(k|0)){y=y+s|0;z=A}else{w=1;break}}}}while(0);if(u){D=w;E=v;F=14;break}x=c[q>>2]|0;A=v-1|0;if((k|0)>0){G=A;H=0}else{I=A;J=w;break}while(1){B=G+h|0;K=(e[f+(B<<1)>>1]|0)+x|0;if(K>>>0<1024>>>0){L=K&65535}else{L=-K>>31&1023}b[l+(B<<1)>>1]=L;B=H+1|0;if((B|0)<(k|0)){G=G+s|0;H=B}else{D=w;E=A;F=14;break}}}else{D=0;E=v;F=14}}while(0);do{if((F|0)==14){if((k|0)<=0){I=E;J=D;break}v=(D|0)<(E|0);w=(a[483096+(r<<2)|0]|0)+h|0;H=(a[483098+(r<<2)|0]|0)+h|0;G=0;L=ba(a[483097+(r<<2)|0]|0,s)|0;q=ba(a[483099+(r<<2)|0]|0,s)|0;u=0;while(1){if(v){z=G+h|0;y=w+L|0;C=H+q|0;A=D;do{x=z+A|0;B=b[f+(x<<1)>>1]|0;K=b[f+(y+A<<1)>>1]|0;if((B&65535)>>>0>(K&65535)>>>0){M=3}else{M=((B<<16>>16!=K<<16>>16)<<31>>31)+2|0}K=b[f+(C+A<<1)>>1]|0;if((B&65535)>>>0>(K&65535)>>>0){N=1}else{N=(B<<16>>16!=K<<16>>16)<<31>>31}K=(B&65535)+(c[i+120+(m*20|0)+(d[483112+(N+M)|0]<<2)>>2]|0)|0;if(K>>>0<1024>>>0){O=K&65535}else{O=-K>>31&1023}b[l+(x<<1)>>1]=O;A=A+1|0;}while((A|0)<(E|0))}A=u+1|0;if((A|0)<(k|0)){G=G+s|0;L=L+s|0;q=q+s|0;u=A}else{I=E;J=D;break}}}}while(0);D=(r|0)==3;if(p<<24>>24==0&D){P=(c[j>>2]|0)==0|0}else{P=0}do{if(!(n<<24>>24==0|g^1)){j=k-P|0;if((j|0)>0){Q=0}else{break}do{E=ba(Q+t|0,s)|0;b[l+(E<<1)>>1]=b[f+(E<<1)>>1]|0;Q=Q+1|0;}while((Q|0)<(j|0))}}while(0);do{if(!(o<<24>>24==0|(r|0)==0)){Q=P+J|0;if((Q|0)<(I|0)){R=Q}else{break}do{Q=R-s|0;b[l+(Q<<1)>>1]=b[f+(Q<<1)>>1]|0;R=R+1|0;}while((R|0)<(I|0))}}while(0);if(!(p<<24>>24!=0&D)){return}D=-s|0;b[l+(D<<1)>>1]=b[f+(D<<1)>>1]|0;return}function pDa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=f;q=g;r=(m|0)!=0|0;s=i+120+(m*20|0)|0;t=c[i+108+(m<<2)>>2]|0;u=h>>>1;h=8>>>(r>>>0);v=-2-h|0;w=h+2|0;h=(c[j+12>>2]|0)==0;if(h){x=l-2-(4>>>(r>>>0))|0}else{x=l}l=(t|0)!=0;do{if(l){do{if((c[j+4>>2]|0)==0){y=0}else{r=c[s>>2]|0;if((w|0)>0){z=0}else{y=1;break}while(1){A=z+v|0;B=(e[q+(A<<1)>>1]|0)+r|0;if(B>>>0<1024>>>0){C=B&65535}else{C=-B>>31&1023}b[k+(A<<1)>>1]=C;A=z+1|0;if((A|0)<(w|0)){z=A}else{y=1;break}}}}while(0);if(h){D=y;E=x;break}r=c[s>>2]|0;A=x-1|0;if((w|0)<=0){D=y;E=A;break}B=(ba(A,u)|0)+v|0;F=0;while(1){G=B+F|0;H=(e[q+(G<<1)>>1]|0)+r|0;if(H>>>0<1024>>>0){I=H&65535}else{I=-H>>31&1023}b[k+(G<<1)>>1]=I;G=F+1|0;if((G|0)<(w|0)){F=G}else{D=y;E=A;break}}}else{D=0;E=x}}while(0);if((D|0)<(E|0)){x=(w|0)>0;y=(a[483096+(t<<2)|0]|0)+v|0;I=(a[483098+(t<<2)|0]|0)+v|0;s=ba(D,u)|0;h=ba((a[483097+(t<<2)|0]|0)+D|0,u)|0;z=ba((a[483099+(t<<2)|0]|0)+D|0,u)|0;C=D;while(1){if(x){A=s+v|0;F=y+h|0;r=I+z|0;B=0;do{G=A+B|0;H=b[q+(G<<1)>>1]|0;J=b[q+(F+B<<1)>>1]|0;if((H&65535)>>>0>(J&65535)>>>0){K=3}else{K=((H<<16>>16!=J<<16>>16)<<31>>31)+2|0}J=b[q+(r+B<<1)>>1]|0;if((H&65535)>>>0>(J&65535)>>>0){L=1}else{L=(H<<16>>16!=J<<16>>16)<<31>>31}J=(H&65535)+(c[i+120+(m*20|0)+(d[483112+(L+K)|0]<<2)>>2]|0)|0;if(J>>>0<1024>>>0){M=J&65535}else{M=-J>>31&1023}b[k+(G<<1)>>1]=M;B=B+1|0;}while((B|0)<(w|0))}B=C+1|0;if((B|0)<(E|0)){s=s+u|0;h=h+u|0;z=z+u|0;C=B}else{break}}}C=(t|0)==3;if(p<<24>>24==0&C){N=(c[j+4>>2]|0)==0|0}else{N=0}do{if(!(n<<24>>24==0|(t|0)==1)){j=N+D|0;if((j|0)<(E|0)){O=j}else{break}do{j=(ba(O,u)|0)-1|0;b[k+(j<<1)>>1]=b[q+(j<<1)>>1]|0;O=O+1|0;}while((O|0)<(E|0))}}while(0);do{if(!(o<<24>>24==0|l^1)){E=w-N|0;if((E|0)>0){P=0}else{break}do{O=P+v|0;b[k+(O<<1)>>1]=b[q+(O<<1)>>1]|0;P=P+1|0;}while((P|0)<(E|0))}}while(0);if(!(p<<24>>24!=0&C)){return}b[f-2>>1]=b[g-2>>1]|0;return}function qDa(e,f,g,h,i,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;k=e;e=f;f=(l|0)!=0|0;j=c[h+108+(l<<2)>>2]|0;i=g>>>1;g=4>>>(f>>>0);p=8>>>(f>>>0);f=p+2|0;q=g+2|0;r=ba(-2-g|0,i)|0;s=r+(-2-p)|0;if((q|0)>0){t=(f|0)>0;u=(a[483096+(j<<2)|0]|0)+s|0;v=(a[483098+(j<<2)|0]|0)+s|0;w=0;x=ba(a[483097+(j<<2)|0]|0,i)|0;y=ba(a[483099+(j<<2)|0]|0,i)|0;z=0;while(1){if(t){A=w+s|0;B=u+x|0;C=v+y|0;D=0;do{E=A+D|0;F=b[e+(E<<1)>>1]|0;G=b[e+(B+D<<1)>>1]|0;if((F&65535)>>>0>(G&65535)>>>0){H=3}else{H=((F<<16>>16!=G<<16>>16)<<31>>31)+2|0}G=b[e+(C+D<<1)>>1]|0;if((F&65535)>>>0>(G&65535)>>>0){I=1}else{I=(F<<16>>16!=G<<16>>16)<<31>>31}G=(F&65535)+(c[h+120+(l*20|0)+(d[483112+(I+H)|0]<<2)>>2]|0)|0;if(G>>>0<1024>>>0){J=G&65535}else{J=-G>>31&1023}b[k+(E<<1)>>1]=J;D=D+1|0;}while((D|0)<(f|0))}D=z+1|0;if((D|0)<(q|0)){w=w+i|0;x=x+i|0;y=y+i|0;z=D}else{break}}}if(o<<24>>24==0){K=(j|0)==2|0}else{K=0}do{if(!(m<<24>>24==0|(j|0)==1)){z=q-K|0;if((z|0)<=0){break}y=r-1|0;x=0;do{w=y+(ba(x,i)|0)|0;b[k+(w<<1)>>1]=b[e+(w<<1)>>1]|0;x=x+1|0;}while((x|0)<(z|0))}}while(0);do{if(!(n<<24>>24==0|(j|0)==0)){r=f-K|0;if((r|0)<=0){break}q=s+(ba(g+1|0,i)|0)|0;m=0;do{z=q+m|0;b[k+(z<<1)>>1]=b[e+(z<<1)>>1]|0;m=m+1|0;}while((m|0)<(r|0))}}while(0);if(!(o<<24>>24!=0&(j|0)==2)){return}j=p+1+(ba(g+1|0,i)|0)+s|0;b[k+(j<<1)>>1]=b[e+(j<<1)>>1]|0;return}function rDa(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;h=e>>>1;if((g|0)<=0){return}e=(f|0)>0;i=0;j=d;d=a;while(1){if(e){a=0;do{b[d+(a<<1)>>1]=b[j+(a<<1)>>1]<<4;a=a+1|0;}while((a|0)<(f|0))}a=i+1|0;if((a|0)<(g|0)){i=a;j=j+(h<<1)|0;d=d+(c<<1)|0}else{break}}return}function sDa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-2<<1)>>1]|0)<<2)-(e[k+(a-3<<1)>>1]|0)+((e[k+(a-1<<1)>>1]|0)*-10|0)+((e[k+(a<<1)>>1]|0)*58|0)+((e[k+(l<<1)>>1]|0)*17|0)+((e[k+(a+2<<1)>>1]|0)*-5|0)+(e[k+(a+3<<1)>>1]|0)|0)>>>2;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function tDa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-2<<1)>>1]|0)<<2)-(e[k+(a-3<<1)>>1]|0)+((e[k+(a+3<<1)>>1]|0)<<2)-(e[k+(a+4<<1)>>1]|0)+(((e[k+(l<<1)>>1]|0)+(e[k+(a<<1)>>1]|0)|0)*40|0)+(((e[k+(a+2<<1)>>1]|0)+(e[k+(a-1<<1)>>1]|0)|0)*-11|0)|0)>>>2;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function uDa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-1<<1)>>1]|0)*-5|0)+(e[k+(a-2<<1)>>1]|0)+((e[k+(a<<1)>>1]|0)*17|0)+((e[k+(l<<1)>>1]|0)*58|0)+((e[k+(a+2<<1)>>1]|0)*-10|0)+((e[k+(a+3<<1)>>1]|0)<<2)-(e[k+(a+4<<1)>>1]|0)|0)>>>2;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function vDa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i*3|0;k=i<<1;l=0;m=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[m+(a-k<<1)>>1]|0)<<2)-(e[m+(a-j<<1)>>1]|0)+((e[m+(a-i<<1)>>1]|0)*-10|0)+((e[m+(a<<1)>>1]|0)*58|0)+((e[m+(a+i<<1)>>1]|0)*17|0)+((e[m+(a+k<<1)>>1]|0)*-5|0)+(e[m+(a+j<<1)>>1]|0)|0)>>>2;a=a+1|0;}while((a|0)<(g|0))}a=l+1|0;if((a|0)<(h|0)){l=a;m=m+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function wDa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206633]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206617]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206617]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function xDa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206633]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206617]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>2;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206617]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function yDa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206633]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206617]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206617]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function zDa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i*3|0;k=i<<1;l=i<<2;m=0;n=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[n+(a-k<<1)>>1]|0)<<2)-(e[n+(a-j<<1)>>1]|0)+((e[n+(a+j<<1)>>1]|0)<<2)-(e[n+(a+l<<1)>>1]|0)+(((e[n+(a+i<<1)>>1]|0)+(e[n+(a<<1)>>1]|0)|0)*40|0)+(((e[n+(a+k<<1)>>1]|0)+(e[n+(a-i<<1)>>1]|0)|0)*-11|0)|0)>>>2;a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function ADa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206634]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206618]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206618]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function BDa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206634]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206618]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>2;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206618]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function CDa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206634]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206618]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206618]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function DDa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i<<1;k=i*3|0;l=i<<2;m=0;n=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[n+(a-i<<1)>>1]|0)*-5|0)+(e[n+(a-j<<1)>>1]|0)+((e[n+(a<<1)>>1]|0)*17|0)+((e[n+(a+i<<1)>>1]|0)*58|0)+((e[n+(a+j<<1)>>1]|0)*-10|0)+((e[n+(a+k<<1)>>1]|0)<<2)-(e[n+(a+l<<1)>>1]|0)|0)>>>2;a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function EDa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206635]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206619]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206619]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function FDa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206635]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206619]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>2;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206619]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function GDa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1206635]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ba(d[1206619]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1206619]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function HDa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;j=e>>>1;if((g|0)<=0){return}e=(f|0)>0;i=0;h=d;d=a;while(1){if(e){a=0;do{b[d+(a<<1)>>1]=b[h+(a<<1)>>1]<<4;a=a+1|0;}while((a|0)<(f|0))}a=i+1|0;if((a|0)<(g|0)){i=a;h=h+(j<<1)|0;d=d+(c<<1)|0}else{break}}return}function IDa(c,d,f,g,h,i,j,k,l){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>>1;g=j-1|0;if((i|0)<=0){return}j=(h|0)>0;k=a[1206920+(g<<4)|0]|0;m=a[1206921+(g<<4)|0]|0;n=a[1206922+(g<<4)|0]|0;o=a[1206923+(g<<4)|0]|0;g=f;f=0;p=c;while(1){if(j){c=0;while(1){q=ba(e[g+(c-1<<1)>>1]|0,k)|0;r=(ba(e[g+(c<<1)>>1]|0,m)|0)+q|0;q=c+1|0;s=r+(ba(e[g+(q<<1)>>1]|0,n)|0)|0;b[p+(c<<1)>>1]=(s+(ba(e[g+(c+2<<1)>>1]|0,o)|0)|0)>>>2;if((q|0)<(h|0)){c=q}else{break}}}c=f+1|0;if((c|0)<(i|0)){g=g+(l<<1)|0;f=c;p=p+(d<<1)|0}else{break}}return}function JDa(c,d,f,g,h,i,j,k,l){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>>1;g=k-1|0;if((i|0)<=0){return}k=(h|0)>0;j=a[1206920+(g<<4)|0]|0;m=a[1206921+(g<<4)|0]|0;n=a[1206922+(g<<4)|0]|0;o=a[1206923+(g<<4)|0]|0;g=l<<1;p=f;f=0;q=c;while(1){if(k){c=0;do{r=ba(e[p+(c-l<<1)>>1]|0,j)|0;s=(ba(e[p+(c<<1)>>1]|0,m)|0)+r|0;r=s+(ba(e[p+(c+l<<1)>>1]|0,n)|0)|0;b[q+(c<<1)>>1]=(r+(ba(e[p+(c+g<<1)>>1]|0,o)|0)|0)>>>2;c=c+1|0;}while((c|0)<(h|0))}c=f+1|0;if((c|0)<(i|0)){p=p+(l<<1)|0;f=c;q=q+(d<<1)|0}else{break}}return}function KDa(c,d,e,f,g,h,j,k,l){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=i;i=i+8576|0;m=l|0;n=f>>>1;f=j-1|0;j=k-1|0;k=1206920+(j<<4)|0;o=h+3|0;if((o|0)>0){p=(g|0)>0;q=a[1206920+(f<<4)|0]|0;r=a[1206921+(f<<4)|0]|0;s=a[1206922+(f<<4)|0]|0;t=a[1206923+(f<<4)|0]|0;f=e+(-n<<1)|0;e=0;u=m|0;while(1){if(p){v=0;w=b[f-2>>1]|0;x=b[f>>1]|0;y=b[f+2>>1]|0;while(1){z=v+1|0;A=(ba(x&65535,r)|0)+(ba(w&65535,q)|0)+(ba(y&65535,s)|0)|0;B=b[f+(v+2<<1)>>1]|0;b[u+(v<<1)>>1]=(A+(ba(B&65535,t)|0)|0)>>>2;if((z|0)<(g|0)){v=z;w=x;x=y;y=B}else{break}}}y=e+1|0;if((y|0)<(o|0)){f=f+(n<<1)|0;e=y;u=u+128|0}else{break}}}if((h|0)<=0){i=l;return}u=(g|0)>0;e=a[k]|0;k=a[1206921+(j<<4)|0]|0;n=a[1206922+(j<<4)|0]|0;f=a[1206923+(j<<4)|0]|0;j=0;o=c;c=m+128|0;while(1){if(u){m=0;do{t=ba(b[c+(m-64<<1)>>1]|0,e)|0;s=(ba(b[c+(m<<1)>>1]|0,k)|0)+t|0;t=s+(ba(b[c+(m+64<<1)>>1]|0,n)|0)|0;b[o+(m<<1)>>1]=(t+(ba(b[c+(m+128<<1)>>1]|0,f)|0)|0)>>>6;m=m+1|0;}while((m|0)<(g|0))}m=j+1|0;if((m|0)<(h|0)){j=m;o=o+(d<<1)|0;c=c+128|0}else{break}}i=l;return}function LDa(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c>>>1;if((g|0)<=0){return}c=(f|0)>0;i=a;a=0;j=d;while(1){if(c){d=0;do{k=(b[j+(d<<1)>>1]|0)+8>>4;if(k>>>0<1024>>>0){l=k&65535}else{l=-k>>31&1023}b[i+(d<<1)>>1]=l;d=d+1|0;}while((d|0)<(f|0))}d=a+1|0;if((d|0)<(g|0)){i=i+(h<<1)|0;a=d;j=j+(e<<1)|0}else{break}}return}function MDa(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=c>>>1;if((h|0)<=0){return}c=(g|0)>0;j=0;k=a;a=e;e=d;while(1){if(c){d=0;do{l=(b[e+(d<<1)>>1]|0)+16+(b[a+(d<<1)>>1]|0)>>5;if(l>>>0<1024>>>0){m=l&65535}else{m=-l>>31&1023}b[k+(d<<1)>>1]=m;d=d+1|0;}while((d|0)<(g|0))}d=j+1|0;if((d|0)<(h|0)){j=d;k=k+(i<<1)|0;a=a+(f<<1)|0;e=e+(f<<1)|0}else{break}}return}function NDa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=f>>>1;f=a&255;a=f+4|0;l=1<<f+3;f=c<<16>>16;c=d<<16>>16<<2;if((j|0)<=0){return}d=(i|0)>0;m=0;n=e;e=g;while(1){if(d){g=0;do{o=((ba(b[e+(g<<1)>>1]|0,f)|0)+l>>a)+c|0;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[n+(g<<1)>>1]=p;g=g+1|0;}while((g|0)<(i|0))}g=m+1|0;if((g|0)<(j|0)){m=g;n=n+(k<<1)|0;e=e+(h<<1)|0}else{break}}return}function ODa(a,c,d,e,f,g,h,i,j,k,l,m){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0;n=h>>>1;h=a&255;a=c<<16>>16;c=d<<16>>16;if((m|0)<=0){return}d=(l|0)>0;o=((f<<16>>16)+(e<<16>>16)<<2|1)<<h+4;e=h+5|0;h=j;j=0;f=g;g=i;while(1){if(d){i=0;do{p=ba(b[g+(i<<1)>>1]|0,a)|0;q=p+o+(ba(b[h+(i<<1)>>1]|0,c)|0)>>e;if(q>>>0<1024>>>0){r=q&65535}else{r=-q>>31&1023}b[f+(i<<1)>>1]=r;i=i+1|0;}while((i|0)<(l|0))}i=j+1|0;if((i|0)<(m|0)){h=h+(k<<1)|0;j=i;f=f+(n<<1)|0;g=g+(k<<1)|0}else{break}}return}function PDa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;QEa(a,b,2,c,d,e,f);return}function QDa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;QEa(a,2,b,c,d,e,f);return}function RDa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;PEa(a,b,2,c,d,e);return}function SDa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;PEa(a,2,b,c,d,e);return}function TDa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((f|0)<=0){return}i=g+8|0;j=g+16|0;k=g|0;g=32-h|0;l=8-h|0;m=0;n=b;while(1){b=0;do{o=c[i>>2]|0;p=c[j>>2]|0;q=(c[k>>2]|0)+(o>>>3)|0;r=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(o&7)>>>(g>>>0);q=o+h|0;c[i>>2]=p>>>0>q>>>0?q:p;a[n+b|0]=r<<l;b=b+1|0;}while((b|0)<(f|0));b=m+1|0;if((b|0)<(f|0)){m=b;n=n+e|0}else{break}}return}function UDa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=e;e=0;h=c;while(1){c=(b[g>>1]|0)+(d[h]|0)|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(b[g+2>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(b[g+4>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(b[g+6>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=e+1|0;if((c|0)<4){g=g+8|0;e=c;h=h+f|0}else{break}}return}function VDa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=e;e=0;h=c;while(1){c=(b[g>>1]|0)+(d[h]|0)|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(b[g+2>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(b[g+4>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(b[g+6>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=h+4|0;j=(b[g+8>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[c]=n;c=h+5|0;j=(b[g+10>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[c]=o;c=h+6|0;j=(b[g+12>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[c]=p;c=h+7|0;j=(b[g+14>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[c]=q;c=e+1|0;if((c|0)<8){g=g+16|0;e=c;h=h+f|0}else{break}}return}function WDa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e;e=0;h=c;while(1){c=g;i=0;while(1){j=h+i|0;k=(b[c>>1]|0)+(d[j]|0)|0;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=l;j=i+1|0;if((j|0)<16){c=c+2|0;i=j}else{break}}i=e+1|0;if((i|0)<16){g=g+32|0;e=i;h=h+f|0}else{break}}return}function XDa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e;e=0;h=c;while(1){c=g;i=0;while(1){j=h+i|0;k=(b[c>>1]|0)+(d[j]|0)|0;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=l;j=i+1|0;if((j|0)<32){c=c+2|0;i=j}else{break}}i=e+1|0;if((i|0)<32){g=g+64|0;e=i;h=h+f|0}else{break}}return}function YDa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c;c=0;while(1){h=((b[e+(c<<1)>>1]|0)+16>>5)+(d[g]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[g]=i;h=g+1|0;j=((b[e+((c|1)<<1)>>1]|0)+16>>5)+(d[h]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=g+2|0;j=((b[e+((c|2)<<1)>>1]|0)+16>>5)+(d[h]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=g+3|0;j=((b[e+((c|3)<<1)>>1]|0)+16>>5)+(d[h]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=c+4|0;if((h|0)<16){g=g+f|0;c=h}else{break}}return}function ZDa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=e;h=0;while(1){i=b[g>>1]|0;j=g+16|0;k=b[j>>1]|0;l=k+i|0;m=g+24|0;n=b[m>>1]|0;o=n+k|0;p=i-n|0;q=g+8|0;r=(b[q>>1]|0)*74|0;s=((i-k+n|0)*74|0)+64|0;n=s>>7;if((n+32768|0)>>>0>65535>>>0){t=(s>>31^32767)&65535}else{t=n&65535}b[j>>1]=t;j=(l*29|0)+64+(o*55|0)+r|0;n=j>>7;if((n+32768|0)>>>0>65535>>>0){u=(j>>31^32767)&65535}else{u=n&65535}b[g>>1]=u;n=(o*-29|0)+64+(p*55|0)+r|0;o=n>>7;if((o+32768|0)>>>0>65535>>>0){v=(n>>31^32767)&65535}else{v=o&65535}b[q>>1]=v;q=(l*55|0)+64+(p*29|0)-r|0;r=q>>7;if((r+32768|0)>>>0>65535>>>0){w=(q>>31^32767)&65535}else{w=r&65535}b[m>>1]=w;m=h+1|0;if((m|0)<4){g=g+2|0;h=m}else{x=c;y=0;z=e;break}}while(1){e=b[z>>1]|0;c=b[z+4>>1]|0;h=c+e|0;g=b[z+6>>1]|0;w=g+c|0;v=e-g|0;u=(b[z+2>>1]|0)*74|0;t=x+2|0;m=((e-c+g|0)*74|0)+2048|0;g=m>>12;if((g+32768|0)>>>0>65535>>>0){A=(m>>31^32767)&65535}else{A=g&65535}g=(A<<16>>16)+(d[t]|0)|0;if(g>>>0>255>>>0){B=-g>>31&255}else{B=g&255}a[t]=B;t=(h*29|0)+2048+(w*55|0)+u|0;g=t>>12;if((g+32768|0)>>>0>65535>>>0){C=(t>>31^32767)&65535}else{C=g&65535}g=(C<<16>>16)+(d[x]|0)|0;if(g>>>0>255>>>0){D=-g>>31&255}else{D=g&255}a[x]=D;g=x+1|0;t=(w*-29|0)+2048+(v*55|0)+u|0;w=t>>12;if((w+32768|0)>>>0>65535>>>0){E=(t>>31^32767)&65535}else{E=w&65535}w=(E<<16>>16)+(d[g]|0)|0;if(w>>>0>255>>>0){F=-w>>31&255}else{F=w&255}a[g]=F;g=x+3|0;w=(h*55|0)+2048+(v*29|0)-u|0;u=w>>12;if((u+32768|0)>>>0>65535>>>0){G=(w>>31^32767)&65535}else{G=u&65535}u=(G<<16>>16)+(d[g]|0)|0;if(u>>>0>255>>>0){H=-u>>31&255}else{H=u&255}a[g]=H;g=y+1|0;if((g|0)<4){x=x+f|0;y=g;z=z+8|0}else{break}}return}function _Da(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=e;h=0;while(1){i=b[g>>1]<<6;j=g+16|0;k=b[j>>1]|0;l=(k<<6)+i|0;m=(k*-64|0)+i|0;i=g+8|0;k=b[i>>1]|0;n=g+24|0;o=b[n>>1]|0;p=(o*36|0)+(k*83|0)|0;q=(o*-83|0)+(k*36|0)|0;k=l+64+p|0;o=k>>7;if((o+32768|0)>>>0>65535>>>0){r=(k>>31^32767)&65535}else{r=o&65535}b[g>>1]=r;o=m+64+q|0;k=o>>7;if((k+32768|0)>>>0>65535>>>0){s=(o>>31^32767)&65535}else{s=k&65535}b[i>>1]=s;i=m-q+64|0;q=i>>7;if((q+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=q&65535}b[j>>1]=t;j=l-p+64|0;p=j>>7;if((p+32768|0)>>>0>65535>>>0){u=(j>>31^32767)&65535}else{u=p&65535}b[n>>1]=u;n=h+1|0;if((n|0)<4){g=g+2|0;h=n}else{v=c;w=0;x=e;break}}while(1){e=b[x>>1]<<6;c=b[x+4>>1]|0;h=(c<<6)+e|0;g=(c*-64|0)+e|0;e=b[x+2>>1]|0;c=b[x+6>>1]|0;u=(c*36|0)+(e*83|0)|0;t=(c*-83|0)+(e*36|0)|0;e=h+2048+u|0;c=e>>12;if((c+32768|0)>>>0>65535>>>0){y=(e>>31^32767)&65535}else{y=c&65535}c=(y<<16>>16)+(d[v]|0)|0;if(c>>>0>255>>>0){z=-c>>31&255}else{z=c&255}a[v]=z;c=v+1|0;e=g+2048+t|0;s=e>>12;if((s+32768|0)>>>0>65535>>>0){A=(e>>31^32767)&65535}else{A=s&65535}s=(A<<16>>16)+(d[c]|0)|0;if(s>>>0>255>>>0){B=-s>>31&255}else{B=s&255}a[c]=B;c=v+2|0;s=g-t+2048|0;t=s>>12;if((t+32768|0)>>>0>65535>>>0){C=(s>>31^32767)&65535}else{C=t&65535}t=(C<<16>>16)+(d[c]|0)|0;if(t>>>0>255>>>0){D=-t>>31&255}else{D=t&255}a[c]=D;c=v+3|0;t=h-u+2048|0;u=t>>12;if((u+32768|0)>>>0>65535>>>0){E=(t>>31^32767)&65535}else{E=u&65535}u=(E<<16>>16)+(d[c]|0)|0;if(u>>>0>255>>>0){F=-u>>31&255}else{F=u&255}a[c]=F;c=w+1|0;if((c|0)<4){v=v+f|0;w=c;x=x+8|0}else{break}}return}function $Da(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+64|0;j=h|0;k=h+16|0;l=h+32|0;m=h+48|0;n=k;o=j|0;p=j+4|0;q=j+8|0;r=j+12|0;s=f;t=0;while(1){TGb(n|0,0,16)|0;u=s+16|0;v=s+48|0;w=s+80|0;x=s+112|0;y=((b[x>>1]|0)*18|0)+(((b[w>>1]|0)*50|0)+(((b[v>>1]|0)*75|0)+((b[u>>1]|0)*89|0)))|0;c[k>>2]=y;c[k+4>>2]=((b[x>>1]|0)*-50|0)+(((b[w>>1]|0)*-89|0)+(((b[v>>1]|0)*-18|0)+((b[u>>1]|0)*75|0)));c[k+8>>2]=((b[x>>1]|0)*75|0)+(((b[w>>1]|0)*18|0)+(((b[v>>1]|0)*-89|0)+((b[u>>1]|0)*50|0)));c[k+12>>2]=((b[x>>1]|0)*-89|0)+(((b[w>>1]|0)*75|0)+(((b[v>>1]|0)*-50|0)+((b[u>>1]|0)*18|0)));u=b[s>>1]<<6;v=b[s+64>>1]|0;w=(v<<6)+u|0;x=(v*-64|0)+u|0;u=b[s+32>>1]|0;v=b[s+96>>1]|0;z=(v*36|0)+(u*83|0)|0;A=(v*-83|0)+(u*36|0)|0;u=z+w|0;c[o>>2]=u;c[p>>2]=A+x;c[q>>2]=x-A;c[r>>2]=w-z;z=0;w=u;u=y;while(1){y=w+64+u|0;A=y>>7;if((A+32768|0)>>>0>65535>>>0){B=(y>>31^32767)&65535}else{B=A&65535}b[s+(z<<3<<1)>>1]=B;A=w-u+64|0;y=A>>7;if((y+32768|0)>>>0>65535>>>0){C=(A>>31^32767)&65535}else{C=y&65535}b[s+(7-z<<3<<1)>>1]=C;y=z+1|0;if((y|0)>=4){break}z=y;w=c[j+(y<<2)>>2]|0;u=c[k+(y<<2)>>2]|0}u=t+1|0;if((u|0)<8){s=s+2|0;t=u}else{break}}t=m;s=l|0;k=l+4|0;j=l+8|0;C=l+12|0;B=e;e=0;r=f;while(1){TGb(t|0,0,16)|0;f=r+2|0;q=r+6|0;p=r+10|0;o=r+14|0;n=((b[o>>1]|0)*18|0)+(((b[p>>1]|0)*50|0)+(((b[q>>1]|0)*75|0)+((b[f>>1]|0)*89|0)))|0;c[m>>2]=n;c[m+4>>2]=((b[o>>1]|0)*-50|0)+(((b[p>>1]|0)*-89|0)+(((b[q>>1]|0)*-18|0)+((b[f>>1]|0)*75|0)));c[m+8>>2]=((b[o>>1]|0)*75|0)+(((b[p>>1]|0)*18|0)+(((b[q>>1]|0)*-89|0)+((b[f>>1]|0)*50|0)));c[m+12>>2]=((b[o>>1]|0)*-89|0)+(((b[p>>1]|0)*75|0)+(((b[q>>1]|0)*-50|0)+((b[f>>1]|0)*18|0)));f=b[r>>1]<<6;q=b[r+8>>1]|0;p=(q<<6)+f|0;o=(q*-64|0)+f|0;f=b[r+4>>1]|0;q=b[r+12>>1]|0;u=(q*36|0)+(f*83|0)|0;w=(q*-83|0)+(f*36|0)|0;f=u+p|0;c[s>>2]=f;c[k>>2]=w+o;c[j>>2]=o-w;c[C>>2]=p-u;u=0;p=f;f=n;while(1){n=B+u|0;w=p+2048+f|0;o=w>>12;if((o+32768|0)>>>0>65535>>>0){D=(w>>31^32767)&65535}else{D=o&65535}o=(D<<16>>16)+(d[n]|0)|0;if(o>>>0>255>>>0){E=-o>>31&255}else{E=o&255}a[n]=E;n=B+(7-u)|0;o=(c[l+(u<<2)>>2]|0)-(c[m+(u<<2)>>2]|0)+2048|0;w=o>>12;if((w+32768|0)>>>0>65535>>>0){F=(o>>31^32767)&65535}else{F=w&65535}w=(F<<16>>16)+(d[n]|0)|0;if(w>>>0>255>>>0){G=-w>>31&255}else{G=w&255}a[n]=G;n=u+1|0;if((n|0)>=4){break}u=n;p=c[l+(n<<2)>>2]|0;f=c[m+(n<<2)>>2]|0}f=e+1|0;if((f|0)<8){B=B+g|0;e=f;r=r+16|0}else{break}}i=h;return}function aEa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+128|0;j=h|0;k=h+32|0;l=h+64|0;m=h+96|0;n=k;o=f;p=0;while(1){TGb(n|0,0,32)|0;q=0;do{r=k+(q<<2)|0;s=(ba(b[o+32>>1]|0,a[184560+q|0]|0)|0)+(c[r>>2]|0)|0;t=(ba(b[o+96>>1]|0,a[184688+q|0]|0)|0)+s|0;s=(ba(b[o+160>>1]|0,a[184816+q|0]|0)|0)+t|0;t=(ba(b[o+224>>1]|0,a[184944+q|0]|0)|0)+s|0;s=(ba(b[o+288>>1]|0,a[185072+q|0]|0)|0)+t|0;t=(ba(b[o+352>>1]|0,a[185200+q|0]|0)|0)+s|0;s=(ba(b[o+416>>1]|0,a[185328+q|0]|0)|0)+t|0;c[r>>2]=(ba(b[o+480>>1]|0,a[185456+q|0]|0)|0)+s;q=q+1|0;}while((q|0)<8);q=o+64|0;s=o+192|0;r=o+320|0;t=o+448|0;u=((b[t>>1]|0)*18|0)+(((b[r>>1]|0)*50|0)+(((b[s>>1]|0)*75|0)+((b[q>>1]|0)*89|0)))|0;v=((b[t>>1]|0)*-50|0)+(((b[r>>1]|0)*-89|0)+(((b[s>>1]|0)*-18|0)+((b[q>>1]|0)*75|0)))|0;w=((b[t>>1]|0)*75|0)+(((b[r>>1]|0)*18|0)+(((b[s>>1]|0)*-89|0)+((b[q>>1]|0)*50|0)))|0;x=((b[t>>1]|0)*-89|0)+(((b[r>>1]|0)*75|0)+(((b[s>>1]|0)*-50|0)+((b[q>>1]|0)*18|0)))|0;q=b[o>>1]<<6;s=b[o+256>>1]|0;r=(s<<6)+q|0;t=(s*-64|0)+q|0;q=b[o+128>>1]|0;s=b[o+384>>1]|0;y=(s*36|0)+(q*83|0)|0;z=(s*-83|0)+(q*36|0)|0;q=y+r|0;s=z+t|0;A=t-z|0;z=r-y|0;y=u+q|0;c[j>>2]=y;c[j+28>>2]=q-u;c[j+4>>2]=v+s;c[j+24>>2]=s-v;c[j+8>>2]=w+A;c[j+20>>2]=A-w;c[j+12>>2]=x+z;c[j+16>>2]=z-x;x=0;z=y;while(1){y=c[k+(x<<2)>>2]|0;w=z+64+y|0;A=w>>7;if((A+32768|0)>>>0>65535>>>0){B=(w>>31^32767)&65535}else{B=A&65535}b[o+(x<<4<<1)>>1]=B;A=z-y+64|0;y=A>>7;if((y+32768|0)>>>0>65535>>>0){C=(A>>31^32767)&65535}else{C=y&65535}b[o+(15-x<<4<<1)>>1]=C;y=x+1|0;if((y|0)>=8){break}x=y;z=c[j+(y<<2)>>2]|0}z=p+1|0;if((z|0)<16){o=o+2|0;p=z}else{break}}p=m;o=e;e=0;j=f;while(1){TGb(p|0,0,32)|0;f=0;do{C=m+(f<<2)|0;B=(ba(b[j+2>>1]|0,a[184560+f|0]|0)|0)+(c[C>>2]|0)|0;k=(ba(b[j+6>>1]|0,a[184688+f|0]|0)|0)+B|0;B=(ba(b[j+10>>1]|0,a[184816+f|0]|0)|0)+k|0;k=(ba(b[j+14>>1]|0,a[184944+f|0]|0)|0)+B|0;B=(ba(b[j+18>>1]|0,a[185072+f|0]|0)|0)+k|0;k=(ba(b[j+22>>1]|0,a[185200+f|0]|0)|0)+B|0;B=(ba(b[j+26>>1]|0,a[185328+f|0]|0)|0)+k|0;c[C>>2]=(ba(b[j+30>>1]|0,a[185456+f|0]|0)|0)+B;f=f+1|0;}while((f|0)<8);f=j+4|0;B=j+12|0;C=j+20|0;k=j+28|0;n=((b[k>>1]|0)*18|0)+(((b[C>>1]|0)*50|0)+(((b[B>>1]|0)*75|0)+((b[f>>1]|0)*89|0)))|0;z=((b[k>>1]|0)*-50|0)+(((b[C>>1]|0)*-89|0)+(((b[B>>1]|0)*-18|0)+((b[f>>1]|0)*75|0)))|0;x=((b[k>>1]|0)*75|0)+(((b[C>>1]|0)*18|0)+(((b[B>>1]|0)*-89|0)+((b[f>>1]|0)*50|0)))|0;y=((b[k>>1]|0)*-89|0)+(((b[C>>1]|0)*75|0)+(((b[B>>1]|0)*-50|0)+((b[f>>1]|0)*18|0)))|0;f=b[j>>1]<<6;B=b[j+16>>1]|0;C=(B<<6)+f|0;k=(B*-64|0)+f|0;f=b[j+8>>1]|0;B=b[j+24>>1]|0;A=(B*36|0)+(f*83|0)|0;w=(B*-83|0)+(f*36|0)|0;f=A+C|0;B=w+k|0;v=k-w|0;w=C-A|0;A=n+f|0;c[l>>2]=A;c[l+28>>2]=f-n;c[l+4>>2]=z+B;c[l+24>>2]=B-z;c[l+8>>2]=x+v;c[l+20>>2]=v-x;c[l+12>>2]=y+w;c[l+16>>2]=w-y;y=0;w=A;while(1){A=o+y|0;x=m+(y<<2)|0;v=w+2048+(c[x>>2]|0)|0;z=v>>12;if((z+32768|0)>>>0>65535>>>0){D=(v>>31^32767)&65535}else{D=z&65535}z=(D<<16>>16)+(d[A]|0)|0;if(z>>>0>255>>>0){E=-z>>31&255}else{E=z&255}a[A]=E;A=o+(15-y)|0;z=(c[l+(y<<2)>>2]|0)-(c[x>>2]|0)+2048|0;x=z>>12;if((x+32768|0)>>>0>65535>>>0){F=(z>>31^32767)&65535}else{F=x&65535}x=(F<<16>>16)+(d[A]|0)|0;if(x>>>0>255>>>0){G=-x>>31&255}else{G=x&255}a[A]=G;A=y+1|0;if((A|0)>=8){break}y=A;w=c[l+(A<<2)>>2]|0}w=e+1|0;if((w|0)<16){o=o+g|0;e=w;j=j+32|0}else{break}}i=h;return}function bEa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+320|0;j=h|0;k=h+64|0;l=h+128|0;m=h+160|0;n=h+224|0;o=h+288|0;p=k;q=l;r=f;s=0;while(1){TGb(p|0,0,64)|0;t=0;do{u=k+(t<<2)|0;v=1;w=c[u>>2]|0;do{w=(ba(b[r+(v<<5<<1)>>1]|0,a[184496+(v<<5)+t|0]|0)|0)+w|0;v=v+2|0;}while((v|0)<32);c[u>>2]=w;t=t+1|0;}while((t|0)<16);TGb(q|0,0,32)|0;t=0;v=0;while(1){x=(ba(b[r+128>>1]|0,a[184560+t|0]|0)|0)+v|0;y=(ba(b[r+384>>1]|0,a[184688+t|0]|0)|0)+x|0;x=(ba(b[r+640>>1]|0,a[184816+t|0]|0)|0)+y|0;y=(ba(b[r+896>>1]|0,a[184944+t|0]|0)|0)+x|0;x=(ba(b[r+1152>>1]|0,a[185072+t|0]|0)|0)+y|0;y=(ba(b[r+1408>>1]|0,a[185200+t|0]|0)|0)+x|0;x=(ba(b[r+1664>>1]|0,a[185328+t|0]|0)|0)+y|0;c[l+(t<<2)>>2]=(ba(b[r+1920>>1]|0,a[185456+t|0]|0)|0)+x;x=t+1|0;if((x|0)>=8){break}t=x;v=c[l+(x<<2)>>2]|0}v=r+256|0;t=r+768|0;x=r+1280|0;y=r+1792|0;z=((b[y>>1]|0)*18|0)+(((b[x>>1]|0)*50|0)+(((b[t>>1]|0)*75|0)+((b[v>>1]|0)*89|0)))|0;A=((b[y>>1]|0)*-50|0)+(((b[x>>1]|0)*-89|0)+(((b[t>>1]|0)*-18|0)+((b[v>>1]|0)*75|0)))|0;B=((b[y>>1]|0)*75|0)+(((b[x>>1]|0)*18|0)+(((b[t>>1]|0)*-89|0)+((b[v>>1]|0)*50|0)))|0;C=((b[y>>1]|0)*-89|0)+(((b[x>>1]|0)*75|0)+(((b[t>>1]|0)*-50|0)+((b[v>>1]|0)*18|0)))|0;v=b[r>>1]<<6;t=b[r+1024>>1]|0;x=(t<<6)+v|0;y=(t*-64|0)+v|0;v=b[r+512>>1]|0;t=b[r+1536>>1]|0;D=(t*36|0)+(v*83|0)|0;E=(t*-83|0)+(v*36|0)|0;v=D+x|0;t=E+y|0;F=y-E|0;E=x-D|0;D=z+v|0;x=v-z|0;z=A+t|0;v=t-A|0;A=B+F|0;t=F-B|0;B=C+E|0;F=E-C|0;C=c[l>>2]|0;E=C+D|0;c[j>>2]=E;c[j+60>>2]=D-C;C=c[l+4>>2]|0;c[j+4>>2]=C+z;c[j+56>>2]=z-C;C=c[l+8>>2]|0;c[j+8>>2]=C+A;c[j+52>>2]=A-C;C=c[l+12>>2]|0;c[j+12>>2]=C+B;c[j+48>>2]=B-C;C=c[l+16>>2]|0;c[j+16>>2]=C+F;c[j+44>>2]=F-C;C=c[l+20>>2]|0;c[j+20>>2]=C+t;c[j+40>>2]=t-C;C=c[l+24>>2]|0;c[j+24>>2]=C+v;c[j+36>>2]=v-C;C=c[l+28>>2]|0;c[j+28>>2]=C+x;c[j+32>>2]=x-C;C=0;x=E;while(1){E=c[k+(C<<2)>>2]|0;v=x+64+E|0;t=v>>7;if((t+32768|0)>>>0>65535>>>0){G=(v>>31^32767)&65535}else{G=t&65535}b[r+(C<<5<<1)>>1]=G;t=x-E+64|0;E=t>>7;if((E+32768|0)>>>0>65535>>>0){H=(t>>31^32767)&65535}else{H=E&65535}b[r+(31-C<<5<<1)>>1]=H;E=C+1|0;if((E|0)>=16){break}C=E;x=c[j+(E<<2)>>2]|0}x=s+1|0;if((x|0)<32){r=r+2|0;s=x}else{break}}s=n;r=o;j=e;e=0;H=f;while(1){TGb(s|0,0,64)|0;f=0;do{G=n+(f<<2)|0;k=1;l=c[G>>2]|0;do{l=(ba(b[H+(k<<1)>>1]|0,a[184496+(k<<5)+f|0]|0)|0)+l|0;k=k+2|0;}while((k|0)<32);c[G>>2]=l;f=f+1|0;}while((f|0)<16);TGb(r|0,0,32)|0;f=0;k=0;while(1){w=(ba(b[H+4>>1]|0,a[184560+f|0]|0)|0)+k|0;u=(ba(b[H+12>>1]|0,a[184688+f|0]|0)|0)+w|0;w=(ba(b[H+20>>1]|0,a[184816+f|0]|0)|0)+u|0;u=(ba(b[H+28>>1]|0,a[184944+f|0]|0)|0)+w|0;w=(ba(b[H+36>>1]|0,a[185072+f|0]|0)|0)+u|0;u=(ba(b[H+44>>1]|0,a[185200+f|0]|0)|0)+w|0;w=(ba(b[H+52>>1]|0,a[185328+f|0]|0)|0)+u|0;c[o+(f<<2)>>2]=(ba(b[H+60>>1]|0,a[185456+f|0]|0)|0)+w;w=f+1|0;if((w|0)>=8){break}f=w;k=c[o+(w<<2)>>2]|0}k=H+8|0;f=H+24|0;w=H+40|0;u=H+56|0;q=((b[u>>1]|0)*18|0)+(((b[w>>1]|0)*50|0)+(((b[f>>1]|0)*75|0)+((b[k>>1]|0)*89|0)))|0;p=((b[u>>1]|0)*-50|0)+(((b[w>>1]|0)*-89|0)+(((b[f>>1]|0)*-18|0)+((b[k>>1]|0)*75|0)))|0;x=((b[u>>1]|0)*75|0)+(((b[w>>1]|0)*18|0)+(((b[f>>1]|0)*-89|0)+((b[k>>1]|0)*50|0)))|0;C=((b[u>>1]|0)*-89|0)+(((b[w>>1]|0)*75|0)+(((b[f>>1]|0)*-50|0)+((b[k>>1]|0)*18|0)))|0;k=b[H>>1]<<6;f=b[H+32>>1]|0;w=(f<<6)+k|0;u=(f*-64|0)+k|0;k=b[H+16>>1]|0;f=b[H+48>>1]|0;E=(f*36|0)+(k*83|0)|0;t=(f*-83|0)+(k*36|0)|0;k=E+w|0;f=t+u|0;v=u-t|0;t=w-E|0;E=q+k|0;w=k-q|0;q=p+f|0;k=f-p|0;p=x+v|0;f=v-x|0;x=C+t|0;v=t-C|0;C=c[o>>2]|0;t=C+E|0;c[m>>2]=t;c[m+60>>2]=E-C;C=c[o+4>>2]|0;c[m+4>>2]=C+q;c[m+56>>2]=q-C;C=c[o+8>>2]|0;c[m+8>>2]=C+p;c[m+52>>2]=p-C;C=c[o+12>>2]|0;c[m+12>>2]=C+x;c[m+48>>2]=x-C;C=c[o+16>>2]|0;c[m+16>>2]=C+v;c[m+44>>2]=v-C;C=c[o+20>>2]|0;c[m+20>>2]=C+f;c[m+40>>2]=f-C;C=c[o+24>>2]|0;c[m+24>>2]=C+k;c[m+36>>2]=k-C;C=c[o+28>>2]|0;c[m+28>>2]=C+w;c[m+32>>2]=w-C;C=0;w=t;while(1){t=j+C|0;k=n+(C<<2)|0;f=w+2048+(c[k>>2]|0)|0;v=f>>12;if((v+32768|0)>>>0>65535>>>0){I=(f>>31^32767)&65535}else{I=v&65535}v=(I<<16>>16)+(d[t]|0)|0;if(v>>>0>255>>>0){J=-v>>31&255}else{J=v&255}a[t]=J;t=j+(31-C)|0;v=(c[m+(C<<2)>>2]|0)-(c[k>>2]|0)+2048|0;k=v>>12;if((k+32768|0)>>>0>65535>>>0){K=(v>>31^32767)&65535}else{K=k&65535}k=(K<<16>>16)+(d[t]|0)|0;if(k>>>0>255>>>0){L=-k>>31&255}else{L=k&255}a[t]=L;t=C+1|0;if((t|0)>=16){break}C=t;w=c[m+(t<<2)>>2]|0}w=e+1|0;if((w|0)<32){j=j+g|0;e=w;H=H+64|0}else{break}}i=h;return}function cEa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;OEa(a,b,c,d,e,f,g,h,0);return}function dEa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;OEa(a,b,c,d,e,f,g,h,1);return}function eEa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;OEa(a,b,c,d,e,f,g,h,2);return}function fEa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;OEa(a,b,c,d,e,f,g,h,3);return}function gEa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;o=(k|0)!=0|0;p=g+120+(k*20|0)|0;q=c[g+108+(k<<2)>>2]|0;r=h+8|0;s=c[r>>2]|0;if((s|0)==0){t=i-2-(8>>>(o>>>0))|0}else{t=i}i=h+12|0;if((c[i>>2]|0)==0){u=j-2-(4>>>(o>>>0))|0}else{u=j}j=(q|0)!=1;if(j){do{if((c[h>>2]|0)==0){v=0;w=s}else{o=c[p>>2]|0;if((u|0)>0){x=0;y=0}else{v=1;w=s;break}while(1){z=(d[e+x|0]|0)+o|0;if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}a[b+x|0]=A;z=y+1|0;if((z|0)<(u|0)){x=x+f|0;y=z}else{break}}v=1;w=c[r>>2]|0}}while(0);do{if((w|0)==0){B=t}else{r=c[p>>2]|0;y=t-1|0;if((u|0)>0){C=y;D=0}else{B=y;break}while(1){x=(d[e+C|0]|0)+r|0;if(x>>>0>255>>>0){E=-x>>31&255}else{E=x&255}a[b+C|0]=E;x=D+1|0;if((x|0)<(u|0)){C=C+f|0;D=x}else{B=y;break}}}}while(0);if((q|0)==0){F=0;G=u;H=B;I=v;J=1}else{K=B;L=v;M=18}}else{K=t;L=0;M=18}do{if((M|0)==18){do{if((c[h+4>>2]|0)==0){N=0}else{t=c[p>>2]|0;if((L|0)<(K|0)){O=L}else{N=1;break}while(1){v=(d[e+O|0]|0)+t|0;if(v>>>0>255>>>0){P=-v>>31&255}else{P=v&255}a[b+O|0]=P;v=O+1|0;if((v|0)<(K|0)){O=v}else{N=1;break}}}}while(0);if((c[i>>2]|0)==0){F=N;G=u;H=K;I=L;J=0;break}t=c[p>>2]|0;v=u-1|0;B=ba(v,f)|0;if((L|0)<(K|0)){Q=L}else{F=N;G=v;H=K;I=L;J=0;break}while(1){D=Q+B|0;C=(d[e+D|0]|0)+t|0;if(C>>>0>255>>>0){R=-C>>31&255}else{R=C&255}a[b+D|0]=R;D=Q+1|0;if((D|0)<(K|0)){Q=D}else{F=N;G=v;H=K;I=L;J=0;break}}}}while(0);L=a[483096+(q<<2)|0]|0;K=a[483098+(q<<2)|0]|0;if((F|0)<(G|0)){N=(I|0)<(H|0);Q=ba(F,f)|0;R=ba((a[483097+(q<<2)|0]|0)+F|0,f)|0;u=ba((a[483099+(q<<2)|0]|0)+F|0,f)|0;p=F;while(1){if(N){i=R+L|0;O=u+K|0;P=I;do{M=P+Q|0;v=a[e+M|0]|0;t=a[e+(i+P)|0]|0;if((v&255)>>>0>(t&255)>>>0){S=3}else{S=((v<<24>>24!=t<<24>>24)<<31>>31)+2|0}t=a[e+(O+P)|0]|0;if((v&255)>>>0>(t&255)>>>0){T=1}else{T=(v<<24>>24!=t<<24>>24)<<31>>31}t=(v&255)+(c[g+120+(k*20|0)+(d[483112+(T+S)|0]<<2)>>2]|0)|0;if(t>>>0>255>>>0){U=-t>>31&255}else{U=t&255}a[b+M|0]=U;P=P+1|0;}while((P|0)<(H|0))}P=p+1|0;if((P|0)<(G|0)){Q=Q+f|0;R=R+f|0;u=u+f|0;p=P}else{break}}}p=(q|0)==2;do{if(n<<24>>24==0&p){if((c[h>>2]|0)!=0){V=0;break}V=(c[h+4>>2]|0)==0|0}else{V=0}}while(0);do{if(!(l<<24>>24==0|j^1)){h=V+F|0;if((h|0)<(G|0)){W=h}else{break}do{h=ba(W,f)|0;a[b+h|0]=a[e+h|0]|0;W=W+1|0;}while((W|0)<(G|0))}}while(0);do{if(!(m<<24>>24==0|J)){G=V+I|0;if((G|0)<(H|0)){X=G}else{break}do{a[b+X|0]=a[e+X|0]|0;X=X+1|0;}while((X|0)<(H|0))}}while(0);if(!(n<<24>>24!=0&p)){return}a[b]=a[e]|0;return}function hEa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=(k|0)!=0|0;o=g+120+(k*20|0)|0;p=c[g+108+(k<<2)>>2]|0;q=4>>>(j>>>0);r=-2-q|0;s=h+8|0;t=c[s>>2]|0;if((t|0)==0){u=i-2-(8>>>(j>>>0))|0}else{u=i}i=q+2|0;q=ba(r,f)|0;j=(p|0)!=1;do{if(j){do{if((c[h>>2]|0)==0){v=0;w=t}else{x=c[o>>2]|0;if((i|0)>0){y=0;z=0}else{v=1;w=t;break}while(1){A=y+q|0;B=(d[e+A|0]|0)+x|0;if(B>>>0>255>>>0){C=-B>>31&255}else{C=B&255}a[b+A|0]=C;A=z+1|0;if((A|0)<(i|0)){y=y+f|0;z=A}else{break}}v=1;w=c[s>>2]|0}}while(0);if((w|0)==0){D=v;E=u;F=15;break}x=c[o>>2]|0;A=u-1|0;if((i|0)>0){G=A;H=0}else{I=A;J=v;break}while(1){B=G+q|0;K=(d[e+B|0]|0)+x|0;if(K>>>0>255>>>0){L=-K>>31&255}else{L=K&255}a[b+B|0]=L;B=H+1|0;if((B|0)<(i|0)){G=G+f|0;H=B}else{D=v;E=A;F=15;break}}}else{D=0;E=u;F=15}}while(0);do{if((F|0)==15){if((i|0)<=0){I=E;J=D;break}u=(D|0)<(E|0);v=(a[483096+(p<<2)|0]|0)+q|0;H=(a[483098+(p<<2)|0]|0)+q|0;G=0;L=ba(a[483097+(p<<2)|0]|0,f)|0;o=ba(a[483099+(p<<2)|0]|0,f)|0;w=0;while(1){if(u){s=G+q|0;z=v+L|0;y=H+o|0;C=D;do{t=s+C|0;A=a[e+t|0]|0;x=a[e+(z+C)|0]|0;if((A&255)>>>0>(x&255)>>>0){M=3}else{M=((A<<24>>24!=x<<24>>24)<<31>>31)+2|0}x=a[e+(y+C)|0]|0;if((A&255)>>>0>(x&255)>>>0){N=1}else{N=(A<<24>>24!=x<<24>>24)<<31>>31}x=(A&255)+(c[g+120+(k*20|0)+(d[483112+(N+M)|0]<<2)>>2]|0)|0;if(x>>>0>255>>>0){O=-x>>31&255}else{O=x&255}a[b+t|0]=O;C=C+1|0;}while((C|0)<(E|0))}C=w+1|0;if((C|0)<(i|0)){G=G+f|0;L=L+f|0;o=o+f|0;w=C}else{I=E;J=D;break}}}}while(0);D=(p|0)==3;if(n<<24>>24==0&D){P=(c[h>>2]|0)==0|0}else{P=0}do{if(!(l<<24>>24==0|j^1)){h=i-P|0;if((h|0)>0){Q=0}else{break}do{E=ba(Q+r|0,f)|0;a[b+E|0]=a[e+E|0]|0;Q=Q+1|0;}while((Q|0)<(h|0))}}while(0);do{if(!(m<<24>>24==0|(p|0)==0)){Q=P+J|0;if((Q|0)<(I|0)){R=Q}else{break}do{Q=R-f|0;a[b+Q|0]=a[e+Q|0]|0;R=R+1|0;}while((R|0)<(I|0))}}while(0);if(!(n<<24>>24!=0&D)){return}D=-f|0;a[b+D|0]=a[e+D|0]|0;return}function iEa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;i=(k|0)!=0|0;o=g+120+(k*20|0)|0;p=c[g+108+(k<<2)>>2]|0;q=8>>>(i>>>0);r=-2-q|0;s=q+2|0;q=h+12|0;t=c[q>>2]|0;if((t|0)==0){u=j-2-(4>>>(i>>>0))|0}else{u=j}j=(p|0)!=0;do{if(j){do{if((c[h+4>>2]|0)==0){v=0;w=t}else{i=c[o>>2]|0;if((s|0)>0){x=0}else{v=1;w=t;break}do{y=x+r|0;z=(d[e+y|0]|0)+i|0;if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}a[b+y|0]=A;x=x+1|0;}while((x|0)<(s|0));v=1;w=c[q>>2]|0}}while(0);if((w|0)==0){B=v;C=u;break}i=c[o>>2]|0;y=u-1|0;if((s|0)<=0){B=v;C=y;break}z=(ba(y,f)|0)+r|0;D=0;while(1){E=z+D|0;F=(d[e+E|0]|0)+i|0;if(F>>>0>255>>>0){G=-F>>31&255}else{G=F&255}a[b+E|0]=G;E=D+1|0;if((E|0)<(s|0)){D=E}else{B=v;C=y;break}}}else{B=0;C=u}}while(0);if((B|0)<(C|0)){u=(s|0)>0;v=(a[483096+(p<<2)|0]|0)+r|0;G=(a[483098+(p<<2)|0]|0)+r|0;o=ba(B,f)|0;w=ba((a[483097+(p<<2)|0]|0)+B|0,f)|0;q=ba((a[483099+(p<<2)|0]|0)+B|0,f)|0;x=B;while(1){if(u){A=o+r|0;t=v+w|0;y=G+q|0;D=0;do{i=A+D|0;z=a[e+i|0]|0;E=a[e+(t+D)|0]|0;if((z&255)>>>0>(E&255)>>>0){H=3}else{H=((z<<24>>24!=E<<24>>24)<<31>>31)+2|0}E=a[e+(y+D)|0]|0;if((z&255)>>>0>(E&255)>>>0){I=1}else{I=(z<<24>>24!=E<<24>>24)<<31>>31}E=(z&255)+(c[g+120+(k*20|0)+(d[483112+(I+H)|0]<<2)>>2]|0)|0;if(E>>>0>255>>>0){J=-E>>31&255}else{J=E&255}a[b+i|0]=J;D=D+1|0;}while((D|0)<(s|0))}D=x+1|0;if((D|0)<(C|0)){o=o+f|0;w=w+f|0;q=q+f|0;x=D}else{break}}}x=(p|0)==3;if(n<<24>>24==0&x){K=(c[h+4>>2]|0)==0|0}else{K=0}do{if(!(l<<24>>24==0|(p|0)==1)){h=K+B|0;if((h|0)<(C|0)){L=h}else{break}do{h=(ba(L,f)|0)-1|0;a[b+h|0]=a[e+h|0]|0;L=L+1|0;}while((L|0)<(C|0))}}while(0);do{if(!(m<<24>>24==0|j^1)){C=s-K|0;if((C|0)>0){M=0}else{break}do{L=M+r|0;a[b+L|0]=a[e+L|0]|0;M=M+1|0;}while((M|0)<(C|0))}}while(0);if(!(n<<24>>24!=0&x)){return}a[b-1|0]=a[e-1|0]|0;return}function jEa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;j=(k|0)!=0|0;i=c[g+108+(k<<2)>>2]|0;h=4>>>(j>>>0);o=8>>>(j>>>0);j=o+2|0;p=h+2|0;q=ba(-2-h|0,f)|0;r=q+(-2-o)|0;if((p|0)>0){s=(j|0)>0;t=(a[483096+(i<<2)|0]|0)+r|0;u=(a[483098+(i<<2)|0]|0)+r|0;v=0;w=ba(a[483097+(i<<2)|0]|0,f)|0;x=ba(a[483099+(i<<2)|0]|0,f)|0;y=0;while(1){if(s){z=v+r|0;A=t+w|0;B=u+x|0;C=0;do{D=z+C|0;E=a[e+D|0]|0;F=a[e+(A+C)|0]|0;if((E&255)>>>0>(F&255)>>>0){G=3}else{G=((E<<24>>24!=F<<24>>24)<<31>>31)+2|0}F=a[e+(B+C)|0]|0;if((E&255)>>>0>(F&255)>>>0){H=1}else{H=(E<<24>>24!=F<<24>>24)<<31>>31}F=(E&255)+(c[g+120+(k*20|0)+(d[483112+(H+G)|0]<<2)>>2]|0)|0;if(F>>>0>255>>>0){I=-F>>31&255}else{I=F&255}a[b+D|0]=I;C=C+1|0;}while((C|0)<(j|0))}C=y+1|0;if((C|0)<(p|0)){v=v+f|0;w=w+f|0;x=x+f|0;y=C}else{break}}}if(n<<24>>24==0){J=(i|0)==2|0}else{J=0}do{if(!(l<<24>>24==0|(i|0)==1)){y=p-J|0;if((y|0)<=0){break}x=q-1|0;w=0;do{v=x+(ba(w,f)|0)|0;a[b+v|0]=a[e+v|0]|0;w=w+1|0;}while((w|0)<(y|0))}}while(0);do{if(!(m<<24>>24==0|(i|0)==0)){q=j-J|0;if((q|0)<=0){break}p=r+(ba(h+1|0,f)|0)|0;l=0;do{y=p+l|0;a[b+y|0]=a[e+y|0]|0;l=l+1|0;}while((l|0)<(q|0))}}while(0);if(!(n<<24>>24!=0&(i|0)==2)){return}i=o+1+(ba(h+1|0,f)|0)+r|0;a[b+i|0]=a[e+i|0]|0;return}function kEa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;if((h|0)<=0){return}i=(g|0)>0;j=0;k=e;e=a;while(1){if(i){a=0;do{b[e+(a<<1)>>1]=(d[k+a|0]|0)<<6;a=a+1|0;}while((a|0)<(g|0))}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+f|0;e=e+(c<<1)|0}else{break}}return}function lEa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((h|0)<=0){return}i=(g|0)>0;j=0;k=e;e=a;while(1){if(i){a=0;while(1){l=a+1|0;b[e+(a<<1)>>1]=(((((((d[k+(a-2)|0]|0)<<2)-(d[k+(a-3)|0]|0)&65535)+((d[k+(a-1)|0]|0)*-10&65535)&65535)+((d[k+a|0]|0)*58&65535)&65535)+((d[k+l|0]|0)*17&65535)&65535)+((d[k+(a+2)|0]|0)*-5&65535)&65535)+(d[k+(a+3)|0]|0);if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+f|0;e=e+(c<<1)|0}else{break}}return}function mEa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((h|0)<=0){return}i=(g|0)>0;j=0;k=e;e=a;while(1){if(i){a=0;while(1){l=a+1|0;b[e+(a<<1)>>1]=((((((d[k+(a-2)|0]|0)<<2)-(d[k+(a-3)|0]|0)&65535)+((d[k+(a+3)|0]|0)<<2)&65535)-(d[k+(a+4)|0]|0)&65535)+(((d[k+l|0]|0)+(d[k+a|0]|0)&65535)*40&65535)&65535)+(((d[k+(a+2)|0]|0)+(d[k+(a-1)|0]|0)&65535)*-11&65535);if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+f|0;e=e+(c<<1)|0}else{break}}return}function nEa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((h|0)<=0){return}i=(g|0)>0;j=0;k=e;e=a;while(1){if(i){a=0;while(1){l=a+1|0;b[e+(a<<1)>>1]=(((((((d[k+(a-1)|0]|0)*-5&65535)+(d[k+(a-2)|0]|0)&65535)+((d[k+a|0]|0)*17&65535)&65535)+((d[k+l|0]|0)*58&65535)&65535)+((d[k+(a+2)|0]|0)*-10&65535)&65535)+((d[k+(a+3)|0]|0)<<2)&65535)-(d[k+(a+4)|0]|0);if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+f|0;e=e+(c<<1)|0}else{break}}return}function oEa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((h|0)<=0){return}i=(g|0)>0;j=f*3|0;k=f<<1;l=0;m=e;e=a;while(1){if(i){a=0;do{b[e+(a<<1)>>1]=(((((((d[m+(a-k)|0]|0)<<2)-(d[m+(a-j)|0]|0)&65535)+((d[m+(a-f)|0]|0)*-10&65535)&65535)+((d[m+a|0]|0)*58&65535)&65535)+((d[m+(a+f)|0]|0)*17&65535)&65535)+((d[m+(a+k)|0]|0)*-5&65535)&65535)+(d[m+(a+j)|0]|0);a=a+1|0;}while((a|0)<(g|0))}a=l+1|0;if((a|0)<(h|0)){l=a;m=m+f|0;e=e+(c<<1)|0}else{break}}return}function pEa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1206633]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ba(d[1206617]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;while(1){x=q+1|0;y=a[p+(q+3)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)<<2)-(r&255)&65535)+((t&255)*-10&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*17&65535)&65535)+((w&255)*-5&65535)&65535)+(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1206617]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+((b[c+(l-64<<1)>>1]|0)*-10|0)+((b[c+(l<<1)>>1]|0)*58|0)+((b[c+(l+64<<1)>>1]|0)*17|0)+((b[c+(l+128<<1)>>1]|0)*-5|0)+(b[c+(l+192<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function qEa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+9088|0;l=k|0;m=(d[1206633]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ba(d[1206617]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;x=a[p+3|0]|0;while(1){y=q+1|0;z=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=((((((s&255)<<2)-(r&255)&65535)+((x&255)<<2)&65535)-(z&255)&65535)+(((v&255)+(u&255)&65535)*40&65535)&65535)+(((w&255)+(t&255)&65535)*-11&65535);if((y|0)<(h|0)){q=y;r=s;s=t;t=u;u=v;v=w;w=x;x=z}else{break}}}x=o+1|0;if((x|0)<(m|0)){o=x;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1206617]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+((b[c+(l-64<<1)>>1]|0)*-10|0)+((b[c+(l<<1)>>1]|0)*58|0)+((b[c+(l+64<<1)>>1]|0)*17|0)+((b[c+(l+128<<1)>>1]|0)*-5|0)+(b[c+(l+192<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function rEa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1206633]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ba(d[1206617]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-2|0]|0;s=a[p-1|0]|0;t=a[p]|0;u=a[p+1|0]|0;v=a[p+2|0]|0;w=a[p+3|0]|0;while(1){x=q+1|0;y=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)*-5&65535)+(r&255)&65535)+((t&255)*17&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*-10&65535)&65535)+((w&255)<<2)&65535)-(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1206617]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+((b[c+(l-64<<1)>>1]|0)*-10|0)+((b[c+(l<<1)>>1]|0)*58|0)+((b[c+(l+64<<1)>>1]|0)*17|0)+((b[c+(l+128<<1)>>1]|0)*-5|0)+(b[c+(l+192<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function sEa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;if((h|0)<=0){return}i=(g|0)>0;j=f*3|0;k=f<<1;l=f<<2;m=0;n=e;e=a;while(1){if(i){a=0;do{b[e+(a<<1)>>1]=((((((d[n+(a-k)|0]|0)<<2)-(d[n+(a-j)|0]|0)&65535)+((d[n+(a+j)|0]|0)<<2)&65535)-(d[n+(a+l)|0]|0)&65535)+(((d[n+(a+f)|0]|0)+(d[n+a|0]|0)&65535)*40&65535)&65535)+(((d[n+(a+k)|0]|0)+(d[n+(a-f)|0]|0)&65535)*-11&65535);a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+f|0;e=e+(c<<1)|0}else{break}}return}function tEa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1206634]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ba(d[1206618]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;while(1){x=q+1|0;y=a[p+(q+3)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)<<2)-(r&255)&65535)+((t&255)*-10&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*17&65535)&65535)+((w&255)*-5&65535)&65535)+(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1206618]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)+(((b[c+(l+64<<1)>>1]|0)+(b[c+(l<<1)>>1]|0)|0)*40|0)+(((b[c+(l+128<<1)>>1]|0)+(b[c+(l-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function uEa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+9088|0;l=k|0;m=(d[1206634]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ba(d[1206618]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;x=a[p+3|0]|0;while(1){y=q+1|0;z=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=((((((s&255)<<2)-(r&255)&65535)+((x&255)<<2)&65535)-(z&255)&65535)+(((v&255)+(u&255)&65535)*40&65535)&65535)+(((w&255)+(t&255)&65535)*-11&65535);if((y|0)<(h|0)){q=y;r=s;s=t;t=u;u=v;v=w;w=x;x=z}else{break}}}x=o+1|0;if((x|0)<(m|0)){o=x;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1206618]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)+(((b[c+(l+64<<1)>>1]|0)+(b[c+(l<<1)>>1]|0)|0)*40|0)+(((b[c+(l+128<<1)>>1]|0)+(b[c+(l-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function vEa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1206634]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ba(d[1206618]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-2|0]|0;s=a[p-1|0]|0;t=a[p]|0;u=a[p+1|0]|0;v=a[p+2|0]|0;w=a[p+3|0]|0;while(1){x=q+1|0;y=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)*-5&65535)+(r&255)&65535)+((t&255)*17&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*-10&65535)&65535)+((w&255)<<2)&65535)-(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1206618]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)+(((b[c+(l+64<<1)>>1]|0)+(b[c+(l<<1)>>1]|0)|0)*40|0)+(((b[c+(l+128<<1)>>1]|0)+(b[c+(l-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function wEa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;if((h|0)<=0){return}i=(g|0)>0;j=f<<1;k=f*3|0;l=f<<2;m=0;n=e;e=a;while(1){if(i){a=0;do{b[e+(a<<1)>>1]=(((((((d[n+(a-f)|0]|0)*-5&65535)+(d[n+(a-j)|0]|0)&65535)+((d[n+a|0]|0)*17&65535)&65535)+((d[n+(a+f)|0]|0)*58&65535)&65535)+((d[n+(a+j)|0]|0)*-10&65535)&65535)+((d[n+(a+k)|0]|0)<<2)&65535)-(d[n+(a+l)|0]|0);a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+f|0;e=e+(c<<1)|0}else{break}}return}function xEa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1206635]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ba(d[1206619]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;while(1){x=q+1|0;y=a[p+(q+3)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)<<2)-(r&255)&65535)+((t&255)*-10&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*17&65535)&65535)+((w&255)*-5&65535)&65535)+(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1206619]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=(((b[c+(l-64<<1)>>1]|0)*-5|0)+(b[c+(l-128<<1)>>1]|0)+((b[c+(l<<1)>>1]|0)*17|0)+((b[c+(l+64<<1)>>1]|0)*58|0)+((b[c+(l+128<<1)>>1]|0)*-10|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function yEa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+9088|0;l=k|0;m=(d[1206635]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ba(d[1206619]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;x=a[p+3|0]|0;while(1){y=q+1|0;z=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=((((((s&255)<<2)-(r&255)&65535)+((x&255)<<2)&65535)-(z&255)&65535)+(((v&255)+(u&255)&65535)*40&65535)&65535)+(((w&255)+(t&255)&65535)*-11&65535);if((y|0)<(h|0)){q=y;r=s;s=t;t=u;u=v;v=w;w=x;x=z}else{break}}}x=o+1|0;if((x|0)<(m|0)){o=x;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1206619]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=(((b[c+(l-64<<1)>>1]|0)*-5|0)+(b[c+(l-128<<1)>>1]|0)+((b[c+(l<<1)>>1]|0)*17|0)+((b[c+(l+64<<1)>>1]|0)*58|0)+((b[c+(l+128<<1)>>1]|0)*-10|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function zEa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1206635]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ba(d[1206619]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-2|0]|0;s=a[p-1|0]|0;t=a[p]|0;u=a[p+1|0]|0;v=a[p+2|0]|0;w=a[p+3|0]|0;while(1){x=q+1|0;y=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)*-5&65535)+(r&255)&65535)+((t&255)*17&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*-10&65535)&65535)+((w&255)<<2)&65535)-(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1206619]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=(((b[c+(l-64<<1)>>1]|0)*-5|0)+(b[c+(l-128<<1)>>1]|0)+((b[c+(l<<1)>>1]|0)*17|0)+((b[c+(l+64<<1)>>1]|0)*58|0)+((b[c+(l+128<<1)>>1]|0)*-10|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function AEa(a,c,e,f,g,h,i,j,k){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;if((h|0)<=0){return}k=(g|0)>0;j=0;i=e;e=a;while(1){if(k){a=0;do{b[e+(a<<1)>>1]=(d[i+a|0]|0)<<6;a=a+1|0;}while((a|0)<(g|0))}a=j+1|0;if((a|0)<(h|0)){j=a;i=i+f|0;e=e+(c<<1)|0}else{break}}return}function BEa(c,e,f,g,h,i,j,k,l){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=j-1|0;if((i|0)<=0){return}j=(h|0)>0;k=a[1206920+(l<<4)|0]|0;m=a[1206921+(l<<4)|0]|0;n=a[1206922+(l<<4)|0]|0;o=a[1206923+(l<<4)|0]|0;l=f;f=0;p=c;while(1){if(j){c=0;while(1){q=ba(d[l+(c-1)|0]|0,k)|0;r=(ba(d[l+c|0]|0,m)|0)+q&65535;q=c+1|0;s=r+(ba(d[l+q|0]|0,n)|0)&65535;b[p+(c<<1)>>1]=s+(ba(d[l+(c+2)|0]|0,o)|0);if((q|0)<(h|0)){c=q}else{break}}}c=f+1|0;if((c|0)<(i|0)){l=l+g|0;f=c;p=p+(e<<1)|0}else{break}}return}function CEa(c,e,f,g,h,i,j,k,l){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=k-1|0;if((i|0)<=0){return}k=(h|0)>0;j=a[1206920+(l<<4)|0]|0;m=a[1206921+(l<<4)|0]|0;n=a[1206922+(l<<4)|0]|0;o=a[1206923+(l<<4)|0]|0;l=g<<1;p=f;f=0;q=c;while(1){if(k){c=0;do{r=ba(d[p+(c-g)|0]|0,j)|0;s=(ba(d[p+c|0]|0,m)|0)+r&65535;r=s+(ba(d[p+(c+g)|0]|0,n)|0)&65535;b[q+(c<<1)>>1]=r+(ba(d[p+(c+l)|0]|0,o)|0);c=c+1|0;}while((c|0)<(h|0))}c=f+1|0;if((c|0)<(i|0)){p=p+g|0;f=c;q=q+(e<<1)|0}else{break}}return}function DEa(c,d,e,f,g,h,j,k,l){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=i;i=i+8576|0;m=l|0;n=j-1|0;j=k-1|0;k=1206920+(j<<4)|0;o=h+3|0;if((o|0)>0){p=(g|0)>0;q=a[1206920+(n<<4)|0]|0;r=a[1206921+(n<<4)|0]|0;s=a[1206922+(n<<4)|0]|0;t=a[1206923+(n<<4)|0]|0;n=e+(-f|0)|0;e=0;u=m|0;while(1){if(p){v=0;w=a[n-1|0]|0;x=a[n]|0;y=a[n+1|0]|0;while(1){z=v+1|0;A=((ba(x&255,r)|0)+(ba(w&255,q)|0)&65535)+(ba(y&255,s)|0)&65535;B=a[n+(v+2)|0]|0;b[u+(v<<1)>>1]=A+(ba(B&255,t)|0);if((z|0)<(g|0)){v=z;w=x;x=y;y=B}else{break}}}y=e+1|0;if((y|0)<(o|0)){n=n+f|0;e=y;u=u+128|0}else{break}}}if((h|0)<=0){i=l;return}u=(g|0)>0;e=a[k]|0;k=a[1206921+(j<<4)|0]|0;f=a[1206922+(j<<4)|0]|0;n=a[1206923+(j<<4)|0]|0;j=0;o=c;c=m+128|0;while(1){if(u){m=0;do{t=ba(b[c+(m-64<<1)>>1]|0,e)|0;s=(ba(b[c+(m<<1)>>1]|0,k)|0)+t|0;t=s+(ba(b[c+(m+64<<1)>>1]|0,f)|0)|0;b[o+(m<<1)>>1]=(t+(ba(b[c+(m+128<<1)>>1]|0,n)|0)|0)>>>6;m=m+1|0;}while((m|0)<(g|0))}m=j+1|0;if((m|0)<(h|0)){j=m;o=o+(d<<1)|0;c=c+128|0}else{break}}i=l;return}function EEa(c,d,e,f,g,h){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((h|0)<=0){return}i=(g|0)>0;j=c;c=0;k=e;while(1){if(i){e=0;do{l=(b[k+(e<<1)>>1]|0)+32>>6;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[j+e|0]=m;e=e+1|0;}while((e|0)<(g|0))}e=c+1|0;if((e|0)<(h|0)){j=j+d|0;c=e;k=k+(f<<1)|0}else{break}}return}function FEa(c,d,e,f,g,h,i){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;if((i|0)<=0){return}j=(h|0)>0;k=0;l=c;c=f;f=e;while(1){if(j){e=0;do{m=(b[f+(e<<1)>>1]|0)+64+(b[c+(e<<1)>>1]|0)>>7;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l+e|0]=n;e=e+1|0;}while((e|0)<(h|0))}e=k+1|0;if((e|0)<(i|0)){k=e;l=l+d|0;c=c+(g<<1)|0;f=f+(g<<1)|0}else{break}}return}function GEa(c,d,e,f,g,h,i,j,k){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0;l=c&255;c=l+6|0;m=1<<l+5;l=d<<16>>16;d=e<<16>>16;if((k|0)<=0){return}e=(j|0)>0;n=0;o=f;f=h;while(1){if(e){h=0;do{p=((ba(b[f+(h<<1)>>1]|0,l)|0)+m>>c)+d|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[o+h|0]=q;h=h+1|0;}while((h|0)<(j|0))}h=n+1|0;if((h|0)<(k|0)){n=h;o=o+g|0;f=f+(i<<1)|0}else{break}}return}function HEa(c,d,e,f,g,h,i,j,k,l,m,n){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0;o=c&255;c=d<<16>>16;d=e<<16>>16;if((n|0)<=0){return}e=(m|0)>0;p=(f<<16>>16)+1+(g<<16>>16)<<o+6;g=o+7|0;o=k;k=0;f=h;h=j;while(1){if(e){j=0;do{q=ba(b[h+(j<<1)>>1]|0,c)|0;r=q+p+(ba(b[o+(j<<1)>>1]|0,d)|0)>>g;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[f+j|0]=s;j=j+1|0;}while((j|0)<(m|0))}j=k+1|0;if((j|0)<(n|0)){o=o+(l<<1)|0;k=j;f=f+i|0;h=h+(l<<1)|0}else{break}}return}function IEa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;NEa(a,b,1,c,d,e,f);return}function JEa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;NEa(a,1,b,c,d,e,f);return}function KEa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;MEa(a,b,1,c,d,e);return}function LEa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;MEa(a,1,b,c,d,e);return}function MEa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=e*-2|0;k=-e|0;l=c[g>>2]|0;if((l|0)>=1){m=-l|0;n=(a[h]|0)==0;o=(a[i]|0)==0;p=b;q=0;while(1){r=p+k|0;s=d[r]|0;t=d[p]|0;u=(d[p+j|0]|0)+4-(d[p+e|0]|0)+(t-s<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}if(n){u=v+s|0;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}a[r]=w}if(o){r=t-v|0;if(r>>>0>255>>>0){x=-r>>31&255}else{x=r&255}a[p]=x}r=q+1|0;if((r|0)<4){p=p+f|0;q=r}else{break}}}q=c[g+4>>2]|0;if((q|0)<1){return}g=-q|0;p=(a[h+1|0]|0)==0;h=(a[i+1|0]|0)==0;i=b+(f<<2)|0;b=0;while(1){x=i+k|0;v=d[x]|0;o=d[i]|0;w=(d[i+j|0]|0)+4-(d[i+e|0]|0)+(o-v<<2)>>3;if((w|0)<(g|0)){y=g}else{y=(w|0)>(q|0)?q:w}if(p){w=y+v|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[x]=z}if(h){x=o-y|0;if(x>>>0>255>>>0){A=-x>>31&255}else{A=x&255}a[i]=A}x=b+1|0;if((x|0)<4){i=i+f|0;b=x}else{break}}return}function NEa(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;k=e*-3|0;l=e*-2|0;m=-e|0;n=e<<1;o=f*3|0;p=o+k|0;q=o+l|0;r=o-e|0;s=o+n|0;t=o+e|0;u=e*-4|0;v=e*3|0;w=o+u|0;x=(f+e|0)*3|0;y=f<<2;z=f<<2;A=b;b=0;while(1){B=a[A+k|0]|0;C=a[A+l|0]|0;D=a[A+m|0]|0;E=D&255;F=(B&255)-((C&255)<<1)+E|0;G=(F|0)>-1?F:-F|0;F=a[A+n|0]|0;H=a[A+e|0]|0;I=a[A]|0;J=I&255;K=(F&255)-((H&255)<<1)+J|0;L=(K|0)>-1?K:-K|0;K=d[A+r|0]|0;M=(d[A+p|0]|0)-((d[A+q|0]|0)<<1)+K|0;N=(M|0)>-1?M:-M|0;M=d[A+o|0]|0;O=(d[A+s|0]|0)-((d[A+t|0]|0)<<1)+M|0;P=(O|0)>-1?O:-O|0;O=L+G|0;Q=P+N|0;R=c[g+(b<<2)>>2]|0;S=c[h+(b<<2)>>2]|0;T=a[i+b|0]|0;U=a[j+b|0]|0;a:do{if((Q+O|0)<(R|0)){V=R>>3;W=R>>2;X=(S*5|0)+1>>1;Y=(d[A+u|0]|0)-E|0;Z=a[A+v|0]|0;_=(Z&255)-J|0;do{if((((_|0)>-1?_:-_|0)+((Y|0)>-1?Y:-Y|0)|0)<(V|0)){$=E-J|0;if(((($|0)>-1?$:-$|0)|0)>=(X|0)){break}$=(d[A+w|0]|0)-K|0;aa=(d[A+x|0]|0)-M|0;if((((aa|0)>-1?aa:-aa|0)+(($|0)>-1?$:-$|0)|0)>=(V|0)){break}$=K-M|0;if(((($|0)>-1?$:-$|0)|0)>=(X|0)){break}if((O<<1|0)>=(W|0)){break}if((Q<<1|0)>=(W|0)){break}$=S<<1;aa=T<<24>>24==0;ba=-$|0;ca=U<<24>>24==0;da=A;ea=1;fa=B;ga=C;ha=D;ia=I;ja=H;ka=F;la=Z;while(1){ma=da+k|0;na=fa&255;oa=da+l|0;pa=ga&255;qa=da+m|0;ra=ha&255;sa=ia&255;ta=da+e|0;ua=ja&255;va=da+n|0;wa=ka&255;xa=la&255;if(aa){ya=d[da+u|0]|0;za=(na+4+ua+(ra+pa+sa<<1)>>3)-ra|0;if((za|0)<(ba|0)){Aa=ba}else{Aa=(za|0)>($|0)?$:za}a[qa]=Aa+ra;qa=((na+2+pa+ra+sa|0)>>>2)-pa|0;if((qa|0)<(ba|0)){Ba=ba}else{Ba=(qa|0)>($|0)?$:qa}a[oa]=Ba+pa;oa=((na*3|0)+4+pa+ra+sa+(ya<<1)>>3)-na|0;if((oa|0)<(ba|0)){Ca=ba}else{Ca=(oa|0)>($|0)?$:oa}a[ma]=Ca+na}if(ca){na=(pa+4+wa+(sa+ra+ua<<1)>>3)-sa|0;if((na|0)<(ba|0)){Da=ba}else{Da=(na|0)>($|0)?$:na}a[da]=Da+sa;na=((ra+2+sa+ua+wa|0)>>>2)-ua|0;if((na|0)<(ba|0)){Ea=ba}else{Ea=(na|0)>($|0)?$:na}a[ta]=Ea+ua;ta=(ra+4+sa+ua+(wa*3|0)+(xa<<1)>>3)-wa|0;if((ta|0)<(ba|0)){Fa=ba}else{Fa=(ta|0)>($|0)?$:ta}a[va]=Fa+wa}wa=da+f|0;if((ea|0)>=4){break}va=a[da+(k+f)|0]|0;ta=a[da+(l+f)|0]|0;xa=a[da+(f-e)|0]|0;ua=a[da+(f+e)|0]|0;sa=a[da+(n+f)|0]|0;ra=a[da+(v+f)|0]|0;da=wa;ea=ea+1|0;fa=va;ga=ta;ha=xa;ia=a[wa]|0;ja=ua;ka=sa;la=ra}Ga=A+z|0;break a}}while(0);Z=S>>1;W=(R>>1)+R>>3;X=S*10|0;V=-S|0;Y=T<<24>>24!=0;_=U<<24>>24!=0;la=(N+G|0)<(W|0)&(Y^1);ka=-Z|0;ja=(P+L|0)<(W|0)&(_^1);W=A;ia=1;ha=B;ga=C;fa=D;ea=I;da=H;$=F;while(1){ba=ha&255;ca=W+l|0;aa=ga&255;ra=W+m|0;sa=fa&255;ua=ea&255;wa=W+e|0;xa=da&255;ta=$&255;va=((ua-sa|0)*9|0)+8+((xa-aa|0)*-3|0)>>4;do{if((((va|0)>-1?va:-va|0)|0)<(X|0)){if((va|0)<(V|0)){Ha=V}else{Ha=(va|0)>(S|0)?S:va}if(!Y){na=Ha+sa|0;if(na>>>0>255>>>0){Ia=-na>>31&255}else{Ia=na&255}a[ra]=Ia}if(!_){na=ua-Ha|0;if(na>>>0>255>>>0){Ja=-na>>31&255}else{Ja=na&255}a[W]=Ja}if(la){na=((ba+1+sa|0)>>>1)-aa+Ha>>1;if((na|0)<(ka|0)){Ka=ka}else{Ka=(na|0)>(Z|0)?Z:na}na=Ka+aa|0;if(na>>>0>255>>>0){La=-na>>31&255}else{La=na&255}a[ca]=La}if(!ja){break}na=((ua+1+ta|0)>>>1)-xa-Ha>>1;if((na|0)<(ka|0)){Ma=ka}else{Ma=(na|0)>(Z|0)?Z:na}na=Ma+xa|0;if(na>>>0>255>>>0){Na=-na>>31&255}else{Na=na&255}a[wa]=Na}}while(0);wa=W+f|0;if((ia|0)>=4){break}xa=a[W+(k+f)|0]|0;ta=a[W+(l+f)|0]|0;ua=a[W+(f-e)|0]|0;ca=a[W+(f+e)|0]|0;aa=a[W+(n+f)|0]|0;W=wa;ia=ia+1|0;ha=xa;ga=ta;fa=ua;ea=a[wa]|0;da=ca;$=aa}Ga=A+z|0}else{Ga=A+y|0}}while(0);S=b+1|0;if((S|0)<2){A=Ga;b=S}else{break}}return}function OEa(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;n=i;i=i+128|0;o=n|0;TGb(o|0,0,128)|0;p=(l|0)!=0|0;q=c[g+96+(l<<2)>>2]|0;do{if((m|0)==0){if((c[h+8>>2]|0)==0){r=j-2-(8>>>(p>>>0))|0}else{r=j}if((c[h+12>>2]|0)!=0){s=0;t=0;u=r;v=k;break}s=0;t=0;u=r;v=k-2-(4>>>(p>>>0))|0}else if((m|0)==3){w=4>>>(p>>>0);x=8>>>(p>>>0);s=-2-x|0;t=-2-w|0;u=x+2|0;v=w+2|0}else if((m|0)==2){w=8>>>(p>>>0);x=-2-w|0;y=w+2|0;if((c[h+12>>2]|0)!=0){s=x;t=0;u=y;v=k;break}s=x;t=0;u=y;v=k-2-(4>>>(p>>>0))|0}else if((m|0)==1){y=4>>>(p>>>0);if((c[h+8>>2]|0)==0){z=j-2-(8>>>(p>>>0))|0}else{z=j}s=0;t=-2-y|0;u=z;v=y+2|0}else{s=0;t=0;u=j;v=k}}while(0);k=(ba(t,f)|0)+s|0;c[o+((q&31)<<2)>>2]=c[g+120+(l*20|0)+4>>2];c[o+((q+1&31)<<2)>>2]=c[g+120+(l*20|0)+8>>2];c[o+((q+2&31)<<2)>>2]=c[g+120+(l*20|0)+12>>2];c[o+((q+3&31)<<2)>>2]=c[g+120+(l*20|0)+16>>2];if((v|0)<=0){i=n;return}l=(u|0)>0;g=e+k|0;e=0;q=b+k|0;while(1){if(l){k=0;do{b=d[g+k|0]|0;s=b+(c[o+(b>>>3<<2)>>2]|0)|0;if(s>>>0>255>>>0){A=-s>>31&255}else{A=s&255}a[q+k|0]=A;k=k+1|0;}while((k|0)<(u|0))}k=e+1|0;if((k|0)<(v|0)){g=g+f|0;e=k;q=q+f|0}else{break}}i=n;return}function PEa(d,f,g,h,i,j){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=d;d=f>>>1;f=g>>>1;g=d*-2|0;l=-d|0;m=c[h>>2]<<2;if((m|0)>=1){n=-m|0;o=(a[i]|0)==0;p=(a[j]|0)==0;q=k;r=0;while(1){s=q+(l<<1)|0;t=e[s>>1]|0;u=e[q>>1]|0;v=(e[q+(g<<1)>>1]|0)+4-(e[q+(d<<1)>>1]|0)+(u-t<<2)>>3;if((v|0)<(n|0)){w=n}else{w=(v|0)>(m|0)?m:v}if(o){v=w+t|0;if(v>>>0<1024>>>0){x=v&65535}else{x=-v>>31&1023}b[s>>1]=x}if(p){s=u-w|0;if(s>>>0<1024>>>0){y=s&65535}else{y=-s>>31&1023}b[q>>1]=y}s=r+1|0;if((s|0)<4){q=q+(f<<1)|0;r=s}else{break}}}r=c[h+4>>2]<<2;if((r|0)<1){return}h=-r|0;q=(a[i+1|0]|0)==0;i=(a[j+1|0]|0)==0;j=k+(f<<2<<1)|0;k=0;while(1){y=j+(l<<1)|0;w=e[y>>1]|0;p=e[j>>1]|0;x=(e[j+(g<<1)>>1]|0)+4-(e[j+(d<<1)>>1]|0)+(p-w<<2)>>3;if((x|0)<(h|0)){z=h}else{z=(x|0)>(r|0)?r:x}if(q){x=z+w|0;if(x>>>0<1024>>>0){A=x&65535}else{A=-x>>31&1023}b[y>>1]=A}if(i){y=p-z|0;if(y>>>0<1024>>>0){B=y&65535}else{B=-y>>31&1023}b[j>>1]=B}y=k+1|0;if((y|0)<4){j=j+(f<<1)|0;k=y}else{break}}return}function QEa(d,f,g,h,i,j,k){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;l=f>>>1;f=g>>>1;g=l*-3|0;m=l*-2|0;n=-l|0;o=l<<1;p=f*3|0;q=p+g|0;r=p+m|0;s=p-l|0;t=p+o|0;u=p+l|0;v=l*-4|0;w=l*3|0;x=p+v|0;y=(f+l|0)*3|0;z=f<<2;A=f<<2;B=d;d=0;while(1){C=b[B+(g<<1)>>1]|0;D=b[B+(m<<1)>>1]|0;E=b[B+(n<<1)>>1]|0;F=E&65535;G=(C&65535)-((D&65535)<<1)+F|0;H=(G|0)>-1?G:-G|0;G=b[B+(o<<1)>>1]|0;I=b[B+(l<<1)>>1]|0;J=b[B>>1]|0;K=J&65535;L=(G&65535)-((I&65535)<<1)+K|0;M=(L|0)>-1?L:-L|0;L=e[B+(s<<1)>>1]|0;N=(e[B+(q<<1)>>1]|0)-((e[B+(r<<1)>>1]|0)<<1)+L|0;O=(N|0)>-1?N:-N|0;N=e[B+(p<<1)>>1]|0;P=(e[B+(t<<1)>>1]|0)-((e[B+(u<<1)>>1]|0)<<1)+N|0;Q=(P|0)>-1?P:-P|0;P=M+H|0;R=Q+O|0;S=c[h+(d<<2)>>2]<<2;T=c[i+(d<<2)>>2]|0;U=T<<2;V=a[j+d|0]|0;W=a[k+d|0]|0;a:do{if((R+P|0)<(S|0)){X=S>>3;Y=S>>2;Z=(T*20|0)>>1;_=(e[B+(v<<1)>>1]|0)-F|0;$=b[B+(w<<1)>>1]|0;aa=($&65535)-K|0;do{if((((aa|0)>-1?aa:-aa|0)+((_|0)>-1?_:-_|0)|0)<(X|0)){ba=F-K|0;if((((ba|0)>-1?ba:-ba|0)|0)>=(Z|0)){break}ba=(e[B+(x<<1)>>1]|0)-L|0;ca=(e[B+(y<<1)>>1]|0)-N|0;if((((ca|0)>-1?ca:-ca|0)+((ba|0)>-1?ba:-ba|0)|0)>=(X|0)){break}ba=L-N|0;if((((ba|0)>-1?ba:-ba|0)|0)>=(Z|0)){break}if((P<<1|0)>=(Y|0)){break}if((R<<1|0)>=(Y|0)){break}ba=T<<3;ca=V<<24>>24==0;da=-ba|0;ea=W<<24>>24==0;fa=B;ga=1;ha=C;ia=D;ja=E;ka=J;la=I;ma=G;na=$;while(1){oa=fa+(g<<1)|0;pa=ha&65535;qa=fa+(m<<1)|0;ra=ia&65535;sa=fa+(n<<1)|0;ta=ja&65535;ua=ka&65535;va=fa+(l<<1)|0;wa=la&65535;xa=fa+(o<<1)|0;ya=ma&65535;za=na&65535;if(ca){Aa=e[fa+(v<<1)>>1]|0;Ba=(pa+4+wa+(ta+ra+ua<<1)>>3)-ta|0;if((Ba|0)<(da|0)){Ca=da}else{Ca=(Ba|0)>(ba|0)?ba:Ba}b[sa>>1]=Ca+ta;sa=((pa+2+ra+ta+ua|0)>>>2)-ra|0;if((sa|0)<(da|0)){Da=da}else{Da=(sa|0)>(ba|0)?ba:sa}b[qa>>1]=Da+ra;qa=((pa*3|0)+4+ra+ta+ua+(Aa<<1)>>3)-pa|0;if((qa|0)<(da|0)){Ea=da}else{Ea=(qa|0)>(ba|0)?ba:qa}b[oa>>1]=Ea+pa}if(ea){pa=(ra+4+ya+(ua+ta+wa<<1)>>3)-ua|0;if((pa|0)<(da|0)){Fa=da}else{Fa=(pa|0)>(ba|0)?ba:pa}b[fa>>1]=Fa+ua;pa=((ta+2+ua+wa+ya|0)>>>2)-wa|0;if((pa|0)<(da|0)){Ga=da}else{Ga=(pa|0)>(ba|0)?ba:pa}b[va>>1]=Ga+wa;va=(ta+4+ua+wa+(ya*3|0)+(za<<1)>>3)-ya|0;if((va|0)<(da|0)){Ha=da}else{Ha=(va|0)>(ba|0)?ba:va}b[xa>>1]=Ha+ya}ya=fa+(f<<1)|0;if((ga|0)>=4){break}xa=b[fa+(f+g<<1)>>1]|0;va=b[fa+(f+m<<1)>>1]|0;za=b[fa+(f-l<<1)>>1]|0;wa=b[fa+(f+l<<1)>>1]|0;ua=b[fa+(f+o<<1)>>1]|0;ta=b[fa+(f+w<<1)>>1]|0;fa=ya;ga=ga+1|0;ha=xa;ia=va;ja=za;ka=b[ya>>1]|0;la=wa;ma=ua;na=ta}Ia=B+(A<<1)|0;break a}}while(0);$=U>>1;Y=(S>>1)+S>>3;Z=T*40|0;X=-U|0;_=V<<24>>24!=0;aa=W<<24>>24!=0;na=(O+H|0)<(Y|0)&(_^1);ma=-$|0;la=(Q+M|0)<(Y|0)&(aa^1);Y=B;ka=1;ja=C;ia=D;ha=E;ga=J;fa=I;ba=G;while(1){da=ja&65535;ea=Y+(m<<1)|0;ca=ia&65535;ta=Y+(n<<1)|0;ua=ha&65535;wa=ga&65535;ya=Y+(l<<1)|0;za=fa&65535;va=ba&65535;xa=((wa-ua|0)*9|0)+8+((za-ca|0)*-3|0)>>4;do{if((((xa|0)>-1?xa:-xa|0)|0)<(Z|0)){if((xa|0)<(X|0)){Ja=X}else{Ja=(xa|0)>(U|0)?U:xa}if(!_){pa=Ja+ua|0;if(pa>>>0<1024>>>0){Ka=pa&65535}else{Ka=-pa>>31&1023}b[ta>>1]=Ka}if(!aa){pa=wa-Ja|0;if(pa>>>0<1024>>>0){La=pa&65535}else{La=-pa>>31&1023}b[Y>>1]=La}if(na){pa=((da+1+ua|0)>>>1)-ca+Ja>>1;if((pa|0)<(ma|0)){Ma=ma}else{Ma=(pa|0)>($|0)?$:pa}pa=Ma+ca|0;if(pa>>>0<1024>>>0){Na=pa&65535}else{Na=-pa>>31&1023}b[ea>>1]=Na}if(!la){break}pa=((wa+1+va|0)>>>1)-za-Ja>>1;if((pa|0)<(ma|0)){Oa=ma}else{Oa=(pa|0)>($|0)?$:pa}pa=Oa+za|0;if(pa>>>0<1024>>>0){Pa=pa&65535}else{Pa=-pa>>31&1023}b[ya>>1]=Pa}}while(0);ya=Y+(f<<1)|0;if((ka|0)>=4){break}za=b[Y+(f+g<<1)>>1]|0;va=b[Y+(f+m<<1)>>1]|0;wa=b[Y+(f-l<<1)>>1]|0;ea=b[Y+(f+l<<1)>>1]|0;ca=b[Y+(f+o<<1)>>1]|0;Y=ya;ka=ka+1|0;ja=za;ia=va;ha=wa;ga=b[ya>>1]|0;fa=ea;ba=ca}Ia=B+(A<<1)|0}else{Ia=B+(z<<1)|0}}while(0);U=d+1|0;if((U|0)<2){B=Ia;d=U}else{break}}return}function REa(a,d,f,g,h,j,k,l,m){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;n=i;i=i+128|0;o=n|0;p=a;a=d;TGb(o|0,0,128)|0;d=(l|0)!=0|0;q=c[g+96+(l<<2)>>2]|0;r=f>>>1;do{if((m|0)==1){f=4>>>(d>>>0);if((c[h+8>>2]|0)==0){s=j-2-(8>>>(d>>>0))|0}else{s=j}t=0;u=-2-f|0;v=s;w=f+2|0}else if((m|0)==0){if((c[h+8>>2]|0)==0){x=j-2-(8>>>(d>>>0))|0}else{x=j}if((c[h+12>>2]|0)!=0){t=0;u=0;v=x;w=k;break}t=0;u=0;v=x;w=k-2-(4>>>(d>>>0))|0}else if((m|0)==2){f=8>>>(d>>>0);y=-2-f|0;z=f+2|0;if((c[h+12>>2]|0)!=0){t=y;u=0;v=z;w=k;break}t=y;u=0;v=z;w=k-2-(4>>>(d>>>0))|0}else if((m|0)==3){z=4>>>(d>>>0);y=8>>>(d>>>0);t=-2-y|0;u=-2-z|0;v=y+2|0;w=z+2|0}else{t=0;u=0;v=j;w=k}}while(0);k=(ba(u,r)|0)+t|0;c[o+((q&31)<<2)>>2]=c[g+120+(l*20|0)+4>>2];c[o+((q+1&31)<<2)>>2]=c[g+120+(l*20|0)+8>>2];c[o+((q+2&31)<<2)>>2]=c[g+120+(l*20|0)+12>>2];c[o+((q+3&31)<<2)>>2]=c[g+120+(l*20|0)+16>>2];if((w|0)<=0){i=n;return}l=(v|0)>0;g=a+(k<<1)|0;a=0;q=p+(k<<1)|0;while(1){if(l){k=0;do{p=e[g+(k<<1)>>1]|0;t=p+(c[o+(p>>>5<<2)>>2]|0)|0;if(t>>>0<1024>>>0){A=t&65535}else{A=-t>>31&1023}b[q+(k<<1)>>1]=A;k=k+1|0;}while((k|0)<(v|0))}k=a+1|0;if((k|0)<(w|0)){g=g+(r<<1)|0;a=k;q=q+(r<<1)|0}else{break}}i=n;return}function SEa(d,f,g,h,i,j){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=d;d=f>>>1;f=g>>>1;g=d*-2|0;l=-d|0;m=c[h>>2]<<1;if((m|0)>=1){n=-m|0;o=(a[i]|0)==0;p=(a[j]|0)==0;q=k;r=0;while(1){s=q+(l<<1)|0;t=e[s>>1]|0;u=e[q>>1]|0;v=(e[q+(g<<1)>>1]|0)+4-(e[q+(d<<1)>>1]|0)+(u-t<<2)>>3;if((v|0)<(n|0)){w=n}else{w=(v|0)>(m|0)?m:v}if(o){v=w+t|0;if(v>>>0<512>>>0){x=v&65535}else{x=-v>>31&511}b[s>>1]=x}if(p){s=u-w|0;if(s>>>0<512>>>0){y=s&65535}else{y=-s>>31&511}b[q>>1]=y}s=r+1|0;if((s|0)<4){q=q+(f<<1)|0;r=s}else{break}}}r=c[h+4>>2]<<1;if((r|0)<1){return}h=-r|0;q=(a[i+1|0]|0)==0;i=(a[j+1|0]|0)==0;j=k+(f<<2<<1)|0;k=0;while(1){y=j+(l<<1)|0;w=e[y>>1]|0;p=e[j>>1]|0;x=(e[j+(g<<1)>>1]|0)+4-(e[j+(d<<1)>>1]|0)+(p-w<<2)>>3;if((x|0)<(h|0)){z=h}else{z=(x|0)>(r|0)?r:x}if(q){x=z+w|0;if(x>>>0<512>>>0){A=x&65535}else{A=-x>>31&511}b[y>>1]=A}if(i){y=p-z|0;if(y>>>0<512>>>0){B=y&65535}else{B=-y>>31&511}b[j>>1]=B}y=k+1|0;if((y|0)<4){j=j+(f<<1)|0;k=y}else{break}}return}function TEa(d,f,g,h,i,j,k){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;l=f>>>1;f=g>>>1;g=l*-3|0;m=l*-2|0;n=-l|0;o=l<<1;p=f*3|0;q=p+g|0;r=p+m|0;s=p-l|0;t=p+o|0;u=p+l|0;v=l*-4|0;w=l*3|0;x=p+v|0;y=(f+l|0)*3|0;z=f<<2;A=f<<2;B=d;d=0;while(1){C=b[B+(g<<1)>>1]|0;D=b[B+(m<<1)>>1]|0;E=b[B+(n<<1)>>1]|0;F=E&65535;G=(C&65535)-((D&65535)<<1)+F|0;H=(G|0)>-1?G:-G|0;G=b[B+(o<<1)>>1]|0;I=b[B+(l<<1)>>1]|0;J=b[B>>1]|0;K=J&65535;L=(G&65535)-((I&65535)<<1)+K|0;M=(L|0)>-1?L:-L|0;L=e[B+(s<<1)>>1]|0;N=(e[B+(q<<1)>>1]|0)-((e[B+(r<<1)>>1]|0)<<1)+L|0;O=(N|0)>-1?N:-N|0;N=e[B+(p<<1)>>1]|0;P=(e[B+(t<<1)>>1]|0)-((e[B+(u<<1)>>1]|0)<<1)+N|0;Q=(P|0)>-1?P:-P|0;P=M+H|0;R=Q+O|0;S=c[h+(d<<2)>>2]<<1;T=c[i+(d<<2)>>2]|0;U=T<<1;V=a[j+d|0]|0;W=a[k+d|0]|0;a:do{if((R+P|0)<(S|0)){X=S>>3;Y=S>>2;Z=(T*10|0)>>1;_=(e[B+(v<<1)>>1]|0)-F|0;$=b[B+(w<<1)>>1]|0;aa=($&65535)-K|0;do{if((((aa|0)>-1?aa:-aa|0)+((_|0)>-1?_:-_|0)|0)<(X|0)){ba=F-K|0;if((((ba|0)>-1?ba:-ba|0)|0)>=(Z|0)){break}ba=(e[B+(x<<1)>>1]|0)-L|0;ca=(e[B+(y<<1)>>1]|0)-N|0;if((((ca|0)>-1?ca:-ca|0)+((ba|0)>-1?ba:-ba|0)|0)>=(X|0)){break}ba=L-N|0;if((((ba|0)>-1?ba:-ba|0)|0)>=(Z|0)){break}if((P<<1|0)>=(Y|0)){break}if((R<<1|0)>=(Y|0)){break}ba=T<<2;ca=V<<24>>24==0;da=-ba|0;ea=W<<24>>24==0;fa=B;ga=1;ha=C;ia=D;ja=E;ka=J;la=I;ma=G;na=$;while(1){oa=fa+(g<<1)|0;pa=ha&65535;qa=fa+(m<<1)|0;ra=ia&65535;sa=fa+(n<<1)|0;ta=ja&65535;ua=ka&65535;va=fa+(l<<1)|0;wa=la&65535;xa=fa+(o<<1)|0;ya=ma&65535;za=na&65535;if(ca){Aa=e[fa+(v<<1)>>1]|0;Ba=(pa+4+wa+(ta+ra+ua<<1)>>3)-ta|0;if((Ba|0)<(da|0)){Ca=da}else{Ca=(Ba|0)>(ba|0)?ba:Ba}b[sa>>1]=Ca+ta;sa=((pa+2+ra+ta+ua|0)>>>2)-ra|0;if((sa|0)<(da|0)){Da=da}else{Da=(sa|0)>(ba|0)?ba:sa}b[qa>>1]=Da+ra;qa=((pa*3|0)+4+ra+ta+ua+(Aa<<1)>>3)-pa|0;if((qa|0)<(da|0)){Ea=da}else{Ea=(qa|0)>(ba|0)?ba:qa}b[oa>>1]=Ea+pa}if(ea){pa=(ra+4+ya+(ua+ta+wa<<1)>>3)-ua|0;if((pa|0)<(da|0)){Fa=da}else{Fa=(pa|0)>(ba|0)?ba:pa}b[fa>>1]=Fa+ua;pa=((ta+2+ua+wa+ya|0)>>>2)-wa|0;if((pa|0)<(da|0)){Ga=da}else{Ga=(pa|0)>(ba|0)?ba:pa}b[va>>1]=Ga+wa;va=(ta+4+ua+wa+(ya*3|0)+(za<<1)>>3)-ya|0;if((va|0)<(da|0)){Ha=da}else{Ha=(va|0)>(ba|0)?ba:va}b[xa>>1]=Ha+ya}ya=fa+(f<<1)|0;if((ga|0)>=4){break}xa=b[fa+(f+g<<1)>>1]|0;va=b[fa+(f+m<<1)>>1]|0;za=b[fa+(f-l<<1)>>1]|0;wa=b[fa+(f+l<<1)>>1]|0;ua=b[fa+(f+o<<1)>>1]|0;ta=b[fa+(f+w<<1)>>1]|0;fa=ya;ga=ga+1|0;ha=xa;ia=va;ja=za;ka=b[ya>>1]|0;la=wa;ma=ua;na=ta}Ia=B+(A<<1)|0;break a}}while(0);$=U>>1;Y=(S>>1)+S>>3;Z=T*20|0;X=-U|0;_=V<<24>>24!=0;aa=W<<24>>24!=0;na=(O+H|0)<(Y|0)&(_^1);ma=-$|0;la=(Q+M|0)<(Y|0)&(aa^1);Y=B;ka=1;ja=C;ia=D;ha=E;ga=J;fa=I;ba=G;while(1){da=ja&65535;ea=Y+(m<<1)|0;ca=ia&65535;ta=Y+(n<<1)|0;ua=ha&65535;wa=ga&65535;ya=Y+(l<<1)|0;za=fa&65535;va=ba&65535;xa=((wa-ua|0)*9|0)+8+((za-ca|0)*-3|0)>>4;do{if((((xa|0)>-1?xa:-xa|0)|0)<(Z|0)){if((xa|0)<(X|0)){Ja=X}else{Ja=(xa|0)>(U|0)?U:xa}if(!_){pa=Ja+ua|0;if(pa>>>0<512>>>0){Ka=pa&65535}else{Ka=-pa>>31&511}b[ta>>1]=Ka}if(!aa){pa=wa-Ja|0;if(pa>>>0<512>>>0){La=pa&65535}else{La=-pa>>31&511}b[Y>>1]=La}if(na){pa=((da+1+ua|0)>>>1)-ca+Ja>>1;if((pa|0)<(ma|0)){Ma=ma}else{Ma=(pa|0)>($|0)?$:pa}pa=Ma+ca|0;if(pa>>>0<512>>>0){Na=pa&65535}else{Na=-pa>>31&511}b[ea>>1]=Na}if(!la){break}pa=((wa+1+va|0)>>>1)-za-Ja>>1;if((pa|0)<(ma|0)){Oa=ma}else{Oa=(pa|0)>($|0)?$:pa}pa=Oa+za|0;if(pa>>>0<512>>>0){Pa=pa&65535}else{Pa=-pa>>31&511}b[ya>>1]=Pa}}while(0);ya=Y+(f<<1)|0;if((ka|0)>=4){break}za=b[Y+(f+g<<1)>>1]|0;va=b[Y+(f+m<<1)>>1]|0;wa=b[Y+(f-l<<1)>>1]|0;ea=b[Y+(f+l<<1)>>1]|0;ca=b[Y+(f+o<<1)>>1]|0;Y=ya;ka=ka+1|0;ja=za;ia=va;ha=wa;ga=b[ya>>1]|0;fa=ea;ba=ca}Ia=B+(A<<1)|0}else{Ia=B+(z<<1)|0}}while(0);U=d+1|0;if((U|0)<2){B=Ia;d=U}else{break}}return}function UEa(a,d,f,g,h,j,k,l,m){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;n=i;i=i+128|0;o=n|0;p=a;a=d;TGb(o|0,0,128)|0;d=(l|0)!=0|0;q=c[g+96+(l<<2)>>2]|0;r=f>>>1;do{if((m|0)==1){f=4>>>(d>>>0);if((c[h+8>>2]|0)==0){s=j-2-(8>>>(d>>>0))|0}else{s=j}t=0;u=-2-f|0;v=s;w=f+2|0}else if((m|0)==0){if((c[h+8>>2]|0)==0){x=j-2-(8>>>(d>>>0))|0}else{x=j}if((c[h+12>>2]|0)!=0){t=0;u=0;v=x;w=k;break}t=0;u=0;v=x;w=k-2-(4>>>(d>>>0))|0}else if((m|0)==2){f=8>>>(d>>>0);y=-2-f|0;z=f+2|0;if((c[h+12>>2]|0)!=0){t=y;u=0;v=z;w=k;break}t=y;u=0;v=z;w=k-2-(4>>>(d>>>0))|0}else if((m|0)==3){z=4>>>(d>>>0);y=8>>>(d>>>0);t=-2-y|0;u=-2-z|0;v=y+2|0;w=z+2|0}else{t=0;u=0;v=j;w=k}}while(0);k=(ba(u,r)|0)+t|0;c[o+((q&31)<<2)>>2]=c[g+120+(l*20|0)+4>>2];c[o+((q+1&31)<<2)>>2]=c[g+120+(l*20|0)+8>>2];c[o+((q+2&31)<<2)>>2]=c[g+120+(l*20|0)+12>>2];c[o+((q+3&31)<<2)>>2]=c[g+120+(l*20|0)+16>>2];if((w|0)>0&(v|0)>0){A=a+(k<<1)|0;B=0;C=p+(k<<1)|0}else{i=n;return}while(1){k=0;do{p=e[A+(k<<1)>>1]|0;a=p+(c[o+(p>>>4<<2)>>2]|0)|0;if(a>>>0<512>>>0){D=a&65535}else{D=-a>>31&511}b[C+(k<<1)>>1]=D;k=k+1|0;}while((k|0)<(v|0));k=B+1|0;if((k|0)<(w|0)){A=A+(r<<1)|0;B=k;C=C+(r<<1)|0}else{break}}i=n;return}function VEa(a,b){a=a|0;b=b|0;if((b|0)==9){c[a>>2]=114;c[a+4>>2]=276;c[a+8>>2]=406;c[a+12>>2]=482;c[a+16>>2]=872;c[a+20>>2]=170;c[a+24>>2]=70;c[a+28>>2]=186;c[a+32>>2]=156;c[a+36>>2]=260;return}else if((b|0)==10){c[a>>2]=152;c[a+4>>2]=332;c[a+8>>2]=586;c[a+12>>2]=330;c[a+16>>2]=584;c[a+20>>2]=28;c[a+24>>2]=134;c[a+28>>2]=216;c[a+32>>2]=132;c[a+36>>2]=214;return}else{c[a>>2]=116;c[a+4>>2]=278;c[a+8>>2]=614;c[a+12>>2]=484;c[a+16>>2]=870;c[a+20>>2]=30;c[a+24>>2]=68;c[a+28>>2]=188;c[a+32>>2]=154;c[a+36>>2]=262;return}}function WEa(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;l=i;i=i+544|0;m=l|0;n=l+136|0;o=l+272|0;p=l+408|0;q=c[f+136>>2]|0;r=c[f+180>>2]|0;s=c[r+13140+(k<<2)>>2]|0;t=c[r+13152+(k<<2)>>2]|0;u=1<<j;v=u<<s;w=c[r+13072>>2]|0;x=v>>w;y=g>>w;z=h>>w;w=c[r+13124>>2]|0;A=(ba(z,w)|0)+y|0;B=c[f+184>>2]|0;C=c[B+1672>>2]|0;D=c[C+(A<<2)>>2]|0;A=c[f+160>>2]|0;E=(c[A+32+(k<<2)>>2]|0)>>>1;F=c[A+(k<<2)>>2]|0;A=(ba(E,h>>t)|0)+(g>>s)|0;G=F+(A<<1)|0;H=c[r+13132>>2]|0;if((k|0)==0){I=c[q+173192>>2]|0}else{I=d[q+184621|0]|0}J=m+2|0;K=o+2|0;L=n+2|0;M=p+2|0;if((c[q+184624>>2]|0)==0){N=0}else{N=(D|0)>(c[C+(y-1+(ba(w,z+x|0)|0)<<2)>>2]|0)}O=N&1;P=c[q+184628>>2]|0;Q=c[q+184636>>2]|0;R=c[q+184632>>2]|0;if((c[q+184640>>2]|0)==0){S=0}else{S=(D|0)>(c[C+(y+x+(ba(w,z-1|0)|0)<<2)>>2]|0)}z=S&1;w=v<<1;x=w+h|0;y=c[r+13100>>2]|0;C=v+h|0;D=((x|0)>(y|0)?y:x)-C>>t;x=w+g|0;w=c[r+13096>>2]|0;q=v+g|0;T=((x|0)>(w|0)?w:x)-q>>s;x=B+20|0;if((a[x]|0)==1){B=c[r+13084>>2]|0;U=v>>B;v=(1<<B)-1|0;V=v&h;W=((U|0)==0)+U|0;U=(v&g|0)!=0;do{if(U|N^1){X=O}else{v=g-1>>B;Y=C>>B;Z=(c[r+13136>>2]|0)-Y|0;_=(W|0)>(Z|0)?Z:W;if((_|0)<=0){X=0;break}Z=c[(c[f+3480>>2]|0)+16>>2]|0;$=0;aa=0;while(1){ca=d[Z+(((ba(aa+Y|0,H)|0)+v|0)*14|0)+12|0]|$;da=aa+1|0;if((da|0)<(_|0)){$=ca;aa=da}else{X=ca;break}}}}while(0);do{if((P|0)!=1|U){ea=P}else{C=g-1>>B;N=h>>B;aa=(c[r+13136>>2]|0)-N|0;$=(W|0)>(aa|0)?aa:W;if(($|0)<=0){ea=0;break}aa=c[(c[f+3480>>2]|0)+16>>2]|0;_=0;v=0;while(1){Y=d[aa+(((ba(v+N|0,H)|0)+C|0)*14|0)+12|0]|_;Z=v+1|0;if((Z|0)<($|0)){_=Y;v=Z}else{ea=Y;break}}}}while(0);if((Q|0)==1){U=(ba(h-1>>B,H)|0)+(g-1>>B)|0;fa=d[(c[(c[f+3480>>2]|0)+16>>2]|0)+(U*14|0)+12|0]|0}else{fa=Q}U=(V|0)!=0;do{if((R|0)!=1|U){ga=R}else{V=g>>B;v=H-V|0;_=(W|0)>(v|0)?v:W;if((_|0)<=0){ga=0;break}v=(ba(h-1>>B,H)|0)+V|0;V=c[(c[f+3480>>2]|0)+16>>2]|0;$=0;C=0;while(1){N=d[V+((v+C|0)*14|0)+12|0]|$;aa=C+1|0;if((aa|0)<(_|0)){$=N;C=aa}else{ga=N;break}}}}while(0);do{if(U|S^1){ha=z}else{C=q>>B;$=H-C|0;_=(W|0)>($|0)?$:W;if((_|0)<=0){ha=0;break}$=(ba(h-1>>B,H)|0)+C|0;C=c[(c[f+3480>>2]|0)+16>>2]|0;v=0;V=0;while(1){N=d[C+(($+V|0)*14|0)+12|0]|v;aa=V+1|0;if((aa|0)<(_|0)){v=N;V=aa}else{ha=N;break}}}}while(0);B=0;while(1){W=B+1|0;b[m+(W<<1)>>1]=128;b[o+(W<<1)>>1]=128;if((W|0)<64){B=W}else{ia=X;ja=ea;ka=fa;la=ga;ma=ha;break}}}else{ia=O;ja=P;ka=Q;la=R;ma=z}z=(ia|0)!=0;do{if(z){R=D+u|0;Q=u<<1;if((R|0)<(Q|0)){P=(-1<<s)+g|0;O=R-1|0;ha=(O<<t)+h|0;ga=F+(A-1+(ba(O,E)|0)<<1)|0;fa=c[r+13084>>2]|0;ea=c[(c[f+3480>>2]|0)+16>>2]|0;X=R;while(1){do{if((a[ea+(((ba(ha>>fa,H)|0)+(P>>fa)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=38;break}oa=X+1|0}else{na=38}}while(0);if((na|0)==38){na=0;B=X+1|0;b[m+(B<<1)>>1]=b[ga>>1]|0;oa=B}if((oa|0)<(Q|0)){X=oa}else{pa=O;break}}}else{pa=R-1|0}if((pa|0)<(u|0)){break}O=(-1<<s)+g|0;X=A-1|0;Q=c[r+13084>>2]|0;ga=c[(c[f+3480>>2]|0)+16>>2]|0;fa=R;P=pa;while(1){if((a[ga+(((ba((P<<t)+h>>Q,H)|0)+(O>>Q)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=43}}else{na=43}if((na|0)==43){na=0;b[m+(fa<<1)>>1]=b[F+(X+(ba(P,E)|0)<<1)>>1]|0}ha=P-1|0;if((ha|0)<(u|0)){break}else{fa=P;P=ha}}}}while(0);pa=(ja|0)!=0;if(pa&(u|0)>0){oa=(-1<<s)+g|0;P=A-1|0;fa=c[r+13084>>2]|0;X=c[(c[f+3480>>2]|0)+16>>2]|0;Q=u;while(1){O=Q-1|0;if((a[X+(((ba((O<<t)+h>>fa,H)|0)+(oa>>fa)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=49}}else{na=49}if((na|0)==49){na=0;b[m+(Q<<1)>>1]=b[F+(P+(ba(O,E)|0)<<1)>>1]|0}if((O|0)>0){Q=O}else{break}}}Q=(ka|0)!=0;do{if(Q){P=c[r+13084>>2]|0;fa=(ba((-1<<t)+h>>P,H)|0)+((-1<<s)+g>>P)|0;if((a[(c[(c[f+3480>>2]|0)+16>>2]|0)+(fa*14|0)+12|0]|0)==0){if((a[x]|0)!=0){break}}fa=b[F+(A+~E<<1)>>1]|0;b[m>>1]=fa;b[o>>1]=fa}}while(0);fa=(la|0)!=0;if(fa&(u|0)>0){P=(-1<<t)+h|0;oa=A-E|0;X=c[r+13084>>2]|0;O=c[(c[f+3480>>2]|0)+16>>2]|0;ga=u;while(1){R=ga-1|0;if((a[O+(((ba(P>>X,H)|0)+((R<<s)+g>>X)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=59}}else{na=59}if((na|0)==59){na=0;b[o+(ga<<1)>>1]=b[F+(oa+R<<1)>>1]|0}if((R|0)>0){ga=R}else{break}}}ga=(ma|0)!=0;do{if(ga){oa=T+u|0;X=u<<1;P=oa-1|0;if((oa|0)<(X|0)){O=(P<<s)+g|0;R=(-1<<t)+h|0;ha=F+(A-E+P<<1)|0;ea=c[r+13084>>2]|0;B=c[(c[f+3480>>2]|0)+16>>2]|0;W=oa;while(1){do{if((a[B+(((ba(R>>ea,H)|0)+(O>>ea)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=68;break}qa=W+1|0}else{na=68}}while(0);if((na|0)==68){na=0;S=W+1|0;b[o+(S<<1)>>1]=b[ha>>1]|0;qa=S}if((qa|0)<(X|0)){W=qa}else{break}}}if((P|0)<(u|0)){break}W=(-1<<t)+h|0;X=A-E|0;ha=c[r+13084>>2]|0;ea=c[(c[f+3480>>2]|0)+16>>2]|0;O=oa;R=P;while(1){if((a[ea+(((ba(W>>ha,H)|0)+((R<<s)+g>>ha)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=73}}else{na=73}if((na|0)==73){na=0;b[o+(O<<1)>>1]=b[F+(X+R<<1)>>1]|0}B=R-1|0;if((B|0)<(u|0)){break}else{O=R;R=B}}}}while(0);do{if((a[x]|0)==1){F=ia|ja;A=(F|0)!=0;qa=F|ka;F=(qa|0)==0;if((la|ma|qa|0)==0){break}qa=u<<1;if(((qa<<s)+g|0)<(w|0)){ra=qa}else{ra=w-g>>s}if(((qa<<t)+h|0)<(y|0)){sa=qa}else{sa=y-h>>t}T=(z?D:0)+u|0;do{if(ga){ta=ra}else{if((q|0)<(w|0)){ta=u;break}ta=w-g>>s}}while(0);do{if(z){ua=sa}else{if(((u<<t)+h|0)<(y|0)){ua=u;break}ua=y-h>>t}}while(0);do{if(F){R=(-1<<t)+h|0;O=f+3480|0;X=0;while(1){if((X|0)>=(ta|0)){break}ha=c[r+13084>>2]|0;W=(ba(R>>ha,H)|0)+((X<<s)+g>>ha)|0;if((a[(c[(c[O>>2]|0)+16>>2]|0)+(W*14|0)+12|0]|0)==0){X=X+1|0}else{break}}do{if((X|0)>0){if((g|0)>0){if(!((X|0)>-1)){break}W=c[r+13084>>2]|0;ha=c[(c[O>>2]|0)+16>>2]|0;ea=X;while(1){P=ea-1|0;if((a[ha+(((ba(R>>W,H)|0)+((P<<s)+g>>W)|0)*14|0)+12|0]|0)==0){b[o+(ea<<1)>>1]=b[o+(ea+1<<1)>>1]|0}if((ea|0)>0){ea=P}else{break}}}else{ea=c[r+13084>>2]|0;W=c[(c[O>>2]|0)+16>>2]|0;ha=X;while(1){P=ha-1|0;if((a[W+(((ba(R>>ea,H)|0)+((P<<s)+g>>ea)|0)*14|0)+12|0]|0)==0){b[o+(ha<<1)>>1]=b[o+(ha+1<<1)>>1]|0}if((P|0)>0){ha=P}else{break}}b[o>>1]=b[K>>1]|0;break}}}while(0);b[m>>1]=b[o>>1]|0;va=0}else{R=(-1<<s)+g|0;X=f+3480|0;O=T;while(1){wa=O-1|0;xa=c[r+13084>>2]|0;if((O|0)<=0){na=90;break}ha=(wa<<t)+h|0;ea=(ba(ha>>xa,H)|0)+(R>>xa)|0;W=c[(c[X>>2]|0)+16>>2]|0;if((a[W+(ea*14|0)+12|0]|0)==0){O=wa}else{ya=W;za=ha;break}}if((na|0)==90){ya=c[(c[X>>2]|0)+16>>2]|0;za=(wa<<t)+h|0}if((a[ya+(((ba(za>>xa,H)|0)+(R>>xa)|0)*14|0)+12|0]|0)!=0){va=wa;break}O=(-1<<t)+h|0;ha=0;while(1){if((ha|0)>=(ta|0)){break}if((a[ya+(((ba(O>>xa,H)|0)+((ha<<s)+g>>xa)|0)*14|0)+12|0]|0)==0){ha=ha+1|0}else{break}}if((ha|0)>-1){R=ha;while(1){X=R-1|0;if((a[ya+(((ba(O>>xa,H)|0)+((X<<s)+g>>xa)|0)*14|0)+12|0]|0)==0){b[o+(R<<1)>>1]=b[o+(R+1<<1)>>1]|0}if((R|0)>0){R=X}else{break}}}b[m>>1]=b[o>>1]|0;va=0}}while(0);if(A&(va|0)<(ua|0)){T=(-1<<s)+g|0;F=c[r+13084>>2]|0;R=c[(c[f+3480>>2]|0)+16>>2]|0;O=va;while(1){if((a[R+(((ba((O<<t)+h>>F,H)|0)+(T>>F)|0)*14|0)+12|0]|0)==0){ha=O+1|0;b[m+(ha<<1)>>1]=b[m+(O<<1)>>1]|0;Aa=ha}else{Aa=O+1|0}if((Aa|0)<(ua|0)){O=Aa}else{break}}}a:do{if((u|0)>0&(pa^1)){O=b[m>>1]|0;F=1;while(1){b[m+(F<<1)>>1]=O;if((F|0)>=(u|0)){break a}F=F+1|0}}}while(0);if((u|0)<(qa|0)&(z^1)){F=b[m+(u<<1)>>1]|0;O=u;do{O=O+1|0;b[m+(O<<1)>>1]=F;}while((O|0)<(qa|0))}qa=(g|0)==0;O=(h|0)==0;b:do{if(qa|O){F=ua-1|0;if(qa){if((ua|0)<=0){break}T=b[m+(ua<<1)>>1]|0;R=F;while(1){b[m+(R<<1)>>1]=T;if((R|0)>0){R=R-1|0}else{break b}}}if((F|0)<=0){break}R=(-1<<s)+g|0;T=c[r+13084>>2]|0;A=c[(c[f+3480>>2]|0)+16>>2]|0;ha=F;while(1){X=ha-1|0;if((a[A+(((ba((X<<t)+h>>T,H)|0)+(R>>T)|0)*14|0)+12|0]|0)==0){b[m+(ha<<1)>>1]=b[m+(ha+1<<1)>>1]|0}if((X|0)>0){ha=X}else{break}}}else{if((ua|0)<=0){break}ha=(-1<<s)+g|0;T=c[r+13084>>2]|0;R=c[(c[f+3480>>2]|0)+16>>2]|0;A=ua;while(1){F=A-1|0;if((a[R+(((ba((A-2<<t)+h>>T,H)|0)+(ha>>T)|0)*14|0)+12|0]|0)==0){b[m+(F<<1)>>1]=b[m+(A<<1)>>1]|0}if((F|0)>0){A=F}else{break}}}}while(0);b[o>>1]=b[m>>1]|0;if(!((ta|0)>0&(O^1))){break}qa=(-1<<t)+h|0;A=c[r+13084>>2]|0;T=c[(c[f+3480>>2]|0)+16>>2]|0;ha=0;while(1){if((a[T+(((ba(qa>>A,H)|0)+((ha<<s)+g>>A)|0)*14|0)+12|0]|0)==0){R=ha+1|0;b[o+(R<<1)>>1]=b[o+(ha<<1)>>1]|0;Ba=R}else{Ba=ha+1|0}if((Ba|0)<(ta|0)){ha=Ba}else{break}}}}while(0);c:do{if(z){na=176}else{if(pa){Ba=u<<1;if((u|0)>=(Ba|0)){na=176;break}ta=b[m+(u<<1)>>1]|0;g=u;while(1){s=g+1|0;b[m+(s<<1)>>1]=ta;if((s|0)<(Ba|0)){g=s}else{na=176;break c}}}if(Q){g=u<<1;if((g|0)<=0){na=178;break}Ba=b[m>>1]|0;ta=1;while(1){b[m+(ta<<1)>>1]=Ba;if((ta|0)>=(g|0)){na=178;break c}ta=ta+1|0}}if(fa){ta=b[K>>1]|0;b[m>>1]=ta;g=u<<1;if((g|0)>0){Ca=1}else{na=180;break}while(1){b[m+(Ca<<1)>>1]=ta;if((Ca|0)>=(g|0)){na=180;break c}Ca=Ca+1|0}}if(ga){if((u|0)>0){g=u;do{b[o+(g<<1)>>1]=b[o+(g+1<<1)>>1]|0;g=g-1|0;}while((g|0)>0)}g=b[K>>1]|0;b[m>>1]=g;ta=u<<1;if((ta|0)>0){Da=1}else{break}while(1){b[m+(Da<<1)>>1]=g;if((Da|0)>=(ta|0)){break c}Da=Da+1|0}}b[m>>1]=256;b[K>>1]=256;ta=u<<1;d:do{if((ta|0)>1){g=2;while(1){b[o+(g<<1)>>1]=256;if((g|0)>=(ta|0)){break d}g=g+1|0}}}while(0);if((ta|0)>0){Ea=1}else{na=176;break}while(1){b[m+(Ea<<1)>>1]=256;if((Ea|0)>=(ta|0)){na=176;break c}Ea=Ea+1|0}}}while(0);do{if((na|0)==176){if((ja|0)==0&(u|0)>0){Fa=u}else{na=178;break}while(1){b[m+(Fa<<1)>>1]=b[m+(Fa+1<<1)>>1]|0;Ea=Fa-1|0;if((Ea|0)>0){Fa=Ea}else{na=178;break}}}}while(0);do{if((na|0)==178){if((ka|0)!=0){na=180;break}b[m>>1]=b[J>>1]|0;na=180}}while(0);e:do{if((na|0)==180){if((la|0)!=0){break}ka=b[m>>1]|0;b[K>>1]=ka;if((u|0)>1){Ga=2}else{break}while(1){b[o+(Ga<<1)>>1]=ka;if((Ga|0)>=(u|0)){break e}Ga=Ga+1|0}}}while(0);do{if(!ga){Ga=u<<1;if((u|0)>=(Ga|0)){break}la=b[o+(u<<1)>>1]|0;na=u;do{na=na+1|0;b[o+(na<<1)>>1]=la;}while((na|0)<(Ga|0))}}while(0);ga=m|0;Ga=b[ga>>1]|0;b[o>>1]=Ga;f:do{if((k|0)!=0|(I|0)==1|(u|0)==4){Ha=J;Ia=K}else{na=I-26|0;la=(na|0)>-1?na:26-I|0;na=I-10|0;ka=(na|0)>-1?na:10-I|0;if((((la|0)>(ka|0)?ka:la)|0)<=(c[906616+(j-3<<2)>>2]|0)){Ha=J;Ia=K;break}do{if((a[r+13061|0]|0)!=0&(j|0)==5){la=Ga&65535;ka=b[o+128>>1]|0;na=ka&65535;Fa=na+la-(e[o+64>>1]<<1)|0;if((((Fa|0)>-1?Fa:-Fa|0)|0)>=16){break}Fa=m+128|0;ja=b[Fa>>1]|0;Ea=(ja&65535)+la-(e[m+64>>1]<<1)|0;if((((Ea|0)>-1?Ea:-Ea|0)|0)>=16){break}b[p>>1]=Ga;b[p+128>>1]=ka;ka=0;while(1){Ea=ka+1|0;b[p+(Ea<<1)>>1]=((ba(la,63-ka|0)|0)+32+(ba(na,Ea)|0)|0)>>>6;if((Ea|0)<63){ka=Ea}else{Ja=0;Ka=Ga;La=ja;break}}while(1){ja=Ja+1|0;b[m+(ja<<1)>>1]=((ba(Ka&65535,63-Ja|0)|0)+32+(ba(La&65535,ja)|0)|0)>>>6;if((ja|0)>=63){Ha=J;Ia=M;break f}Ja=ja;Ka=b[ga>>1]|0;La=b[Fa>>1]|0}}}while(0);Fa=u<<1;ja=b[m+(Fa<<1)>>1]|0;b[n+(Fa<<1)>>1]=ja;ka=b[o+(Fa<<1)>>1]|0;b[p+(Fa<<1)>>1]=ka;na=Fa-2|0;Fa=(na|0)>-1;if(Fa){la=na;Ea=ja;while(1){ja=la+1|0;Da=b[m+(ja<<1)>>1]|0;b[n+(ja<<1)>>1]=((Ea&65535)+2+((Da&65535)<<1)+(e[m+(la<<1)>>1]|0)|0)>>>2;if((la|0)>0){la=la-1|0;Ea=Da}else{break}}}Ea=((e[J>>1]|0)+2+((Ga&65535)<<1)+(e[K>>1]|0)|0)>>>2&65535;b[n>>1]=Ea;b[p>>1]=Ea;if(Fa){Ma=na;Na=ka}else{Ha=L;Ia=M;break}while(1){Ea=Ma+1|0;la=b[o+(Ea<<1)>>1]|0;b[p+(Ea<<1)>>1]=((Na&65535)+2+((la&65535)<<1)+(e[o+(Ma<<1)>>1]|0)|0)>>>2;if((Ma|0)>0){Ma=Ma-1|0;Na=la}else{Ha=L;Ia=M;break}}}}while(0);if((I|0)==1){Se[c[f+5840>>2]&511](G,Ia,Ha,E,j,k);i=l;return}else if((I|0)==0){cf[c[f+5824+(j-2<<2)>>2]&1023](G,Ia,Ha,E);i=l;return}else{Se[c[f+5844+(j-2<<2)>>2]&511](G,Ia,Ha,E,k,I);i=l;return}}function XEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=a;a=c;h=d;i=c+8|0;j=d+8|0;d=0;while(1){k=h+(d<<1)|0;l=3-d|0;m=d+1|0;n=ba(d,f)|0;o=ba(e[a>>1]|0,l)|0;b[g+(n<<1)>>1]=(((e[k>>1]|0)*3|0)+4+(e[i>>1]|0)+o+(ba(e[j>>1]|0,m)|0)|0)>>>3;o=ba(e[c+2>>1]|0,l)|0;b[g+(n+1<<1)>>1]=(((e[k>>1]|0)<<1)+4+((e[i>>1]|0)<<1)+o+(ba(e[j>>1]|0,m)|0)|0)>>>3;o=ba(e[c+4>>1]|0,l)|0;b[g+(n+2<<1)>>1]=((e[k>>1]|0)+4+((e[i>>1]|0)*3|0)+o+(ba(e[j>>1]|0,m)|0)|0)>>>3;o=ba(e[c+6>>1]|0,l)|0;b[g+(n+3<<1)>>1]=(((e[i>>1]|0)<<2)+4+o+(ba(e[j>>1]|0,m)|0)|0)>>>3;if((m|0)<4){d=m}else{break}}return}function YEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+16|0;c=d+16|0;d=0;while(1){j=h+(d<<1)|0;k=7-d|0;l=d+1|0;m=ba(d,f)|0;n=0;while(1){o=ba(e[j>>1]|0,7-n|0)|0;p=n+1|0;q=ba(e[i>>1]|0,p)|0;r=ba(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+8+q+r+(ba(e[c>>1]|0,l)|0)|0)>>>4;if((p|0)<8){n=p}else{break}}if((l|0)<8){d=l}else{break}}return}function ZEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+32|0;c=d+32|0;d=0;while(1){j=h+(d<<1)|0;k=15-d|0;l=d+1|0;m=ba(d,f)|0;n=0;while(1){o=ba(e[j>>1]|0,15-n|0)|0;p=n+1|0;q=ba(e[i>>1]|0,p)|0;r=ba(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+16+q+r+(ba(e[c>>1]|0,l)|0)|0)>>>5;if((p|0)<16){n=p}else{break}}if((l|0)<16){d=l}else{break}}return}function _Ea(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+64|0;c=d+64|0;d=0;while(1){j=h+(d<<1)|0;k=31-d|0;l=d+1|0;m=ba(d,f)|0;n=0;while(1){o=ba(e[j>>1]|0,31-n|0)|0;p=n+1|0;q=ba(e[i>>1]|0,p)|0;r=ba(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+32+q+r+(ba(e[c>>1]|0,l)|0)|0)>>>6;if((p|0)<32){n=p}else{break}}if((l|0)<32){d=l}else{break}}return}function $Ea(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=1<<h;k=a;a=d;d=f;f=(j|0)>0;do{if(f){l=j;m=0;do{l=(e[d+(m<<1)>>1]|0)+l+(e[a+(m<<1)>>1]|0)|0;m=m+1|0;}while((m|0)<(j|0));m=l>>h+1;n=gHb(m,(m|0)<0|0?-1:0,65537,65537)|0;o=F;if(!f){p=m;break}q=(j|0)/4|0;if((j|0)>3){r=0}else{p=m;break}while(1){s=ba(r,g)|0;t=0;do{u=k+((t<<2)+s<<1)|0;c[u>>2]=n;c[u+4>>2]=o;t=t+1|0;}while((t|0)<(q|0));t=r+1|0;if((t|0)<(j|0)){r=t}else{p=m;break}}}else{p=j>>h+1}}while(0);if(!((i|0)==0&(j|0)<32)){return}b[k>>1]=((p<<1)+2+(e[d>>1]|0)+(e[a>>1]|0)|0)>>>2;i=(j|0)>1;if(!i){return}h=(p*3|0)+2|0;r=1;do{b[k+(r<<1)>>1]=(h+(e[a+(r<<1)>>1]|0)|0)>>>2;r=r+1|0;}while((r|0)<(j|0));if(!i){return}i=(p*3|0)+2|0;p=1;do{b[k+((ba(p,g)|0)<<1)>>1]=(i+(e[d+(p<<1)>>1]|0)|0)>>>2;p=p+1|0;}while((p|0)<(j|0));return}function aFa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;k=i;i=i+200|0;l=k|0;m=a;n=d;o=f;p=c[562400+(j-2<<2)>>2]|0;q=l+8|0;r=p>>3;if((j|0)>17){s=d-2|0;t=s;u=j-11|0;do{if(u>>>0<15>>>0&(r|0)<-1){v=q;b[v>>1]=b[s>>1]|0;b[v+2>>1]=b[s+2>>1]|0;b[v+4>>1]=b[s+4>>1]|0;b[v+6>>1]=b[s+6>>1]|0;b[v+8>>1]=b[s+8>>1]|0;if((r|0)>=0){w=q;break}v=c[562336+(u<<2)>>2]|0;x=r;while(1){b[l+(x+4<<1)>>1]=b[o+(((ba(x,v)|0)+128>>8)-1<<1)>>1]|0;y=x+1|0;if((y|0)<0){x=y}else{w=q;break}}}else{w=t}}while(0);t=0;while(1){u=t+1|0;s=ba(u,p)|0;x=s>>5;v=s&31;if((v|0)==0){s=ba(t,g)|0;b[m+(s<<1)>>1]=b[w+(x+1<<1)>>1]|0;b[m+(s+1<<1)>>1]=b[w+(x+2<<1)>>1]|0;b[m+(s+2<<1)>>1]=b[w+(x+3<<1)>>1]|0;b[m+(s+3<<1)>>1]=b[w+(x+4<<1)>>1]|0}else{s=32-v|0;y=ba(t,g)|0;z=ba(e[w+(x+1<<1)>>1]|0,s)|0;b[m+(y<<1)>>1]=(z+16+(ba(e[w+(x+2<<1)>>1]|0,v)|0)|0)>>>5;z=ba(e[w+(x+2<<1)>>1]|0,s)|0;b[m+(y+1<<1)>>1]=(z+16+(ba(e[w+(x+3<<1)>>1]|0,v)|0)|0)>>>5;z=ba(e[w+(x+3<<1)>>1]|0,s)|0;b[m+(y+2<<1)>>1]=(z+16+(ba(e[w+(x+4<<1)>>1]|0,v)|0)|0)>>>5;z=ba(e[w+(x+4<<1)>>1]|0,s)|0;b[m+(y+3<<1)>>1]=(z+16+(ba(e[w+(x+5<<1)>>1]|0,v)|0)|0)>>>5}if((u|0)<4){t=u}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}t=f-2|0;w=((e[o>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(w>>>0<512>>>0){A=w&65535}else{A=-w>>31&511}b[m>>1]=A;A=((e[f+2>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(A>>>0<512>>>0){B=A&65535}else{B=-A>>31&511}b[m+(g<<1)>>1]=B;B=((e[f+4>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(B>>>0<512>>>0){C=B&65535}else{C=-B>>31&511}b[m+(g<<1<<1)>>1]=C;C=((e[f+6>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(C>>>0<512>>>0){D=C&65535}else{D=-C>>31&511}b[m+((g*3|0)<<1)>>1]=D;i=k;return}else{D=f-2|0;f=D;C=j-11|0;do{if(C>>>0<15>>>0&(r|0)<-1){t=q;b[t>>1]=b[D>>1]|0;b[t+2>>1]=b[D+2>>1]|0;b[t+4>>1]=b[D+4>>1]|0;b[t+6>>1]=b[D+6>>1]|0;b[t+8>>1]=b[D+8>>1]|0;if((r|0)>=0){E=q;break}t=c[562336+(C<<2)>>2]|0;B=r;while(1){b[l+(B+4<<1)>>1]=b[n+(((ba(B,t)|0)+128>>8)-1<<1)>>1]|0;A=B+1|0;if((A|0)<0){B=A}else{E=q;break}}}else{E=f}}while(0);f=0;while(1){q=f+1|0;l=ba(q,p)|0;r=l>>5;C=l&31;if((C|0)==0){b[m+(f<<1)>>1]=b[E+(r+1<<1)>>1]|0;b[m+(f+g<<1)>>1]=b[E+(r+2<<1)>>1]|0;b[m+((g<<1)+f<<1)>>1]=b[E+(r+3<<1)>>1]|0;b[m+((g*3|0)+f<<1)>>1]=b[E+(r+4<<1)>>1]|0}else{l=32-C|0;D=ba(e[E+(r+1<<1)>>1]|0,l)|0;b[m+(f<<1)>>1]=(D+16+(ba(e[E+(r+2<<1)>>1]|0,C)|0)|0)>>>5;D=ba(e[E+(r+2<<1)>>1]|0,l)|0;b[m+(f+g<<1)>>1]=(D+16+(ba(e[E+(r+3<<1)>>1]|0,C)|0)|0)>>>5;D=ba(e[E+(r+3<<1)>>1]|0,l)|0;b[m+((g<<1)+f<<1)>>1]=(D+16+(ba(e[E+(r+4<<1)>>1]|0,C)|0)|0)>>>5;D=ba(e[E+(r+4<<1)>>1]|0,l)|0;b[m+((g*3|0)+f<<1)>>1]=(D+16+(ba(e[E+(r+5<<1)>>1]|0,C)|0)|0)>>>5}if((q|0)<4){f=q}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;j=((e[n>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(j>>>0<512>>>0){F=j&65535}else{F=-j>>31&511}b[m>>1]=F;F=((e[d+2>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(F>>>0<512>>>0){G=F&65535}else{G=-F>>31&511}b[a+2>>1]=G;G=((e[d+4>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(G>>>0<512>>>0){H=G&65535}else{H=-G>>31&511}b[a+4>>1]=H;H=((e[d+6>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(H>>>0<512>>>0){I=H&65535}else{I=-H>>31&511}b[a+6>>1]=I;i=k;return}}function bFa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+200|0;l=k|0;m=a;a=d;n=f;o=c[562400+(j-2<<2)>>2]|0;p=l+16|0;q=o>>2;if((j|0)>17){r=d-2|0;s=r;t=j-11|0;do{if(t>>>0<15>>>0&(q|0)<-1){UGb(p|0,r|0,18)|0;if((q|0)>=0){u=p;break}v=c[562336+(t<<2)>>2]|0;w=q;while(1){b[l+(w+8<<1)>>1]=b[n+(((ba(w,v)|0)+128>>8)-1<<1)>>1]|0;x=w+1|0;if((x|0)<0){w=x}else{u=p;break}}}else{u=s}}while(0);s=0;while(1){t=s+1|0;r=ba(t,o)|0;w=r>>5;v=r&31;if((v|0)==0){r=ba(s,g)|0;b[m+(r<<1)>>1]=b[u+(w+1<<1)>>1]|0;b[m+(r+1<<1)>>1]=b[u+(w+2<<1)>>1]|0;b[m+(r+2<<1)>>1]=b[u+(w+3<<1)>>1]|0;b[m+(r+3<<1)>>1]=b[u+(w+4<<1)>>1]|0;b[m+(r+4<<1)>>1]=b[u+(w+5<<1)>>1]|0;b[m+(r+5<<1)>>1]=b[u+(w+6<<1)>>1]|0;b[m+(r+6<<1)>>1]=b[u+(w+7<<1)>>1]|0;b[m+(r+7<<1)>>1]=b[u+(w+8<<1)>>1]|0}else{r=32-v|0;x=ba(s,g)|0;y=0;do{z=y+w|0;A=ba(e[u+(z+1<<1)>>1]|0,r)|0;b[m+(y+x<<1)>>1]=(A+16+(ba(e[u+(z+2<<1)>>1]|0,v)|0)|0)>>>5;y=y+1|0;}while((y|0)<8)}if((t|0)<8){s=t}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}s=f-2|0;u=0;do{y=((e[n+(u<<1)>>1]|0)-(e[s>>1]|0)>>1)+(e[a>>1]|0)|0;if(y>>>0<512>>>0){B=y&65535}else{B=-y>>31&511}b[m+((ba(u,g)|0)<<1)>>1]=B;u=u+1|0;}while((u|0)<8);i=k;return}else{u=f-2|0;f=u;B=j-11|0;do{if(B>>>0<15>>>0&(q|0)<-1){UGb(p|0,u|0,18)|0;if((q|0)>=0){C=p;break}s=c[562336+(B<<2)>>2]|0;y=q;while(1){b[l+(y+8<<1)>>1]=b[a+(((ba(y,s)|0)+128>>8)-1<<1)>>1]|0;v=y+1|0;if((v|0)<0){y=v}else{C=p;break}}}else{C=f}}while(0);f=0;while(1){p=f+1|0;l=ba(p,o)|0;q=l>>5;B=l&31;if((B|0)==0){b[m+(f<<1)>>1]=b[C+(q+1<<1)>>1]|0;b[m+(f+g<<1)>>1]=b[C+(q+2<<1)>>1]|0;b[m+((g<<1)+f<<1)>>1]=b[C+(q+3<<1)>>1]|0;b[m+((g*3|0)+f<<1)>>1]=b[C+(q+4<<1)>>1]|0;b[m+((g<<2)+f<<1)>>1]=b[C+(q+5<<1)>>1]|0;b[m+((g*5|0)+f<<1)>>1]=b[C+(q+6<<1)>>1]|0;b[m+((g*6|0)+f<<1)>>1]=b[C+(q+7<<1)>>1]|0;b[m+((g*7|0)+f<<1)>>1]=b[C+(q+8<<1)>>1]|0}else{l=32-B|0;u=0;do{y=u+q|0;s=ba(e[C+(y+1<<1)>>1]|0,l)|0;b[m+((ba(u,g)|0)+f<<1)>>1]=(s+16+(ba(e[C+(y+2<<1)>>1]|0,B)|0)|0)>>>5;u=u+1|0;}while((u|0)<8)}if((p|0)<8){f=p}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;d=0;do{j=((e[a+(d<<1)>>1]|0)-(e[h>>1]|0)>>1)+(e[n>>1]|0)|0;if(j>>>0<512>>>0){D=j&65535}else{D=-j>>31&511}b[m+(d<<1)>>1]=D;d=d+1|0;}while((d|0)<8);i=k;return}}function cFa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+200|0;l=k|0;m=a;a=d;n=f;o=c[562400+(j-2<<2)>>2]|0;p=l+32|0;q=o>>1;if((j|0)>17){r=d-2|0;s=r;t=j-11|0;do{if(t>>>0<15>>>0&(q|0)<-1){UGb(p|0,r|0,34)|0;if((q|0)>=0){u=p;break}v=c[562336+(t<<2)>>2]|0;w=q;while(1){b[l+(w+16<<1)>>1]=b[n+(((ba(w,v)|0)+128>>8)-1<<1)>>1]|0;x=w+1|0;if((x|0)<0){w=x}else{u=p;break}}}else{u=s}}while(0);s=0;while(1){t=s+1|0;r=ba(t,o)|0;w=r>>5;v=r&31;if((v|0)==0){r=ba(s,g)|0;b[m+(r<<1)>>1]=b[u+(w+1<<1)>>1]|0;b[m+(r+1<<1)>>1]=b[u+(w+2<<1)>>1]|0;b[m+(r+2<<1)>>1]=b[u+(w+3<<1)>>1]|0;b[m+(r+3<<1)>>1]=b[u+(w+4<<1)>>1]|0;b[m+(r+4<<1)>>1]=b[u+(w+5<<1)>>1]|0;b[m+(r+5<<1)>>1]=b[u+(w+6<<1)>>1]|0;b[m+(r+6<<1)>>1]=b[u+(w+7<<1)>>1]|0;b[m+(r+7<<1)>>1]=b[u+(w+8<<1)>>1]|0;b[m+(r+8<<1)>>1]=b[u+(w+9<<1)>>1]|0;b[m+(r+9<<1)>>1]=b[u+(w+10<<1)>>1]|0;b[m+(r+10<<1)>>1]=b[u+(w+11<<1)>>1]|0;b[m+(r+11<<1)>>1]=b[u+(w+12<<1)>>1]|0;b[m+(r+12<<1)>>1]=b[u+(w+13<<1)>>1]|0;b[m+(r+13<<1)>>1]=b[u+(w+14<<1)>>1]|0;b[m+(r+14<<1)>>1]=b[u+(w+15<<1)>>1]|0;b[m+(r+15<<1)>>1]=b[u+(w+16<<1)>>1]|0}else{r=32-v|0;x=ba(s,g)|0;y=0;do{z=y+w|0;A=ba(e[u+(z+1<<1)>>1]|0,r)|0;b[m+(y+x<<1)>>1]=(A+16+(ba(e[u+(z+2<<1)>>1]|0,v)|0)|0)>>>5;y=y+1|0;}while((y|0)<16)}if((t|0)<16){s=t}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}s=f-2|0;u=0;do{y=((e[n+(u<<1)>>1]|0)-(e[s>>1]|0)>>1)+(e[a>>1]|0)|0;if(y>>>0<512>>>0){B=y&65535}else{B=-y>>31&511}b[m+((ba(u,g)|0)<<1)>>1]=B;u=u+1|0;}while((u|0)<16);i=k;return}u=f-2|0;f=u;B=j-11|0;do{if(B>>>0<15>>>0&(q|0)<-1){UGb(p|0,u|0,34)|0;if((q|0)>=0){C=p;break}s=c[562336+(B<<2)>>2]|0;y=q;while(1){b[l+(y+16<<1)>>1]=b[a+(((ba(y,s)|0)+128>>8)-1<<1)>>1]|0;v=y+1|0;if((v|0)<0){y=v}else{C=p;break}}}else{C=f}}while(0);f=0;while(1){p=f+1|0;l=ba(p,o)|0;q=l>>5;B=l&31;if((B|0)==0){l=q+1|0;u=0;do{b[m+((ba(u,g)|0)+f<<1)>>1]=b[C+(l+u<<1)>>1]|0;u=u+1|0;}while((u|0)<16)}else{u=32-B|0;l=0;do{y=l+q|0;s=ba(e[C+(y+1<<1)>>1]|0,u)|0;b[m+((ba(l,g)|0)+f<<1)>>1]=(s+16+(ba(e[C+(y+2<<1)>>1]|0,B)|0)|0)>>>5;l=l+1|0;}while((l|0)<16)}if((p|0)<16){f=p}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;d=0;do{j=((e[a+(d<<1)>>1]|0)-(e[h>>1]|0)>>1)+(e[n>>1]|0)|0;if(j>>>0<512>>>0){D=j&65535}else{D=-j>>31&511}b[m+(d<<1)>>1]=D;d=d+1|0;}while((d|0)<16);i=k;return}function dFa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+200|0;k=h|0;l=a;a=d;m=f;n=c[562400+(j-2<<2)>>2]|0;o=k+64|0;if((j|0)>17){p=d-2|0;d=p;q=j-11|0;if(q>>>0<15>>>0){UGb(o|0,p|0,66)|0;p=c[562336+(q<<2)>>2]|0;q=n;while(1){b[k+(q+32<<1)>>1]=b[m+(((ba(q,p)|0)+128>>8)-1<<1)>>1]|0;r=q+1|0;if((r|0)<0){q=r}else{s=o;break}}}else{s=d}d=0;while(1){q=d+1|0;p=ba(q,n)|0;m=p>>5;r=p&31;if((r|0)==0){p=m+1|0;t=ba(d,g)|0;u=0;do{b[l+(u+t<<1)>>1]=b[s+(p+u<<1)>>1]|0;u=u+1|0;}while((u|0)<32)}else{u=32-r|0;p=ba(d,g)|0;t=0;do{v=t+m|0;w=ba(e[s+(v+1<<1)>>1]|0,u)|0;b[l+(t+p<<1)>>1]=(w+16+(ba(e[s+(v+2<<1)>>1]|0,r)|0)|0)>>>5;t=t+1|0;}while((t|0)<32)}if((q|0)<32){d=q}else{break}}i=h;return}else{d=f-2|0;f=d;s=j-11|0;if(s>>>0<15>>>0){UGb(o|0,d|0,66)|0;d=c[562336+(s<<2)>>2]|0;s=n;while(1){b[k+(s+32<<1)>>1]=b[a+(((ba(s,d)|0)+128>>8)-1<<1)>>1]|0;j=s+1|0;if((j|0)<0){s=j}else{x=o;break}}}else{x=f}f=0;while(1){o=f+1|0;s=ba(o,n)|0;d=s>>5;a=s&31;if((a|0)==0){s=d+1|0;k=0;do{b[l+((ba(k,g)|0)+f<<1)>>1]=b[x+(s+k<<1)>>1]|0;k=k+1|0;}while((k|0)<32)}else{k=32-a|0;s=0;do{q=s+d|0;j=ba(e[x+(q+1<<1)>>1]|0,k)|0;b[l+((ba(s,g)|0)+f<<1)>>1]=(j+16+(ba(e[x+(q+2<<1)>>1]|0,a)|0)|0)>>>5;s=s+1|0;}while((s|0)<32)}if((o|0)<32){f=o}else{break}}i=h;return}}function eFa(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;l=i;i=i+544|0;m=l|0;n=l+136|0;o=l+272|0;p=l+408|0;q=c[f+136>>2]|0;r=c[f+180>>2]|0;s=c[r+13140+(k<<2)>>2]|0;t=c[r+13152+(k<<2)>>2]|0;u=1<<j;v=u<<s;w=c[r+13072>>2]|0;x=v>>w;y=g>>w;z=h>>w;w=c[r+13124>>2]|0;A=(ba(z,w)|0)+y|0;B=c[f+184>>2]|0;C=c[B+1672>>2]|0;D=c[C+(A<<2)>>2]|0;A=c[f+160>>2]|0;E=(c[A+32+(k<<2)>>2]|0)>>>1;F=c[A+(k<<2)>>2]|0;A=(ba(E,h>>t)|0)+(g>>s)|0;G=F+(A<<1)|0;H=c[r+13132>>2]|0;if((k|0)==0){I=c[q+173192>>2]|0}else{I=d[q+184621|0]|0}J=m+2|0;K=o+2|0;L=n+2|0;M=p+2|0;if((c[q+184624>>2]|0)==0){N=0}else{N=(D|0)>(c[C+(y-1+(ba(w,z+x|0)|0)<<2)>>2]|0)}O=N&1;P=c[q+184628>>2]|0;Q=c[q+184636>>2]|0;R=c[q+184632>>2]|0;if((c[q+184640>>2]|0)==0){S=0}else{S=(D|0)>(c[C+(y+x+(ba(w,z-1|0)|0)<<2)>>2]|0)}z=S&1;w=v<<1;x=w+h|0;y=c[r+13100>>2]|0;C=v+h|0;D=((x|0)>(y|0)?y:x)-C>>t;x=w+g|0;w=c[r+13096>>2]|0;q=v+g|0;T=((x|0)>(w|0)?w:x)-q>>s;x=B+20|0;if((a[x]|0)==1){B=c[r+13084>>2]|0;U=v>>B;v=(1<<B)-1|0;V=v&h;W=((U|0)==0)+U|0;U=(v&g|0)!=0;do{if(U|N^1){X=O}else{v=g-1>>B;Y=C>>B;Z=(c[r+13136>>2]|0)-Y|0;_=(W|0)>(Z|0)?Z:W;if((_|0)<=0){X=0;break}Z=c[(c[f+3480>>2]|0)+16>>2]|0;$=0;aa=0;while(1){ca=d[Z+(((ba(aa+Y|0,H)|0)+v|0)*14|0)+12|0]|$;da=aa+1|0;if((da|0)<(_|0)){$=ca;aa=da}else{X=ca;break}}}}while(0);do{if((P|0)!=1|U){ea=P}else{C=g-1>>B;N=h>>B;aa=(c[r+13136>>2]|0)-N|0;$=(W|0)>(aa|0)?aa:W;if(($|0)<=0){ea=0;break}aa=c[(c[f+3480>>2]|0)+16>>2]|0;_=0;v=0;while(1){Y=d[aa+(((ba(v+N|0,H)|0)+C|0)*14|0)+12|0]|_;Z=v+1|0;if((Z|0)<($|0)){_=Y;v=Z}else{ea=Y;break}}}}while(0);if((Q|0)==1){U=(ba(h-1>>B,H)|0)+(g-1>>B)|0;fa=d[(c[(c[f+3480>>2]|0)+16>>2]|0)+(U*14|0)+12|0]|0}else{fa=Q}U=(V|0)!=0;do{if((R|0)!=1|U){ga=R}else{V=g>>B;v=H-V|0;_=(W|0)>(v|0)?v:W;if((_|0)<=0){ga=0;break}v=(ba(h-1>>B,H)|0)+V|0;V=c[(c[f+3480>>2]|0)+16>>2]|0;$=0;C=0;while(1){N=d[V+((v+C|0)*14|0)+12|0]|$;aa=C+1|0;if((aa|0)<(_|0)){$=N;C=aa}else{ga=N;break}}}}while(0);do{if(U|S^1){ha=z}else{C=q>>B;$=H-C|0;_=(W|0)>($|0)?$:W;if((_|0)<=0){ha=0;break}$=(ba(h-1>>B,H)|0)+C|0;C=c[(c[f+3480>>2]|0)+16>>2]|0;v=0;V=0;while(1){N=d[C+(($+V|0)*14|0)+12|0]|v;aa=V+1|0;if((aa|0)<(_|0)){v=N;V=aa}else{ha=N;break}}}}while(0);B=0;while(1){W=B+1|0;b[m+(W<<1)>>1]=128;b[o+(W<<1)>>1]=128;if((W|0)<64){B=W}else{ia=X;ja=ea;ka=fa;la=ga;ma=ha;break}}}else{ia=O;ja=P;ka=Q;la=R;ma=z}z=(ia|0)!=0;do{if(z){R=D+u|0;Q=u<<1;if((R|0)<(Q|0)){P=(-1<<s)+g|0;O=R-1|0;ha=(O<<t)+h|0;ga=F+(A-1+(ba(O,E)|0)<<1)|0;fa=c[r+13084>>2]|0;ea=c[(c[f+3480>>2]|0)+16>>2]|0;X=R;while(1){do{if((a[ea+(((ba(ha>>fa,H)|0)+(P>>fa)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=38;break}oa=X+1|0}else{na=38}}while(0);if((na|0)==38){na=0;B=X+1|0;b[m+(B<<1)>>1]=b[ga>>1]|0;oa=B}if((oa|0)<(Q|0)){X=oa}else{pa=O;break}}}else{pa=R-1|0}if((pa|0)<(u|0)){break}O=(-1<<s)+g|0;X=A-1|0;Q=c[r+13084>>2]|0;ga=c[(c[f+3480>>2]|0)+16>>2]|0;fa=R;P=pa;while(1){if((a[ga+(((ba((P<<t)+h>>Q,H)|0)+(O>>Q)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=43}}else{na=43}if((na|0)==43){na=0;b[m+(fa<<1)>>1]=b[F+(X+(ba(P,E)|0)<<1)>>1]|0}ha=P-1|0;if((ha|0)<(u|0)){break}else{fa=P;P=ha}}}}while(0);pa=(ja|0)!=0;if(pa&(u|0)>0){oa=(-1<<s)+g|0;P=A-1|0;fa=c[r+13084>>2]|0;X=c[(c[f+3480>>2]|0)+16>>2]|0;Q=u;while(1){O=Q-1|0;if((a[X+(((ba((O<<t)+h>>fa,H)|0)+(oa>>fa)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=49}}else{na=49}if((na|0)==49){na=0;b[m+(Q<<1)>>1]=b[F+(P+(ba(O,E)|0)<<1)>>1]|0}if((O|0)>0){Q=O}else{break}}}Q=(ka|0)!=0;do{if(Q){P=c[r+13084>>2]|0;fa=(ba((-1<<t)+h>>P,H)|0)+((-1<<s)+g>>P)|0;if((a[(c[(c[f+3480>>2]|0)+16>>2]|0)+(fa*14|0)+12|0]|0)==0){if((a[x]|0)!=0){break}}fa=b[F+(A+~E<<1)>>1]|0;b[m>>1]=fa;b[o>>1]=fa}}while(0);fa=(la|0)!=0;if(fa&(u|0)>0){P=(-1<<t)+h|0;oa=A-E|0;X=c[r+13084>>2]|0;O=c[(c[f+3480>>2]|0)+16>>2]|0;ga=u;while(1){R=ga-1|0;if((a[O+(((ba(P>>X,H)|0)+((R<<s)+g>>X)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=59}}else{na=59}if((na|0)==59){na=0;b[o+(ga<<1)>>1]=b[F+(oa+R<<1)>>1]|0}if((R|0)>0){ga=R}else{break}}}ga=(ma|0)!=0;do{if(ga){oa=T+u|0;X=u<<1;P=oa-1|0;if((oa|0)<(X|0)){O=(P<<s)+g|0;R=(-1<<t)+h|0;ha=F+(A-E+P<<1)|0;ea=c[r+13084>>2]|0;B=c[(c[f+3480>>2]|0)+16>>2]|0;W=oa;while(1){do{if((a[B+(((ba(R>>ea,H)|0)+(O>>ea)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=68;break}qa=W+1|0}else{na=68}}while(0);if((na|0)==68){na=0;S=W+1|0;b[o+(S<<1)>>1]=b[ha>>1]|0;qa=S}if((qa|0)<(X|0)){W=qa}else{break}}}if((P|0)<(u|0)){break}W=(-1<<t)+h|0;X=A-E|0;ha=c[r+13084>>2]|0;ea=c[(c[f+3480>>2]|0)+16>>2]|0;O=oa;R=P;while(1){if((a[ea+(((ba(W>>ha,H)|0)+((R<<s)+g>>ha)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=73}}else{na=73}if((na|0)==73){na=0;b[o+(O<<1)>>1]=b[F+(X+R<<1)>>1]|0}B=R-1|0;if((B|0)<(u|0)){break}else{O=R;R=B}}}}while(0);do{if((a[x]|0)==1){F=ia|ja;A=(F|0)!=0;qa=F|ka;F=(qa|0)==0;if((la|ma|qa|0)==0){break}qa=u<<1;if(((qa<<s)+g|0)<(w|0)){ra=qa}else{ra=w-g>>s}if(((qa<<t)+h|0)<(y|0)){sa=qa}else{sa=y-h>>t}T=(z?D:0)+u|0;do{if(ga){ta=ra}else{if((q|0)<(w|0)){ta=u;break}ta=w-g>>s}}while(0);do{if(z){ua=sa}else{if(((u<<t)+h|0)<(y|0)){ua=u;break}ua=y-h>>t}}while(0);do{if(F){R=(-1<<t)+h|0;O=f+3480|0;X=0;while(1){if((X|0)>=(ta|0)){break}ha=c[r+13084>>2]|0;W=(ba(R>>ha,H)|0)+((X<<s)+g>>ha)|0;if((a[(c[(c[O>>2]|0)+16>>2]|0)+(W*14|0)+12|0]|0)==0){X=X+1|0}else{break}}do{if((X|0)>0){if((g|0)>0){if(!((X|0)>-1)){break}W=c[r+13084>>2]|0;ha=c[(c[O>>2]|0)+16>>2]|0;ea=X;while(1){P=ea-1|0;if((a[ha+(((ba(R>>W,H)|0)+((P<<s)+g>>W)|0)*14|0)+12|0]|0)==0){b[o+(ea<<1)>>1]=b[o+(ea+1<<1)>>1]|0}if((ea|0)>0){ea=P}else{break}}}else{ea=c[r+13084>>2]|0;W=c[(c[O>>2]|0)+16>>2]|0;ha=X;while(1){P=ha-1|0;if((a[W+(((ba(R>>ea,H)|0)+((P<<s)+g>>ea)|0)*14|0)+12|0]|0)==0){b[o+(ha<<1)>>1]=b[o+(ha+1<<1)>>1]|0}if((P|0)>0){ha=P}else{break}}b[o>>1]=b[K>>1]|0;break}}}while(0);b[m>>1]=b[o>>1]|0;va=0}else{R=(-1<<s)+g|0;X=f+3480|0;O=T;while(1){wa=O-1|0;xa=c[r+13084>>2]|0;if((O|0)<=0){na=90;break}ha=(wa<<t)+h|0;ea=(ba(ha>>xa,H)|0)+(R>>xa)|0;W=c[(c[X>>2]|0)+16>>2]|0;if((a[W+(ea*14|0)+12|0]|0)==0){O=wa}else{ya=W;za=ha;break}}if((na|0)==90){ya=c[(c[X>>2]|0)+16>>2]|0;za=(wa<<t)+h|0}if((a[ya+(((ba(za>>xa,H)|0)+(R>>xa)|0)*14|0)+12|0]|0)!=0){va=wa;break}O=(-1<<t)+h|0;ha=0;while(1){if((ha|0)>=(ta|0)){break}if((a[ya+(((ba(O>>xa,H)|0)+((ha<<s)+g>>xa)|0)*14|0)+12|0]|0)==0){ha=ha+1|0}else{break}}if((ha|0)>-1){R=ha;while(1){X=R-1|0;if((a[ya+(((ba(O>>xa,H)|0)+((X<<s)+g>>xa)|0)*14|0)+12|0]|0)==0){b[o+(R<<1)>>1]=b[o+(R+1<<1)>>1]|0}if((R|0)>0){R=X}else{break}}}b[m>>1]=b[o>>1]|0;va=0}}while(0);if(A&(va|0)<(ua|0)){T=(-1<<s)+g|0;F=c[r+13084>>2]|0;R=c[(c[f+3480>>2]|0)+16>>2]|0;O=va;while(1){if((a[R+(((ba((O<<t)+h>>F,H)|0)+(T>>F)|0)*14|0)+12|0]|0)==0){ha=O+1|0;b[m+(ha<<1)>>1]=b[m+(O<<1)>>1]|0;Aa=ha}else{Aa=O+1|0}if((Aa|0)<(ua|0)){O=Aa}else{break}}}a:do{if((u|0)>0&(pa^1)){O=b[m>>1]|0;F=1;while(1){b[m+(F<<1)>>1]=O;if((F|0)>=(u|0)){break a}F=F+1|0}}}while(0);if((u|0)<(qa|0)&(z^1)){F=b[m+(u<<1)>>1]|0;O=u;do{O=O+1|0;b[m+(O<<1)>>1]=F;}while((O|0)<(qa|0))}qa=(g|0)==0;O=(h|0)==0;b:do{if(qa|O){F=ua-1|0;if(qa){if((ua|0)<=0){break}T=b[m+(ua<<1)>>1]|0;R=F;while(1){b[m+(R<<1)>>1]=T;if((R|0)>0){R=R-1|0}else{break b}}}if((F|0)<=0){break}R=(-1<<s)+g|0;T=c[r+13084>>2]|0;A=c[(c[f+3480>>2]|0)+16>>2]|0;ha=F;while(1){X=ha-1|0;if((a[A+(((ba((X<<t)+h>>T,H)|0)+(R>>T)|0)*14|0)+12|0]|0)==0){b[m+(ha<<1)>>1]=b[m+(ha+1<<1)>>1]|0}if((X|0)>0){ha=X}else{break}}}else{if((ua|0)<=0){break}ha=(-1<<s)+g|0;T=c[r+13084>>2]|0;R=c[(c[f+3480>>2]|0)+16>>2]|0;A=ua;while(1){F=A-1|0;if((a[R+(((ba((A-2<<t)+h>>T,H)|0)+(ha>>T)|0)*14|0)+12|0]|0)==0){b[m+(F<<1)>>1]=b[m+(A<<1)>>1]|0}if((F|0)>0){A=F}else{break}}}}while(0);b[o>>1]=b[m>>1]|0;if(!((ta|0)>0&(O^1))){break}qa=(-1<<t)+h|0;A=c[r+13084>>2]|0;T=c[(c[f+3480>>2]|0)+16>>2]|0;ha=0;while(1){if((a[T+(((ba(qa>>A,H)|0)+((ha<<s)+g>>A)|0)*14|0)+12|0]|0)==0){R=ha+1|0;b[o+(R<<1)>>1]=b[o+(ha<<1)>>1]|0;Ba=R}else{Ba=ha+1|0}if((Ba|0)<(ta|0)){ha=Ba}else{break}}}}while(0);c:do{if(z){na=176}else{if(pa){Ba=u<<1;if((u|0)>=(Ba|0)){na=176;break}ta=b[m+(u<<1)>>1]|0;g=u;while(1){s=g+1|0;b[m+(s<<1)>>1]=ta;if((s|0)<(Ba|0)){g=s}else{na=176;break c}}}if(Q){g=u<<1;if((g|0)<=0){na=178;break}Ba=b[m>>1]|0;ta=1;while(1){b[m+(ta<<1)>>1]=Ba;if((ta|0)>=(g|0)){na=178;break c}ta=ta+1|0}}if(fa){ta=b[K>>1]|0;b[m>>1]=ta;g=u<<1;if((g|0)>0){Ca=1}else{na=180;break}while(1){b[m+(Ca<<1)>>1]=ta;if((Ca|0)>=(g|0)){na=180;break c}Ca=Ca+1|0}}if(ga){if((u|0)>0){g=u;do{b[o+(g<<1)>>1]=b[o+(g+1<<1)>>1]|0;g=g-1|0;}while((g|0)>0)}g=b[K>>1]|0;b[m>>1]=g;ta=u<<1;if((ta|0)>0){Da=1}else{break}while(1){b[m+(Da<<1)>>1]=g;if((Da|0)>=(ta|0)){break c}Da=Da+1|0}}b[m>>1]=512;b[K>>1]=512;ta=u<<1;d:do{if((ta|0)>1){g=2;while(1){b[o+(g<<1)>>1]=512;if((g|0)>=(ta|0)){break d}g=g+1|0}}}while(0);if((ta|0)>0){Ea=1}else{na=176;break}while(1){b[m+(Ea<<1)>>1]=512;if((Ea|0)>=(ta|0)){na=176;break c}Ea=Ea+1|0}}}while(0);do{if((na|0)==176){if((ja|0)==0&(u|0)>0){Fa=u}else{na=178;break}while(1){b[m+(Fa<<1)>>1]=b[m+(Fa+1<<1)>>1]|0;Ea=Fa-1|0;if((Ea|0)>0){Fa=Ea}else{na=178;break}}}}while(0);do{if((na|0)==178){if((ka|0)!=0){na=180;break}b[m>>1]=b[J>>1]|0;na=180}}while(0);e:do{if((na|0)==180){if((la|0)!=0){break}ka=b[m>>1]|0;b[K>>1]=ka;if((u|0)>1){Ga=2}else{break}while(1){b[o+(Ga<<1)>>1]=ka;if((Ga|0)>=(u|0)){break e}Ga=Ga+1|0}}}while(0);do{if(!ga){Ga=u<<1;if((u|0)>=(Ga|0)){break}la=b[o+(u<<1)>>1]|0;na=u;do{na=na+1|0;b[o+(na<<1)>>1]=la;}while((na|0)<(Ga|0))}}while(0);ga=m|0;Ga=b[ga>>1]|0;b[o>>1]=Ga;f:do{if((k|0)!=0|(I|0)==1|(u|0)==4){Ha=J;Ia=K}else{na=I-26|0;la=(na|0)>-1?na:26-I|0;na=I-10|0;ka=(na|0)>-1?na:10-I|0;if((((la|0)>(ka|0)?ka:la)|0)<=(c[906616+(j-3<<2)>>2]|0)){Ha=J;Ia=K;break}do{if((a[r+13061|0]|0)!=0&(j|0)==5){la=Ga&65535;ka=b[o+128>>1]|0;na=ka&65535;Fa=na+la-(e[o+64>>1]<<1)|0;if((((Fa|0)>-1?Fa:-Fa|0)|0)>=32){break}Fa=m+128|0;ja=b[Fa>>1]|0;Ea=(ja&65535)+la-(e[m+64>>1]<<1)|0;if((((Ea|0)>-1?Ea:-Ea|0)|0)>=32){break}b[p>>1]=Ga;b[p+128>>1]=ka;ka=0;while(1){Ea=ka+1|0;b[p+(Ea<<1)>>1]=((ba(la,63-ka|0)|0)+32+(ba(na,Ea)|0)|0)>>>6;if((Ea|0)<63){ka=Ea}else{Ja=0;Ka=Ga;La=ja;break}}while(1){ja=Ja+1|0;b[m+(ja<<1)>>1]=((ba(Ka&65535,63-Ja|0)|0)+32+(ba(La&65535,ja)|0)|0)>>>6;if((ja|0)>=63){Ha=J;Ia=M;break f}Ja=ja;Ka=b[ga>>1]|0;La=b[Fa>>1]|0}}}while(0);Fa=u<<1;ja=b[m+(Fa<<1)>>1]|0;b[n+(Fa<<1)>>1]=ja;ka=b[o+(Fa<<1)>>1]|0;b[p+(Fa<<1)>>1]=ka;na=Fa-2|0;Fa=(na|0)>-1;if(Fa){la=na;Ea=ja;while(1){ja=la+1|0;Da=b[m+(ja<<1)>>1]|0;b[n+(ja<<1)>>1]=((Ea&65535)+2+((Da&65535)<<1)+(e[m+(la<<1)>>1]|0)|0)>>>2;if((la|0)>0){la=la-1|0;Ea=Da}else{break}}}Ea=((e[J>>1]|0)+2+((Ga&65535)<<1)+(e[K>>1]|0)|0)>>>2&65535;b[n>>1]=Ea;b[p>>1]=Ea;if(Fa){Ma=na;Na=ka}else{Ha=L;Ia=M;break}while(1){Ea=Ma+1|0;la=b[o+(Ea<<1)>>1]|0;b[p+(Ea<<1)>>1]=((Na&65535)+2+((la&65535)<<1)+(e[o+(Ma<<1)>>1]|0)|0)>>>2;if((Ma|0)>0){Ma=Ma-1|0;Na=la}else{Ha=L;Ia=M;break}}}}while(0);if((I|0)==0){cf[c[f+5824+(j-2<<2)>>2]&1023](G,Ia,Ha,E);i=l;return}else if((I|0)==1){Se[c[f+5840>>2]&511](G,Ia,Ha,E,j,k);i=l;return}else{Se[c[f+5844+(j-2<<2)>>2]&511](G,Ia,Ha,E,k,I);i=l;return}}function fFa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=a;a=c;h=d;i=c+8|0;j=d+8|0;d=0;while(1){k=h+(d<<1)|0;l=3-d|0;m=d+1|0;n=ba(d,f)|0;o=ba(e[a>>1]|0,l)|0;b[g+(n<<1)>>1]=(((e[k>>1]|0)*3|0)+4+(e[i>>1]|0)+o+(ba(e[j>>1]|0,m)|0)|0)>>>3;o=ba(e[c+2>>1]|0,l)|0;b[g+(n+1<<1)>>1]=(((e[k>>1]|0)<<1)+4+((e[i>>1]|0)<<1)+o+(ba(e[j>>1]|0,m)|0)|0)>>>3;o=ba(e[c+4>>1]|0,l)|0;b[g+(n+2<<1)>>1]=((e[k>>1]|0)+4+((e[i>>1]|0)*3|0)+o+(ba(e[j>>1]|0,m)|0)|0)>>>3;o=ba(e[c+6>>1]|0,l)|0;b[g+(n+3<<1)>>1]=(((e[i>>1]|0)<<2)+4+o+(ba(e[j>>1]|0,m)|0)|0)>>>3;if((m|0)<4){d=m}else{break}}return}function gFa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+16|0;c=d+16|0;d=0;while(1){j=h+(d<<1)|0;k=7-d|0;l=d+1|0;m=ba(d,f)|0;n=0;while(1){o=ba(e[j>>1]|0,7-n|0)|0;p=n+1|0;q=ba(e[i>>1]|0,p)|0;r=ba(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+8+q+r+(ba(e[c>>1]|0,l)|0)|0)>>>4;if((p|0)<8){n=p}else{break}}if((l|0)<8){d=l}else{break}}return}function hFa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+32|0;c=d+32|0;d=0;while(1){j=h+(d<<1)|0;k=15-d|0;l=d+1|0;m=ba(d,f)|0;n=0;while(1){o=ba(e[j>>1]|0,15-n|0)|0;p=n+1|0;q=ba(e[i>>1]|0,p)|0;r=ba(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+16+q+r+(ba(e[c>>1]|0,l)|0)|0)>>>5;if((p|0)<16){n=p}else{break}}if((l|0)<16){d=l}else{break}}return}function iFa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+64|0;c=d+64|0;d=0;while(1){j=h+(d<<1)|0;k=31-d|0;l=d+1|0;m=ba(d,f)|0;n=0;while(1){o=ba(e[j>>1]|0,31-n|0)|0;p=n+1|0;q=ba(e[i>>1]|0,p)|0;r=ba(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+32+q+r+(ba(e[c>>1]|0,l)|0)|0)>>>6;if((p|0)<32){n=p}else{break}}if((l|0)<32){d=l}else{break}}return}function jFa(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=1<<h;k=a;a=d;d=f;f=(j|0)>0;do{if(f){l=j;m=0;do{l=(e[d+(m<<1)>>1]|0)+l+(e[a+(m<<1)>>1]|0)|0;m=m+1|0;}while((m|0)<(j|0));m=l>>h+1;n=gHb(m,(m|0)<0|0?-1:0,65537,65537)|0;o=F;if(!f){p=m;break}q=(j|0)/4|0;if((j|0)>3){r=0}else{p=m;break}while(1){s=ba(r,g)|0;t=0;do{u=k+((t<<2)+s<<1)|0;c[u>>2]=n;c[u+4>>2]=o;t=t+1|0;}while((t|0)<(q|0));t=r+1|0;if((t|0)<(j|0)){r=t}else{p=m;break}}}else{p=j>>h+1}}while(0);if(!((i|0)==0&(j|0)<32)){return}b[k>>1]=((p<<1)+2+(e[d>>1]|0)+(e[a>>1]|0)|0)>>>2;i=(j|0)>1;if(!i){return}h=(p*3|0)+2|0;r=1;do{b[k+(r<<1)>>1]=(h+(e[a+(r<<1)>>1]|0)|0)>>>2;r=r+1|0;}while((r|0)<(j|0));if(!i){return}i=(p*3|0)+2|0;p=1;do{b[k+((ba(p,g)|0)<<1)>>1]=(i+(e[d+(p<<1)>>1]|0)|0)>>>2;p=p+1|0;}while((p|0)<(j|0));return}function kFa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;k=i;i=i+200|0;l=k|0;m=a;n=d;o=f;p=c[562400+(j-2<<2)>>2]|0;q=l+8|0;r=p>>3;if((j|0)>17){s=d-2|0;t=s;u=j-11|0;do{if(u>>>0<15>>>0&(r|0)<-1){v=q;b[v>>1]=b[s>>1]|0;b[v+2>>1]=b[s+2>>1]|0;b[v+4>>1]=b[s+4>>1]|0;b[v+6>>1]=b[s+6>>1]|0;b[v+8>>1]=b[s+8>>1]|0;if((r|0)>=0){w=q;break}v=c[562336+(u<<2)>>2]|0;x=r;while(1){b[l+(x+4<<1)>>1]=b[o+(((ba(x,v)|0)+128>>8)-1<<1)>>1]|0;y=x+1|0;if((y|0)<0){x=y}else{w=q;break}}}else{w=t}}while(0);t=0;while(1){u=t+1|0;s=ba(u,p)|0;x=s>>5;v=s&31;if((v|0)==0){s=ba(t,g)|0;b[m+(s<<1)>>1]=b[w+(x+1<<1)>>1]|0;b[m+(s+1<<1)>>1]=b[w+(x+2<<1)>>1]|0;b[m+(s+2<<1)>>1]=b[w+(x+3<<1)>>1]|0;b[m+(s+3<<1)>>1]=b[w+(x+4<<1)>>1]|0}else{s=32-v|0;y=ba(t,g)|0;z=ba(e[w+(x+1<<1)>>1]|0,s)|0;b[m+(y<<1)>>1]=(z+16+(ba(e[w+(x+2<<1)>>1]|0,v)|0)|0)>>>5;z=ba(e[w+(x+2<<1)>>1]|0,s)|0;b[m+(y+1<<1)>>1]=(z+16+(ba(e[w+(x+3<<1)>>1]|0,v)|0)|0)>>>5;z=ba(e[w+(x+3<<1)>>1]|0,s)|0;b[m+(y+2<<1)>>1]=(z+16+(ba(e[w+(x+4<<1)>>1]|0,v)|0)|0)>>>5;z=ba(e[w+(x+4<<1)>>1]|0,s)|0;b[m+(y+3<<1)>>1]=(z+16+(ba(e[w+(x+5<<1)>>1]|0,v)|0)|0)>>>5}if((u|0)<4){t=u}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}t=f-2|0;w=((e[o>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(w>>>0<1024>>>0){A=w&65535}else{A=-w>>31&1023}b[m>>1]=A;A=((e[f+2>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(A>>>0<1024>>>0){B=A&65535}else{B=-A>>31&1023}b[m+(g<<1)>>1]=B;B=((e[f+4>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(B>>>0<1024>>>0){C=B&65535}else{C=-B>>31&1023}b[m+(g<<1<<1)>>1]=C;C=((e[f+6>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(C>>>0<1024>>>0){D=C&65535}else{D=-C>>31&1023}b[m+((g*3|0)<<1)>>1]=D;i=k;return}else{D=f-2|0;f=D;C=j-11|0;do{if(C>>>0<15>>>0&(r|0)<-1){t=q;b[t>>1]=b[D>>1]|0;b[t+2>>1]=b[D+2>>1]|0;b[t+4>>1]=b[D+4>>1]|0;b[t+6>>1]=b[D+6>>1]|0;b[t+8>>1]=b[D+8>>1]|0;if((r|0)>=0){E=q;break}t=c[562336+(C<<2)>>2]|0;B=r;while(1){b[l+(B+4<<1)>>1]=b[n+(((ba(B,t)|0)+128>>8)-1<<1)>>1]|0;A=B+1|0;if((A|0)<0){B=A}else{E=q;break}}}else{E=f}}while(0);f=0;while(1){q=f+1|0;l=ba(q,p)|0;r=l>>5;C=l&31;if((C|0)==0){b[m+(f<<1)>>1]=b[E+(r+1<<1)>>1]|0;b[m+(f+g<<1)>>1]=b[E+(r+2<<1)>>1]|0;b[m+((g<<1)+f<<1)>>1]=b[E+(r+3<<1)>>1]|0;b[m+((g*3|0)+f<<1)>>1]=b[E+(r+4<<1)>>1]|0}else{l=32-C|0;D=ba(e[E+(r+1<<1)>>1]|0,l)|0;b[m+(f<<1)>>1]=(D+16+(ba(e[E+(r+2<<1)>>1]|0,C)|0)|0)>>>5;D=ba(e[E+(r+2<<1)>>1]|0,l)|0;b[m+(f+g<<1)>>1]=(D+16+(ba(e[E+(r+3<<1)>>1]|0,C)|0)|0)>>>5;D=ba(e[E+(r+3<<1)>>1]|0,l)|0;b[m+((g<<1)+f<<1)>>1]=(D+16+(ba(e[E+(r+4<<1)>>1]|0,C)|0)|0)>>>5;D=ba(e[E+(r+4<<1)>>1]|0,l)|0;b[m+((g*3|0)+f<<1)>>1]=(D+16+(ba(e[E+(r+5<<1)>>1]|0,C)|0)|0)>>>5}if((q|0)<4){f=q}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;j=((e[n>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(j>>>0<1024>>>0){F=j&65535}else{F=-j>>31&1023}b[m>>1]=F;F=((e[d+2>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(F>>>0<1024>>>0){G=F&65535}else{G=-F>>31&1023}b[a+2>>1]=G;G=((e[d+4>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(G>>>0<1024>>>0){H=G&65535}else{H=-G>>31&1023}b[a+4>>1]=H;H=((e[d+6>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(H>>>0<1024>>>0){I=H&65535}else{I=-H>>31&1023}b[a+6>>1]=I;i=k;return}}function lFa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+200|0;l=k|0;m=a;a=d;n=f;o=c[562400+(j-2<<2)>>2]|0;p=l+16|0;q=o>>2;if((j|0)>17){r=d-2|0;s=r;t=j-11|0;do{if(t>>>0<15>>>0&(q|0)<-1){UGb(p|0,r|0,18)|0;if((q|0)>=0){u=p;break}v=c[562336+(t<<2)>>2]|0;w=q;while(1){b[l+(w+8<<1)>>1]=b[n+(((ba(w,v)|0)+128>>8)-1<<1)>>1]|0;x=w+1|0;if((x|0)<0){w=x}else{u=p;break}}}else{u=s}}while(0);s=0;while(1){t=s+1|0;r=ba(t,o)|0;w=r>>5;v=r&31;if((v|0)==0){r=ba(s,g)|0;b[m+(r<<1)>>1]=b[u+(w+1<<1)>>1]|0;b[m+(r+1<<1)>>1]=b[u+(w+2<<1)>>1]|0;b[m+(r+2<<1)>>1]=b[u+(w+3<<1)>>1]|0;b[m+(r+3<<1)>>1]=b[u+(w+4<<1)>>1]|0;b[m+(r+4<<1)>>1]=b[u+(w+5<<1)>>1]|0;b[m+(r+5<<1)>>1]=b[u+(w+6<<1)>>1]|0;b[m+(r+6<<1)>>1]=b[u+(w+7<<1)>>1]|0;b[m+(r+7<<1)>>1]=b[u+(w+8<<1)>>1]|0}else{r=32-v|0;x=ba(s,g)|0;y=0;do{z=y+w|0;A=ba(e[u+(z+1<<1)>>1]|0,r)|0;b[m+(y+x<<1)>>1]=(A+16+(ba(e[u+(z+2<<1)>>1]|0,v)|0)|0)>>>5;y=y+1|0;}while((y|0)<8)}if((t|0)<8){s=t}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}s=f-2|0;u=0;do{y=((e[n+(u<<1)>>1]|0)-(e[s>>1]|0)>>1)+(e[a>>1]|0)|0;if(y>>>0<1024>>>0){B=y&65535}else{B=-y>>31&1023}b[m+((ba(u,g)|0)<<1)>>1]=B;u=u+1|0;}while((u|0)<8);i=k;return}else{u=f-2|0;f=u;B=j-11|0;do{if(B>>>0<15>>>0&(q|0)<-1){UGb(p|0,u|0,18)|0;if((q|0)>=0){C=p;break}s=c[562336+(B<<2)>>2]|0;y=q;while(1){b[l+(y+8<<1)>>1]=b[a+(((ba(y,s)|0)+128>>8)-1<<1)>>1]|0;v=y+1|0;if((v|0)<0){y=v}else{C=p;break}}}else{C=f}}while(0);f=0;while(1){p=f+1|0;l=ba(p,o)|0;q=l>>5;B=l&31;if((B|0)==0){b[m+(f<<1)>>1]=b[C+(q+1<<1)>>1]|0;b[m+(f+g<<1)>>1]=b[C+(q+2<<1)>>1]|0;b[m+((g<<1)+f<<1)>>1]=b[C+(q+3<<1)>>1]|0;b[m+((g*3|0)+f<<1)>>1]=b[C+(q+4<<1)>>1]|0;b[m+((g<<2)+f<<1)>>1]=b[C+(q+5<<1)>>1]|0;b[m+((g*5|0)+f<<1)>>1]=b[C+(q+6<<1)>>1]|0;b[m+((g*6|0)+f<<1)>>1]=b[C+(q+7<<1)>>1]|0;b[m+((g*7|0)+f<<1)>>1]=b[C+(q+8<<1)>>1]|0}else{l=32-B|0;u=0;do{y=u+q|0;s=ba(e[C+(y+1<<1)>>1]|0,l)|0;b[m+((ba(u,g)|0)+f<<1)>>1]=(s+16+(ba(e[C+(y+2<<1)>>1]|0,B)|0)|0)>>>5;u=u+1|0;}while((u|0)<8)}if((p|0)<8){f=p}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;d=0;do{j=((e[a+(d<<1)>>1]|0)-(e[h>>1]|0)>>1)+(e[n>>1]|0)|0;if(j>>>0<1024>>>0){D=j&65535}else{D=-j>>31&1023}b[m+(d<<1)>>1]=D;d=d+1|0;}while((d|0)<8);i=k;return}}function mFa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+200|0;l=k|0;m=a;a=d;n=f;o=c[562400+(j-2<<2)>>2]|0;p=l+32|0;q=o>>1;if((j|0)>17){r=d-2|0;s=r;t=j-11|0;do{if(t>>>0<15>>>0&(q|0)<-1){UGb(p|0,r|0,34)|0;if((q|0)>=0){u=p;break}v=c[562336+(t<<2)>>2]|0;w=q;while(1){b[l+(w+16<<1)>>1]=b[n+(((ba(w,v)|0)+128>>8)-1<<1)>>1]|0;x=w+1|0;if((x|0)<0){w=x}else{u=p;break}}}else{u=s}}while(0);s=0;while(1){t=s+1|0;r=ba(t,o)|0;w=r>>5;v=r&31;if((v|0)==0){r=ba(s,g)|0;b[m+(r<<1)>>1]=b[u+(w+1<<1)>>1]|0;b[m+(r+1<<1)>>1]=b[u+(w+2<<1)>>1]|0;b[m+(r+2<<1)>>1]=b[u+(w+3<<1)>>1]|0;b[m+(r+3<<1)>>1]=b[u+(w+4<<1)>>1]|0;b[m+(r+4<<1)>>1]=b[u+(w+5<<1)>>1]|0;b[m+(r+5<<1)>>1]=b[u+(w+6<<1)>>1]|0;b[m+(r+6<<1)>>1]=b[u+(w+7<<1)>>1]|0;b[m+(r+7<<1)>>1]=b[u+(w+8<<1)>>1]|0;b[m+(r+8<<1)>>1]=b[u+(w+9<<1)>>1]|0;b[m+(r+9<<1)>>1]=b[u+(w+10<<1)>>1]|0;b[m+(r+10<<1)>>1]=b[u+(w+11<<1)>>1]|0;b[m+(r+11<<1)>>1]=b[u+(w+12<<1)>>1]|0;b[m+(r+12<<1)>>1]=b[u+(w+13<<1)>>1]|0;b[m+(r+13<<1)>>1]=b[u+(w+14<<1)>>1]|0;b[m+(r+14<<1)>>1]=b[u+(w+15<<1)>>1]|0;b[m+(r+15<<1)>>1]=b[u+(w+16<<1)>>1]|0}else{r=32-v|0;x=ba(s,g)|0;y=0;do{z=y+w|0;A=ba(e[u+(z+1<<1)>>1]|0,r)|0;b[m+(y+x<<1)>>1]=(A+16+(ba(e[u+(z+2<<1)>>1]|0,v)|0)|0)>>>5;y=y+1|0;}while((y|0)<16)}if((t|0)<16){s=t}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}s=f-2|0;u=0;do{y=((e[n+(u<<1)>>1]|0)-(e[s>>1]|0)>>1)+(e[a>>1]|0)|0;if(y>>>0<1024>>>0){B=y&65535}else{B=-y>>31&1023}b[m+((ba(u,g)|0)<<1)>>1]=B;u=u+1|0;}while((u|0)<16);i=k;return}u=f-2|0;f=u;B=j-11|0;do{if(B>>>0<15>>>0&(q|0)<-1){UGb(p|0,u|0,34)|0;if((q|0)>=0){C=p;break}s=c[562336+(B<<2)>>2]|0;y=q;while(1){b[l+(y+16<<1)>>1]=b[a+(((ba(y,s)|0)+128>>8)-1<<1)>>1]|0;v=y+1|0;if((v|0)<0){y=v}else{C=p;break}}}else{C=f}}while(0);f=0;while(1){p=f+1|0;l=ba(p,o)|0;q=l>>5;B=l&31;if((B|0)==0){l=q+1|0;u=0;do{b[m+((ba(u,g)|0)+f<<1)>>1]=b[C+(l+u<<1)>>1]|0;u=u+1|0;}while((u|0)<16)}else{u=32-B|0;l=0;do{y=l+q|0;s=ba(e[C+(y+1<<1)>>1]|0,u)|0;b[m+((ba(l,g)|0)+f<<1)>>1]=(s+16+(ba(e[C+(y+2<<1)>>1]|0,B)|0)|0)>>>5;l=l+1|0;}while((l|0)<16)}if((p|0)<16){f=p}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;d=0;do{j=((e[a+(d<<1)>>1]|0)-(e[h>>1]|0)>>1)+(e[n>>1]|0)|0;if(j>>>0<1024>>>0){D=j&65535}else{D=-j>>31&1023}b[m+(d<<1)>>1]=D;d=d+1|0;}while((d|0)<16);i=k;return}function nFa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+200|0;k=h|0;l=a;a=d;m=f;n=c[562400+(j-2<<2)>>2]|0;o=k+64|0;if((j|0)>17){p=d-2|0;d=p;q=j-11|0;if(q>>>0<15>>>0){UGb(o|0,p|0,66)|0;p=c[562336+(q<<2)>>2]|0;q=n;while(1){b[k+(q+32<<1)>>1]=b[m+(((ba(q,p)|0)+128>>8)-1<<1)>>1]|0;r=q+1|0;if((r|0)<0){q=r}else{s=o;break}}}else{s=d}d=0;while(1){q=d+1|0;p=ba(q,n)|0;m=p>>5;r=p&31;if((r|0)==0){p=m+1|0;t=ba(d,g)|0;u=0;do{b[l+(u+t<<1)>>1]=b[s+(p+u<<1)>>1]|0;u=u+1|0;}while((u|0)<32)}else{u=32-r|0;p=ba(d,g)|0;t=0;do{v=t+m|0;w=ba(e[s+(v+1<<1)>>1]|0,u)|0;b[l+(t+p<<1)>>1]=(w+16+(ba(e[s+(v+2<<1)>>1]|0,r)|0)|0)>>>5;t=t+1|0;}while((t|0)<32)}if((q|0)<32){d=q}else{break}}i=h;return}else{d=f-2|0;f=d;s=j-11|0;if(s>>>0<15>>>0){UGb(o|0,d|0,66)|0;d=c[562336+(s<<2)>>2]|0;s=n;while(1){b[k+(s+32<<1)>>1]=b[a+(((ba(s,d)|0)+128>>8)-1<<1)>>1]|0;j=s+1|0;if((j|0)<0){s=j}else{x=o;break}}}else{x=f}f=0;while(1){o=f+1|0;s=ba(o,n)|0;d=s>>5;a=s&31;if((a|0)==0){s=d+1|0;k=0;do{b[l+((ba(k,g)|0)+f<<1)>>1]=b[x+(s+k<<1)>>1]|0;k=k+1|0;}while((k|0)<32)}else{k=32-a|0;s=0;do{q=s+d|0;j=ba(e[x+(q+1<<1)>>1]|0,k)|0;b[l+((ba(s,g)|0)+f<<1)>>1]=(j+16+(ba(e[x+(q+2<<1)>>1]|0,a)|0)|0)>>>5;s=s+1|0;}while((s|0)<32)}if((o|0)<32){f=o}else{break}}i=h;return}}function oFa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;j=i;i=i+288|0;k=j|0;l=j+72|0;m=j+144|0;n=j+216|0;o=c[b+136>>2]|0;p=c[b+180>>2]|0;q=c[p+13140+(h<<2)>>2]|0;r=c[p+13152+(h<<2)>>2]|0;s=1<<g;t=s<<q;u=c[p+13072>>2]|0;v=t>>u;w=e>>u;x=f>>u;u=c[p+13124>>2]|0;y=(ba(x,u)|0)+w|0;z=c[b+184>>2]|0;A=c[z+1672>>2]|0;B=c[A+(y<<2)>>2]|0;y=c[b+160>>2]|0;C=c[y+32+(h<<2)>>2]|0;D=c[y+(h<<2)>>2]|0;y=(ba(C,f>>r)|0)+(e>>q)|0;E=D+y|0;F=c[p+13132>>2]|0;if((h|0)==0){G=c[o+173192>>2]|0}else{G=d[o+184621|0]|0}H=k+1|0;I=m+1|0;J=l+1|0;K=n+1|0;if((c[o+184624>>2]|0)==0){L=0}else{L=(B|0)>(c[A+(w-1+(ba(u,x+v|0)|0)<<2)>>2]|0)}M=L&1;N=c[o+184628>>2]|0;O=c[o+184636>>2]|0;P=c[o+184632>>2]|0;if((c[o+184640>>2]|0)==0){Q=0}else{Q=(B|0)>(c[A+(w+v+(ba(u,x-1|0)|0)<<2)>>2]|0)}x=Q&1;u=t<<1;v=u+f|0;w=p+13100|0;A=c[w>>2]|0;B=t+f|0;o=((v|0)>(A|0)?A:v)-B>>r;v=u+e|0;u=p+13096|0;A=c[u>>2]|0;R=t+e|0;S=((v|0)>(A|0)?A:v)-R>>q;v=z+20|0;if((a[v]|0)==1){z=c[p+13084>>2]|0;A=t>>z;t=(1<<z)-1|0;T=t&f;U=((A|0)==0)+A|0;A=(t&e|0)!=0;do{if(A|L^1){V=M}else{t=e-1>>z;W=B>>z;X=(c[p+13136>>2]|0)-W|0;Y=(U|0)>(X|0)?X:U;if((Y|0)<=0){V=0;break}X=c[(c[b+3480>>2]|0)+16>>2]|0;Z=0;_=0;while(1){$=d[X+(((ba(_+W|0,F)|0)+t|0)*14|0)+12|0]|Z;aa=_+1|0;if((aa|0)<(Y|0)){Z=$;_=aa}else{V=$;break}}}}while(0);do{if((N|0)!=1|A){ca=N}else{B=e-1>>z;L=f>>z;_=(c[p+13136>>2]|0)-L|0;Z=(U|0)>(_|0)?_:U;if((Z|0)<=0){ca=0;break}_=c[(c[b+3480>>2]|0)+16>>2]|0;Y=0;t=0;while(1){W=d[_+(((ba(t+L|0,F)|0)+B|0)*14|0)+12|0]|Y;X=t+1|0;if((X|0)<(Z|0)){Y=W;t=X}else{ca=W;break}}}}while(0);if((O|0)==1){A=(ba(f-1>>z,F)|0)+(e-1>>z)|0;da=d[(c[(c[b+3480>>2]|0)+16>>2]|0)+(A*14|0)+12|0]|0}else{da=O}A=(T|0)!=0;do{if((P|0)!=1|A){ea=P}else{T=e>>z;t=F-T|0;Y=(U|0)>(t|0)?t:U;if((Y|0)<=0){ea=0;break}t=(ba(f-1>>z,F)|0)+T|0;T=c[(c[b+3480>>2]|0)+16>>2]|0;Z=0;B=0;while(1){L=d[T+((t+B|0)*14|0)+12|0]|Z;_=B+1|0;if((_|0)<(Y|0)){Z=L;B=_}else{ea=L;break}}}}while(0);do{if(A|Q^1){fa=x}else{B=R>>z;Z=F-B|0;Y=(U|0)>(Z|0)?Z:U;if((Y|0)<=0){fa=0;break}Z=(ba(f-1>>z,F)|0)+B|0;B=c[(c[b+3480>>2]|0)+16>>2]|0;t=0;T=0;while(1){L=d[B+((Z+T|0)*14|0)+12|0]|t;_=T+1|0;if((_|0)<(Y|0)){t=L;T=_}else{fa=L;break}}}}while(0);TGb(H|0,-128|0,64)|0;TGb(I|0,-128|0,64)|0;ga=V;ha=ca;ia=da;ja=ea;ka=fa}else{ga=M;ha=N;ia=O;ja=P;ka=x}x=(ga|0)!=0;do{if(x){P=o+s|0;O=s<<1;if((P|0)<(O|0)){N=(-1<<q)+e|0;M=P-1|0;fa=(M<<r)+f|0;ea=D+(y-1+(ba(M,C)|0))|0;da=c[b+3480>>2]|0;ca=P;while(1){V=c[p+13084>>2]|0;z=(ba(fa>>V,F)|0)+(N>>V)|0;do{if((a[(c[da+16>>2]|0)+(z*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=37;break}ma=ca+1|0}else{la=37}}while(0);if((la|0)==37){la=0;z=ca+1|0;a[k+z|0]=a[ea]|0;ma=z}if((ma|0)<(O|0)){ca=ma}else{na=M;break}}}else{na=P-1|0}if((na|0)<(s|0)){break}M=(-1<<q)+e|0;ca=y-1|0;O=c[b+3480>>2]|0;ea=P;da=na;while(1){N=c[p+13084>>2]|0;fa=(ba((da<<r)+f>>N,F)|0)+(M>>N)|0;if((a[(c[O+16>>2]|0)+(fa*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=42}}else{la=42}if((la|0)==42){la=0;a[k+ea|0]=a[D+(ca+(ba(da,C)|0))|0]|0}fa=da-1|0;if((fa|0)<(s|0)){break}else{ea=da;da=fa}}}}while(0);na=(ha|0)!=0;if(na&(s|0)>0){ma=(-1<<q)+e|0;da=y-1|0;ea=c[b+3480>>2]|0;ca=s;while(1){O=ca-1|0;M=c[p+13084>>2]|0;P=(ba((O<<r)+f>>M,F)|0)+(ma>>M)|0;if((a[(c[ea+16>>2]|0)+(P*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=48}}else{la=48}if((la|0)==48){la=0;a[k+ca|0]=a[D+(da+(ba(O,C)|0))|0]|0}if((O|0)>0){ca=O}else{break}}}ca=(ia|0)!=0;do{if(ca){da=c[p+13084>>2]|0;ea=(ba((-1<<r)+f>>da,F)|0)+((-1<<q)+e>>da)|0;if((a[(c[(c[b+3480>>2]|0)+16>>2]|0)+(ea*14|0)+12|0]|0)==0){if((a[v]|0)!=0){break}}ea=a[D+(y+~C)|0]|0;a[k|0]=ea;a[m|0]=ea}}while(0);ea=(ja|0)!=0;if(ea&(s|0)>0){da=(-1<<r)+f|0;ma=y-C|0;O=c[b+3480>>2]|0;P=s;while(1){M=P-1|0;fa=c[p+13084>>2]|0;N=(ba(da>>fa,F)|0)+((M<<q)+e>>fa)|0;if((a[(c[O+16>>2]|0)+(N*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=58}}else{la=58}if((la|0)==58){la=0;a[m+P|0]=a[D+(ma+M)|0]|0}if((M|0)>0){P=M}else{break}}}P=(ka|0)!=0;do{if(P){ma=S+s|0;O=s<<1;da=ma-1|0;if((ma|0)<(O|0)){M=(da<<q)+e|0;N=(-1<<r)+f|0;fa=D+(y-C+da)|0;z=c[b+3480>>2]|0;V=ma;while(1){U=c[p+13084>>2]|0;Q=(ba(N>>U,F)|0)+(M>>U)|0;do{if((a[(c[z+16>>2]|0)+(Q*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=67;break}oa=V+1|0}else{la=67}}while(0);if((la|0)==67){la=0;Q=V+1|0;a[m+Q|0]=a[fa]|0;oa=Q}if((oa|0)<(O|0)){V=oa}else{break}}}if((da|0)<(s|0)){break}V=(-1<<r)+f|0;O=y-C|0;fa=c[b+3480>>2]|0;z=ma;M=da;while(1){N=c[p+13084>>2]|0;Q=(ba(V>>N,F)|0)+((M<<q)+e>>N)|0;if((a[(c[fa+16>>2]|0)+(Q*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=72}}else{la=72}if((la|0)==72){la=0;a[m+z|0]=a[D+(O+M)|0]|0}Q=M-1|0;if((Q|0)<(s|0)){break}else{z=M;M=Q}}}}while(0);do{if((a[v]|0)==1){D=ga|ha;y=(D|0)!=0;oa=D|ia;D=(oa|0)==0;if((ja|ka|oa|0)==0){break}oa=s<<1;S=c[u>>2]|0;if(((oa<<q)+e|0)<(S|0)){pa=oa}else{pa=S-e>>q}M=c[w>>2]|0;if(((oa<<r)+f|0)<(M|0)){qa=oa}else{qa=M-f>>r}z=(x?o:0)+s|0;do{if(P){ra=pa}else{if((R|0)<(S|0)){ra=s;break}ra=S-e>>q}}while(0);do{if(x){sa=qa}else{if(((s<<r)+f|0)<(M|0)){sa=s;break}sa=M-f>>r}}while(0);do{if(D){M=(-1<<r)+f|0;S=b+3480|0;O=0;while(1){if((O|0)>=(ra|0)){break}fa=c[p+13084>>2]|0;V=(ba(M>>fa,F)|0)+((O<<q)+e>>fa)|0;if((a[(c[(c[S>>2]|0)+16>>2]|0)+(V*14|0)+12|0]|0)==0){O=O+1|0}else{break}}do{if((O|0)>0){if((e|0)>0){if(!((O|0)>-1)){break}V=c[S>>2]|0;fa=O;while(1){da=fa-1|0;ma=c[p+13084>>2]|0;Q=(ba(M>>ma,F)|0)+((da<<q)+e>>ma)|0;if((a[(c[V+16>>2]|0)+(Q*14|0)+12|0]|0)==0){a[m+fa|0]=a[m+(fa+1)|0]|0}if((fa|0)>0){fa=da}else{break}}}else{fa=c[S>>2]|0;V=O;while(1){da=V-1|0;Q=c[p+13084>>2]|0;ma=(ba(M>>Q,F)|0)+((da<<q)+e>>Q)|0;if((a[(c[fa+16>>2]|0)+(ma*14|0)+12|0]|0)==0){a[m+V|0]=a[m+(V+1)|0]|0}if((da|0)>0){V=da}else{break}}a[m|0]=a[I]|0;break}}}while(0);a[k|0]=a[m|0]|0;ta=0}else{M=(-1<<q)+e|0;O=b+3480|0;S=z;while(1){ua=S-1|0;va=c[p+13084>>2]|0;if((S|0)<=0){la=89;break}V=(ua<<r)+f|0;fa=(ba(V>>va,F)|0)+(M>>va)|0;da=c[O>>2]|0;ma=c[da+16>>2]|0;if((a[ma+(fa*14|0)+12|0]|0)==0){S=ua}else{wa=da;xa=ma;ya=V;break}}if((la|0)==89){S=c[O>>2]|0;wa=S;xa=c[S+16>>2]|0;ya=(ua<<r)+f|0}S=p+13084|0;V=wa+16|0;if((a[xa+(((ba(ya>>va,F)|0)+(M>>va)|0)*14|0)+12|0]|0)!=0){ta=ua;break}ma=(-1<<r)+f|0;da=0;while(1){if((da|0)>=(ra|0)){break}if((a[xa+(((ba(ma>>va,F)|0)+((da<<q)+e>>va)|0)*14|0)+12|0]|0)==0){da=da+1|0}else{break}}a:do{if((da|0)>-1){M=da;O=va;fa=xa;while(1){Q=M-1|0;if((a[fa+(((ba(ma>>O,F)|0)+((Q<<q)+e>>O)|0)*14|0)+12|0]|0)==0){a[m+M|0]=a[m+(M+1)|0]|0}if((M|0)<=0){break a}M=Q;O=c[S>>2]|0;fa=c[V>>2]|0}}}while(0);a[k|0]=a[m|0]|0;ta=0}}while(0);if(y&(ta|0)<(sa|0)){z=(-1<<q)+e|0;D=c[b+3480>>2]|0;V=ta;while(1){S=c[p+13084>>2]|0;ma=(ba((V<<r)+f>>S,F)|0)+(z>>S)|0;if((a[(c[D+16>>2]|0)+(ma*14|0)+12|0]|0)==0){ma=V+1|0;a[k+ma|0]=a[k+V|0]|0;za=ma}else{za=V+1|0}if((za|0)<(sa|0)){V=za}else{break}}}b:do{if((s|0)>0&(na^1)){V=a[k|0]|0;D=1;while(1){a[k+D|0]=V;if((D|0)>=(s|0)){break b}D=D+1|0}}}while(0);if((s|0)<(oa|0)&(x^1)){D=a[k+s|0]|0;V=s;do{V=V+1|0;a[k+V|0]=D;}while((V|0)<(oa|0))}oa=(e|0)==0;V=(f|0)==0;c:do{if(oa|V){D=sa-1|0;if(oa){if((sa|0)<=0){break}z=a[k+sa|0]|0;y=D;while(1){a[k+y|0]=z;if((y|0)>0){y=y-1|0}else{break c}}}if((D|0)<=0){break}y=(-1<<q)+e|0;z=c[b+3480>>2]|0;ma=D;while(1){S=c[p+13084>>2]|0;da=ma-1|0;fa=(ba((da<<r)+f>>S,F)|0)+(y>>S)|0;if((a[(c[z+16>>2]|0)+(fa*14|0)+12|0]|0)==0){a[k+ma|0]=a[k+(ma+1)|0]|0}if((da|0)>0){ma=da}else{break}}}else{if((sa|0)<=0){break}ma=(-1<<q)+e|0;z=c[b+3480>>2]|0;y=sa;while(1){D=y-1|0;da=c[p+13084>>2]|0;fa=(ba((y-2<<r)+f>>da,F)|0)+(ma>>da)|0;if((a[(c[z+16>>2]|0)+(fa*14|0)+12|0]|0)==0){a[k+D|0]=a[k+y|0]|0}if((D|0)>0){y=D}else{break}}}}while(0);a[m|0]=a[k|0]|0;if(!((ra|0)>0&(V^1))){break}oa=(-1<<r)+f|0;y=c[b+3480>>2]|0;z=0;while(1){ma=c[p+13084>>2]|0;D=(ba(oa>>ma,F)|0)+((z<<q)+e>>ma)|0;if((a[(c[y+16>>2]|0)+(D*14|0)+12|0]|0)==0){D=z+1|0;a[m+D|0]=a[m+z|0]|0;Aa=D}else{Aa=z+1|0}if((Aa|0)<(ra|0)){z=Aa}else{break}}}}while(0);d:do{if(x){la=176}else{if(na){Aa=s<<1;if((s|0)>=(Aa|0)){la=176;break}ra=a[k+s|0]|0;e=s;while(1){q=e+1|0;a[k+q|0]=ra;if((q|0)<(Aa|0)){e=q}else{la=176;break d}}}if(ca){e=s<<1;if((e|0)<=0){la=178;break}Aa=a[k|0]|0;ra=1;while(1){a[k+ra|0]=Aa;if((ra|0)>=(e|0)){la=178;break d}ra=ra+1|0}}if(ea){ra=a[I]|0;a[k|0]=ra;e=s<<1;if((e|0)>0){Ba=1}else{la=180;break}while(1){a[k+Ba|0]=ra;if((Ba|0)>=(e|0)){la=180;break d}Ba=Ba+1|0}}if(P){if((s|0)>0){e=s;do{a[m+e|0]=a[m+(e+1)|0]|0;e=e-1|0;}while((e|0)>0)}e=a[I]|0;a[k|0]=e;ra=s<<1;if((ra|0)>0){Ca=1}else{break}while(1){a[k+Ca|0]=e;if((Ca|0)>=(ra|0)){break d}Ca=Ca+1|0}}a[k|0]=-128;a[I]=-128;ra=s<<1;e:do{if((ra|0)>1){e=2;while(1){a[m+e|0]=-128;if((e|0)>=(ra|0)){break e}e=e+1|0}}}while(0);if((ra|0)>0){Da=1}else{la=176;break}while(1){a[k+Da|0]=-128;if((Da|0)>=(ra|0)){la=176;break d}Da=Da+1|0}}}while(0);do{if((la|0)==176){if((ha|0)==0&(s|0)>0){Ea=s}else{la=178;break}while(1){a[k+Ea|0]=a[k+(Ea+1)|0]|0;Da=Ea-1|0;if((Da|0)>0){Ea=Da}else{la=178;break}}}}while(0);do{if((la|0)==178){if((ia|0)!=0){la=180;break}a[k|0]=a[H]|0;la=180}}while(0);f:do{if((la|0)==180){if((ja|0)!=0){break}ia=a[k|0]|0;a[I]=ia;if((s|0)>1){Fa=2}else{break}while(1){a[m+Fa|0]=ia;if((Fa|0)>=(s|0)){break f}Fa=Fa+1|0}}}while(0);do{if(!P){Fa=s<<1;if((s|0)>=(Fa|0)){break}ja=a[m+s|0]|0;la=s;do{la=la+1|0;a[m+la|0]=ja;}while((la|0)<(Fa|0))}}while(0);P=k|0;Fa=a[P]|0;a[m|0]=Fa;g:do{if((h|0)!=0|(G|0)==1|(s|0)==4){Ga=H;Ha=I}else{la=G-26|0;ja=(la|0)>-1?la:26-G|0;la=G-10|0;ia=(la|0)>-1?la:10-G|0;if((((ja|0)>(ia|0)?ia:ja)|0)<=(c[906616+(g-3<<2)>>2]|0)){Ga=H;Ha=I;break}do{if((a[p+13061|0]|0)!=0&(g|0)==5){ja=Fa&255;ia=a[m+64|0]|0;la=ia&255;Ea=la+ja-(d[m+32|0]<<1)|0;if((((Ea|0)>-1?Ea:-Ea|0)|0)>=8){break}Ea=k+64|0;ha=a[Ea]|0;Da=(ha&255)+ja-(d[k+32|0]<<1)|0;if((((Da|0)>-1?Da:-Da|0)|0)>=8){break}a[n|0]=Fa;a[n+64|0]=ia;ia=0;while(1){Da=ia+1|0;a[n+Da|0]=((ba(ja,63-ia|0)|0)+32+(ba(la,Da)|0)|0)>>>6;if((Da|0)<63){ia=Da}else{Ia=0;Ja=Fa;Ka=ha;break}}while(1){ha=Ia+1|0;a[k+ha|0]=((ba(Ja&255,63-Ia|0)|0)+32+(ba(Ka&255,ha)|0)|0)>>>6;if((ha|0)>=63){Ga=H;Ha=K;break g}Ia=ha;Ja=a[P]|0;Ka=a[Ea]|0}}}while(0);Ea=s<<1;ha=a[k+Ea|0]|0;a[l+Ea|0]=ha;ia=a[m+Ea|0]|0;a[n+Ea|0]=ia;la=Ea-2|0;Ea=(la|0)>-1;if(Ea){ja=la;Da=ha;while(1){ha=ja+1|0;Ca=a[k+ha|0]|0;a[l+ha|0]=((Da&255)+2+((Ca&255)<<1)+(d[k+ja|0]|0)|0)>>>2;if((ja|0)>0){ja=ja-1|0;Da=Ca}else{break}}}Da=((d[H]|0)+2+((Fa&255)<<1)+(d[I]|0)|0)>>>2&255;a[l|0]=Da;a[n|0]=Da;if(Ea){La=la;Ma=ia}else{Ga=J;Ha=K;break}while(1){Da=La+1|0;ja=a[m+Da|0]|0;a[n+Da|0]=((Ma&255)+2+((ja&255)<<1)+(d[m+La|0]|0)|0)>>>2;if((La|0)>0){La=La-1|0;Ma=ja}else{Ga=J;Ha=K;break}}}}while(0);if((G|0)==1){Se[c[b+5840>>2]&511](E,Ha,Ga,C,g,h);i=j;return}else if((G|0)==0){cf[c[b+5824+(g-2<<2)>>2]&1023](E,Ha,Ga,C);i=j;return}else{Se[c[b+5844+(g-2<<2)>>2]&511](E,Ha,Ga,C,h,G);i=j;return}}function pFa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c+4|0;h=e+4|0;i=0;while(1){j=e+i|0;k=3-i|0;l=i+1|0;m=ba(i,f)|0;n=ba(d[c]|0,k)|0;a[b+m|0]=(((d[j]|0)*3|0)+4+(d[g]|0)+n+(ba(d[h]|0,l)|0)|0)>>>3;n=ba(d[c+1|0]|0,k)|0;a[b+(m+1)|0]=(((d[j]|0)<<1)+4+((d[g]|0)<<1)+n+(ba(d[h]|0,l)|0)|0)>>>3;n=ba(d[c+2|0]|0,k)|0;a[b+(m+2)|0]=((d[j]|0)+4+((d[g]|0)*3|0)+n+(ba(d[h]|0,l)|0)|0)>>>3;n=ba(d[c+3|0]|0,k)|0;a[b+(m+3)|0]=(((d[g]|0)<<2)+4+n+(ba(d[h]|0,l)|0)|0)>>>3;if((l|0)<4){i=l}else{break}}return}function qFa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c+8|0;h=e+8|0;i=0;while(1){j=e+i|0;k=7-i|0;l=i+1|0;m=ba(i,f)|0;n=0;while(1){o=ba(d[j]|0,7-n|0)|0;p=n+1|0;q=ba(d[g]|0,p)|0;r=ba(d[c+n|0]|0,k)|0;a[b+(n+m)|0]=(o+8+q+r+(ba(d[h]|0,l)|0)|0)>>>4;if((p|0)<8){n=p}else{break}}if((l|0)<8){i=l}else{break}}return}function rFa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c+16|0;h=e+16|0;i=0;while(1){j=e+i|0;k=15-i|0;l=i+1|0;m=ba(i,f)|0;n=0;while(1){o=ba(d[j]|0,15-n|0)|0;p=n+1|0;q=ba(d[g]|0,p)|0;r=ba(d[c+n|0]|0,k)|0;a[b+(n+m)|0]=(o+16+q+r+(ba(d[h]|0,l)|0)|0)>>>5;if((p|0)<16){n=p}else{break}}if((l|0)<16){i=l}else{break}}return}function sFa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c+32|0;h=e+32|0;i=0;while(1){j=e+i|0;k=31-i|0;l=i+1|0;m=ba(i,f)|0;n=0;while(1){o=ba(d[j]|0,31-n|0)|0;p=n+1|0;q=ba(d[g]|0,p)|0;r=ba(d[c+n|0]|0,k)|0;a[b+(n+m)|0]=(o+32+q+r+(ba(d[h]|0,l)|0)|0)>>>6;if((p|0)<32){n=p}else{break}}if((l|0)<32){i=l}else{break}}return}function tFa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=1<<h;k=(j|0)>0;do{if(k){l=j;m=0;do{l=(d[f+m|0]|0)+l+(d[e+m|0]|0)|0;m=m+1|0;}while((m|0)<(j|0));m=l>>h+1;n=ba(m,16843009)|0;if(!k){o=m;break}p=(j|0)/4|0;if((j|0)>3){q=0}else{o=m;break}while(1){r=ba(q,g)|0;s=0;do{c[b+((s<<2)+r)>>2]=n;s=s+1|0;}while((s|0)<(p|0));s=q+1|0;if((s|0)<(j|0)){q=s}else{o=m;break}}}else{o=j>>h+1}}while(0);if(!((i|0)==0&(j|0)<32)){return}a[b]=((o<<1)+2+(d[f]|0)+(d[e]|0)|0)>>>2;i=(j|0)>1;if(!i){return}h=(o*3|0)+2|0;q=1;do{a[b+q|0]=(h+(d[e+q|0]|0)|0)>>>2;q=q+1|0;}while((q|0)<(j|0));if(!i){return}i=(o*3|0)+2|0;o=1;do{a[b+(ba(o,g)|0)|0]=(i+(d[f+o|0]|0)|0)>>>2;o=o+1|0;}while((o|0)<(j|0));return}function uFa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;k=i;i=i+104|0;l=k|0;m=c[562400+(j-2<<2)>>2]|0;n=l+4|0;o=m>>3;if((j|0)>17){p=e-1|0;q=j-11|0;do{if(q>>>0<15>>>0&(o|0)<-1){a[n]=a[p]|0;a[n+1|0]=a[p+1|0]|0;a[n+2|0]=a[p+2|0]|0;a[n+3|0]=a[p+3|0]|0;a[n+4|0]=a[p+4|0]|0;if((o|0)>=0){r=n;break}s=c[562336+(q<<2)>>2]|0;t=o;while(1){a[l+(t+4)|0]=a[f+(((ba(t,s)|0)+128>>8)-1)|0]|0;u=t+1|0;if((u|0)<0){t=u}else{r=n;break}}}else{r=p}}while(0);p=0;while(1){q=p+1|0;t=ba(q,m)|0;s=t>>5;u=t&31;if((u|0)==0){t=ba(p,g)|0;a[b+t|0]=a[r+(s+1)|0]|0;a[b+(t+1)|0]=a[r+(s+2)|0]|0;a[b+(t+2)|0]=a[r+(s+3)|0]|0;a[b+(t+3)|0]=a[r+(s+4)|0]|0}else{t=32-u|0;v=ba(p,g)|0;w=ba(d[r+(s+1)|0]|0,t)|0;a[b+v|0]=(w+16+(ba(d[r+(s+2)|0]|0,u)|0)|0)>>>5;w=ba(d[r+(s+2)|0]|0,t)|0;a[b+(v+1)|0]=(w+16+(ba(d[r+(s+3)|0]|0,u)|0)|0)>>>5;w=ba(d[r+(s+3)|0]|0,t)|0;a[b+(v+2)|0]=(w+16+(ba(d[r+(s+4)|0]|0,u)|0)|0)>>>5;w=ba(d[r+(s+4)|0]|0,t)|0;a[b+(v+3)|0]=(w+16+(ba(d[r+(s+5)|0]|0,u)|0)|0)>>>5}if((q|0)<4){p=q}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}p=f-1|0;r=((d[f]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(r>>>0>255>>>0){x=-r>>31&255}else{x=r&255}a[b]=x;x=((d[f+1|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(x>>>0>255>>>0){y=-x>>31&255}else{y=x&255}a[b+g|0]=y;y=((d[f+2|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}a[b+(g<<1)|0]=z;z=((d[f+3|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}a[b+(g*3|0)|0]=A;i=k;return}else{A=f-1|0;z=j-11|0;do{if(z>>>0<15>>>0&(o|0)<-1){a[n]=a[A]|0;a[n+1|0]=a[A+1|0]|0;a[n+2|0]=a[A+2|0]|0;a[n+3|0]=a[A+3|0]|0;a[n+4|0]=a[A+4|0]|0;if((o|0)>=0){B=n;break}p=c[562336+(z<<2)>>2]|0;y=o;while(1){a[l+(y+4)|0]=a[e+(((ba(y,p)|0)+128>>8)-1)|0]|0;x=y+1|0;if((x|0)<0){y=x}else{B=n;break}}}else{B=A}}while(0);A=0;while(1){n=A+1|0;l=ba(n,m)|0;o=l>>5;z=l&31;if((z|0)==0){a[b+A|0]=a[B+(o+1)|0]|0;a[b+(A+g)|0]=a[B+(o+2)|0]|0;a[b+((g<<1)+A)|0]=a[B+(o+3)|0]|0;a[b+((g*3|0)+A)|0]=a[B+(o+4)|0]|0}else{l=32-z|0;y=ba(d[B+(o+1)|0]|0,l)|0;a[b+A|0]=(y+16+(ba(d[B+(o+2)|0]|0,z)|0)|0)>>>5;y=ba(d[B+(o+2)|0]|0,l)|0;a[b+(A+g)|0]=(y+16+(ba(d[B+(o+3)|0]|0,z)|0)|0)>>>5;y=ba(d[B+(o+3)|0]|0,l)|0;a[b+((g<<1)+A)|0]=(y+16+(ba(d[B+(o+4)|0]|0,z)|0)|0)>>>5;y=ba(d[B+(o+4)|0]|0,l)|0;a[b+((g*3|0)+A)|0]=(y+16+(ba(d[B+(o+5)|0]|0,z)|0)|0)>>>5}if((n|0)<4){A=n}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=e-1|0;j=((d[e]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(j>>>0>255>>>0){C=-j>>31&255}else{C=j&255}a[b]=C;C=((d[e+1|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(C>>>0>255>>>0){D=-C>>31&255}else{D=C&255}a[b+1|0]=D;D=((d[e+2|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(D>>>0>255>>>0){E=-D>>31&255}else{E=D&255}a[b+2|0]=E;E=((d[e+3|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(E>>>0>255>>>0){F=-E>>31&255}else{F=E&255}a[b+3|0]=F;i=k;return}}function vFa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=i;i=i+104|0;l=k|0;m=c[562400+(j-2<<2)>>2]|0;n=l+8|0;o=m>>2;if((j|0)>17){p=e-1|0;q=j-11|0;do{if(q>>>0<15>>>0&(o|0)<-1){UGb(n|0,p|0,9)|0;if((o|0)>=0){r=n;break}s=c[562336+(q<<2)>>2]|0;t=o;while(1){a[l+(t+8)|0]=a[f+(((ba(t,s)|0)+128>>8)-1)|0]|0;u=t+1|0;if((u|0)<0){t=u}else{r=n;break}}}else{r=p}}while(0);p=0;while(1){q=p+1|0;t=ba(q,m)|0;s=t>>5;u=t&31;if((u|0)==0){t=ba(p,g)|0;a[b+t|0]=a[r+(s+1)|0]|0;a[b+(t+1)|0]=a[r+(s+2)|0]|0;a[b+(t+2)|0]=a[r+(s+3)|0]|0;a[b+(t+3)|0]=a[r+(s+4)|0]|0;a[b+(t+4)|0]=a[r+(s+5)|0]|0;a[b+(t+5)|0]=a[r+(s+6)|0]|0;a[b+(t+6)|0]=a[r+(s+7)|0]|0;a[b+(t+7)|0]=a[r+(s+8)|0]|0}else{t=32-u|0;v=ba(p,g)|0;w=0;do{x=w+s|0;y=ba(d[r+(x+1)|0]|0,t)|0;a[b+(w+v)|0]=(y+16+(ba(d[r+(x+2)|0]|0,u)|0)|0)>>>5;w=w+1|0;}while((w|0)<8)}if((q|0)<8){p=q}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}p=f-1|0;r=0;do{w=((d[f+r|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[b+(ba(r,g)|0)|0]=z;r=r+1|0;}while((r|0)<8);i=k;return}else{r=f-1|0;z=j-11|0;do{if(z>>>0<15>>>0&(o|0)<-1){UGb(n|0,r|0,9)|0;if((o|0)>=0){A=n;break}p=c[562336+(z<<2)>>2]|0;w=o;while(1){a[l+(w+8)|0]=a[e+(((ba(w,p)|0)+128>>8)-1)|0]|0;u=w+1|0;if((u|0)<0){w=u}else{A=n;break}}}else{A=r}}while(0);r=0;while(1){n=r+1|0;l=ba(n,m)|0;o=l>>5;z=l&31;if((z|0)==0){a[b+r|0]=a[A+(o+1)|0]|0;a[b+(r+g)|0]=a[A+(o+2)|0]|0;a[b+((g<<1)+r)|0]=a[A+(o+3)|0]|0;a[b+((g*3|0)+r)|0]=a[A+(o+4)|0]|0;a[b+((g<<2)+r)|0]=a[A+(o+5)|0]|0;a[b+((g*5|0)+r)|0]=a[A+(o+6)|0]|0;a[b+((g*6|0)+r)|0]=a[A+(o+7)|0]|0;a[b+((g*7|0)+r)|0]=a[A+(o+8)|0]|0}else{l=32-z|0;w=0;do{p=w+o|0;q=ba(d[A+(p+1)|0]|0,l)|0;a[b+((ba(w,g)|0)+r)|0]=(q+16+(ba(d[A+(p+2)|0]|0,z)|0)|0)>>>5;w=w+1|0;}while((w|0)<8)}if((n|0)<8){r=n}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=e-1|0;j=0;do{r=((d[e+j|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(r>>>0>255>>>0){B=-r>>31&255}else{B=r&255}a[b+j|0]=B;j=j+1|0;}while((j|0)<8);i=k;return}}function wFa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=i;i=i+104|0;l=k|0;m=c[562400+(j-2<<2)>>2]|0;n=l+16|0;o=m>>1;if((j|0)>17){p=e-1|0;q=j-11|0;do{if(q>>>0<15>>>0&(o|0)<-1){UGb(n|0,p|0,17)|0;if((o|0)>=0){r=n;break}s=c[562336+(q<<2)>>2]|0;t=o;while(1){a[l+(t+16)|0]=a[f+(((ba(t,s)|0)+128>>8)-1)|0]|0;u=t+1|0;if((u|0)<0){t=u}else{r=n;break}}}else{r=p}}while(0);p=0;while(1){q=p+1|0;t=ba(q,m)|0;s=t>>5;u=t&31;if((u|0)==0){t=ba(p,g)|0;a[b+t|0]=a[r+(s+1)|0]|0;a[b+(t+1)|0]=a[r+(s+2)|0]|0;a[b+(t+2)|0]=a[r+(s+3)|0]|0;a[b+(t+3)|0]=a[r+(s+4)|0]|0;a[b+(t+4)|0]=a[r+(s+5)|0]|0;a[b+(t+5)|0]=a[r+(s+6)|0]|0;a[b+(t+6)|0]=a[r+(s+7)|0]|0;a[b+(t+7)|0]=a[r+(s+8)|0]|0;a[b+(t+8)|0]=a[r+(s+9)|0]|0;a[b+(t+9)|0]=a[r+(s+10)|0]|0;a[b+(t+10)|0]=a[r+(s+11)|0]|0;a[b+(t+11)|0]=a[r+(s+12)|0]|0;a[b+(t+12)|0]=a[r+(s+13)|0]|0;a[b+(t+13)|0]=a[r+(s+14)|0]|0;a[b+(t+14)|0]=a[r+(s+15)|0]|0;a[b+(t+15)|0]=a[r+(s+16)|0]|0}else{t=32-u|0;v=ba(p,g)|0;w=0;do{x=w+s|0;y=ba(d[r+(x+1)|0]|0,t)|0;a[b+(w+v)|0]=(y+16+(ba(d[r+(x+2)|0]|0,u)|0)|0)>>>5;w=w+1|0;}while((w|0)<16)}if((q|0)<16){p=q}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}p=f-1|0;r=0;do{w=((d[f+r|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[b+(ba(r,g)|0)|0]=z;r=r+1|0;}while((r|0)<16);i=k;return}r=f-1|0;z=j-11|0;do{if(z>>>0<15>>>0&(o|0)<-1){UGb(n|0,r|0,17)|0;if((o|0)>=0){A=n;break}p=c[562336+(z<<2)>>2]|0;w=o;while(1){a[l+(w+16)|0]=a[e+(((ba(w,p)|0)+128>>8)-1)|0]|0;u=w+1|0;if((u|0)<0){w=u}else{A=n;break}}}else{A=r}}while(0);r=0;while(1){n=r+1|0;l=ba(n,m)|0;o=l>>5;z=l&31;if((z|0)==0){l=o+1|0;w=0;do{a[b+((ba(w,g)|0)+r)|0]=a[A+(l+w)|0]|0;w=w+1|0;}while((w|0)<16)}else{w=32-z|0;l=0;do{p=l+o|0;q=ba(d[A+(p+1)|0]|0,w)|0;a[b+((ba(l,g)|0)+r)|0]=(q+16+(ba(d[A+(p+2)|0]|0,z)|0)|0)>>>5;l=l+1|0;}while((l|0)<16)}if((n|0)<16){r=n}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=e-1|0;j=0;do{r=((d[e+j|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(r>>>0>255>>>0){B=-r>>31&255}else{B=r&255}a[b+j|0]=B;j=j+1|0;}while((j|0)<16);i=k;return}function xFa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+104|0;k=h|0;l=c[562400+(j-2<<2)>>2]|0;m=k+32|0;if((j|0)>17){n=e-1|0;o=j-11|0;if(o>>>0<15>>>0){UGb(m|0,n|0,33)|0;p=c[562336+(o<<2)>>2]|0;o=l;while(1){a[k+(o+32)|0]=a[f+(((ba(o,p)|0)+128>>8)-1)|0]|0;q=o+1|0;if((q|0)<0){o=q}else{r=m;break}}}else{r=n}n=0;while(1){o=n+1|0;p=ba(o,l)|0;q=p>>5;s=p&31;if((s|0)==0){p=q+1|0;t=ba(n,g)|0;u=0;do{a[b+(u+t)|0]=a[r+(p+u)|0]|0;u=u+1|0;}while((u|0)<32)}else{u=32-s|0;p=ba(n,g)|0;t=0;do{v=t+q|0;w=ba(d[r+(v+1)|0]|0,u)|0;a[b+(t+p)|0]=(w+16+(ba(d[r+(v+2)|0]|0,s)|0)|0)>>>5;t=t+1|0;}while((t|0)<32)}if((o|0)<32){n=o}else{break}}i=h;return}else{n=f-1|0;f=j-11|0;if(f>>>0<15>>>0){UGb(m|0,n|0,33)|0;j=c[562336+(f<<2)>>2]|0;f=l;while(1){a[k+(f+32)|0]=a[e+(((ba(f,j)|0)+128>>8)-1)|0]|0;r=f+1|0;if((r|0)<0){f=r}else{x=m;break}}}else{x=n}n=0;while(1){m=n+1|0;f=ba(m,l)|0;j=f>>5;e=f&31;if((e|0)==0){f=j+1|0;k=0;do{a[b+((ba(k,g)|0)+n)|0]=a[x+(f+k)|0]|0;k=k+1|0;}while((k|0)<32)}else{k=32-e|0;f=0;do{o=f+j|0;r=ba(d[x+(o+1)|0]|0,k)|0;a[b+((ba(f,g)|0)+n)|0]=(r+16+(ba(d[x+(o+2)|0]|0,e)|0)|0)>>>5;f=f+1|0;}while((f|0)<32)}if((m|0)<32){n=m}else{break}}i=h;return}}function yFa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=c[b+60>>2]|0;if((c[b+100>>2]|0)<1){yDb(b,16,2352552,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1094995529;i=d;return g|0}a[e]=a[c[b+96>>2]|0]|0;c[b+140>>2]=11;h=b+120|0;c[e+4>>2]=c[h>>2];j=b+124|0;c[e+8>>2]=c[j>>2];k=e+20|0;l=k;c[l>>2]=cEb(ba(c[j>>2]|0,c[h>>2]|0)|0)|0;m=e+24|0;n=m;c[n>>2]=cEb(ba(c[j>>2]|0,c[h>>2]|0)|0)|0;o=cEb(ba(c[j>>2]|0,c[h>>2]|0)|0)|0;p=e+28|0;c[p>>2]=o;q=c[l>>2]|0;do{if((q|0)!=0){l=c[n>>2]|0;if((l|0)==0|(o|0)==0){break}r=c[j>>2]|0;if(!((ba(r,c[h>>2]|0)|0)!=0&(r&1|0)==0)){break}c[e+12>>2]=q;c[e+16>>2]=l;g=0;i=d;return g|0}}while(0);yDb(b,16,2332360,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;$Db(k);$Db(m);$Db(p);g=-12;i=d;return g|0}function zFa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0;h=i;j=e;k=b+60|0;l=c[k>>2]|0;m=g+28|0;n=c[m>>2]|0;if((n|0)<8){yDb(b,16,2187232,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}q=g+24|0;g=c[q>>2]|0;r=g+4|0;s=(d[r]|d[r+1|0]<<8)<<16>>16;a:do{if((s<<16>>16|0)==21833){r=_$a(b,j,0)|0;if((r|0)<0){p=r;i=h;return p|0}r=c[q>>2]|0;t=r+8|0;u=c[m>>2]|0;v=u-8|0;w=c[k>>2]|0;x=(v|0)>-1;do{if((a[l]|0)==74){if(!x){yDb(0,0,1940112,(o=i,i=i+24|0,c[o>>2]=1915928,c[o+8>>2]=1895360,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}y=t;b:do{if((v|0)!=0){z=r+u|0;A=w+4|0;B=w+8|0;C=w+12|0;D=w+16|0;E=t;F=0;G=y;c:while(1){H=z-G|0;do{if((H|0)<1){I=E;J=93}else{K=a[E]|0;L=K&63;M=L&255;if(L<<24>>24==0){N=E+1|0;O=(K&255)>>>6;if((O|0)==0){I=N;J=93;break}else if((O|0)==3){break b}else if((O|0)==2){P=(c[A>>2]|0)+F|0;Q=N;J=104;break}else if((O|0)!=1){P=F;Q=N;J=104;break}O=c[A>>2]|0;if(!((O+F|0)>>>0<(ba(c[B>>2]|0,O)|0)>>>0)){J=97;break c}if((z-N|0)<1){R=0;S=N}else{R=a[N]|0;S=E+2|0}a[(c[C>>2]|0)+F|0]=R;if((z-S|0)<1){T=0;U=S}else{T=a[S]|0;U=S+1|0}a[(c[C>>2]|0)+((c[A>>2]|0)+F)|0]=T;P=F+1|0;Q=U;J=104;break}N=K&255;K=N&64;O=H>>>0>1>>>0?1:H;V=E+O|0;if((z-V|0)<2){W=0;X=V}else{Y=V;W=(d[Y]|d[Y+1|0]<<8)<<16>>16&65535;X=E+(O+2)|0}O=W+F|0;if((N&128|0)==0){Z=O}else{if(O>>>0<65536>>>0){J=111;break c}Z=O-65536|0}O=c[A>>2]|0;N=ba(c[B>>2]|0,O)|0;if(!((Z+M+O|0)>>>0<N>>>0)){J=114;break c}if(!((M+F+O|0)>>>0<N>>>0)){J=116;break c}N=L-1&255;if((K|0)==0){K=L;O=Z;M=F;while(1){Y=c[C>>2]|0;a[Y+M|0]=a[Y+O|0]|0;Y=c[A>>2]|0;V=c[C>>2]|0;a[V+(Y+M)|0]=a[V+(Y+O)|0]|0;Y=K-1&255;if(Y<<24>>24==0){break}else{K=Y;O=O+1|0;M=M+1|0}}_=F+1+N|0;$=X;break}else{M=L;O=Z;K=F;while(1){a[(c[C>>2]|0)+K|0]=a[(c[D>>2]|0)+O|0]|0;Y=c[A>>2]|0;a[(c[C>>2]|0)+(Y+K)|0]=a[(c[D>>2]|0)+(Y+O)|0]|0;Y=M-1&255;if(Y<<24>>24==0){break}else{M=Y;O=O+1|0;K=K+1|0}}_=F+1+N|0;$=X;break}}}while(0);if((J|0)==93){J=0;if((z-I|0)<1){aa=0;ca=I}else{aa=d[I]|0;ca=I+1|0}P=aa+F|0;Q=ca;J=104}if((J|0)==104){J=0;if(P>>>0>(ba(c[B>>2]|0,c[A>>2]|0)|0)>>>0){J=106;break}else{_=P;$=Q}}H=$;if((H-y|0)>>>0<v>>>0){E=$;F=_;G=H}else{break b}}if((J|0)==97){yDb(b,16,2051784,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==106){yDb(b,16,2051784,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==111){yDb(b,16,2006392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==114){yDb(b,16,2006392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==116){yDb(b,16,1968600,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);UGb(c[l+28>>2]|0,c[l+12>>2]|0,ba(c[l+8>>2]|0,c[l+4>>2]|0)|0)|0}else{if(!x){yDb(0,0,1940112,(o=i,i=i+24|0,c[o>>2]=1915928,c[o+8>>2]=1895360,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}y=t;d:do{if((v|0)!=0){G=r+u|0;F=w+4|0;E=w+8|0;A=w+12|0;B=w+16|0;z=t;D=0;C=y;e:while(1){H=G-C|0;do{if((H|0)<1){da=z;J=129}else{K=a[z]|0;O=K&255;M=O&31;if((M|0)==0){L=z+1|0;Y=O>>>5;if((Y|0)==1){if((G-L|0)<1){ea=0;fa=L}else{ea=d[L]<<1;fa=z+2|0}ga=ea+D|0;ha=fa;J=152;break}else if((Y|0)==3){if((G-L|0)<1){ia=0;ja=L}else{ia=d[L]<<1;ja=z+2|0}V=ia+D|0;if(V>>>0>(ba(c[E>>2]|0,c[F>>2]|0)|0)>>>0){J=147;break e}ka=G-ja|0;if((ia|0)>0){la=(ka|0)<1;ma=ia;na=D;while(1){if(la){oa=0}else{oa=a[ja]|0}a[(c[A>>2]|0)+na|0]=oa;pa=ma-1|0;if((pa|0)>0){ma=pa;na=na+1|0}else{qa=V;break}}}else{qa=D}ga=qa;ha=ja+(ka>>>0>1>>>0?1:ka)|0;J=152;break}else if((Y|0)==2){if((G-L|0)<2){ra=0;sa=L}else{V=L;ra=((d[V]|d[V+1|0]<<8)<<16>>16&65535)<<1;sa=z+3|0}ga=ra+D|0;ha=sa;J=152;break}else if((Y|0)==0){da=L;J=129;break}else{break d}}V=H>>>0>1>>>0?1:H;na=z+V|0;ma=G-na|0;do{if((ma|0)<1){ta=0;ua=na;va=0}else{la=d[na]|0;if((ma|0)<2){ta=0;ua=na;va=la;break}N=na;ta=(d[N]|d[N+1|0]<<8)<<16>>16&65534;ua=z+(V+2)|0;va=la}}while(0);V=ta+D|0;na=V-32768|0;ma=K<<24>>24<0;if(ma){L=c[F>>2]|0;Y=c[E>>2]|0;if((V-32767|0)>=(ba(Y,L)|0)){J=163;break e}wa=L;xa=Y;ya=M<<1}else{Y=M<<1;L=c[F>>2]|0;V=c[E>>2]|0;if((na+Y|0)>(ba(V,L)|0)){J=160;break e}else{wa=L;xa=V;ya=Y}}if((ya+D|0)>>>0>(ba(wa,xa)|0)>>>0){J=165;break e}Y=O&64;V=(Y|0)!=0;L=(wa<<1)-1&-(Y>>>6);if(ma){if((na|0)<(ya-2+L|0)){J=168;break e}}else{if((na|0)<(L|0)){J=170;break e}}L=ma?-2:2;ma=K&31;Y=-ma|0;ka=(Y|0)>-1;la=(ka?Y:2147483647)+ma<<1;if((K&32)==0){ma=na;N=M;pa=D;while(1){if(V){za=c[A>>2]|0;a[za+pa|0]=a[za+(ma+1-(c[F>>2]<<1))|0]|0;za=c[A>>2]|0;a[za+(pa+1)|0]=a[za+ma|0]|0}else{za=c[A>>2]|0;a[za+pa|0]=a[za+ma|0]|0;za=c[A>>2]|0;a[za+(pa+1)|0]=a[za+(ma+1)|0]|0}za=N-1|0;if((za|0)>0){ma=ma+L|0;N=za;pa=pa+2|0}else{break}}}else{pa=na;N=M;ma=D;while(1){if(V){a[(c[A>>2]|0)+ma|0]=a[(c[B>>2]|0)+(pa+1-(c[F>>2]<<1))|0]|0;a[(c[A>>2]|0)+(ma+1)|0]=a[(c[B>>2]|0)+pa|0]|0}else{a[(c[A>>2]|0)+ma|0]=a[(c[B>>2]|0)+pa|0]|0;a[(c[A>>2]|0)+(ma+1)|0]=a[(c[B>>2]|0)+(pa+1)|0]|0}K=N-1|0;if((K|0)>0){pa=pa+L|0;N=K;ma=ma+2|0}else{break}}}ma=D+2+la|0;if((va&1|0)==0){Aa=ma;Ba=ua;break}N=M;L=ma-ya|0;while(1){pa=c[A>>2]|0;V=pa+L|0;na=a[V]|0;K=L+1|0;a[V]=a[pa+K|0]|0;a[(c[A>>2]|0)+K|0]=na;na=N-1|0;if((na|0)>0){N=na;L=L+2|0}else{break}}Aa=(ka?(Y<<1)+2|0:0)+ma|0;Ba=ua}}while(0);if((J|0)==129){J=0;H=D+2|0;if(H>>>0>(ba(c[E>>2]|0,c[F>>2]|0)|0)>>>0){J=130;break}if((G-da|0)<1){Ca=0;Da=da}else{Ca=a[da]|0;Da=da+1|0}a[(c[A>>2]|0)+D|0]=Ca;if((G-Da|0)<1){Ea=0;Fa=Da}else{Ea=a[Da]|0;Fa=Da+1|0}a[(c[A>>2]|0)+(D+1)|0]=Ea;ga=H;ha=Fa;J=152}if((J|0)==152){J=0;if(ga>>>0>(ba(c[E>>2]|0,c[F>>2]|0)|0)>>>0){J=154;break}else{Aa=ga;Ba=ha}}H=Ba;if((H-y|0)>>>0<v>>>0){z=Ba;D=Aa;C=H}else{break d}}if((J|0)==130){yDb(b,16,2051784,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==147){yDb(b,16,2051784,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==154){yDb(b,16,2051784,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==160){yDb(b,16,2006392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==163){yDb(b,16,2006392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==165){yDb(b,16,1968600,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==168){yDb(b,16,2006392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==170){yDb(b,16,2006392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);y=c[k>>2]|0;C=y+8|0;D=c[C>>2]|0;if((D|0)==0){break}z=y+4|0;F=y+12|0;E=y+28|0;y=0;A=c[z>>2]|0;G=D;while(1){D=y&1;if((A|0)==0){Ga=0;Ha=G}else{B=(ba(y-D|0,A)|0)+D|0;D=0;H=A;while(1){L=(ba(H,y)|0)+D|0;a[(c[E>>2]|0)+L|0]=a[(c[F>>2]|0)+B|0]|0;L=D+1|0;Ia=c[z>>2]|0;if(L>>>0<Ia>>>0){B=B+2|0;D=L;H=Ia}else{break}}Ga=Ia;Ha=c[C>>2]|0}H=y+1|0;if(H>>>0<Ha>>>0){y=H;A=Ga;G=Ha}else{break}}}}while(0);v=c[k>>2]|0;t=v+8|0;if((c[t>>2]|0)>0){w=v+4|0;u=e+32|0;r=c[v+28>>2]|0;v=c[e>>2]|0;x=0;G=c[w>>2]|0;while(1){UGb(v|0,r|0,G)|0;A=c[w>>2]|0;y=x+1|0;if((y|0)<(c[t>>2]|0)){r=r+A|0;v=v+(c[u>>2]|0)|0;x=y;G=A}else{break}}}c[e+88>>2]=2;c[e+84>>2]=0;UGb(c[e+4>>2]|0,l+32|0,1024)|0;c[f>>2]=1;G=l+12|0;x=c[G>>2]|0;u=l+16|0;c[G>>2]=c[u>>2];c[u>>2]=x}else if((s<<16>>16|0)==19536){if((a[g+7|0]|0)<0){Ja=(a[l]|0)==74}else{Ja=0}x=g+8|0;u=n-8|0;if(!((u|0)>-1)){yDb(0,0,1940112,(o=i,i=i+24|0,c[o>>2]=1915928,c[o+8>>2]=1895360,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}G=x;if((u|0)==0){break}v=g+n|0;r=l+32|0;if(Ja){t=x;w=G;while(1){if((v-w|0)<1){Ka=0;La=t}else{Ka=d[t]|0;La=t+1|0}A=Ka&255;if((v-La|0)<1){Ma=La;Na=256;Oa=A;J=16}else{y=La+1|0;C=a[La]|0;if((Ka|0)==255&C<<24>>24==-1){break a}z=C<<24>>24==0?256:C&255;if(z<<16>>16==0){Pa=y}else{Ma=y;Na=z;Oa=A;J=16}}if((J|0)==16){while(1){J=0;if((v-Ma|0)<3){Qa=0;Ra=Ma}else{Qa=d[Ma+1|0]<<8|d[Ma]<<16|d[Ma+2|0];Ra=Ma+3|0}c[r+((Oa&255)<<2)>>2]=Qa;A=Na-1&65535;if(A<<16>>16==0){Pa=Ra;break}else{Ma=Ra;Na=A;Oa=Oa+1&255;J=16}}}A=Pa;if((A-G|0)>>>0<u>>>0){t=Pa;w=A}else{break}}}else{w=x;t=G;while(1){if((v-t|0)<1){Sa=0;Ta=w}else{Sa=d[w]|0;Ta=w+1|0}A=Sa&255;if((v-Ta|0)<1){Ua=Ta;Va=256;Wa=A;J=25}else{z=Ta+1|0;y=a[Ta]|0;if((Sa|0)==255&y<<24>>24==-1){break a}C=y<<24>>24==0?256:y&255;if(C<<16>>16==0){Xa=z}else{Ua=z;Va=C;Wa=A;J=25}}if((J|0)==25){while(1){J=0;if((v-Ua|0)<3){Ya=0;Za=Ua}else{Ya=(d[Ua+1|0]<<8|d[Ua]<<16|d[Ua+2|0])<<2;Za=Ua+3|0}c[r+((Wa&255)<<2)>>2]=Ya;A=Va-1&65535;if(A<<16>>16==0){Xa=Za;break}else{Ua=Za;Va=A;Wa=Wa+1&255;J=25}}}A=Xa;if((A-G|0)>>>0<u>>>0){w=Xa;t=A}else{break}}}}else if((s<<16>>16|0)==23113){if((n|0)<12){yDb(b,16,2187232,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}t=_$a(b,j,0)|0;if((t|0)<0){p=t;i=h;return p|0}t=c[q>>2]|0;w=t+12|0;u=c[m>>2]|0;G=u-12|0;r=c[k>>2]|0;if(!((G|0)>-1)){yDb(0,0,1940112,(o=i,i=i+24|0,c[o>>2]=1915928,c[o+8>>2]=1895360,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}v=w;f:do{if((G|0)!=0){x=t+u|0;A=r+4|0;C=r+8|0;z=r+12|0;y=w;F=0;E=0;H=0;D=v;g:while(1){do{if((E|0)==0){if((x-D|0)<4){_a=29;$a=0;ab=y;bb=0;J=60;break}B=y;cb=32;db=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;eb=y+4|0;J=38}else{cb=E;db=F;eb=y;J=38}}while(0);do{if((J|0)==38){J=0;B=db<<1;L=cb-1|0;if(!((db|0)>-1)){if(!(H>>>0<(ba(c[C>>2]|0,c[A>>2]|0)|0)>>>0)){J=40;break g}if((x-eb|0)<1){fb=0;gb=eb}else{fb=a[eb]|0;gb=eb+1|0}a[(c[z>>2]|0)+H|0]=fb;hb=H+1|0;ib=L;jb=B;kb=gb;break}if((L|0)==0){if((x-eb|0)<4){_a=30;$a=0;ab=eb;bb=0;J=60;break}N=eb;lb=32;mb=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;nb=eb+4|0}else{lb=L;mb=B;nb=eb}B=mb<<1;L=lb-1|0;if(!((mb|0)>-1)){if((x-nb|0)<2){ob=nb;pb=-8192}else{N=nb+2|0;M=nb;la=(d[M]|d[M+1|0]<<8)<<16>>16&65535;M=la&7;na=la>>>3|-8192;if((M|0)==0){ob=N;pb=na}else{qb=na;rb=M;sb=L;tb=B;ub=N;J=62;break}}if((x-ob|0)<1){break f}N=a[ob]|0;if(N<<24>>24==0){break f}else{qb=pb;rb=N&255;sb=L;tb=B;ub=ob+1|0;J=62;break}}if((L|0)==0){if((x-nb|0)<4){vb=0;wb=nb}else{L=nb;vb=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;wb=nb+4|0}_a=31;$a=vb<<1;ab=wb;bb=vb>>>31<<1;J=60;break}else{L=lb-2|0;B=mb>>>30<<1&2;if((L|0)!=0){_a=L;$a=mb<<2;ab=nb;bb=B;J=60;break}if((x-nb|0)<4){_a=32;$a=0;ab=nb;bb=B;J=60;break}L=nb;_a=32;$a=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;ab=nb+4|0;bb=B;J=60;break}}}while(0);do{if((J|0)==60){J=0;B=$a<<1;L=_a-1|0;N=$a>>>31|bb;if((x-ab|0)<1){qb=-256;rb=N;sb=L;tb=B;ub=ab;J=62;break}qb=d[ab]|-256;rb=N;sb=L;tb=B;ub=ab+1|0;J=62}}while(0);do{if((J|0)==62){J=0;B=rb+2|0;L=qb+H|0;if((L|0)<0){J=64;break g}N=ba(c[C>>2]|0,c[A>>2]|0)|0;if(!((L+B|0)>>>0<N>>>0)){J=64;break g}M=B+H|0;if(!(M>>>0<N>>>0)){J=67;break g}if((B|0)==0){hb=H;ib=sb;jb=tb;kb=ub;break}else{xb=B;yb=H;zb=L}while(1){L=xb-1|0;B=c[z>>2]|0;a[B+yb|0]=a[B+zb|0]|0;if((L|0)==0){hb=M;ib=sb;jb=tb;kb=ub;break}else{xb=L;yb=yb+1|0;zb=zb+1|0}}}}while(0);M=kb;if((M-v|0)>>>0<G>>>0){y=kb;F=jb;E=ib;H=hb;D=M}else{break f}}if((J|0)==40){yDb(b,16,1968600,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==64){yDb(b,16,2006392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((J|0)==67){yDb(b,16,1968600,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);G=l+12|0;v=l+4|0;w=l+8|0;UGb(c[l+16>>2]|0,c[G>>2]|0,ba(c[w>>2]|0,c[v>>2]|0)|0)|0;do{if((a[l]|0)==74){UGb(c[l+28>>2]|0,c[G>>2]|0,ba(c[w>>2]|0,c[v>>2]|0)|0)|0}else{r=c[k>>2]|0;u=r+8|0;t=c[u>>2]|0;if((t|0)==0){break}D=r+4|0;H=r+12|0;E=r+28|0;r=0;F=c[D>>2]|0;y=t;while(1){t=r&1;if((F|0)==0){Ab=0;Bb=y}else{z=(ba(r-t|0,F)|0)+t|0;t=0;A=F;while(1){C=(ba(A,r)|0)+t|0;a[(c[E>>2]|0)+C|0]=a[(c[H>>2]|0)+z|0]|0;C=t+1|0;Cb=c[D>>2]|0;if(C>>>0<Cb>>>0){z=z+2|0;t=C;A=Cb}else{break}}Ab=Cb;Bb=c[u>>2]|0}A=r+1|0;if(A>>>0<Bb>>>0){r=A;F=Ab;y=Bb}else{break}}}}while(0);v=c[k>>2]|0;w=v+8|0;if((c[w>>2]|0)>0){G=v+4|0;y=e+32|0;F=c[v+28>>2]|0;v=c[e>>2]|0;r=0;u=c[G>>2]|0;while(1){UGb(v|0,F|0,u)|0;D=c[G>>2]|0;H=r+1|0;if((H|0)<(c[w>>2]|0)){F=F+D|0;v=v+(c[y>>2]|0)|0;r=H;u=D}else{break}}}c[e+88>>2]=1;c[e+84>>2]=1;UGb(c[e+4>>2]|0,l+32|0,1024)|0;c[f>>2]=1}else{yDb(b,16,2110016,(o=i,i=i+8|0,c[o>>2]=s&65535,o)|0);i=o;p=-1094995529;i=h;return p|0}}while(0);p=c[m>>2]|0;i=h;return p|0}function AFa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+20|0);$Db(b+24|0);$Db(b+28|0);return 0}function BFa(a,b){a=a|0;b=b|0;c[a>>2]=534;c[a+4>>2]=412;c[a+8>>2]=346;c[a+12>>2]=662;c[a+16>>2]=176;c[a+20>>2]=642;c[a+24>>2]=564;c[a+28>>2]=174;c[a+32>>2]=46;c[a+36>>2]=780;c[a+40>>2]=492;c[a+44>>2]=436;c[a+48>>2]=168;c[a+52>>2]=590;c[a+56>>2]=316;c[a+60>>2]=720;c[a+128>>2]=570;c[a+132>>2]=776;c[a+136>>2]=698;c[a+140>>2]=302;c[a+144>>2]=176;c[a+148>>2]=14;c[a+152>>2]=364;c[a+156>>2]=340;c[a+64>>2]=434;c[a+68>>2]=198;c[a+72>>2]=520;c[a+76>>2]=108;c[a+80>>2]=548;c[a+84>>2]=834;c[a+88>>2]=190;c[a+92>>2]=606;c[a+96>>2]=20;c[a+100>>2]=162;c[a+104>>2]=82;c[a+108>>2]=192;c[a+112>>2]=572;c[a+116>>2]=372;c[a+120>>2]=824;c[a+124>>2]=444;c[a+192>>2]=422;c[a+196>>2]=216;c[a+200>>2]=158;c[a+204>>2]=470;return}function CFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){j=g;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=g+4|0;c[h+4>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=i+1|0;if((j|0)<(f|0)){g=g+e|0;h=h+e|0;i=j}else{break}}i=b+8|0;b=a+8|0;a=0;while(1){h=i;c[b>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=i+4|0;c[b+4>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=a+1|0;if((h|0)<(f|0)){i=i+e|0;b=b+e|0;a=h}else{break}}return}function DFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>0){g=0}else{return}while(1){h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);j=h+4|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(h+5)|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=(h|i)-((h^i)>>>1&2139062143);i=g+1|0;if((i|0)<(f|0)){g=i}else{l=0;break}}do{g=ba(l,e)|0;i=g+8|0;h=b+i|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(g+9)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+i>>2]=(k|j)-((k^j)>>>1&2139062143);j=g+12|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(g+13)|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=(g|i)-((g^i)>>>1&2139062143);l=l+1|0;}while((l|0)<(f|0));return}function EFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);j=h+4|0;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(j+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+j>>2]=(i|k)-((i^k)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));g=e+8|0;k=e+12|0;i=0;do{j=ba(i,e)|0;h=j+8|0;l=b+h|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(g+j)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+h>>2]=(n|m)-((n^m)>>>1&2139062143);m=j+12|0;n=b+m|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(k+j)|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[a+m>>2]=(j|h)-((j^h)>>>1&2139062143);i=i+1|0;}while((i|0)<(f|0));return}function FFa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;JFa(a,b,c,d);JFa(a+8|0,b+8|0,c,d);return}function GFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){a=g;c[h>>2]=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24;a=g+4|0;c[h+4>>2]=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24;a=i+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=a}else{break}}return}function HFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);j=h+4|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(h+5)|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=(h|i)-((h^i)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function IFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);j=h+4|0;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(j+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+j>>2]=(i|k)-((i^k)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function JFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=e+4-(ba(f+1|0,e)|0)|0;h=4-(ba(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+33686018+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;c[b>>2]=r+o+((a+l|0)>>>2&252645135);p=n+j|0;q=p;s=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+k|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=(s&50529027)+33686018+(t&50529027)|0;u=(t>>>2&1061109567)+(s>>>2&1061109567)|0;c[b+e>>2]=u+r+((q+a|0)>>>2&252645135);a=m+2|0;if((a|0)<(f|0)){l=q;o=u;m=a;n=p;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+33686018+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(p&50529027)+(b&50529027)|0;a=(p>>>2&1061109567)+(b>>>2&1061109567)|0;c[m>>2]=a+n+((h+o|0)>>>2&252645135);b=g+j|0;p=b;u=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+k|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=(u&50529027)+33686018+(q&50529027)|0;r=(q>>>2&1061109567)+(u>>>2&1061109567)|0;c[m+e>>2]=r+a+((p+h|0)>>>2&252645135);h=l+2|0;if((h|0)<(f|0)){o=p;n=r;l=h;g=b;m=m+j|0}else{break}}return}function KFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){a=g;c[h>>2]=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24;a=i+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=a}else{break}}return}function LFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function MFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function NFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=b;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=b+1|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;if((f|0)<=0){return}g=e+1|0;j=e<<1;k=j|1;l=(i>>>2&1061109567)+(h>>>2&1061109567)|0;m=(h&50529027)+33686018+(i&50529027)|0;i=0;h=b;b=a;while(1){a=h+e|0;n=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=h+g|0;o=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(o&50529027)+(n&50529027)|0;p=(o>>>2&1061109567)+(n>>>2&1061109567)|0;c[b>>2]=p+l+((a+m|0)>>>2&252645135);n=h+j|0;o=n;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+k|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(q&50529027)+33686018+(r&50529027)|0;s=(r>>>2&1061109567)+(q>>>2&1061109567)|0;c[b+e>>2]=s+p+((o+a|0)>>>2&252645135);a=i+2|0;if((a|0)<(f|0)){l=s;m=o;i=a;h=n;b=b+j|0}else{break}}return}function OFa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((f|0)>0){g=c;h=a;i=0}else{return}while(1){a=g;b[h>>1]=(d[a]|d[a+1|0]<<8)<<16>>16;a=i+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=a}else{break}}return}function PFa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=c+h|0;j=(d[i]|d[i+1|0]<<8)<<16>>16;i=c+(h+1)|0;k=(d[i]|d[i+1|0]<<8)<<16>>16;b[a+h>>1]=(k|j)-(((k^j)&65535)>>>1&32639);g=g+1|0;}while((g|0)<(f|0));return}function QFa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=c+h|0;j=(d[i]|d[i+1|0]<<8)<<16>>16;i=c+(h+e)|0;k=(d[i]|d[i+1|0]<<8)<<16>>16;b[a+h>>1]=(k|j)-(((k^j)&65535)>>>1&32639);g=g+1|0;}while((g|0)<(f|0));return}function RFa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=(d[c+1|0]|0)+2|0;if((f|0)<=0){return}h=e+1|0;i=e+2|0;j=e<<1;k=j|1;l=j+2|0;m=g+(d[c]|0)|0;n=g+(d[c+2|0]|0)|0;g=0;o=b;b=c;while(1){c=d[b+h|0]|0;p=c+(d[b+e|0]|0)|0;q=(d[b+i|0]|0)+c|0;a[o]=(p+m|0)>>>2;a[o+1|0]=(q+n|0)>>>2;c=b+j|0;r=(d[b+k|0]|0)+2|0;s=r+(d[c]|0)|0;t=r+(d[b+l|0]|0)|0;a[o+e|0]=(s+p|0)>>>2;a[o+h|0]=(t+q|0)>>>2;q=g+2|0;if((q|0)<(f|0)){m=s;n=t;g=q;o=o+j|0;b=c}else{break}}return}function SFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){j=g;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=g+4|0;c[h+4>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=i+1|0;if((j|0)<(f|0)){g=g+e|0;h=h+e|0;i=j}else{break}}i=b+8|0;b=a+8|0;a=0;while(1){h=i;c[b>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=i+4|0;c[b+4>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=a+1|0;if((h|0)<(f|0)){i=i+e|0;b=b+e|0;a=h}else{break}}return}function TFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>0){g=0}else{return}while(1){h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=((k^j)>>>1&2139062143)+(k&j);j=h+4|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(h+5)|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=((h^i)>>>1&2139062143)+(h&i);i=g+1|0;if((i|0)<(f|0)){g=i}else{l=0;break}}do{g=ba(l,e)|0;i=g+8|0;h=b+i|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(g+9)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+i>>2]=((k^j)>>>1&2139062143)+(k&j);j=g+12|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(g+13)|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=((g^i)>>>1&2139062143)+(g&i);l=l+1|0;}while((l|0)<(f|0));return}function UFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=((k^j)>>>1&2139062143)+(k&j);j=h+4|0;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(j+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+j>>2]=((i^k)>>>1&2139062143)+(i&k);g=g+1|0;}while((g|0)<(f|0));g=e+8|0;k=e+12|0;i=0;do{j=ba(i,e)|0;h=j+8|0;l=b+h|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(g+j)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+h>>2]=((n^m)>>>1&2139062143)+(n&m);m=j+12|0;n=b+m|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(k+j)|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[a+m>>2]=((j^h)>>>1&2139062143)+(j&h);i=i+1|0;}while((i|0)<(f|0));return}function VFa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;YFa(a,b,c,d);YFa(a+8|0,b+8|0,c,d);return}function WFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=((k^j)>>>1&2139062143)+(k&j);j=h+4|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(h+5)|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=((h^i)>>>1&2139062143)+(h&i);g=g+1|0;}while((g|0)<(f|0));return}function XFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=((k^j)>>>1&2139062143)+(k&j);j=h+4|0;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(j+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+j>>2]=((i^k)>>>1&2139062143)+(i&k);g=g+1|0;}while((g|0)<(f|0));return}function YFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=e+4-(ba(f+1|0,e)|0)|0;h=4-(ba(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+16843009+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;c[b>>2]=r+o+((a+l|0)>>>2&252645135);p=n+j|0;q=p;s=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+k|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=(s&50529027)+16843009+(t&50529027)|0;u=(t>>>2&1061109567)+(s>>>2&1061109567)|0;c[b+e>>2]=u+r+((q+a|0)>>>2&252645135);a=m+2|0;if((a|0)<(f|0)){l=q;o=u;m=a;n=p;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+16843009+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(p&50529027)+(b&50529027)|0;a=(p>>>2&1061109567)+(b>>>2&1061109567)|0;c[m>>2]=a+n+((h+o|0)>>>2&252645135);b=g+j|0;p=b;u=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+k|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=(u&50529027)+16843009+(q&50529027)|0;r=(q>>>2&1061109567)+(u>>>2&1061109567)|0;c[m+e>>2]=r+a+((p+h|0)>>>2&252645135);h=l+2|0;if((h|0)<(f|0)){o=p;n=r;l=h;g=b;m=m+j|0}else{break}}return}function ZFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){j=h;k=c[j>>2]|0;l=g;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[j>>2]=(m|k)-((m^k)>>>1&2139062143);k=h+4|0;m=c[k>>2]|0;j=g+4|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=i+1|0;if((m|0)<(f|0)){g=g+e|0;h=h+e|0;i=m}else{break}}i=b+8|0;b=a+8|0;a=0;while(1){h=b;g=c[h>>2]|0;m=i;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[h>>2]=(l|g)-((l^g)>>>1&2139062143);g=b+4|0;l=c[g>>2]|0;h=i+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[g>>2]=(m|l)-((m^l)>>>1&2139062143);l=a+1|0;if((l|0)<(f|0)){i=i+e|0;b=b+e|0;a=l}else{break}}return}function _Fa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>0){g=0}else{return}while(1){h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;m=b+l|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+5)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+l|0;l=c[m>>2]|0;j=(h|i)-((h^i)>>>1&2139062143)|0;c[m>>2]=(j|l)-((j^l)>>>1&2139062143);l=g+1|0;if((l|0)<(f|0)){g=l}else{n=0;break}}do{g=ba(n,e)|0;l=g+8|0;j=b+l|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(g+9)|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+l|0;l=c[j>>2]|0;h=(i|m)-((i^m)>>>1&2139062143)|0;c[j>>2]=(h|l)-((h^l)>>>1&2139062143);l=g+12|0;h=b+l|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(g+13)|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;m=(g|j)-((g^j)>>>1&2139062143)|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);n=n+1|0;}while((n|0)<(f|0));return}function $Fa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(l+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;j=(i|m)-((i^m)>>>1&2139062143)|0;c[h>>2]=(j|l)-((j^l)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));g=e+8|0;l=e+12|0;j=0;do{h=ba(j,e)|0;m=h+8|0;i=b+m|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(g+h)|0;n=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+m|0;m=c[i>>2]|0;o=(n|k)-((n^k)>>>1&2139062143)|0;c[i>>2]=(o|m)-((o^m)>>>1&2139062143);m=h+12|0;o=b+m|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(l+h)|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+m|0;m=c[o>>2]|0;k=(h|i)-((h^i)>>>1&2139062143)|0;c[o>>2]=(k|m)-((k^m)>>>1&2139062143);j=j+1|0;}while((j|0)<(f|0));return}function aGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eGa(a,b,c,d);eGa(a+8|0,b+8|0,c,d);return}function bGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){a=h;b=c[a>>2]|0;j=g;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a>>2]=(k|b)-((k^b)>>>1&2139062143);b=h+4|0;k=c[b>>2]|0;a=g+4|0;j=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;c[b>>2]=(j|k)-((j^k)>>>1&2139062143);k=i+1|0;if((k|0)<(f|0)){g=g+e|0;h=h+e|0;i=k}else{break}}return}function cGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;m=b+l|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+5)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+l|0;l=c[m>>2]|0;j=(h|i)-((h^i)>>>1&2139062143)|0;c[m>>2]=(j|l)-((j^l)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function dGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(l+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;j=(i|m)-((i^m)>>>1&2139062143)|0;c[h>>2]=(j|l)-((j^l)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function eGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=e+4-(ba(f+1|0,e)|0)|0;h=4-(ba(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+33686018+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;p=b;q=c[p>>2]|0;s=r+o+((a+l|0)>>>2&252645135)|0;c[p>>2]=(s|q)-((s^q)>>>1&2139062143);q=n+j|0;s=q;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+k|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=(p&50529027)+33686018+(t&50529027)|0;u=(t>>>2&1061109567)+(p>>>2&1061109567)|0;p=b+e|0;t=c[p>>2]|0;v=u+r+((s+a|0)>>>2&252645135)|0;c[p>>2]=(v|t)-((v^t)>>>1&2139062143);t=m+2|0;if((t|0)<(f|0)){l=s;o=u;m=t;n=q;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+33686018+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(q&50529027)+(b&50529027)|0;t=(q>>>2&1061109567)+(b>>>2&1061109567)|0;b=m;q=c[b>>2]|0;u=t+n+((h+o|0)>>>2&252645135)|0;c[b>>2]=(u|q)-((u^q)>>>1&2139062143);q=g+j|0;u=q;b=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=g+k|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=(b&50529027)+33686018+(s&50529027)|0;v=(s>>>2&1061109567)+(b>>>2&1061109567)|0;b=m+e|0;s=c[b>>2]|0;p=v+t+((u+h|0)>>>2&252645135)|0;c[b>>2]=(p|s)-((p^s)>>>1&2139062143);s=l+2|0;if((s|0)<(f|0)){o=u;n=v;l=s;g=q;m=m+j|0}else{break}}return}function fGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){a=h;b=c[a>>2]|0;j=g;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a>>2]=(k|b)-((k^b)>>>1&2139062143);b=i+1|0;if((b|0)<(f|0)){g=g+e|0;h=h+e|0;i=b}else{break}}return}function gGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;h=c[i>>2]|0;l=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(l|h)-((l^h)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function hGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;h=c[i>>2]|0;l=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(l|h)-((l^h)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function iGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=b;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=b+1|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;if((f|0)<=0){return}g=e+1|0;j=e<<1;k=j|1;l=(i>>>2&1061109567)+(h>>>2&1061109567)|0;m=(h&50529027)+33686018+(i&50529027)|0;i=0;h=b;b=a;while(1){a=h+e|0;n=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=h+g|0;o=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(o&50529027)+(n&50529027)|0;p=(o>>>2&1061109567)+(n>>>2&1061109567)|0;n=b;o=c[n>>2]|0;q=p+l+((a+m|0)>>>2&252645135)|0;c[n>>2]=(q|o)-((q^o)>>>1&2139062143);o=h+j|0;q=o;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+k|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=(n&50529027)+33686018+(r&50529027)|0;s=(r>>>2&1061109567)+(n>>>2&1061109567)|0;n=b+e|0;r=c[n>>2]|0;t=s+p+((q+a|0)>>>2&252645135)|0;c[n>>2]=(t|r)-((t^r)>>>1&2139062143);r=i+2|0;if((r|0)<(f|0)){l=s;m=q;i=r;h=o;b=b+j|0}else{break}}return}function jGa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=c;h=a;i=0}else{return}while(1){a=h;c=b[a>>1]|0;j=g;k=(d[j]|d[j+1|0]<<8)<<16>>16;b[a>>1]=(k|c)-(((k^c)&65535)>>>1&32639);c=i+1|0;if((c|0)<(f|0)){g=g+e|0;h=h+e|0;i=c}else{break}}return}function kGa(a,c,f,g){a=a|0;c=c|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)>0){h=0}else{return}do{i=ba(h,f)|0;j=c+i|0;k=(d[j]|d[j+1|0]<<8)<<16>>16;j=c+(i+1)|0;l=(d[j]|d[j+1|0]<<8)<<16>>16;j=a+i|0;i=e[j>>1]|0;m=((l|k)&65535)-(((l^k)&65535)>>>1&32639)|0;b[j>>1]=(m|i)-((m^i)>>>1&32639);h=h+1|0;}while((h|0)<(g|0));return}function lGa(a,c,f,g){a=a|0;c=c|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)>0){h=0}else{return}do{i=ba(h,f)|0;j=c+i|0;k=(d[j]|d[j+1|0]<<8)<<16>>16;j=c+(i+f)|0;l=(d[j]|d[j+1|0]<<8)<<16>>16;j=a+i|0;i=e[j>>1]|0;m=((l|k)&65535)-(((l^k)&65535)>>>1&32639)|0;b[j>>1]=(m|i)-((m^i)>>>1&32639);h=h+1|0;}while((h|0)<(g|0));return}function mGa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=(d[c+1|0]|0)+2|0;if((f|0)<=0){return}h=e+1|0;i=e+2|0;j=e<<1;k=j|1;l=j+2|0;m=g+(d[c]|0)|0;n=g+(d[c+2|0]|0)|0;g=0;o=b;b=c;while(1){c=d[b+h|0]|0;p=c+(d[b+e|0]|0)|0;q=(d[b+i|0]|0)+c|0;a[o]=(p+m|0)>>>2;a[o+1|0]=(q+n|0)>>>2;c=b+j|0;r=(d[b+k|0]|0)+2|0;s=r+(d[c]|0)|0;t=r+(d[b+l|0]|0)|0;a[o+e|0]=(s+p|0)>>>2;a[o+h|0]=(t+q|0)>>>2;q=g+2|0;if((q|0)<(f|0)){m=s;n=t;g=q;o=o+j|0;b=c}else{break}}return}function nGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){j=h;k=c[j>>2]|0;l=g;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[j>>2]=(m|k)-((m^k)>>>1&2139062143);k=h+4|0;m=c[k>>2]|0;j=g+4|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=i+1|0;if((m|0)<(f|0)){g=g+e|0;h=h+e|0;i=m}else{break}}i=b+8|0;b=a+8|0;a=0;while(1){h=b;g=c[h>>2]|0;m=i;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[h>>2]=(l|g)-((l^g)>>>1&2139062143);g=b+4|0;l=c[g>>2]|0;h=i+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[g>>2]=(m|l)-((m^l)>>>1&2139062143);l=a+1|0;if((l|0)<(f|0)){i=i+e|0;b=b+e|0;a=l}else{break}}return}function oGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>0){g=0}else{return}while(1){h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=((k^j)>>>1&2139062143)+(k&j)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;m=b+l|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+5)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+l|0;l=c[m>>2]|0;j=((h^i)>>>1&2139062143)+(h&i)|0;c[m>>2]=(j|l)-((j^l)>>>1&2139062143);l=g+1|0;if((l|0)<(f|0)){g=l}else{n=0;break}}do{g=ba(n,e)|0;l=g+8|0;j=b+l|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(g+9)|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+l|0;l=c[j>>2]|0;h=((i^m)>>>1&2139062143)+(i&m)|0;c[j>>2]=(h|l)-((h^l)>>>1&2139062143);l=g+12|0;h=b+l|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(g+13)|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;m=((g^j)>>>1&2139062143)+(g&j)|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);n=n+1|0;}while((n|0)<(f|0));return}function pGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)>0){g=0}else{return}do{h=ba(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=((k^j)>>>1&2139062143)+(k&j)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(l+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;j=((i^m)>>>1&2139062143)+(i&m)|0;c[h>>2]=(j|l)-((j^l)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));g=e+8|0;l=e+12|0;j=0;do{h=ba(j,e)|0;m=h+8|0;i=b+m|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(g+h)|0;n=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+m|0;m=c[i>>2]|0;o=((n^k)>>>1&2139062143)+(n&k)|0;c[i>>2]=(o|m)-((o^m)>>>1&2139062143);m=h+12|0;o=b+m|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(l+h)|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+m|0;m=c[o>>2]|0;k=((h^i)>>>1&2139062143)+(h&i)|0;c[o>>2]=(k|m)-((k^m)>>>1&2139062143);j=j+1|0;}while((j|0)<(f|0));return}function qGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;rGa(a,b,c,d);rGa(a+8|0,b+8|0,c,d);return}function rGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=e+4-(ba(f+1|0,e)|0)|0;h=4-(ba(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+16843009+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;p=b;q=c[p>>2]|0;s=r+o+((a+l|0)>>>2&252645135)|0;c[p>>2]=(s|q)-((s^q)>>>1&2139062143);q=n+j|0;s=q;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+k|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=(p&50529027)+16843009+(t&50529027)|0;u=(t>>>2&1061109567)+(p>>>2&1061109567)|0;p=b+e|0;t=c[p>>2]|0;v=u+r+((s+a|0)>>>2&252645135)|0;c[p>>2]=(v|t)-((v^t)>>>1&2139062143);t=m+2|0;if((t|0)<(f|0)){l=s;o=u;m=t;n=q;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+16843009+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(q&50529027)+(b&50529027)|0;t=(q>>>2&1061109567)+(b>>>2&1061109567)|0;b=m;q=c[b>>2]|0;u=t+n+((h+o|0)>>>2&252645135)|0;c[b>>2]=(u|q)-((u^q)>>>1&2139062143);q=g+j|0;u=q;b=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=g+k|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=(b&50529027)+16843009+(s&50529027)|0;v=(s>>>2&1061109567)+(b>>>2&1061109567)|0;b=m+e|0;s=c[b>>2]|0;p=v+t+((u+h|0)>>>2&252645135)|0;c[b>>2]=(p|s)-((p^s)>>>1&2139062143);s=l+2|0;if((s|0)<(f|0)){o=u;n=v;l=s;g=q;m=m+j|0}else{break}}return}function sGa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=i;i=i+48|0;g=WDb(e<<4)|0;h=g;j=WDb(e<<3)|0;k=j;l=e<<1;m=WDb(l)|0;if((g|0)==0|(j|0)==0|(m|0)==0){n=-12;ZDb(g);ZDb(j);ZDb(m);i=f;return n|0}o=(e|0)>0;p=(e|0)/2|0;q=(e|0)>1;r=f+32|0;s=e-1|0;t=l-1|0;u=(t|0)>(e|0);v=g;w=g+8|0;x=f|0;y=f+16|0;z=1;while(1){if(o){A=z;B=(z|0)<0|0?-1:0;C=0;do{c[h+(C<<4)+8>>2]=C;D=d+(C<<3)|0;E=c[D>>2]|0;G=YGb(E<<14|0>>>18,c[D+4>>2]<<14|E>>>18,A,B)|0;E=h+(C<<4)|0;c[E>>2]=G;c[E+4>>2]=F;C=C+1|0;}while((C|0)<(e|0))}if(q){C=p;do{C=C-1|0;B=C<<1|1;a:do{if((B|0)<(e|0)){A=C;E=B;while(1){if((E|0)<(s|0)){G=h+(E<<4)|0;D=c[G+4>>2]|0;H=E+1|0;I=h+(H<<4)|0;J=c[I+4>>2]|0;K=D>>>0>J>>>0|D>>>0==J>>>0&(c[G>>2]|0)>>>0>(c[I>>2]|0)>>>0?H:E}else{K=E}H=h+(A<<4)|0;I=H|0;G=c[I+4>>2]|0;J=h+(K<<4)|0;D=J|0;L=c[D+4>>2]|0;if(!(G>>>0>L>>>0|G>>>0==L>>>0&(c[I>>2]|0)>>>0>(c[D>>2]|0)>>>0)){break a}D=J;c[r>>2]=c[D>>2];c[r+4>>2]=c[D+4>>2];c[r+8>>2]=c[D+8>>2];c[r+12>>2]=c[D+12>>2];J=H;c[D>>2]=c[J>>2];c[D+4>>2]=c[J+4>>2];c[D+8>>2]=c[J+8>>2];c[D+12>>2]=c[J+12>>2];c[J>>2]=c[r>>2];c[J+4>>2]=c[r+4>>2];c[J+8>>2]=c[r+8>>2];c[J+12>>2]=c[r+12>>2];J=K<<1|1;if((J|0)<(e|0)){A=K;E=J}else{break}}}}while(0);}while((C|0)>0)}b:do{if(u){if(q){M=e}else{C=e;B=c[v+4>>2]|0;E=c[v>>2]|0;A=c[w>>2]|0;while(1){c[k+(A<<2)>>2]=C;c[w>>2]=C;J=YGb(E,B,-1,2147483647)|0;D=F;c[v>>2]=J;c[v+4>>2]=D;H=C+1|0;if((H|0)<(t|0)){A=C;C=H;B=D;E=J}else{break b}}}do{E=c[v>>2]|0;B=c[v+4>>2]|0;c[k+(c[w>>2]<<2)>>2]=M;c[v>>2]=-1;c[v+4>>2]=2147483647;C=0;A=1;while(1){if((A|0)<(s|0)){J=h+(A<<4)|0;D=c[J+4>>2]|0;H=A+1|0;I=h+(H<<4)|0;L=c[I+4>>2]|0;N=D>>>0>L>>>0|D>>>0==L>>>0&(c[J>>2]|0)>>>0>(c[I>>2]|0)>>>0?H:A}else{N=A}H=h+(C<<4)|0;I=H|0;J=c[I+4>>2]|0;L=h+(N<<4)|0;D=L|0;G=c[D+4>>2]|0;if(!(J>>>0>G>>>0|J>>>0==G>>>0&(c[I>>2]|0)>>>0>(c[D>>2]|0)>>>0)){break}D=L;c[x>>2]=c[D>>2];c[x+4>>2]=c[D+4>>2];c[x+8>>2]=c[D+8>>2];c[x+12>>2]=c[D+12>>2];L=H;c[D>>2]=c[L>>2];c[D+4>>2]=c[L+4>>2];c[D+8>>2]=c[L+8>>2];c[D+12>>2]=c[L+12>>2];c[L>>2]=c[x>>2];c[L+4>>2]=c[x+4>>2];c[L+8>>2]=c[x+8>>2];c[L+12>>2]=c[x+12>>2];L=N<<1|1;if((L|0)<(e|0)){C=N;A=L}else{break}}A=c[v>>2]|0;C=c[v+4>>2]|0;c[k+(c[w>>2]<<2)>>2]=M;c[w>>2]=M;L=YGb(A,C,E,B)|0;c[v>>2]=L;c[v+4>>2]=F;L=0;C=1;while(1){if((C|0)<(s|0)){A=h+(C<<4)|0;D=c[A+4>>2]|0;H=C+1|0;I=h+(H<<4)|0;G=c[I+4>>2]|0;O=D>>>0>G>>>0|D>>>0==G>>>0&(c[A>>2]|0)>>>0>(c[I>>2]|0)>>>0?H:C}else{O=C}H=h+(L<<4)|0;I=H|0;A=c[I+4>>2]|0;G=h+(O<<4)|0;D=G|0;J=c[D+4>>2]|0;if(!(A>>>0>J>>>0|A>>>0==J>>>0&(c[I>>2]|0)>>>0>(c[D>>2]|0)>>>0)){break}D=G;c[y>>2]=c[D>>2];c[y+4>>2]=c[D+4>>2];c[y+8>>2]=c[D+8>>2];c[y+12>>2]=c[D+12>>2];G=H;c[D>>2]=c[G>>2];c[D+4>>2]=c[G+4>>2];c[D+8>>2]=c[G+8>>2];c[D+12>>2]=c[G+12>>2];c[G>>2]=c[y>>2];c[G+4>>2]=c[y+4>>2];c[G+8>>2]=c[y+8>>2];c[G+12>>2]=c[y+12>>2];G=O<<1|1;if((G|0)<(e|0)){L=O;C=G}else{break}}M=M+1|0;}while((M|0)<(t|0))}}while(0);a[m+(l-2)|0]=0;C=l-3|0;if((C|0)<(e|0)){P=0}else{L=C;while(1){a[m+L|0]=(a[m+(c[k+(L<<2)>>2]|0)|0]|0)+1;C=L-1|0;if((C|0)<(e|0)){P=0;break}else{L=C}}}while(1){if((P|0)>=(e|0)){break}L=(a[m+(c[k+(P<<2)>>2]|0)|0]|0)+1&255;a[b+P|0]=L;if((L&255)>>>0>31>>>0){break}else{P=P+1|0}}if((P|0)==(e|0)){n=0;break}else{z=z<<1}}ZDb(g);ZDb(j);ZDb(m);i=f;return n|0}function tGa(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+1800|0;l=k|0;m=k+1024|0;n=k+1536|0;o=k+1792|0;do{if((e|0)>0){p=0;q=0;r=0;do{b[g+(p<<3)>>1]=p;b[g+(p<<3)+2>>1]=-2;r=YGb(c[g+(p<<3)+4>>2]|0,0,r,q)|0;q=F;p=p+1|0;}while((p|0)<(e|0));p=0;if(!(q>>>0>p>>>0|q>>>0==p>>>0&r>>>0>2147483647>>>0)){break}yDb(a,16,2277312,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1;i=k;return t|0}}while(0);Yc(g|0,e|0,8,h|0);h=e<<1;p=h-1|0;c[g+(p<<3)+4>>2]=0;if((p|0)>0){u=(j&1|0)==0;v=0;w=e;while(1){e=(c[g+((v|1)<<3)+4>>2]|0)+(c[g+(v<<3)+4>>2]|0)|0;x=v+2|0;a:do{if((w|0)>(x|0)){if(u){y=w;while(1){z=y-1|0;if(!(e>>>0<(c[g+(z<<3)+4>>2]|0)>>>0)){A=y;break a}B=g+(z<<3)|0;C=g+(y<<3)|0;D=c[B+4>>2]|0;c[C>>2]=c[B>>2];c[C+4>>2]=D;if((z|0)>(x|0)){y=z}else{A=z;break}}}else{y=w;while(1){z=y-1|0;if(e>>>0>(c[g+(z<<3)+4>>2]|0)>>>0){A=y;break a}D=g+(z<<3)|0;C=g+(y<<3)|0;B=c[D+4>>2]|0;c[C>>2]=c[D>>2];c[C+4>>2]=B;if((z|0)>(x|0)){y=z}else{A=z;break}}}}else{A=w}}while(0);b[g+(A<<3)>>1]=-1;c[g+(A<<3)+4>>2]=e;b[g+(A<<3)+2>>1]=v;if((x|0)<(p|0)){v=x;w=w+1|0}else{break}}}w=n|0;c[o>>2]=0;uGa(l|0,m|0,w,g,h-2|0,0,0,o,j>>>1&1^1);if((N_(d,f,c[o>>2]|0,m,2,2,l,4,4,w,1,1,0)|0)>=0){t=0;i=k;return t|0}yDb(a,16,2323576,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1;i=k;return t|0}function uGa(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;m=b[g+(h<<3)>>1]|0;n=m&255;o=j&65535;do{if(m<<16>>16==-1){if((l|0)==0){p=h;q=i;r=j;do{s=q<<1;r=r+1|0;t=g+(p<<3)+2|0;uGa(d,e,f,g,b[t>>1]|0,s,r,k,0);q=s|1;p=(b[t>>1]|0)+1|0;u=b[g+(p<<3)>>1]|0;}while(u<<16>>16==-1);v=q;w=r&65535;x=u&255;break}else{y=h;z=i;A=j;B=-1}while(1){if((c[g+(y<<3)+4>>2]|0)==0){C=6;break}p=z<<1;D=A+1|0;t=g+(y<<3)+2|0;uGa(d,e,f,g,b[t>>1]|0,p,D,k,l);E=p|1;p=(b[t>>1]|0)+1|0;t=b[g+(p<<3)>>1]|0;F=t&255;if(t<<16>>16==-1){y=p;z=E;A=D;B=F}else{C=7;break}}if((C|0)==6){v=z;w=A&65535;x=B;break}else if((C|0)==7){v=E;w=D&65535;x=F;break}}else{v=i;w=o;x=n}}while(0);c[d+(c[k>>2]<<2)>>2]=v;v=c[k>>2]|0;b[e+(v<<1)>>1]=w;a[f+v|0]=x;c[k>>2]=(c[k>>2]|0)+1;return}function vGa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=i;i=i+24|0;f=e|0;g=c[b+60>>2]|0;h=g;TGb(g+860320|0,0,80)|0;j=(c[b+124>>2]|0)>288|0;k=g+52|0;c[k>>2]=j;l=g+72|0;c[l>>2]=1;m=b+100|0;n=c[m>>2]|0;a:do{if((n|0)==0){c[g+64>>2]=0;o=0}else{p=c[b+792>>2]|0;if(!((p&7|0)==0|(p|0)==12)){c[g+64>>2]=1;o=1;break}do{if((n|0)>3){if((a[(c[b+96>>2]|0)+3|0]|0)!=0){break}c[g+64>>2]=2;o=2;break a}}while(0);c[g+64>>2]=3;o=3}}while(0);n=g+76|0;c[n>>2]=8;p=g+80|0;c[p>>2]=256;q=g+84|0;c[q>>2]=256;r=g+92|0;c[r>>2]=1;s=g+64|0;do{if(o>>>0>1>>>0){if((c[m>>2]|0)<4){t=-1;i=e;return t|0}u=c[b+96>>2]|0;v=d[u]|0;c[g+56>>2]=v>>>6&1;c[g+4>>2]=v&63;v=u+1|0;w=a[v]|0;x=w&255;do{if((o|0)==2){y=g+60|0;c[y>>2]=x;if(!(w<<24>>24==0)){break}c[y>>2]=c[b+792>>2]&-8}else{y=(x>>>4)+1|0;c[n>>2]=y;z=1<<y;c[p>>2]=z;c[q>>2]=(z|0)>16384?16384:z;c[g+100>>2]=a[v]&3;c[g+104>>2]=(d[v]|0)>>>2&3;z=u+2|0;c[g+96>>2]=a[z]&1;c[r>>2]=(a[z]&3)!=0;c[g+88>>2]=(d[z]|0)>>>2&1}}while(0);v=u+2|0;x=(d[v]|0)>>>4&3;if((x|0)==1){A=1}else{A=(x|0)==2?0:j}c[k>>2]=A;c[g+120>>2]=(d[v]|0)>>>6&1;if((yGa(h,u+4|0,(c[m>>2]|0)-4|0)|0)<0){t=-1094995529}else{break}i=e;return t|0}else{v=b+792|0;x=c[v>>2]|0;w=x&7;if((w|0)==1){c[g+4>>2]=0;c[g+56>>2]=0}else if((w|0)==4){c[g+4>>2]=2;c[g+56>>2]=0}else if((w|0)==2){c[g+4>>2]=0;c[g+56>>2]=1}else if((w|0)==3){c[g+4>>2]=1;c[g+56>>2]=(x|0)>23}else{c[g+4>>2]=0;c[g+56>>2]=0}x=g+60|0;c[x>>2]=c[v>>2]&-8;c[g+120>>2]=0;v=f|0;c[v>>2]=1484544;w=f+12|0;c[w>>2]=336;z=f+16|0;c[z>>2]=344;y=f+4|0;c[y>>2]=1484586;B=f+8|0;c[B>>2]=0;C=g+524448|0;if((DGa(C,f,256)|0)<0){t=-1094995529;i=e;return t|0}c[v>>2]=1484608;c[w>>2]=472;c[z>>2]=480;c[y>>2]=1484667;c[B>>2]=0;B=g+540832|0;if((DGa(B,f,256)|0)<0){t=-1094995529;i=e;return t|0}else{D=0}while(1){c[h+589984+(D<<2)>>2]=d[1484688+D|0]|0;y=D+1|0;if((y|0)<256){D=y}else{E=0;break}}do{c[h+655520+(E<<2)>>2]=d[1484944+E|0]|0;E=E+1|0;}while((E|0)<256);u=g+655520|0;if((c[x>>2]|0)>23){UGb(u|0,g+589984|0,1024)|0;UGb(B|0,C|0,256)|0}UGb(g+721056|0,u|0,1024)|0;UGb(g+557216|0,B|0,256)|0;u=0;while(1){if((u|0)>=4){break}y=h+860320+(u*20|0)|0;Q_(y);if((N_(y,11,256,h+524448+(u<<14)|0,1,1,h+589984+(u<<16)|0,4,4,0,0,0,0)|0)<0){t=-1094995529;F=97;break}else{u=u+1|0}}if((F|0)==97){i=e;return t|0}if((EGa(h)|0)<0){t=-1094995529}else{break}i=e;return t|0}}while(0);b:do{if((c[s>>2]|0)<3){F=c[g+60>>2]|0;do{if((F|0)==24){E=b+140|0;if((c[l>>2]|0)==0){c[E>>2]=3;G=3;break}else{c[E>>2]=298;G=298;break}}else if((F|0)==32){if((c[l>>2]|0)==0){yDb(0,0,1940080,(H=i,i=i+24|0,c[H>>2]=2332344,c[H+8>>2]=1895336,c[H+16>>2]=371,H)|0);i=H;Cd();return 0}else{c[b+140>>2]=30;c[g+88>>2]=1;G=30;break}}else if((F|0)==12){c[b+140>>2]=0;c[g+96>>2]=1;G=0}else if((F|0)==16){E=(c[g+68>>2]|0)==0?4:1;c[b+140>>2]=E;c[g+96>>2]=1;G=E}else{t=-1094995529;i=e;return t|0}}while(0);eFb(G,g+100|0,g+104|0)|0}else{switch(c[g+96>>2]<<9|c[r>>2]<<10|c[g+88>>2]<<8|c[g+100>>2]|(c[n>>2]<<4)-16|c[g+104>>2]<<2|0){case 1712:{c[b+140>>2]=310;break b;break};case 1744:{c[b+140>>2]=312;break b;break};case 1909:{c[b+140>>2]=35;break b;break};case 1925:{c[b+140>>2]=92;break b;break};case 1941:{c[b+140>>2]=98;break b;break};case 1937:{c[b+140>>2]=100;break b;break};case 2033:{c[b+140>>2]=106;break b;break};case 1717:{c[b+140>>2]=302;break b;break};case 1749:{c[b+140>>2]=304;break b;break};case 2032:{c[b+140>>2]=108;break b;break};case 1905:{c[b+140>>2]=300;break b;break};case 1921:{c[b+140>>2]=94;break b;break};case 112:{c[b+140>>2]=8;break b;break};case 1232:{c[b+140>>2]=316;break b;break};case 1264:{c[b+140>>2]=88;break b;break};case 1781:{c[b+140>>2]=54;break b;break};case 1658:{c[b+140>>2]=6;break b;break};case 1904:{c[b+140>>2]=299;break b;break};case 1669:{c[b+140>>2]=70;break b;break};case 1685:{c[b+140>>2]=72;break b;break};case 1664:{c[b+140>>2]=76;break b;break};case 1680:{c[b+140>>2]=78;break b;break};case 240:{c[b+140>>2]=32;break b;break};case 1665:{c[b+140>>2]=80;break b;break};case 1681:{c[b+140>>2]=74;break b;break};case 1652:{c[b+140>>2]=33;break b;break};case 1653:{c[b+140>>2]=0;break b;break};case 1713:{c[b+140>>2]=306;break b;break};case 1745:{c[b+140>>2]=308;break b;break};case 2037:{c[b+140>>2]=104;break b;break};case 1776:{c[b+140>>2]=58;break b;break};case 1649:{c[b+140>>2]=4;break b;break};case 1920:{c[b+140>>2]=96;break b;break};case 1936:{c[b+140>>2]=102;break b;break};case 368:{c[b+140>>2]=66;break b;break};case 1136:{c[b+140>>2]=82;break b;break};case 1152:{c[b+140>>2]=84;break b;break};case 1777:{c[b+140>>2]=56;break b;break};case 1650:{c[b+140>>2]=7;break b;break};case 1168:{c[b+140>>2]=86;break b;break};case 1200:{c[b+140>>2]=314;break b;break};case 1392:{c[b+140>>2]=317;break b;break};case 1648:{c[b+140>>2]=5;break b;break};default:{t=-1094995529;i=e;return t|0}}}}while(0);jlb(b);n=c[b+140>>2]|0;do{if((n|0)==4|(n|0)==0){if((c[b+120>>2]&1|0)==0){break}yDb(b,16,2308016,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;t=-1094995529;i=e;return t|0}}while(0);do{if((c[g+4>>2]|0)==2&(n|0)==4){if((c[b+120>>2]&3|0)==0){break}yDb(b,16,2289464,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;t=-1094995529;i=e;return t|0}}while(0);if((ilb(h)|0)==0){t=0;i=e;return t|0}klb(h);t=-12;i=e;return t|0}function wGa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;h=i;i=i+144|0;j=h|0;k=h+32|0;l=h+48|0;m=h+56|0;n=h+64|0;o=h+72|0;p=h+80|0;q=h+88|0;r=h+96|0;s=h+104|0;t=h+112|0;u=h+120|0;v=h+128|0;w=h+136|0;x=c[g+24>>2]|0;y=c[g+28>>2]|0;g=c[b+60>>2]|0;z=g;A=c[g+108>>2]|0;B=A>>1;C=g+112|0;D=c[C>>2]|0;E=e;c[k>>2]=E;c[k+4>>2]=0;c[k+8>>2]=0;F=g+860480|0;G=F;O$a(F,g+860484|0,y);F=c[G>>2]|0;if((F|0)==0){H=-12;i=h;return H|0}Xe[c[g+861584>>2]&4095](F,x,(y|0)/4|0);x=W0a(b,k,0)|0;if((x|0)<0){H=x;i=h;return H|0}do{if((c[g+120>>2]|0)==0){I=0}else{x=yGa(z,c[G>>2]|0,y)|0;if((x|0)<0){H=-1094995529}else{I=x;break}i=h;return H|0}}while(0);x=y-I|0;if(x>>>0>268435454>>>0){H=-1094995529;i=h;return H|0}y=(c[G>>2]|0)+I|0;G=x<<3;x=G>>>0>2147483639>>>0|(y|0)==0;k=x?0:y;y=x?0:G;G=g+8|0;c[G>>2]=k;c[g+20>>2]=y;x=y+8|0;F=g+24|0;c[F>>2]=x;c[g+12>>2]=k+(y>>3);y=g+16|0;c[y>>2]=0;J=g+52|0;K=e+32|0;L=K;M=K;K=(c[J>>2]|0)!=0|0;N=c[M>>2]<<K;O=e+36|0;P=c[O>>2]<<K;Q=e+40|0;R=c[Q>>2]<<K;K=g+128|0;c[K>>2]=0;do{if((c[g+64>>2]|0)>2){S=g+92|0;T=c[S>>2]|0;U=g+88|0;if(((T<<1|1)+(c[U>>2]|0)|0)>0){V=g+4|0;W=e;X=g+132|0;Y=g+76|0;Z=g+861576|0;_=g+861560|0;$=g+861732|0;aa=g+80|0;ca=g+861748|0;da=g+861572|0;ea=g+861744|0;fa=g+100|0;ga=g+104|0;ha=0;ia=T;do{do{if((ia|0)==0){ja=A;ka=D;la=N}else{if(!((ha-1|0)>>>0<2>>>0)){ja=A;ka=D;la=N;break}ja=A>>c[fa>>2];ka=D>>c[ga>>2];la=(ha|0)==1?P:R}}while(0);T=c[V>>2]|0;do{if((T|0)==2){zGa(z,ja,ha);ma=W+(ha<<2)|0;na=c[ma>>2]|0;oa=c[X>>2]|0;if((c[Y>>2]|0)<9){pa=_e[c[Z>>2]&1023](na,oa,ja,0)|0}else{pa=Pe[c[ca>>2]&255](na,oa,(c[aa>>2]|0)-1|0,ja,0)|0}c[l>>2]=pa;if((c[J>>2]|0)==0){qa=2}else{zGa(z,ja,ha);oa=(c[ma>>2]|0)+(c[L+(ha<<2)>>2]|0)|0;na=c[X>>2]|0;ra=c[l>>2]|0;if((c[Y>>2]|0)<9){sa=_e[c[Z>>2]&1023](oa,na,ja,ra)|0}else{sa=Pe[c[ca>>2]&255](oa,na,(c[aa>>2]|0)-1|0,ja,ra)|0}c[l>>2]=sa;qa=3}c[m>>2]=d[c[ma>>2]|0]|0;zGa(z,ja,ha);ra=c[ma>>2]|0;na=ra+la|0;oa=c[X>>2]|0;if((c[Y>>2]|0)<9){Se[c[da>>2]&511](na,ra,oa,ja,l,m)}else{Ke[c[ea>>2]&1023](na,ra,oa,(c[aa>>2]|0)-1|0,ja,l,m)}if((qa|0)>=(ka|0)){break}oa=L+(ha<<2)|0;ra=qa;do{zGa(z,ja,ha);na=c[ma>>2]|0;ta=ba(c[oa>>2]|0,ra)|0;ua=na+ta|0;va=na+(ta-la)|0;ta=c[X>>2]|0;if((c[Y>>2]|0)<9){Se[c[da>>2]&511](ua,va,ta,ja,l,m)}else{Ke[c[ea>>2]&1023](ua,va,ta,(c[aa>>2]|0)-1|0,ja,l,m)}ra=ra+1|0;}while((ra|0)<(ka|0))}else if((T|0)==0|(T|0)==1){zGa(z,ja,ha);ra=W+(ha<<2)|0;oa=c[ra>>2]|0;ma=c[X>>2]|0;if((c[Y>>2]|0)<9){wa=_e[c[Z>>2]&1023](oa,ma,ja,0)|0}else{wa=Pe[c[ca>>2]&255](oa,ma,(c[aa>>2]|0)-1|0,ja,0)|0}c[l>>2]=wa;if((ka|0)<=1){break}ma=L+(ha<<2)|0;oa=1;do{ta=c[ra>>2]|0;va=ba(c[ma>>2]|0,oa)|0;ua=ta+va|0;zGa(z,ja,ha);na=c[X>>2]|0;xa=c[l>>2]|0;if((c[Y>>2]|0)<9){ya=_e[c[Z>>2]&1023](ua,na,ja,xa)|0}else{ya=Pe[c[ca>>2]&255](ua,na,(c[aa>>2]|0)-1|0,ja,xa)|0}c[l>>2]=ya;do{if((c[V>>2]|0)==1){if((oa|0)<=(c[J>>2]|0)){break}xa=ta+(va-la)|0;if((c[Y>>2]|0)<9){Xe[c[_>>2]&4095](ua,xa,ja);break}else{cf[c[$>>2]&1023](ua,xa,(c[aa>>2]|0)-1|0,ja);break}}}while(0);oa=oa+1|0;}while((oa|0)<(ka|0))}}while(0);ha=ha+1|0;ia=c[S>>2]|0;}while((ha|0)<((ia<<1|1)+(c[U>>2]|0)|0))}U=c[g>>2]|0;ia=U+148|0;if((c[ia>>2]|0)==0){break}ha=c[K>>2]|0;S=ha>>((c[g+60>>2]|0)==12);aa=j|0;c[aa>>2]=ba(c[M>>2]|0,ha)|0;c[j+4>>2]=ba(S,c[O>>2]|0)|0;c[j+8>>2]=ba(c[Q>>2]|0,S)|0;TGb(j+12|0,0,20)|0;Se[c[ia>>2]&511](U,E,aa,ha,3,D-ha|0);c[K>>2]=D}else{ha=g+60|0;aa=c[ha>>2]|0;if((aa|0)>=24){U=ba(c[M>>2]|0,D-1|0)|0;ia=k;S=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;ia=S&255;c[y>>2]=x>>>0>8>>>0?8:x;$=S&255;if((aa|0)==32){aa=e;a[(c[aa>>2]|0)+(U+3)|0]=$;c[w>>2]=ia;S=c[y>>2]|0;_=c[F>>2]|0;Y=(c[G>>2]|0)+(S>>>3)|0;V=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(S&7)>>>24;Y=S+8|0;c[y>>2]=_>>>0>Y>>>0?Y:_;a[(c[aa>>2]|0)+(U+2)|0]=V;c[t>>2]=V;V=c[y>>2]|0;_=c[F>>2]|0;Y=(c[G>>2]|0)+(V>>>3)|0;S=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(V&7)>>>24;Y=V+8|0;c[y>>2]=_>>>0>Y>>>0?Y:_;a[(c[aa>>2]|0)+(U+1)|0]=S;c[u>>2]=S;S=c[y>>2]|0;_=c[F>>2]|0;Y=(c[G>>2]|0)+(S>>>3)|0;V=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(S&7)>>>24;Y=S+8|0;c[y>>2]=_>>>0>Y>>>0?Y:_;a[(c[aa>>2]|0)+U|0]=V;c[v>>2]=V}else{V=e;a[(c[V>>2]|0)+(U+2)|0]=$;c[t>>2]=ia;ia=c[y>>2]|0;$=c[F>>2]|0;aa=(c[G>>2]|0)+(ia>>>3)|0;_=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ia&7)>>>24;aa=ia+8|0;c[y>>2]=$>>>0>aa>>>0?aa:$;a[(c[V>>2]|0)+(U+1)|0]=_;c[u>>2]=_;_=c[y>>2]|0;$=c[F>>2]|0;aa=(c[G>>2]|0)+(_>>>3)|0;ia=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(_&7)>>>24;aa=_+8|0;c[y>>2]=$>>>0>aa>>>0?aa:$;a[(c[V>>2]|0)+U|0]=ia;c[v>>2]=ia;a[(c[V>>2]|0)+(U+3)|0]=-1;c[w>>2]=255;V=c[F>>2]|0;ia=(c[y>>2]|0)+8|0;c[y>>2]=V>>>0>ia>>>0?ia:V}if((c[g+72>>2]|0)==0){yDb(b,16,1968560,(za=i,i=i+1|0,i=i+7&-8,c[za>>2]=0,za)|0);i=za;H=-1163346256;i=h;return H|0}V=g+4|0;if(!((c[V>>2]|0)>>>0<2>>>0)){yDb(b,16,2006360,(za=i,i=i+1|0,i=i+7&-8,c[za>>2]=0,za)|0);i=za;break}ia=A-1|0;CGa(z,ia);$=g+861580|0;aa=e;_=g+132|0;Ke[c[$>>2]&1023]((c[aa>>2]|0)+(U+4)|0,c[_>>2]|0,ia,t,u,v,w);ia=(c[C>>2]|0)-2|0;if((ia|0)>-1){U=g+861560|0;Y=ia;while(1){CGa(z,A);ia=(c[aa>>2]|0)+(ba(c[M>>2]|0,Y)|0)|0;Ke[c[$>>2]&1023](ia,c[_>>2]|0,A,t,u,v,w);do{if((c[V>>2]|0)==1){if((c[ha>>2]|0)!=32){c[w>>2]=0}ia=c[J>>2]|0;if((ia&Y|0)!=0){break}if((Y|0)>=((c[C>>2]|0)+~ia|0)){break}ia=c[aa>>2]|0;S=ba(c[M>>2]|0,Y)|0;Xe[c[U>>2]&4095](ia+S|0,ia+(S+N)|0,N)}}while(0);if((Y|0)>0){Y=Y-1|0}else{break}}}Y=c[g>>2]|0;U=Y+148|0;if((c[U>>2]|0)==0){break}aa=c[K>>2]|0;V=aa>>((c[ha>>2]|0)==12);_=j|0;c[_>>2]=ba(c[M>>2]|0,aa)|0;c[j+4>>2]=ba(V,c[O>>2]|0)|0;c[j+8>>2]=ba(c[Q>>2]|0,V)|0;TGb(j+12|0,0,20)|0;Se[c[U>>2]&511](Y,E,_,aa,3,D-aa|0);c[K>>2]=D;break}aa=(c[g+68>>2]|0)==0;_=k;Y=d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0;c[y>>2]=x>>>0>8>>>0?8:x;_=Y&255;if(!aa){aa=e;a[(c[aa>>2]|0)+3|0]=_;U=c[y>>2]|0;V=c[F>>2]|0;$=(c[G>>2]|0)+(U>>>3)|0;S=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(U&7)>>>24;$=U+8|0;c[y>>2]=V>>>0>$>>>0?$:V;a[(c[aa>>2]|0)+2|0]=S;S=c[y>>2]|0;V=c[F>>2]|0;$=(c[G>>2]|0)+(S>>>3)|0;U=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(S&7)>>>24;$=S+8|0;c[y>>2]=V>>>0>$>>>0?$:V;a[(c[aa>>2]|0)+1|0]=U;U=c[y>>2]|0;V=c[F>>2]|0;$=(c[G>>2]|0)+(U>>>3)|0;S=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(U&7)>>>24;$=U+8|0;c[y>>2]=V>>>0>$>>>0?$:V;a[c[aa>>2]|0]=S;yDb(b,16,2051744,(za=i,i=i+1|0,i=i+7&-8,c[za>>2]=0,za)|0);i=za;H=-1163346256;i=h;return H|0}S=e+8|0;a[c[S>>2]|0]=_;c[p>>2]=Y&255;Y=c[y>>2]|0;_=c[F>>2]|0;aa=(c[G>>2]|0)+(Y>>>3)|0;V=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(Y&7)>>>24;aa=Y+8|0;c[y>>2]=_>>>0>aa>>>0?aa:_;_=e;a[(c[_>>2]|0)+1|0]=V;c[n>>2]=V;V=c[y>>2]|0;aa=c[F>>2]|0;Y=(c[G>>2]|0)+(V>>>3)|0;$=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(V&7)>>>24;Y=V+8|0;c[y>>2]=aa>>>0>Y>>>0?Y:aa;aa=e+4|0;a[c[aa>>2]|0]=$;c[o>>2]=$;$=c[y>>2]|0;Y=c[F>>2]|0;V=(c[G>>2]|0)+($>>>3)|0;U=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<($&7)>>>24;V=$+8|0;c[y>>2]=Y>>>0>V>>>0?V:Y;a[c[_>>2]|0]=U;U=g+4|0;Y=c[U>>2]|0;if((Y|0)==0|(Y|0)==1){V=A-2|0;AGa(z,V);$=g+861576|0;ia=g+132|0;c[n>>2]=_e[c[$>>2]&1023]((c[_>>2]|0)+2|0,c[ia>>2]|0,V,c[n>>2]|0)|0;V=g+116|0;if((c[V>>2]&8192|0)==0){ca=B-1|0;c[o>>2]=_e[c[$>>2]&1023]((c[aa>>2]|0)+1|0,c[g+136>>2]|0,ca,c[o>>2]|0)|0;c[p>>2]=_e[c[$>>2]&1023]((c[S>>2]|0)+1|0,c[g+140>>2]|0,ca,c[p>>2]|0)|0}a:do{if((c[C>>2]|0)>1){ca=g+861560|0;Z=j;X=g;W=g+136|0;ea=g+140|0;da=j|0;ga=j+4|0;fa=j+8|0;T=j+12|0;oa=1;ma=1;while(1){if((c[ha>>2]|0)==12){BGa(z,A);ra=c[_>>2]|0;ua=ba(c[M>>2]|0,oa)|0;va=ra+ua|0;c[n>>2]=_e[c[$>>2]&1023](va,c[ia>>2]|0,A,c[n>>2]|0)|0;do{if((c[U>>2]|0)==1){if((oa|0)<=(c[J>>2]|0)){break}Xe[c[ca>>2]&4095](va,ra+(ua-N)|0,A)}}while(0);ua=oa+1|0;if((ua|0)<(c[C>>2]|0)){Aa=ua}else{Ba=Z;Ca=X;break a}}else{Aa=oa}ua=c[X>>2]|0;ra=ua+148|0;if((c[ra>>2]|0)!=0){va=c[K>>2]|0;ta=va>>((c[ha>>2]|0)==12);c[da>>2]=ba(c[M>>2]|0,va)|0;c[ga>>2]=ba(ta,c[O>>2]|0)|0;c[fa>>2]=ba(c[Q>>2]|0,ta)|0;TGb(T|0,0,20)|0;Se[c[ra>>2]&511](ua,E,da,va,3,Aa-va|0);c[K>>2]=Aa}va=c[_>>2]|0;ua=ba(c[M>>2]|0,Aa)|0;ra=va+ua|0;ta=c[aa>>2]|0;xa=ba(c[O>>2]|0,ma)|0;na=ta+xa|0;Da=c[S>>2]|0;Ea=ba(c[Q>>2]|0,ma)|0;Fa=Da+Ea|0;AGa(z,A);c[n>>2]=_e[c[$>>2]&1023](ra,c[ia>>2]|0,A,c[n>>2]|0)|0;if((c[V>>2]&8192|0)==0){c[o>>2]=_e[c[$>>2]&1023](na,c[W>>2]|0,B,c[o>>2]|0)|0;c[p>>2]=_e[c[$>>2]&1023](Fa,c[ea>>2]|0,B,c[p>>2]|0)|0}do{if((c[U>>2]|0)==1){if((ma|0)<=(c[J>>2]|0)){break}Xe[c[ca>>2]&4095](ra,va+(ua-N)|0,A);if((c[V>>2]&8192|0)!=0){break}Xe[c[ca>>2]&4095](na,ta+(xa-P)|0,B);Xe[c[ca>>2]&4095](Fa,Da+(Ea-R)|0,B)}}while(0);Ea=Aa+1|0;if((Ea|0)<(c[C>>2]|0)){oa=Ea;ma=ma+1|0}else{Ba=Z;Ca=X;break}}}else{Ba=j;Ca=g}}while(0);V=c[Ca>>2]|0;U=V+148|0;if((c[U>>2]|0)==0){break}$=c[K>>2]|0;ia=$>>((c[ha>>2]|0)==12);X=j|0;c[X>>2]=ba(c[M>>2]|0,$)|0;c[j+4>>2]=ba(ia,c[O>>2]|0)|0;c[j+8>>2]=ba(c[Q>>2]|0,ia)|0;TGb(j+12|0,0,20)|0;Se[c[U>>2]&511](V,E,X,$,3,D-$|0);c[K>>2]=D;break}else if((Y|0)!=2){break}$=A-2|0;AGa(z,$);X=g+861576|0;V=g+132|0;c[n>>2]=_e[c[X>>2]&1023]((c[_>>2]|0)+2|0,c[V>>2]|0,$,c[n>>2]|0)|0;$=g+116|0;if((c[$>>2]&8192|0)==0){U=B-1|0;c[o>>2]=_e[c[X>>2]&1023]((c[aa>>2]|0)+1|0,c[g+136>>2]|0,U,c[o>>2]|0)|0;c[p>>2]=_e[c[X>>2]&1023]((c[S>>2]|0)+1|0,c[g+140>>2]|0,U,c[p>>2]|0)|0}do{if((c[J>>2]|0)==0){Ga=2}else{AGa(z,A);c[n>>2]=_e[c[X>>2]&1023]((c[_>>2]|0)+(c[M>>2]|0)|0,c[V>>2]|0,A,c[n>>2]|0)|0;if((c[$>>2]&8192|0)!=0){Ga=3;break}c[o>>2]=_e[c[X>>2]&1023]((c[aa>>2]|0)+(c[Q>>2]|0)|0,c[g+136>>2]|0,B,c[o>>2]|0)|0;c[p>>2]=_e[c[X>>2]&1023]((c[S>>2]|0)+(c[O>>2]|0)|0,c[g+140>>2]|0,B,c[p>>2]|0)|0;Ga=3}}while(0);AGa(z,4);c[n>>2]=_e[c[X>>2]&1023]((c[_>>2]|0)+N|0,c[V>>2]|0,4,c[n>>2]|0)|0;if((c[$>>2]&8192|0)==0){c[o>>2]=_e[c[X>>2]&1023]((c[aa>>2]|0)+P|0,c[g+136>>2]|0,2,c[o>>2]|0)|0;c[p>>2]=_e[c[X>>2]&1023]((c[S>>2]|0)+R|0,c[g+140>>2]|0,2,c[p>>2]|0)|0}c[q>>2]=d[(c[_>>2]|0)+3|0]|0;Y=A-4|0;AGa(z,Y);U=g+861572|0;ia=c[_>>2]|0;Se[c[U>>2]&511](ia+(N+4)|0,ia+4|0,c[V>>2]|0,Y,n,q);if((c[$>>2]&8192|0)==0){Y=c[aa>>2]|0;c[r>>2]=d[Y+1|0]|0;c[s>>2]=d[(c[S>>2]|0)+1|0]|0;ia=B-2|0;Se[c[U>>2]&511](Y+(P+2)|0,Y+2|0,c[g+136>>2]|0,ia,o,r);Y=c[S>>2]|0;Se[c[U>>2]&511](Y+(R+2)|0,Y+2|0,c[g+140>>2]|0,ia,p,s)}ia=g;b:do{if((Ga|0)<(D|0)){Y=g+136|0;Z=g+140|0;ma=j|0;oa=j+4|0;ca=j+8|0;ea=j+12|0;W=Ga;da=Ga;T=Ga<<1;while(1){if((c[ha>>2]|0)==12){fa=da<<1;if((fa|0)>(W|0)){ga=W;while(1){BGa(z,A);Ea=c[_>>2]|0;Da=ba(c[M>>2]|0,ga)|0;Se[c[U>>2]&511](Ea+Da|0,Ea+(Da-N)|0,c[V>>2]|0,A,n,q);Da=ga+1|0;if((fa|0)>(Da|0)){ga=Da}else{Ha=T;break}}}else{Ha=W}if((Ha|0)<(D|0)){Ia=Ha}else{break b}}else{Ia=W}ga=c[ia>>2]|0;fa=ga+148|0;if((c[fa>>2]|0)!=0){Da=c[K>>2]|0;Ea=Da>>((c[ha>>2]|0)==12);c[ma>>2]=ba(c[M>>2]|0,Da)|0;c[oa>>2]=ba(Ea,c[O>>2]|0)|0;c[ca>>2]=ba(c[Q>>2]|0,Ea)|0;TGb(ea|0,0,20)|0;Se[c[fa>>2]&511](ga,E,ma,Da,3,Ia-Da|0);c[K>>2]=Ia}AGa(z,A);Da=c[_>>2]|0;ga=ba(c[M>>2]|0,Ia)|0;fa=c[aa>>2]|0;Ea=ba(c[O>>2]|0,da)|0;Fa=c[S>>2]|0;xa=ba(c[Q>>2]|0,da)|0;Se[c[U>>2]&511](Da+ga|0,Da+(ga-N)|0,c[V>>2]|0,A,n,q);if((c[$>>2]&8192|0)==0){Se[c[U>>2]&511](fa+Ea|0,fa+(Ea-P)|0,c[Y>>2]|0,B,o,r);Se[c[U>>2]&511](Fa+xa|0,Fa+(xa-R)|0,c[Z>>2]|0,B,p,s)}xa=Ia+1|0;if((xa|0)<(D|0)){W=xa;da=da+1|0;T=T+2|0}else{break}}}}while(0);U=c[ia>>2]|0;$=U+148|0;if((c[$>>2]|0)==0){break}V=c[K>>2]|0;S=V>>((c[ha>>2]|0)==12);aa=j|0;c[aa>>2]=ba(c[M>>2]|0,V)|0;c[j+4>>2]=ba(S,c[O>>2]|0)|0;c[j+8>>2]=ba(c[Q>>2]|0,S)|0;TGb(j+12|0,0,20)|0;Se[c[$>>2]&511](U,E,aa,V,3,D-V|0);c[K>>2]=D}}while(0);c[f>>2]=1;H=((((c[y>>2]|0)+31|0)/32|0)<<2)+I|0;i=h;return H|0}function xGa(a){a=a|0;var b=0;b=c[a+60>>2]|0;klb(b);$Db(b+860480|0);Q_(b+860320|0);Q_(b+860340|0);Q_(b+860360|0);Q_(b+860380|0);Q_(b+860400|0);Q_(b+860420|0);Q_(b+860440|0);Q_(b+860460|0);return 0}function yGa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+24|0;f=e|0;g=d<<3;d=g>>>0>2147483639>>>0|(b|0)==0;h=d?0:b;b=d?0:g;c[f>>2]=h;c[f+12>>2]=b;c[f+16>>2]=b+8;c[f+4>>2]=h+(b>>3);b=f+8|0;c[b>>2]=0;if((c[a+64>>2]|0)>2){j=(c[a+88>>2]|0)+1+(c[a+92>>2]<<1)|0}else{j=3}h=a+84|0;g=0;while(1){if((g|0)>=(j|0)){k=8;break}d=a+524448+(g<<14)|0;if((DGa(d,f,c[h>>2]|0)|0)<0){l=-1;k=10;break}m=a+589984+(g<<16)|0;if((hlb(m,d,c[h>>2]|0)|0)<0){l=-1;k=10;break}n=a+860320+(g*20|0)|0;Q_(n);o=N_(n,11,c[h>>2]|0,d,1,1,m,4,4,0,0,0,0)|0;if((o|0)<0){l=o;k=10;break}else{g=g+1|0}}if((k|0)==8){g=EGa(a)|0;if((g|0)<0){l=g;i=e;return l|0}l=((c[b>>2]|0)+7|0)/8|0;i=e;return l|0}else if((k|0)==10){i=e;return l|0}return 0}function zGa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;h=(f|0)/2|0;i=c[e+76>>2]|0;if((i|0)<9){j=e+8|0;k=e+16|0;l=c[k>>2]|0;m=e+20|0;n=c[m>>2]|0;o=(f|0)>1;if((h|0)<((n-l|0)/62|0|0)){if(!o){return}p=e+860320+((g+4|0)*20|0)+4|0;q=e+24|0;r=j|0;s=e+860320+(g*20|0)+4|0;t=e+132|0;u=0;v=l;while(1){w=c[p>>2]|0;x=c[q>>2]|0;y=c[r>>2]|0;z=y+(v>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(v&7)>>>21;z=b[w+(A<<2)>>1]|0;B=z<<16>>16;C=(b[w+(A<<2)+2>>1]|0)+v|0;A=x>>>0>C>>>0?C:x;c[k>>2]=A;if((B&65535|0)==65535){C=c[s>>2]|0;w=y+(A>>>3)|0;D=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(A&7)>>>21;w=b[C+(D<<2)>>1]|0;E=b[C+(D<<2)+2>>1]|0;D=E<<16>>16;F=w&255;do{if(E<<16>>16<0){G=A+11|0;H=x>>>0>G>>>0?G:x;G=y+(H>>>3)|0;I=((fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>((D+32|0)>>>0))+(w<<16>>16)|0;G=b[C+(I<<2)>>1]|0;J=b[C+(I<<2)+2>>1]|0;I=J<<16>>16;if(!(J<<16>>16<0)){K=I;L=G&255;M=H;break}J=H-D|0;H=x>>>0>J>>>0?J:x;J=y+(H>>>3)|0;N=((fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>((I+32|0)>>>0))+(G<<16>>16)|0;K=b[C+(N<<2)+2>>1]|0;L=b[C+(N<<2)>>1]&255;M=H}else{K=D;L=F;M=A}}while(0);A=K+M|0;c[k>>2]=x>>>0>A>>>0?A:x;A=u<<1;a[(c[t>>2]|0)+A|0]=L;F=c[s>>2]|0;D=c[k>>2]|0;C=c[q>>2]|0;y=c[r>>2]|0;w=y+(D>>>3)|0;E=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(D&7)>>>21;w=b[F+(E<<2)>>1]|0;H=b[F+(E<<2)+2>>1]|0;E=H<<16>>16;N=w&255;do{if(H<<16>>16<0){G=D+11|0;I=C>>>0>G>>>0?G:C;G=y+(I>>>3)|0;J=((fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(I&7)>>>((E+32|0)>>>0))+(w<<16>>16)|0;G=b[F+(J<<2)>>1]|0;O=b[F+(J<<2)+2>>1]|0;J=O<<16>>16;if(!(O<<16>>16<0)){P=J;Q=G&255;R=I;break}O=I-E|0;I=C>>>0>O>>>0?O:C;O=y+(I>>>3)|0;S=((fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(I&7)>>>((J+32|0)>>>0))+(G<<16>>16)|0;P=b[F+(S<<2)+2>>1]|0;Q=b[F+(S<<2)>>1]&255;R=I}else{P=E;Q=N;R=D}}while(0);D=P+R|0;c[k>>2]=C>>>0>D>>>0?D:C;a[(c[t>>2]|0)+(A|1)|0]=Q}else{D=u<<1;a[(c[t>>2]|0)+D|0]=B>>>8;a[(c[t>>2]|0)+(D|1)|0]=z}D=u+1|0;if((D|0)>=(h|0)){break}u=D;v=c[k>>2]|0}return}if(!o){return}o=e+860320+((g+4|0)*20|0)+4|0;v=e+24|0;u=j|0;j=e+860320+(g*20|0)+4|0;t=e+132|0;Q=0;R=l;l=n;while(1){if((l-R|0)<=0){T=77;break}n=c[o>>2]|0;P=c[v>>2]|0;r=c[u>>2]|0;q=r+(R>>>3)|0;s=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(R&7)>>>21;q=b[n+(s<<2)>>1]|0;L=q<<16>>16;M=(b[n+(s<<2)+2>>1]|0)+R|0;s=P>>>0>M>>>0?M:P;c[k>>2]=s;if((L&65535|0)==65535){M=c[j>>2]|0;n=r+(s>>>3)|0;K=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(s&7)>>>21;n=b[M+(K<<2)>>1]|0;p=b[M+(K<<2)+2>>1]|0;K=p<<16>>16;D=n&255;do{if(p<<16>>16<0){N=s+11|0;E=P>>>0>N>>>0?N:P;N=r+(E>>>3)|0;F=((fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(E&7)>>>((K+32|0)>>>0))+(n<<16>>16)|0;N=b[M+(F<<2)>>1]|0;y=b[M+(F<<2)+2>>1]|0;F=y<<16>>16;if(!(y<<16>>16<0)){U=F;V=N&255;W=E;break}y=E-K|0;E=P>>>0>y>>>0?y:P;y=r+(E>>>3)|0;w=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(E&7)>>>((F+32|0)>>>0))+(N<<16>>16)|0;U=b[M+(w<<2)+2>>1]|0;V=b[M+(w<<2)>>1]&255;W=E}else{U=K;V=D;W=s}}while(0);s=U+W|0;c[k>>2]=P>>>0>s>>>0?s:P;s=Q<<1;a[(c[t>>2]|0)+s|0]=V;D=c[j>>2]|0;K=c[k>>2]|0;M=c[v>>2]|0;r=c[u>>2]|0;n=r+(K>>>3)|0;p=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(K&7)>>>21;n=b[D+(p<<2)>>1]|0;z=b[D+(p<<2)+2>>1]|0;p=z<<16>>16;B=n&255;do{if(z<<16>>16<0){A=K+11|0;C=M>>>0>A>>>0?A:M;A=r+(C>>>3)|0;E=((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(C&7)>>>((p+32|0)>>>0))+(n<<16>>16)|0;A=b[D+(E<<2)>>1]|0;w=b[D+(E<<2)+2>>1]|0;E=w<<16>>16;if(!(w<<16>>16<0)){X=E;Y=A&255;Z=C;break}w=C-p|0;C=M>>>0>w>>>0?w:M;w=r+(C>>>3)|0;N=((fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(C&7)>>>((E+32|0)>>>0))+(A<<16>>16)|0;X=b[D+(N<<2)+2>>1]|0;Y=b[D+(N<<2)>>1]&255;Z=C}else{X=p;Y=B;Z=K}}while(0);K=X+Z|0;c[k>>2]=M>>>0>K>>>0?K:M;a[(c[t>>2]|0)+(s|1)|0]=Y}else{K=Q<<1;a[(c[t>>2]|0)+K|0]=L>>>8;a[(c[t>>2]|0)+(K|1)|0]=q}K=Q+1|0;if((K|0)>=(h|0)){T=77;break}Q=K;R=c[k>>2]|0;l=c[m>>2]|0}if((T|0)==77){return}}m=e+8|0;l=e+16|0;k=c[l>>2]|0;R=c[e+20>>2]|0;Q=(h|0)>=((R-k|0)/62|0|0);t=(f|0)>1;if((i|0)>=15){if(!Q){if(!t){return}i=e+860320+(g*20|0)+4|0;f=e+144|0;Y=c[e+24>>2]|0;Z=c[m>>2]|0;X=0;u=k;do{v=c[i>>2]|0;j=Z+(u>>>3)|0;V=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(u&7)>>>21;j=b[v+(V<<2)>>1]|0;W=b[v+(V<<2)+2>>1]|0;V=W<<16>>16;do{if(W<<16>>16<0){U=u+11|0;o=Y>>>0>U>>>0?U:Y;U=Z+(o>>>3)|0;K=((fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(o&7)>>>((V+32|0)>>>0))+(j<<16>>16)|0;U=b[v+(K<<2)>>1]|0;B=b[v+(K<<2)+2>>1]|0;K=B<<16>>16;if(!(B<<16>>16<0)){_=K;$=U;aa=o;break}B=o-V|0;o=Y>>>0>B>>>0?B:Y;B=Z+(o>>>3)|0;p=((fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(o&7)>>>((K+32|0)>>>0))+(U<<16>>16)|0;_=b[v+(p<<2)+2>>1]|0;$=b[v+(p<<2)>>1]|0;aa=o}else{_=V;$=j;aa=u}}while(0);j=_+aa|0;V=Y>>>0>j>>>0?j:Y;c[l>>2]=V;j=$<<2;v=X<<1;W=c[f>>2]|0;q=W+(v<<1)|0;b[q>>1]=j;L=Z+(V>>>3)|0;s=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(V&7)>>>30;L=V+2|0;V=Y>>>0>L>>>0?L:Y;c[l>>2]=V;b[q>>1]=j&65535|s;s=c[i>>2]|0;j=Z+(V>>>3)|0;q=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(V&7)>>>21;j=b[s+(q<<2)>>1]|0;L=b[s+(q<<2)+2>>1]|0;q=L<<16>>16;do{if(L<<16>>16<0){M=V+11|0;o=Y>>>0>M>>>0?M:Y;M=Z+(o>>>3)|0;p=((fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(o&7)>>>((q+32|0)>>>0))+(j<<16>>16)|0;M=b[s+(p<<2)>>1]|0;U=b[s+(p<<2)+2>>1]|0;p=U<<16>>16;if(!(U<<16>>16<0)){ba=p;ca=M;da=o;break}U=o-q|0;o=Y>>>0>U>>>0?U:Y;U=Z+(o>>>3)|0;K=((fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(o&7)>>>((p+32|0)>>>0))+(M<<16>>16)|0;ba=b[s+(K<<2)+2>>1]|0;ca=b[s+(K<<2)>>1]|0;da=o}else{ba=q;ca=j;da=V}}while(0);V=ba+da|0;j=Y>>>0>V>>>0?V:Y;c[l>>2]=j;V=ca<<2;q=W+((v|1)<<1)|0;b[q>>1]=V;s=Z+(j>>>3)|0;L=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(j&7)>>>30;s=j+2|0;u=Y>>>0>s>>>0?s:Y;c[l>>2]=u;b[q>>1]=V&65535|L;X=X+1|0;}while((X|0)<(h|0));return}if(!t){return}X=e+860320+(g*20|0)+4|0;u=e+24|0;Y=m|0;Z=e+144|0;ca=0;da=k;while(1){if((R-da|0)<=0){T=77;break}ba=c[X>>2]|0;i=c[u>>2]|0;f=c[Y>>2]|0;$=f+(da>>>3)|0;aa=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(da&7)>>>21;$=b[ba+(aa<<2)>>1]|0;_=b[ba+(aa<<2)+2>>1]|0;aa=_<<16>>16;do{if(_<<16>>16<0){L=da+11|0;V=i>>>0>L>>>0?L:i;L=f+(V>>>3)|0;q=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(V&7)>>>((aa+32|0)>>>0))+($<<16>>16)|0;L=b[ba+(q<<2)>>1]|0;s=b[ba+(q<<2)+2>>1]|0;q=s<<16>>16;if(!(s<<16>>16<0)){ea=q;fa=L;ga=V;break}s=V-aa|0;V=i>>>0>s>>>0?s:i;s=f+(V>>>3)|0;j=((fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(V&7)>>>((q+32|0)>>>0))+(L<<16>>16)|0;ea=b[ba+(j<<2)+2>>1]|0;fa=b[ba+(j<<2)>>1]|0;ga=V}else{ea=aa;fa=$;ga=da}}while(0);$=ea+ga|0;aa=i>>>0>$>>>0?$:i;c[l>>2]=aa;$=fa<<2;ba=ca<<1;_=c[Z>>2]|0;v=_+(ba<<1)|0;b[v>>1]=$;W=f+(aa>>>3)|0;V=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(aa&7)>>>30;W=aa+2|0;aa=i>>>0>W>>>0?W:i;c[l>>2]=aa;b[v>>1]=$&65535|V;V=c[X>>2]|0;$=f+(aa>>>3)|0;v=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(aa&7)>>>21;$=b[V+(v<<2)>>1]|0;W=b[V+(v<<2)+2>>1]|0;v=W<<16>>16;do{if(W<<16>>16<0){j=aa+11|0;L=i>>>0>j>>>0?j:i;j=f+(L>>>3)|0;q=((fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(L&7)>>>((v+32|0)>>>0))+($<<16>>16)|0;j=b[V+(q<<2)>>1]|0;s=b[V+(q<<2)+2>>1]|0;q=s<<16>>16;if(!(s<<16>>16<0)){ha=q;ia=j;ja=L;break}s=L-v|0;L=i>>>0>s>>>0?s:i;s=f+(L>>>3)|0;o=((fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(L&7)>>>((q+32|0)>>>0))+(j<<16>>16)|0;ha=b[V+(o<<2)+2>>1]|0;ia=b[V+(o<<2)>>1]|0;ja=L}else{ha=v;ia=$;ja=aa}}while(0);aa=ha+ja|0;$=i>>>0>aa>>>0?aa:i;c[l>>2]=$;aa=ia<<2;v=_+((ba|1)<<1)|0;b[v>>1]=aa;V=f+($>>>3)|0;W=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<($&7)>>>30;V=$+2|0;$=i>>>0>V>>>0?V:i;c[l>>2]=$;b[v>>1]=aa&65535|W;W=ca+1|0;if((W|0)<(h|0)){ca=W;da=$}else{T=77;break}}if((T|0)==77){return}}if(!Q){if(!t){return}Q=e+860320+((g+4|0)*20|0)+4|0;da=e+860320+(g*20|0)+4|0;ca=e+144|0;ia=c[e+24>>2]|0;ja=c[m>>2]|0;ha=0;X=k;while(1){Z=c[Q>>2]|0;fa=ja+(X>>>3)|0;ga=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(X&7)>>>21;fa=b[Z+(ga<<2)>>1]|0;ea=(b[Z+(ga<<2)+2>>1]|0)+X|0;ga=ia>>>0>ea>>>0?ea:ia;c[l>>2]=ga;if(fa<<16>>16==-1){ea=c[da>>2]|0;Z=ja+(ga>>>3)|0;Y=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(ga&7)>>>21;Z=b[ea+(Y<<2)>>1]|0;u=b[ea+(Y<<2)+2>>1]|0;Y=u<<16>>16;do{if(u<<16>>16<0){$=ga+11|0;W=ia>>>0>$>>>0?$:ia;$=ja+(W>>>3)|0;aa=((fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(W&7)>>>((Y+32|0)>>>0))+(Z<<16>>16)|0;$=b[ea+(aa<<2)>>1]|0;v=b[ea+(aa<<2)+2>>1]|0;aa=v<<16>>16;if(!(v<<16>>16<0)){ka=aa;la=$;ma=W;break}v=W-Y|0;W=ia>>>0>v>>>0?v:ia;v=ja+(W>>>3)|0;V=((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(W&7)>>>((aa+32|0)>>>0))+($<<16>>16)|0;ka=b[ea+(V<<2)+2>>1]|0;la=b[ea+(V<<2)>>1]|0;ma=W}else{ka=Y;la=Z;ma=ga}}while(0);Z=ka+ma|0;Y=ia>>>0>Z>>>0?Z:ia;c[l>>2]=Y;Z=ha<<1;ea=c[ca>>2]|0;b[ea+(Z<<1)>>1]=la;u=c[da>>2]|0;i=ja+(Y>>>3)|0;f=(fe(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(Y&7)>>>21;i=b[u+(f<<2)>>1]|0;ba=b[u+(f<<2)+2>>1]|0;f=ba<<16>>16;do{if(ba<<16>>16<0){_=Y+11|0;W=ia>>>0>_>>>0?_:ia;_=ja+(W>>>3)|0;V=((fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(W&7)>>>((f+32|0)>>>0))+(i<<16>>16)|0;_=b[u+(V<<2)>>1]|0;$=b[u+(V<<2)+2>>1]|0;V=$<<16>>16;if(!($<<16>>16<0)){na=V;oa=_;pa=W;break}$=W-f|0;W=ia>>>0>$>>>0?$:ia;$=ja+(W>>>3)|0;aa=((fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(W&7)>>>((V+32|0)>>>0))+(_<<16>>16)|0;na=b[u+(aa<<2)+2>>1]|0;oa=b[u+(aa<<2)>>1]|0;pa=W}else{na=f;oa=i;pa=Y}}while(0);Y=na+pa|0;i=ia>>>0>Y>>>0?Y:ia;c[l>>2]=i;b[ea+((Z|1)<<1)>>1]=oa;qa=i}else{i=fa&65535;Y=ha<<1;f=c[ca>>2]|0;b[f+(Y<<1)>>1]=i<<16>>24;b[f+((Y|1)<<1)>>1]=i<<24>>24;qa=ga}i=ha+1|0;if((i|0)<(h|0)){ha=i;X=qa}else{break}}return}if(!t){return}t=e+860320+((g+4|0)*20|0)+4|0;qa=e+24|0;X=m|0;m=e+860320+(g*20|0)+4|0;g=e+144|0;e=0;ha=k;while(1){if((R-ha|0)<=0){T=77;break}k=c[t>>2]|0;ca=c[qa>>2]|0;oa=c[X>>2]|0;ia=oa+(ha>>>3)|0;pa=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(ha&7)>>>21;ia=b[k+(pa<<2)>>1]|0;na=(b[k+(pa<<2)+2>>1]|0)+ha|0;pa=ca>>>0>na>>>0?na:ca;c[l>>2]=pa;if(ia<<16>>16==-1){na=c[m>>2]|0;k=oa+(pa>>>3)|0;ja=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(pa&7)>>>21;k=b[na+(ja<<2)>>1]|0;da=b[na+(ja<<2)+2>>1]|0;ja=da<<16>>16;do{if(da<<16>>16<0){la=pa+11|0;ma=ca>>>0>la>>>0?la:ca;la=oa+(ma>>>3)|0;ka=((fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>((ja+32|0)>>>0))+(k<<16>>16)|0;la=b[na+(ka<<2)>>1]|0;Q=b[na+(ka<<2)+2>>1]|0;ka=Q<<16>>16;if(!(Q<<16>>16<0)){ra=ka;sa=la;ta=ma;break}Q=ma-ja|0;ma=ca>>>0>Q>>>0?Q:ca;Q=oa+(ma>>>3)|0;i=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(ma&7)>>>((ka+32|0)>>>0))+(la<<16>>16)|0;ra=b[na+(i<<2)+2>>1]|0;sa=b[na+(i<<2)>>1]|0;ta=ma}else{ra=ja;sa=k;ta=pa}}while(0);k=ra+ta|0;ja=ca>>>0>k>>>0?k:ca;c[l>>2]=ja;k=e<<1;na=c[g>>2]|0;b[na+(k<<1)>>1]=sa;da=c[m>>2]|0;ga=oa+(ja>>>3)|0;fa=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ja&7)>>>21;ga=b[da+(fa<<2)>>1]|0;Z=b[da+(fa<<2)+2>>1]|0;fa=Z<<16>>16;do{if(Z<<16>>16<0){ea=ja+11|0;ma=ca>>>0>ea>>>0?ea:ca;ea=oa+(ma>>>3)|0;i=((fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ma&7)>>>((fa+32|0)>>>0))+(ga<<16>>16)|0;ea=b[da+(i<<2)>>1]|0;la=b[da+(i<<2)+2>>1]|0;i=la<<16>>16;if(!(la<<16>>16<0)){ua=i;va=ea;wa=ma;break}la=ma-fa|0;ma=ca>>>0>la>>>0?la:ca;la=oa+(ma>>>3)|0;ka=((fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>((i+32|0)>>>0))+(ea<<16>>16)|0;ua=b[da+(ka<<2)+2>>1]|0;va=b[da+(ka<<2)>>1]|0;wa=ma}else{ua=fa;va=ga;wa=ja}}while(0);ja=ua+wa|0;ga=ca>>>0>ja>>>0?ja:ca;c[l>>2]=ga;b[na+((k|1)<<1)>>1]=va;xa=ga}else{ga=ia&65535;ja=e<<1;fa=c[g>>2]|0;b[fa+(ja<<1)>>1]=ga<<16>>24;b[fa+((ja|1)<<1)>>1]=ga<<24>>24;xa=pa}ga=e+1|0;if((ga|0)<(h|0)){e=ga;ha=xa}else{T=77;break}}if((T|0)==77){return}}function AGa(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;g=(f|0)/2|0;h=e+8|0;i=e+16|0;j=c[i>>2]|0;k=e+20|0;l=c[k>>2]|0;m=(f|0)>1;if((g|0)<((l-j|0)/124|0|0)){if(!m){return}f=e+860424|0;n=e+24|0;o=h|0;p=e+860324|0;q=e+132|0;r=e+860344|0;s=e+136|0;t=e+860444|0;u=e+860364|0;v=e+140|0;w=0;x=j;while(1){y=c[f>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;B=A+(x>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>21;B=b[y+(C<<2)>>1]|0;D=B<<16>>16;E=(b[y+(C<<2)+2>>1]|0)+x|0;C=z>>>0>E>>>0?E:z;c[i>>2]=C;if((D&65535|0)==65535){E=c[p>>2]|0;y=A+(C>>>3)|0;F=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(C&7)>>>21;y=b[E+(F<<2)>>1]|0;G=b[E+(F<<2)+2>>1]|0;F=G<<16>>16;H=y&255;do{if(G<<16>>16<0){I=C+11|0;J=z>>>0>I>>>0?I:z;I=A+(J>>>3)|0;K=((fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>((F+32|0)>>>0))+(y<<16>>16)|0;I=b[E+(K<<2)>>1]|0;L=b[E+(K<<2)+2>>1]|0;K=L<<16>>16;if(!(L<<16>>16<0)){M=K;N=I&255;O=J;break}L=J-F|0;J=z>>>0>L>>>0?L:z;L=A+(J>>>3)|0;P=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(J&7)>>>((K+32|0)>>>0))+(I<<16>>16)|0;M=b[E+(P<<2)+2>>1]|0;N=b[E+(P<<2)>>1]&255;O=J}else{M=F;N=H;O=C}}while(0);C=M+O|0;c[i>>2]=z>>>0>C>>>0?C:z;a[(c[q>>2]|0)+(w<<1)|0]=N;C=c[r>>2]|0;H=c[i>>2]|0;F=c[n>>2]|0;E=c[o>>2]|0;A=E+(H>>>3)|0;y=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(H&7)>>>21;A=b[C+(y<<2)>>1]|0;G=b[C+(y<<2)+2>>1]|0;y=G<<16>>16;J=A&255;do{if(G<<16>>16<0){P=H+11|0;I=F>>>0>P>>>0?P:F;P=E+(I>>>3)|0;K=((fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(I&7)>>>((y+32|0)>>>0))+(A<<16>>16)|0;P=b[C+(K<<2)>>1]|0;L=b[C+(K<<2)+2>>1]|0;K=L<<16>>16;if(!(L<<16>>16<0)){Q=K;R=P&255;S=I;break}L=I-y|0;I=F>>>0>L>>>0?L:F;L=E+(I>>>3)|0;T=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(I&7)>>>((K+32|0)>>>0))+(P<<16>>16)|0;Q=b[C+(T<<2)+2>>1]|0;R=b[C+(T<<2)>>1]&255;S=I}else{Q=y;R=J;S=H}}while(0);H=Q+S|0;c[i>>2]=F>>>0>H>>>0?H:F;a[(c[s>>2]|0)+w|0]=R}else{a[(c[q>>2]|0)+(w<<1)|0]=D>>>8;a[(c[s>>2]|0)+w|0]=B}H=c[t>>2]|0;J=c[i>>2]|0;y=c[n>>2]|0;C=c[o>>2]|0;E=C+(J>>>3)|0;A=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(J&7)>>>21;E=b[H+(A<<2)>>1]|0;G=E<<16>>16;z=(b[H+(A<<2)+2>>1]|0)+J|0;J=y>>>0>z>>>0?z:y;c[i>>2]=J;if((G&65535|0)==65535){z=c[p>>2]|0;A=C+(J>>>3)|0;H=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(J&7)>>>21;A=b[z+(H<<2)>>1]|0;I=b[z+(H<<2)+2>>1]|0;H=I<<16>>16;T=A&255;do{if(I<<16>>16<0){P=J+11|0;K=y>>>0>P>>>0?P:y;P=C+(K>>>3)|0;L=((fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(K&7)>>>((H+32|0)>>>0))+(A<<16>>16)|0;P=b[z+(L<<2)>>1]|0;U=b[z+(L<<2)+2>>1]|0;L=U<<16>>16;if(!(U<<16>>16<0)){V=L;W=P&255;X=K;break}U=K-H|0;K=y>>>0>U>>>0?U:y;U=C+(K>>>3)|0;Y=((fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(K&7)>>>((L+32|0)>>>0))+(P<<16>>16)|0;V=b[z+(Y<<2)+2>>1]|0;W=b[z+(Y<<2)>>1]&255;X=K}else{V=H;W=T;X=J}}while(0);J=V+X|0;c[i>>2]=y>>>0>J>>>0?J:y;a[(c[q>>2]|0)+(w<<1|1)|0]=W;J=c[u>>2]|0;T=c[i>>2]|0;H=c[n>>2]|0;z=c[o>>2]|0;C=z+(T>>>3)|0;A=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(T&7)>>>21;C=b[J+(A<<2)>>1]|0;I=b[J+(A<<2)+2>>1]|0;A=I<<16>>16;B=C&255;do{if(I<<16>>16<0){D=T+11|0;F=H>>>0>D>>>0?D:H;D=z+(F>>>3)|0;K=((fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(F&7)>>>((A+32|0)>>>0))+(C<<16>>16)|0;D=b[J+(K<<2)>>1]|0;Y=b[J+(K<<2)+2>>1]|0;K=Y<<16>>16;if(!(Y<<16>>16<0)){Z=K;_=D&255;$=F;break}Y=F-A|0;F=H>>>0>Y>>>0?Y:H;Y=z+(F>>>3)|0;P=((fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(F&7)>>>((K+32|0)>>>0))+(D<<16>>16)|0;Z=b[J+(P<<2)+2>>1]|0;_=b[J+(P<<2)>>1]&255;$=F}else{Z=A;_=B;$=T}}while(0);T=Z+$|0;c[i>>2]=H>>>0>T>>>0?T:H;a[(c[v>>2]|0)+w|0]=_}else{a[(c[q>>2]|0)+(w<<1|1)|0]=G>>>8;a[(c[v>>2]|0)+w|0]=E}T=w+1|0;if((T|0)>=(g|0)){break}w=T;x=c[i>>2]|0}return}a:do{if(m){x=e+860424|0;w=e+24|0;v=h|0;q=e+860324|0;_=e+132|0;$=e+860344|0;Z=e+136|0;o=e+860444|0;n=e+860364|0;u=e+140|0;W=0;X=j;V=l;while(1){if((V-X|0)<=0){aa=W;break a}p=c[x>>2]|0;t=c[w>>2]|0;s=c[v>>2]|0;R=s+(X>>>3)|0;S=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(X&7)>>>21;R=b[p+(S<<2)>>1]|0;Q=R<<16>>16;r=(b[p+(S<<2)+2>>1]|0)+X|0;S=t>>>0>r>>>0?r:t;c[i>>2]=S;if((Q&65535|0)==65535){r=c[q>>2]|0;p=s+(S>>>3)|0;N=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(S&7)>>>21;p=b[r+(N<<2)>>1]|0;O=b[r+(N<<2)+2>>1]|0;N=O<<16>>16;M=p&255;do{if(O<<16>>16<0){f=S+11|0;T=t>>>0>f>>>0?f:t;f=s+(T>>>3)|0;B=((fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(T&7)>>>((N+32|0)>>>0))+(p<<16>>16)|0;f=b[r+(B<<2)>>1]|0;A=b[r+(B<<2)+2>>1]|0;B=A<<16>>16;if(!(A<<16>>16<0)){ba=B;ca=f&255;da=T;break}A=T-N|0;T=t>>>0>A>>>0?A:t;A=s+(T>>>3)|0;J=((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(T&7)>>>((B+32|0)>>>0))+(f<<16>>16)|0;ba=b[r+(J<<2)+2>>1]|0;ca=b[r+(J<<2)>>1]&255;da=T}else{ba=N;ca=M;da=S}}while(0);S=ba+da|0;c[i>>2]=t>>>0>S>>>0?S:t;a[(c[_>>2]|0)+(W<<1)|0]=ca;S=c[$>>2]|0;M=c[i>>2]|0;N=c[w>>2]|0;r=c[v>>2]|0;s=r+(M>>>3)|0;p=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(M&7)>>>21;s=b[S+(p<<2)>>1]|0;O=b[S+(p<<2)+2>>1]|0;p=O<<16>>16;T=s&255;do{if(O<<16>>16<0){J=M+11|0;f=N>>>0>J>>>0?J:N;J=r+(f>>>3)|0;B=((fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(f&7)>>>((p+32|0)>>>0))+(s<<16>>16)|0;J=b[S+(B<<2)>>1]|0;A=b[S+(B<<2)+2>>1]|0;B=A<<16>>16;if(!(A<<16>>16<0)){ea=B;fa=J&255;ga=f;break}A=f-p|0;f=N>>>0>A>>>0?A:N;A=r+(f>>>3)|0;z=((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(f&7)>>>((B+32|0)>>>0))+(J<<16>>16)|0;ea=b[S+(z<<2)+2>>1]|0;fa=b[S+(z<<2)>>1]&255;ga=f}else{ea=p;fa=T;ga=M}}while(0);M=ea+ga|0;c[i>>2]=N>>>0>M>>>0?M:N;a[(c[Z>>2]|0)+W|0]=fa}else{a[(c[_>>2]|0)+(W<<1)|0]=Q>>>8;a[(c[Z>>2]|0)+W|0]=R}M=c[o>>2]|0;T=c[i>>2]|0;p=c[w>>2]|0;S=c[v>>2]|0;r=S+(T>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(T&7)>>>21;r=b[M+(s<<2)>>1]|0;O=r<<16>>16;t=(b[M+(s<<2)+2>>1]|0)+T|0;T=p>>>0>t>>>0?t:p;c[i>>2]=T;if((O&65535|0)==65535){t=c[q>>2]|0;s=S+(T>>>3)|0;M=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(T&7)>>>21;s=b[t+(M<<2)>>1]|0;f=b[t+(M<<2)+2>>1]|0;M=f<<16>>16;z=s&255;do{if(f<<16>>16<0){J=T+11|0;B=p>>>0>J>>>0?J:p;J=S+(B>>>3)|0;A=((fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(B&7)>>>((M+32|0)>>>0))+(s<<16>>16)|0;J=b[t+(A<<2)>>1]|0;C=b[t+(A<<2)+2>>1]|0;A=C<<16>>16;if(!(C<<16>>16<0)){ha=A;ia=J&255;ja=B;break}C=B-M|0;B=p>>>0>C>>>0?C:p;C=S+(B>>>3)|0;I=((fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7)>>>((A+32|0)>>>0))+(J<<16>>16)|0;ha=b[t+(I<<2)+2>>1]|0;ia=b[t+(I<<2)>>1]&255;ja=B}else{ha=M;ia=z;ja=T}}while(0);T=ha+ja|0;c[i>>2]=p>>>0>T>>>0?T:p;a[(c[_>>2]|0)+(W<<1|1)|0]=ia;T=c[n>>2]|0;z=c[i>>2]|0;M=c[w>>2]|0;t=c[v>>2]|0;S=t+(z>>>3)|0;s=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(z&7)>>>21;S=b[T+(s<<2)>>1]|0;f=b[T+(s<<2)+2>>1]|0;s=f<<16>>16;R=S&255;do{if(f<<16>>16<0){Q=z+11|0;N=M>>>0>Q>>>0?Q:M;Q=t+(N>>>3)|0;B=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(N&7)>>>((s+32|0)>>>0))+(S<<16>>16)|0;Q=b[T+(B<<2)>>1]|0;I=b[T+(B<<2)+2>>1]|0;B=I<<16>>16;if(!(I<<16>>16<0)){ka=B;la=Q&255;ma=N;break}I=N-s|0;N=M>>>0>I>>>0?I:M;I=t+(N>>>3)|0;J=((fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(N&7)>>>((B+32|0)>>>0))+(Q<<16>>16)|0;ka=b[T+(J<<2)+2>>1]|0;la=b[T+(J<<2)>>1]&255;ma=N}else{ka=s;la=R;ma=z}}while(0);z=ka+ma|0;c[i>>2]=M>>>0>z>>>0?z:M;a[(c[u>>2]|0)+W|0]=la}else{a[(c[_>>2]|0)+(W<<1|1)|0]=O>>>8;a[(c[u>>2]|0)+W|0]=r}z=W+1|0;if((z|0)>=(g|0)){aa=z;break a}W=z;X=c[i>>2]|0;V=c[k>>2]|0}}else{aa=0}}while(0);if((aa|0)>=(g|0)){return}k=e+140|0;i=e+132|0;la=e+136|0;e=aa;do{a[(c[k>>2]|0)+e|0]=-128;aa=e<<1;a[(c[i>>2]|0)+(aa|1)|0]=-128;a[(c[la>>2]|0)+e|0]=-128;a[(c[i>>2]|0)+aa|0]=-128;e=e+1|0;}while((e|0)<(g|0));return}function BGa(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=(f|0)/2|0;h=e+8|0;i=e+16|0;j=c[i>>2]|0;k=e+20|0;l=c[k>>2]|0;m=(f|0)>1;if((g|0)<((l-j|0)/62|0|0)){if(!m){return}f=e+860404|0;n=e+24|0;o=h|0;p=e+860324|0;q=e+132|0;r=0;s=j;while(1){t=c[f>>2]|0;u=c[n>>2]|0;v=c[o>>2]|0;w=v+(s>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(s&7)>>>21;w=b[t+(x<<2)>>1]|0;y=w<<16>>16;z=(b[t+(x<<2)+2>>1]|0)+s|0;x=u>>>0>z>>>0?z:u;c[i>>2]=x;if((y&65535|0)==65535){z=c[p>>2]|0;t=v+(x>>>3)|0;A=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(x&7)>>>21;t=b[z+(A<<2)>>1]|0;B=b[z+(A<<2)+2>>1]|0;A=B<<16>>16;C=t&255;do{if(B<<16>>16<0){D=x+11|0;E=u>>>0>D>>>0?D:u;D=v+(E>>>3)|0;F=((fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7)>>>((A+32|0)>>>0))+(t<<16>>16)|0;D=b[z+(F<<2)>>1]|0;G=b[z+(F<<2)+2>>1]|0;F=G<<16>>16;if(!(G<<16>>16<0)){H=F;I=D&255;J=E;break}G=E-A|0;E=u>>>0>G>>>0?G:u;G=v+(E>>>3)|0;K=((fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7)>>>((F+32|0)>>>0))+(D<<16>>16)|0;H=b[z+(K<<2)+2>>1]|0;I=b[z+(K<<2)>>1]&255;J=E}else{H=A;I=C;J=x}}while(0);x=H+J|0;c[i>>2]=u>>>0>x>>>0?x:u;x=r<<1;a[(c[q>>2]|0)+x|0]=I;C=c[p>>2]|0;A=c[i>>2]|0;z=c[n>>2]|0;v=c[o>>2]|0;t=v+(A>>>3)|0;B=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(A&7)>>>21;t=b[C+(B<<2)>>1]|0;E=b[C+(B<<2)+2>>1]|0;B=E<<16>>16;K=t&255;do{if(E<<16>>16<0){D=A+11|0;F=z>>>0>D>>>0?D:z;D=v+(F>>>3)|0;G=((fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(F&7)>>>((B+32|0)>>>0))+(t<<16>>16)|0;D=b[C+(G<<2)>>1]|0;L=b[C+(G<<2)+2>>1]|0;G=L<<16>>16;if(!(L<<16>>16<0)){M=G;N=D&255;O=F;break}L=F-B|0;F=z>>>0>L>>>0?L:z;L=v+(F>>>3)|0;P=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(F&7)>>>((G+32|0)>>>0))+(D<<16>>16)|0;M=b[C+(P<<2)+2>>1]|0;N=b[C+(P<<2)>>1]&255;O=F}else{M=B;N=K;O=A}}while(0);A=M+O|0;c[i>>2]=z>>>0>A>>>0?A:z;a[(c[q>>2]|0)+(x|1)|0]=N}else{A=r<<1;a[(c[q>>2]|0)+A|0]=y>>>8;a[(c[q>>2]|0)+(A|1)|0]=w}A=r+1|0;if((A|0)>=(g|0)){break}r=A;s=c[i>>2]|0}return}if(!m){return}m=e+860404|0;s=e+24|0;r=h|0;h=e+860324|0;q=e+132|0;e=0;N=j;j=l;while(1){if((j-N|0)<=0){Q=29;break}l=c[m>>2]|0;O=c[s>>2]|0;M=c[r>>2]|0;o=M+(N>>>3)|0;n=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(N&7)>>>21;o=b[l+(n<<2)>>1]|0;p=o<<16>>16;I=(b[l+(n<<2)+2>>1]|0)+N|0;n=O>>>0>I>>>0?I:O;c[i>>2]=n;if((p&65535|0)==65535){I=c[h>>2]|0;l=M+(n>>>3)|0;J=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(n&7)>>>21;l=b[I+(J<<2)>>1]|0;H=b[I+(J<<2)+2>>1]|0;J=H<<16>>16;f=l&255;do{if(H<<16>>16<0){A=n+11|0;K=O>>>0>A>>>0?A:O;A=M+(K>>>3)|0;B=((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(K&7)>>>((J+32|0)>>>0))+(l<<16>>16)|0;A=b[I+(B<<2)>>1]|0;C=b[I+(B<<2)+2>>1]|0;B=C<<16>>16;if(!(C<<16>>16<0)){R=B;S=A&255;T=K;break}C=K-J|0;K=O>>>0>C>>>0?C:O;C=M+(K>>>3)|0;v=((fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(K&7)>>>((B+32|0)>>>0))+(A<<16>>16)|0;R=b[I+(v<<2)+2>>1]|0;S=b[I+(v<<2)>>1]&255;T=K}else{R=J;S=f;T=n}}while(0);n=R+T|0;c[i>>2]=O>>>0>n>>>0?n:O;n=e<<1;a[(c[q>>2]|0)+n|0]=S;f=c[h>>2]|0;J=c[i>>2]|0;I=c[s>>2]|0;M=c[r>>2]|0;l=M+(J>>>3)|0;H=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(J&7)>>>21;l=b[f+(H<<2)>>1]|0;w=b[f+(H<<2)+2>>1]|0;H=w<<16>>16;y=l&255;do{if(w<<16>>16<0){x=J+11|0;z=I>>>0>x>>>0?x:I;x=M+(z>>>3)|0;K=((fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7)>>>((H+32|0)>>>0))+(l<<16>>16)|0;x=b[f+(K<<2)>>1]|0;v=b[f+(K<<2)+2>>1]|0;K=v<<16>>16;if(!(v<<16>>16<0)){U=K;V=x&255;W=z;break}v=z-H|0;z=I>>>0>v>>>0?v:I;v=M+(z>>>3)|0;A=((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(z&7)>>>((K+32|0)>>>0))+(x<<16>>16)|0;U=b[f+(A<<2)+2>>1]|0;V=b[f+(A<<2)>>1]&255;W=z}else{U=H;V=y;W=J}}while(0);J=U+W|0;c[i>>2]=I>>>0>J>>>0?J:I;a[(c[q>>2]|0)+(n|1)|0]=V}else{J=e<<1;a[(c[q>>2]|0)+J|0]=p>>>8;a[(c[q>>2]|0)+(J|1)|0]=o}J=e+1|0;if((J|0)>=(g|0)){Q=29;break}e=J;N=c[i>>2]|0;j=c[k>>2]|0}if((Q|0)==29){return}}function CGa(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;g=(c[e+60>>2]|0)==24;h=(f|0)>0;if((c[e+56>>2]|0)==0){if(g){if(!h){return}i=e+860404|0;j=e+16|0;k=e+24|0;l=e+8|0;m=e+860324|0;n=e+132|0;o=e+860344|0;p=e+860364|0;q=0;do{r=c[i>>2]|0;s=c[j>>2]|0;t=c[k>>2]|0;u=c[l>>2]|0;v=u+(s>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(s&7)>>>21;v=b[r+(w<<2)>>1]|0;x=(b[r+(w<<2)+2>>1]|0)+s|0;s=t>>>0>x>>>0?x:t;c[j>>2]=s;if(v<<16>>16==-1){x=c[m>>2]|0;w=u+(s>>>3)|0;r=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(s&7)>>>21;w=b[x+(r<<2)>>1]|0;y=b[x+(r<<2)+2>>1]|0;r=y<<16>>16;do{if(y<<16>>16<0){z=s+11|0;A=t>>>0>z>>>0?z:t;z=u+(A>>>3)|0;B=((fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(A&7)>>>((r+32|0)>>>0))+(w<<16>>16)|0;z=b[x+(B<<2)>>1]|0;C=b[x+(B<<2)+2>>1]|0;B=C<<16>>16;if(C<<16>>16<0){C=A-r|0;D=t>>>0>C>>>0?C:t;C=u+(D>>>3)|0;E=((fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(D&7)>>>((B+32|0)>>>0))+(z<<16>>16)|0;F=b[x+(E<<2)+2>>1]|0;G=b[x+(E<<2)>>1]&255;H=D;break}else{F=B;G=z&255;H=A;break}}else{F=r;G=w&255;H=s}}while(0);s=F+H|0;c[j>>2]=t>>>0>s>>>0?s:t;s=q<<2;a[(c[n>>2]|0)+s|0]=G;w=c[o>>2]|0;r=c[j>>2]|0;x=c[k>>2]|0;u=c[l>>2]|0;y=u+(r>>>3)|0;A=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(r&7)>>>21;y=b[w+(A<<2)>>1]|0;z=b[w+(A<<2)+2>>1]|0;A=z<<16>>16;B=y&255;do{if(z<<16>>16<0){D=r+11|0;E=x>>>0>D>>>0?D:x;D=u+(E>>>3)|0;C=((fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7)>>>((A+32|0)>>>0))+(y<<16>>16)|0;D=b[w+(C<<2)>>1]|0;I=b[w+(C<<2)+2>>1]|0;C=I<<16>>16;if(!(I<<16>>16<0)){J=C;K=D&255;L=E;break}I=E-A|0;E=x>>>0>I>>>0?I:x;I=u+(E>>>3)|0;M=((fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(E&7)>>>((C+32|0)>>>0))+(D<<16>>16)|0;J=b[w+(M<<2)+2>>1]|0;K=b[w+(M<<2)>>1]&255;L=E}else{J=A;K=B;L=r}}while(0);r=J+L|0;c[j>>2]=x>>>0>r>>>0?r:x;a[(c[n>>2]|0)+(s|1)|0]=K;r=c[p>>2]|0;B=c[j>>2]|0;A=c[k>>2]|0;w=c[l>>2]|0;u=w+(B>>>3)|0;y=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(B&7)>>>21;u=b[r+(y<<2)>>1]|0;z=b[r+(y<<2)+2>>1]|0;y=z<<16>>16;t=u&255;do{if(z<<16>>16<0){E=B+11|0;M=A>>>0>E>>>0?E:A;E=w+(M>>>3)|0;D=((fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(M&7)>>>((y+32|0)>>>0))+(u<<16>>16)|0;E=b[r+(D<<2)>>1]|0;C=b[r+(D<<2)+2>>1]|0;D=C<<16>>16;if(!(C<<16>>16<0)){N=D;O=E&255;P=M;break}C=M-y|0;M=A>>>0>C>>>0?C:A;C=w+(M>>>3)|0;I=((fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(M&7)>>>((D+32|0)>>>0))+(E<<16>>16)|0;N=b[r+(I<<2)+2>>1]|0;O=b[r+(I<<2)>>1]&255;P=M}else{N=y;O=t;P=B}}while(0);B=N+P|0;c[j>>2]=A>>>0>B>>>0?B:A;a[(c[n>>2]|0)+(s|2)|0]=O}else{c[(c[n>>2]|0)+(q<<2)>>2]=c[e+852128+(v<<16>>16<<2)>>2]}q=q+1|0;}while((q|0)<(f|0));return}if(!h){return}q=e+860404|0;n=e+16|0;O=e+24|0;j=e+8|0;P=e+860324|0;N=e+132|0;l=e+860344|0;k=e+860364|0;p=0;do{K=c[q>>2]|0;L=c[n>>2]|0;J=c[O>>2]|0;o=c[j>>2]|0;G=o+(L>>>3)|0;H=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(L&7)>>>21;G=b[K+(H<<2)>>1]|0;F=(b[K+(H<<2)+2>>1]|0)+L|0;L=J>>>0>F>>>0?F:J;c[n>>2]=L;if(G<<16>>16==-1){F=c[P>>2]|0;H=o+(L>>>3)|0;K=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(L&7)>>>21;H=b[F+(K<<2)>>1]|0;m=b[F+(K<<2)+2>>1]|0;K=m<<16>>16;do{if(m<<16>>16<0){i=L+11|0;B=J>>>0>i>>>0?i:J;i=o+(B>>>3)|0;t=((fe(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(B&7)>>>((K+32|0)>>>0))+(H<<16>>16)|0;i=b[F+(t<<2)>>1]|0;y=b[F+(t<<2)+2>>1]|0;t=y<<16>>16;if(y<<16>>16<0){y=B-K|0;r=J>>>0>y>>>0?y:J;y=o+(r>>>3)|0;w=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(r&7)>>>((t+32|0)>>>0))+(i<<16>>16)|0;Q=b[F+(w<<2)+2>>1]|0;R=b[F+(w<<2)>>1]&255;S=r;break}else{Q=t;R=i&255;S=B;break}}else{Q=K;R=H&255;S=L}}while(0);L=Q+S|0;c[n>>2]=J>>>0>L>>>0?L:J;L=p<<2;a[(c[N>>2]|0)+L|0]=R;H=c[l>>2]|0;K=c[n>>2]|0;F=c[O>>2]|0;m=c[j>>2]|0;v=m+(K>>>3)|0;s=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(K&7)>>>21;v=b[H+(s<<2)>>1]|0;A=b[H+(s<<2)+2>>1]|0;s=A<<16>>16;B=v&255;do{if(A<<16>>16<0){i=K+11|0;t=F>>>0>i>>>0?i:F;i=m+(t>>>3)|0;r=((fe(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(t&7)>>>((s+32|0)>>>0))+(v<<16>>16)|0;i=b[H+(r<<2)>>1]|0;w=b[H+(r<<2)+2>>1]|0;r=w<<16>>16;if(!(w<<16>>16<0)){T=r;U=i&255;V=t;break}w=t-s|0;t=F>>>0>w>>>0?w:F;w=m+(t>>>3)|0;y=((fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(t&7)>>>((r+32|0)>>>0))+(i<<16>>16)|0;T=b[H+(y<<2)+2>>1]|0;U=b[H+(y<<2)>>1]&255;V=t}else{T=s;U=B;V=K}}while(0);K=T+V|0;c[n>>2]=F>>>0>K>>>0?K:F;a[(c[N>>2]|0)+(L|1)|0]=U;K=c[k>>2]|0;B=c[n>>2]|0;s=c[O>>2]|0;H=c[j>>2]|0;m=H+(B>>>3)|0;v=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>21;m=b[K+(v<<2)>>1]|0;A=b[K+(v<<2)+2>>1]|0;v=A<<16>>16;J=m&255;do{if(A<<16>>16<0){t=B+11|0;y=s>>>0>t>>>0?t:s;t=H+(y>>>3)|0;i=((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(y&7)>>>((v+32|0)>>>0))+(m<<16>>16)|0;t=b[K+(i<<2)>>1]|0;r=b[K+(i<<2)+2>>1]|0;i=r<<16>>16;if(!(r<<16>>16<0)){W=i;X=t&255;Y=y;break}r=y-v|0;y=s>>>0>r>>>0?r:s;r=H+(y>>>3)|0;w=((fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(y&7)>>>((i+32|0)>>>0))+(t<<16>>16)|0;W=b[K+(w<<2)+2>>1]|0;X=b[K+(w<<2)>>1]&255;Y=y}else{W=v;X=J;Y=B}}while(0);B=W+Y|0;c[n>>2]=s>>>0>B>>>0?B:s;a[(c[N>>2]|0)+(L|2)|0]=X;Z=c[j>>2]|0}else{c[(c[N>>2]|0)+(p<<2)>>2]=c[e+852128+(G<<16>>16<<2)>>2];Z=o}B=c[k>>2]|0;J=c[n>>2]|0;v=c[O>>2]|0;K=Z+(J>>>3)|0;H=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(J&7)>>>21;K=b[B+(H<<2)>>1]|0;m=b[B+(H<<2)+2>>1]|0;H=m<<16>>16;do{if(m<<16>>16<0){A=J+11|0;F=v>>>0>A>>>0?A:v;A=Z+(F>>>3)|0;y=((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(F&7)>>>((H+32|0)>>>0))+(K<<16>>16)|0;A=b[B+(y<<2)>>1]|0;w=b[B+(y<<2)+2>>1]|0;y=w<<16>>16;if(w<<16>>16<0){w=F-H|0;t=v>>>0>w>>>0?w:v;w=Z+(t>>>3)|0;i=((fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(t&7)>>>((y+32|0)>>>0))+(A<<16>>16)|0;_=b[B+(i<<2)+2>>1]|0;$=b[B+(i<<2)>>1]&255;aa=t;break}else{_=y;$=A&255;aa=F;break}}else{_=H;$=K&255;aa=J}}while(0);J=_+aa|0;c[n>>2]=v>>>0>J>>>0?J:v;a[(c[N>>2]|0)+(p<<2|3)|0]=$;p=p+1|0;}while((p|0)<(f|0));return}else{if(g){if(!h){return}g=e+860404|0;p=e+16|0;$=e+24|0;N=e+8|0;n=e+860324|0;aa=e+132|0;_=e+860344|0;Z=e+860364|0;O=0;do{k=c[g>>2]|0;j=c[p>>2]|0;X=c[$>>2]|0;Y=c[N>>2]|0;W=Y+(j>>>3)|0;U=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(j&7)>>>21;W=b[k+(U<<2)>>1]|0;V=(b[k+(U<<2)+2>>1]|0)+j|0;j=X>>>0>V>>>0?V:X;c[p>>2]=j;if(W<<16>>16==-1){V=c[_>>2]|0;U=Y+(j>>>3)|0;k=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(j&7)>>>21;U=b[V+(k<<2)>>1]|0;T=b[V+(k<<2)+2>>1]|0;k=T<<16>>16;do{if(T<<16>>16<0){l=j+11|0;R=X>>>0>l>>>0?l:X;l=Y+(R>>>3)|0;S=((fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(R&7)>>>((k+32|0)>>>0))+(U<<16>>16)|0;l=b[V+(S<<2)>>1]|0;Q=b[V+(S<<2)+2>>1]|0;S=Q<<16>>16;if(Q<<16>>16<0){Q=R-k|0;P=X>>>0>Q>>>0?Q:X;Q=Y+(P>>>3)|0;q=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(P&7)>>>((S+32|0)>>>0))+(l<<16>>16)|0;ba=b[V+(q<<2)+2>>1]|0;ca=b[V+(q<<2)>>1]&255;da=P;break}else{ba=S;ca=l&255;da=R;break}}else{ba=k;ca=U&255;da=j}}while(0);j=ba+da|0;c[p>>2]=X>>>0>j>>>0?j:X;j=O<<2;U=j|1;a[(c[aa>>2]|0)+U|0]=ca;k=c[n>>2]|0;V=c[p>>2]|0;Y=c[$>>2]|0;T=c[N>>2]|0;v=T+(V>>>3)|0;R=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(V&7)>>>21;v=b[k+(R<<2)>>1]|0;l=b[k+(R<<2)+2>>1]|0;R=l<<16>>16;do{if(l<<16>>16<0){S=V+11|0;P=Y>>>0>S>>>0?S:Y;S=T+(P>>>3)|0;q=((fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(P&7)>>>((R+32|0)>>>0))+v|0;S=b[k+(q<<2)>>1]|0;Q=b[k+(q<<2)+2>>1]|0;q=Q<<16>>16;if(!(Q<<16>>16<0)){ea=q;fa=S;ga=P;break}Q=P-R|0;P=Y>>>0>Q>>>0?Q:Y;Q=T+(P>>>3)|0;J=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(P&7)>>>((q+32|0)>>>0))+S|0;ea=b[k+(J<<2)+2>>1]|0;fa=b[k+(J<<2)>>1]|0;ga=P}else{ea=R;fa=v;ga=V}}while(0);V=ea+ga|0;c[p>>2]=Y>>>0>V>>>0?V:Y;V=c[aa>>2]|0;a[V+j|0]=(d[V+U|0]|0)+fa;V=c[Z>>2]|0;v=c[p>>2]|0;R=c[$>>2]|0;k=c[N>>2]|0;T=k+(v>>>3)|0;l=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(v&7)>>>21;T=b[V+(l<<2)>>1]|0;X=b[V+(l<<2)+2>>1]|0;l=X<<16>>16;do{if(X<<16>>16<0){P=v+11|0;J=R>>>0>P>>>0?P:R;P=k+(J>>>3)|0;S=((fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(J&7)>>>((l+32|0)>>>0))+T|0;P=b[V+(S<<2)>>1]|0;q=b[V+(S<<2)+2>>1]|0;S=q<<16>>16;if(!(q<<16>>16<0)){ha=S;ia=P;ja=J;break}q=J-l|0;J=R>>>0>q>>>0?q:R;q=k+(J>>>3)|0;Q=((fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(J&7)>>>((S+32|0)>>>0))+P|0;ha=b[V+(Q<<2)+2>>1]|0;ia=b[V+(Q<<2)>>1]|0;ja=J}else{ha=l;ia=T;ja=v}}while(0);v=ha+ja|0;c[p>>2]=R>>>0>v>>>0?v:R;v=c[aa>>2]|0;a[v+(j|2)|0]=(d[v+U|0]|0)+ia}else{c[(c[aa>>2]|0)+(O<<2)>>2]=c[e+852128+(W<<16>>16<<2)>>2]}O=O+1|0;}while((O|0)<(f|0));return}if(!h){return}h=e+860404|0;O=e+16|0;aa=e+24|0;ia=e+8|0;p=e+860324|0;ja=e+132|0;ha=e+860344|0;N=e+860364|0;$=0;do{Z=c[h>>2]|0;fa=c[O>>2]|0;ga=c[aa>>2]|0;ea=c[ia>>2]|0;n=ea+(fa>>>3)|0;ca=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(fa&7)>>>21;n=b[Z+(ca<<2)>>1]|0;da=(b[Z+(ca<<2)+2>>1]|0)+fa|0;fa=ga>>>0>da>>>0?da:ga;c[O>>2]=fa;if(n<<16>>16==-1){da=c[ha>>2]|0;ca=ea+(fa>>>3)|0;Z=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(fa&7)>>>21;ca=b[da+(Z<<2)>>1]|0;ba=b[da+(Z<<2)+2>>1]|0;Z=ba<<16>>16;do{if(ba<<16>>16<0){_=fa+11|0;g=ga>>>0>_>>>0?_:ga;_=ea+(g>>>3)|0;v=((fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(g&7)>>>((Z+32|0)>>>0))+(ca<<16>>16)|0;_=b[da+(v<<2)>>1]|0;T=b[da+(v<<2)+2>>1]|0;v=T<<16>>16;if(T<<16>>16<0){T=g-Z|0;l=ga>>>0>T>>>0?T:ga;T=ea+(l>>>3)|0;V=((fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(l&7)>>>((v+32|0)>>>0))+(_<<16>>16)|0;ka=b[da+(V<<2)+2>>1]|0;la=b[da+(V<<2)>>1]&255;ma=l;break}else{ka=v;la=_&255;ma=g;break}}else{ka=Z;la=ca&255;ma=fa}}while(0);fa=ka+ma|0;c[O>>2]=ga>>>0>fa>>>0?fa:ga;fa=$<<2;ca=fa|1;a[(c[ja>>2]|0)+ca|0]=la;Z=c[p>>2]|0;da=c[O>>2]|0;ba=c[aa>>2]|0;W=c[ia>>2]|0;U=W+(da>>>3)|0;j=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(da&7)>>>21;U=b[Z+(j<<2)>>1]|0;R=b[Z+(j<<2)+2>>1]|0;j=R<<16>>16;do{if(R<<16>>16<0){g=da+11|0;_=ba>>>0>g>>>0?g:ba;g=W+(_>>>3)|0;v=((fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(_&7)>>>((j+32|0)>>>0))+U|0;g=b[Z+(v<<2)>>1]|0;l=b[Z+(v<<2)+2>>1]|0;v=l<<16>>16;if(!(l<<16>>16<0)){na=v;oa=g;pa=_;break}l=_-j|0;_=ba>>>0>l>>>0?l:ba;l=W+(_>>>3)|0;V=((fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(_&7)>>>((v+32|0)>>>0))+g|0;na=b[Z+(V<<2)+2>>1]|0;oa=b[Z+(V<<2)>>1]|0;pa=_}else{na=j;oa=U;pa=da}}while(0);da=na+pa|0;c[O>>2]=ba>>>0>da>>>0?da:ba;da=c[ja>>2]|0;a[da+fa|0]=(d[da+ca|0]|0)+oa;da=c[N>>2]|0;U=c[O>>2]|0;j=c[aa>>2]|0;Z=c[ia>>2]|0;W=Z+(U>>>3)|0;R=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(U&7)>>>21;W=b[da+(R<<2)>>1]|0;ga=b[da+(R<<2)+2>>1]|0;R=ga<<16>>16;do{if(ga<<16>>16<0){_=U+11|0;V=j>>>0>_>>>0?_:j;_=Z+(V>>>3)|0;g=((fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(V&7)>>>((R+32|0)>>>0))+W|0;_=b[da+(g<<2)>>1]|0;v=b[da+(g<<2)+2>>1]|0;g=v<<16>>16;if(!(v<<16>>16<0)){qa=g;ra=_;sa=V;break}v=V-R|0;V=j>>>0>v>>>0?v:j;v=Z+(V>>>3)|0;l=((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(V&7)>>>((g+32|0)>>>0))+_|0;qa=b[da+(l<<2)+2>>1]|0;ra=b[da+(l<<2)>>1]|0;sa=V}else{qa=R;ra=W;sa=U}}while(0);U=qa+sa|0;c[O>>2]=j>>>0>U>>>0?U:j;U=c[ja>>2]|0;a[U+(fa|2)|0]=(d[U+ca|0]|0)+ra;ta=c[ia>>2]|0}else{c[(c[ja>>2]|0)+($<<2)>>2]=c[e+852128+(n<<16>>16<<2)>>2];ta=ea}U=c[N>>2]|0;W=c[O>>2]|0;R=c[aa>>2]|0;da=ta+(W>>>3)|0;Z=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(W&7)>>>21;da=b[U+(Z<<2)>>1]|0;ga=b[U+(Z<<2)+2>>1]|0;Z=ga<<16>>16;do{if(ga<<16>>16<0){ba=W+11|0;V=R>>>0>ba>>>0?ba:R;ba=ta+(V>>>3)|0;l=((fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(V&7)>>>((Z+32|0)>>>0))+(da<<16>>16)|0;ba=b[U+(l<<2)>>1]|0;_=b[U+(l<<2)+2>>1]|0;l=_<<16>>16;if(_<<16>>16<0){_=V-Z|0;g=R>>>0>_>>>0?_:R;_=ta+(g>>>3)|0;v=((fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(g&7)>>>((l+32|0)>>>0))+(ba<<16>>16)|0;ua=b[U+(v<<2)+2>>1]|0;va=b[U+(v<<2)>>1]&255;wa=g;break}else{ua=l;va=ba&255;wa=V;break}}else{ua=Z;va=da&255;wa=W}}while(0);W=ua+wa|0;c[O>>2]=R>>>0>W>>>0?W:R;a[(c[ja>>2]|0)+($<<2|3)|0]=va;$=$+1|0;}while(($|0)<(f|0));return}}function DGa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;if((e|0)<=0){g=0;i=f;return g|0}h=b+8|0;j=b+16|0;k=b|0;l=b+12|0;b=0;while(1){m=c[h>>2]|0;n=c[j>>2]|0;o=c[k>>2]|0;p=o+(m>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>29;p=m+3|0;m=n>>>0>p>>>0?p:n;c[h>>2]=m;p=o+(m>>>3)|0;r=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>27;p=m+5|0;m=n>>>0>p>>>0?p:n;c[h>>2]=m;if((q|0)==0){p=o+(m>>>3)|0;o=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>24;p=m+8|0;s=n>>>0>p>>>0?p:n;c[h>>2]=s;t=o;u=s}else{t=q;u=m}m=t+b|0;if((m|0)>(e|0)){break}if(((c[l>>2]|0)-u|0)<0){break}if((t|0)==0){v=b}else{TGb(a+b|0,r&255|0,t|0)|0;v=m}if((v|0)<(e|0)){b=v}else{g=0;w=11;break}}if((w|0)==11){i=f;return g|0}yDb(0,16,2352520,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;g=-1;i=f;return g|0}function EGa(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+10240|0;f=e|0;g=e+4096|0;h=e+8192|0;j=d+64|0;do{if((c[d+60>>2]|0)<24){k=3}else{if((c[j>>2]|0)>2){k=3;break}l=d+56|0;m=c[l>>2]|0;n=(m|0)==0|0;o=-16;p=0;a:while(1){q=o&255;r=a[d+524448+(m<<14)+q|0]|0;s=11-(r&255)|0;if((s|0)<2|r<<24>>24==0){t=p}else{u=d+589984+(m<<16)+(q<<2)|0;q=o&255;v=-16;w=p;while(1){x=v&255;y=a[d+524448+(n<<14)+x|0]|0;z=y&255;A=s-z|0;if((A|0)<1|y<<24>>24==0){B=w}else{C=(c[u>>2]<<z)+(c[d+589984+(n<<16)+(x<<2)>>2]|0)|0;x=y+r&255;y=v&255;z=v+o&255;D=-16;E=w;while(1){F=D&255;G=a[d+557216+F|0]|0;H=G&255;if((H|0)<=(A|0)&G<<24>>24!=0){if((E|0)>=2048){k=24;break a}a[h+E|0]=x+G;b[g+(E<<1)>>1]=(c[d+721056+(F<<2)>>2]|0)+(C<<H);H=d+852128+(E<<2)|0;F=H;if((c[l>>2]|0)==0){a[H]=q;a[F+1|0]=y;a[F+2|0]=D}else{a[F+1|0]=q;a[H]=z;a[F+2|0]=D+o}I=E+1|0}else{I=E}F=D+1|0;if((F|0)<16){D=F;E=I}else{B=I;break}}}E=v+1|0;if((E|0)<16){v=E;w=B}else{t=B;break}}}w=o+1|0;if((w|0)<16){o=w;p=t}else{break}}if((k|0)==24){yDb(0,0,1940080,(J=i,i=i+24|0,c[J>>2]=1915912,c[J+8>>2]=1895336,c[J+16>>2]=172,J)|0);i=J;Cd();return 0}p=d+860400|0;Q_(p);o=N_(p,11,t,h|0,1,1,g,2,2,0,0,0,0)|0;if((o|0)<0){K=o}else{break}i=e;return K|0}}while(0);b:do{if((k|0)==3){t=d+84|0;B=h|0;I=g;o=f;p=0;c:while(1){if((p|0)>=4){break b}l=(c[j>>2]|0)>2?p:0;n=c[t>>2]|0;if((n|0)>0){m=0;w=0;while(1){v=a[d+524448+(l<<14)+m|0]|0;q=11-(v&255)|0;do{if((q|0)<1|v<<24>>24==0){L=w}else{r=n-1|0;if((r&m<<24>>24|0)!=(m|0)){L=w;break}u=d+589984+(l<<16)+(m<<2)|0;s=m<<8;E=0;D=w;while(1){z=a[d+524448+(p<<14)+E|0]|0;y=z&255;do{if((y|0)<=(q|0)&z<<24>>24!=0){if((r&E<<24>>24|0)!=(E|0)){M=D;break}if((D|0)>=2048){k=12;break c}a[h+D|0]=z+v;b[g+(D<<1)>>1]=(c[u>>2]<<y)+(c[d+589984+(p<<16)+(E<<2)>>2]|0);C=E&255|s;b[f+(D<<1)>>1]=C;M=((C&65535|0)!=65535)+D|0}else{M=D}}while(0);y=E+1|0;if((y|0)<(n|0)){E=y;D=M}else{L=M;break}}}}while(0);v=m+1|0;if((v|0)<(n|0)){m=v;w=L}else{N=L;break}}}else{N=0}w=d+860320+((p+4|0)*20|0)|0;Q_(w);m=N_(w,11,N,B,1,1,I,2,2,o,2,2,0)|0;if((m|0)<0){K=m;k=34;break}else{p=p+1|0}}if((k|0)==12){yDb(0,0,1940080,(J=i,i=i+24|0,c[J>>2]=1915912,c[J+8>>2]=1895336,c[J+16>>2]=136,J)|0);i=J;Cd();return 0}else if((k|0)==34){i=e;return K|0}}}while(0);K=0;i=e;return K|0}function FGa(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;f=i;i=i+8|0;g=f|0;h=c[b+60>>2]|0;j=h;k=b+140|0;l=bFb(c[k>>2]|0)|0;jlb(b);m=cEb(196612)|0;n=b+96|0;c[n>>2]=m;if((m|0)==0){o=-12;i=f;return o|0}m=h+116|0;do{if((c[m>>2]&512|0)!=0){p=cEb(4128772)|0;c[b+668>>2]=p;if((p|0)==0){o=-12}else{break}i=f;return o|0}}while(0);p=h+64|0;c[p>>2]=2;q=ICb()|0;c[b+804>>2]=q;if((q|0)==0){o=-12;i=f;return o|0}c[q+88>>2]=1;c[q+84>>2]=1;q=h+76|0;c[q>>2]=((e[l+8>>1]|0)>>>11&15)+1;r=l+7|0;s=l+4|0;if((a[r]&32)==0){t=(d[s]|0)>>>0>1>>>0|0}else{t=0}l=h+96|0;c[l>>2]=t;t=h+92|0;c[t>>2]=(d[s]|0)>>>0>2>>>0;s=h+88|0;c[s>>2]=(d[r]|0)>>>7&255;u=h+100|0;v=h+104|0;eFb(c[k>>2]|0,u,v)|0;w=c[k>>2]|0;a:do{switch(w|0){case 5:case 6:case 7:case 33:case 82:case 84:case 86:case 314:case 316:case 88:case 8:case 32:case 299:case 35:case 300:case 317:case 66:case 70:case 72:case 302:case 304:case 54:case 80:case 74:case 306:case 308:case 56:case 76:case 78:case 310:case 312:case 58:case 92:case 98:case 104:case 94:case 100:case 106:case 96:case 102:case 108:{c[p>>2]=3;x=c[h+60>>2]|0;break};case 0:case 4:{if((c[h+108>>2]&1|0)==0){k=(w|0)==0?12:16;c[h+60>>2]=k;x=k;break a}yDb(b,16,2307968,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0};case 30:{c[h+60>>2]=32;x=32;break};case 2:{c[h+60>>2]=24;x=24;break};default:{yDb(b,16,2289440,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}}}while(0);k=1<<c[q>>2];c[h+80>>2]=k;z=h+84|0;c[z>>2]=(k|0)>16384?16384:k;k=h+60|0;c[b+792>>2]=x;do{if((c[k>>2]|0)>23){if((c[l>>2]|0)!=0){A=0;break}A=((d[r]|0)>>>4&1^1)&255}else{A=0}}while(0);r=h+56|0;c[r>>2]=A;A=h+4|0;c[A>>2]=c[b+216>>2];x=(c[b+88>>2]|0)>>>29;B=h+52|0;c[B>>2]=x&1;C=b+572|0;D=h+120|0;do{if((c[C>>2]|0)==1){c[D>>2]=1;if((c[m>>2]&1536|0)==0){break}yDb(b,16,2273424,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}else{c[D>>2]=0}}while(0);do{if((c[(c[b+12>>2]|0)+12>>2]|0)==26){if((w|0)==0){yDb(b,16,2257792,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}if((c[C>>2]|0)!=0){yDb(b,16,2243536,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}if((c[p>>2]|0)>2){yDb(b,16,2231056,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}else{if(!((c[h+112>>2]|0)>288^(x&1|0)!=0)){break}yDb(b,32,2218984,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;break}}}while(0);x=c[p>>2]|0;do{if((x|0)>2){if(!((c[b+680>>2]|0)>-2)){break}yDb(b,16,2209528,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}}while(0);C=c[A>>2]|0;do{if((c[k>>2]|0)>23&(C|0)==2){if((x|0)>=3){E=2;break}yDb(b,16,2200920,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}else{E=C}}while(0);a[c[n>>2]|0]=c[r>>2]<<6|E;a[(c[n>>2]|0)+2|0]=(c[B>>2]|0)!=0?16:32;if((c[D>>2]|0)!=0){B=(c[n>>2]|0)+2|0;a[B]=a[B]|64}if((c[p>>2]|0)<3){a[(c[n>>2]|0)+1|0]=c[k>>2];a[(c[n>>2]|0)+3|0]=0}else{a[(c[n>>2]|0)+1|0]=(c[q>>2]<<4)+240|c[u>>2]|c[v>>2]<<2;if((c[t>>2]|0)!=0){t=(c[n>>2]|0)+2|0;a[t]=a[t]|((c[l>>2]|0)!=0?1:2)}if((c[s>>2]|0)!=0){s=(c[n>>2]|0)+2|0;a[s]=a[s]|4}a[(c[n>>2]|0)+3|0]=1}n=h;c[(c[n>>2]|0)+100>>2]=4;s=c[b+672>>2]|0;b=h+160|0;l=c[z>>2]|0;t=(l|0)>0;b:do{if((s|0)==0){if(t){G=0;H=l}else{break}do{v=H-G|0;u=1e8/(((G|0)>(v|0)?v:G)+1|0)|0;v=b+(G<<3)|0;c[v>>2]=u;c[v+4>>2]=(u|0)<0|0?-1:0;G=G+1|0;H=c[z>>2]|0;}while((G|0)<(H|0));if((H|0)>0){I=0;J=H}else{break}do{u=J-I|0;v=1e8/(((I|0)>(u|0)?u:I)+1|0)|0;u=b+131072+(I<<3)|0;c[u>>2]=v;c[u+4>>2]=(v|0)<0|0?-1:0;I=I+1|0;J=c[z>>2]|0;}while((I|0)<(J|0));if((J|0)>0){K=0;L=J}else{break}do{v=L-K|0;u=1e8/(((K|0)>(v|0)?v:K)+1|0)|0;v=b+262144+(K<<3)|0;c[v>>2]=u;c[v+4>>2]=(u|0)<0|0?-1:0;K=K+1|0;L=c[z>>2]|0;}while((K|0)<(L|0));if((L|0)>0){M=0;N=L}else{break}do{u=N-M|0;v=1e8/(((M|0)>(u|0)?u:M)+1|0)|0;u=b+393216+(M<<3)|0;c[u>>2]=v;c[u+4>>2]=(v|0)<0|0?-1:0;M=M+1|0;N=c[z>>2]|0;}while((M|0)<(N|0))}else{do{if(t){v=0;do{u=b+(v<<3)|0;c[u>>2]=1;c[u+4>>2]=0;v=v+1|0;O=c[z>>2]|0;}while((v|0)<(O|0));if((O|0)>0){P=0}else{Q=0;R=s;S=O;break}do{v=b+131072+(P<<3)|0;c[v>>2]=1;c[v+4>>2]=0;P=P+1|0;T=c[z>>2]|0;}while((P|0)<(T|0));if((T|0)>0){U=0}else{Q=0;R=s;S=T;break}do{v=b+262144+(U<<3)|0;c[v>>2]=1;c[v+4>>2]=0;U=U+1|0;V=c[z>>2]|0;}while((U|0)<(V|0));if((V|0)>0){W=0}else{Q=0;R=s;S=V;break}while(1){v=b+393216+(W<<3)|0;c[v>>2]=1;c[v+4>>2]=0;v=W+1|0;u=c[z>>2]|0;if((v|0)<(u|0)){W=v}else{Q=0;R=s;S=u;break}}}else{Q=0;R=s;S=l}}while(0);c:while(1){u=R+1|0;v=R+2|0;q=Q;while(1){if((q|0)<4){X=0;Y=R;Z=S;break}if((a[R]|0)==0){break b}if((a[u]|0)==0){break b}if((a[v]|0)==0){break b}else{q=0}}while(1){if((X|0)>=(Z|0)){break}v=kb(Y|0,g|0,0)|0;u=b+(q<<17)+(X<<3)|0;k=YGb(c[u>>2]|0,c[u+4>>2]|0,v,(v|0)<0|0?-1:0)|0;c[u>>2]=k;c[u+4>>2]=F;u=c[g>>2]|0;if((u|0)==(Y|0)){o=-1;break c}X=X+1|0;Y=u;Z=c[z>>2]|0}Q=q+1|0;R=Y;S=Z}i=f;return o|0}}while(0);Z=c[n>>2]|0;S=IGa(j,(c[Z+96>>2]|0)+(c[Z+100>>2]|0)|0)|0;if((S|0)<0){o=S;i=f;return o|0}Z=(c[n>>2]|0)+100|0;c[Z>>2]=(c[Z>>2]|0)+S;do{if((c[D>>2]|0)==0){S=h+160|0;if((c[z>>2]|0)>0){_=0}else{break}do{Z=S+(_<<3)|0;c[Z>>2]=0;c[Z+4>>2]=0;_=_+1|0;$=c[z>>2]|0;}while((_|0)<($|0));if(($|0)>0){aa=0}else{break}do{Z=S+131072+(aa<<3)|0;c[Z>>2]=0;c[Z+4>>2]=0;aa=aa+1|0;ca=c[z>>2]|0;}while((aa|0)<(ca|0));if((ca|0)>0){da=0}else{break}do{Z=S+262144+(da<<3)|0;c[Z>>2]=0;c[Z+4>>2]=0;da=da+1|0;ea=c[z>>2]|0;}while((da|0)<(ea|0));if((ea|0)>0){fa=0}else{break}do{Z=S+393216+(fa<<3)|0;c[Z>>2]=0;c[Z+4>>2]=0;fa=fa+1|0;}while((fa|0)<(c[z>>2]|0))}else{S=h+108|0;Z=h+112|0;n=h+160|0;Y=(ba(c[Z>>2]|0,c[S>>2]|0)|0)/10|0;R=c[z>>2]|0;if((R|0)>0){ga=0;ha=R}else{break}do{R=ha-ga|0;Q=(Y|0)/(((ga|0)>(R|0)?R:ga)+1|0)|0;R=n+(ga<<3)|0;c[R>>2]=Q;c[R+4>>2]=(Q|0)<0|0?-1:0;ga=ga+1|0;ha=c[z>>2]|0;}while((ga|0)<(ha|0));Y=(ba(c[Z>>2]|0,c[S>>2]|0)|0)/40|0;if((ha|0)>0){ia=0;ja=ha}else{break}do{Q=ja-ia|0;R=(Y|0)/(((ia|0)>(Q|0)?Q:ia)+1|0)|0;Q=n+131072+(ia<<3)|0;c[Q>>2]=R;c[Q+4>>2]=(R|0)<0|0?-1:0;ia=ia+1|0;ja=c[z>>2]|0;}while((ia|0)<(ja|0));Y=(ba(c[Z>>2]|0,c[S>>2]|0)|0)/40|0;if((ja|0)>0){ka=0;la=ja}else{break}do{R=la-ka|0;Q=(Y|0)/(((ka|0)>(R|0)?R:ka)+1|0)|0;R=n+262144+(ka<<3)|0;c[R>>2]=Q;c[R+4>>2]=(Q|0)<0|0?-1:0;ka=ka+1|0;la=c[z>>2]|0;}while((ka|0)<(la|0));Y=(ba(c[Z>>2]|0,c[S>>2]|0)|0)/40|0;if((la|0)>0){ma=0;na=la}else{break}do{Q=na-ma|0;R=(Y|0)/(((ma|0)>(Q|0)?Q:ma)+1|0)|0;Q=n+393216+(ma<<3)|0;c[Q>>2]=R;c[Q+4>>2]=(R|0)<0|0?-1:0;ma=ma+1|0;na=c[z>>2]|0;}while((ma|0)<(na|0))}}while(0);if((ilb(j)|0)==0){c[h+124>>2]=0;o=0;i=f;return o|0}else{klb(j);o=-12;i=f;return o|0}return 0}function GGa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0;j=i;i=i+64|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=j+48|0;r=j+56|0;s=c[e+60>>2]|0;t=s;u=c[s+108>>2]|0;v=u>>1;w=s+112|0;y=c[w>>2]|0;z=s+52|0;A=g+32|0;B=(c[z>>2]|0)!=0|0;C=c[A>>2]<<B;D=g+36|0;E=c[D>>2]<<B;F=g+40|0;G=c[F>>2]<<B;B=(ba(u*12|0,y)|0)+16384|0;H=r0a(e,f,B,(B|0)<0|0?-1:0)|0;if((H|0)<0){I=H;i=j;return I|0}H=f+24|0;do{if((c[s+120>>2]|0)==0){J=0}else{B=IGa(t,c[H>>2]|0)|0;if((B|0)<0){I=B;i=j;return I|0}K=s+84|0;L=s+160|0;if((c[K>>2]|0)>0){M=0}else{J=B;break}do{N=L+(M<<3)|0;O=c[N+4>>2]|0;c[N>>2]=(c[N>>2]|0)>>>1|O<<31;c[N+4>>2]=O>>>1|0<<31;M=M+1|0;P=c[K>>2]|0;}while((M|0)<(P|0));if((P|0)>0){Q=0}else{J=B;break}do{O=L+131072+(Q<<3)|0;N=c[O+4>>2]|0;c[O>>2]=(c[O>>2]|0)>>>1|N<<31;c[O+4>>2]=N>>>1|0<<31;Q=Q+1|0;R=c[K>>2]|0;}while((Q|0)<(R|0));if((R|0)>0){S=0}else{J=B;break}do{N=L+262144+(S<<3)|0;O=c[N+4>>2]|0;c[N>>2]=(c[N>>2]|0)>>>1|O<<31;c[N+4>>2]=O>>>1|0<<31;S=S+1|0;T=c[K>>2]|0;}while((S|0)<(T|0));if((T|0)>0){U=0}else{J=B;break}while(1){O=L+393216+(U<<3)|0;N=c[O+4>>2]|0;c[O>>2]=(c[O>>2]|0)>>>1|N<<31;c[O+4>>2]=N>>>1|0<<31;N=U+1|0;if((N|0)<(c[K>>2]|0)){U=N}else{J=B;break}}}}while(0);U=f+28|0;T=(c[U>>2]|0)-J|0;S=(T|0)<0;R=S?0:(c[H>>2]|0)+J|0;Q=S?0:T;c[s+48>>2]=Q<<3;T=s+36|0;c[T>>2]=R;c[s+44>>2]=R+Q;Q=s+40|0;c[Q>>2]=R;S=s+32|0;c[S>>2]=32;P=s+28|0;c[P>>2]=0;M=c[e+140>>2]|0;a:do{if((M|0)==4|(M|0)==0){B=g+8|0;K=d[c[B>>2]|0]|0;c[m>>2]=K;L=c[P>>2]|0;N=c[S>>2]|0;if((N|0)>8){V=N-8|0;W=L<<8|K;X=R}else{O=R;x=fe(K>>>((8-N|0)>>>0)|L<<N|0)|0;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;O=(c[Q>>2]|0)+4|0;c[Q>>2]=O;V=N+24|0;W=K;X=O}c[P>>2]=W;c[S>>2]=V;O=g|0;K=d[(c[O>>2]|0)+1|0]|0;c[k>>2]=K;N=c[P>>2]|0;L=c[S>>2]|0;if((L|0)>8){Y=L-8|0;Z=N<<8|K;_=X}else{$=X;x=fe(K>>>((8-L|0)>>>0)|N<<L|0)|0;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;$=(c[Q>>2]|0)+4|0;c[Q>>2]=$;Y=L+24|0;Z=K;_=$}c[P>>2]=Z;c[S>>2]=Y;$=g+4|0;K=d[c[$>>2]|0]|0;c[l>>2]=K;L=c[P>>2]|0;N=c[S>>2]|0;if((N|0)>8){aa=N-8|0;ca=L<<8|K;da=_}else{ea=_;x=fe(K>>>((8-N|0)>>>0)|L<<N|0)|0;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;ea=(c[Q>>2]|0)+4|0;c[Q>>2]=ea;aa=N+24|0;ca=K;da=ea}c[P>>2]=ca;c[S>>2]=aa;ea=c[O>>2]|0;K=d[ea]|0;if((aa|0)>8){fa=aa-8|0;ga=ca<<8|K;ha=ea}else{ea=da;x=fe(K>>>((8-aa|0)>>>0)|ca<<aa|0)|0;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;fa=aa+24|0;ga=K;ha=c[O>>2]|0}c[P>>2]=ga;c[S>>2]=fa;K=s+132|0;c[k>>2]=JGa(t,c[K>>2]|0,ha,u,0)|0;ea=s+136|0;c[l>>2]=JGa(t,c[ea>>2]|0,c[$>>2]|0,v,0)|0;N=s+140|0;c[m>>2]=JGa(t,c[N>>2]|0,c[B>>2]|0,v,0)|0;KGa(t,2,u-2|0);L=s+4|0;if((c[L>>2]|0)!=2){if((y|0)<=1){break}ia=s+60|0;ja=s+861564|0;ka=1;la=1;while(1){if((c[ia>>2]|0)==12){ma=c[O>>2]|0;na=ba(c[A>>2]|0,la)|0;oa=ma+na|0;do{if((c[L>>2]|0)==1){if((c[z>>2]|0)>=(la|0)){pa=45;break}cf[c[ja>>2]&1023](c[ea>>2]|0,oa,ma+(na-C)|0,u);qa=JGa(t,c[K>>2]|0,c[ea>>2]|0,u,c[k>>2]|0)|0}else{pa=45}}while(0);if((pa|0)==45){pa=0;qa=JGa(t,c[K>>2]|0,oa,u,c[k>>2]|0)|0}c[k>>2]=qa;LGa(t,u);na=la+1|0;if((na|0)<(y|0)){ra=na}else{break a}}else{ra=la}na=c[O>>2]|0;ma=ba(c[A>>2]|0,ra)|0;sa=na+ma|0;ta=c[$>>2]|0;ua=ba(c[D>>2]|0,ka)|0;va=ta+ua|0;wa=c[B>>2]|0;xa=ba(c[F>>2]|0,ka)|0;ya=wa+xa|0;do{if((c[L>>2]|0)==1){if((c[z>>2]|0)>=(ka|0)){pa=50;break}cf[c[ja>>2]&1023](c[ea>>2]|0,sa,na+(ma-C)|0,u);cf[c[ja>>2]&1023](c[N>>2]|0,va,ta+(ua-E)|0,v);cf[c[ja>>2]&1023]((c[N>>2]|0)+v|0,ya,wa+(xa-G)|0,v);c[k>>2]=JGa(t,c[K>>2]|0,c[ea>>2]|0,u,c[k>>2]|0)|0;c[l>>2]=JGa(t,c[ea>>2]|0,c[N>>2]|0,v,c[l>>2]|0)|0;za=c[N>>2]|0;Aa=JGa(t,za,za+v|0,v,c[m>>2]|0)|0}else{pa=50}}while(0);if((pa|0)==50){pa=0;c[k>>2]=JGa(t,c[K>>2]|0,sa,u,c[k>>2]|0)|0;c[l>>2]=JGa(t,c[ea>>2]|0,va,v,c[l>>2]|0)|0;Aa=JGa(t,c[N>>2]|0,ya,v,c[m>>2]|0)|0}c[m>>2]=Aa;KGa(t,0,u);xa=ra+1|0;if((xa|0)<(y|0)){ka=ka+1|0;la=xa}else{break a}}}if((c[z>>2]|0)==0){Ba=2}else{c[k>>2]=JGa(t,c[K>>2]|0,(c[O>>2]|0)+(c[A>>2]|0)|0,u,c[k>>2]|0)|0;c[l>>2]=JGa(t,c[ea>>2]|0,(c[$>>2]|0)+(c[D>>2]|0)|0,v,c[l>>2]|0)|0;c[m>>2]=JGa(t,c[N>>2]|0,(c[B>>2]|0)+(c[F>>2]|0)|0,v,c[m>>2]|0)|0;KGa(t,0,u);Ba=3}la=c[K>>2]|0;ka=c[O>>2]|0;ja=c[k>>2]|0;L=s+76|0;ia=ka+C|0;if((c[L>>2]|0)<9){xa=a[ia]|0;a[la]=(xa&255)-ja;wa=a[ka+(C+1)|0]|0;a[la+1|0]=wa-xa;xa=a[ka+(C+2)|0]|0;a[la+2|0]=xa-wa;wa=a[ka+(C+3)|0]|0;a[la+3|0]=wa-xa;Ca=wa&255}else{wa=b[ia>>1]|0;b[la>>1]=(wa&65535)-ja;ja=b[ka+(C+2)>>1]|0;b[la+2>>1]=ja-wa;wa=b[ka+(C+4)>>1]|0;b[la+4>>1]=wa-ja;ja=b[ka+(C+6)>>1]|0;b[la+6>>1]=ja-wa;Ca=ja&65535}c[k>>2]=Ca;ja=c[ea>>2]|0;wa=c[$>>2]|0;la=c[l>>2]|0;ka=wa+E|0;if((c[L>>2]|0)<9){ia=a[ka]|0;a[ja]=(ia&255)-la;xa=a[wa+(E+1)|0]|0;a[ja+1|0]=xa-ia;Da=xa&255}else{xa=b[ka>>1]|0;b[ja>>1]=(xa&65535)-la;la=b[wa+(E+2)>>1]|0;b[ja+2>>1]=la-xa;Da=la&65535}c[l>>2]=Da;la=c[N>>2]|0;xa=c[B>>2]|0;ja=c[m>>2]|0;wa=xa+G|0;if((c[L>>2]|0)<9){L=a[wa]|0;a[la]=(L&255)-ja;ka=a[xa+(G+1)|0]|0;a[la+1|0]=ka-L;Ea=ka&255}else{ka=b[wa>>1]|0;b[la>>1]=(ka&65535)-ja;ja=b[xa+(G+2)>>1]|0;b[la+2>>1]=ja-ka;Ea=ja&65535}c[m>>2]=Ea;KGa(t,0,4);ja=c[O>>2]|0;c[n>>2]=d[ja+3|0]|0;c[o>>2]=d[(c[$>>2]|0)+1|0]|0;c[p>>2]=d[(c[B>>2]|0)+1|0]|0;ka=s+861568|0;la=u-4|0;Se[c[ka>>2]&511](c[K>>2]|0,ja+4|0,ja+(C+4)|0,la,k,n);ja=c[$>>2]|0;xa=v-2|0;Se[c[ka>>2]&511](c[ea>>2]|0,ja+2|0,ja+(E+2)|0,xa,l,o);ja=c[B>>2]|0;Se[c[ka>>2]&511](c[N>>2]|0,ja+2|0,ja+(G+2)|0,xa,m,p);KGa(t,0,la);if((Ba|0)>=(y|0)){break}la=s+60|0;xa=Ba;ja=Ba;wa=Ba<<1;while(1){if((c[la>>2]|0)==12){L=xa<<1;if((L|0)>(ja|0)){ia=ja;while(1){ua=c[O>>2]|0;ta=ba(c[A>>2]|0,ia)|0;Se[c[ka>>2]&511](c[K>>2]|0,ua+(ta-C)|0,ua+ta|0,u,k,n);LGa(t,u);ta=ia+1|0;if((L|0)>(ta|0)){ia=ta}else{Fa=wa;break}}}else{Fa=ja}if((Fa|0)<(y|0)){Ga=Fa}else{break a}}else{Ga=ja}ia=c[O>>2]|0;L=ba(c[A>>2]|0,Ga)|0;ya=c[$>>2]|0;va=ba(c[D>>2]|0,xa)|0;sa=c[B>>2]|0;ta=ba(c[F>>2]|0,xa)|0;Se[c[ka>>2]&511](c[K>>2]|0,ia+(L-C)|0,ia+L|0,u,k,n);Se[c[ka>>2]&511](c[ea>>2]|0,ya+(va-E)|0,ya+va|0,v,l,o);Se[c[ka>>2]&511](c[N>>2]|0,sa+(ta-G)|0,sa+ta|0,v,m,p);KGa(t,0,u);ta=Ga+1|0;if((ta|0)<(y|0)){xa=xa+1|0;ja=ta;wa=wa+2|0}else{break}}}else if((M|0)==30){wa=c[g>>2]|0;ja=c[A>>2]|0;xa=ba(ja,y-1|0)|0;N=a[wa+(xa+3)|0]|0;ka=N&255;c[P>>2]=ka;c[S>>2]=24;ea=a[wa+(xa+2)|0]|0;K=ka<<8|ea&255;c[P>>2]=K;c[S>>2]=16;ka=a[wa+(xa+1)|0]|0;B=K<<8|ka&255;c[P>>2]=B;c[S>>2]=8;K=a[wa+xa|0]|0;$=K&255;O=R;x=fe($|B<<8|0)|0;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;c[P>>2]=$;c[S>>2]=32;$=s+132|0;O=c[$>>2]|0;B=xa+4|0;la=u-1|0;ta=(la|0)>4?4:la;if((ta|0)>0){sa=N;N=K;K=ka;ka=ea;ea=0;while(1){va=ea<<2;ya=va|2;L=a[wa+(ya+B)|0]|0;ia=va|1;ua=a[wa+(ia+B)|0]|0;ma=a[wa+(va+B)|0]|0;na=va|3;oa=a[wa+(na+B)|0]|0;a[O+ya|0]=L-ka;a[O+ia|0]=ua-K;a[O+va|0]=ma-N;a[O+na|0]=oa-sa;na=ea+1|0;if((na|0)<(ta|0)){sa=oa;N=ma;K=ua;ka=L;ea=na}else{break}}}ea=s+861564|0;ka=la<<2;cf[c[ea>>2]&1023](O+16|0,wa+(xa+20)|0,wa+(xa+16)|0,ka-16|0);K=a[wa+(ka-2+B)|0]|0;N=a[wa+(ka-3+B)|0]|0;sa=a[wa+(xa+ka)|0]|0;ta=a[wa+(ka-1+B)|0]|0;MGa(t,la,4);if((c[w>>2]|0)<=1){break}ka=s+4|0;na=s+136|0;L=u<<2;ua=(u|0)>4?4:u;ma=(ua|0)>0;oa=L-16|0;va=L-4|0;ia=L-2|0;ya=L-3|0;za=L-1|0;Ha=K;K=N;N=sa;sa=ta;ta=1;do{Ia=xa-(ba(ta,ja)|0)|0;Ja=wa+Ia|0;do{if((c[ka>>2]|0)==1){if((c[z>>2]|0)>=(ta|0)){pa=61;break}cf[c[ea>>2]&1023](c[na>>2]|0,Ja,wa+(Ia+C)|0,L);Ka=c[$>>2]|0;La=c[na>>2]|0;if(ma){Ma=sa;Na=N;Oa=K;Pa=Ha;Qa=0;while(1){Ra=Qa<<2;Sa=Ra|2;Ta=a[La+Sa|0]|0;Ua=Ra|1;Va=a[La+Ua|0]|0;Wa=a[La+Ra|0]|0;Xa=Ra|3;Ya=a[La+Xa|0]|0;a[Ka+Sa|0]=Ta-Pa;a[Ka+Ua|0]=Va-Oa;a[Ka+Ra|0]=Wa-Na;a[Ka+Xa|0]=Ya-Ma;Xa=Qa+1|0;if((Xa|0)<(ua|0)){Ma=Ya;Na=Wa;Oa=Va;Pa=Ta;Qa=Xa}else{break}}}cf[c[ea>>2]&1023](Ka+16|0,La+16|0,La+12|0,oa);Za=La+va|0;_a=La+ya|0;$a=La+ia|0;ab=La+za|0}else{pa=61}}while(0);if((pa|0)==61){pa=0;Ja=c[$>>2]|0;if(ma){Qa=sa;Pa=N;Oa=K;Na=Ha;Ma=0;while(1){Xa=Ma<<2;Ta=Xa|2;Va=a[wa+(Ta+Ia)|0]|0;Wa=Xa|1;Ya=a[wa+(Wa+Ia)|0]|0;Ra=a[wa+(Xa+Ia)|0]|0;Ua=Xa|3;Sa=a[wa+(Ua+Ia)|0]|0;a[Ja+Ta|0]=Va-Na;a[Ja+Wa|0]=Ya-Oa;a[Ja+Xa|0]=Ra-Pa;a[Ja+Ua|0]=Sa-Qa;Ua=Ma+1|0;if((Ua|0)<(ua|0)){Qa=Sa;Pa=Ra;Oa=Ya;Na=Va;Ma=Ua}else{break}}}cf[c[ea>>2]&1023](Ja+16|0,wa+(Ia+16)|0,wa+(Ia+12)|0,oa);Za=wa+(va+Ia)|0;_a=wa+(ya+Ia)|0;$a=wa+(ia+Ia)|0;ab=wa+(za+Ia)|0}N=a[Za]|0;K=a[_a]|0;Ha=a[$a]|0;sa=a[ab]|0;MGa(t,u,4);ta=ta+1|0;}while((ta|0)<(c[w>>2]|0))}else if((M|0)==2){ta=c[g>>2]|0;sa=c[A>>2]|0;Ha=ba(sa,y-1|0)|0;K=a[ta+Ha|0]|0;N=K&255;c[P>>2]=N;c[S>>2]=24;za=a[ta+(Ha+1)|0]|0;wa=N<<8|za&255;c[P>>2]=wa;c[S>>2]=16;N=a[ta+(Ha+2)|0]|0;ia=R;x=fe((wa<<8|N&255)<<8|0)|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;c[P>>2]=0;c[S>>2]=32;ia=s+132|0;wa=c[ia>>2]|0;ya=Ha+3|0;va=u-1|0;oa=(va|0)>16?16:va;if((oa|0)>0){ea=N;N=za;za=K;K=0;while(1){ua=K*3|0;ma=a[ta+(ua+ya)|0]|0;$=ua+1|0;na=a[ta+($+ya)|0]|0;L=ua+2|0;ka=a[ta+(L+ya)|0]|0;a[wa+ua|0]=ma-za;a[wa+$|0]=na-N;a[wa+L|0]=ka-ea;L=K+1|0;if((L|0)<(oa|0)){ea=ka;N=na;za=ma;K=L}else{break}}}K=s+861564|0;za=va*3|0;cf[c[K>>2]&1023](wa+48|0,ta+(Ha+51)|0,ta+(Ha+48)|0,za-48|0);N=a[ta+(Ha+za)|0]|0;ea=a[ta+(za-2+ya)|0]|0;oa=a[ta+(za-1+ya)|0]|0;MGa(t,va,3);if((c[w>>2]|0)<=1){break}za=s+4|0;L=s+136|0;ma=u*3|0;na=(u|0)>16?16:u;ka=(na|0)>0;$=ma-48|0;ua=ma-3|0;ja=ma-2|0;xa=ma-1|0;la=N;N=ea;ea=oa;oa=1;do{B=Ha-(ba(oa,sa)|0)|0;O=ta+B|0;do{if((c[za>>2]|0)==1){if((c[z>>2]|0)>=(oa|0)){pa=74;break}cf[c[K>>2]&1023](c[L>>2]|0,O,ta+(B+C)|0,ma);Ma=c[ia>>2]|0;Na=c[L>>2]|0;if(ka){Oa=ea;Pa=N;Qa=la;Ua=0;while(1){Va=Ua*3|0;Ya=a[Na+Va|0]|0;Ra=Va+1|0;Sa=a[Na+Ra|0]|0;Xa=Va+2|0;Wa=a[Na+Xa|0]|0;a[Ma+Va|0]=Ya-Qa;a[Ma+Ra|0]=Sa-Pa;a[Ma+Xa|0]=Wa-Oa;Xa=Ua+1|0;if((Xa|0)<(na|0)){Oa=Wa;Pa=Sa;Qa=Ya;Ua=Xa}else{break}}}cf[c[K>>2]&1023](Ma+48|0,Na+48|0,Na+45|0,$);bb=Na+ja|0;cb=Na+ua|0;db=Na+xa|0}else{pa=74}}while(0);if((pa|0)==74){pa=0;O=c[ia>>2]|0;if(ka){Ia=ea;Ja=N;Ua=la;Qa=0;while(1){Pa=Qa*3|0;Oa=a[ta+(Pa+B)|0]|0;La=Pa+1|0;Ka=a[ta+(La+B)|0]|0;Xa=Pa+2|0;Ya=a[ta+(Xa+B)|0]|0;a[O+Pa|0]=Oa-Ua;a[O+La|0]=Ka-Ja;a[O+Xa|0]=Ya-Ia;Xa=Qa+1|0;if((Xa|0)<(na|0)){Ia=Ya;Ja=Ka;Ua=Oa;Qa=Xa}else{break}}}cf[c[K>>2]&1023](O+48|0,ta+(B+48)|0,ta+(B+45)|0,$);bb=ta+(ja+B)|0;cb=ta+(ua+B)|0;db=ta+(xa+B)|0}N=a[bb]|0;la=a[cb]|0;ea=a[db]|0;MGa(t,u,3);oa=oa+1|0;}while((oa|0)<(c[w>>2]|0))}else{if((c[s+64>>2]|0)<=2){yDb(e,16,2006336,(eb=i,i=i+1|0,i=i+7&-8,c[eb>>2]=0,eb)|0);i=eb;break}oa=s+92|0;ea=c[oa>>2]|0;la=s+88|0;if(((ea<<1|1)+(c[la>>2]|0)|0)<=0){break}N=s+132|0;xa=s+4|0;ta=s+76|0;ua=s+861568|0;ja=s+861740|0;$=s+80|0;K=s+136|0;na=s+861564|0;ka=s+861736|0;ia=s+100|0;L=s+104|0;ma=0;za=ea;do{do{if((za|0)==0){fb=C;gb=y;hb=u}else{if(!((ma-1|0)>>>0<2>>>0)){fb=C;gb=y;hb=u;break}fb=(ma|0)==1?E:G;gb=y>>c[L>>2];hb=u>>c[ia>>2]}}while(0);B=g+(ma<<2)|0;O=JGa(t,c[N>>2]|0,c[B>>2]|0,hb,0)|0;c[q>>2]=O;NGa(t,hb,ma);ea=c[xa>>2]|0;b:do{if((ea|0)==2){if((c[z>>2]|0)==0){ib=1}else{c[q>>2]=JGa(t,c[N>>2]|0,(c[B>>2]|0)+(c[g+32+(ma<<2)>>2]|0)|0,hb,O)|0;NGa(t,hb,ma);ib=2}sa=c[B>>2]|0;c[r>>2]=d[sa]|0;if((ib|0)>=(gb|0)){break}Ha=g+32+(ma<<2)|0;va=ib;ya=sa;while(1){sa=ba(c[Ha>>2]|0,va)|0;wa=ya+sa|0;Qa=c[N>>2]|0;Ua=ya+(sa-fb)|0;if((c[ta>>2]|0)<9){Se[c[ua>>2]&511](Qa,Ua,wa,hb,q,r)}else{Ke[c[ja>>2]&1023](Qa,Ua,wa,(c[$>>2]|0)-1|0,hb,q,r)}NGa(t,hb,ma);wa=va+1|0;if((wa|0)>=(gb|0)){break b}va=wa;ya=c[B>>2]|0}}else{if((gb|0)<=1){break}ya=g+32+(ma<<2)|0;va=1;Ha=ea;while(1){Na=c[B>>2]|0;Ma=ba(c[ya>>2]|0,va)|0;wa=Na+Ma|0;do{if((Ha|0)==1){if((c[z>>2]|0)>=(va|0)){pa=102;break}Ua=c[K>>2]|0;Qa=Na+(Ma-fb)|0;if((c[ta>>2]|0)<9){cf[c[na>>2]&1023](Ua,wa,Qa,hb)}else{le[c[ka>>2]&1023](Ua,wa,Qa,(c[$>>2]|0)-1|0,hb)}jb=JGa(t,c[N>>2]|0,c[K>>2]|0,hb,c[q>>2]|0)|0}else{pa=102}}while(0);if((pa|0)==102){pa=0;jb=JGa(t,c[N>>2]|0,wa,hb,c[q>>2]|0)|0}c[q>>2]=jb;NGa(t,hb,ma);Ma=va+1|0;if((Ma|0)>=(gb|0)){break b}va=Ma;Ha=c[xa>>2]|0}}}while(0);ma=ma+1|0;za=c[oa>>2]|0;}while((ma|0)<((za<<1|1)+(c[la>>2]|0)|0))}}while(0);gb=c[S>>2]|0;hb=c[Q>>2]|0;t=((63-gb+(hb-(c[T>>2]|0)<<3)|0)/8|0)+J|0;J=c[P>>2]|0;if((gb|0)>16){kb=gb-16|0;lb=J<<16;mb=hb}else{T=hb;x=fe(J<<gb|0)|0;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;T=(c[Q>>2]|0)+4|0;c[Q>>2]=T;kb=gb+16|0;lb=0;mb=T}c[P>>2]=lb;c[S>>2]=kb;if((kb|0)>15){nb=kb-15|0;ob=lb<<15}else{T=mb;x=fe(lb<<kb|0)|0;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;nb=kb+17|0;ob=0}c[P>>2]=ob;c[S>>2]=nb;nb=(t|0)/4|0;c:do{if((c[s+116>>2]&512|0)==0){pa=120}else{if((c[s+124>>2]&31|0)!=0){pa=120;break}t=c[e+668>>2]|0;ob=t+4128772|0;kb=s+84|0;T=ob;lb=s+160|0;mb=t;t=0;while(1){if((t|0)>=4){break c}gb=T-mb|0;if((c[kb>>2]|0)>0){J=0;hb=mb;jb=gb;while(1){q=lb+(t<<17)+(J<<3)|0;fb=c[q+4>>2]|0;Lb(hb|0,jb|0,1968552,(eb=i,i=i+16|0,c[eb>>2]=c[q>>2],c[eb+8>>2]=fb,eb)|0)|0;i=eb;fb=hb+(SGb(hb|0)|0)|0;c[q>>2]=0;c[q+4>>2]=0;q=J+1|0;z=T-fb|0;if((q|0)<(c[kb>>2]|0)){J=q;hb=fb;jb=z}else{pb=fb;qb=z;break}}}else{pb=mb;qb=gb}Lb(pb|0,qb|0,1940072,(eb=i,i=i+1|0,i=i+7&-8,c[eb>>2]=0,eb)|0)|0;i=eb;jb=pb+1|0;if(ob>>>0>jb>>>0){mb=jb;t=t+1|0}else{I=-12;break}}i=j;return I|0}}while(0);do{if((pa|0)==120){pb=c[e+668>>2]|0;if((pb|0)==0){break}a[pb]=0}}while(0);if((c[(c[s>>2]|0)+92>>2]&4|0)==0){e=c[S>>2]|0;d:do{if((e|0)<32){pa=c[P>>2]<<e;c[P>>2]=pa;pb=pa>>>24&255;while(1){pa=c[Q>>2]|0;c[Q>>2]=pa+1;a[pa]=pb;pa=c[P>>2]|0;c[P>>2]=pa<<8;eb=(c[S>>2]|0)+8|0;c[S>>2]=eb;if((eb|0)>=32){break d}pb=pa>>>16&255}}}while(0);c[S>>2]=32;c[P>>2]=0;P=c[H>>2]|0;Xe[c[s+861584>>2]&4095](P,P,nb)}P=s+124|0;c[P>>2]=(c[P>>2]|0)+1;c[U>>2]=nb<<2;nb=f+36|0;c[nb>>2]=c[nb>>2]|1;c[h>>2]=1;I=0;i=j;return I|0}function HGa(a){a=a|0;klb(c[a+60>>2]|0);$Db(a+96|0);$Db(a+668|0);JCb(a+804|0);return 0}function IGa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;do{if((c[b+64>>2]|0)>2){f=(c[b+88>>2]|0)+1+(c[b+92>>2]<<1)|0;if((f|0)>0){g=f;break}else{h=0}i=e;return h|0}else{g=3}}while(0);f=b+84|0;j=0;k=0;a:while(1){l=b+524448+(j<<14)|0;m=sGa(l,b+160+(j<<17)|0,c[f>>2]|0)|0;if((m|0)<0){h=m;n=19;break}if((hlb(b+589984+(j<<16)|0,l,c[f>>2]|0)|0)<0){h=-1;n=19;break}l=c[f>>2]|0;if((l|0)>0){m=k+1|0;o=0;p=0;while(1){q=a[b+524448+(j<<14)+p|0]|0;r=q&255;b:do{if((p|0)<(l|0)){s=0;t=p;while(1){u=s+1|0;v=t+1|0;if((v|0)>=(l|0)){w=v;x=u;break b}if((a[b+524448+(j<<14)+v|0]|0)==q<<24>>24&(u|0)<255){s=u;t=v}else{w=v;x=u;break}}}else{w=p;x=0}}while(0);if(!((q&255)>>>0<32>>>0&q<<24>>24!=0)){n=13;break a}if(!((x-1|0)>>>0<255>>>0)){n=13;break a}if((x|0)>7){a[d+(o+k)|0]=q;a[d+(m+o)|0]=x;y=o+2|0}else{a[d+(o+k)|0]=x<<5|r;y=o+1|0}if((w|0)<(l|0)){o=y;p=w}else{z=y;break}}}else{z=0}p=z+k|0;o=j+1|0;if((o|0)<(g|0)){j=o;k=p}else{h=p;n=19;break}}if((n|0)==13){yDb(0,0,1895304,(k=i,i=i+24|0,c[k>>2]=2352472,c[k+8>>2]=2332320,c[k+16>>2]=176,k)|0);i=k;Cd();return 0}else if((n|0)==19){i=e;return h|0}return 0}function JGa(f,g,h,i,j){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[f+76>>2]|0)<9){if((i|0)>=32){k=0;l=j;while(1){m=d[h+k|0]|0;a[g+k|0]=m-l;n=k+1|0;if((n|0)<16){k=n;l=m}else{break}}cf[c[f+861564>>2]&1023](g+16|0,h+16|0,h+15|0,i-16|0);o=d[h+(i-1)|0]|0;return o|0}if((i|0)>0){p=0;q=j}else{o=j;return o|0}while(1){l=d[h+p|0]|0;a[g+p|0]=l-q;k=p+1|0;if((k|0)<(i|0)){p=k;q=l}else{o=l;break}}return o|0}else{q=h;p=g;if((i|0)>=32){l=0;k=j;while(1){m=e[q+(l<<1)>>1]|0;b[p+(l<<1)>>1]=m-k;n=l+1|0;if((n|0)<16){l=n;k=m}else{break}}le[c[f+861736>>2]&1023](g+32|0,h+32|0,h+30|0,(c[f+80>>2]|0)-1|0,i-16|0);o=e[q+(i-1<<1)>>1]|0;return o|0}if((i|0)>0){r=0;s=j}else{o=j;return o|0}while(1){j=e[q+(r<<1)>>1]|0;b[p+(r<<1)>>1]=j-s;f=r+1|0;if((f|0)<(i|0)){r=f;s=j}else{o=j;break}}return o|0}return 0}function KGa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=i;h=c[b+132>>2]|0;j=c[b+136>>2]|0;k=(e|0)/2|0;l=c[b+140>>2]|0;m=b+28|0;n=c[b+36>>2]|0;o=b+32|0;p=b+40|0;if(((c[b+44>>2]|0)-n-(32-(c[o>>2]|0)+((c[p>>2]|0)-n<<3)>>3)|0)<(f<<3|0)){yDb(c[b>>2]|0,16,1915880,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;i=g;return}n=(f|0)/2|0;if((c[b+116>>2]&512|0)!=0&(f|0)>1){q=0;do{r=q<<1;s=d[h+((r|1)+e)|0]|0;t=q+k|0;u=d[j+t|0]|0;v=d[l+t|0]|0;t=b+160+((d[h+(r+e)|0]|0)<<3)|0;r=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=r;c[t+4>>2]=F;t=b+131232+(u<<3)|0;u=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=u;c[t+4>>2]=F;t=b+160+(s<<3)|0;s=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=F;t=b+262304+(v<<3)|0;v=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=v;c[t+4>>2]=F;q=q+1|0;}while((q|0)<(n|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=g;return}q=(f|0)>1;if((c[b+120>>2]|0)==0){if(!q){i=g;return}f=m|0;t=0;v=c[f>>2]|0;s=c[o>>2]|0;while(1){u=t<<1;r=d[h+(u+e)|0]|0;w=d[h+((u|1)+e)|0]|0;u=t+k|0;y=d[j+u|0]|0;z=d[l+u|0]|0;u=d[b+524448+r|0]|0;A=c[b+589984+(r<<2)>>2]|0;if((s|0)>(u|0)){B=s-u|0;C=v<<u|A}else{r=fe(A>>>((u-s|0)>>>0)|v<<s|0)|0;D=c[p>>2]|0;x=r;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;B=32-u+s|0;C=A}c[f>>2]=C;c[o>>2]=B;A=d[b+540832+y|0]|0;u=c[b+655520+(y<<2)>>2]|0;if((B|0)>(A|0)){E=B;G=C<<A|u}else{y=fe(u>>>((A-B|0)>>>0)|C<<B|0)|0;D=c[p>>2]|0;x=y;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;E=B+32|0;G=u}u=E-A|0;c[f>>2]=G;c[o>>2]=u;A=d[b+524448+w|0]|0;D=c[b+589984+(w<<2)>>2]|0;if((u|0)>(A|0)){H=u;I=G<<A|D}else{w=fe(D>>>((A-u|0)>>>0)|G<<u|0)|0;y=c[p>>2]|0;x=w;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;H=u+32|0;I=D}D=H-A|0;c[f>>2]=I;c[o>>2]=D;A=d[b+557216+z|0]|0;u=c[b+721056+(z<<2)>>2]|0;if((D|0)>(A|0)){J=D;K=I<<A|u}else{z=fe(u>>>((A-D|0)>>>0)|I<<D|0)|0;y=c[p>>2]|0;x=z;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;J=D+32|0;K=u}u=J-A|0;c[f>>2]=K;c[o>>2]=u;A=t+1|0;if((A|0)<(n|0)){t=A;v=K;s=u}else{break}}i=g;return}else{if(!q){i=g;return}q=m|0;m=0;do{s=m<<1;K=d[h+(s+e)|0]|0;v=d[h+((s|1)+e)|0]|0;s=m+k|0;t=d[j+s|0]|0;f=d[l+s|0]|0;s=b+160+(K<<3)|0;J=YGb(c[s>>2]|0,c[s+4>>2]|0,1,0)|0;c[s>>2]=J;c[s+4>>2]=F;s=d[b+524448+K|0]|0;J=c[b+589984+(K<<2)>>2]|0;K=c[q>>2]|0;I=c[o>>2]|0;if((I|0)>(s|0)){L=I-s|0;M=K<<s|J}else{H=fe(J>>>((s-I|0)>>>0)|K<<I|0)|0;K=c[p>>2]|0;x=H;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;L=32-s+I|0;M=J}c[q>>2]=M;c[o>>2]=L;J=b+131232+(t<<3)|0;I=YGb(c[J>>2]|0,c[J+4>>2]|0,1,0)|0;c[J>>2]=I;c[J+4>>2]=F;J=d[b+540832+t|0]|0;I=c[b+655520+(t<<2)>>2]|0;t=c[q>>2]|0;s=c[o>>2]|0;if((s|0)>(J|0)){N=s-J|0;O=t<<J|I}else{K=fe(I>>>((J-s|0)>>>0)|t<<s|0)|0;t=c[p>>2]|0;x=K;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;N=32-J+s|0;O=I}c[q>>2]=O;c[o>>2]=N;I=b+160+(v<<3)|0;s=YGb(c[I>>2]|0,c[I+4>>2]|0,1,0)|0;c[I>>2]=s;c[I+4>>2]=F;I=d[b+524448+v|0]|0;s=c[b+589984+(v<<2)>>2]|0;v=c[q>>2]|0;J=c[o>>2]|0;if((J|0)>(I|0)){P=J-I|0;Q=v<<I|s}else{t=fe(s>>>((I-J|0)>>>0)|v<<J|0)|0;v=c[p>>2]|0;x=t;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;P=32-I+J|0;Q=s}c[q>>2]=Q;c[o>>2]=P;s=b+262304+(f<<3)|0;J=YGb(c[s>>2]|0,c[s+4>>2]|0,1,0)|0;c[s>>2]=J;c[s+4>>2]=F;s=d[b+557216+f|0]|0;J=c[b+721056+(f<<2)>>2]|0;f=c[q>>2]|0;I=c[o>>2]|0;if((I|0)>(s|0)){R=I-s|0;S=f<<s|J}else{v=fe(J>>>((s-I|0)>>>0)|f<<I|0)|0;f=c[p>>2]|0;x=v;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;R=32-s+I|0;S=J}c[q>>2]=S;c[o>>2]=R;m=m+1|0;}while((m|0)<(n|0));i=g;return}}function LGa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;g=b+28|0;h=c[b+36>>2]|0;j=b+32|0;k=b+40|0;if(((c[b+44>>2]|0)-h-(32-(c[j>>2]|0)+((c[k>>2]|0)-h<<3)>>3)|0)<(e<<2|0)){yDb(c[b>>2]|0,16,1915880,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;i=f;return}h=(e|0)/2|0;if((c[b+116>>2]&512|0)!=0&(e|0)>1){l=b+132|0;m=0;do{n=m<<1;o=c[l>>2]|0;p=d[o+(n|1)|0]|0;q=b+160+((d[o+n|0]|0)<<3)|0;n=YGb(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;c[q>>2]=n;c[q+4>>2]=F;q=b+160+(p<<3)|0;p=YGb(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;c[q>>2]=p;c[q+4>>2]=F;m=m+1|0;}while((m|0)<(h|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=f;return}m=(e|0)>1;if((c[b+120>>2]|0)==0){if(!m){i=f;return}e=b+132|0;l=g|0;q=0;p=c[l>>2]|0;n=c[j>>2]|0;while(1){o=q<<1;r=c[e>>2]|0;s=d[r+o|0]|0;t=d[r+(o|1)|0]|0;o=d[b+524448+s|0]|0;r=c[b+589984+(s<<2)>>2]|0;if((n|0)>(o|0)){u=n-o|0;v=p<<o|r}else{s=fe(r>>>((o-n|0)>>>0)|p<<n|0)|0;w=c[k>>2]|0;x=s;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;u=32-o+n|0;v=r}c[l>>2]=v;c[j>>2]=u;r=d[b+524448+t|0]|0;o=c[b+589984+(t<<2)>>2]|0;if((u|0)>(r|0)){y=u;z=v<<r|o}else{t=fe(o>>>((r-u|0)>>>0)|v<<u|0)|0;w=c[k>>2]|0;x=t;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;y=u+32|0;z=o}o=y-r|0;c[l>>2]=z;c[j>>2]=o;r=q+1|0;if((r|0)<(h|0)){q=r;p=z;n=o}else{break}}i=f;return}else{if(!m){i=f;return}m=b+132|0;n=g|0;g=0;do{z=g<<1;p=c[m>>2]|0;q=d[p+z|0]|0;l=d[p+(z|1)|0]|0;z=b+160+(q<<3)|0;p=YGb(c[z>>2]|0,c[z+4>>2]|0,1,0)|0;c[z>>2]=p;c[z+4>>2]=F;z=b+160+(l<<3)|0;p=YGb(c[z>>2]|0,c[z+4>>2]|0,1,0)|0;c[z>>2]=p;c[z+4>>2]=F;z=d[b+524448+q|0]|0;p=c[b+589984+(q<<2)>>2]|0;q=c[n>>2]|0;y=c[j>>2]|0;if((y|0)>(z|0)){A=y-z|0;B=q<<z|p}else{u=fe(p>>>((z-y|0)>>>0)|q<<y|0)|0;q=c[k>>2]|0;x=u;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;A=32-z+y|0;B=p}c[n>>2]=B;c[j>>2]=A;p=d[b+524448+l|0]|0;y=c[b+589984+(l<<2)>>2]|0;if((A|0)>(p|0)){C=A;D=B<<p|y}else{l=fe(y>>>((p-A|0)>>>0)|B<<A|0)|0;z=c[k>>2]|0;x=l;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;C=A+32|0;D=y}c[n>>2]=D;c[j>>2]=C-p;g=g+1|0;}while((g|0)<(h|0));i=f;return}}function MGa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;g=i;h=b+28|0;j=c[b+36>>2]|0;k=b+32|0;l=c[k>>2]|0;m=b+40|0;n=c[m>>2]|0;if(((c[b+44>>2]|0)-j-(32-l+(n-j<<3)>>3)|0)<(ba(e<<2,f)|0)){yDb(c[b>>2]|0,16,1915880,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;i=g;return}j=(c[b+116>>2]&512|0)==0;do{if(!j){if((c[(c[b>>2]|0)+92>>2]&4|0)==0){break}if((e|0)<=0){i=g;return}o=(f|0)==3;p=b+132|0;q=(f|0)==4;r=0;do{if(o){s=r*3|0;t=c[p>>2]|0;u=d[t+(s+1)|0]|0;v=s;w=u;y=(d[t+(s+2)|0]|0)-u|0;z=t}else{t=r<<2;u=c[p>>2]|0;s=d[u+(t|1)|0]|0;v=t|2;w=s;y=(d[u+t|0]|0)-s|0;z=u}u=(d[z+v|0]|0)-w&255;s=a[z+((ba(r,f)|0)+3)|0]|0;t=b+160+((y&255)<<3)|0;A=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=A;c[t+4>>2]=F;t=b+131232+(w<<3)|0;A=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=A;c[t+4>>2]=F;t=b+262304+(u<<3)|0;u=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=u;c[t+4>>2]=F;if(q){t=b+262304+((s&255)<<3)|0;s=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=F}r=r+1|0;}while((r|0)<(e|0));i=g;return}}while(0);w=(e|0)>0;if((c[b+120>>2]|0)!=0|j^1){if(!w){i=g;return}j=(f|0)==3;y=b+132|0;z=(f|0)==4;v=h|0;r=0;do{if(j){q=r*3|0;p=c[y>>2]|0;o=d[p+(q+1)|0]|0;B=q;C=o;D=(d[p+(q+2)|0]|0)-o|0;E=p}else{p=r<<2;o=c[y>>2]|0;q=d[o+(p|1)|0]|0;B=p|2;C=q;D=(d[o+p|0]|0)-q|0;E=o}o=D&255;q=(d[E+B|0]|0)-C&255;p=d[E+((ba(r,f)|0)+3)|0]|0;t=b+160+(o<<3)|0;s=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=F;t=b+131232+(C<<3)|0;s=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=F;t=b+262304+(q<<3)|0;s=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=F;if(z){t=b+262304+(p<<3)|0;s=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=F}t=d[b+540832+C|0]|0;s=c[b+655520+(C<<2)>>2]|0;u=c[v>>2]|0;A=c[k>>2]|0;if((A|0)>(t|0)){G=A-t|0;H=u<<t|s}else{I=fe(s>>>((t-A|0)>>>0)|u<<A|0)|0;u=c[m>>2]|0;x=I;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;G=32-t+A|0;H=s}c[v>>2]=H;c[k>>2]=G;s=d[b+524448+o|0]|0;A=c[b+589984+(o<<2)>>2]|0;if((G|0)>(s|0)){J=G;K=H<<s|A}else{o=fe(A>>>((s-G|0)>>>0)|H<<G|0)|0;t=c[m>>2]|0;x=o;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;J=G+32|0;K=A}A=J-s|0;c[v>>2]=K;c[k>>2]=A;s=d[b+557216+q|0]|0;t=c[b+721056+(q<<2)>>2]|0;if((A|0)>(s|0)){L=A;M=K<<s|t}else{q=fe(t>>>((s-A|0)>>>0)|K<<A|0)|0;o=c[m>>2]|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;L=A+32|0;M=t}t=L-s|0;c[v>>2]=M;c[k>>2]=t;if(z){s=d[b+557216+p|0]|0;A=c[b+721056+(p<<2)>>2]|0;if((t|0)>(s|0)){N=t;O=M<<s|A}else{p=fe(A>>>((s-t|0)>>>0)|M<<t|0)|0;o=c[m>>2]|0;x=p;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;N=t+32|0;O=A}c[v>>2]=O;c[k>>2]=N-s}r=r+1|0;}while((r|0)<(e|0));i=g;return}if(!w){i=g;return}w=b+132|0;r=h|0;h=(f|0)==4;if((f|0)==3){N=0;O=l;v=n;while(1){M=N*3|0;z=c[w>>2]|0;L=d[z+(M+1)|0]|0;K=(d[z+(M+2)|0]|0)-L&255;J=(d[z+M|0]|0)-L&255;G=d[z+(M+3)|0]|0;M=d[b+540832+L|0]|0;z=c[b+655520+(L<<2)>>2]|0;L=c[r>>2]|0;if((O|0)>(M|0)){P=O-M|0;Q=L<<M|z;R=v}else{H=v;x=fe(z>>>((M-O|0)>>>0)|L<<O|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=(c[m>>2]|0)+4|0;c[m>>2]=H;P=32-M+O|0;Q=z;R=H}c[r>>2]=Q;c[k>>2]=P;H=d[b+524448+K|0]|0;z=c[b+589984+(K<<2)>>2]|0;if((P|0)>(H|0)){S=P;T=Q<<H|z;U=R}else{K=R;x=fe(z>>>((H-P|0)>>>0)|Q<<P|0)|0;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;K=(c[m>>2]|0)+4|0;c[m>>2]=K;S=P+32|0;T=z;U=K}K=S-H|0;c[r>>2]=T;c[k>>2]=K;H=d[b+557216+J|0]|0;z=c[b+721056+(J<<2)>>2]|0;if((K|0)>(H|0)){V=K;W=T<<H|z;X=U}else{J=U;x=fe(z>>>((H-K|0)>>>0)|T<<K|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;J=(c[m>>2]|0)+4|0;c[m>>2]=J;V=K+32|0;W=z;X=J}J=V-H|0;c[r>>2]=W;c[k>>2]=J;if(h){H=d[b+557216+G|0]|0;z=c[b+721056+(G<<2)>>2]|0;if((J|0)>(H|0)){Y=J;Z=W<<H|z;_=X}else{G=X;x=fe(z>>>((H-J|0)>>>0)|W<<J|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;G=(c[m>>2]|0)+4|0;c[m>>2]=G;Y=J+32|0;Z=z;_=G}G=Y-H|0;c[r>>2]=Z;c[k>>2]=G;$=G;aa=_}else{$=J;aa=X}J=N+1|0;if((J|0)<(e|0)){N=J;O=$;v=aa}else{break}}i=g;return}else{aa=0;v=l;l=n;while(1){n=aa<<2;$=c[w>>2]|0;O=d[$+(n|1)|0]|0;N=(d[$+n|0]|0)-O&255;X=(d[$+(n|2)|0]|0)-O&255;n=d[$+((ba(aa,f)|0)+3)|0]|0;$=d[b+540832+O|0]|0;_=c[b+655520+(O<<2)>>2]|0;O=c[r>>2]|0;if((v|0)>($|0)){ca=v-$|0;da=O<<$|_;ea=l}else{Z=l;x=fe(_>>>(($-v|0)>>>0)|O<<v|0)|0;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;Z=(c[m>>2]|0)+4|0;c[m>>2]=Z;ca=32-$+v|0;da=_;ea=Z}c[r>>2]=da;c[k>>2]=ca;Z=d[b+524448+N|0]|0;_=c[b+589984+(N<<2)>>2]|0;if((ca|0)>(Z|0)){fa=ca;ga=da<<Z|_;ha=ea}else{N=ea;x=fe(_>>>((Z-ca|0)>>>0)|da<<ca|0)|0;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;N=(c[m>>2]|0)+4|0;c[m>>2]=N;fa=ca+32|0;ga=_;ha=N}N=fa-Z|0;c[r>>2]=ga;c[k>>2]=N;Z=d[b+557216+X|0]|0;_=c[b+721056+(X<<2)>>2]|0;if((N|0)>(Z|0)){ia=N;ja=ga<<Z|_;ka=ha}else{X=ha;x=fe(_>>>((Z-N|0)>>>0)|ga<<N|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=(c[m>>2]|0)+4|0;c[m>>2]=X;ia=N+32|0;ja=_;ka=X}X=ia-Z|0;c[r>>2]=ja;c[k>>2]=X;if(h){Z=d[b+557216+n|0]|0;_=c[b+721056+(n<<2)>>2]|0;if((X|0)>(Z|0)){la=X;ma=ja<<Z|_;na=ka}else{n=ka;x=fe(_>>>((Z-X|0)>>>0)|ja<<X|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=(c[m>>2]|0)+4|0;c[m>>2]=n;la=X+32|0;ma=_;na=n}n=la-Z|0;c[r>>2]=ma;c[k>>2]=n;oa=n;pa=na}else{oa=X;pa=ka}X=aa+1|0;if((X|0)<(e|0)){aa=X;v=oa;l=pa}else{break}}i=g;return}}function NGa(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0;h=i;j=b+28|0;k=c[b+36>>2]|0;l=b+32|0;m=b+40|0;n=c[b+76>>2]|0;if(((c[b+44>>2]|0)-k-(32-(c[l>>2]|0)+((c[m>>2]|0)-k<<3)>>3)|0)<((ba(n,f)|0)/2|0|0)){yDb(c[b>>2]|0,16,1915880,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;i=h;return}k=(f|0)/2|0;if((n|0)<9){if((c[b+116>>2]&512|0)!=0&(f|0)>1){o=b+132|0;p=0;do{q=p<<1;r=c[o>>2]|0;s=d[r+(q|1)|0]|0;t=b+160+(g<<17)+((d[r+q|0]|0)<<3)|0;q=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=q;c[t+4>>2]=F;t=b+160+(g<<17)+(s<<3)|0;s=YGb(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=F;p=p+1|0;}while((p|0)<(k|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=h;return}p=(f|0)>1;if((c[b+120>>2]|0)==0){if(!p){i=h;return}o=b+132|0;t=j|0;s=0;q=c[t>>2]|0;r=c[l>>2]|0;while(1){u=s<<1;v=c[o>>2]|0;w=d[v+u|0]|0;y=d[v+(u|1)|0]|0;u=d[b+524448+(g<<14)+w|0]|0;v=c[b+589984+(g<<16)+(w<<2)>>2]|0;if((r|0)>(u|0)){z=r-u|0;A=q<<u|v}else{w=fe(v>>>((u-r|0)>>>0)|q<<r|0)|0;B=c[m>>2]|0;x=w;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;z=32-u+r|0;A=v}c[t>>2]=A;c[l>>2]=z;v=d[b+524448+(g<<14)+y|0]|0;u=c[b+589984+(g<<16)+(y<<2)>>2]|0;if((z|0)>(v|0)){C=z;D=A<<v|u}else{y=fe(u>>>((v-z|0)>>>0)|A<<z|0)|0;B=c[m>>2]|0;x=y;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;C=z+32|0;D=u}u=C-v|0;c[t>>2]=D;c[l>>2]=u;v=s+1|0;if((v|0)<(k|0)){s=v;q=D;r=u}else{break}}i=h;return}else{if(!p){i=h;return}p=b+132|0;r=j|0;D=0;do{q=D<<1;s=c[p>>2]|0;t=d[s+q|0]|0;C=d[s+(q|1)|0]|0;q=b+160+(g<<17)+(t<<3)|0;s=YGb(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;c[q>>2]=s;c[q+4>>2]=F;q=b+160+(g<<17)+(C<<3)|0;s=YGb(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;c[q>>2]=s;c[q+4>>2]=F;q=d[b+524448+(g<<14)+t|0]|0;s=c[b+589984+(g<<16)+(t<<2)>>2]|0;t=c[r>>2]|0;z=c[l>>2]|0;if((z|0)>(q|0)){E=z-q|0;G=t<<q|s}else{A=fe(s>>>((q-z|0)>>>0)|t<<z|0)|0;t=c[m>>2]|0;x=A;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;E=32-q+z|0;G=s}c[r>>2]=G;c[l>>2]=E;s=d[b+524448+(g<<14)+C|0]|0;z=c[b+589984+(g<<16)+(C<<2)>>2]|0;if((E|0)>(s|0)){H=E;I=G<<s|z}else{C=fe(z>>>((s-E|0)>>>0)|G<<E|0)|0;q=c[m>>2]|0;x=C;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;H=E+32|0;I=z}c[r>>2]=I;c[l>>2]=H-s;D=D+1|0;}while((D|0)<(k|0));i=h;return}}if((n|0)<15){n=(c[b+80>>2]|0)-1|0;if((c[b+116>>2]&512|0)!=0&(f|0)>1){D=b+144|0;H=0;do{I=H<<1;r=c[D>>2]|0;E=(e[r+((I|1)<<1)>>1]|0)&n;G=b+160+(g<<17)+(((e[r+(I<<1)>>1]|0)&n)<<3)|0;I=YGb(c[G>>2]|0,c[G+4>>2]|0,1,0)|0;c[G>>2]=I;c[G+4>>2]=F;G=b+160+(g<<17)+(E<<3)|0;E=YGb(c[G>>2]|0,c[G+4>>2]|0,1,0)|0;c[G>>2]=E;c[G+4>>2]=F;H=H+1|0;}while((H|0)<(k|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=h;return}H=(f|0)>1;if((c[b+120>>2]|0)==0){if(!H){i=h;return}D=b+144|0;G=j|0;E=0;I=c[G>>2]|0;r=c[l>>2]|0;while(1){p=E<<1;s=c[D>>2]|0;z=(e[s+(p<<1)>>1]|0)&n;q=(e[s+((p|1)<<1)>>1]|0)&n;p=d[b+524448+(g<<14)+z|0]|0;s=c[b+589984+(g<<16)+(z<<2)>>2]|0;if((r|0)>(p|0)){J=r-p|0;K=I<<p|s}else{z=fe(s>>>((p-r|0)>>>0)|I<<r|0)|0;C=c[m>>2]|0;x=z;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;J=32-p+r|0;K=s}c[G>>2]=K;c[l>>2]=J;s=d[b+524448+(g<<14)+q|0]|0;p=c[b+589984+(g<<16)+(q<<2)>>2]|0;if((J|0)>(s|0)){L=J;M=K<<s|p}else{q=fe(p>>>((s-J|0)>>>0)|K<<J|0)|0;C=c[m>>2]|0;x=q;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;L=J+32|0;M=p}p=L-s|0;c[G>>2]=M;c[l>>2]=p;s=E+1|0;if((s|0)<(k|0)){E=s;I=M;r=p}else{break}}i=h;return}else{if(!H){i=h;return}H=b+144|0;r=j|0;M=0;do{I=M<<1;E=c[H>>2]|0;G=(e[E+(I<<1)>>1]|0)&n;L=(e[E+((I|1)<<1)>>1]|0)&n;I=b+160+(g<<17)+(G<<3)|0;E=YGb(c[I>>2]|0,c[I+4>>2]|0,1,0)|0;c[I>>2]=E;c[I+4>>2]=F;I=b+160+(g<<17)+(L<<3)|0;E=YGb(c[I>>2]|0,c[I+4>>2]|0,1,0)|0;c[I>>2]=E;c[I+4>>2]=F;I=d[b+524448+(g<<14)+G|0]|0;E=c[b+589984+(g<<16)+(G<<2)>>2]|0;G=c[r>>2]|0;J=c[l>>2]|0;if((J|0)>(I|0)){N=J-I|0;O=G<<I|E}else{K=fe(E>>>((I-J|0)>>>0)|G<<J|0)|0;G=c[m>>2]|0;x=K;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;N=32-I+J|0;O=E}c[r>>2]=O;c[l>>2]=N;E=d[b+524448+(g<<14)+L|0]|0;J=c[b+589984+(g<<16)+(L<<2)>>2]|0;if((N|0)>(E|0)){P=N;Q=O<<E|J}else{L=fe(J>>>((E-N|0)>>>0)|O<<N|0)|0;I=c[m>>2]|0;x=L;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;P=N+32|0;Q=J}c[r>>2]=Q;c[l>>2]=P-E;M=M+1|0;}while((M|0)<(k|0));i=h;return}}if((c[b+116>>2]&512|0)!=0&(f|0)>1){M=b+144|0;P=0;do{Q=P<<1;r=c[M>>2]|0;N=e[r+((Q|1)<<1)>>1]|0;O=b+160+(g<<17)+((e[r+(Q<<1)>>1]|0)>>>2<<3)|0;Q=YGb(c[O>>2]|0,c[O+4>>2]|0,1,0)|0;c[O>>2]=Q;c[O+4>>2]=F;O=b+160+(g<<17)+(N>>>2<<3)|0;N=YGb(c[O>>2]|0,c[O+4>>2]|0,1,0)|0;c[O>>2]=N;c[O+4>>2]=F;P=P+1|0;}while((P|0)<(k|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=h;return}P=(f|0)>1;if((c[b+120>>2]|0)==0){if(!P){i=h;return}f=b+144|0;M=j|0;O=0;N=c[M>>2]|0;Q=c[l>>2]|0;while(1){r=O<<1;n=c[f>>2]|0;H=e[n+(r<<1)>>1]|0;E=e[n+((r|1)<<1)>>1]|0;r=H>>>2;n=d[b+524448+(g<<14)+r|0]|0;J=c[b+589984+(g<<16)+(r<<2)>>2]|0;if((Q|0)>(n|0)){R=Q-n|0;S=N<<n|J}else{r=fe(J>>>((n-Q|0)>>>0)|N<<Q|0)|0;I=c[m>>2]|0;x=r;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;R=32-n+Q|0;S=J}c[M>>2]=S;c[l>>2]=R;J=H&3;if((R|0)>2){T=R-2|0;U=S<<2|J}else{H=fe(J>>>((2-R|0)>>>0)|S<<R|0)|0;n=c[m>>2]|0;x=H;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;T=R+30|0;U=J}c[M>>2]=U;c[l>>2]=T;J=E>>>2;n=d[b+524448+(g<<14)+J|0]|0;H=c[b+589984+(g<<16)+(J<<2)>>2]|0;if((T|0)>(n|0)){V=T;W=U<<n|H}else{J=fe(H>>>((n-T|0)>>>0)|U<<T|0)|0;I=c[m>>2]|0;x=J;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;V=T+32|0;W=H}H=V-n|0;c[M>>2]=W;c[l>>2]=H;n=E&3;if((H|0)>2){X=H-2|0;Y=W<<2|n}else{E=fe(n>>>((2-H|0)>>>0)|W<<H|0)|0;I=c[m>>2]|0;x=E;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;X=H+30|0;Y=n}c[M>>2]=Y;c[l>>2]=X;n=O+1|0;if((n|0)<(k|0)){O=n;N=Y;Q=X}else{break}}i=h;return}else{if(!P){i=h;return}P=b+144|0;X=j|0;j=0;do{Q=j<<1;Y=c[P>>2]|0;N=e[Y+(Q<<1)>>1]|0;O=e[Y+((Q|1)<<1)>>1]|0;Q=N>>>2;Y=b+160+(g<<17)+(Q<<3)|0;M=YGb(c[Y>>2]|0,c[Y+4>>2]|0,1,0)|0;c[Y>>2]=M;c[Y+4>>2]=F;Y=O>>>2;M=b+160+(g<<17)+(Y<<3)|0;W=YGb(c[M>>2]|0,c[M+4>>2]|0,1,0)|0;c[M>>2]=W;c[M+4>>2]=F;M=d[b+524448+(g<<14)+Q|0]|0;W=c[b+589984+(g<<16)+(Q<<2)>>2]|0;Q=c[X>>2]|0;V=c[l>>2]|0;if((V|0)>(M|0)){Z=V-M|0;_=Q<<M|W}else{T=fe(W>>>((M-V|0)>>>0)|Q<<V|0)|0;Q=c[m>>2]|0;x=T;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;Z=32-M+V|0;_=W}c[X>>2]=_;c[l>>2]=Z;W=N&3;if((Z|0)>2){$=Z-2|0;aa=_<<2|W}else{N=fe(W>>>((2-Z|0)>>>0)|_<<Z|0)|0;V=c[m>>2]|0;x=N;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;$=Z+30|0;aa=W}c[X>>2]=aa;c[l>>2]=$;W=d[b+524448+(g<<14)+Y|0]|0;V=c[b+589984+(g<<16)+(Y<<2)>>2]|0;if(($|0)>(W|0)){ca=$;da=aa<<W|V}else{Y=fe(V>>>((W-$|0)>>>0)|aa<<$|0)|0;N=c[m>>2]|0;x=Y;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;ca=$+32|0;da=V}V=ca-W|0;c[X>>2]=da;c[l>>2]=V;W=O&3;if((V|0)>2){ea=V-2|0;fa=da<<2|W}else{O=fe(W>>>((2-V|0)>>>0)|da<<V|0)|0;N=c[m>>2]|0;x=O;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;ea=V+30|0;fa=W}c[X>>2]=fa;c[l>>2]=ea;j=j+1|0;}while((j|0)<(k|0));i=h;return}}function OGa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=c[b+60>>2]|0;g=f;c[f>>2]=b;c[b+140>>2]=11;if((c[b+100>>2]|0)!=65536){yDb(b,16,2109896,(h=i,i=i+8|0,c[h>>2]=65536,h)|0);i=h;j=-1;i=e;return j|0}h=c[b+96>>2]|0;b=f+12|0;f=0;k=0;while(1){l=0;m=k;while(1){c[b+(f<<13)+(l<<4)>>2]=d[h+m|0]|0;n=l+1|0;if((n|0)<256){l=n;m=m+1|0}else{o=0;break}}do{a[g+12+(f<<13)+(o<<4)+4|0]=0;o=o+1|0;}while((o|0)<512);m=k+256|0;l=256;while(1){n=0;p=99999999;q=-1;while(1){if((a[g+12+(f<<13)+(n<<4)+4|0]|0)==0){r=c[g+12+(f<<13)+(n<<4)>>2]|0;s=(r|0)!=0&(r|0)<(p|0);t=s?n:q;u=s?r:p}else{t=q;u=p}r=n+1|0;if((r|0)<(l|0)){n=r;p=u;q=t}else{break}}if((t|0)==-1){v=l;w=13;break}a[g+12+(f<<13)+(t<<4)+4|0]=1;c[g+12+(f<<13)+(l<<4)+8>>2]=t;q=0;p=99999999;n=-1;while(1){if((a[g+12+(f<<13)+(q<<4)+4|0]|0)==0){r=c[g+12+(f<<13)+(q<<4)>>2]|0;s=(r|0)!=0&(r|0)<(p|0);x=s?q:n;y=s?r:p}else{x=n;y=p}r=q+1|0;if((r|0)<(l|0)){q=r;p=y;n=x}else{break}}if((x|0)==-1){w=19;break}a[g+12+(f<<13)+(x<<4)+4|0]=1;c[g+12+(f<<13)+(l<<4)+12>>2]=x;c[g+12+(f<<13)+(l<<4)>>2]=(c[g+12+(f<<13)+(x<<4)>>2]|0)+(c[g+12+(f<<13)+(t<<4)>>2]|0);n=l+1|0;if((n|0)>0){l=n}else{v=n;w=13;break}}if((w|0)==13){w=0;c[g+12+(f<<13)+(v<<4)+8>>2]=-1;z=v}else if((w|0)==19){w=0;c[g+12+(f<<13)+(l<<4)+12>>2]=-1;z=l}c[g+2097164+(f<<2)>>2]=z-1;n=f+1|0;if((n|0)<256){f=n;k=m}else{j=0;break}}i=e;return j|0}function PGa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;k=c[b+60>>2]|0;l=HZ(f,0,0)|0;f=k+4|0;c[f>>2]=h;h=k+8|0;c[h>>2]=j;m=_$a(b,d,0)|0;if((m|0)<0){n=m;i=g;return n|0}m=k;b=d+32|0;o=c[b>>2]|0;p=k;q=c[p>>2]|0;a:do{if((ba(c[q+124>>2]|0,o)|0)>0){r=d;s=0;t=0;u=0;v=0;w=0;x=q;y=o;b:while(1){if((c[x+120>>2]|0)>0){z=s;A=t;B=u;C=v;D=w;E=x;while(1){F=c[m+2097164+(A<<2)>>2]|0;if((F|0)>255){G=B;H=C;I=D;J=F;while(1){if((H|0)==0){if((I|0)>=(c[h>>2]|0)){break b}K=I+1|0;L=8;M=a[(c[f>>2]|0)+I|0]|0}else{K=I;L=H;M=G}N=(M&255)>>>1;O=L-1|0;P=c[m+12+(A<<13)+(J<<4)+8+((M&1)<<2)>>2]|0;if((P|0)>255){G=N;H=O;I=K;J=P}else{Q=N;R=O;S=K;T=P;break}}}else{Q=B;R=C;S=D;T=F}a[(c[r>>2]|0)+z|0]=T;J=z+1|0;U=c[p>>2]|0;if((J|0)<((c[U+120>>2]|0)+s|0)){z=J;A=T;B=Q;C=R;D=S;E=U}else{break}}V=T;W=Q;X=R;Y=S;Z=c[b>>2]|0;_=U}else{V=t;W=u;X=v;Y=w;Z=y;_=x}D=Z+s|0;if((D|0)<(ba(c[_+124>>2]|0,Z)|0)){s=D;t=V;u=W;v=X;w=Y;x=_;y=Z}else{break a}}yDb(E,16,2187136,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;n=-1094995529;i=g;return n|0}}while(0);if((l|0)==0){$=k+2098188|0}else{c[d+304>>2]=1;E=k+2098188|0;UGb(E|0,l|0,1024)|0;$=E}UGb(c[d+4>>2]|0,$|0,1024)|0;c[e>>2]=1;n=j;i=g;return n|0}function QGa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=a+60|0;f=c[e>>2]|0;g=a+792|0;h=c[g>>2]|0;do{if((h|0)<9){j=c[a+100>>2]|0;k=(j|0)>1;if(k){l=c[a+96>>2]|0;m=j-((de((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&65535)|0}else{m=0}l=(h|0)<8;if(l|k^1){n=l?11:8}else{n=(m|0)!=0?11:8}c[a+140>>2]=n}else{if((h|0)>=33){o=-1094995529;i=b;return o|0}l=c[a+52>>2]|0;if((l|0)==1346716996){break}else if((l|0)==1312966482){c[a+140>>2]=62;break}else if((l|0)==943867730){c[a+140>>2]=30;break}else{if((h|0)==24){c[a+140>>2]=296;break}else if((h|0)==32){c[a+140>>2]=28;break}else{DDb(a,2243504,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;o=-1163346256;i=b;return o|0}}}}while(0);h=a+120|0;n=hDb(c[h>>2]|0,c[a+124>>2]|0,0,a)|0;if((n|0)!=0){o=n;i=b;return o|0}n=(c[h>>2]|0)+15>>3&-2;c[f+4>>2]=n;h=WDb(n+16|0)|0;c[f+8>>2]=h;if((h|0)==0){o=-12;i=b;return o|0}c[f+32>>2]=c[g>>2];g=ICb()|0;c[f>>2]=g;if((g|0)==0){g=c[e>>2]|0;JCb(g);$Db(g+8|0);$Db(g+12|0);$Db(g+16|0);o=-12;i=b;return o|0}else{g=TGa(a,0)|0;o=(g|0)<0?g:0;i=b;return o|0}return 0}function RGa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0;j=i;k=e+60|0;l=c[k>>2]|0;m=c[h+28>>2]|0;if((m|0)>1){n=c[h+24>>2]|0;o=n;p=(de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;q=m-p|0;r=n+p|0}else{q=0;r=0}p=r+q|0;n=TGa(e,h)|0;if((n|0)<0){s=n;i=j;return s|0}n=l;h=$$a(e,c[n>>2]|0)|0;if((h|0)<0){s=h;i=j;return s|0}h=l+52|0;do{if((c[h>>2]|0)==0){if((c[e+792>>2]|0)>=9){break}if((c[e+140>>2]|0)==11){m=UGa(e,c[(c[n>>2]|0)+4>>2]|0)|0;if((m|0)<0){s=m}else{break}i=j;return s|0}if((c[e+140>>2]|0)!=30){break}m=UGa(e,c[l+24>>2]|0)|0;if((m|0)<0){s=m}else{break}i=j;return s|0}}while(0);c[h>>2]=1;h=c[l+28>>2]|0;a:do{if((h|0)==0){m=c[e+52>>2]|0;if((m|0)==1296190537){o=c[e+140>>2]|0;if((o|0)==11|(o|0)==8){o=e+124|0;if((c[o>>2]|0)<=0){break}t=e+120|0;u=l+32|0;v=l+4|0;w=p;x=0;y=r;while(1){z=c[n>>2]|0;A=ba(c[z+32>>2]|0,x)|0;B=(c[z>>2]|0)+A|0;TGb(B|0,0,c[t>>2]|0)|0;if((c[u>>2]|0)!=0&y>>>0<p>>>0){A=0;z=y;C=c[v>>2]|0;while(1){D=w-z|0;if((A|0)>7){yDb(0,24,1940040,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E}else{F=B;G=z;H=(C|0)>(D|0)?D:C;while(1){D=F;I=563696+(A<<11)+((d[G]|0)<<3)|0;J=c[I+4>>2]|c[D+4>>2];c[D>>2]=c[I>>2]|c[D>>2];c[D+4>>2]=J;J=H-1|0;if((J|0)==0){break}else{F=F+8|0;G=G+1|0;H=J}}}H=c[v>>2]|0;G=z+H|0;F=A+1|0;if(F>>>0<(c[u>>2]|0)>>>0&G>>>0<p>>>0){A=F;z=G;C=H}else{K=G;break}}}else{K=y}C=x+1|0;if((C|0)<(c[o>>2]|0)){x=C;y=K}else{break a}}}y=e+124|0;x=(c[y>>2]|0)>0;if((c[l+36>>2]|0)==0){if(!x){break}o=e+120|0;u=l+32|0;v=l+4|0;w=p;t=0;C=r;while(1){z=c[n>>2]|0;A=ba(c[z+32>>2]|0,t)|0;B=(c[z>>2]|0)+A|0;TGb(B|0,0,c[o>>2]<<2|0)|0;if((c[u>>2]|0)!=0&C>>>0<p>>>0){A=B;B=0;z=C;G=c[v>>2]|0;while(1){H=w-z|0;F=A;J=z;D=(G|0)>(H|0)?H:G;while(1){H=(d[J]|0)>>>2;I=H&60;L=I|1;c[F>>2]=c[F>>2]|c[580080+(B<<8)+(I<<2)>>2];I=F+4|0;c[I>>2]=c[I>>2]|c[580080+(B<<8)+(L<<2)>>2];I=F+8|0;c[I>>2]=c[I>>2]|c[580080+(B<<8)+(L+1<<2)>>2];L=F+12|0;c[L>>2]=c[L>>2]|c[580080+(B<<8)+((H|3)<<2)>>2];H=(d[J]|0)<<2&60;L=H|1;I=F+16|0;c[I>>2]=c[I>>2]|c[580080+(B<<8)+(H<<2)>>2];I=F+20|0;c[I>>2]=c[I>>2]|c[580080+(B<<8)+(L<<2)>>2];I=F+24|0;c[I>>2]=c[I>>2]|c[580080+(B<<8)+(L+1<<2)>>2];L=F+28|0;c[L>>2]=c[L>>2]|c[580080+(B<<8)+((H|3)<<2)>>2];H=D-1|0;if((H|0)==0){break}else{F=F+32|0;J=J+1|0;D=H}}D=c[v>>2]|0;J=z+D|0;F=B+1|0;if(F>>>0<(c[u>>2]|0)>>>0&J>>>0<p>>>0){B=F;z=J;G=D}else{M=J;break}}}else{M=C}G=t+1|0;if((G|0)<(c[y>>2]|0)){t=G;C=M}else{break a}}}if(!x){break}C=l+12|0;t=l+4|0;u=l+32|0;v=l+16|0;w=p;o=0;G=r;while(1){z=c[n>>2]|0;B=ba(c[z+32>>2]|0,o)|0;A=(c[z>>2]|0)+B|0;TGb(c[C>>2]|0,0,c[t>>2]<<3|0)|0;B=c[t>>2]|0;if((c[u>>2]|0)!=0&G>>>0<p>>>0){z=0;J=G;D=B;while(1){F=w-J|0;if((z|0)>7){yDb(0,24,1940040,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E}else{H=c[C>>2]|0;L=J;I=(D|0)>(F|0)?F:D;while(1){F=H;N=563696+(z<<11)+((d[L]|0)<<3)|0;O=c[N+4>>2]|c[F+4>>2];c[F>>2]=c[N>>2]|c[F>>2];c[F+4>>2]=O;O=I-1|0;if((O|0)==0){break}else{H=H+8|0;L=L+1|0;I=O}}}I=c[t>>2]|0;L=J+I|0;H=z+1|0;if(H>>>0<(c[u>>2]|0)>>>0&L>>>0<p>>>0){z=H;J=L;D=I}else{P=L;Q=I;break}}}else{P=G;Q=B}VGa(A,c[C>>2]|0,c[v>>2]|0,Q);D=o+1|0;if((D|0)<(c[y>>2]|0)){o=D;G=P}else{break}}}else if((m|0)==1346716996){G=e+140|0;o=bFb(c[G>>2]|0)|0;y=e+120|0;v=c[y>>2]|0;C=ba(($Eb(o)|0)>>3,v)|0;v=e+124|0;if(!((c[v>>2]|0)>0&(q|0)>0)){break}o=p;u=0;t=r;do{w=c[n>>2]|0;x=ba(c[w+32>>2]|0,u)|0;D=c[w>>2]|0;w=o-t|0;UGb(D+x|0,t|0,(C|0)>(w|0)?w:C)|0;t=t+C|0;do{if((c[G>>2]|0)==28){if((c[y>>2]|0)>0){R=0}else{break}do{w=D+((R<<2|3)+x)|0;J=a[w]|0;a[w]=J&-16|(J&255)>>>4;R=R+1|0;}while((R|0)<(c[y>>2]|0))}}while(0);u=u+1|0;}while((u|0)<(c[v>>2]|0)&t>>>0<p>>>0)}else if((m|0)==1296188225){t=c[e+140>>2]|0;if((t|0)==11|(t|0)==8){t=c[n>>2]|0;v=e+124|0;TGb(c[t>>2]|0,0,ba(c[t+32>>2]|0,c[v>>2]|0)|0)|0;t=l+32|0;u=c[t>>2]|0;if((u|0)==0){break}y=l+4|0;G=p;C=0;o=r;x=c[v>>2]|0;D=u;while(1){if((x|0)>0&o>>>0<p>>>0){if((C|0)>7){u=0;A=o;while(1){yDb(0,24,1940040,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;B=c[v>>2]|0;J=A+(c[y>>2]|0)|0;w=u+1|0;if((w|0)<(B|0)&J>>>0<p>>>0){u=w;A=J}else{S=J;T=B;break}}}else{A=0;u=o;B=c[y>>2]|0;while(1){J=c[n>>2]|0;w=G-u|0;z=ba(c[J+32>>2]|0,A)|0;I=(c[J>>2]|0)+z|0;z=u;J=(B|0)>(w|0)?w:B;while(1){w=I;L=563696+(C<<11)+((d[z]|0)<<3)|0;H=c[L+4>>2]|c[w+4>>2];c[w>>2]=c[L>>2]|c[w>>2];c[w+4>>2]=H;H=J-1|0;if((H|0)==0){break}else{I=I+8|0;z=z+1|0;J=H}}J=c[y>>2]|0;z=c[v>>2]|0;I=u+J|0;H=A+1|0;if((H|0)<(z|0)&I>>>0<p>>>0){A=H;u=I;B=J}else{S=I;T=z;break}}}U=S;V=T;W=c[t>>2]|0}else{U=o;V=x;W=D}B=C+1|0;if(B>>>0<W>>>0){C=B;o=U;x=V;D=W}else{break a}}}if((c[l+36>>2]|0)==0){D=c[k>>2]|0;x=c[D+32>>2]|0;o=c[D+36>>2]|0;DDb(e,1968512,(E=i,i=i+24|0,c[E>>2]=c[D+28>>2],c[E+8>>2]=x,c[E+16>>2]=o,E)|0);i=E;s=-1094995529;i=j;return s|0}o=c[n>>2]|0;x=e+124|0;TGb(c[o>>2]|0,0,ba(c[o+32>>2]|0,c[x>>2]|0)|0)|0;if((c[x>>2]|0)<=0){break}o=l+12|0;D=l+4|0;C=l+32|0;t=l+16|0;v=p;y=0;do{G=c[n>>2]|0;B=ba(c[G+32>>2]|0,y)|0;u=(c[G>>2]|0)+B|0;TGb(c[o>>2]|0,0,c[D>>2]<<3|0)|0;b:do{if((c[C>>2]|0)!=0){B=0;do{G=(ba(c[x>>2]|0,B)|0)+y|0;A=c[D>>2]|0;z=ba(G,A)|0;G=r+z|0;if((z|0)>=(q|0)){break b}z=v-G|0;if((B|0)>7){yDb(0,24,1940040,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E}else{I=c[o>>2]|0;J=G;G=(A|0)>(z|0)?z:A;while(1){A=I;z=563696+(B<<11)+((d[J]|0)<<3)|0;H=c[z+4>>2]|c[A+4>>2];c[A>>2]=c[z>>2]|c[A>>2];c[A+4>>2]=H;H=G-1|0;if((H|0)==0){break}else{I=I+8|0;J=J+1|0;G=H}}}B=B+1|0;}while(B>>>0<(c[C>>2]|0)>>>0)}}while(0);VGa(u,c[o>>2]|0,c[t>>2]|0,c[D>>2]|0);y=y+1|0;}while((y|0)<(c[x>>2]|0))}else if((m|0)==541934160){x=c[e+140>>2]|0;if((x|0)==11|(x|0)==8){x=e+124|0;if(!((c[x>>2]|0)>0&(q|0)>0)){break}y=e+120|0;D=p;t=0;o=r;C=c[y>>2]|0;while(1){v=c[n>>2]|0;B=ba(c[v+32>>2]|0,t)|0;G=D-o|0;UGb((c[v>>2]|0)+B|0,o|0,(C|0)>(G|0)?G:C)|0;C=c[y>>2]|0;o=o+(((C|0)%2|0)+C)|0;t=t+1|0;if(!((t|0)<(c[x>>2]|0)&p>>>0>o>>>0)){break a}}}if((c[l+36>>2]|0)==0){o=c[k>>2]|0;x=c[o+32>>2]|0;t=c[o+36>>2]|0;DDb(e,1968512,(E=i,i=i+24|0,c[E>>2]=c[o+28>>2],c[E+8>>2]=x,c[E+16>>2]=t,E)|0);i=E;s=-1094995529;i=j;return s|0}t=e+124|0;if(!((c[t>>2]|0)>0&(q|0)>0)){break}x=l+12|0;o=e+120|0;C=p;y=l+16|0;D=l+4|0;m=0;G=r;do{B=c[n>>2]|0;v=ba(c[B+32>>2]|0,m)|0;J=(c[B>>2]|0)+v|0;v=c[o>>2]|0;B=C-G|0;UGb(c[x>>2]|0,G|0,(v|0)>(B|0)?B:v)|0;v=c[o>>2]|0;G=G+((v&1)+v)|0;VGa(J,c[x>>2]|0,c[y>>2]|0,c[D>>2]|0);m=m+1|0;}while((m|0)<(c[t>>2]|0)&p>>>0>G>>>0)}else{break}}else if((h|0)==4){if(!((q|0)>-1)){yDb(0,0,2187104,(E=i,i=i+24|0,c[E>>2]=2109880,c[E+8>>2]=2051704,c[E+16>>2]=135,E)|0);i=E;Cd();return 0}G=c[e+52>>2]|0;if((G|0)==1312966482){t=c[n>>2]|0;m=c[t>>2]|0;D=c[e+120>>2]|0;y=c[e+124>>2]|0;x=c[t+32>>2]|0;t=p;if(q>>>0>1>>>0){X=0;Y=0;Z=r}else{break}while(1){o=Z+2|0;C=Z;J=de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0;C=J&7;v=(J&65535)>>>4;if((C|0)==0){if((t-o|0)<1){_=o;$=223}else{J=Z+3|0;B=a[o]|0;if(B<<24>>24==0){_=J;$=223}else{aa=B&255;ca=J}}if(($|0)==223){$=0;if((t-_|0)<2){break a}J=_;B=(d[J]|d[J+1|0]<<8)<<16>>16;J=(de(B|0)|0)&65535;if(B<<16>>16==0){break a}else{aa=J;ca=_+2|0}}if((aa|0)==0){da=X;ea=Y;fa=ca}else{ga=ca;ha=aa;$=226}}else{ga=o;ha=C;$=226}if(($|0)==226){$=0;C=X;o=Y;J=0;while(1){b[m+((C<<1)+(ba(o,x)|0))>>1]=v;B=C+1|0;if((B|0)<(D|0)){ia=o;ja=B}else{B=o+1|0;if((B|0)<(y|0)){ia=B;ja=0}else{break a}}B=J+1|0;if((B|0)<(ha|0)){C=ja;o=ia;J=B}else{da=ja;ea=ia;fa=ga;break}}}if((t-fa|0)>>>0>1>>>0){X=da;Y=ea;Z=fa}else{break}}}else if((G|0)==943867730){t=c[n>>2]|0;y=c[t>>2]|0;D=c[e+120>>2]|0;x=c[e+124>>2]|0;m=c[t+32>>2]|0;t=p;if(q>>>0>3>>>0){ka=0;la=0;ma=r}else{break}while(1){if((t-ma|0)<3){na=-16777216;oa=ma}else{na=(d[ma]|0)<<16|(d[ma+1|0]|0)<<8|(d[ma+2|0]|0)|-16777216;oa=ma+3|0}if((t-oa|0)<1){pa=oa;$=209}else{J=oa+1|0;o=a[oa]&127;if((o|0)==0){pa=J;$=209}else{qa=J;ra=o;$=214}}if(($|0)==209){$=0;if((t-pa|0)<1){sa=pa;$=211}else{o=pa+1|0;J=a[pa]|0;if(J<<24>>24==0){sa=o;$=211}else{ta=J&255;ua=o}}if(($|0)==211){$=0;if((t-sa|0)<2){break a}o=sa;J=(d[o]|d[o+1|0]<<8)<<16>>16;o=(de(J|0)|0)&65535;if(J<<16>>16==0){break a}else{ta=o;ua=sa+2|0}}if((ta|0)==0){va=ka;wa=la;xa=ua}else{qa=ua;ra=ta;$=214}}if(($|0)==214){$=0;o=ka;J=0;C=la;while(1){c[y+((ba(o,m)|0)+(C<<2))>>2]=na;v=C+1|0;if((v|0)<(D|0)){ya=v;za=o}else{v=o+1|0;if((v|0)<(x|0)){ya=0;za=v}else{break a}}v=J+1|0;if((v|0)<(ra|0)){o=za;J=v;C=ya}else{va=za;wa=ya;xa=qa;break}}}if((t-xa|0)>>>0>3>>>0){ka=va;la=wa;ma=xa}else{break}}}else{t=c[k>>2]|0;x=c[t+32>>2]|0;D=c[t+36>>2]|0;DDb(e,1968512,(E=i,i=i+24|0,c[E>>2]=c[t+28>>2],c[E+8>>2]=x,c[E+16>>2]=D,E)|0);i=E;s=-1094995529;i=j;return s|0}}else if((h|0)==1){D=c[e+52>>2]|0;if((D|0)==1346716996){if(($Eb(bFb(c[e+140>>2]|0)|0)|0)!=32){x=c[k>>2]|0;t=c[x+32>>2]|0;m=c[x+36>>2]|0;DDb(e,1968512,(E=i,i=i+24|0,c[E>>2]=c[x+28>>2],c[E+8>>2]=t,c[E+16>>2]=m,E)|0);i=E;s=-1094995529;i=j;return s|0}m=c[n>>2]|0;t=c[m>>2]|0;x=c[e+120>>2]|0;y=c[e+124>>2]|0;G=c[m+32>>2]|0;if((q|0)<5){break}m=0;C=0;J=r;o=r+5|0;while(1){v=J+1|0;u=a[J]|0;B=u<<24>>24;do{if(u<<24>>24>-1){I=B+1|0;if((I|0)>0){Aa=0;Ba=m;Ca=C;Da=v}else{Ea=v;Fa=C;Ga=m;break}while(1){H=I-Aa|0;A=(H|0)>(x|0)?x:H;H=A<<2;UGb(t+((ba(Ba,G)|0)+(Ca<<2))|0,Da|0,H)|0;z=Da+H|0;H=A+Ca|0;if((H|0)<(x|0)){Ha=H;Ia=Ba}else{H=Ba+1|0;if((H|0)<(y|0)){Ha=0;Ia=H}else{break a}}H=Aa+1+A|0;if((H|0)<(I|0)){Aa=H;Ba=Ia;Ca=Ha;Da=z}else{Ea=z;Fa=Ha;Ga=Ia;break}}}else{I=1-B|0;z=v;H=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;if((I|0)>0){Ja=0;Ka=m;La=C}else{Ea=o;Fa=C;Ga=m;break}while(1){c[t+((ba(Ka,G)|0)+(La<<2))>>2]=H;z=La+1|0;if((z|0)<(x|0)){Ma=z;Na=Ka}else{z=Ka+1|0;if((z|0)<(y|0)){Ma=0;Na=z}else{break a}}z=Ja+1|0;if((z|0)<(I|0)){Ja=z;Ka=Na;La=Ma}else{Ea=o;Fa=Ma;Ga=Na;break}}}}while(0);v=Ea+5|0;if(v>>>0>p>>>0){break}else{m=Ga;C=Fa;J=Ea;o=v}}}else if((D|0)==541934160){o=c[e+140>>2]|0;if((o|0)==11|(o|0)==8){o=e+124|0;if((c[o>>2]|0)<=0){break}J=e+120|0;C=p;m=0;y=r;while(1){x=c[n>>2]|0;G=ba(c[x+32>>2]|0,m)|0;t=c[x>>2]|0;x=c[J>>2]|0;c:do{if((x|0)==0){Oa=y}else{v=0;B=y;d:while(1){Pa=B;while(1){if(!(Pa>>>0<p>>>0)){break d}Qa=Pa+1|0;u=a[Pa]|0;Ra=u<<24>>24;if(u<<24>>24>-1){$=166;break}if(u<<24>>24==-128){Pa=Qa}else{$=167;break}}if(($|0)==166){$=0;u=Ra+1|0;I=x-v|0;H=u>>>0>I>>>0?I:u;u=C-Qa|0;I=H>>>0>u>>>0?u:H;UGb(t+(v+G)|0,Qa|0,I)|0;Sa=Pa+(I+1)|0;Ta=I}else if(($|0)==167){$=0;I=1-Ra|0;H=x-v|0;u=I>>>0>H>>>0?H:I;TGb(t+(v+G)|0,a[Qa]|0,u|0)|0;Sa=Pa+2|0;Ta=u}u=Ta+v|0;if(u>>>0<x>>>0){v=u;B=Sa}else{Oa=Sa;break c}}yDb(0,24,2006296,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;TGb(t+(v+G)|0,0,x-v|0)|0;Oa=Pa}}while(0);x=m+1|0;if((x|0)>=(c[o>>2]|0)){break a}m=x;y=y+(Oa-y)|0}}if((c[l+36>>2]|0)==0){y=c[k>>2]|0;m=c[y+32>>2]|0;o=c[y+36>>2]|0;DDb(e,1968512,(E=i,i=i+24|0,c[E>>2]=c[y+28>>2],c[E+8>>2]=m,c[E+16>>2]=o,E)|0);i=E;s=-1094995529;i=j;return s|0}o=e+124|0;if((c[o>>2]|0)<=0){break}m=l+12|0;y=e+120|0;C=p;J=l+16|0;x=l+4|0;G=0;t=r;while(1){B=c[n>>2]|0;u=ba(c[B+32>>2]|0,G)|0;I=(c[B>>2]|0)+u|0;u=c[m>>2]|0;B=c[y>>2]|0;e:do{if((B|0)==0){Ua=t}else{H=0;z=t;f:while(1){Va=z;while(1){if(!(Va>>>0<p>>>0)){break f}Wa=Va+1|0;A=a[Va]|0;Xa=A<<24>>24;if(A<<24>>24>-1){$=180;break}if(A<<24>>24==-128){Va=Wa}else{$=181;break}}if(($|0)==180){$=0;A=Xa+1|0;w=B-H|0;L=A>>>0>w>>>0?w:A;A=C-Wa|0;w=L>>>0>A>>>0?A:L;UGb(u+H|0,Wa|0,w)|0;Ya=Va+(w+1)|0;Za=w}else if(($|0)==181){$=0;w=1-Xa|0;L=B-H|0;A=w>>>0>L>>>0?L:w;TGb(u+H|0,a[Wa]|0,A|0)|0;Ya=Va+2|0;Za=A}A=Za+H|0;if(A>>>0<B>>>0){H=A;z=Ya}else{Ua=Ya;break e}}yDb(0,24,2006296,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;TGb(u+H|0,0,B-H|0)|0;Ua=Va}}while(0);VGa(I,c[m>>2]|0,c[J>>2]|0,c[x>>2]|0);B=G+1|0;if((B|0)<(c[o>>2]|0)){G=B;t=t+(Ua-t)|0}else{break}}}else if((D|0)==1296190537){t=c[e+140>>2]|0;if((t|0)==11|(t|0)==8){t=e+124|0;if((c[t>>2]|0)<=0){break}G=e+120|0;o=l+32|0;x=l+8|0;J=l+4|0;m=p;C=0;y=r;while(1){B=c[n>>2]|0;u=ba(c[B+32>>2]|0,C)|0;z=(c[B>>2]|0)+u|0;TGb(z|0,0,c[G>>2]|0)|0;if((c[o>>2]|0)==0){_a=y}else{u=0;B=y;while(1){v=c[x>>2]|0;A=c[J>>2]|0;g:do{if((A|0)==0){$a=B}else{w=0;L=B;h:while(1){ab=L;while(1){if(!(ab>>>0<p>>>0)){break h}bb=ab+1|0;O=a[ab]|0;cb=O<<24>>24;if(O<<24>>24>-1){$=91;break}if(O<<24>>24==-128){ab=bb}else{$=92;break}}if(($|0)==91){$=0;O=cb+1|0;F=A-w|0;N=O>>>0>F>>>0?F:O;O=m-bb|0;F=N>>>0>O>>>0?O:N;UGb(v+w|0,bb|0,F)|0;db=ab+(F+1)|0;eb=F}else if(($|0)==92){$=0;F=1-cb|0;N=A-w|0;O=F>>>0>N>>>0?N:F;TGb(v+w|0,a[bb]|0,O|0)|0;db=ab+2|0;eb=O}O=eb+w|0;if(O>>>0<A>>>0){w=O;L=db}else{$a=db;break g}}yDb(0,24,2006296,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;TGb(v+w|0,0,A-w|0)|0;$a=ab}}while(0);A=B+($a-B)|0;if((u|0)>7){yDb(0,24,1940040,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E}else{v=z;H=c[x>>2]|0;L=c[J>>2]|0;while(1){O=v;F=563696+(u<<11)+((d[H]|0)<<3)|0;N=c[F+4>>2]|c[O+4>>2];c[O>>2]=c[F>>2]|c[O>>2];c[O+4>>2]=N;N=L-1|0;if((N|0)==0){break}else{v=v+8|0;H=H+1|0;L=N}}}L=u+1|0;if(L>>>0<(c[o>>2]|0)>>>0){u=L;B=A}else{_a=A;break}}}B=C+1|0;if((B|0)<(c[t>>2]|0)){C=B;y=_a}else{break a}}}if((c[e+792>>2]|0)<9){y=e+124|0;if((c[y>>2]|0)<=0){break}C=l+20|0;t=e+120|0;o=l+32|0;J=l+24|0;x=l+8|0;m=l+4|0;G=p;D=0;B=r;u=c[C>>2]|0;while(1){z=c[n>>2]|0;I=ba(c[z+32>>2]|0,D)|0;L=(c[z>>2]|0)+I|0;TGb(u|0,0,c[t>>2]<<2|0)|0;if((c[o>>2]|0)==0){fb=B;gb=c[C>>2]|0}else{I=0;z=B;H=c[x>>2]|0;while(1){v=c[m>>2]|0;i:do{if((v|0)==0){hb=z}else{N=0;O=z;j:while(1){ib=O;while(1){if(!(ib>>>0<p>>>0)){break j}jb=ib+1|0;F=a[ib]|0;kb=F<<24>>24;if(F<<24>>24>-1){$=112;break}if(F<<24>>24==-128){ib=jb}else{$=113;break}}if(($|0)==112){$=0;F=kb+1|0;lb=v-N|0;mb=F>>>0>lb>>>0?lb:F;F=G-jb|0;lb=mb>>>0>F>>>0?F:mb;UGb(H+N|0,jb|0,lb)|0;nb=ib+(lb+1)|0;ob=lb}else if(($|0)==113){$=0;lb=1-kb|0;mb=v-N|0;F=lb>>>0>mb>>>0?mb:lb;TGb(H+N|0,a[jb]|0,F|0)|0;nb=ib+2|0;ob=F}F=ob+N|0;if(F>>>0<v>>>0){N=F;O=nb}else{hb=nb;break i}}yDb(0,24,2006296,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;TGb(H+N|0,0,v-N|0)|0;hb=ib}}while(0);v=hb-z|0;A=c[C>>2]|0;O=c[x>>2]|0;w=A;F=O;lb=c[m>>2]|0;while(1){mb=(d[F]|0)>>>2;pb=mb&60;qb=pb|1;c[w>>2]=c[w>>2]|c[580080+(I<<8)+(pb<<2)>>2];pb=w+4|0;c[pb>>2]=c[pb>>2]|c[580080+(I<<8)+(qb<<2)>>2];pb=w+8|0;c[pb>>2]=c[pb>>2]|c[580080+(I<<8)+(qb+1<<2)>>2];qb=w+12|0;c[qb>>2]=c[qb>>2]|c[580080+(I<<8)+((mb|3)<<2)>>2];mb=(d[F]|0)<<2&60;qb=mb|1;pb=w+16|0;c[pb>>2]=c[pb>>2]|c[580080+(I<<8)+(mb<<2)>>2];pb=w+20|0;c[pb>>2]=c[pb>>2]|c[580080+(I<<8)+(qb<<2)>>2];pb=w+24|0;c[pb>>2]=c[pb>>2]|c[580080+(I<<8)+(qb+1<<2)>>2];qb=w+28|0;c[qb>>2]=c[qb>>2]|c[580080+(I<<8)+((mb|3)<<2)>>2];mb=lb-1|0;if((mb|0)==0){break}else{w=w+32|0;F=F+1|0;lb=mb}}lb=z+v|0;F=I+1|0;if(F>>>0<(c[o>>2]|0)>>>0){I=F;z=lb;H=O}else{fb=lb;gb=A;break}}}H=c[J>>2]|0;z=c[t>>2]|0;I=L;lb=gb;while(1){c[I>>2]=c[H+(c[lb>>2]<<2)>>2];F=z-1|0;if((F|0)==0){break}else{z=F;I=I+4|0;lb=lb+4|0}}lb=D+1|0;if((lb|0)<(c[y>>2]|0)){D=lb;B=fb;u=gb}else{break a}}}u=e+124|0;B=(c[u>>2]|0)>0;if((c[l+36>>2]|0)==0){if(!B){break}D=e+120|0;y=l+32|0;t=l+8|0;J=l+4|0;o=p;m=0;x=r;while(1){C=c[n>>2]|0;G=ba(c[C+32>>2]|0,m)|0;lb=(c[C>>2]|0)+G|0;TGb(lb|0,0,c[D>>2]<<2|0)|0;if((c[y>>2]|0)==0){rb=x}else{G=lb;lb=0;C=x;I=c[t>>2]|0;while(1){z=c[J>>2]|0;k:do{if((z|0)==0){sb=C}else{H=0;L=C;l:while(1){tb=L;while(1){if(!(tb>>>0<p>>>0)){break l}ub=tb+1|0;F=a[tb]|0;vb=F<<24>>24;if(F<<24>>24>-1){$=150;break}if(F<<24>>24==-128){tb=ub}else{$=151;break}}if(($|0)==150){$=0;F=vb+1|0;w=z-H|0;mb=F>>>0>w>>>0?w:F;F=o-ub|0;w=mb>>>0>F>>>0?F:mb;UGb(I+H|0,ub|0,w)|0;wb=tb+(w+1)|0;xb=w}else if(($|0)==151){$=0;w=1-vb|0;mb=z-H|0;F=w>>>0>mb>>>0?mb:w;TGb(I+H|0,a[ub]|0,F|0)|0;wb=tb+2|0;xb=F}F=xb+H|0;if(F>>>0<z>>>0){H=F;L=wb}else{sb=wb;break k}}yDb(0,24,2006296,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;TGb(I+H|0,0,z-H|0)|0;sb=tb}}while(0);z=sb-C|0;A=c[t>>2]|0;O=G;v=A;L=c[J>>2]|0;while(1){N=(d[v]|0)>>>2;F=N&60;w=F|1;c[O>>2]=c[O>>2]|c[580080+(lb<<8)+(F<<2)>>2];F=O+4|0;c[F>>2]=c[F>>2]|c[580080+(lb<<8)+(w<<2)>>2];F=O+8|0;c[F>>2]=c[F>>2]|c[580080+(lb<<8)+(w+1<<2)>>2];w=O+12|0;c[w>>2]=c[w>>2]|c[580080+(lb<<8)+((N|3)<<2)>>2];N=(d[v]|0)<<2&60;w=N|1;F=O+16|0;c[F>>2]=c[F>>2]|c[580080+(lb<<8)+(N<<2)>>2];F=O+20|0;c[F>>2]=c[F>>2]|c[580080+(lb<<8)+(w<<2)>>2];F=O+24|0;c[F>>2]=c[F>>2]|c[580080+(lb<<8)+(w+1<<2)>>2];w=O+28|0;c[w>>2]=c[w>>2]|c[580080+(lb<<8)+((N|3)<<2)>>2];N=L-1|0;if((N|0)==0){break}else{O=O+32|0;v=v+1|0;L=N}}L=C+z|0;v=lb+1|0;if(v>>>0<(c[y>>2]|0)>>>0){lb=v;C=L;I=A}else{rb=L;break}}}I=m+1|0;if((I|0)<(c[u>>2]|0)){m=I;x=rb}else{break a}}}if(!B){break}x=l+12|0;m=l+4|0;y=l+32|0;J=l+16|0;t=l+8|0;o=p;D=0;I=r;while(1){C=c[n>>2]|0;lb=ba(c[C+32>>2]|0,D)|0;G=(c[C>>2]|0)+lb|0;TGb(c[x>>2]|0,0,c[m>>2]<<3|0)|0;if((c[y>>2]|0)==0){yb=I}else{lb=0;C=I;while(1){L=c[t>>2]|0;v=c[m>>2]|0;m:do{if((v|0)==0){zb=C}else{O=0;N=C;n:while(1){Ab=N;while(1){if(!(Ab>>>0<p>>>0)){break n}Bb=Ab+1|0;w=a[Ab]|0;Cb=w<<24>>24;if(w<<24>>24>-1){$=133;break}if(w<<24>>24==-128){Ab=Bb}else{$=134;break}}if(($|0)==133){$=0;w=Cb+1|0;F=v-O|0;mb=w>>>0>F>>>0?F:w;w=o-Bb|0;F=mb>>>0>w>>>0?w:mb;UGb(L+O|0,Bb|0,F)|0;Db=Ab+(F+1)|0;Eb=F}else if(($|0)==134){$=0;F=1-Cb|0;mb=v-O|0;w=F>>>0>mb>>>0?mb:F;TGb(L+O|0,a[Bb]|0,w|0)|0;Db=Ab+2|0;Eb=w}w=Eb+O|0;if(w>>>0<v>>>0){O=w;N=Db}else{zb=Db;break m}}yDb(0,24,2006296,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;TGb(L+O|0,0,v-O|0)|0;zb=Ab}}while(0);v=C+(zb-C)|0;if((lb|0)>7){yDb(0,24,1940040,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E}else{L=c[x>>2]|0;A=c[t>>2]|0;z=c[m>>2]|0;while(1){N=L;H=563696+(lb<<11)+((d[A]|0)<<3)|0;w=c[H+4>>2]|c[N+4>>2];c[N>>2]=c[H>>2]|c[N>>2];c[N+4>>2]=w;w=z-1|0;if((w|0)==0){break}else{L=L+8|0;A=A+1|0;z=w}}}z=lb+1|0;if(z>>>0<(c[y>>2]|0)>>>0){lb=z;C=v}else{yb=v;break}}}VGa(G,c[x>>2]|0,c[J>>2]|0,c[m>>2]|0);C=D+1|0;if((C|0)<(c[u>>2]|0)){D=C;I=yb}else{break}}}else{break}}else if((h|0)==5){if((c[e+52>>2]|0)!=1346716996){I=c[k>>2]|0;D=c[I+32>>2]|0;u=c[I+36>>2]|0;DDb(e,1968512,(E=i,i=i+24|0,c[E>>2]=c[I+28>>2],c[E+8>>2]=D,c[E+16>>2]=u,E)|0);i=E;s=-1094995529;i=j;return s|0}if(($Eb(bFb(c[e+140>>2]|0)|0)|0)!=32){u=c[k>>2]|0;D=c[u+32>>2]|0;I=c[u+36>>2]|0;DDb(e,1968512,(E=i,i=i+24|0,c[E>>2]=c[u+28>>2],c[E+8>>2]=D,c[E+16>>2]=I,E)|0);i=E;s=-1094995529;i=j;return s|0}I=c[n>>2]|0;D=c[I>>2]|0;u=c[e+120>>2]|0;m=c[e+124>>2]|0;J=c[I+32>>2]|0;I=l+56|0;x=q<<1;y=~u;t=0;o=0;B=0;while(1){C=o+(ba(B,J)|0)|0;lb=t;z=0;A=0;while(1){if((lb|0)>=(x|0)){break a}L=d[r+(lb>>1)|0]|0;w=b[I+(((lb&1|0)!=0?L&15:L>>>4)<<1)>>1]|0;L=lb+1|0;do{if(w<<16>>16==0){if((L|0)>=(x|0)){break a}N=d[r+(L>>1)|0]|0;H=(L&1|0)!=0?N&15:N>>>4;N=H+1|0;F=lb+2|0;mb=u-A|0;qb=(N|0)>(mb|0)?mb:N;if((qb|0)<=0){Fb=F;Gb=z;Hb=A;break}N=A+y|0;mb=-2-H|0;H=(N|0)>(mb|0);pb=A;Ib=0;while(1){a[D+(C+(pb<<2))|0]=z;Jb=Ib+1|0;if((Jb|0)<(qb|0)){pb=pb+1|0;Ib=Jb}else{break}}Fb=F;Gb=z;Hb=A-1-(H?N:mb)|0}else{Ib=(w&255)+z&255;a[D+(C+(A<<2))|0]=Ib;Fb=L;Gb=Ib;Hb=A+1|0}}while(0);if((Hb|0)<(u|0)){lb=Fb;z=Gb;A=Hb}else{break}}A=o+1|0;if((A|0)>3){z=B+1|0;if((z|0)<(m|0)){Kb=0;Lb=z}else{break a}}else{Kb=A;Lb=B}t=Fb+1&-2;o=Kb;B=Lb}}else{B=c[k>>2]|0;o=c[B+32>>2]|0;t=c[B+36>>2]|0;DDb(e,1968512,(E=i,i=i+24|0,c[E>>2]=c[B+28>>2],c[E+8>>2]=o,c[E+16>>2]=t,E)|0);i=E;s=-1094995529;i=j;return s|0}}while(0);E=MCb(f,c[n>>2]|0)|0;if((E|0)<0){s=E;i=j;return s|0}c[g>>2]=1;s=q;i=j;return s|0}function SGa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b);$Db(b+8|0);$Db(b+12|0);$Db(b+16|0);return 0}function TGa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=c[e+60>>2]|0;j=c[e+100>>2]|0;if((j|0)<2){yDb(e,16,1895280,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}m=e+96|0;n=c[m>>2]|0;o=n;p=de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0;o=p&65535;q=j-o|0;do{if((f|0)==0){if(!((p&65535)>>>0<2>>>0|(q|0)<0)){r=o;s=n;break}yDb(e,16,2332256,(k=i,i=i+16|0,c[k>>2]=o,c[k+8>>2]=q,k)|0);i=k;l=-1094995529;i=g;return l|0}else{j=c[f+28>>2]|0;if((j|0)<2){l=-1094995529;i=g;return l|0}t=c[f+24>>2]|0;u=t;v=de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=v&65535;w=j-u|0;if(!((v&65535)>>>0<2>>>0|(w|0)<2)){r=u;s=t;break}yDb(e,16,2352408,(k=i,i=i+16|0,c[k>>2]=u,c[k+8>>2]=w,k)|0);i=k;l=-1094995529;i=g;return l|0}}while(0);if(!(r>>>0>40>>>0)){l=0;i=g;return l|0}c[h+28>>2]=d[s+2|0]|0;r=a[s+3|0]|0;f=r&255;o=h+32|0;c[o>>2]=f;n=a[s+4|0]|0;p=h+36|0;c[p>>2]=n&255;c[h+40>>2]=d[s+5|0]|0;w=s+6|0;c[h+44>>2]=(de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535;w=d[s+8|0]|0;u=h+48|0;c[u>>2]=w;t=s+9|0;b[h+56>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+11|0;b[h+58>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+13|0;b[h+60>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+15|0;b[h+62>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+17|0;b[h+64>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+19|0;b[h+66>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+21|0;b[h+68>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+23|0;b[h+70>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+25|0;b[h+72>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+27|0;b[h+74>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+29|0;b[h+76>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+31|0;b[h+78>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+33|0;b[h+80>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+35|0;b[h+82>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+37|0;b[h+84>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+39|0;b[h+86>>1]=de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;if((w|0)==0|(w|0)==2){x=f}else if((w|0)==1){y=11}else{yDb(e,16,2289416,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=g;return l|0}if((y|0)==11){do{if((r&255)>>>0>7>>>0&n<<24>>24==0){c[e+140>>2]=30;w=h+20|0;$Db(w);t=h+24|0;$Db(t);s=WDb(c[h+4>>2]<<5|16)|0;c[w>>2]=s;if((s|0)==0){l=-12;i=g;return l|0}s=c[o>>2]|0;if(s>>>0>16>>>0){yDb(e,16,2307936,(k=i,i=i+8|0,c[k>>2]=s,k)|0);i=k;$Db(w);l=-12;i=g;return l|0}v=WDb((8<<s)+16|0)|0;c[t>>2]=v;if((v|0)!=0){z=c[o>>2]|0;break}$Db(w);l=-12;i=g;return l|0}else{z=f}}while(0);f=z+1|0;c[o>>2]=f;x=f}if((x|0)==0|x>>>0>32>>>0){yDb(e,16,2273384,(k=i,i=i+8|0,c[k>>2]=x,k)|0);i=k;l=-1094995529;i=g;return l|0}x=c[p>>2]|0;if(x>>>0>7>>>0){yDb(e,16,2257744,(k=i,i=i+8|0,c[k>>2]=x,k)|0);i=k;l=-1094995529;i=g;return l|0}k=h+12|0;$Db(k);x=h+16|0;e=x;$Db(x);x=c[p>>2]|0;if((x|0)==0){l=0;i=g;return l|0}f=(q|0)/3|0;q=1<<x;x=(f|0)>(q|0)?q:f;f=c[m>>2]|0;m=f;q=(de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535;m=WDb((c[h+4>>2]<<3)+16|0)|0;c[k>>2]=m;if((m|0)==0){l=-12;i=g;return l|0}m=8<<c[p>>2];h=WDb((m<<((c[u>>2]|0)==1)<<2)+16|0)|0;z=h;c[e>>2]=z;if((h|0)==0){$Db(k);l=-12;i=g;return l|0}k=c[p>>2]|0;do{if((x|0)==0){n=1<<k;if((n|0)>0){A=0}else{break}while(1){r=A<<1;c[z+(r<<2)>>2]=-16777216;w=(A*255|0)>>c[p>>2];c[z+((r|1)<<2)>>2]=w|w<<8|w<<16|-16777216;w=A+1|0;if((w|0)<(n|0)){A=w}else{B=n;y=35;break}}}else{TGb(h|0,0,8<<k|0)|0;if((x|0)>0){n=c[e>>2]|0;w=0;do{r=(w*3|0)+q|0;c[n+((w<<1|1)<<2)>>2]=(d[f+(r+2)|0]|0)<<16|(d[f+(r+1)|0]|0)<<8|(d[f+r|0]|0)|-16777216;w=w+1|0;}while((w|0)<(x|0))}B=1<<c[p>>2];y=35}}while(0);do{if((y|0)==35){if((B|0)<=0){break}x=c[e>>2]|0;f=B<<1;q=B*3|0;k=0;do{h=c[p>>2]|0;A=k<<8-h;z=A>>>(h>>>0)|A;A=k+B<<1;c[x+(A<<2)>>2]=-16711681;h=k+f<<1;c[x+(h<<2)>>2]=-256;w=k+q<<1;c[x+(w<<2)>>2]=-65281;c[x+((A|1)<<2)>>2]=z<<16|-16777216;c[x+((h|1)<<2)>>2]=z|-16777216;c[x+((w|1)<<2)>>2]=z<<8|-16777216;k=k+1|0;}while((k|0)<(B|0))}}while(0);if(!((c[u>>2]|0)==1&(m|0)>0)){l=0;i=g;return l|0}u=c[e>>2]|0;e=0;while(1){c[u+((1<<c[o>>2])+e<<2)>>2]=c[u+(e<<2)>>2]|-16777216;B=e+1|0;if((B|0)<(m|0)){e=B}else{l=0;break}}i=g;return l|0}function UGa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[a+60>>2]|0;g=c[a+96>>2]|0;h=g;j=(de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;h=a+792|0;k=c[h>>2]|0;if((k|0)>8){yDb(a,16,1915832,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=e;return m|0}l=1<<k;n=((c[a+100>>2]|0)-j|0)/3|0;a=(n|0)>(l|0)?l:n;a:do{if((a|0)==0){if((l|0)>0){o=0;p=k}else{q=l;break}while(1){n=(o*255|0)>>p;c[b+(o<<2)>>2]=n|n<<8|n<<16|-16777216;n=o+1|0;if((n|0)>=(l|0)){q=l;break a}o=n;p=c[h>>2]|0}}else{if((a|0)>0){r=0}else{q=a;break}do{n=(r*3|0)+j|0;c[b+(r<<2)>>2]=(d[g+n|0]|0)<<16|(d[g+(n+1)|0]|0)<<8|(d[g+(n+2)|0]|0)|-16777216;r=r+1|0;}while((r|0)<(a|0));if((c[f+40>>2]|0)!=0&(a|0)>31){s=0}else{q=a;break}do{n=(s*3|0)+j|0;c[b+(s+32<<2)>>2]=((d[g+(n+1)|0]|0)<<8|(d[g+n|0]|0)<<16|(d[g+(n+2)|0]|0))>>>1&8355711|-16777216;s=s+1|0;}while((s|0)<32);q=(a|0)>64?a:64}}while(0);a=c[f+48>>2]|0;if((a|0)==1){UGb(b+(1<<c[h>>2]<<2)|0,b|0,q<<2)|0;if((q|0)>0){t=0}else{m=0;i=e;return m|0}while(1){s=b+(t<<2)|0;c[s>>2]=c[s>>2]&16777215;s=t+1|0;if((s|0)<(q|0)){t=s}else{m=0;break}}i=e;return m|0}else if((a|0)==2){a=c[f+44>>2]|0;if(!(a>>>0<1<<c[h>>2]>>>0)){m=0;i=e;return m|0}h=b+(a<<2)|0;c[h>>2]=c[h>>2]&16777215;m=0;i=e;return m|0}else{m=0;i=e;return m|0}return 0}function VGa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=a;a=b;b=c[e+4>>2]|0;h=f;while(1){f=(d[a]|0)<<1;i=(d[a+1|0]|0)<<1;j=c[e+(f<<2)>>2]&b|c[e+((f|1)<<2)>>2];c[g>>2]=j;f=j&c[e+(i<<2)>>2]|c[e+((i|1)<<2)>>2];c[g+4>>2]=f;i=(d[a+2|0]|0)<<1;j=(d[a+3|0]|0)<<1;k=c[e+(i<<2)>>2]&f|c[e+((i|1)<<2)>>2];c[g+8>>2]=k;i=k&c[e+(j<<2)>>2]|c[e+((j|1)<<2)>>2];c[g+12>>2]=i;j=(d[a+4|0]|0)<<1;k=(d[a+5|0]|0)<<1;f=c[e+(j<<2)>>2]&i|c[e+((j|1)<<2)>>2];c[g+16>>2]=f;j=f&c[e+(k<<2)>>2]|c[e+((k|1)<<2)>>2];c[g+20>>2]=j;k=(d[a+6|0]|0)<<1;f=(d[a+7|0]|0)<<1;i=c[e+(k<<2)>>2]&j|c[e+((k|1)<<2)>>2];c[g+24>>2]=i;k=i&c[e+(f<<2)>>2]|c[e+((f|1)<<2)>>2];c[g+28>>2]=k;f=h-1|0;if((f|0)==0){break}else{g=g+32|0;a=a+8|0;b=k;h=f}}return}function WGa(e){e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0.0,B=0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0;f=i;i=i+768|0;j=f|0;k=f+256|0;l=f+512|0;m=c[e+60>>2]|0;n=m;o=e+48|0;p=e+416|0;do{if((c[o>>2]|0)==86043){c[p>>2]=1;q=e+416|0;r=5}else{s=c[p>>2]|0;t=e+416|0;if((s|0)<=2){if((s|0)>0){q=t;r=5;break}else{u=t;break}}DDb(e,2289392,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1163346256;i=f;return w|0}}while(0);if((r|0)==5){r=m;p=0;while(1){t=m+((p*7044|0)+6016)|0;c[r+(p*7044|0)+7040>>2]=1;s=0;do{g[r+(p*7044|0)+(s<<2)>>2]=1.0;s=s+1|0;}while((s|0)<32);TGb(t|0,0,512)|0;s=p+1|0;if((s|0)<(c[q>>2]|0)){p=s}else{u=q;break}}}q=m+14088|0;p=q;UXa(q,256);q=0;do{r=p+(q<<2)|0;g[r>>2]=+g[r>>2]*1.4142135623730951;q=q+1|0;}while((q|0)<256);q=m+15112|0;p=m+16136|0;r=m+17160|0;s=m+18184|0;x=0;do{y=+(x|0);z=y*.00390625*3.141592653589793;g[q+(x<<2)>>2]=+T(z)*30517578125.0e-15;g[p+(x<<2)>>2]=+U(z)*30517578125.0e-15;z=(y*4.0+1.0)*.0009765625*3.141592653589793;y=+U(z);A=+T(z);z=y+A;if((x&1|0)==0){g[r+(x<<2)>>2]=z*-1.4142135623730951;g[s+(x<<2)>>2]=(y-A)*1.4142135623730951}else{g[r+(x<<2)>>2]=z*1.4142135623730951;g[s+(x<<2)>>2]=(y-A)*-1.4142135623730951}x=x+1|0;}while((x|0)<128);x=m+19208|0;s=0;while(1){g[x+(s<<2)>>2]=+R(+(s|0));r=s+1|0;if((r|0)<30){s=r}else{B=0;break}}do{s=B<<2;x=d[915072+B|0]|0;r=c[134976+(s<<2)>>2]|0;c[5099076+(B*80|0)>>2]=2547112+(r<<2);p=s|1;q=c[134976+(p<<2)>>2]|0;c[5099084+(B*80|0)>>2]=q-r;N_(5099072+(B*80|0)|0,9,x,915080+(B*72|0)|0,1,1,915368+(B*144|0)|0,2,2,0,0,0,4)|0;c[5099096+(B*80|0)>>2]=2547112+(q<<2);c[5099104+(B*80|0)>>2]=(c[134976+(p+1<<2)>>2]|0)-q;N_(5099092+(B*80|0)|0,9,x,915098+(B*72|0)|0,1,1,915404+(B*144|0)|0,2,2,0,0,0,4)|0;q=c[134976+((s|2)<<2)>>2]|0;c[5099116+(B*80|0)>>2]=2547112+(q<<2);c[5099124+(B*80|0)>>2]=(c[134976+((s|3)<<2)>>2]|0)-q;N_(5099112+(B*80|0)|0,9,x,915116+(B*72|0)|0,1,1,915440+(B*144|0)|0,2,2,0,0,0,4)|0;q=s|3;s=c[134976+(q<<2)>>2]|0;c[5099136+(B*80|0)>>2]=2547112+(s<<2);c[5099144+(B*80|0)>>2]=(c[134976+(q+1<<2)>>2]|0)-s;N_(5099132+(B*80|0)|0,9,x,915134+(B*72|0)|0,1,1,915476+(B*144|0)|0,2,2,0,0,0,4)|0;B=B+1|0;}while((B|0)<4);if((c[o>>2]|0)==86075){A=+(c[e+412>>2]|0);y=A*.0009765625;z=A*.5;A=0.0;o=0;B=0;while(1){x=o+1|0;s=b[1738192+(x<<1)>>1]|0;C=y*+((B&65535)-1+(s&65535)|0);D=C/7500.0;E=+Y(D*D)*3.5+ +Y(C*76.0e-5)*13.0;if((o|0)>0){D=E-A;q=o-1|0;g[n+21800+(q<<2)>>2]=+S(+10.0,+(D*-1.0));g[n+21924+(q<<2)>>2]=+S(+10.0,+(D*-2.7))}h[k+(o<<3)>>3]=C;D=E+.5;F=C;while(1){if(!(F<z)){G=F;break}H=F+.5;I=H/7500.0;if(+Y(I*I)*3.5+ +Y(H*76.0e-5)*13.0>D){G=H;break}else{F=H}}h[l+(o<<3)>>3]=G;F=E+-.5;D=C;while(1){if(!(D>0.0)){J=D;break}H=D+-.5;I=H/7500.0;if(+Y(I*I)*3.5+ +Y(H*76.0e-5)*13.0>F){D=H}else{J=H;break}}h[j+(o<<3)>>3]=J;if((x|0)<32){A=E;o=x;B=s}else{K=0;break}}do{A=+h[l+(K<<3)>>3];B=31;while(1){if((B|0)<=0){break}if(A>+h[k+(B<<3)>>3]){break}else{B=B-1|0}}a[n+21736+K|0]=B+1;A=+h[j+(K<<3)>>3];s=0;while(1){if((s|0)>=32){break}if(A<+h[k+(s<<3)>>3]){break}else{s=s+1|0}}a[n+21768+K|0]=s+255;K=K+1|0;}while((K|0)<32)}else{UGb(m+21736|0,1410064,32)|0;UGb(m+21768|0,1410032,32)|0;UGb(m+21800|0,914368,124)|0;UGb(m+21924|0,914240,124)|0}K=$8(m+20628|0,7,1)|0;if((K|0)==0){Z3(m+19348|0,e);fCb(m+20592|0,c[e+88>>2]&8388608);c[e+420>>2]=8;m=(c[u>>2]|0)==1;u=e+448|0;c[u>>2]=m?4:3;c[u+4>>2]=m?0:0;w=0;i=f;return w|0}else{yDb(e,32,2273360,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=K;i=f;return w|0}return 0}function XGa(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0.0,ra=0.0,sa=0.0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0.0,Ia=0.0,Ja=0,Ka=0.0,La=0,Ma=0,Na=0.0,Oa=0,Pa=0,Qa=0.0,Ra=0,Sa=0,Ta=0.0,Ua=0,Va=0,Wa=0,Xa=0.0,Ya=0,Za=0.0,_a=0,$a=0.0,ab=0,bb=0.0,cb=0.0,db=0,eb=0,fb=0,gb=0,hb=0.0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0.0,Ab=0,Bb=0.0,Cb=0,Db=0,Eb=0.0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0;m=i;i=i+336|0;n=m|0;o=m+128|0;p=m+144|0;q=m+272|0;r=q|0;s=c[f+60>>2]|0;t=s;u=q;v=f+416|0;if((c[l+28>>2]|0)<(c[v>>2]<<6|0)){yDb(f,16,2006272,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1094995529;i=m;return x|0}y=c[l+24>>2]|0;c[j+76>>2]=256;l=_$a(f,j,0)|0;if((l|0)<0){x=l;i=m;return x|0}do{if((c[v>>2]|0)>0){l=j+64|0;z=s+21728|0;A=s+20448|0;B=q;C=s+19328|0;D=s+19340|0;E=s+19344|0;F=q+64|0;G=s+19332|0;H=s+19336|0;I=s+21732|0;J=f+48|0;K=p;L=s+20628|0;M=s+20660|0;N=s+20704|0;O=s+20664|0;P=p|0;Q=p+4|0;R=p+8|0;T=p+12|0;U=o|0;V=o+4|0;W=o+8|0;X=o+12|0;Y=0;Z=y;a:while(1){c[z>>2]=c[(c[l>>2]|0)+(Y<<2)>>2];Xe[c[A>>2]&4095](u,Z,32);c[C>>2]=B;c[D>>2]=512;c[E>>2]=520;c[G>>2]=F;c[H>>2]=0;_=t+(Y*7044|0)|0;$=(fe(c[r>>2]|0)|0)>>>23;c[H>>2]=9;if(($&24|0)!=0){aa=7;break}ca=B+1|0;da=fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0;ca=da>>>28;c[H>>2]=12;ea=ca&4;fa=(ea|0)!=0;ga=t+(Y*7044|0)+7040|0;if(fa){c[ga>>2]=1;ha=0;aa=12}else{if((c[ga>>2]|0)==0){ia=12;ja=B;ka=520}else{ha=0;aa=12}}if((aa|0)==12){while(1){aa=0;g[t+(Y*7044|0)+(ha<<2)>>2]=1.0;la=ha+1|0;if((la|0)<32){ha=la;aa=12}else{break}}TGb(t+(Y*7044|0)+896|0,0,1024)|0;c[ga>>2]=0;ia=c[H>>2]|0;ja=c[C>>2]|0;ka=c[E>>2]|0}la=d[ja+(ia>>>3)|0]<<(ia&7)>>>7;ma=((ia|0)<(ka|0))+ia|0;c[H>>2]=ma;na=la&1;la=(ca&1|0)!=0;oa=t+(Y*7044|0)+3200|0;if(la){pa=c[I>>2]|0;qa=2.0e4/+Wc(+(+(c[oa>>2]|0)*.18945));g[t+(Y*7044|0)+128+(pa<<2)>>2]=qa;ra=+gc(+(+g[t+(Y*7044|0)+128>>2]));g[t+(Y*7044|0)+256+(pa<<2)>>2]=ra;sa=ra;ta=0;ua=t+(Y*7044|0)+3204|0;while(1){if((ta|0)==(pa|0)){va=ua}else{wa=c[ua>>2]|0;g[t+(Y*7044|0)+128+(ta<<2)>>2]=qa*+S(+10.0,+(+(-wa|0)*.4375));g[t+(Y*7044|0)+256+(ta<<2)>>2]=sa- +(wa|0)*1.4533435415;va=ua+4|0}wa=ta+1|0;if((wa|0)<32){ta=wa;ua=va}else{break}}}else{ua=da>>>29&3;c[U>>2]=5099072+(ua*80|0);c[V>>2]=5099092+(ua*80|0);c[W>>2]=5099112+(ua*80|0);c[X>>2]=5099132+(ua*80|0);if((ea|0)==0){xa=ja}else{ta=ja+(ma>>>3)|0;pa=(fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(ma&7)>>>25;ta=ma+7|0;c[H>>2]=ka>>>0>ta>>>0?ta:ka;c[oa>>2]=pa;xa=c[C>>2]|0}pa=ea>>>2;do{ta=c[o+(d[916072+(ua<<5)+pa|0]<<2)>>2]|0;wa=c[ta+4>>2]|0;ya=c[ta>>2]|0;ta=c[H>>2]|0;za=c[E>>2]|0;Aa=xa+(ta>>>3)|0;Ba=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(ta&7)>>>((32-ya|0)>>>0);Aa=b[wa+(Ba<<2)>>1]|0;Ca=b[wa+(Ba<<2)+2>>1]|0;Ba=Ca<<16>>16;if(Ca<<16>>16<0){Ca=ta+ya|0;ya=za>>>0>Ca>>>0?Ca:za;Ca=xa+(ya>>>3)|0;Da=((fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(ya&7)>>>((Ba+32|0)>>>0))+Aa|0;Ea=b[wa+(Da<<2)+2>>1]|0;Fa=b[wa+(Da<<2)>>1]|0;Ga=ya}else{Ea=Ba;Fa=Aa;Ga=ta}ta=Ea+Ga|0;c[H>>2]=za>>>0>ta>>>0?ta:za;za=t+(Y*7044|0)+3200+(pa<<2)|0;c[za>>2]=Fa;if((Fa|0)==17){ta=c[H>>2]|0;Aa=c[E>>2]|0;Ba=xa+(ta>>>3)|0;ya=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(ta&7)>>>28;Ba=ta+4|0;c[H>>2]=Aa>>>0>Ba>>>0?Ba:Aa;c[za>>2]=ya+(c[za>>2]|0)}pa=pa+1|0;}while((pa|0)<32)}if(fa){sa=2.0e4/+Wc(+(+(c[oa>>2]|0)*.18945));g[t+(Y*7044|0)+128>>2]=sa;qa=+gc(+sa);g[t+(Y*7044|0)+256>>2]=qa;pa=1;ra=sa;sa=qa;while(1){ua=c[t+(Y*7044|0)+3200+(pa<<2)>>2]|0;if((ua|0)==16){g[t+(Y*7044|0)+128+(pa<<2)>>2]=1.0;g[t+(Y*7044|0)+256+(pa<<2)>>2]=0.0;Ha=sa;Ia=ra}else{do{if((ua|0)<17){Ja=ua-7|0}else{if((ua|0)<25){Ja=ua-32|0;break}else{Ja=ua-16|0;break}}}while(0);qa=ra*+g[915944+(Ja+15<<2)>>2];Ka=sa+ +(Ja|0)*.83048;g[t+(Y*7044|0)+128+(pa<<2)>>2]=qa;g[t+(Y*7044|0)+256+(pa<<2)>>2]=Ka;Ha=Ka;Ia=qa}ua=pa+1|0;if((ua|0)<32){pa=ua;ra=Ia;sa=Ha}else{La=0;break}}}else{pa=0;while(1){oa=t+(Y*7044|0)+128+(pa<<2)|0;g[oa>>2]=0.0;fa=c[t+(Y*7044|0)+3200+(pa<<2)>>2]|0;if((fa|0)<16){g[oa>>2]=+g[915944+(fa+8<<2)>>2]*+g[t+(Y*7044|0)+(pa<<2)>>2];ua=t+(Y*7044|0)+256+(pa<<2)|0;g[ua>>2]=+(fa-7|0)*.83048+ +g[ua>>2]}else{g[oa>>2]=+g[t+(Y*7044|0)+(pa<<2)>>2]}oa=pa+1|0;if((oa|0)<32){pa=oa}else{La=0;break}}}while(1){if((La|0)>=32){break}if(+g[t+(Y*7044|0)+128+(La<<2)>>2]>2147483648.0){aa=43;break a}else{La=La+1|0}}UGb(_|0,t+(Y*7044|0)+128|0,128)|0;if(la){pa=0;oa=0;while(1){ua=pa+1|0;fa=e[1738192+(ua<<1)>>1]|0;c[t+(Y*7044|0)+1920+(pa<<2)>>2]=fa-oa;c[t+(Y*7044|0)+3328+(pa<<2)>>2]=0;g[t+(Y*7044|0)+384+(pa<<2)>>2]=+g[t+(Y*7044|0)+256+(pa<<2)>>2]*2.0;g[t+(Y*7044|0)+640+(pa<<2)>>2]=1.0;if((ua|0)<32){pa=ua;oa=fa}else{break}}}else{oa=0;while(1){if((c[t+(Y*7044|0)+3200+(oa<<2)>>2]|0)==16){c[t+(Y*7044|0)+1920+(oa<<2)>>2]=0;Ma=oa+1|0}else{pa=oa+1|0;c[t+(Y*7044|0)+1920+(oa<<2)>>2]=(e[1738192+(pa<<1)>>1]|0)-(e[1738192+(oa<<1)>>1]|0);Ma=pa}if((Ma|0)<32){oa=Ma}else{break}}TGb(t+(Y*7044|0)+3328|0,0,128)|0;oa=0;do{if((c[t+(Y*7044|0)+1920+(oa<<2)>>2]|0)!=0){pa=c[H>>2]|0;_=d[(c[C>>2]|0)+(pa>>>3)|0]<<(pa&7)>>>7;c[H>>2]=((pa|0)<(c[E>>2]|0))+pa;c[t+(Y*7044|0)+3328+(oa<<2)>>2]=_&1}oa=oa+1|0;}while((oa|0)<31);TGb(K|0,0,128)|0;oa=0;while(1){g[t+(Y*7044|0)+640+(oa<<2)>>2]=0.0;_=c[t+(Y*7044|0)+1920+(oa<<2)>>2]|0;if((_|0)==0){g[t+(Y*7044|0)+384+(oa<<2)>>2]=-3.0e4;Na=0.0}else{sa=+g[t+(Y*7044|0)+128+(oa<<2)>>2];g[t+(Y*7044|0)+384+(oa<<2)>>2]=+g[t+(Y*7044|0)+256+(oa<<2)>>2]*2.0;Na=sa*sa}sa=+(_|0)*Na*.01;g[n+(oa<<2)>>2]=sa>1.0000000031710769e-30?sa:0.0;_=oa+1|0;if((_|0)<32){oa=_}else{Oa=0;break}}while(1){oa=t+21736+Oa|0;sa=+g[n+(Oa<<2)>>2];if((Oa|0)<(a[oa]|0)){_=Oa;while(1){pa=t+(Y*7044|0)+640+(_<<2)|0;g[pa>>2]=sa+ +g[pa>>2];pa=_+1|0;if((pa|0)<(a[oa]|0)){_=pa}else{Pa=pa;break}}}else{Pa=Oa}_=p+(Pa-1<<2)|0;g[_>>2]=sa+ +g[_>>2];_=Oa+1|0;if((_|0)<32){Oa=_}else{Qa=0.0;Ra=1;break}}do{_=Ra-1|0;Qa=(Qa+ +g[p+(_<<2)>>2])*+g[t+21800+(_<<2)>>2];_=t+(Y*7044|0)+640+(Ra<<2)|0;g[_>>2]=+g[_>>2]+Qa;Ra=Ra+1|0;}while((Ra|0)<32);TGb(K|0,0,128)|0;_=0;while(1){oa=_-1|0;pa=t+21768+_|0;ra=+g[n+(_<<2)>>2];if((oa|0)>(a[pa]|0)){fa=oa;while(1){oa=t+(Y*7044|0)+640+(fa<<2)|0;g[oa>>2]=ra+ +g[oa>>2];oa=fa-1|0;if((oa|0)>(a[pa]|0)){fa=oa}else{Sa=fa;break}}}else{Sa=_}fa=p+(Sa<<2)|0;g[fa>>2]=ra+ +g[fa>>2];fa=_+1|0;if((fa|0)<32){_=fa}else{Ta=0.0;Ua=30;break}}while(1){sa=(Ta+ +g[p+(Ua+1<<2)>>2])*+g[t+21924+(Ua<<2)>>2];_=t+(Y*7044|0)+640+(Ua<<2)|0;g[_>>2]=+g[_>>2]+sa;if((Ua|0)>0){Ta=sa;Ua=Ua-1|0}else{break}}}_=ca&2;fa=(_|0)!=0;do{if(fa){c[t+(Y*7044|0)+2048>>2]=5;c[t+(Y*7044|0)+2176>>2]=5;c[t+(Y*7044|0)+2180>>2]=5;c[t+(Y*7044|0)+2184>>2]=5;if(la){c[t+(Y*7044|0)+2052>>2]=5;c[t+(Y*7044|0)+2188>>2]=5;c[t+(Y*7044|0)+2192>>2]=5;c[t+(Y*7044|0)+2196>>2]=5;c[t+(Y*7044|0)+2056>>2]=5;c[t+(Y*7044|0)+2200>>2]=5;c[t+(Y*7044|0)+2204>>2]=5;c[t+(Y*7044|0)+2208>>2]=5;c[t+(Y*7044|0)+2060>>2]=5;c[t+(Y*7044|0)+2212>>2]=5;c[t+(Y*7044|0)+2216>>2]=5;c[t+(Y*7044|0)+2220>>2]=5;Va=60;break}else{pa=(c[t+(Y*7044|0)+3204>>2]|0)==16?0:5;c[t+(Y*7044|0)+2052>>2]=pa;c[t+(Y*7044|0)+2188>>2]=pa;c[t+(Y*7044|0)+2192>>2]=pa;c[t+(Y*7044|0)+2196>>2]=pa;oa=(c[t+(Y*7044|0)+3208>>2]|0)==16?0:5;c[t+(Y*7044|0)+2056>>2]=oa;c[t+(Y*7044|0)+2200>>2]=oa;c[t+(Y*7044|0)+2204>>2]=oa;c[t+(Y*7044|0)+2208>>2]=oa;ua=(c[t+(Y*7044|0)+3212>>2]|0)==16?0:5;c[t+(Y*7044|0)+2060>>2]=ua;c[t+(Y*7044|0)+2212>>2]=ua;c[t+(Y*7044|0)+2216>>2]=ua;c[t+(Y*7044|0)+2220>>2]=ua;Va=((oa+pa+ua|0)*3|0)+15|0;break}}else{Va=0}}while(0);do{if((c[J>>2]|0)==86075){ca=((c[t+(Y*7044|0)+2044>>2]|0)!=0)+Va|0;if(fa){Wa=ca;break}Wa=ca+16|0}else{Wa=Va}}while(0);ca=c[H>>2]|0;sa=0.0;ua=0;do{qa=+g[t+(Y*7044|0)+128+(ua<<2)>>2];sa=sa>qa?sa:qa;ua=ua+1|0;}while((ua|0)<32);ua=512-Wa-ca|0;pa=0;do{Xa=+g[t+(Y*7044|0)+640+(pa<<2)>>2];if(!(Xa>0.0)){aa=79;break a}qa=+g[t+(Y*7044|0)+384+(pa<<2)>>2];g[t+(Y*7044|0)+512+(pa<<2)>>2]=qa- +gc(+Xa);pa=pa+1|0;}while((pa|0)<31);g[t+(Y*7044|0)+636>>2]=-100000002004087730000.0;qa=sa*.25;pa=0;ca=0;while(1){oa=pa+1|0;ea=b[1738192+(oa<<1)>>1]|0;ma=(ea&65535)-(ca&65535)|0;za=c[t+(Y*7044|0)+1920+(pa<<2)>>2]|0;ya=((ma|0)/2|0|0)<(za|0)?(ma|0)>(za|0)?1:((ma|0)!=(za|0))<<31>>31:2;if((ya|0)==-1){break a}za=t+(Y*7044|0)+512+(pa<<2)|0;g[za>>2]=+g[2888+(((+g[t+(Y*7044|0)+128+(pa<<2)>>2]<qa|ya<<1)<<1|na)<<2)>>2]+ +g[za>>2];if((oa|0)<32){pa=oa;ca=ea}else{break}}if(fa){g[t+(Y*7044|0)+512>>2]=-100000002004087730000.0;g[t+(Y*7044|0)+516>>2]=-100000002004087730000.0;g[t+(Y*7044|0)+520>>2]=-100000002004087730000.0;g[t+(Y*7044|0)+524>>2]=-100000002004087730000.0}ca=_<<1;qa=0.0;pa=0;na=ca;do{ea=c[t+(Y*7044|0)+1920+(na<<2)>>2]|0;pa=ea+pa|0;qa=qa+ +(ea|0)*+g[t+(Y*7044|0)+512+(na<<2)>>2];na=na+1|0;}while((na|0)<31);if((pa|0)==0){break}c[t+(Y*7044|0)+2044>>2]=0;na=8-ua|0;_=0;ea=1;sa=(qa*.5- +(ua|0))/+(pa|0);oa=0;za=0;while(1){if((na+oa|0)>>>0<17>>>0){Ya=oa;break}Ka=sa;ya=ca;ma=0;Aa=0;do{Za=+g[t+(Y*7044|0)+512+(ya<<2)>>2]*.5-Ka+.5;if(Za<0.0){_a=0}else{_a=Za>6.0?6:~~Za}c[t+(Y*7044|0)+2048+(ya<<2)>>2]=_a;Ba=c[t+(Y*7044|0)+1920+(ya<<2)>>2]|0;Aa=(ba(Ba,_a)|0)+Aa|0;ma=((_a|0)>0?Ba:0)+ma|0;ya=ya+1|0;}while((ya|0)<32);ya=(Aa|0)>(ua|0)?-1:1;Ba=((((za|0)==0?ya:ea)|0)!=(ya|0))+_|0;Ka=sa+ +(Aa-ua|0)/+(ba(Ba+1|0,ma)|0);ta=za+1|0;if((ta|0)<16){_=Ba;ea=ya;sa=Ka;oa=Aa;za=ta}else{Ya=Aa;break}}za=ca;oa=b[1738192+(ca<<1)>>1]|0;while(1){ea=za+1|0;_=b[1738192+(ea<<1)>>1]|0;if((oa&65535)>>>0<(_&65535)>>>0){na=t+(Y*7044|0)+2048+(za<<2)|0;pa=_&65535;ta=oa&65535;do{c[t+(Y*7044|0)+2176+(ta<<2)>>2]=c[na>>2];ta=ta+1|0;}while((ta|0)<(pa|0))}if((ea|0)<32){za=ea;oa=_}else{break}}b:do{if((Ya|0)<(ua|0)){oa=0;while(1){za=c[t+(Y*7044|0)+2048+(oa<<2)>>2]|0;if((za|0)==6){$a=-100000002004087730000.0}else{$a=+(za*-2|0|0)+ +g[t+(Y*7044|0)+512+(oa<<2)>>2]+-.415}g[p+(oa<<2)>>2]=$a;za=oa+1|0;if((za|0)<32){oa=za}else{ab=Ya;bb=0.0;break}}while(1){if(bb>-1.0e20){cb=-100000002004087730000.0;db=0;eb=0}else{fb=ab;break b}do{sa=+g[p+(db<<2)>>2];oa=sa>cb;cb=oa?sa:cb;eb=oa?db:eb;db=db+1|0;}while((db|0)<32);do{if(cb>-1.0e20){oa=p+(eb<<2)|0;g[oa>>2]=+g[oa>>2]+-2.0;_=t+(Y*7044|0)+2048+(eb<<2)|0;ea=(c[_>>2]|0)+1|0;c[_>>2]=ea;if((ea|0)==6){g[oa>>2]=-100000002004087730000.0}oa=b[1738192+(eb<<1)>>1]|0;ea=b[1738192+(eb+1<<1)>>1]|0;if(!((oa&65535)>>>0<(ea&65535)>>>0&(ab|0)<(ua|0))){gb=ab;break}_=oa&65535;oa=ea&65535;ea=_+1|0;za=_-(ea>>>0>oa>>>0?ea:oa)|0;ea=_;_=ab;do{ca=t+(Y*7044|0)+2176+(ea<<2)|0;c[ca>>2]=(c[ca>>2]|0)+1;_=_+1|0;ea=ea+1|0;}while((ea|0)<(oa|0)&(_|0)<(ua|0));_=ab-ua|0;gb=ab-(_>>>0>za>>>0?_:za)|0}else{gb=ab}}while(0);if((gb|0)<(ua|0)){ab=gb;bb=cb}else{fb=gb;break}}}else{fb=Ya}}while(0);if((fb|0)>(ua|0)){_=0;do{oa=c[t+(Y*7044|0)+2048+(_<<2)>>2]|0;if((oa|0)==0){hb=100000002004087730000.0}else{hb=+(oa*-2|0|0)+ +g[t+(Y*7044|0)+512+(_<<2)>>2]+1.585}g[p+(_<<2)>>2]=hb;_=_+1|0;}while((_|0)<32);if(fa){g[P>>2]=100000002004087730000.0;g[Q>>2]=100000002004087730000.0;g[R>>2]=100000002004087730000.0;g[T>>2]=100000002004087730000.0;ib=fb}else{ib=fb}while(1){_=0;sa=1.0e10;oa=0;do{qa=+g[p+(_<<2)>>2];ea=qa<sa;sa=ea?qa:sa;oa=ea?_:oa;_=_+1|0;}while((_|0)<32);_=p+(oa<<2)|0;g[_>>2]=sa+2.0;ea=t+(Y*7044|0)+2048+(oa<<2)|0;ca=(c[ea>>2]|0)-1|0;c[ea>>2]=ca;if((ca|0)==0){g[_>>2]=100000002004087730000.0}_=b[1738192+(oa<<1)>>1]|0;ca=b[1738192+(oa+1<<1)>>1]|0;if((_&65535)>>>0<(ca&65535)>>>0&(ib|0)>(ua|0)){ea=ca&65535;ca=_&65535;_=ib;while(1){pa=t+(Y*7044|0)+2176+(ca<<2)|0;ta=c[pa>>2]|0;if((ta|0)>0){c[pa>>2]=ta-1;jb=_-1|0}else{jb=_}ta=ca+1|0;if((ta|0)<(ea|0)&(jb|0)>(ua|0)){ca=ta;_=jb}else{kb=jb;break}}}else{kb=ib}if((kb|0)>(ua|0)){ib=kb}else{break}}}c:do{if(la){TGb(t+(Y*7044|0)+3968|0,0,128)|0;lb=0;mb=0}else{ua=0;fa=0;while(1){_=t+(Y*7044|0)+3456+(ua<<2)|0;c[_>>2]=0;ca=t+(Y*7044|0)+3584+(ua<<2)|0;c[ca>>2]=0;ea=1738192+(ua<<1)|0;oa=ua+1|0;ta=b[1738192+(oa<<1)>>1]|0;pa=ta&65535;if((fa&65535)>>>0<(ta&65535)>>>0){na=fa&65535;Aa=0;while(1){ma=(c[t+(Y*7044|0)+2176+(na<<2)>>2]|0)+Aa|0;c[_>>2]=ma;ya=na+1|0;if((ya|0)<(pa|0)){na=ya;Aa=ma}else{nb=ma;break}}}else{nb=0}do{if((c[t+(Y*7044|0)+3328+(ua<<2)>>2]|0)!=0){if(!(+(pa-(e[ea>>1]|0)|0)*1.5>+(nb|0)&(nb|0)>0)){break}c[ca>>2]=1}}while(0);if((oa|0)<32){ua=oa;fa=ta}else{break}}TGb(t+(Y*7044|0)+3712|0,0,256)|0;fa=0;while(1){d:do{if((c[t+(Y*7044|0)+3328+(fa<<2)>>2]|0)!=0){if((c[t+(Y*7044|0)+1920+(fa<<2)>>2]|0)==0){break}if((c[t+(Y*7044|0)+3584+(fa<<2)>>2]|0)==0){ua=b[1738192+(fa+1<<1)>>1]|0;ca=ua&65535;ea=b[1738192+(fa<<1)>>1]|0;pa=ea&65535;c[t+(Y*7044|0)+3712+(fa<<2)>>2]=ca-pa;if(!((ea&65535)>>>0<(ua&65535)>>>0)){break}ua=t+(Y*7044|0)+3840+(fa<<2)|0;ea=c[C>>2]|0;Aa=pa;while(1){pa=c[H>>2]|0;na=d[ea+(pa>>>3)|0]<<(pa&7)>>>7;c[H>>2]=((pa|0)<(c[E>>2]|0))+pa;pa=na&1;c[t+(Y*7044|0)+3968+(Aa<<2)>>2]=pa;if((pa|0)!=0){c[ua>>2]=(c[ua>>2]|0)+1}Aa=Aa+1|0;if((Aa|0)>=(ca|0)){break d}}}ca=e[1738192+(fa<<1)>>1]|0;Aa=e[1738192+(fa+1<<1)>>1]|0;ua=Aa-1|0;if((ca|0)<(ua|0)){ea=t+(Y*7044|0)+3712+(fa<<2)|0;za=t+(Y*7044|0)+3840+(fa<<2)|0;pa=ca+2|0;na=(ua|0)>(pa|0);_=c[C>>2]|0;ma=ca;do{ya=c[H>>2]|0;Ba=d[_+(ya>>>3)|0]|0;Da=c[E>>2]|0;wa=((ya|0)<(Da|0))+ya|0;c[H>>2]=wa;do{if((Ba&128>>>((ya&7)>>>0)|0)==0){c[ea>>2]=(c[ea>>2]|0)+1;c[t+(Y*7044|0)+3968+(ma<<2)>>2]=1;c[t+(Y*7044|0)+3968+(ma+1<<2)>>2]=1;c[za>>2]=(c[za>>2]|0)+2}else{Ca=d[_+(wa>>>3)|0]|0;c[H>>2]=((wa|0)<(Da|0))+wa;ob=c[ea>>2]|0;if((Ca&128>>>((wa&7)>>>0)|0)!=0){c[ea>>2]=ob+2;c[t+(Y*7044|0)+3968+(ma<<2)>>2]=0;c[t+(Y*7044|0)+3968+(ma+1<<2)>>2]=1;c[za>>2]=(c[za>>2]|0)+1;break}c[ea>>2]=ob+3;c[t+(Y*7044|0)+3968+(ma+1<<2)>>2]=0;ob=c[H>>2]|0;Ca=d[_+(ob>>>3)|0]|0;c[H>>2]=((ob|0)<(c[E>>2]|0))+ob;pb=t+(Y*7044|0)+3968+(ma<<2)|0;if((Ca&128>>>((ob&7)>>>0)|0)==0){c[pb>>2]=1;c[za>>2]=(c[za>>2]|0)+1;break}else{c[pb>>2]=0;break}}}while(0);ma=ma+2|0;}while((ma|0)<(ua|0));qb=(1-ca+(na?ua:pa)&-2)+ca|0}else{qb=ca}if((qb|0)>=(Aa|0)){break}ma=t+(Y*7044|0)+3712+(fa<<2)|0;c[ma>>2]=(c[ma>>2]|0)+1;ma=c[H>>2]|0;za=d[(c[C>>2]|0)+(ma>>>3)|0]<<(ma&7)>>>7;c[H>>2]=((ma|0)<(c[E>>2]|0))+ma;ma=za&1;c[t+(Y*7044|0)+3968+(qb<<2)>>2]=ma;if((ma|0)==0){break}ma=t+(Y*7044|0)+3840+(fa<<2)|0;c[ma>>2]=(c[ma>>2]|0)+1}}while(0);ta=fa+1|0;if((ta|0)<32){fa=ta}else{rb=0;break}}while(1){sa=+g[t+(Y*7044|0)+128+(rb<<2)>>2];fa=t+(Y*7044|0)+768+(rb<<2)|0;g[fa>>2]=sa;ta=rb+1|0;do{if((c[t+(Y*7044|0)+3328+(rb<<2)>>2]|0)!=0){oa=(e[1738192+(ta<<1)>>1]|0)-(e[1738192+(rb<<1)>>1]|0)|0;ma=c[t+(Y*7044|0)+3840+(rb<<2)>>2]|0;if((oa|0)==(ma|0)){break}g[fa>>2]=sa*(+g[t+19208+(oa<<2)>>2]/+g[t+19208+(oa-ma<<2)>>2])}}while(0);if((ta|0)<32){rb=ta}else{sb=0;tb=0;break}}while(1){if((c[t+(Y*7044|0)+3328+(sb<<2)>>2]|0)==0){ub=tb;vb=sb+1|0}else{fa=b[1738192+(sb<<1)>>1]|0;ma=sb+1|0;oa=b[1738192+(ma<<1)>>1]|0;if((fa&65535)>>>0<(oa&65535)>>>0){za=oa&65535;oa=fa&65535;fa=tb;while(1){if((c[t+(Y*7044|0)+3968+(oa<<2)>>2]|0)==0){wb=fa}else{_=t+(Y*7044|0)+2176+(oa<<2)|0;ea=(c[_>>2]|0)+fa|0;c[_>>2]=0;wb=ea}ea=oa+1|0;if((ea|0)<(za|0)){oa=ea;fa=wb}else{xb=wb;break}}}else{xb=tb}ub=xb-(c[t+(Y*7044|0)+3712+(sb<<2)>>2]|0)|0;vb=ma}if((vb|0)<32){sb=vb;tb=ub}else{yb=0;break}}do{fa=c[t+(Y*7044|0)+2048+(yb<<2)>>2]|0;if((fa|0)==6){zb=-100000002004087730000.0}else{zb=+(fa*-2|0|0)+ +g[t+(Y*7044|0)+512+(yb<<2)>>2]+-.415}g[p+(yb<<2)>>2]=zb;yb=yb+1|0;}while((yb|0)<32);if((ub|0)>0){Ab=0;Bb=0.0;Cb=0}else{lb=0;mb=0;break}while(1){fa=Cb;sa=Bb;while(1){if(sa>-1.0e20){Db=0;Eb=-100000002004087730000.0;Fb=fa}else{lb=0;mb=0;break c}do{qa=+g[p+(Db<<2)>>2];oa=qa>Eb;Eb=oa?qa:Eb;Fb=oa?Db:Fb;Db=Db+1|0;}while((Db|0)<32);if(Eb>-1.0e20){break}else{fa=Fb;sa=Eb}}fa=p+(Fb<<2)|0;g[fa>>2]=+g[fa>>2]+-2.0;ma=t+(Y*7044|0)+2048+(Fb<<2)|0;Aa=(c[ma>>2]|0)+1|0;c[ma>>2]=Aa;if((Aa|0)==6){g[fa>>2]=-100000002004087730000.0}fa=b[1738192+(Fb<<1)>>1]|0;Aa=b[1738192+(Fb+1<<1)>>1]|0;if((fa&65535)>>>0<(Aa&65535)>>>0&(Ab|0)<(ub|0)){ma=Aa&65535;Aa=Ab;ca=fa&65535;while(1){do{if((c[t+(Y*7044|0)+3968+(ca<<2)>>2]|0)==0){fa=t+(Y*7044|0)+2176+(ca<<2)|0;pa=c[fa>>2]|0;if((pa|0)>=6){Gb=Aa;break}c[fa>>2]=pa+1;Gb=Aa+1|0}else{Gb=Aa}}while(0);pa=ca+1|0;if((pa|0)<(ma|0)&(Gb|0)<(ub|0)){Aa=Gb;ca=pa}else{Hb=Gb;break}}}else{Hb=Ab}if((Hb|0)<(ub|0)){Ab=Hb;Bb=Eb;Cb=Fb}else{lb=0;mb=0;break}}}}while(0);while(1){la=t+(Y*7044|0)+3456+(lb<<2)|0;c[la>>2]=0;ca=lb+1|0;Aa=b[1738192+(ca<<1)>>1]|0;if((mb&65535)>>>0<(Aa&65535)>>>0){ma=Aa&65535;pa=mb&65535;fa=0;while(1){if((c[t+(Y*7044|0)+3968+(pa<<2)>>2]|0)==0){ua=(c[t+(Y*7044|0)+2176+(pa<<2)>>2]|0)+fa|0;c[la>>2]=ua;Ib=ua}else{Ib=fa}ua=pa+1|0;if((ua|0)<(ma|0)){pa=ua;fa=Ib}else{break}}}if((ca|0)<32){lb=ca;mb=Aa}else{break}}TGb(t+(Y*7044|0)+4992|0,0,1024)|0;fa=0;do{do{if((c[t+(Y*7044|0)+3456+(fa<<2)>>2]|0)!=0){pa=t+(Y*7044|0)+3328+(fa<<2)|0;if((c[pa>>2]|0)==0){if((c[t+(Y*7044|0)+1920+(fa<<2)>>2]|0)==0){break}}ma=b[1738192+(fa<<1)>>1]|0;la=b[1738192+(fa+1<<1)>>1]|0;if(!((ma&65535)>>>0<(la&65535)>>>0)){break}ua=la&65535;la=ma&65535;do{ma=c[t+(Y*7044|0)+2176+(la<<2)>>2]|0;na=c[H>>2]|0;oa=na+ma|0;if((oa|0)>512){aa=214;break a}do{if((ma|0)==0){Jb=0}else{if((c[pa>>2]|0)!=0){if((c[t+(Y*7044|0)+3968+(la<<2)>>2]|0)!=0){Jb=0;break}}za=c[E>>2]|0;ta=(c[C>>2]|0)+(na>>>3)|0;ea=(fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(na&7)>>>((32-ma|0)>>>0);c[H>>2]=za>>>0>oa>>>0?oa:za;Jb=ea}}while(0);c[t+(Y*7044|0)+4992+(la<<2)>>2]=Jb;la=la+1|0;}while((la|0)<(ua|0))}}while(0);fa=fa+1|0;}while((fa|0)<32);fa=da>>>29&1;Aa=0;ca=0;while(1){ua=Aa+1|0;la=b[1738192+(ua<<1)>>1]|0;if((ca&65535)>>>0<(la&65535)>>>0){pa=t+(Y*7044|0)+768+(Aa<<2)|0;oa=t+(Y*7044|0)+3328+(Aa<<2)|0;ma=la&65535;na=ca&65535;do{ea=t+(Y*7044|0)+896+(na<<2)|0;g[ea>>2]=0.0;za=c[t+(Y*7044|0)+2176+(na<<2)>>2]|0;do{if((za|0)>=1){if((c[t+(Y*7044|0)+3968+(na<<2)>>2]|0)!=0){break}ta=1<<za;_=ta>>1;wa=c[t+(Y*7044|0)+4992+(na<<2)>>2]|0;if((wa|0)>=(ta|0)|(wa|0)<0){aa=230;break a}if((za|0)>3){if((wa|0)<(_|0)){g[ea>>2]=+g[pa>>2]*(-0.0- +g[914496+(fa*224|0)+(ta-9-wa<<2)>>2]);break}else{g[ea>>2]=+g[914496+(fa*224|0)+(wa-8<<2)>>2]*+g[pa>>2];break}}else{Da=c[oa>>2]<<1|fa;if((wa|0)<(_|0)){g[ea>>2]=+g[pa>>2]*(-0.0- +g[914944+(Da<<5)+(ta-2-wa<<2)>>2]);break}else{g[ea>>2]=+g[914944+(Da<<5)+(wa-1<<2)>>2]*+g[pa>>2];break}}}}while(0);na=na+1|0;}while((na|0)<(ma|0))}if((ua|0)<32){Aa=ua;ca=la}else{break}}TGb(t+(Y*7044|0)+3968|0,0,1024)|0;ca=c[z>>2]|0;Aa=0;do{fa=t+17160+(Aa<<2)|0;da=Aa<<1;ma=t+(Y*7044|0)+896+(255-da<<2)|0;na=t+18184+(Aa<<2)|0;pa=t+(Y*7044|0)+896+(da<<2)|0;g[t+20704+(Aa<<3)>>2]=-0.0- +g[fa>>2]*+g[ma>>2]- +g[na>>2]*+g[pa>>2];g[t+20704+(Aa<<3)+4>>2]=+g[na>>2]*+g[ma>>2]- +g[fa>>2]*+g[pa>>2];Aa=Aa+1|0;}while((Aa|0)<128);ne[c[M>>2]&1023](L,N);ne[c[O>>2]&1023](L,N);Aa=0;pa=ca;fa=ca+1020|0;while(1){sa=+g[t+20704+(Aa<<3)>>2];qa=+g[t+15112+(Aa<<2)>>2];Ka=-0.0- +g[t+20704+(Aa<<3)+4>>2];ra=+g[t+16136+(Aa<<2)>>2];Za=sa*qa+ra*Ka;ma=Aa<<1;na=t+14088+(255-ma<<2)|0;da=t+(Y*7044|0)+6016+(Aa<<2)|0;oa=t+14088+(ma<<2)|0;g[pa>>2]=+g[na>>2]*+g[da>>2]+Za*+g[oa>>2];g[fa>>2]=+g[oa>>2]*+g[da>>2]-Za*+g[na>>2];g[da>>2]=qa*Ka-sa*ra;da=Aa+1|0;if((da|0)<128){Aa=da;pa=pa+8|0;fa=fa-8|0}else{break}}fa=Y+1|0;Kb=c[v>>2]|0;if((fa|0)<(Kb|0)){Y=fa;Z=Z+64|0}else{aa=236;break}}if((aa|0)==7){Z=f;yDb(Z,16,1968480,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;yDb(Z,16,1940024,(w=i,i=i+8|0,c[w>>2]=$,w)|0);i=w;x=-1094995529;i=m;return x|0}else if((aa|0)==43){yDb(f,16,1915800,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1094995529;i=m;return x|0}else if((aa|0)==79){yDb(0,16,2307912,(w=i,i=i+8|0,h[w>>3]=Xa,w)|0);i=w}else if((aa|0)==214){yDb(f,16,2352376,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;c[ga>>2]=1;x=-1094995529;i=m;return x|0}else if((aa|0)==230){yDb(f,16,2332208,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;c[ga>>2]=1;x=-1094995529;i=m;return x|0}else if((aa|0)==236){if((Kb|0)!=2){break}Z=c[j+64>>2]|0;Xe[c[s+20620>>2]&4095](c[Z>>2]|0,c[Z+4>>2]|0,256);break}yDb(f,16,1895256,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;c[ga>>2]=1;x=-1094995529;i=m;return x|0}}while(0);c[k>>2]=1;x=c[v>>2]<<6;i=m;return x|0}function YGa(a){a=a|0;d9((c[a+60>>2]|0)+20628|0);return 0}function ZGa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+14084>>2]=1;c[b+7040>>2]=1;return}function _Ga(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=i;g=bFb(a)|0;if((g|0)==0){yDb(0,0,2276088,(a=i,i=i+24|0,c[a>>2]=2323360,c[a+8>>2]=2187016,c[a+16>>2]=68,a)|0);i=a;Cd()}else{c[b>>2]=d[g+5|0]|0;c[e>>2]=d[g+6|0]|0;i=f;return}}function $Ga(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;i=bFb(f)|0;j=bFb(d)|0;if(d>>>0>332>>>0){k=-1;return k|0}c[g>>2]=0;if((d|0)==(f|0)){k=2147483647;return k|0}l=bFb(f)|0;if((l|0)==0){k=-22;return k|0}if((a[l+4|0]|0)==0){k=-22;return k|0}l=bFb(d)|0;if((l|0)==0){k=-22;return k|0}if((a[l+4|0]|0)==0){k=-22;return k|0}l=a[i+7|0]|0;m=(l&2)==0;do{if(m){n=a[i+4|0]|0;if((n-1&255)>>>0<2>>>0){o=1;break}p=c[i>>2]|0;if((p|0)!=0){if((RGb(p,2109840,4)|0)==0){o=3;break}}if(!((l&32)==0)){o=0;break}o=n<<24>>24==0?-1:2}else{o=0}}while(0);l=a[j+7|0]|0;n=(l&2)==0;p=a[j+4|0]|0;do{if(n){if((p-1&255)>>>0<2>>>0){q=1;break}r=c[j>>2]|0;if((r|0)!=0){if((RGb(r,2109840,4)|0)==0){q=3;break}}if(!((l&32)==0)){q=0;break}q=p<<24>>24==0?-1:2}else{q=0}}while(0);l=a[i+4|0]|0;r=(l&255)>>>0>(p&255)>>>0?p:l;s=r&255;do{if(r<<24>>24==0){t=0;u=2147483646}else{if((h&2|0)==0){t=0;u=2147483646;break}else{v=0;w=0;x=2147483646}while(1){y=(e[j+8+(w<<1)>>1]|0)>>>11&15;if(((e[i+8+(w<<1)>>1]|0)>>>11&15)>>>0>(y&65535)>>>0){z=x-(65536>>>((y&65535)>>>0))|0;A=v|2}else{z=x;A=v}y=w+1|0;if((y|0)<(s|0)){v=A;w=y;x=z}else{t=A;u=z;break}}}}while(0);do{if((h&1|0)==0){B=u;C=t}else{z=a[j+5|0]|0;A=a[i+5|0]|0;if((z&255)>>>0>(A&255)>>>0){D=u-(256<<(z&255))|0;E=t|1}else{D=u;E=t}x=a[j+6|0]|0;w=a[i+6|0]|0;if((x&255)>>>0>(w&255)>>>0){F=D-(256<<(x&255))|0;G=E|1}else{F=D;G=E}if(!(z<<24>>24==1&A<<24>>24==0&x<<24>>24==1)){B=F;C=G;break}B=w<<24>>24==0?F+512|0:F;C=G}}while(0);do{if((h&4|0)==0){H=C}else{if((q|0)==0){H=o>>>0>1>>>0?C|4:C;break}else if((q|0)==1){H=(o|0)==1?C:C|4;break}else if((q|0)==2){H=(o|0)==2?C:C|4;break}else if((q|0)==3){H=(o-2|0)>>>0>1>>>0&(o|0)!=1?C|4:C;break}else{H=(o|0)==(q|0)?C:C|4;break}}}while(0);if((H&4|0)==0){I=B}else{C=b[j+8>>1]|0;j=b[i+8>>1]|0;I=B-(s<<16>>>((((((C&65535)>>>11&15)>>>0>((j&65535)>>>11&15)>>>0?j:C)&65535)>>>11&15)>>>0))|0}C=(o|0)==1;do{if((q|0)!=1|C){J=I;K=H}else{if((h&32|0)==0){J=I;K=H;break}J=I-131072|0;K=H|32}}while(0);do{if((p<<24>>24|0)==2|(p<<24>>24|0)==4){L=J;M=K}else{if(!n){L=J;M=K;break}if(!((l<<24>>24|0)==2|(l<<24>>24|0)==4)){if(m){L=J;M=K;break}}if((h&8|0)==0){L=J;M=K;break}L=J-65536|0;M=K|8}}while(0);do{if((d|0)==11){if((h&16|0)==0|(f|0)==11){N=L;O=M;break}if(C){if(!((l<<24>>24|0)==2|(l<<24>>24|0)==4)){if(m){N=L;O=M;break}}if((h&8|0)==0){N=L;O=M;break}}N=L-65536|0;O=M|16}else{N=L;O=M}}while(0);c[g>>2]=O;k=N;return k|0}function aHa(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+24|0;j=h|0;k=bFb(a)|0;l=bFb(b)|0;m=(g|0)!=0;if(m){n=~c[g>>2]}else{n=-1}o=(f|0)==0?n&-9:n;n=$Ga(a,e,h+8|0,o)|0;p=$Ga(b,e,h+16|0,o)|0;do{if((n|0)==(p|0)){o=aFb(l)|0;if((o|0)==(aFb(k)|0)){q=(d[l+4|0]|0)>>>0<(d[k+4|0]|0)>>>0?b:a;break}else{o=aFb(l)|0;r=(o|0)<(aFb(k)|0);q=r?b:a;break}}else{q=(n|0)<(p|0)?b:a}}while(0);if(!m){i=h;return q|0}m=$Ga(q,e,j,(f|0)!=0?-1:-9)|0;c[g>>2]=(m|0)<0?m:c[j>>2]|0;i=h;return q|0}function bHa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((h|0)<=0){return}i=f<<1;if((g|0)<=3){j=e;k=b;l=h;while(1){if((g|0)>0){m=g;n=j;o=j+f|0;p=k;while(1){a[p]=((d[n]|0)+2+(d[n+1|0]|0)+(d[o]|0)+(d[o+1|0]|0)|0)>>>2;q=m-1|0;if((q|0)>0){m=q;n=n+2|0;o=o+2|0;p=p+1|0}else{break}}}p=l-1|0;if((p|0)>0){j=j+i|0;k=k+c|0;l=p}else{break}}return}l=g-4|0;k=l>>>2;j=k<<2;p=l-j|0;l=k<<3;k=f<<1;o=e;n=b;m=h;h=b+(j+4)|0;j=e+(l+f+8)|0;b=e+(l+8)|0;while(1){l=g;e=o;q=o+f|0;r=n;while(1){a[r]=((d[e]|0)+2+(d[e+1|0]|0)+(d[q]|0)+(d[q+1|0]|0)|0)>>>2;a[r+1|0]=((d[e+2|0]|0)+2+(d[e+3|0]|0)+(d[q+2|0]|0)+(d[q+3|0]|0)|0)>>>2;a[r+2|0]=((d[e+4|0]|0)+2+(d[e+5|0]|0)+(d[q+4|0]|0)+(d[q+5|0]|0)|0)>>>2;a[r+3|0]=((d[e+6|0]|0)+2+(d[e+7|0]|0)+(d[q+6|0]|0)+(d[q+7|0]|0)|0)>>>2;s=l-4|0;if((s|0)>3){l=s;e=e+8|0;q=q+8|0;r=r+4|0}else{break}}if((p|0)>0){r=p;q=b;e=j;l=h;while(1){a[l]=((d[q]|0)+2+(d[q+1|0]|0)+(d[e]|0)+(d[e+1|0]|0)|0)>>>2;s=r-1|0;if((s|0)>0){r=s;q=q+2|0;e=e+2|0;l=l+1|0}else{break}}}l=m-1|0;if((l|0)>0){o=o+i|0;n=n+c|0;m=l;h=h+c|0;j=j+k|0;b=b+k|0}else{break}}return}function cHa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((h|0)<=0){return}i=f<<1;j=i+f|0;k=f<<2;if((g|0)>0){l=e;m=b;n=h}else{return}while(1){h=g;b=l;e=l+f|0;o=l+i|0;p=l+j|0;q=m;while(1){a[q]=((d[b]|0)+8+(d[b+1|0]|0)+(d[b+2|0]|0)+(d[b+3|0]|0)+(d[e]|0)+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[o]|0)+(d[o+1|0]|0)+(d[o+2|0]|0)+(d[o+3|0]|0)+(d[p]|0)+(d[p+1|0]|0)+(d[p+2|0]|0)+(d[p+3|0]|0)|0)>>>4;r=h-1|0;if((r|0)>0){h=r;b=b+4|0;e=e+4|0;o=o+4|0;p=p+4|0;q=q+1|0}else{break}}q=n-1|0;if((q|0)>0){l=l+k|0;m=m+c|0;n=q}else{break}}return}function dHa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((h|0)<=0){return}i=(g|0)>0;j=f<<3;k=j-(g<<3)|0;l=c-g|0;c=8-j|0;j=f*7|0;m=g<<3;n=e;e=b;b=h;while(1){if(i){h=n+m|0;o=n;p=e;q=g;while(1){r=o;s=0;t=0;while(1){u=(d[r]|0)+t+(d[r+1|0]|0)+(d[r+2|0]|0)+(d[r+3|0]|0)+(d[r+4|0]|0)+(d[r+5|0]|0)+(d[r+6|0]|0)+(d[r+7|0]|0)|0;v=s+1|0;if((v|0)<8){r=r+f|0;s=v;t=u}else{break}}a[p]=(u+32|0)>>>6;t=q-1|0;if((t|0)>0){o=o+(j+(c+f))|0;p=p+1|0;q=t}else{break}}w=h;x=e+g|0}else{w=n;x=e}q=b-1|0;if((q|0)>0){n=w+k|0;e=x+l|0;b=q}else{break}}return}function eHa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=6;a=ICb()|0;c[b+4>>2]=a;if((a|0)==0){d=-12;return d|0}c[1254087]=5016368;c[1254089]=16384;N_(5016344,14,143,902450,4,2,902448,4,2,0,0,0,6)|0;d=0;return d|0}function fHa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;h=c[b+60>>2]|0;j=h;k=c[f+24>>2]|0;l=c[f+28>>2]|0;f=d;d=c[h+4>>2]|0;m=$$a(b,d)|0;if((m|0)<0){n=m;i=g;return n|0}if((l|0)<49){yDb(c[h>>2]|0,16,2186976,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1094995529;i=g;return n|0}m=a[k+18|0]|0;c[h+28>>2]=m&255;o=k+48|0;k=(l<<3)-384|0;p=k>>>0>2147483639>>>0|(o|0)==0;q=p?0:o;o=p?0:k;c[h+8>>2]=q;c[h+20>>2]=o;c[h+24>>2]=o+8;c[h+12>>2]=q+(o>>3);c[h+16>>2]=0;h=b+120|0;o=c[h>>2]|0;q=b+124|0;b=c[q>>2]|0;k=c[d>>2]|0;p=c[d+32>>2]|0;do{if(m<<24>>24==0){r=iHa(j,o,b,k,p)|0;if((r|0)<0){n=r;i=g;return n|0}r=iHa(j,c[h>>2]>>2,c[q>>2]>>2,c[d+8>>2]|0,c[d+40>>2]|0)|0;if((r|0)<0){n=r;i=g;return n|0}r=iHa(j,c[h>>2]>>2,c[q>>2]>>2,c[d+4>>2]|0,c[d+36>>2]|0)|0;if((r|0)<0){n=r}else{break}i=g;return n|0}else{r=hHa(j,o,b,k,p)|0;if((r|0)<0){n=r;i=g;return n|0}r=hHa(j,c[h>>2]>>2,c[q>>2]>>2,c[d+8>>2]|0,c[d+40>>2]|0)|0;if((r|0)<0){n=r;i=g;return n|0}r=hHa(j,c[h>>2]>>2,c[q>>2]>>2,c[d+4>>2]|0,c[d+36>>2]|0)|0;if((r|0)<0){n=r}else{break}i=g;return n|0}}while(0);q=MCb(f,d)|0;if((q|0)<0){n=q;i=g;return n|0}c[e>>2]=1;n=l;i=g;return n|0}function gHa(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function hHa(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((f&1|0)!=0){j=-1094995529;return j|0}k=(f|0)>0;a:do{if(k){l=e+16|0;m=e+24|0;n=e+8|0;o=0;b:while(1){p=c[1254087]|0;q=c[l>>2]|0;r=c[m>>2]|0;s=(c[n>>2]|0)+(q>>>3)|0;t=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((q&7)>>>0)&16383;s=b[p+(t<<2)>>1]|0;u=(b[p+(t<<2)+2>>1]|0)+q|0;c[l>>2]=r>>>0>u>>>0?u:r;r=s+1|0;u=r<<1;do{if((r|0)>127){q=u-254|0;if((q+o|0)>(f|0)){j=-1094995529;break b}if((q|0)<=0){v=o;break}q=s<<1;TGb(h+o|0,-128|0,q-252|0)|0;v=o-252+q|0}else{a[h+o|0]=a[902192+u|0]|0;a[h+(o+1)|0]=a[902192+(u|1)|0]|0;v=o+2|0}}while(0);if((v|0)<(f|0)){o=v}else{break a}}return j|0}}while(0);if((g|0)<=1){j=0;return j|0}v=e+16|0;o=e+24|0;l=e+8|0;if(k){w=1;x=h}else{h=1;while(1){k=h+1|0;if((k|0)<(g|0)){h=k}else{j=0;break}}return j|0}c:while(1){h=x+i|0;k=0;while(1){e=c[1254087]|0;n=c[v>>2]|0;m=c[o>>2]|0;u=(c[l>>2]|0)+(n>>>3)|0;s=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((n&7)>>>0)&16383;u=b[e+(s<<2)>>1]|0;r=(b[e+(s<<2)+2>>1]|0)+n|0;c[v>>2]=m>>>0>r>>>0?r:m;m=u+1|0;do{if((m|0)>127){r=(m<<1)-254|0;if((r+k|0)>(f|0)){j=-1094995529;y=27;break c}if((r|0)<=0){z=k;break}n=u<<1;s=0;e=k;while(1){a[x+(e+i)|0]=a[x+e|0]|0;q=s+1|0;if((q|0)<(r|0)){s=q;e=e+1|0}else{break}}z=k-252+n|0}else{e=m<<1;s=(d[x+k|0]|0)-128+(d[902192+e|0]|0)|0;if(s>>>0>255>>>0){A=-s>>31&255}else{A=s&255}a[x+(k+i)|0]=A;s=k+1|0;r=(d[x+s|0]|0)-128+(d[902192+(e|1)|0]|0)|0;if(r>>>0>255>>>0){B=-r>>31&255}else{B=r&255}a[x+(s+i)|0]=B;z=k+2|0}}while(0);if((z|0)<(f|0)){k=z}else{break}}k=w+1|0;if((k|0)<(g|0)){w=k;x=h}else{j=0;y=27;break}}if((y|0)==27){return j|0}return 0}function iHa(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((f&1|0)!=0){j=-1094995529;return j|0}if((g|0)<=0){j=0;return j|0}k=(f|0)>0;l=e+16|0;m=e+24|0;n=e+8|0;e=h;h=0;while(1){if(k){o=0;while(1){p=c[1254087]|0;q=c[l>>2]|0;r=c[m>>2]|0;s=(c[n>>2]|0)+(q>>>3)|0;t=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((q&7)>>>0)&16383;s=b[p+(t<<2)>>1]|0;u=(b[p+(t<<2)+2>>1]|0)+q|0;c[l>>2]=r>>>0>u>>>0?u:r;r=s+1|0;if((r|0)>127){v=o-254+(r<<1)|0}else{s=e+o|0;u=r<<1;r=(((d[902192+u|0]|0)*3|0)-384>>2)+(d[s]|0)|0;if(r>>>0>255>>>0){w=-r>>31&255}else{w=r&255}a[s]=w;s=e+(o+1)|0;r=(((d[902192+(u|1)|0]|0)*3|0)-384>>2)+(d[s]|0)|0;if(r>>>0>255>>>0){x=-r>>31&255}else{x=r&255}a[s]=x;v=o+2|0}if((v|0)<(f|0)){o=v}else{break}}}o=h+1|0;if((o|0)<(g|0)){e=e+i|0;h=o}else{j=0;break}}return j|0}function jHa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[b+60>>2]|0;c[e>>2]=b;c[b+140>>2]=6;f=0;do{g=f+2|0;h=a[1678904+f|0]|0;i=d[1678912+f|0]|0;j=0;do{k=j+h|0;a[4597504+(f<<7)+j|0]=i-((k|0)%(g|0)|0)+k;j=j+1|0;}while((j|0)<128);f=f+1|0;}while((f|0)<8);a[4597631]=126;a[4597751]=118;a[4597752]=118;a[4597886]=124;a[4597887]=124;x=2021161080;a[4598396]=x;x=x>>8;a[4598397]=x;x=x>>8;a[4598398]=x;x=x>>8;a[4598399]=x;a[4597639]=10;a[4598024]=10;BFa(e+4|0,c[b+88>>2]|0);return qHa(e,b,c[b+120>>2]|0,c[b+124>>2]|0)|0}function kHa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;j=i;k=c[e+60>>2]|0;l=k;m=c[h+24>>2]|0;n=c[h+28>>2]|0;h=f;if(!((n|0)>-1)){yDb(0,0,2144840,(o=i,i=i+24|0,c[o>>2]=2139224,c[o+8>>2]=2132952,c[o+16>>2]=135,o)|0);i=o;Cd();return 0}p=m+n|0;if((n|0)<4){q=0;r=m}else{s=m;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;r=m+4|0}if((p-r|0)<4){t=0;u=r}else{m=r;t=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;u=r+4|0}if((p-u|0)<4){v=0;w=u}else{r=u;v=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;w=u+4|0}if((p-w|0)<4){x=0;y=w}else{u=w;x=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;y=w+4|0}if((q^1179798856^t^x|0)!=(v|0)){yDb(e,16,2209496,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1094995529;i=j;return z|0}v=y;do{if((p-v|0)>=2){x=y+2|0;t=y;if(!((d[t]|d[t+1|0]<<8)<<16>>16<<16>>16==32)){break}c[k+260>>2]=q;if((p-x|0)<2){A=0;B=x}else{t=x;A=(d[t]|d[t+1|0]<<8)<<16>>16;B=y+4|0}t=k+268|0;b[t>>1]=A;if((p-B|0)<4){C=0;D=B}else{x=B;C=((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24)+7|0)>>>3;D=B+4|0}x=k+264|0;c[x>>2]=C;if((p-D|0)<1){E=0;F=D}else{E=a[D]|0;F=D+1|0}a[k+270|0]=E;a:do{if((C|0)!=16){w=n-16|0;c[x>>2]=C>>>0>w>>>0?w:C;w=p-F|0;u=w>>>0>3>>>0?3:w;w=F+u|0;if((p-w|0)<2){G=0;H=w}else{r=w;G=(d[r]|d[r+1|0]<<8)<<16>>16&65535;H=F+(u+2)|0}if((p-H|0)<2){I=0;J=H}else{u=H;I=(d[u]|d[u+1|0]<<8)<<16>>16&65535;J=H+2|0}u=e;if((hDb(I,G,0,u)|0)!=0){z=-1094995529;i=j;return z|0}r=k+256|0;if((I|0)==(b[r>>1]|0)){if((G|0)!=(b[k+258>>1]|0)){K=30}}else{K=30}b:do{if((K|0)==30){do{if(!((I-16|0)>>>0>624>>>0|G>>>0<16>>>0|G>>>0>480>>>0)){if((I&3|0)!=0){break}if((G&3|0)!=0){break}b[k+258>>1]=0;b[r>>1]=0;$Db(k+300|0);$Db(k+304|0);c[k+312>>2]=0;c[k+308>>2]=0;$Db(k+328|0);$Db(k+332|0);c[k+340>>2]=0;c[k+336>>2]=0;$Db(k+356|0);$Db(k+360|0);c[k+368>>2]=0;c[k+364>>2]=0;w=qHa(l,e,I,G)|0;if((w|0)<0){z=w;i=j;return z|0}w=V$a(e,I,G)|0;if((w|0)<0){z=w}else{break b}i=j;return z|0}}while(0);yDb(u,16,2192432,(o=i,i=i+16|0,c[o>>2]=I,c[o+8>>2]=G,o)|0);i=o;z=-1094995529;i=j;return z|0}}while(0);if((p-J|0)<4){L=0;M=J}else{r=J;L=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;M=J+4|0}if((p-M|0)<4){N=0;O=M}else{r=M;N=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;O=M+4|0}if((p-O|0)<4){P=0;Q=O}else{r=O;P=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;Q=O+4|0}r=p-Q|0;w=c[x>>2]|0;m=P>>>0<w>>>0;s=m&P>>>0>L>>>0?P:w;R=m&P>>>0>N>>>0?P:w;m=L>>>0>N>>>0;S=N>>>0<w>>>0&N>>>0>P>>>0?N:w;T=Q+(r>>>0>4>>>0?4:r)|0;r=(N>>>0<s>>>0&N>>>0>L>>>0?N:s)-L|0;s=k+284|0;c[s>>2]=r;U=(L>>>0<R>>>0&m?L:R)-N|0;R=k+288|0;c[R>>2]=U;V=(L>>>0<S>>>0&L>>>0>P>>>0?L:S)-P|0;S=k+292|0;c[S>>2]=V;W=m?L:N;do{if((W>>>0>P>>>0?W:P)>>>0<(w-16|0)>>>0){X=m?N:L;if((X>>>0>P>>>0?P:X)>>>0<(16-v+T|0)>>>0){break}X=(r|0)>(U|0)?U:r;if((((X|0)>(V|0)?V:X)|0)<1){break}X=k+272|0;c[X>>2]=y+L;Y=k+276|0;c[Y>>2]=y+N;Z=k+280|0;c[Z>>2]=y+P;c[k+296>>2]=T;if((w|0)==16){yDb(u,48,2165560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break a}_=b[t>>1]|0;$=_&65535;if(($&2|0)!=0){DDb(u,2158928,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1163346256;i=j;return z|0}if(($&48|0)!=0){DDb(u,2151872,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1163346256;i=j;return z|0}do{if(!((_&256)==0)){if((c[e+856>>2]|0)>7){z=0}else{break}i=j;return z|0}}while(0);do{if((_&4)==0){if((c[e+856>>2]|0)>31){z=0}else{break}i=j;return z|0}}while(0);$=k+271|0;a[$]=(_&65535)>>>9&1;aa=_$a(e,h,0)|0;if((aa|0)<0){z=aa;i=j;return z|0}aa=k+300|0;ba=mHa(l,e,aa,c[X>>2]|0,c[s>>2]|0,40)|0;if((ba|0)!=0){z=ba;i=j;return z|0}ba=k+328|0;ca=mHa(l,e,ba,c[Z>>2]|0,c[S>>2]|0,10)|0;if((ca|0)!=0){z=ca;i=j;return z|0}ca=k+356|0;da=mHa(l,e,ca,c[Y>>2]|0,c[R>>2]|0,10)|0;if((da|0)!=0){z=da;i=j;return z|0}da=c[f+32>>2]|0;ea=e+124|0;fa=c[ea>>2]|0;ga=c[k+324>>2]|0;ha=c[k+320>>2]|0;ia=ha>>>0<fa>>>0?ha:fa;if((ia|0)>0){ha=k+316|0;ja=0;ka=c[aa+8+(d[$]<<2)>>2]|0;aa=c[f>>2]|0;la=c[ha>>2]|0;while(1){if(la>>>0>3>>>0){ma=0;na=ka;oa=aa;do{c[oa>>2]=c[na>>2]<<1&-16843010;na=na+4|0;oa=oa+4|0;ma=ma+1|0;pa=c[ha>>2]|0;}while(ma>>>0<pa>>>2>>>0);qa=ma<<2;ra=na;sa=oa;ta=pa}else{qa=0;ra=ka;sa=aa;ta=la}if(qa>>>0<ta>>>0){ua=qa;va=ra;wa=sa;while(1){xa=va+1|0;ya=wa+1|0;a[wa]=a[va]<<1;za=ua+1|0;Aa=c[ha>>2]|0;if(za>>>0<Aa>>>0){ua=za;va=xa;wa=ya}else{Ba=xa;Ca=ya;Da=Aa;break}}}else{Ba=ra;Ca=sa;Da=ta}wa=ja+1|0;if((wa|0)<(ia|0)){ja=wa;ka=Ba+(ga-Da)|0;aa=Ca+(da-Da)|0;la=Da}else{break}}Ea=c[ea>>2]|0}else{Ea=fa}la=c[f+36>>2]|0;da=Ea+3>>2;aa=c[k+352>>2]|0;ga=c[k+348>>2]|0;ka=ga>>>0<da>>>0?ga:da;if((ka|0)>0){da=k+344|0;ga=0;ja=c[ba+8+(d[$]<<2)>>2]|0;ia=c[f+4>>2]|0;ha=c[da>>2]|0;while(1){if(ha>>>0>3>>>0){Y=0;Z=ja;X=ia;do{c[X>>2]=c[Z>>2]<<1&-16843010;Z=Z+4|0;X=X+4|0;Y=Y+1|0;Fa=c[da>>2]|0;}while(Y>>>0<Fa>>>2>>>0);Ga=Y<<2;Ha=Z;Ia=X;Ja=Fa}else{Ga=0;Ha=ja;Ia=ia;Ja=ha}if(Ga>>>0<Ja>>>0){_=Ga;wa=Ha;va=Ia;while(1){ua=wa+1|0;oa=va+1|0;a[va]=a[wa]<<1;na=_+1|0;ma=c[da>>2]|0;if(na>>>0<ma>>>0){_=na;wa=ua;va=oa}else{Ka=ua;La=oa;Ma=ma;break}}}else{Ka=Ha;La=Ia;Ma=Ja}va=ga+1|0;if((va|0)<(ka|0)){ga=va;ja=Ka+(aa-Ma)|0;ia=La+(la-Ma)|0;ha=Ma}else{break}}Na=c[ea>>2]|0}else{Na=Ea}ha=c[f+40>>2]|0;la=Na+3>>2;ia=c[k+380>>2]|0;aa=c[k+376>>2]|0;ja=aa>>>0<la>>>0?aa:la;if((ja|0)>0){la=k+372|0;aa=0;ga=c[ca+8+(d[$]<<2)>>2]|0;ka=c[f+8>>2]|0;da=c[la>>2]|0;while(1){if(da>>>0>3>>>0){ba=0;fa=ga;va=ka;do{c[va>>2]=c[fa>>2]<<1&-16843010;fa=fa+4|0;va=va+4|0;ba=ba+1|0;Oa=c[la>>2]|0;}while(ba>>>0<Oa>>>2>>>0);Pa=ba<<2;Qa=fa;Ra=va;Sa=Oa}else{Pa=0;Qa=ga;Ra=ka;Sa=da}if(Pa>>>0<Sa>>>0){wa=Pa;_=Qa;X=Ra;while(1){Z=_+1|0;Y=X+1|0;a[X]=a[_]<<1;ma=wa+1|0;oa=c[la>>2]|0;if(ma>>>0<oa>>>0){wa=ma;_=Z;X=Y}else{Ta=Z;Ua=Y;Va=oa;break}}}else{Ta=Qa;Ua=Ra;Va=Sa}X=aa+1|0;if((X|0)<(ja|0)){aa=X;ga=Ta+(ia-Va)|0;ka=Ua+(ha-Va)|0;da=Va}else{break}}}c[g>>2]=1;z=n;i=j;return z|0}}while(0);yDb(u,16,2176112,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1094995529;i=j;return z|0}}while(0);c[g>>2]=0;z=n;i=j;return z|0}}while(0);yDb(e,16,2200888,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1094995529;i=j;return z|0}function lHa(a){a=a|0;var d=0;d=c[a+60>>2]|0;b[d+258>>1]=0;b[d+256>>1]=0;$Db(d+300|0);$Db(d+304|0);c[d+312>>2]=0;c[d+308>>2]=0;$Db(d+328|0);$Db(d+332|0);c[d+340>>2]=0;c[d+336>>2]=0;$Db(d+356|0);$Db(d+360|0);c[d+368>>2]=0;c[d+364>>2]=0;return 0}function mHa(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;l=i;i=i+16|0;m=l|0;n=h;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j-4|0;if(o>>>0>256>>>0){yDb(c[e>>2]|0,16,2186896,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=-1094995529;i=l;return q|0}p=o<<1;if(p>>>0>n>>>0){q=-1094995529;i=l;return q|0}c[e+252>>2]=o;c[e+248>>2]=(o|0)!=0?h+4|0:0;o=h+(p+4)|0;r=n-p<<3;p=r>>>0>2147483639>>>0|(o|0)==0;n=p?0:o;o=p?0:r;c[e+212>>2]=n;c[e+224>>2]=o;c[e+228>>2]=o+8;c[e+216>>2]=n+(o>>3);c[e+220>>2]=0;c[e+236>>2]=0;c[e+232>>2]=0;c[e+244>>2]=h+j;b[m+2>>1]=0;b[m>>1]=0;b[m+4>>1]=(c[g+16>>2]|0)>>>2;b[m+6>>1]=(c[g+20>>2]|0)>>>2;a[m+8|0]=0;c[m+12>>2]=0;q=nHa(e,f,g,2,m,20,k)|0;i=l;return q|0}function nHa(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;m=i;i=i+40|0;n=m|0;o=m+8|0;p=m+16|0;q=m+24|0;if((k|0)<1){yDb(f,16,2109776,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=m;return s|0}t=q;u=j;c[t>>2]=c[u>>2];c[t+4>>2]=c[u+4>>2];c[t+8>>2]=c[u+8>>2];c[t+12>>2]=c[u+12>>2];do{if((h|0)==0){u=j+6|0;t=b[u>>1]|0;if(t<<16>>16>2){v=((t<<16>>16)+2|0)>>>2<<1&65535}else{v=1}b[q+6>>1]=v;w=j+2|0;b[w>>1]=(b[w>>1]|0)+v;w=t-v&65535;b[u>>1]=w;if(w<<16>>16<1|v<<16>>16<1){s=-1094995529}else{break}i=m;return s|0}else if((h|0)==1){w=q+4|0;u=b[w>>1]|0;do{if((u|0)>(l|0)){t=(ba((u|0)<=(l<<1|0)?1:2,l)|0)&65535;x=t;y=b[j+4>>1]|0}else{t=b[j+4>>1]|0;if(!(t<<16>>16>2)){x=1;y=t;break}x=((t<<16>>16)+2|0)>>>2<<1&65535;y=t}}while(0);b[w>>1]=x;u=j|0;b[u>>1]=(b[u>>1]|0)+x;u=y-x&65535;b[j+4>>1]=u;if(u<<16>>16<1|x<<16>>16<1){s=-1094995529}else{break}i=m;return s|0}}while(0);x=e+220|0;j=c[x>>2]|0;y=e+224|0;h=c[y>>2]|0;if((h-j|0)<=1){s=-1094995529;i=m;return s|0}v=e+232|0;u=e+228|0;t=e+212|0;z=k-1|0;k=q+8|0;A=q+12|0;B=e+240|0;C=e+244|0;D=e+252|0;E=e+248|0;F=e+236|0;G=j;j=h;while(1){h=c[v>>2]|0;do{if((h|0)==0){H=G;I=0}else{if((G&7|0)!=0){H=G;I=h;break}J=c[F>>2]|0;K=-G|0;L=(c[u>>2]|0)-G|0;if((J|0)<(K|0)){M=K}else{M=(L|0)<(J|0)?L:J}J=M+G|0;c[x>>2]=J;c[F>>2]=0;c[v>>2]=0;H=J;I=0}}while(0);N=c[u>>2]|0;O=c[t>>2]|0;h=O+(H>>>3)|0;w=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(H&7)>>>30;h=H+2|0;P=N>>>0>h>>>0?h:N;c[x>>2]=P;if((w|0)==3){Q=(I|0)!=0;if((a[k]|0)!=0){R=49;break}if(Q){S=c[B>>2]|0}else{h=O+(P+7>>3)|0;c[B>>2]=h;S=h}if(!(S>>>0<(c[C>>2]|0)>>>0)){R=44;break}c[B>>2]=S+1;h=d[S]|0;if(!(h>>>0<(c[D>>2]|0)>>>0)){R=46;break}c[A>>2]=(c[E>>2]|0)+(h<<1);a[k]=1;c[F>>2]=(c[F>>2]|0)+8;c[v>>2]=1;T=P;U=j}else if((w|0)==2){if((a[k]|0)!=0){R=24;break}c[A>>2]=0;a[k]=1;T=P;U=j}else if((w|0)==0|(w|0)==1){if((nHa(e,f,g,w,q,z,l)|0)!=0){s=-1094995529;R=95;break}T=c[x>>2]|0;U=c[y>>2]|0}else{T=P;U=j}if((U-T|0)>1){G=T;j=U}else{s=-1094995529;R=95;break}}if((R|0)==24){do{if((I|0)==0){V=P}else{if((P&7|0)!=0){V=P;break}U=c[F>>2]|0;j=-P|0;T=N-P|0;if((U|0)<(j|0)){W=j}else{W=(T|0)<(U|0)?T:U}U=W+P|0;c[x>>2]=U;c[F>>2]=0;c[v>>2]=0;V=U}}while(0);W=O+(V>>>3)|0;I=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(V&7);W=I>>>30;U=V+2|0;c[x>>2]=N>>>0>U>>>0?U:N;if((I|0)<0){yDb(f,16,2051624,(r=i,i=i+8|0,c[r>>2]=W,r)|0);i=r;s=-1094995529;i=m;return s|0}if((W|0)==1){yDb(f,16,2006192,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}W=b[q>>1]|0;I=b[q+4>>1]|0;N=b[q+2>>1]|0;do{if((I+W|0)>>>0>(c[g+16>>2]|0)>>>2>>>0){X=b[q+6>>1]|0}else{U=b[q+6>>1]|0;if(((U<<16>>16)+(N<<16>>16)|0)>>>0>(c[g+20>>2]|0)>>>2>>>0){X=U;break}if((c[A>>2]|0)==0){s=-1094995529;i=m;return s|0}s=oHa(e,g,q)|0;i=m;return s|0}}while(0);yDb(f,16,1968408,(r=i,i=i+32|0,c[r>>2]=W,c[r+8>>2]=N<<16>>16,c[r+16>>2]=I,c[r+24>>2]=X<<16>>16,r)|0);i=r;s=-1094995529;i=m;return s|0}else if((R|0)==44){yDb(f,16,1939968,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=m;return s|0}else if((R|0)==46){yDb(f,16,1915736,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=m;return s|0}else if((R|0)==49){if(!Q){c[B>>2]=O+(P+7>>3)}P=b[q>>1]|0;O=q+4|0;Q=b[O>>1]|0;X=Q+P|0;I=c[g+16>>2]|0;N=b[q+2>>1]|0;do{if(X>>>0>I>>>2>>>0){Y=b[q+6>>1]|0}else{W=N<<16>>16;U=b[q+6>>1]|0;x=(U<<16>>16)+W|0;V=c[g+20>>2]|0;if(x>>>0>V>>>2>>>0){Y=U;break}U=c[B>>2]|0;T=c[C>>2]|0;c[n>>2]=U+1;j=a[U]|0;G=j&255;y=G>>>4;l=G&15;G=W<<2;W=g+24|0;z=c[W>>2]|0;k=P<<2;E=k+(ba(G,z)|0)|0;D=d[e+271|0]|0;S=c[g+8+(D<<2)>>2]|0;H=S+E|0;t=c[A>>2]|0;a:do{if((t|0)==0){Z=S+(E-z)|0;R=65}else{if((j&255)>>>0>159>>>0){u=oHa(e,g,q)|0;if((u|0)<0){_=u;break}else{Z=0;R=65;break}}u=a[t]|0;M=a[t+1|0]|0;do{if(!((u+G|0)<-1)){if((M+k|0)<0){break}if(((x<<2)+u|0)>>>0>V>>>0){break}if(((X<<2)+M|0)>>>0>I>>>0){break}w=M+E+(ba(u,z)|0)|0;Z=(c[g+8+((D^1)<<2)>>2]|0)+w|0;R=65;break a}}while(0);yDb(c[e>>2]|0,16,1895192,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;_=-1094995529}}while(0);b:do{if((R|0)==65){if((y|0)==4|(y|0)==1){D=a[(c[e+296>>2]|0)+l|0]|0;z=D&255;E=d[e+270|0]|0;$=l;aa=D;ca=(z&15)+E|0;da=(z>>>4)+E|0}else{E=(d[e+270|0]|0)+l|0;$=E;aa=j;ca=E;da=E}if((da|0)>23|(ca|0)>23){yDb(f,16,2352288,(r=i,i=i+16|0,c[r>>2]=da,c[r+8>>2]=ca,r)|0);i=r;_=-1094995529;break}E=p|0;c[E>>2]=92072+(ca*12|0);c[p+4>>2]=92072+(da*12|0);z=o|0;c[z>>2]=(ca|0)>15;c[o+4>>2]=(da|0)>15;do{if(!(($|0)<8|(Z|0)==0)){if((b[O>>1]<<2|0)<=0){break}D=$&7;V=0;do{x=Z+V|0;a[x]=a[(a[x]&127)+(4597504+(D<<7))|0]|0;V=V+1|0;}while((V|0)<(b[O>>1]<<2|0))}}while(0);c:do{switch(y|0){case 10:case 11:{V=(y|0)==10;D=(c[A>>2]|0)==0;do{if(V){if(!D){break}ea=pHa(q,H,Z,c[W>>2]|0,1,1,10,E,z,n,T)|0;break c}else{if(!D){break}yDb(f,16,2307832,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;_=-1094995529;break b}}while(0);ea=pHa(q,H,Z,c[W>>2]|0,V&1,1,y,E,z,n,T)|0;break};case 0:case 1:case 3:case 4:{D=(j&255)>>>0>47>>>0;do{if(D){if((c[A>>2]|0)==0){break}yDb(f,16,2332136,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;_=-1094995529;break b}}while(0);ea=pHa(q,H,Z,c[W>>2]|0,0,D&1,y,E,z,n,T)|0;break};default:{yDb(f,16,2289336,(r=i,i=i+8|0,c[r>>2]=y,r)|0);i=r;_=-1094995529;break b}}}while(0);switch(ea|0){case 5:{yDb(f,16,2218880,(r=i,i=i+8|0,c[r>>2]=y,r)|0);i=r;_=-1094995529;break b;break};case 4:{z=d[(c[n>>2]|0)-1|0]|0;yDb(f,16,2230976,(r=i,i=i+16|0,c[r>>2]=y,c[r+8>>2]=z,r)|0);i=r;_=-1094995529;break b;break};case 1:{z=d[(c[n>>2]|0)-1|0]|0;yDb(f,16,2273272,(r=i,i=i+16|0,c[r>>2]=y,c[r+8>>2]=z,r)|0);i=r;_=-1094995529;break b;break};case 2:{yDb(f,16,2257680,(r=i,i=i+8|0,c[r>>2]=y,r)|0);i=r;_=-1094995529;break b;break};case 3:{yDb(f,16,2243432,(r=i,i=i+16|0,c[r>>2]=y,c[r+8>>2]=aa&255,r)|0);i=r;_=-1094995529;break b;break};default:{_=(c[n>>2]|0)-U|0;break b}}}}while(0);if((_|0)<0){s=-1094995529;i=m;return s|0}c[F>>2]=(c[F>>2]|0)+(_<<3);c[v>>2]=1;c[B>>2]=(c[B>>2]|0)+_;s=0;i=m;return s|0}}while(0);yDb(f,16,1968408,(r=i,i=i+32|0,c[r>>2]=P,c[r+8>>2]=N<<16>>16,c[r+16>>2]=Q,c[r+24>>2]=Y<<16>>16,r)|0);i=r;s=-1094995529;i=m;return s|0}else if((R|0)==95){i=m;return s|0}return 0}function oHa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;j=b[g+2>>1]|0;k=j<<2;l=f+24|0;m=c[l>>2]|0;n=ba(k,m)|0;o=g|0;p=b[o>>1]|0;q=p<<16>>16;r=q<<2;s=r+n|0;n=d[e+271|0]|0;t=(c[f+8+(n<<2)>>2]|0)+s|0;u=c[g+12>>2]|0;if((u|0)==0){v=0;w=0}else{v=a[u]|0;w=a[u+1|0]|0}do{if(!((k+v|0)<-1)){if((r+w|0)<0){break}u=b[g+6>>1]|0;if(((u+j<<2)+v|0)>>>0>(c[f+20>>2]|0)>>>0){break}x=b[g+4>>1]|0;y=x<<16>>16;if(((y+q<<2)+w|0)>>>0>(c[f+16>>2]|0)>>>0){break}z=u<<2;if(!(x<<16>>16>0)){A=0;i=h;return A|0}x=ba(m,v)|0;u=e+20|0;B=e+36|0;C=e+4|0;D=y;y=(c[f+8+((n^1)<<2)>>2]|0)+(w+s+x)|0;x=t;E=p;while(1){if((E&3)==0&(D|0)>3){F=D-4|0;G=F>>>2;H=F-(G<<2)|0;F=G<<4;G=x;I=y;J=D;while(1){cf[c[C>>2]&1023](G,I,c[l>>2]|0,z);K=J-4|0;if((K|0)<=3){break}G=G+16|0;I=I+16|0;J=K}L=x+(F+16)|0;M=y+(F+16)|0;N=H;O=b[o>>1]|0}else{L=x;M=y;N=D;O=E}if((O&1)==0&(N|0)>1){cf[c[u>>2]&1023](L,M,c[l>>2]|0,z);P=L+8|0;Q=M+8|0;R=N-2|0}else{if((N|0)<=0){A=0;S=21;break}cf[c[B>>2]&1023](L,M,c[l>>2]|0,z);P=L+4|0;Q=M+4|0;R=N-1|0}if((R|0)<=0){A=0;S=21;break}D=R;y=Q;x=P;E=b[o>>1]|0}if((S|0)==21){i=h;return A|0}}}while(0);yDb(c[e>>2]|0,16,1895192,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;A=-1094995529;i=h;return A|0}function pHa(e,f,g,h,i,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0;p=e+4|0;q=b[p>>1]|0;r=q<<16>>16;s=(h<<j+2)-(r<<2)|0;t=(j|0)!=0?h:0;u=e+6|0;v=b[u>>1]|0;if((v<<16>>16&j|0)!=0){w=2;return w|0}if((r&i|0)!=0){w=2;return w|0}if(!(v<<16>>16>0)){w=0;return w|0}r=j+1|0;y=(k|0)<5;z=e+12|0;A=4<<j;B=(A|0)>0;C=(k|0)==10;D=4<<i;E=i+1|0;i=t+2|0;G=(k|0)>2;H=e+2|0;e=h+4|0;I=h+2|0;J=(k|0)>9;k=y^1;K=l+4|0;L=0;M=0;N=0;O=1;P=g;g=f;f=q;q=v;a:while(1){if(f<<16>>16>0){v=(O|0)==0;Q=(O|0)!=0;R=L;S=M;T=0;U=P;V=g;while(1){if((R|0)>0){do{if(y){if((S|0)!=0&(c[z>>2]|0)==0|B^1){break}else{W=U;X=V;Y=0}while(1){Z=W;_=X;x=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;_=Y+1|0;if((_|0)<(A|0)){W=W+h|0;X=X+h|0;Y=_}else{break}}}else{if(!C){break}if((c[z>>2]|0)!=0){break}_=U;Z=_|0;$=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;Z=_+4|0;aa=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;if(v){Z=V;c[Z>>2]=$;c[Z+4>>2]=aa;Z=V+h|0;c[Z>>2]=$;c[Z+4>>2]=aa;Z=h<<1;ca=V+Z|0;c[ca>>2]=$;c[ca+4>>2]=aa;ca=Z+h|0;Z=V+ca|0;c[Z>>2]=$;c[Z+4>>2]=aa;Z=ca+h|0;ca=V+Z|0;c[ca>>2]=$;c[ca+4>>2]=aa;ca=Z+h|0;Z=V+ca|0;c[Z>>2]=$;c[Z+4>>2]=aa;Z=ca+h|0;ca=V+Z|0;c[ca>>2]=$;c[ca+4>>2]=aa;ca=V+(Z+h)|0;c[ca>>2]=$;c[ca+4>>2]=aa;break}else{ca=$&16711935;$=aa&16711935;aa=ca<<8|0>>>24|ca;Z=$<<8|ca>>>24|$;$=V+h|0;c[$>>2]=aa;c[$+4>>2]=Z;ca=h<<1;da=V+ca|0;c[da>>2]=aa;c[da+4>>2]=Z;da=ca+h|0;ca=V+da|0;c[ca>>2]=aa;c[ca+4>>2]=Z;ca=da+h|0;da=V+ca|0;c[da>>2]=aa;c[da+4>>2]=Z;da=ca+h|0;ca=V+da|0;c[ca>>2]=aa;c[ca+4>>2]=Z;ca=da+h|0;da=V+ca|0;c[da>>2]=aa;c[da+4>>2]=Z;da=V+(ca+h)|0;c[da>>2]=aa;c[da+4>>2]=Z;Z=_|0;da=_+4|0;_=$|0;aa=$+4|0;$=YGb(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0,d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0,d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0,d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0;da=F;Z=V;c[Z>>2]=($>>>1|da<<31)&2139062143;c[Z+4>>2]=(da>>>1|0<<31)&2139062143;break}}}while(0);ea=S;fa=R-1|0}else{da=0;Z=R;$=V;aa=U;_=S;while(1){ca=(da|0)==0;ga=ca&Q;if(y){ha=l+((da&1)<<2)|0}else{ha=K}ia=c[ha>>2]|0;ja=c[n>>2]|0;if(!(ja>>>0<o>>>0)){w=5;ka=79;break a}la=ja+1|0;c[n>>2]=la;ma=a[ja]|0;na=ma&255;b:do{if((ma&255)>>>0<248>>>0){oa=ia+8|0;pa=a[oa]|0;if((ma&255)>>>0<(pa&255)>>>0){if(!(la>>>0<o>>>0)){w=5;ka=79;break a}c[n>>2]=ja+2;qa=a[la]|0;if((qa&255)>>>0>=(d[oa]|0)>>>0|(qa&255)>>>0>247>>>0){w=2;ka=79;break a}else{ra=na;sa=qa&255}}else{qa=na-(pa&255)&255;pa=d[ia+9|0]|0;oa=(qa>>>0)/(pa>>>0)|0;ta=(qa>>>0)%(pa>>>0)|0;pa=(c[m+((da&1)<<2)>>2]|0)==0;ra=pa?ta:oa;sa=pa?oa:ta}if(y){ta=aa;oa=ia|0;b[$+t>>1]=(b[(c[oa>>2]|0)+(sa<<1)>>1]|0)+((d[ta]|d[ta+1|0]<<8)<<16>>16)&32639;ta=aa+2|0;b[$+i>>1]=(b[(c[oa>>2]|0)+(ra<<1)>>1]|0)+((d[ta]|d[ta+1|0]<<8)<<16>>16)&32639;if(!G){ua=_;va=Z;wa=1;break}do{if(ga){if((b[H>>1]|0)!=0){break}ta=$+h|0;oa=$;x=d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;ua=_;va=Z;wa=1;break b}}while(0);oa=aa;ta=$+h|0;c[$>>2]=((d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)|0)>>>1&2139062143;ua=_;va=Z;wa=1;break}if(!C){oa=$;ta=ia|0;b[oa>>1]=(b[(c[ta>>2]|0)+(sa<<1)>>1]|0)+((d[oa]|d[oa+1|0]<<8)<<16>>16)&32639;oa=$+2|0;b[oa>>1]=(b[(c[ta>>2]|0)+(ra<<1)>>1]|0)+((d[oa]|d[oa+1|0]<<8)<<16>>16)&32639;oa=$+h|0;b[oa>>1]=(b[(c[ta>>2]|0)+(sa<<1)>>1]|0)+((d[oa]|d[oa+1|0]<<8)<<16>>16)&32639;oa=$+I|0;b[oa>>1]=(b[(c[ta>>2]|0)+(ra<<1)>>1]|0)+((d[oa]|d[oa+1|0]<<8)<<16>>16)&32639;ua=_;va=Z;wa=1;break}if((c[z>>2]|0)!=0){oa=$;ta=ia+4|0;c[oa>>2]=(c[(c[ta>>2]|0)+(sa<<2)>>2]|0)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&2139062143;oa=$+4|0;c[oa>>2]=(c[(c[ta>>2]|0)+(ra<<2)>>2]|0)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&2139062143;oa=$+h|0;c[oa>>2]=(c[(c[ta>>2]|0)+(sa<<2)>>2]|0)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&2139062143;oa=$+e|0;c[oa>>2]=(c[(c[ta>>2]|0)+(ra<<2)>>2]|0)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&2139062143;ua=_;va=Z;wa=1;break}oa=aa;ta=d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0;do{if(ga){oa=ta&16711935;pa=ia+4|0;qa=$+h|0;c[qa>>2]=(c[(c[pa>>2]|0)+(sa<<2)>>2]|0)+(oa<<8|oa)&2139062143;oa=aa+4|0;xa=(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&16711935;c[$+e>>2]=(xa<<8|xa)+(c[(c[pa>>2]|0)+(ra<<2)>>2]|0)&2139062143;if((b[H>>1]|0)!=0){break}pa=qa;qa=pa|0;xa=pa+4|0;pa=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;xa=$;oa=xa|0;x=d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;oa=xa+4|0;x=pa;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;ua=_;va=Z;wa=1;break b}else{oa=ia+4|0;c[$+h>>2]=(c[(c[oa>>2]|0)+(sa<<2)>>2]|0)+ta&2139062143;pa=aa+4|0;c[$+e>>2]=(c[(c[oa>>2]|0)+(ra<<2)>>2]|0)+(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24)&2139062143}}while(0);ta=aa;pa=ta|0;oa=ta+4|0;ta=$+h|0;xa=ta|0;qa=ta+4|0;ta=YGb(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0,d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0,d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0,d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0;oa=F;pa=$;c[pa>>2]=(ta>>>1|oa<<31)&2139062143;c[pa+4>>2]=(oa>>>1|0<<31)&2139062143;ua=_;va=Z;wa=1}else{switch(na|0){case 252:{ya=0;za=-3;Aa=1;break};case 255:case 254:case 253:{ya=_;za=ma;Aa=Z;break};case 251:{if(!(la>>>0<o>>>0)){w=5;ka=79;break a}c[n>>2]=ja+2;oa=a[la]|0;pa=oa&255;ta=(pa&31)-1|0;if((oa&255)>>>0>63>>>0|(ta|0)<0){w=3;ka=79;break a}oa=pa&32;pa=4-da|0;if(!J){if(!((c[z>>2]|0)!=0|(oa|0)==0)){ua=oa;va=ta;wa=pa;break b}}if(y){qa=pa<<j;if((qa|0)>0){Ba=aa;Ca=$;Da=0}else{ua=oa;va=ta;wa=pa;break b}while(1){xa=Ba;Ea=Ca;x=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;a[Ea]=x;x=x>>8;a[Ea+1|0]=x;x=x>>8;a[Ea+2|0]=x;x=x>>8;a[Ea+3|0]=x;Ea=Da+1|0;if((Ea|0)<(qa|0)){Ba=Ba+h|0;Ca=Ca+h|0;Da=Ea}else{ua=oa;va=ta;wa=pa;break b}}}if(!C){ua=oa;va=ta;wa=pa;break b}if((c[z>>2]|0)!=0){ua=oa;va=ta;wa=pa;break b}qa=aa;Ea=qa|0;xa=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0;Ea=qa+4|0;Fa=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0;if(!ga){Ea=pa<<1;if((Ea|0)>0){Ga=Ea;Ha=$}else{ua=oa;va=ta;wa=pa;break b}while(1){Ea=Ha;c[Ea>>2]=xa;c[Ea+4>>2]=Fa;Ea=Ga-1|0;if((Ea|0)>0){Ga=Ea;Ha=Ha+h|0}else{ua=oa;va=ta;wa=pa;break b}}}Ea=xa&16711935;Ia=Fa&16711935;Ja=Ea<<8|0>>>24|Ea;Ka=Ia<<8|Ea>>>24|Ia;Ia=$+h|0;Ea=(pa<<1)-1|0;if((Ea|0)>0){La=Ea;Ea=Ia;while(1){Ma=Ea;c[Ma>>2]=Ja;c[Ma+4>>2]=Ka;Ma=La-1|0;if((Ma|0)>0){La=Ma;Ea=Ea+h|0}else{break}}Ea=qa|0;La=qa+4|0;Na=d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0;Oa=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0}else{Na=Fa;Oa=xa}Ea=Ia;La=Ea|0;Ka=Ea+4|0;Ea=YGb(d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0,d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0,Oa,Na)|0;Ka=F;La=$;c[La>>2]=(Ea>>>1|Ka<<31)&2139062143;c[La+4>>2]=(Ka>>>1|0<<31)&2139062143;ua=oa;va=ta;wa=pa;break b;break};case 249:{Pa=1;Qa=1;ka=72;break};case 250:{Pa=_;Qa=Z;ka=72;break};default:{w=4;ka=79;break a}}if((ka|0)==72){ka=0;if(!ca){w=1;ka=79;break a}if((c[z>>2]|0)==0|k|B^1){ua=Pa;va=Qa;wa=4;break}else{Ra=aa;Sa=$;Ta=0}while(1){Ka=Ra;La=Sa;x=d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0;a[La]=x;x=x>>8;a[La+1|0]=x;x=x>>8;a[La+2|0]=x;x=x>>8;a[La+3|0]=x;La=Ta+1|0;if((La|0)<(A|0)){Ra=Ra+h|0;Sa=Sa+h|0;Ta=La}else{ua=Pa;va=Qa;wa=4;break b}}}pa=257-(za&255)-da|0;if((pa|0)<1){w=1;ka=79;break a}if(y){ta=pa<<j;if((ta|0)>0){Ua=aa;Va=$;Wa=0}else{ua=ya;va=Aa;wa=pa;break}while(1){oa=Ua;Ia=Va;x=d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0;a[Ia]=x;x=x>>8;a[Ia+1|0]=x;x=x>>8;a[Ia+2|0]=x;x=x>>8;a[Ia+3|0]=x;Ia=Wa+1|0;if((Ia|0)<(ta|0)){Ua=Ua+h|0;Va=Va+h|0;Wa=Ia}else{ua=ya;va=Aa;wa=pa;break b}}}if(!C){ua=ya;va=Aa;wa=pa;break}if((c[z>>2]|0)!=0){ua=ya;va=Aa;wa=pa;break}ta=aa;Ia=ta|0;oa=d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0;Ia=ta+4|0;xa=d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0;if(!ga){Ia=pa<<1;if((Ia|0)>0){Xa=Ia;Ya=$}else{ua=ya;va=Aa;wa=pa;break}while(1){Ia=Ya;c[Ia>>2]=oa;c[Ia+4>>2]=xa;Ia=Xa-1|0;if((Ia|0)>0){Xa=Ia;Ya=Ya+h|0}else{ua=ya;va=Aa;wa=pa;break b}}}Ia=oa&16711935;Fa=xa&16711935;qa=Ia<<8|0>>>24|Ia;La=Fa<<8|Ia>>>24|Fa;Fa=$+h|0;Ia=(pa<<1)-1|0;if((Ia|0)>0){Ka=Ia;Ia=Fa;while(1){Ea=Ia;c[Ea>>2]=qa;c[Ea+4>>2]=La;Ea=Ka-1|0;if((Ea|0)>0){Ka=Ea;Ia=Ia+h|0}else{break}}Ia=ta|0;Ka=ta+4|0;Za=d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0;_a=d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0}else{Za=xa;_a=oa}Ia=Fa;Ka=Ia|0;La=Ia+4|0;Ia=YGb(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0,d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0,_a,Za)|0;La=F;Ka=$;c[Ka>>2]=(Ia>>>1|La<<31)&2139062143;c[Ka+4>>2]=(La>>>1|0<<31)&2139062143;ua=ya;va=Aa;wa=pa}}while(0);ga=wa+da|0;ca=ba(wa<<j,h)|0;if((ga|0)<4){da=ga;Z=va;$=$+ca|0;aa=aa+ca|0;_=ua}else{ea=ua;fa=va;break}}}$a=V+D|0;ab=U+D|0;_=E+T|0;bb=b[p>>1]|0;if((_|0)<(bb<<16>>16|0)){R=fa;S=ea;T=_;U=ab;V=$a}else{break}}cb=fa;db=ea;eb=ab;fb=$a;gb=bb;hb=b[u>>1]|0}else{cb=L;db=M;eb=P;fb=g;gb=f;hb=q}V=r+N|0;if((V|0)<(hb<<16>>16|0)){L=cb;M=db;N=V;O=0;P=eb+s|0;g=fb+s|0;f=gb;q=hb}else{w=0;ka=79;break}}if((ka|0)==79){return w|0}return 0}function qHa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;do{if(!((e-16|0)>>>0>624>>>0)){if((f-16|0)>>>0>464>>>0){break}if((e&3|0)!=0){break}if((f&3|0)!=0){break}h=a+256|0;b[h>>1]=e;j=a+258|0;b[j>>1]=f;k=(e>>2)+3&-4;l=(f>>2)+3&-4;m=e+15&-16;n=k+15&-16;o=ba(m,f+1|0)|0;p=ba(n,l|1)|0;q=0;while(1){r=(q|0)!=0;s=a+300+(q*28|0)+24|0;c[s>>2]=r?n:m;c[a+300+(q*28|0)+16>>2]=r?k:e;t=a+300+(q*28|0)+20|0;c[t>>2]=r?l:f;u=r?p:o;r=a+300+(q*28|0)|0;c[r>>2]=WDb(u)|0;v=WDb(u)|0;u=a+300+(q*28|0)+4|0;c[u>>2]=v;w=c[r>>2]|0;if((w|0)==0|(v|0)==0){break}TGb(w|0,64,c[s>>2]|0)|0;TGb(c[u>>2]|0,64,c[s>>2]|0)|0;w=c[s>>2]|0;v=(c[r>>2]|0)+w|0;c[a+300+(q*28|0)+8>>2]=v;r=a+300+(q*28|0)+12|0;c[r>>2]=(c[u>>2]|0)+w;TGb(v|0,0,ba(c[t>>2]|0,w)|0)|0;TGb(c[r>>2]|0,0,ba(c[t>>2]|0,c[s>>2]|0)|0)|0;s=q+1|0;if((s|0)<3){q=s}else{x=0;y=10;break}}if((y|0)==10){i=g;return x|0}b[j>>1]=0;b[h>>1]=0;$Db(a+300|0);$Db(a+304|0);c[a+312>>2]=0;c[a+308>>2]=0;$Db(a+328|0);$Db(a+332|0);c[a+340>>2]=0;c[a+336>>2]=0;$Db(a+356|0);$Db(a+360|0);c[a+368>>2]=0;c[a+364>>2]=0;x=-12;i=g;return x|0}}while(0);yDb(d,16,2192432,(d=i,i=i+16|0,c[d>>2]=e,c[d+8>>2]=f,d)|0);i=d;x=-1094995529;i=g;return x|0}function rHa(a){a=a|0;var d=0;d=c[a+60>>2]|0;sIa();UGb(d+20|0,1194080,4626)|0;b[d+4692>>1]=0;b[d+4694>>1]=0;c[a+140>>2]=6;c[d+4872>>2]=162;c[d+4876>>2]=12;c[d+4880>>2]=160;c[d+4884>>2]=330;c[d+4888>>2]=672;return 0}function sHa(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;h=i;i=i+16|0;j=h|0;k=f|0;l=f+8|0;m=c[l>>2]|0;n=f+16|0;o=c[n>>2]|0;p=f|0;q=c[p>>2]|0;r=q+(m>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&262143;r=m+18|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;if((s|0)!=262136){yDb(g,16,2176080,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}s=f+4652|0;c[f+4656>>2]=c[s>>2];r=q+(m>>>3)|0;v=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&7;r=m+3|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;c[s>>2]=v;if((v|0)==7){yDb(g,16,2165536,(t=i,i=i+8|0,c[t>>2]=7,t)|0);i=t;u=-1094995529;i=h;return u|0}s=(d[q+(m>>>3)|0]|0)>>>((m&7)>>>0);r=((m|0)<(o|0))+m|0;c[l>>2]=r;c[f+4668>>2]=s&1;s=d[q+(r>>>3)|0]|0;m=((r|0)<(o|0))+r|0;c[l>>2]=m;if((s&1<<(r&7)|0)!=0){yDb(g,16,2158904,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}r=d[q+(m>>>3)|0]|0;s=((m|0)<(o|0))+m|0;c[l>>2]=s;if((r&1<<(m&7)|0)==0){w=0;x=s}else{m=q+(s>>>3)|0;r=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((s&7)>>>0)&16777215;m=s+24|0;s=o>>>0>m>>>0?m:o;c[l>>2]=s;w=r;x=s}c[f+4660>>2]=w;if(v>>>0>4>>>0){u=0;i=h;return u|0}v=d[q+(x>>>3)|0]|0;w=((x|0)<(o|0))+x|0;c[l>>2]=w;if((v&1<<(x&7)|0)==0){y=w}else{x=-w|0;v=o-w|0;if((x|0)>32){z=x}else{z=(v|0)<32?v:32}v=z+w|0;c[l>>2]=v;y=v}v=q+(y>>>3)|0;w=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((y&7)>>>0)&7;v=y+3|0;y=o>>>0>v>>>0?v:o;c[l>>2]=y;if((w|0)==7){v=q+(y>>>3)|0;z=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((y&7)>>>0);v=y+16|0;x=o>>>0>v>>>0?v:o;c[l>>2]=x;v=z&65535;b[j+2>>1]=v;z=q+(x>>>3)|0;s=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((x&7)>>>0);z=x+16|0;x=o>>>0>z>>>0?z:o;c[l>>2]=x;z=s&65535;b[j>>1]=z;A=x;B=v;C=z}else{z=w<<1;w=b[900800+((z|1)<<1)>>1]|0;b[j+2>>1]=w;v=b[900800+(z<<1)>>1]|0;b[j>>1]=v;A=y;B=w;C=v}v=d[q+(A>>>3)|0]|0;w=((A|0)<(o|0))+A|0;c[l>>2]=w;if((v&1<<(A&7)|0)==0){b[j+10>>1]=B;b[j+8>>1]=C;D=w;E=C;F=B}else{A=q+(w>>>3)|0;v=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((w&7)>>>0)&15;A=w+4|0;w=o>>>0>A>>>0?A:o;c[l>>2]=w;if((v|0)==15){G=B}else{G=(v<<5)+32&65535}b[j+10>>1]=G;v=q+(w>>>3)|0;A=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((w&7)>>>0)&15;v=w+4|0;w=o>>>0>v>>>0?v:o;c[l>>2]=w;if((A|0)==15){H=C}else{H=(A<<5)+32&65535}b[j+8>>1]=H;D=w;E=H;F=G}G=q+(D>>>3)|0;H=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;G=D+2|0;w=o>>>0>G>>>0?G:o;c[l>>2]=w;if((H&3<<(D&7)|0)!=0){yDb(g,16,2151832,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}D=((B&65535)+3|0)>>>2&65535;b[j+6>>1]=D;H=((C&65535)+3|0)>>>2&65535;b[j+4>>1]=H;G=q+(w>>>3)|0;A=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((w&7)>>>0)&3;G=w+2|0;w=o>>>0>G>>>0?G:o;c[l>>2]=w;a:do{if((A|0)==2){G=0;v=w;while(1){if((G|0)>=4){I=4;J=v;K=30;break a}y=q+(v>>>3)|0;z=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((v&7)>>>0)&3;y=v+2|0;x=o>>>0>y>>>0?y:o;c[l>>2]=x;if((z|0)==3){G=G+1|0;v=x}else{K=29;break}}}else if((A|0)==3){I=1;J=w;K=30}else{K=29}}while(0);do{if((K|0)==29){a[j+12|0]=0;a[j+13|0]=0;c[f+4664>>2]=1;L=0;M=0}else if((K|0)==30){w=j+12|0;a[w]=I;A=j+13|0;a[A]=0;v=q+(J>>>3)|0;G=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((J&7)>>>0)&3;v=J+2|0;x=o>>>0>v>>>0?v:o;c[l>>2]=x;b:do{if((G|0)==3){N=1;O=x}else if((G|0)==2){v=0;z=x;while(1){if((v|0)>=4){N=4;O=z;break b}y=q+(z>>>3)|0;s=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((z&7)>>>0)&3;y=z+2|0;r=o>>>0>y>>>0?y:o;c[l>>2]=r;if((s|0)==3){v=v+1|0;z=r}else{N=0;O=r;break}}}else{N=0;O=x}}while(0);a[A]=N;if(I<<24>>24==1){x=N<<24>>24!=1;G=f+4664|0;c[G>>2]=x&1;if(x){L=N;M=1;break}else{P=G;Q=1}}else{G=f+4664|0;c[G>>2]=1;if(!(I<<24>>24==4)){L=N;M=I;break}if(N<<24>>24==1){P=G;Q=4}else{L=N;M=4;break}}G=f+4692|0;do{if(C<<16>>16==(b[G>>1]|0)){if(!(B<<16>>16==(b[f+4694>>1]|0))){K=47;break}if(!(H<<16>>16==(b[f+4696>>1]|0))){K=47;break}if(!(D<<16>>16==(b[f+4698>>1]|0))){K=47;break}if(!(E<<16>>16==(b[f+4700>>1]|0))){K=47;break}if(!(F<<16>>16==(b[f+4702>>1]|0))){K=47;break}if(!(Q<<24>>24==(a[f+4704|0]|0))){K=47;break}if((a[f+4705|0]|0)==1){R=O;S=q;T=o}else{K=47}}else{K=47}}while(0);do{if((K|0)==47){x=f+4708|0;if((vIa(x,j)|0)!=0){yDb(g,16,2139184,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;a[f+4704|0]=0;u=-12;i=h;return u|0}z=G;v=j;b[z>>1]=b[v>>1]|0;b[z+2>>1]=b[v+2>>1]|0;b[z+4>>1]=b[v+4>>1]|0;b[z+6>>1]=b[v+6>>1]|0;b[z+8>>1]=b[v+8>>1]|0;b[z+10>>1]=b[v+10>>1]|0;b[z+12>>1]=b[v+12>>1]|0;if((a[w]|0)!=0){v=c[f+4716>>2]|0;z=0;do{c[v+(z*332|0)+56>>2]=(c[P>>2]|0)==0?16:8;c[v+(z*332|0)+60>>2]=8;z=z+1|0;}while((z|0)<(d[w]|0))}do{if((a[A]|0)!=0){z=c[f+4728>>2]|0;v=0;do{c[z+(v*332|0)+56>>2]=4;c[z+(v*332|0)+60>>2]=4;v=v+1|0;U=a[A]|0;}while((v|0)<(U&255|0));if(U<<24>>24==0){break}v=c[f+4740>>2]|0;z=0;do{c[v+(z*332|0)+56>>2]=4;c[v+(z*332|0)+60>>2]=4;z=z+1|0;}while((z|0)<(d[A]|0))}}while(0);if((xIa(x,e[f+4700>>1]|0,e[f+4702>>1]|0)|0)==0){R=c[l>>2]|0;S=c[p>>2]|0;T=c[n>>2]|0;break}yDb(g,16,2132904,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-12;i=h;return u|0}}while(0);A=d[S+(R>>>3)|0]|0;w=((R|0)<(T|0))+R|0;c[l>>2]=w;if((A&1<<(R&7)|0)==0){V=0;W=w}else{A=S+(w>>>3)|0;G=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((w&7)>>>0)&1048575;A=w+20|0;w=T>>>0>A>>>0?A:T;c[l>>2]=w;V=G;W=w}c[f+4648>>2]=V;w=((W|0)<(T|0))+W|0;if((d[S+(W>>>3)|0]&1<<(W&7)|0)==0){X=w}else{G=w+8|0;X=T>>>0>G>>>0?G:T}c[l>>2]=X;G=(d[S+(X>>>3)|0]|0)>>>((X&7)>>>0);c[l>>2]=((X|0)<(T|0))+X;if((uIa(k,G&1,0,f+4760|0,g)|0)!=0){u=-1094995529;i=h;return u|0}G=c[l>>2]|0;w=(d[(c[p>>2]|0)+(G>>>3)|0]|0)>>>((G&7)>>>0);c[l>>2]=((G|0)<(c[n>>2]|0))+G;if((uIa(k,w&1,1,f+4808|0,g)|0)!=0){u=-1094995529;i=h;return u|0}w=c[l>>2]|0;G=c[p>>2]|0;A=d[G+(w>>>3)|0]|0;z=c[n>>2]|0;v=((w|0)<(z|0))+w|0;c[l>>2]=v;if((A&1<<(w&7)|0)==0){Y=8;Z=v}else{w=G+(v>>>3)|0;A=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((v&7)>>>0);w=v+3|0;v=z>>>0>w>>>0?w:z;c[l>>2]=v;Y=A&7;Z=v}a[f+4856|0]=Y;v=(d[G+(Z>>>3)|0]|0)>>>((Z&7)>>>0);A=((Z|0)<(z|0))+Z|0;c[l>>2]=A;a[f+4857|0]=v&1;v=(d[G+(A>>>3)|0]|0)>>>((A&7)>>>0);w=((A|0)<(z|0))+A|0;c[l>>2]=w;a[f+4858|0]=v&1;v=G+(w>>>3)|0;A=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((w&7)>>>0);v=w+5|0;w=z>>>0>v>>>0?v:z;c[l>>2]=w;a[f+4859|0]=A&31;A=d[G+(w>>>3)|0]|0;v=((w|0)<(z|0))+w|0;c[l>>2]=v;if((A&1<<(w&7)|0)==0){_=0;$=v}else{w=G+(v>>>3)|0;A=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((v&7)>>>0);w=v+3|0;v=z>>>0>w>>>0?w:z;c[l>>2]=v;_=A&7;$=v}a[f+4860|0]=_;v=d[G+($>>>3)|0]|0;A=(($|0)<(z|0))+$|0;c[l>>2]=A;if((v&1<<($&7)|0)==0){aa=0;ba=A}else{v=G+(A>>>3)|0;w=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((A&7)>>>0);v=A+16|0;A=z>>>0>v>>>0?v:z;c[l>>2]=A;aa=w&65535;ba=A}b[f+4690>>1]=aa;A=d[G+(ba>>>3)|0]|0;w=((ba|0)<(z|0))+ba|0;c[l>>2]=w;if((A&1<<(ba&7)|0)==0){ca=w}else{A=w;while(1){w=A+8|0;v=z>>>0>w>>>0?w:z;c[l>>2]=v;w=d[G+(v>>>3)|0]|0;r=((v|0)<(z|0))+v|0;c[l>>2]=r;if((w&1<<(v&7)|0)==0){ca=r;break}else{A=r}}}A=d[G+(ca>>>3)|0]|0;r=((ca|0)<(z|0))+ca|0;c[l>>2]=r;if((A&1<<(ca&7)|0)==0){da=r}else{yDb(g,16,2126504,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;da=c[l>>2]|0}r=-da&7;if((r|0)==0){u=0;i=h;return u|0}A=c[n>>2]|0;v=r+da|0;c[l>>2]=A>>>0>v>>>0?v:A;u=0;i=h;return u|0}}while(0);yDb(g,16,2144768,(t=i,i=i+16|0,c[t>>2]=M&255,c[t+8>>2]=L&255,t)|0);i=t;u=-1094995529;i=h;return u|0}function tHa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;h=b|0;j=b+8|0;k=c[j>>2]|0;l=b+16|0;m=c[l>>2]|0;n=b|0;o=c[n>>2]|0;p=o+(k>>>3)|0;q=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((k&7)>>>0)&3;p=k+2|0;k=m>>>0>p>>>0?p:m;c[j>>2]=k;p=o+(k>>>3)|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;s=m>>>0>p>>>0?p:m;c[j>>2]=s;do{if((c[e>>2]|0)==(q|0)){if((c[e+4>>2]|0)!=(r>>>((k&7)>>>0)&15|0)){break}p=(d[o+(s>>>3)|0]|0)>>>((s&7)>>>0);c[j>>2]=((s|0)<(m|0))+s;t=p&1;c[e+52>>2]=t;p=e+60|0;a:do{if((t|0)==0){u=c[p>>2]|0;v=c[j>>2]|0;w=c[l>>2]|0;x=((v|0)<(w|0))+v|0;if(((d[o+(v>>>3)|0]|0)&1<<(v&7)|0)==0){y=x}else{v=x+16|0;y=w>>>0>v>>>0?v:w}c[j>>2]=y;v=o+(y>>>3)|0;x=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((y&7)>>>0)&3;v=y+2|0;c[j>>2]=w>>>0>v>>>0?v:w;c[e+64>>2]=x;if(x>>>0>1>>>0){yDb(f,16,1939904,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z;A=-1094995529;i=g;return A|0}x=c[j>>2]|0;w=(d[o+(x>>>3)|0]|0)>>>((x&7)>>>0);c[j>>2]=((x|0)<(c[l>>2]|0))+x;x=w&1;c[e+308>>2]=x;if((x|0)!=0){x=c[j>>2]|0;w=c[l>>2]|0;v=o+(x>>>3)|0;B=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((x&7)>>>0)&65535;v=x+16|0;c[j>>2]=w>>>0>v>>>0?v:w;c[e+304>>2]=B}B=c[j>>2]|0;w=c[l>>2]|0;v=o+(B>>>3)|0;x=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((B&7)>>>0)&3;v=B+2|0;c[j>>2]=w>>>0>v>>>0?v:w;if((x|0)==3){yDb(f,16,1915712,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}c[e+56>>2]=16>>>(x>>>0);c[p>>2]=8>>>(x>>>1>>>0);x=c[j>>2]|0;w=(d[o+(x>>>3)|0]|0)>>>((x&7)>>>0);c[j>>2]=((x|0)<(c[l>>2]|0))+x;c[e+68>>2]=w&1;w=c[j>>2]|0;x=(d[o+(w>>>3)|0]|0)>>>((w&7)>>>0);c[j>>2]=((w|0)<(c[l>>2]|0))+w;c[e+72>>2]=x&1;x=c[j>>2]|0;w=c[l>>2]|0;v=o+(x>>>3)|0;B=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((x&7)>>>0)&31;v=x+5|0;c[j>>2]=w>>>0>v>>>0?v:w;c[e+84>>2]=B;B=c[j>>2]|0;w=d[o+(B>>>3)|0]|0;v=c[l>>2]|0;x=((B|0)<(v|0))+B|0;c[j>>2]=x;do{if((w&1<<(B&7)|0)==0){C=16}else{if((c[b+4652>>2]|0)==0){C=16;break}if((u|0)==(c[p>>2]|0)){D=o;E=c[e+80>>2]|0;break}yDb(f,16,2230912,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}}while(0);b:do{if((C|0)==16){u=o+(x>>>3)|0;B=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((x&7)>>>0)&31;u=x+5|0;c[j>>2]=v>>>0>u>>>0?u:v;do{if(!(B>>>0>17>>>0)){if((136064>>>(B>>>0)&1|0)!=0){break}if((B-7|0)>>>0<3>>>0|(B|0)==17){DDb(f,2352272,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1163346256;i=g;return A|0}u=B>>>0<10>>>0;w=c[p>>2]|0;if(u&(w|0)<8){yDb(f,16,2332112,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}c[e+288>>2]=c[184280+(B*12|0)>>2];c[e+296>>2]=c[184284+(B*12|0)>>2];c[e+300>>2]=c[184288+(B*12|0)>>2];F=u?8:4;c[e+292>>2]=F;if((w|0)!=(F|0)){yDb(f,16,2307784,(z=i,i=i+16|0,c[z>>2]=F,c[z+8>>2]=w,z)|0);i=z;A=-1094995529;i=g;return A|0}w=c[j>>2]|0;F=c[l>>2]|0;u=(c[n>>2]|0)+(w>>>3)|0;G=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((w&7)>>>0)&15;u=w+4|0;c[j>>2]=F>>>0>u>>>0?u:F;if((G|0)==15){yDb(f,16,2289296,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}F=c[p>>2]|0;do{if((G-5|0)>>>0<5>>>0){if((F|0)==4){break}yDb(f,16,2273240,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}else{if((F|0)==8){break}yDb(f,16,2273240,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}}while(0);c[e+88>>2]=c[473080+(G<<2)>>2];c[e+92>>2]=F;u=c[j>>2]|0;w=c[l>>2]|0;H=c[n>>2]|0;I=H+(u>>>3)|0;J=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((u&7)>>>0)&31;I=u+5|0;c[j>>2]=w>>>0>I>>>0?I:w;if((J|0)==31){yDb(f,16,2257640,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}if(!(J>>>0>21>>>0)){c[e+80>>2]=J;D=H;E=J;break b}DDb(f,2243408,(z=i,i=i+8|0,c[z>>2]=J,z)|0);i=z;A=-1094995529;i=g;return A|0}}while(0);DDb(f,1895176,(z=i,i=i+8|0,c[z>>2]=B,z)|0);i=z;A=-1163346256;i=g;return A|0}}while(0);v=e+80|0;x=c[p>>2]|0;if((29184>>>(E>>>0)&1|0)!=0&(x|0)==4){yDb(f,16,2218824,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;c[v>>2]=0;A=-1094995529;i=g;return A|0}if((c[e+92>>2]|0)!=(x|0)){yDb(f,16,2273240,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}if((c[e+292>>2]|0)==8&(x|0)<8){yDb(f,16,2209464,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}x=c[j>>2]|0;J=d[D+(x>>>3)|0]|0;H=c[l>>2]|0;w=((x|0)<(H|0))+x|0;c[j>>2]=w;do{if((J&1<<(x&7)|0)==0){c[e+100>>2]=c[b+4812>>2];K=w;L=H}else{if((uIa(h,1,1,e+96|0,f)|0)==0){K=c[j>>2]|0;L=c[l>>2]|0;break}else{A=-1094995529;i=g;return A|0}}}while(0);H=c[n>>2]|0;w=d[H+(K>>>3)|0]|0;x=((K|0)<(L|0))+K|0;c[j>>2]=x;if((w&1<<(K&7)|0)==0){M=8}else{w=H+(x>>>3)|0;J=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((x&7)>>>0)&7;w=x+3|0;c[j>>2]=L>>>0>w>>>0?w:L;M=J}c[e+272>>2]=M;J=e+144|0;c[J>>2]=0;w=c[j>>2]|0;x=d[H+(w>>>3)|0]|0;I=c[l>>2]|0;u=((w|0)<(I|0))+w|0;c[j>>2]=u;if((x&1<<(w&7)|0)==0){N=v;break}w=H+(u>>>3)|0;x=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((u&7)>>>0)&255;w=u+8|0;c[j>>2]=I>>>0>w>>>0?w:I;c[J>>2]=x;if(x>>>0>61>>>0){yDb(f,16,2200856,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z;A=-1094995529;i=g;return A|0}if((x|0)==0){N=v;break}else{O=0;P=H}while(1){H=c[j>>2]|0;x=c[l>>2]|0;I=P+(H>>>3)|0;w=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((H&7)>>>0);I=H+8|0;c[j>>2]=x>>>0>I>>>0?I:x;a[e+148+O|0]=w;w=O+1|0;if((w|0)>=(c[J>>2]<<1|0)){N=v;break a}O=w;P=c[n>>2]|0}}else{N=e+80|0}}while(0);t=d[552976+(c[N>>2]|0)|0]|0;if((c[p>>2]|0)==8){c[e+316>>2]=898160+(t<<7);c[e+320>>2]=899312+(t<<7)}else{c[e+316>>2]=900464+(t<<5);c[e+320>>2]=900624+(t<<5)}c[e+324>>2]=0;c[e+328>>2]=0;t=c[j>>2]|0;v=-t&7;if((v|0)!=0){J=c[l>>2]|0;w=v+t|0;c[j>>2]=J>>>0>w>>>0?w:J}if((c[e+88>>2]|0)!=0){A=0;i=g;return A|0}yDb(f,16,2192408,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}}while(0);yDb(f,16,1968360,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}function uHa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0;j=i;k=f+56|0;l=c[k>>2]|0;m=f+48|0;n=c[m>>2]|0;o=ba(n,l)|0;p=g+4|0;q=c[p>>2]|0;r=g|0;s=(l|0)!=(c[f+60>>2]|0)?4:1;t=e+4652|0;u=(c[t>>2]|0)==3?2:1;v=c[(c[e+4716>>2]|0)+56>>2]>>3;w=l>>3;x=v-w|0;y=g+8|0;z=c[y>>2]|0;A=l-1|0;B=g+12|0;C=c[B>>2]|0;D=ba((A+C|0)/(l|0)|0,(A+z|0)/(l|0)|0)|0;A=c[g+28>>2]|0;if((D|0)!=(A|0)){yDb(h,16,2186864,(E=i,i=i+32|0,c[E>>2]=z,c[E+8>>2]=C,c[E+16>>2]=l,c[E+24>>2]=A,E)|0);i=E;F=-1;i=j;return F|0}a:do{if((C|0)>0){A=ba(q,n)|0;D=c[r>>2]|0;G=e+8|0;H=e|0;I=e+16|0;J=f+68|0;K=32-u|0;L=32-s|0;M=f+72|0;N=f|0;O=f+4|0;P=e+4858|0;Q=e+4764|0;R=(v|0)==(w|0);S=x-1|0;T=f+64|0;U=f+312|0;V=D+A|0;A=0;W=0;X=q;Y=c[g+32>>2]|0;Z=c[g+36>>2]|0;_=z;$=l;aa=q;ca=C;da=D;b:while(1){if((_|0)>0){D=X&65535;ea=X-1|0;fa=V;ga=A;ha=W;ia=da;ja=Y;ka=Z;while(1){b[ja>>1]=ia;b[ja+2>>1]=D;c[ja+4>>2]=fa;la=c[G>>2]|0;ma=c[H>>2]|0;na=d[ma+(la>>>3)|0]|0;oa=c[I>>2]|0;pa=((la|0)<(oa|0))+la|0;c[G>>2]=pa;do{if((na&1<<(la&7)|0)==0){do{if((c[J>>2]|0)==0){if((c[t>>2]|0)>>>0<2>>>0){a[ja+8|0]=0;break}else{qa=ma+(pa>>>3)|0;ra=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((pa&7)>>>0)<<K>>>(K>>>0);qa=pa+u|0;c[G>>2]=oa>>>0>qa>>>0?qa:oa;a[ja+8|0]=ra;break}}else{if((ka|0)==0){sa=21;break b}a[ja+8|0]=a[ka+8|0]|0}}while(0);ra=c[G>>2]|0;qa=c[I>>2]|0;ta=(c[H>>2]|0)+(ra>>>3)|0;ua=(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)>>>((ra&7)>>>0)<<L>>>(L>>>0);ta=ra+s|0;c[G>>2]=qa>>>0>ta>>>0?ta:qa;qa=ua&255;a[ja+9|0]=qa;ua=ja+10|0;a[ua]=0;do{if((c[M>>2]|0)==0){if(qa<<24>>24==0){if((c[N>>2]|0)!=0){break}if((c[O>>2]|0)!=0){break}if((a[P]|0)==0){break}}ta=c[(c[Q>>2]|0)+4>>2]|0;ra=c[G>>2]|0;va=c[I>>2]|0;wa=(c[H>>2]|0)+(ra>>>3)|0;xa=(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)>>>((ra&7)>>>0)&8191;wa=b[ta+(xa<<2)>>1]|0;ya=(b[ta+(xa<<2)+2>>1]|0)+ra|0;c[G>>2]=va>>>0>ya>>>0?ya:va;a[ua]=-(wa<<24>>25^-(wa&1))}else{if((ka|0)==0){break}a[ua]=a[ka+10|0]|0}}while(0);if((a[ja+8|0]|0)==0){a[ja+12|0]=0;a[ja+11|0]=0;za=ha;Aa=ga;break}if((c[J>>2]|0)==0){ua=c[(c[Q>>2]|0)+4>>2]|0;qa=c[G>>2]|0;wa=c[I>>2]|0;va=c[H>>2]|0;ya=va+(qa>>>3)|0;ra=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((qa&7)>>>0)&8191;ya=b[ua+(ra<<2)>>1]|0;xa=(b[ua+(ra<<2)+2>>1]|0)+qa|0;qa=wa>>>0>xa>>>0?xa:wa;c[G>>2]=qa;xa=ga-(ya>>1^-(ya&1))|0;ya=va+(qa>>>3)|0;va=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((qa&7)>>>0)&8191;ya=b[ua+(va<<2)>>1]|0;ra=(b[ua+(va<<2)+2>>1]|0)+qa|0;c[G>>2]=wa>>>0>ra>>>0?ra:wa;wa=ha-(ya>>1^-(ya&1))|0;a[ja+11|0]=wa;a[ja+12|0]=xa;za=wa;Aa=xa;break}if((ka|0)==0){za=ha;Aa=ga;break}xa=a[ka+11|0]|0;if(R){a[ja+11|0]=xa;a[ja+12|0]=a[ka+12|0]|0;za=ha;Aa=ga;break}else{a[ja+11|0]=S+(xa<<24>>24)+(xa<<24>>24>0)>>x;xa=a[ka+12|0]|0;a[ja+12|0]=S+(xa<<24>>24)+(xa<<24>>24>0)>>x;za=ha;Aa=ga;break}}else{if((c[t>>2]|0)==0){sa=10;break b}a[ja+8|0]=1;a[ja+9|0]=0;xa=ja+10|0;a[xa]=0;do{if((c[N>>2]|0)==0){if((c[O>>2]|0)!=0){break}if((a[P]|0)==0){break}wa=c[(c[Q>>2]|0)+4>>2]|0;ya=c[G>>2]|0;ra=c[I>>2]|0;qa=(c[H>>2]|0)+(ya>>>3)|0;va=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((ya&7)>>>0)&8191;qa=b[wa+(va<<2)>>1]|0;ua=(b[wa+(va<<2)+2>>1]|0)+ya|0;c[G>>2]=ra>>>0>ua>>>0?ua:ra;a[xa]=-(qa<<24>>25^-(qa&1))}}while(0);xa=ja+12|0;a[xa]=0;qa=ja+11|0;a[qa]=0;if((c[J>>2]|0)==0|(ka|0)==0){za=ha;Aa=ga;break}ra=a[ka+11|0]|0;if(R){a[qa]=ra;a[xa]=a[ka+12|0]|0;za=ha;Aa=ga;break}else{a[qa]=S+(ra<<24>>24)+(ra<<24>>24>0)>>x;ra=a[ka+12|0]|0;a[xa]=S+(ra<<24>>24)+(ra<<24>>24>0)>>x;za=ha;Aa=ga;break}}}while(0);Ba=c[T>>2]|0;if((a[ja+8|0]|0)==0){Ca=c[k>>2]|0}else{Da=a[ja+11|0]|0;Ea=a[ja+12|0]|0;oa=c[m>>2]|0;if(((Da>>Ba)+ia+(ba((Ea>>Ba)+X|0,oa)|0)|0)<0){sa=46;break b}pa=c[k>>2]|0;ma=ia-1+(Da+Ba>>Ba)+pa+(ba(ea+(Ea+Ba>>Ba)+pa|0,oa)|0)|0;if((ma|0)>((c[U>>2]|0)-1|0)){sa=46;break b}else{Ca=pa}}Fa=ja+16|0;Ga=(ka|0)==0?0:ka+16|0;pa=Ca+ia|0;Ha=c[r>>2]|0;Ia=c[y>>2]|0;if((pa|0)<(Ia+Ha|0)){fa=Ca+fa|0;ga=Aa;ha=za;ia=pa;ja=Fa;ka=Ga}else{break}}Ja=Aa;Ka=za;La=Fa;Ma=Ga;Na=Ia;Oa=Ca;Pa=c[p>>2]|0;Qa=c[B>>2]|0;Ra=Ha}else{Ja=A;Ka=W;La=Y;Ma=Z;Na=_;Oa=$;Pa=aa;Qa=ca;Ra=da}ka=Oa+X|0;if((ka|0)<(Qa+Pa|0)){V=V+o|0;A=Ja;W=Ka;X=ka;Y=La;Z=Ma;_=Na;$=Oa;aa=Pa;ca=Qa;da=Ra}else{Sa=G;break a}}if((sa|0)==10){yDb(h,16,2109736,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1094995529;i=j;return F|0}else if((sa|0)==21){yDb(h,16,2051584,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1094995529;i=j;return F|0}else if((sa|0)==46){G=Da+(ba(Ba,ia)|0)|0;da=Ea+(ba(Ba,X)|0)|0;yDb(h,16,2006144,(E=i,i=i+16|0,c[E>>2]=G,c[E+8>>2]=da,E)|0);i=E;F=-1094995529;i=j;return F|0}}else{Sa=e+8|0}}while(0);E=c[Sa>>2]|0;h=-E&7;if((h|0)==0){F=0;i=j;return F|0}Ba=c[e+16>>2]|0;e=h+E|0;c[Sa>>2]=Ba>>>0>e>>>0?e:Ba;F=0;i=j;return F|0}function vHa(a){a=a|0;var b=0,d=0,e=0,f=0;if((c[a+4656>>2]|0)>>>0<3>>>0){b=a+4744|0;d=c[b>>2]|0;e=d^1;c[b>>2]=e;c[a+4748>>2]=e;c[a+4752>>2]=d}d=c[a+4652>>2]|0;if((d|0)==0|(d|0)==1){c[a+4744>>2]=0;f=0}else if((d|0)==2){f=c[a+4744>>2]|0}else{return}c[a+4748>>2]=f;c[a+4752>>2]=f^1;return}function wHa(a){a=a|0;return(c[a+4652>>2]|0)<5|0}function xHa(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=c[d+60>>2]|0;sIa();UGb(f+20|0,1194080,4626)|0;g=c[d+120>>2]|0;h=g&65535;j=f+4692|0;b[j>>1]=h;k=c[d+124>>2]|0;l=k&65535;b[f+4694>>1]=l;b[f+4696>>1]=(g+3|0)>>>2;b[f+4698>>1]=(k+3|0)>>>2;b[f+4700>>1]=h;b[f+4702>>1]=l;a[f+4705|0]=1;a[f+4704|0]=1;if((vIa(f+4708|0,j)|0)==0){c[f+4744>>2]=0;c[f+4676>>2]=0;c[f+4872>>2]=786;c[f+4876>>2]=262;c[f+4880>>2]=276;c[f+4884>>2]=188;c[f+4888>>2]=120;c[d+140>>2]=6;m=0;i=e;return m|0}else{yDb(d,16,2186792,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;m=-1094995529;i=e;return m|0}return 0}function yHa(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;h=i;i=i+16|0;j=h|0;k=f|0;l=f+8|0;m=c[l>>2]|0;n=f+16|0;o=c[n>>2]|0;p=f|0;q=c[p>>2]|0;r=q+(m>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&31;r=m+5|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;if((s|0)!=31){yDb(g,16,1939872,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}s=f+4652|0;c[f+4656>>2]=c[s>>2];r=q+(m>>>3)|0;v=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&7;r=m+3|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;c[s>>2]=v;if(v>>>0>4>>>0){yDb(g,16,1915672,(t=i,i=i+8|0,c[t>>2]=v,t)|0);i=t;u=-1094995529;i=h;return u|0}r=q+(m>>>3)|0;w=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&255;r=m+8|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;c[f+4648>>2]=w;a:do{if((v|0)==0){w=j;r=q+(m>>>3)|0;x=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0);r=m+8|0;y=o>>>0>r>>>0?r:o;c[l>>2]=y;r=x&255;z=f+4864|0;a[z]=r;if((x&1|0)==0){A=0;B=y}else{x=q+(y>>>3)|0;C=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((y&7)>>>0);x=y+16|0;y=o>>>0>x>>>0?x:o;c[l>>2]=y;A=C&65535;B=y}b[f+4862>>1]=A;if((r&32)==0){D=B}else{y=q+(B>>>3)|0;C=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((B&7)>>>0)&65535;y=B+16|0;x=o>>>0>y>>>0?y:o;c[l>>2]=x;y=q+(x>>>3)|0;E=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((x&7)>>>0);y=x+16|0;x=o>>>0>y>>>0?y:o;c[l>>2]=x;c[f+4868>>2]=E<<16|C;D=x}do{if((r&64)==0){F=0;G=D;H=13}else{x=q+(D>>>3)|0;C=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((D&7)>>>0)&3;x=D+2|0;E=o>>>0>x>>>0?x:o;c[l>>2]=E;x=64<<C;if((x|0)<=256){F=x;G=E;H=13;break}yDb(g,16,2332088,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;I=-1094995529}}while(0);b:do{if((H|0)==13){x=q+(G>>>3)|0;E=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((G&7)>>>0)&3;x=G+2|0;C=o>>>0>x>>>0?x:o;c[l>>2]=C;x=(E*3|0)+1|0;E=x&255;y=j+12|0;a[y]=E;J=(d[q+(C>>>3)|0]|0)>>>((C&7)>>>0);K=((C|0)<(o|0))+C|0;c[l>>2]=K;C=(-(J&1)&3)+1|0;J=C&255;L=j+13|0;a[L]=J;if((E<<24>>24|0)==1){M=(C&255|0)!=1;if(M){H=16}else{N=M&1}}else if((E<<24>>24|0)==4){if(J<<24>>24==1){N=1}else{H=16}}else{H=16}if((H|0)==16){yDb(g,16,2307712,(t=i,i=i+16|0,c[t>>2]=x&255,c[t+8>>2]=C&255,t)|0);i=t;I=-1094995529;break}C=q+(K>>>3)|0;x=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((K&7)>>>0)&15;C=K+4|0;K=o>>>0>C>>>0?C:o;c[l>>2]=K;if((x|0)==15){C=q+(K>>>3)|0;M=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((K&7)>>>0);C=K+13|0;K=o>>>0>C>>>0?C:o;c[l>>2]=K;C=M&8191;b[j+2>>1]=C;M=q+(K>>>3)|0;O=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((K&7)>>>0);M=K+13|0;c[l>>2]=o>>>0>M>>>0?M:o;M=O&8191;b[j>>1]=M;P=C;Q=M}else{M=x<<1;x=d[896768+(M|1)|0]<<2;b[j+2>>1]=x;C=d[896768+M|0]<<2;b[j>>1]=C;P=x;Q=C}if(!((r&2)==0)){EDb(g,2289272,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1163346256;break}C=((P&65535)+3|0)>>>2&65535;b[j+6>>1]=C;x=((Q&65535)+3|0)>>>2&65535;b[j+4>>1]=x;if((F|0)==0){b[j+10>>1]=P;b[j+8>>1]=Q;R=Q;S=P}else{M=F&65535;b[j+8>>1]=M;b[j+10>>1]=M;R=M;S=M}M=f+4692|0;do{if(Q<<16>>16==(b[M>>1]|0)){if(!(P<<16>>16==(b[f+4694>>1]|0))){H=34;break}if(!(x<<16>>16==(b[f+4696>>1]|0))){H=34;break}if(!(C<<16>>16==(b[f+4698>>1]|0))){H=34;break}if(!(R<<16>>16==(b[f+4700>>1]|0))){H=34;break}if(!(S<<16>>16==(b[f+4702>>1]|0))){H=34;break}if(!(E<<24>>24==(a[f+4704|0]|0))){H=34;break}if(!(J<<24>>24==(a[f+4705|0]|0))){H=34;break}if((c[f+4892>>2]|0)==0){T=0;U=0}else{H=34}}else{H=34}}while(0);do{if((H|0)==34){J=vIa(f+4708|0,j)|0;if((J|0)<0){yDb(g,16,2273200,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=J;break b}else{J=M;b[J>>1]=b[w>>1]|0;b[J+2>>1]=b[w+2>>1]|0;b[J+4>>1]=b[w+4>>1]|0;b[J+6>>1]=b[w+6>>1]|0;b[J+8>>1]=b[w+8>>1]|0;b[J+10>>1]=b[w+10>>1]|0;b[J+12>>1]=b[w+12>>1]|0;c[f+4664>>2]=N;T=0;U=1;break}}}while(0);c:while(1){M=(T|0)!=0;J=f+4708+(T*12|0)+8|0;E=(T|0)==0;C=T<<2;x=0;V=U;while(1){W=a[L]|0;if((x|0)>=((M?W:a[y]|0)&255|0)){break}O=c[J>>2]|0;K=c[l>>2]|0;X=c[p>>2]|0;Y=(d[X+(K>>>3)|0]|0)>>>((K&7)>>>0);c[l>>2]=((K|0)<(c[n>>2]|0))+K;c[O+(x*332|0)+64>>2]=Y&1;Y=c[l>>2]|0;K=d[X+(Y>>>3)|0]|0;Z=c[n>>2]|0;_=((Y|0)<(Z|0))+Y|0;c[l>>2]=_;$=(d[X+(_>>>3)|0]|0)>>>((_&7)>>>0);aa=((_|0)<(Z|0))+_|0;c[l>>2]=aa;_=8>>>(($&1)>>>0);$=_<<((K&1<<(Y&7)|0)==0);if(E&(_|0)==4){H=42;break c}Y=O+(x*332|0)+56|0;K=O+(x*332|0)+60|0;if(($|0)==(c[Y>>2]|0)){ba=(_|0)!=(c[K>>2]|0);ca=ba&1;if(ba){da=ca;H=45}else{ea=ca;fa=aa;ga=Z}}else{da=1;H=45}if((H|0)==45){H=0;c[Y>>2]=$;c[K>>2]=_;ea=da;fa=c[l>>2]|0;ga=c[n>>2]|0}_=d[X+(fa>>>3)|0]|0;c[l>>2]=((fa|0)<(ga|0))+fa;if((_&1<<(fa&7)|0)!=0){H=47;break c}switch(x+C|0){case 4:{c[O+(x*332|0)+288>>2]=714;c[O+(x*332|0)+296>>2]=4;c[O+(x*332|0)+88>>2]=1198784;c[O+(x*332|0)+292>>2]=4;ha=714;H=55;break};case 2:{c[O+(x*332|0)+288>>2]=792;c[O+(x*332|0)+296>>2]=442;c[O+(x*332|0)+88>>2]=1198720;c[O+(x*332|0)+292>>2]=8;ha=792;H=55;break};case 1:{c[O+(x*332|0)+288>>2]=414;c[O+(x*332|0)+296>>2]=204;c[O+(x*332|0)+88>>2]=1194016;c[O+(x*332|0)+292>>2]=8;ha=414;H=55;break};case 3:{c[O+(x*332|0)+288>>2]=138;c[O+(x*332|0)+296>>2]=712;c[O+(x*332|0)+88>>2]=1198720;c[O+(x*332|0)+292>>2]=8;ha=138;H=55;break};case 0:{c[O+(x*332|0)+288>>2]=150;c[O+(x*332|0)+296>>2]=4;c[O+(x*332|0)+88>>2]=1075976;c[O+(x*332|0)+292>>2]=8;ia=1;break};default:{_=c[O+(x*332|0)+288>>2]|0;if((_|0)==150){ia=1}else{ha=_;H=55}}}if((H|0)==55){H=0;ia=(ha|0)==714|0}c[O+(x*332|0)+300>>2]=ia;ja=c[O+(x*332|0)+292>>2]|0;ka=c[K>>2]|0;if((ja|0)!=(ka|0)){H=57;break c}if(M){la=5}else{la=(d[y]|0)>>>0>1>>>0?x+1|0:0}if((ja|0)==8){if((la|0)>4){H=62;break c}c[O+(x*332|0)+316>>2]=896800+(la<<7);c[O+(x*332|0)+320>>2]=897440+(la<<7);c[O+(x*332|0)+324>>2]=896480+(la*24|0);c[O+(x*332|0)+328>>2]=896600+(la*24|0)}else{c[O+(x*332|0)+316>>2]=898080;c[O+(x*332|0)+320>>2]=898112;c[O+(x*332|0)+324>>2]=896720;c[O+(x*332|0)+328>>2]=896744}O=c[l>>2]|0;K=c[n>>2]|0;_=(c[p>>2]|0)+(O>>>3)|0;X=d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0;_=O+2|0;c[l>>2]=K>>>0>_>>>0?_:K;if((X&3<<(O&7)|0)!=0){H=67;break c}x=x+1|0;V=ea}x=T+1|0;if((x|0)<2){T=x;U=V}else{H=38;break}}if((H|0)==38){if(!(W<<24>>24==0)){y=f+4728|0;x=f+4740|0;M=0;do{C=c[y>>2]|0;E=c[x>>2]|0;c[E+(M*332|0)+8>>2]=c[C+(M*332|0)+8>>2];c[E+(M*332|0)+12>>2]=c[C+(M*332|0)+12>>2];c[E+(M*332|0)+56>>2]=c[C+(M*332|0)+56>>2];c[E+(M*332|0)+60>>2]=c[C+(M*332|0)+60>>2];c[E+(M*332|0)+64>>2]=c[C+(M*332|0)+64>>2];c[E+(M*332|0)+316>>2]=c[C+(M*332|0)+316>>2];c[E+(M*332|0)+320>>2]=c[C+(M*332|0)+320>>2];c[E+(M*332|0)+324>>2]=c[C+(M*332|0)+324>>2];c[E+(M*332|0)+328>>2]=c[C+(M*332|0)+328>>2];c[E+(M*332|0)+88>>2]=c[C+(M*332|0)+88>>2];c[E+(M*332|0)+288>>2]=c[C+(M*332|0)+288>>2];c[E+(M*332|0)+296>>2]=c[C+(M*332|0)+296>>2];c[E+(M*332|0)+300>>2]=c[C+(M*332|0)+300>>2];c[E+(M*332|0)+292>>2]=c[C+(M*332|0)+292>>2];M=M+1|0;}while((M|0)<(d[L]|0))}do{if((V|0)!=0){L=xIa(f+4708|0,e[j+8>>1]|0,e[j+10>>1]|0)|0;if((L|0)>=0){break}yDb(g,16,2200808,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=L;break b}}while(0);L=c[l>>2]|0;M=c[n>>2]|0;do{if((a[z]&8)==0){ma=L}else{x=c[p>>2]|0;y=x+(L>>>3)|0;C=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=L+3|0;E=M>>>0>y>>>0?y:M;c[l>>2]=E;if((C&7<<(L&7)|0)!=0){yDb(g,16,2192376,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1094995529;break b}C=d[x+(E>>>3)|0]|0;x=((E|0)<(M|0))+E|0;c[l>>2]=x;if((C&1<<(E&7)|0)==0){ma=x;break}E=-x|0;C=M-x|0;if((E|0)>24){na=E}else{na=(C|0)<24?C:24}C=na+x|0;c[l>>2]=C;ma=C}}while(0);L=-ma&7;if((L|0)==0){oa=ma}else{C=L+ma|0;L=M>>>0>C>>>0?C:M;c[l>>2]=L;oa=L}L=oa+23|0;C=M>>>0>L>>>0?L:M;c[l>>2]=C;L=c[p>>2]|0;x=d[L+(C>>>3)|0]|0;E=((C|0)<(M|0))+C|0;c[l>>2]=E;if((1<<(C&7)&x|0)==0){pa=E}else{x=E;while(1){E=L+(x>>>3)|0;C=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=x+16|0;y=M>>>0>E>>>0?E:M;c[l>>2]=y;if((32768<<(x&7)&C|0)==0){pa=y;break}else{x=y}}}x=-pa&7;if((x|0)==0){qa=pa}else{y=x+pa|0;x=M>>>0>y>>>0?y:M;c[l>>2]=x;qa=x}c[f+4892>>2]=0;ra=c[s>>2]|0;sa=qa;ta=M;ua=L;break a}else if((H|0)==42){yDb(g,16,2257600,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1163346256;break}else if((H|0)==47){EDb(g,2243384,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1163346256;break}else if((H|0)==57){yDb(g,16,2230824,(t=i,i=i+16|0,c[t>>2]=ja,c[t+8>>2]=ka,t)|0);i=t;I=-1094995529;break}else if((H|0)==62){yDb(g,16,2218792,(t=i,i=i+8|0,c[t>>2]=la,t)|0);i=t;I=-1;break}else if((H|0)==67){yDb(g,16,2209440,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1094995529;break}}}while(0);yDb(g,16,1895128,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;c[f+4892>>2]=1;u=I;i=h;return u|0}else{ra=v;sa=m;ta=o;ua=q}}while(0);do{if((ra|0)==2){if((c[f+4664>>2]|0)!=0){H=91;break}yDb(g,16,2352224,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;c[s>>2]=1;u=-1094995529;i=h;return u|0}else if((ra|0)==4){va=sa;wa=ta}else{H=91}}while(0);do{if((H|0)==91){ra=ua+(sa>>>3)|0;s=(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)>>>((sa&7)>>>0);ra=sa+8|0;t=ta>>>0>ra>>>0?ra:ta;c[l>>2]=t;ra=s&255;a[f+4688|0]=ra;if((s&1|0)==0){xa=0;ya=t}else{q=ua+(t>>>3)|0;o=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((t&7)>>>0)&16777215;q=t+24|0;t=ta>>>0>q>>>0?q:ta;c[l>>2]=t;xa=o;ya=t}c[f+4684>>2]=xa;if((ra&16)==0){za=0;Aa=ya}else{t=ua+(ya>>>3)|0;o=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>((ya&7)>>>0);t=ya+16|0;q=ta>>>0>t>>>0?t:ta;c[l>>2]=q;za=o&65535;Aa=q}b[f+4690>>1]=za;d:do{if(!((ra&32)==0)){q=Aa;while(1){o=ua+(q>>>3)|0;t=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((q&7)>>>0)&255;o=q+8|0;m=ta>>>0>o>>>0?o:ta;c[l>>2]=m;if((t|0)==0){break d}else{Ba=0;Ca=m}do{m=Ca+8|0;Ca=ta>>>0>m>>>0?m:ta;Ba=Ba+1|0;}while((Ba|0)<(t|0));c[l>>2]=Ca;q=Ca}}}while(0);ra=uIa(k,s&64,0,f+4760|0,g)|0;if((ra|0)<0){u=ra;i=h;return u|0}else{ra=c[n>>2]|0;q=(c[l>>2]|0)+3|0;L=ra>>>0>q>>>0?q:ra;c[l>>2]=L;va=L;wa=ra;break}}}while(0);n=-va&7;if((n|0)==0){u=0;i=h;return u|0}g=n+va|0;c[l>>2]=wa>>>0>g>>>0?g:wa;u=0;i=h;return u|0}function zHa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;h=b|0;j=b+8|0;k=c[j>>2]|0;l=b+16|0;m=c[l>>2]|0;n=b|0;o=c[n>>2]|0;p=o+(k>>>3)|0;q=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((k&7)>>>0);p=k+8|0;k=m>>>0>p>>>0?p:m;c[j>>2]=k;if((q&1|0)!=0){c[e+52>>2]=1;r=0;i=g;return r|0}if((a[b+4688|0]|0)<0){b=o+(k>>>3)|0;p=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((k&7)>>>0)&16777215;b=k+24|0;c[j>>2]=m>>>0>b>>>0?b:m;s=p}else{s=0}c[e+24>>2]=s;c[e+68>>2]=q&2;s=e+72|0;c[s>>2]=q&8;p=q&4;c[e+76>>2]=p;if((p|0)==0){c[s>>2]=1}s=e+144|0;c[s>>2]=0;a:do{if((q&16|0)!=0){p=c[j>>2]|0;m=c[l>>2]|0;b=o+(p>>>3)|0;k=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((p&7)>>>0)&255;b=p+8|0;c[j>>2]=m>>>0>b>>>0?b:m;c[s>>2]=k;if(k>>>0>61>>>0){yDb(f,16,1968328,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;r=-1094995529;i=g;return r|0}if((k|0)==0){break}else{t=0;u=o}while(1){k=c[j>>2]|0;m=c[l>>2]|0;b=u+(k>>>3)|0;p=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((k&7)>>>0);b=k+8|0;c[j>>2]=m>>>0>b>>>0?b:m;a[e+148+t|0]=p;p=t+1|0;if((p|0)>=(c[s>>2]<<1|0)){break a}t=p;u=c[n>>2]|0}}}while(0);if((q&64|0)==0){v=8}else{u=c[j>>2]|0;t=c[l>>2]|0;s=(c[n>>2]|0)+(u>>>3)|0;o=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((u&7)>>>0)&7;s=u+3|0;c[j>>2]=t>>>0>s>>>0?s:t;v=o}c[e+272>>2]=v;v=uIa(h,q&128,1,e+96|0,f)|0;if((v|0)<0){r=v;i=g;return r|0}v=c[j>>2]|0;f=c[n>>2]|0;n=(d[f+(v>>>3)|0]|0)>>>((v&7)>>>0);c[j>>2]=((v|0)<(c[l>>2]|0))+v;v=n&1;c[e+308>>2]=v;if((v|0)!=0){v=c[j>>2]|0;n=c[l>>2]|0;h=f+(v>>>3)|0;o=(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>((v&7)>>>0)&65535;h=v+16|0;c[j>>2]=n>>>0>h>>>0?h:n;c[e+304>>2]=o}o=c[j>>2]|0;n=c[l>>2]|0;h=f+(o>>>3)|0;v=(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>((o&7)>>>0)&31;h=o+5|0;c[j>>2]=n>>>0>h>>>0?h:n;c[e+84>>2]=v;v=c[j>>2]|0;b:do{if((q&32|0)==0){w=v}else{e=-v&7;n=c[l>>2]|0;if((e|0)==0){x=v}else{h=e+v|0;e=n>>>0>h>>>0?h:n;c[j>>2]=e;x=e}while(1){e=f+(x>>>3)|0;h=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>((x&7)>>>0)&255;e=x+8|0;o=n>>>0>e>>>0?e:n;c[j>>2]=o;if((h|0)==0){w=o;break b}else{y=0;z=o}do{o=z+8|0;z=n>>>0>o>>>0?o:n;y=y+1|0;}while((y|0)<(h|0));c[j>>2]=z;x=z}}}while(0);z=-w&7;if((z|0)==0){r=0;i=g;return r|0}x=c[l>>2]|0;l=z+w|0;c[j>>2]=x>>>0>l>>>0?l:x;r=0;i=g;return r|0}function AHa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0;j=i;k=f+56|0;l=c[k>>2]|0;m=f+48|0;n=c[m>>2]|0;o=ba(n,l)|0;p=c[g+32>>2]|0;q=c[g+36>>2]|0;r=g+4|0;s=c[r>>2]|0;t=ba(s,n)|0;n=g|0;u=c[n>>2]|0;v=t+u|0;do{if((q|0)==0){do{if((c[f+76>>2]|0)!=0){if((c[f+72>>2]|0)==0){break}else{w=-1094995529}i=j;return w|0}}while(0);if((c[f+68>>2]|0)==0){break}else{w=-1094995529}i=j;return w|0}}while(0);t=c[g+28>>2]|0;x=g+8|0;y=c[x>>2]|0;z=g+12|0;g=c[z>>2]|0;A=ba((l-1+g|0)/(l|0)|0,(y-1+l|0)/(l|0)|0)|0;if((t|0)!=(A|0)){yDb(h,16,2109680,(B=i,i=i+16|0,c[B>>2]=t,c[B+8>>2]=A,B)|0);i=B;w=-1094995529;i=j;return w|0}A=c[(c[e+4716>>2]|0)+56>>2]>>3;t=l>>3;C=A-t|0;D=e+8|0;a:do{if((g|0)>0){E=e|0;F=e+16|0;G=f+68|0;H=e+4652|0;I=f+60|0;J=f+76|0;K=e+4764|0;L=(A|0)==(t|0);M=C-1|0;N=f+72|0;O=f|0;P=f+4|0;Q=e+4688|0;R=f+64|0;S=f+312|0;T=0;U=v;V=0;W=s;X=p;Y=q;Z=y;_=l;$=s;aa=g;ca=u;b:while(1){if((Z|0)>0){da=W&65535;ea=W-1|0;fa=T;ga=U;ha=V;ia=ca;ja=X;ka=Y;while(1){b[ja>>1]=ia;b[ja+2>>1]=da;c[ja+4>>2]=ga;la=c[D>>2]|0;ma=c[E>>2]|0;na=d[ma+(la>>>3)|0]|0;oa=c[F>>2]|0;pa=((la|0)<(oa|0))+la|0;c[D>>2]=pa;do{if((na&1<<(la&7)|0)==0){qa=(ka|0)==0;do{if((c[G>>2]|0)==0|qa){if((c[H>>2]|0)==0){a[ja+8|0]=0;break}else{ra=(d[ma+(pa>>>3)|0]|0)>>>((pa&7)>>>0);c[D>>2]=((pa|0)<(oa|0))+pa;a[ja+8|0]=ra&1;break}}else{a[ja+8|0]=a[ka+8|0]|0}}while(0);ra=(c[k>>2]|0)!=(c[I>>2]|0)?4:1;sa=c[D>>2]|0;ta=c[F>>2]|0;ua=(c[E>>2]|0)+(sa>>>3)|0;va=32-ra|0;wa=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((sa&7)>>>0)<<va>>>(va>>>0);va=ra+sa|0;c[D>>2]=ta>>>0>va>>>0?va:ta;ta=wa&255;a[ja+9|0]=ta;wa=ja+10|0;a[wa]=0;do{if((c[J>>2]|0)!=0){if((c[N>>2]|0)!=0){if(qa){break}a[wa]=a[ka+10|0]|0;break}if(ta<<24>>24==0){if((c[O>>2]|0)!=0){break}if((c[P>>2]|0)!=0){break}if((a[Q]&8)==0){break}}va=c[(c[K>>2]|0)+4>>2]|0;sa=c[D>>2]|0;ra=c[F>>2]|0;ua=(c[E>>2]|0)+(sa>>>3)|0;xa=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((sa&7)>>>0)&8191;ua=b[va+(xa<<2)>>1]|0;ya=(b[va+(xa<<2)+2>>1]|0)+sa|0;c[D>>2]=ra>>>0>ya>>>0?ya:ra;a[wa]=-(ua<<24>>25^-(ua&1))}}while(0);if((a[ja+8|0]|0)==0){a[ja+12|0]=0;a[ja+11|0]=0;za=ha;Aa=fa;Ba=0;Ca=0;break}if((c[G>>2]|0)==0|qa){wa=c[(c[K>>2]|0)+4>>2]|0;ta=c[D>>2]|0;ua=c[F>>2]|0;ra=c[E>>2]|0;ya=ra+(ta>>>3)|0;sa=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((ta&7)>>>0)&8191;ya=b[wa+(sa<<2)>>1]|0;xa=(b[wa+(sa<<2)+2>>1]|0)+ta|0;ta=ua>>>0>xa>>>0?xa:ua;c[D>>2]=ta;xa=fa-(ya>>1^-(ya&1))|0;ya=ra+(ta>>>3)|0;ra=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((ta&7)>>>0)&8191;ya=b[wa+(ra<<2)>>1]|0;sa=(b[wa+(ra<<2)+2>>1]|0)+ta|0;c[D>>2]=ua>>>0>sa>>>0?sa:ua;ua=ha-(ya>>1^-(ya&1))|0;ya=ua&255;a[ja+11|0]=ya;sa=xa&255;a[ja+12|0]=sa;za=ua;Aa=xa;Ba=ya;Ca=sa;break}sa=a[ka+11|0]|0;if(L){a[ja+11|0]=sa;ya=a[ka+12|0]|0;a[ja+12|0]=ya;za=ha;Aa=fa;Ba=sa;Ca=ya;break}else{ya=M+(sa<<24>>24)+(sa<<24>>24>0)>>C&255;a[ja+11|0]=ya;sa=a[ka+12|0]|0;xa=M+(sa<<24>>24)+(sa<<24>>24>0)>>C&255;a[ja+12|0]=xa;za=ha;Aa=fa;Ba=ya;Ca=xa;break}}else{if((c[H>>2]|0)==0){Da=13;break b}a[ja+8|0]=1;a[ja+9|0]=0;xa=ja+10|0;a[xa]=0;do{if((c[O>>2]|0)==0){if((c[P>>2]|0)!=0){break}if((a[Q]&8)==0){break}ya=c[(c[K>>2]|0)+4>>2]|0;sa=c[D>>2]|0;ua=c[F>>2]|0;ta=(c[E>>2]|0)+(sa>>>3)|0;ra=(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)>>>((sa&7)>>>0)&8191;ta=b[ya+(ra<<2)>>1]|0;wa=(b[ya+(ra<<2)+2>>1]|0)+sa|0;c[D>>2]=ua>>>0>wa>>>0?wa:ua;a[xa]=-(ta<<24>>25^-(ta&1))}}while(0);xa=ja+12|0;a[xa]=0;qa=ja+11|0;a[qa]=0;if((c[G>>2]|0)==0|(ka|0)==0){za=ha;Aa=fa;Ba=0;Ca=0;break}ta=a[ka+11|0]|0;if(L){a[qa]=ta;ua=a[ka+12|0]|0;a[xa]=ua;za=ha;Aa=fa;Ba=ta;Ca=ua;break}else{ua=M+(ta<<24>>24)+(ta<<24>>24>0)>>C&255;a[qa]=ua;qa=a[ka+12|0]|0;ta=M+(qa<<24>>24)+(qa<<24>>24>0)>>C&255;a[xa]=ta;za=ha;Aa=fa;Ba=ua;Ca=ta;break}}}while(0);Ea=c[R>>2]|0;if((a[ja+8|0]|0)==0){Fa=c[k>>2]|0}else{Ga=Ba<<24>>24;Ha=Ca<<24>>24;pa=c[m>>2]|0;if(((Ga>>Ea)+ia+(ba((Ha>>Ea)+W|0,pa)|0)|0)<0){Da=47;break b}oa=c[k>>2]|0;ma=ia-1+(Ga+Ea>>Ea)+oa+(ba(ea+(Ha+Ea>>Ea)+oa|0,pa)|0)|0;if((ma|0)>((c[S>>2]|0)-1|0)){Da=47;break b}else{Fa=oa}}Ia=ja+16|0;Ja=(ka|0)==0?0:ka+16|0;oa=Fa+ia|0;Ka=c[n>>2]|0;La=c[x>>2]|0;if((oa|0)<(La+Ka|0)){fa=Aa;ga=Fa+ga|0;ha=za;ia=oa;ja=Ia;ka=Ja}else{break}}Ma=Aa;Na=za;Oa=Ia;Pa=Ja;Qa=La;Ra=Fa;Sa=c[r>>2]|0;Ta=c[z>>2]|0;Ua=Ka}else{Ma=T;Na=V;Oa=X;Pa=Y;Qa=Z;Ra=_;Sa=$;Ta=aa;Ua=ca}ka=Ra+W|0;if((ka|0)<(Ta+Sa|0)){T=Ma;U=U+o|0;V=Na;W=ka;X=Oa;Y=Pa;Z=Qa;_=Ra;$=Sa;aa=Ta;ca=Ua}else{break a}}if((Da|0)==13){yDb(h,16,2051544,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;w=-1094995529;i=j;return w|0}else if((Da|0)==47){ca=Ga+(ba(Ea,ia)|0)|0;aa=Ha+(ba(Ea,W)|0)|0;yDb(h,16,2006104,(B=i,i=i+16|0,c[B>>2]=ca,c[B+8>>2]=aa,B)|0);i=B;w=-1094995529;i=j;return w|0}}}while(0);B=c[D>>2]|0;h=-B&7;if((h|0)==0){w=0;i=j;return w|0}Ea=c[e+16>>2]|0;e=h+B|0;c[D>>2]=Ea>>>0>e>>>0?e:Ea;w=0;i=j;return w|0}function BHa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+4656>>2]|0;if((b|0)==0|(b|0)==1){d=a+4744|0;e=c[d>>2]|0;f=e^1;c[d>>2]=f;c[a+4748>>2]=f;c[a+4752>>2]=e}else if((b|0)==2){b=a+4676|0;e=a+4756|0;if((c[b>>2]|0)==0){c[e>>2]=2;c[b>>2]=1;g=2}else{g=c[e>>2]|0}e=a+4748|0;b=c[e>>2]|0;c[a+4756>>2]=b;c[e>>2]=g;c[a+4752>>2]=b}b=c[a+4652>>2]|0;if((b|0)==1){h=c[a+4744>>2]|0}else if((b|0)==0){c[a+4744>>2]=0;h=0}else{return}c[a+4676>>2]=0;c[a+4748>>2]=h;c[a+4752>>2]=h^1;return}function CHa(a){a=a|0;return(c[a+4652>>2]|0)!=4|0}function DHa(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;f=a+14128|0;g=c[f>>2]|0;h=a+14136|0;j=c[h>>2]|0;k=a+14120|0;l=c[k>>2]|0;m=l+(g>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(g&7);m=g+22|0;g=j>>>0>m>>>0?m:j;c[f>>2]=g;if((n&-1024|0)!=32768){yDb(c[a+4>>2]|0,16,2274704,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}n=l+(g>>>3)|0;m=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(g&7)>>>24;n=g+8|0;g=j>>>0>n>>>0?n:j;c[f>>2]=g;c[a+108>>2]=m;m=d[l+(g>>>3)|0]|0;n=((g|0)<(j|0))+g|0;c[f>>2]=n;if((m&128>>>((g&7)>>>0)|0)==0){yDb(c[a+4>>2]|0,16,2323056,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}g=d[l+(n>>>3)|0]|0;m=((n|0)<(j|0))+n|0;c[f>>2]=m;if((g&128>>>((n&7)>>>0)|0)!=0){yDb(c[a+4>>2]|0,16,2186768,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}n=m+1|0;m=(j>>>0>n>>>0?n:j)+1|0;n=(j>>>0>m>>>0?m:j)+1|0;m=j>>>0>n>>>0?n:j;c[f>>2]=m;n=l+(m>>>3)|0;g=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(m&7);n=g>>>29;q=m+3|0;m=j>>>0>q>>>0?q:j;c[f>>2]=m;if((n|0)==6|(n|0)==0){yDb(c[a+4>>2]|0,16,2109600,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}c[a+40>>2]=0;q=(d[l+(m>>>3)|0]|0)<<(m&7)>>>7;r=((m|0)<(j|0))+m|0;c[f>>2]=r;c[a+9992>>2]=(q&1)+1;q=(d[l+(r>>>3)|0]|0)<<(r&7)>>>7;m=((r|0)<(j|0))+r|0;c[f>>2]=m;r=q&1;c[a+10052>>2]=r;q=d[l+(m>>>3)|0]|0;s=((m|0)<(j|0))+m|0;c[f>>2]=s;if((q&128>>>((m&7)>>>0)|0)!=0){yDb(c[a+4>>2]|0,16,2051488,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}m=(d[l+(s>>>3)|0]|0)<<(s&7)>>>7;q=((s|0)<(j|0))+s|0;c[f>>2]=q;s=m&1;c[a+13788>>2]=s;c[a+10048>>2]=(s|0)==0?r:1;r=(d[l+(q>>>3)|0]|0)<<(q&7)>>>7;s=((q|0)<(j|0))+q|0;c[f>>2]=s;q=a+36|0;c[q>>2]=r&1;do{if(g>>>0<3221225472>>>0){c[a+8>>2]=e[1210824+(n<<2)>>1]|0;c[a+12>>2]=e[1210826+(n<<2)>>1]|0;r=c[a+4>>2]|0;c[r+224>>2]=12;c[r+228>>2]=11;t=n}else{r=l+(s>>>3)|0;m=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>29;r=s+3|0;u=j>>>0>r>>>0?r:j;c[f>>2]=u;if((m|0)==7|(m|0)==0){yDb(c[a+4>>2]|0,16,2006056,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}r=l+(u>>>3)|0;v=fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;r=u+2|0;w=j>>>0>r>>>0?r:j;c[f>>2]=w;r=a+4|0;if((v&-1073741824>>>((u&7)>>>0)|0)==0){x=w;y=l;z=j}else{yDb(c[r>>2]|0,16,1968296,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;x=c[f>>2]|0;y=c[k>>2]|0;z=c[h>>2]|0}w=(d[y+(x>>>3)|0]|0)<<(x&7)>>>7;u=((x|0)<(z|0))+x|0;c[f>>2]=u;v=c[r>>2]|0;c[a+13836>>2]=w&1&-((c[v+800>>2]|0)==0|0);w=d[y+(u>>>3)|0]|0;A=((u|0)<(z|0))+u|0;c[f>>2]=A;if((w&128>>>((u&7)>>>0)|0)==0){B=A;C=y;D=z}else{yDb(v,16,1968296,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;B=c[f>>2]|0;C=c[k>>2]|0;D=c[h>>2]|0}v=d[C+(B>>>3)|0]|0;A=((B|0)<(D|0))+B|0;c[f>>2]=A;if((v&128>>>((B&7)>>>0)|0)!=0){c[q>>2]=2}v=C+(A>>>3)|0;u=fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;v=A+5|0;w=D>>>0>v>>>0?v:D;c[f>>2]=w;if((u&-134217728>>>((A&7)>>>0)|0)==0){E=w;F=D;G=C}else{yDb(c[r>>2]|0,16,1968296,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;E=c[f>>2]|0;F=c[h>>2]|0;G=c[k>>2]|0}w=G+(E>>>3)|0;A=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(E&7);w=E+5|0;c[f>>2]=F>>>0>w>>>0?w:F;if((A&-134217728|0)==134217728){t=m;break}yDb(c[r>>2]|0,16,1939856,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=m}}while(0);do{if((t|0)==6){F=c[f>>2]|0;E=c[h>>2]|0;G=c[k>>2]|0;C=G+(F>>>3)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(F&7)>>>28;C=F+4|0;F=(E>>>0>C>>>0?C:E)+9|0;C=(E>>>0>F>>>0?F:E)+1|0;F=(E>>>0>C>>>0?C:E)+9|0;C=E>>>0>F>>>0?F:E;c[f>>2]=C;if((D|0)==15){F=G+(C>>>3)|0;B=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(C&7)>>>24;F=C+8|0;c[f>>2]=E>>>0>F>>>0?F:E;E=c[a+4>>2]|0;c[E+224>>2]=B;B=c[f>>2]|0;F=c[h>>2]|0;C=G+(B>>>3)|0;G=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7)>>>24;C=B+8|0;c[f>>2]=F>>>0>C>>>0?C:F;c[E+228>>2]=G;H=E}else{E=a+4|0;G=1210392+(D<<3)|0;D=(c[E>>2]|0)+224|0;F=c[G+4>>2]|0;c[D>>2]=c[G>>2];c[D+4>>2]=F;H=c[E>>2]|0}if((c[H+224>>2]|0)!=0){break}yDb(H,16,1915648,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);o=c[f>>2]|0;H=c[h>>2]|0;h=c[k>>2]|0;k=h+(o>>>3)|0;t=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(o&7)>>>27;k=o+5|0;c[a+9960>>2]=t;c[a+9964>>2]=t;t=(H>>>0>k>>>0?k:H)+1|0;k=H>>>0>t>>>0?t:H;c[f>>2]=k;if((c[q>>2]|0)==0){I=k}else{q=k+3|0;k=(H>>>0>q>>>0?q:H)+2|0;q=H>>>0>k>>>0?k:H;c[f>>2]=q;I=q}q=c[a+14132>>2]|0;if((q-I|0)<1){p=-1094995529;i=b;return p|0}else{J=I}while(1){I=d[h+(J>>>3)|0]|0;k=((J|0)<(H|0))+J|0;c[f>>2]=k;if((I&128>>>((J&7)>>>0)|0)==0){break}I=k+8|0;k=H>>>0>I>>>0?I:H;c[f>>2]=k;if((q-k|0)<1){p=-1094995529;K=37;break}else{J=k}}if((K|0)==37){i=b;return p|0}c[a+11556>>2]=1;c[a+9892>>2]=1179688;c[a+9888>>2]=1179688;fIa(a);p=0;i=b;return p|0}function EHa(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;c[b>>2]=a;d=(c[a+792>>2]|0)==16;c[b+228>>2]=d&1;c[a+140>>2]=d?46:11;BFa(b+4|0,c[a+88>>2]|0);a=b+216|0;c[a>>2]=ICb()|0;d=ICb()|0;e=b+212|0;c[e>>2]=d;if(!((c[a>>2]|0)==0|(d|0)==0)){f=0;return f|0}JCb(a);JCb(e);f=-12;return f|0}function FHa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;k=c[a+60>>2]|0;l=k;m=b;n=(ba(c[a+124>>2]|0,c[a+120>>2]|0)|0)/128|0;o=k+224|0;c[o>>2]=n;if((j|0)<(n|0)){p=j;i=g;return p|0}if((HZ(f,2,0)|0)!=0){KCb(c[k+216>>2]|0);KCb(c[k+212>>2]|0)}n=k+220|0;c[n>>2]=h;q=c[o>>2]|0;r=h+q|0;if(!((j-q|0)>-1)){yDb(0,0,2289232,(s=i,i=i+24|0,c[s>>2]=2273176,c[s+8>>2]=2257576,c[s+16>>2]=135,s)|0);i=s;Cd();return 0}q=k+232|0;t=q;c[t>>2]=r;c[k+240>>2]=r;r=k+236|0;c[r>>2]=h+j;h=_$a(a,m,1)|0;if((h|0)<0){p=h;i=g;return p|0}h=k+228|0;do{if((c[h>>2]|0)==0){a=HZ(f,0,0)|0;if((a|0)==0){break}c[b+304>>2]=1;UGb(k+272|0,a|0,1024)|0}}while(0);f=c[t>>2]|0;a=c[r>>2]|0;u=a-f|0;v=u>>>0>14>>>0?14:u;u=f+v|0;c[t>>2]=u;w=c[h>>2]|0;if((w|0)==0){UGb(c[b+4>>2]|0,k+272|0,1024)|0;x=c[b+32>>2]|0;c[k+264>>2]=x;y=x;z=c[h>>2]|0}else{x=c[b+32>>2]>>1;c[k+264>>2]=x;A=k+244|0;c[A>>2]=c[q>>2];c[A+4>>2]=c[q+4>>2];c[A+8>>2]=c[q+8>>2];if((a-u|0)<2){B=0}else{c[t>>2]=f+(v+2);v=u;B=(d[v]|d[v+1|0]<<8)<<16>>16&65535}v=A;A=c[v>>2]|0;u=(c[k+248>>2]|0)-A|0;c[v>>2]=A+(u>>>0>B>>>0?B:u);y=x;z=w}c[k+260>>2]=y-8;y=k;w=c[y>>2]|0;x=w+124|0;u=b+32|0;B=ba((c[x>>2]|0)-8|0,c[u>>2]|0)|0;c[k+268>>2]=(ba((c[w+120>>2]|0)-8|0,z+1|0)|0)+B;B=c[n>>2]|0;n=c[o>>2]<<3;o=n>>>0>2147483639>>>0|(B|0)==0;z=o?0:B;B=o?8:n+8|0;a:do{if((c[x>>2]|0)>0){n=b;o=k+256|0;A=0;v=0;f=w;b:while(1){if((c[f+120>>2]|0)>0){a=A;C=0;while(1){q=z+(a>>>3)|0;D=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((a&7)>>>0)&15;q=a+4|0;E=B>>>0>q>>>0?q:B;q=c[n>>2]|0;if((c[h>>2]|0)==0){c[o>>2]=q+((ba(c[u>>2]|0,v)|0)+C);F=Oe[c[903208+(D<<2)>>2]&1023](l,m)|0}else{c[o>>2]=q+((ba(c[u>>2]|0,v)|0)+(C<<1));F=Oe[c[903144+(D<<2)>>2]&1023](l,m)|0}if((F|0)!=0){break b}D=C+8|0;q=c[y>>2]|0;if((D|0)<(c[q+120>>2]|0)){a=E;C=D}else{G=q;H=E;break}}}else{G=f;H=A}a=v+8|0;if((a|0)<(c[G+124>>2]|0)){A=H;v=a;f=G}else{I=G;J=25;break a}}f=c[y>>2]|0;yDb(f,16,2186720,(s=i,i=i+24|0,c[s>>2]=c[f+428>>2],c[s+8>>2]=C,c[s+16>>2]=v,s)|0);i=s}else{I=w;J=25}}while(0);do{if((J|0)==25){w=(c[r>>2]|0)-(c[t>>2]|0)|0;if(!(w>>>0>1>>>0)){break}yDb(I,16,2109552,(s=i,i=i+8|0,c[s>>2]=w,s)|0);i=s}}while(0);c[e>>2]=1;e=k+212|0;KCb(c[e>>2]|0);s=k+216|0;k=c[s>>2]|0;I=c[e>>2]|0;c[s>>2]=I;c[e>>2]=k;k=MCb(I,m)|0;p=(k|0)<0?k:j;i=g;return p|0}function GHa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+216|0);JCb(b+212|0);return 0}function HHa(a,b){a=a|0;b=b|0;return WHa(a,c[a+216>>2]|0,c[b>>2]|0,c[b+32>>2]|0,0,0)|0}function IHa(a,b){a=a|0;b=b|0;return WHa(a,c[a+212>>2]|0,c[b>>2]|0,c[b+32>>2]|0,0,0)|0}function JHa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((c[b+228>>2]|0)==0){e=b+232|0;f=c[e>>2]|0;if(((c[b+236>>2]|0)-f|0)<1){g=0;h=7;break}c[e>>2]=f+1;i=f;h=6}else{f=b+244|0;e=c[f>>2]|0;if(((c[b+248>>2]|0)-e|0)<1){g=0;h=7;break}c[f>>2]=e+1;i=e;h=6}}while(0);do{if((h|0)==6){e=a[i]|0;if((e&255)>>>0<56>>>0){g=e;h=7;break}f=(e&255)-56|0;j=((f|0)/29|0)+8|0;k=((f|0)%29|0)-14|0}}while(0);if((h|0)==7){j=((g&255)/7|0)&255;k=((g&255)%7|0)&255|8}return WHa(b,c[b+212>>2]|0,c[d>>2]|0,c[d+32>>2]|0,k,j)|0}function KHa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((c[b+228>>2]|0)==0){e=b+232|0;f=c[e>>2]|0;if(((c[b+236>>2]|0)-f|0)<1){g=0;h=7;break}c[e>>2]=f+1;i=f;h=6}else{f=b+244|0;e=c[f>>2]|0;if(((c[b+248>>2]|0)-e|0)<1){g=0;h=7;break}c[f>>2]=e+1;i=e;h=6}}while(0);do{if((h|0)==6){e=a[i]|0;if((e&255)>>>0<56>>>0){g=e;h=7;break}f=(e&255)-56|0;j=-8-((f|0)/29|0)|0;k=14-((f|0)%29|0)|0}}while(0);if((h|0)==7){j=-(((g&255)/7|0)&255)|0;k=-(((g&255)%7|0)&255|8)|0}return WHa(b,d,c[d>>2]|0,c[d+32>>2]|0,k,j)|0}function LHa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;do{if((c[b+228>>2]|0)==0){e=b+232|0;f=c[e>>2]|0;if(((c[b+236>>2]|0)-f|0)<1){g=0;break}c[e>>2]=f+1;g=a[f]|0}else{f=b+244|0;e=c[f>>2]|0;if(((c[b+248>>2]|0)-e|0)<1){g=0;break}c[f>>2]=e+1;g=a[e]|0}}while(0);return WHa(b,c[b+216>>2]|0,c[d>>2]|0,c[d+32>>2]|0,(g&15)-8|0,((g&255)>>>4&255)-8|0)|0}function MHa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+232|0;f=c[e>>2]|0;g=c[b+236>>2]|0;if((g-f|0)<1){h=0;i=f}else{j=f+1|0;c[e>>2]=j;h=a[f]|0;i=j}if((g-i|0)<1){k=0}else{c[e>>2]=i+1;k=a[i]|0}return WHa(b,c[b+216>>2]|0,c[d>>2]|0,c[d+32>>2]|0,h,k)|0}function NHa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+232|0;f=c[e>>2]|0;g=c[b+236>>2]|0;if((g-f|0)<1){h=0;i=f}else{j=f+1|0;c[e>>2]=j;h=a[f]|0;i=j}if((g-i|0)<1){k=0}else{c[e>>2]=i+1;k=a[i]|0}return WHa(b,c[b+212>>2]|0,c[d>>2]|0,c[d+32>>2]|0,h,k)|0}function OHa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=c[a+256>>2]|0;h=a+232|0;j=c[h>>2]|0;k=c[a+236>>2]|0;if((k-j|0)<2){l=0;m=j}else{n=j+2|0;c[h>>2]=n;o=j;l=(d[o]|d[o+1|0]<<8)<<16>>16;m=n}b[f>>1]=l;if((k-m|0)<2){p=0;q=m}else{n=m+2|0;c[h>>2]=n;o=m;p=(d[o]|d[o+1|0]<<8)<<16>>16;q=n}b[f+2>>1]=p;if(l<<16>>16<0){if((k-q|0)<2){r=0}else{c[h>>2]=q+2;l=q;r=(d[l]|d[l+1|0]<<8)<<16>>16&65535}l=c[a+264>>2]|0;p=l<<1;n=0;o=r;r=g;while(1){m=b[f+((o&1)<<1)>>1]|0;b[r+(l+1<<1)>>1]=m;b[r+(l<<1)>>1]=m;b[r+2>>1]=m;b[r>>1]=m;m=b[f+((o>>>1&1)<<1)>>1]|0;b[r+(l+3<<1)>>1]=m;b[r+(l+2<<1)>>1]=m;b[r+6>>1]=m;b[r+4>>1]=m;m=b[f+((o>>>2&1)<<1)>>1]|0;b[r+(l+5<<1)>>1]=m;b[r+(l+4<<1)>>1]=m;b[r+10>>1]=m;b[r+8>>1]=m;m=b[f+((o>>>3&1)<<1)>>1]|0;b[r+(l+7<<1)>>1]=m;b[r+(l+6<<1)>>1]=m;b[r+14>>1]=m;b[r+12>>1]=m;m=n+2|0;if((m|0)<8){n=m;o=o>>>4;r=r+(p<<1)|0}else{break}}i=e;return 0}p=a+260|0;a=0;r=g;g=q;while(1){if((k-g|0)<1){s=256;t=g}else{q=g+1|0;c[h>>2]=q;s=d[g]|0|256;t=q}q=s;o=r;while(1){b[o>>1]=b[f+((q&1)<<1)>>1]|0;n=q>>>1;if((n|0)==1){break}else{q=n;o=o+2|0}}q=a+1|0;if((q|0)<8){a=q;r=o+((c[p>>2]|0)+1<<1)|0;g=t}else{break}}i=e;return 0}function PHa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+8|0;f=e|0;g=c[a+256>>2]|0;h=a+232|0;j=c[h>>2]|0;k=c[a+236>>2]|0;if((k-j|0)<2){l=0;m=j}else{n=j+2|0;c[h>>2]=n;o=j;l=(d[o]|d[o+1|0]<<8)<<16>>16;m=n}n=f|0;b[n>>1]=l;if((k-m|0)<2){p=0;q=m}else{o=m+2|0;c[h>>2]=o;j=m;p=(d[j]|d[j+1|0]<<8)<<16>>16;q=o}o=f+2|0;b[o>>1]=p;if(!(l<<16>>16<0)){l=a+264|0;p=0;j=0;m=g;r=q;while(1){do{if((p&3|0)==0){if((p|0)==0){s=r}else{if((k-r|0)<2){t=0;u=r}else{v=r+2|0;c[h>>2]=v;w=r;t=(d[w]|d[w+1|0]<<8)<<16>>16;u=v}b[n>>1]=t;if((k-u|0)<2){x=0;y=u}else{v=u+2|0;c[h>>2]=v;w=u;x=(d[w]|d[w+1|0]<<8)<<16>>16;y=v}b[o>>1]=x;s=y}if((k-s|0)<2){z=0;A=s;break}v=s+2|0;c[h>>2]=v;w=s;z=(d[w]|d[w+1|0]<<8)<<16>>16&65535;A=v}else{z=j;A=r}}while(0);b[m>>1]=b[f+((z&1)<<1)>>1]|0;b[m+2>>1]=b[f+((z>>>1&1)<<1)>>1]|0;b[m+4>>1]=b[f+((z>>>2&1)<<1)>>1]|0;b[m+6>>1]=b[f+((z>>>3&1)<<1)>>1]|0;v=z>>>4;w=c[l>>2]|0;if((p|0)==7){p=p+1|0;j=v;m=m+((-(w<<3)|4)+w<<1)|0;r=A;continue}else{B=p+1|0;if((B|0)<16){p=B;j=v;m=m+(w<<1)|0;r=A;continue}else{break}}}i=e;return 0}if((k-q|0)<4){C=0;D=q}else{A=q+4|0;c[h>>2]=A;r=q;C=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;D=A}if((k-D|0)<2){E=0;F=D}else{A=D+2|0;c[h>>2]=A;r=D;E=(d[r]|d[r+1|0]<<8)<<16>>16;F=A}A=f+4|0;b[A>>1]=E;if((k-F|0)<2){G=0;H=F}else{r=F+2|0;c[h>>2]=r;D=F;G=(d[D]|d[D+1|0]<<8)<<16>>16;H=r}r=f+6|0;b[r>>1]=G;if(E<<16>>16<0){E=a+260|0;G=0;D=C;F=g;q=H;while(1){do{if((G|0)==4){b[n>>1]=b[A>>1]|0;b[o>>1]=b[r>>1]|0;if((k-q|0)<4){I=0;J=q;break}m=q+4|0;c[h>>2]=m;j=q;I=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;J=m}else{I=D;J=q}}while(0);b[F>>1]=b[f+((I&1)<<1)>>1]|0;b[F+2>>1]=b[f+((I>>>1&1)<<1)>>1]|0;b[F+4>>1]=b[f+((I>>>2&1)<<1)>>1]|0;b[F+6>>1]=b[f+((I>>>3&1)<<1)>>1]|0;b[F+8>>1]=b[f+((I>>>4&1)<<1)>>1]|0;b[F+10>>1]=b[f+((I>>>5&1)<<1)>>1]|0;b[F+12>>1]=b[f+((I>>>6&1)<<1)>>1]|0;b[F+14>>1]=b[f+((I>>>7&1)<<1)>>1]|0;m=G+1|0;if((m|0)<8){G=m;D=I>>>8;F=F+((c[E>>2]|0)+8<<1)|0;q=J}else{break}}i=e;return 0}J=c[a+264>>2]|0;a=0;q=C;C=g;g=H;a:while(1){b[C>>1]=b[f+((q&1)<<1)>>1]|0;b[C+2>>1]=b[f+((q>>>1&1)<<1)>>1]|0;b[C+4>>1]=b[f+((q>>>2&1)<<1)>>1]|0;b[C+6>>1]=b[f+((q>>>3&1)<<1)>>1]|0;H=q>>>4;E=J-4|0;do{if((a|0)==7){F=4-(J<<3)|0;b[n>>1]=b[A>>1]|0;b[o>>1]=b[r>>1]|0;if((k-g|0)<4){a=a+1|0;q=0;C=C+(F+J<<1)|0;g=g;continue a}else{I=g+4|0;c[h>>2]=I;D=g;K=F+E|0;L=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;M=I;break}}else{K=E;L=H;M=g}}while(0);H=a+1|0;if((H|0)<16){a=H;q=L;C=C+(K+4<<1)|0;g=M}else{break}}i=e;return 0}function QHa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+8|0;f=e|0;g=c[a+256>>2]|0;h=a+232|0;j=c[h>>2]|0;k=c[a+236>>2]|0;if((k-j|0)<2){l=0;m=j}else{n=j+2|0;c[h>>2]=n;o=j;l=(d[o]|d[o+1|0]<<8)<<16>>16;m=n}b[f>>1]=l;if((k-m|0)<2){p=0;q=m}else{n=m+2|0;c[h>>2]=n;o=m;p=(d[o]|d[o+1|0]<<8)<<16>>16;q=n}b[f+2>>1]=p;if((k-q|0)<2){r=0;s=q}else{p=q+2|0;c[h>>2]=p;n=q;r=(d[n]|d[n+1|0]<<8)<<16>>16;s=p}b[f+4>>1]=r;if((k-s|0)<2){t=0;u=s}else{p=s+2|0;c[h>>2]=p;n=s;t=(d[n]|d[n+1|0]<<8)<<16>>16;u=p}b[f+6>>1]=t;t=g;if(l<<16>>16<0){if((k-u|0)<8){v=0;w=0}else{c[h>>2]=u+8;l=u;g=l|0;p=l+4|0;v=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;w=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0}g=c[a+264>>2]|0;if(!(r<<16>>16<0)){p=0;l=t;n=v;s=w;while(1){q=b[f+((s&3)<<1)>>1]|0;b[l+2>>1]=q;b[l>>1]=q;q=b[f+(((s>>>2|n<<30)&3)<<1)>>1]|0;b[l+6>>1]=q;b[l+4>>1]=q;q=b[f+(((s>>>4|n<<28)&3)<<1)>>1]|0;b[l+10>>1]=q;b[l+8>>1]=q;q=b[f+(((s>>>6|n<<26)&3)<<1)>>1]|0;b[l+14>>1]=q;b[l+12>>1]=q;q=s>>>8|n<<24;o=p+1|0;if((o|0)<8){p=o;l=l+(g<<1)|0;n=n>>>8|0<<24;s=q}else{break}}i=e;return 0}s=g<<1;n=0;l=t;p=v;v=w;while(1){w=b[f+((v&3)<<1)>>1]|0;b[l+(g<<1)>>1]=w;b[l>>1]=w;w=b[f+(((v>>>2|p<<30)&3)<<1)>>1]|0;b[l+(g+1<<1)>>1]=w;b[l+2>>1]=w;w=b[f+(((v>>>4|p<<28)&3)<<1)>>1]|0;b[l+(g+2<<1)>>1]=w;b[l+4>>1]=w;w=b[f+(((v>>>6|p<<26)&3)<<1)>>1]|0;b[l+(g+3<<1)>>1]=w;b[l+6>>1]=w;w=b[f+(((v>>>8|p<<24)&3)<<1)>>1]|0;b[l+(g+4<<1)>>1]=w;b[l+8>>1]=w;w=b[f+(((v>>>10|p<<22)&3)<<1)>>1]|0;b[l+(g+5<<1)>>1]=w;b[l+10>>1]=w;w=b[f+(((v>>>12|p<<20)&3)<<1)>>1]|0;b[l+(g+6<<1)>>1]=w;b[l+12>>1]=w;w=b[f+(((v>>>14|p<<18)&3)<<1)>>1]|0;b[l+(g+7<<1)>>1]=w;b[l+14>>1]=w;w=v>>>16|p<<16;q=n+2|0;if((q|0)<8){n=q;l=l+(s<<1)|0;p=p>>>16|0<<16;v=w}else{break}}i=e;return 0}if(r<<16>>16<0){if((k-u|0)<4){x=0}else{c[h>>2]=u+4;r=u;x=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0}r=c[a+264>>2]|0;v=r<<1;p=0;s=t;l=x;while(1){x=b[f+((l&3)<<1)>>1]|0;b[s+(r+1<<1)>>1]=x;b[s+(r<<1)>>1]=x;b[s+2>>1]=x;b[s>>1]=x;x=b[f+((l>>>2&3)<<1)>>1]|0;b[s+(r+3<<1)>>1]=x;b[s+(r+2<<1)>>1]=x;b[s+6>>1]=x;b[s+4>>1]=x;x=b[f+((l>>>4&3)<<1)>>1]|0;b[s+(r+5<<1)>>1]=x;b[s+(r+4<<1)>>1]=x;b[s+10>>1]=x;b[s+8>>1]=x;x=b[f+((l>>>6&3)<<1)>>1]|0;b[s+(r+7<<1)>>1]=x;b[s+(r+6<<1)>>1]=x;b[s+14>>1]=x;b[s+12>>1]=x;x=p+2|0;if((x|0)<8){p=x;s=s+(v<<1)|0;l=l>>>8}else{break}}i=e;return 0}else{l=a+260|0;a=0;v=t;t=u;while(1){if((k-t|0)<2){y=0;z=t}else{u=t+2|0;c[h>>2]=u;s=t;y=(d[s]|d[s+1|0]<<8)<<16>>16&65535;z=u}b[v>>1]=b[f+((y&3)<<1)>>1]|0;b[v+2>>1]=b[f+((y>>>2&3)<<1)>>1]|0;b[v+4>>1]=b[f+((y>>>4&3)<<1)>>1]|0;b[v+6>>1]=b[f+((y>>>6&3)<<1)>>1]|0;b[v+8>>1]=b[f+((y>>>8&3)<<1)>>1]|0;b[v+10>>1]=b[f+((y>>>10&3)<<1)>>1]|0;b[v+12>>1]=b[f+((y>>>12&3)<<1)>>1]|0;b[v+14>>1]=b[f+(y>>>14<<1)>>1]|0;u=a+1|0;if((u|0)<8){a=u;v=v+((c[l>>2]|0)+8<<1)|0;t=z}else{break}}i=e;return 0}return 0}function RHa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;e=i;i=i+16|0;f=e|0;g=f;h=c[a+256>>2]|0;j=a+232|0;k=c[j>>2]|0;l=c[a+236>>2]|0;if((l-k|0)<2){m=0;n=k}else{o=k+2|0;c[j>>2]=o;p=k;m=(d[p]|d[p+1|0]<<8)<<16>>16;n=o}o=f;b[o>>1]=m;if((l-n|0)<2){q=0;r=n}else{p=n+2|0;c[j>>2]=p;k=n;q=(d[k]|d[k+1|0]<<8)<<16>>16;r=p}p=g+2|0;b[p>>1]=q;if((l-r|0)<2){s=0;t=r}else{q=r+2|0;c[j>>2]=q;k=r;s=(d[k]|d[k+1|0]<<8)<<16>>16;t=q}q=g+4|0;b[q>>1]=s;if((l-t|0)<2){u=0;v=t}else{s=t+2|0;c[j>>2]=s;k=t;u=(d[k]|d[k+1|0]<<8)<<16>>16;v=s}s=g+6|0;b[s>>1]=u;u=f|0;k=h;if(!(m<<16>>16<0)){m=a+264|0;h=0;t=0;r=k;n=v;while(1){do{if((h&3|0)==0){if((h|0)==0){w=n}else{if((l-n|0)<2){x=0;y=n}else{z=n+2|0;c[j>>2]=z;A=n;x=(d[A]|d[A+1|0]<<8)<<16>>16;y=z}b[o>>1]=x;if((l-y|0)<2){B=0;C=y}else{z=y+2|0;c[j>>2]=z;A=y;B=(d[A]|d[A+1|0]<<8)<<16>>16;C=z}b[p>>1]=B;if((l-C|0)<2){D=0;E=C}else{z=C+2|0;c[j>>2]=z;A=C;D=(d[A]|d[A+1|0]<<8)<<16>>16;E=z}b[q>>1]=D;if((l-E|0)<2){F=0;G=E}else{z=E+2|0;c[j>>2]=z;A=E;F=(d[A]|d[A+1|0]<<8)<<16>>16;G=z}b[s>>1]=F;w=G}if((l-w|0)<4){H=0;I=w;break}z=w+4|0;c[j>>2]=z;A=w;H=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;I=z}else{H=t;I=n}}while(0);b[r>>1]=b[g+((H&3)<<1)>>1]|0;b[r+2>>1]=b[g+((H>>>2&3)<<1)>>1]|0;b[r+4>>1]=b[g+((H>>>4&3)<<1)>>1]|0;b[r+6>>1]=b[g+((H>>>6&3)<<1)>>1]|0;z=H>>8;A=c[m>>2]|0;if((h|0)==7){h=h+1|0;t=z;r=r+((-(A<<3)|4)+A<<1)|0;n=I;continue}else{J=h+1|0;if((J|0)<16){h=J;t=z;r=r+(A<<1)|0;n=I;continue}else{break}}}i=e;return 0}if((l-v|0)<8){K=0;L=0;M=v}else{I=v+8|0;c[j>>2]=I;n=v;v=n|0;r=n+4|0;K=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;L=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;M=I}if((l-M|0)<2){N=0;O=M}else{I=M+2|0;c[j>>2]=I;v=M;N=(d[v]|d[v+1|0]<<8)<<16>>16;O=I}b[f+8>>1]=N;if((l-O|0)<2){P=0;Q=O}else{I=O+2|0;c[j>>2]=I;v=O;P=(d[v]|d[v+1|0]<<8)<<16>>16;Q=I}b[g+10>>1]=P;if((l-Q|0)<2){R=0;S=Q}else{P=Q+2|0;c[j>>2]=P;I=Q;R=(d[I]|d[I+1|0]<<8)<<16>>16;S=P}b[g+12>>1]=R;if((l-S|0)<2){T=0;U=S}else{R=S+2|0;c[j>>2]=R;P=S;T=(d[P]|d[P+1|0]<<8)<<16>>16;U=R}b[g+14>>1]=T;T=f+8|0;f=a+264|0;R=a+260|0;if(N<<16>>16>-1){N=0;a=k;P=K;S=L;I=U;a:while(1){b[a>>1]=b[g+((S&3)<<1)>>1]|0;b[a+2>>1]=b[g+(((S>>>2|P<<30)&3)<<1)>>1]|0;b[a+4>>1]=b[g+(((S>>>4|P<<28)&3)<<1)>>1]|0;b[a+6>>1]=b[g+(((S>>>6|P<<26)&3)<<1)>>1]|0;Q=S>>>8|P<<24;v=P>>>8|0<<24;O=c[f>>2]|0;M=a+(O<<1)|0;do{if((N|0)==7){r=a+((-(O<<3)|4)+O<<1)|0;n=c[T+4>>2]|0;c[u>>2]=c[T>>2];c[u+4>>2]=n;if((l-I|0)<8){N=N+1|0;a=r;P=0;S=0;I=I;continue a}else{n=I+8|0;c[j>>2]=n;t=I;h=t|0;m=t+4|0;V=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;W=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;X=r;Y=n;break}}else{V=v;W=Q;X=M;Y=I}}while(0);M=N+1|0;if((M|0)<16){N=M;a=X;P=V;S=W;I=Y}else{break}}i=e;return 0}else{Z=0;_=k;$=K;aa=L;ba=U}while(1){b[_>>1]=b[g+((aa&3)<<1)>>1]|0;b[_+2>>1]=b[g+(((aa>>>2|$<<30)&3)<<1)>>1]|0;b[_+4>>1]=b[g+(((aa>>>4|$<<28)&3)<<1)>>1]|0;b[_+6>>1]=b[g+(((aa>>>6|$<<26)&3)<<1)>>1]|0;U=aa>>>8|$<<24;L=$>>>8|0<<24;if((Z&1|0)==0){ca=_+8|0}else{ca=_+((c[R>>2]|0)+4<<1)|0}if((Z|0)!=7){K=Z+1|0;if((K|0)<16){Z=K;_=ca;$=L;aa=U;ba=ba;continue}else{break}}U=c[T+4>>2]|0;c[u>>2]=c[T>>2];c[u+4>>2]=U;if((l-ba|0)<8){da=0;ea=0;fa=ba}else{U=ba+8|0;c[j>>2]=U;L=ba;K=L|0;k=L+4|0;da=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;ea=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0;fa=U}Z=Z+1|0;_=ca;$=da;aa=ea;ba=fa}i=e;return 0}function SHa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=a+232|0;f=a+264|0;g=c[a+236>>2]|0;h=0;i=c[a+256>>2]|0;a=c[e>>2]|0;while(1){j=g;if((j-a|0)<2){k=0;l=a}else{m=a+2|0;c[e>>2]=m;n=a;k=(d[n]|d[n+1|0]<<8)<<16>>16;l=m}b[i>>1]=k;if((j-l|0)<2){o=0;p=l}else{m=l+2|0;c[e>>2]=m;n=l;o=(d[n]|d[n+1|0]<<8)<<16>>16;p=m}b[i+2>>1]=o;if((j-p|0)<2){q=0;r=p}else{m=p+2|0;c[e>>2]=m;n=p;q=(d[n]|d[n+1|0]<<8)<<16>>16;r=m}b[i+4>>1]=q;if((j-r|0)<2){s=0;t=r}else{m=r+2|0;c[e>>2]=m;n=r;s=(d[n]|d[n+1|0]<<8)<<16>>16;t=m}b[i+6>>1]=s;if((j-t|0)<2){u=0;v=t}else{m=t+2|0;c[e>>2]=m;n=t;u=(d[n]|d[n+1|0]<<8)<<16>>16;v=m}b[i+8>>1]=u;if((j-v|0)<2){w=0;x=v}else{m=v+2|0;c[e>>2]=m;n=v;w=(d[n]|d[n+1|0]<<8)<<16>>16;x=m}b[i+10>>1]=w;if((j-x|0)<2){y=0;z=x}else{m=x+2|0;c[e>>2]=m;n=x;y=(d[n]|d[n+1|0]<<8)<<16>>16;z=m}b[i+12>>1]=y;if((j-z|0)<2){A=0;B=z}else{j=z+2|0;c[e>>2]=j;m=z;A=(d[m]|d[m+1|0]<<8)<<16>>16;B=j}b[i+14>>1]=A;j=h+1|0;if((j|0)<8){h=j;i=i+(c[f>>2]<<1)|0;a=B}else{break}}return 0}function THa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=a+232|0;f=a+264|0;g=c[a+236>>2]|0;h=0;i=c[a+256>>2]|0;a=c[e>>2]|0;while(1){j=g;if((j-a|0)<2){k=0;l=a}else{m=a+2|0;c[e>>2]=m;n=a;k=(d[n]|d[n+1|0]<<8)<<16>>16;l=m}m=c[f>>2]|0;b[i+(m+1<<1)>>1]=k;b[i+(m<<1)>>1]=k;b[i+2>>1]=k;b[i>>1]=k;if((j-l|0)<2){o=0;p=l}else{n=l+2|0;c[e>>2]=n;q=l;o=(d[q]|d[q+1|0]<<8)<<16>>16;p=n}b[i+(m+3<<1)>>1]=o;b[i+(m+2<<1)>>1]=o;b[i+6>>1]=o;b[i+4>>1]=o;if((j-p|0)<2){r=0;s=p}else{n=p+2|0;c[e>>2]=n;q=p;r=(d[q]|d[q+1|0]<<8)<<16>>16;s=n}b[i+(m+5<<1)>>1]=r;b[i+(m+4<<1)>>1]=r;b[i+10>>1]=r;b[i+8>>1]=r;if((j-s|0)<2){t=0;u=s}else{j=s+2|0;c[e>>2]=j;n=s;t=(d[n]|d[n+1|0]<<8)<<16>>16;u=j}b[i+(m+7<<1)>>1]=t;b[i+(m+6<<1)>>1]=t;b[i+14>>1]=t;b[i+12>>1]=t;j=h+2|0;if((j|0)<8){h=j;i=i+(m<<1<<1)|0;a=u}else{break}}return 0}function UHa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=a+236|0;h=a+232|0;j=f|0;k=f+2|0;f=a+264|0;l=0;m=c[a+256>>2]|0;while(1){if((l&3|0)==0){a=c[h>>2]|0;n=c[g>>2]|0;if((n-a|0)<2){o=0;p=a}else{q=a+2|0;c[h>>2]=q;r=a;o=(d[r]|d[r+1|0]<<8)<<16>>16;p=q}b[j>>1]=o;if((n-p|0)<2){s=0}else{c[h>>2]=p+2;n=p;s=(d[n]|d[n+1|0]<<8)<<16>>16}b[k>>1]=s;t=o}else{t=b[j>>1]|0}b[m>>1]=t;b[m+2>>1]=b[j>>1]|0;b[m+4>>1]=b[j>>1]|0;b[m+6>>1]=b[j>>1]|0;b[m+8>>1]=b[k>>1]|0;b[m+10>>1]=b[k>>1]|0;b[m+12>>1]=b[k>>1]|0;b[m+14>>1]=b[k>>1]|0;n=l+1|0;if((n|0)<8){l=n;m=m+(c[f>>2]<<1)|0}else{break}}i=e;return 0}function VHa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0;e=c[a+256>>2]|0;f=e;g=a+232|0;h=c[g>>2]|0;if(((c[a+236>>2]|0)-h|0)<2){i=0}else{c[g>>2]=h+2;g=h;i=(d[g]|d[g+1|0]<<8)<<16>>16}g=c[a+264>>2]|0;b[f>>1]=i;b[e+2>>1]=i;b[e+4>>1]=i;b[e+6>>1]=i;b[e+8>>1]=i;b[e+10>>1]=i;b[e+12>>1]=i;b[e+14>>1]=i;b[f+(g<<1)>>1]=i;b[f+(g+1<<1)>>1]=i;b[f+(g+2<<1)>>1]=i;b[f+(g+3<<1)>>1]=i;b[f+(g+4<<1)>>1]=i;b[f+(g+5<<1)>>1]=i;b[f+(g+6<<1)>>1]=i;b[f+(g+7<<1)>>1]=i;e=g<<1;b[f+(e<<1)>>1]=i;b[f+((e|1)<<1)>>1]=i;b[f+(e+2<<1)>>1]=i;b[f+(e+3<<1)>>1]=i;b[f+(e+4<<1)>>1]=i;b[f+(e+5<<1)>>1]=i;b[f+(e+6<<1)>>1]=i;b[f+(e+7<<1)>>1]=i;a=e+g|0;b[f+(a<<1)>>1]=i;b[f+(a+1<<1)>>1]=i;b[f+(a+2<<1)>>1]=i;b[f+(a+3<<1)>>1]=i;b[f+(a+4<<1)>>1]=i;b[f+(a+5<<1)>>1]=i;b[f+(a+6<<1)>>1]=i;b[f+(a+7<<1)>>1]=i;e=a+g|0;b[f+(e<<1)>>1]=i;b[f+(e+1<<1)>>1]=i;b[f+(e+2<<1)>>1]=i;b[f+(e+3<<1)>>1]=i;b[f+(e+4<<1)>>1]=i;b[f+(e+5<<1)>>1]=i;b[f+(e+6<<1)>>1]=i;b[f+(e+7<<1)>>1]=i;a=e+g|0;b[f+(a<<1)>>1]=i;b[f+(a+1<<1)>>1]=i;b[f+(a+2<<1)>>1]=i;b[f+(a+3<<1)>>1]=i;b[f+(a+4<<1)>>1]=i;b[f+(a+5<<1)>>1]=i;b[f+(a+6<<1)>>1]=i;b[f+(a+7<<1)>>1]=i;e=a+g|0;b[f+(e<<1)>>1]=i;b[f+(e+1<<1)>>1]=i;b[f+(e+2<<1)>>1]=i;b[f+(e+3<<1)>>1]=i;b[f+(e+4<<1)>>1]=i;b[f+(e+5<<1)>>1]=i;b[f+(e+6<<1)>>1]=i;b[f+(e+7<<1)>>1]=i;a=e+g|0;b[f+(a<<1)>>1]=i;b[f+(a+1<<1)>>1]=i;b[f+(a+2<<1)>>1]=i;b[f+(a+3<<1)>>1]=i;b[f+(a+4<<1)>>1]=i;b[f+(a+5<<1)>>1]=i;b[f+(a+6<<1)>>1]=i;b[f+(a+7<<1)>>1]=i;return 0}function WHa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=c[a+256>>2]|0;k=ba(g,e)|0;g=c[a+228>>2]|0;l=k-d+j+(ba(g+1|0,f)|0)|0;if((l|0)<0){yDb(c[a>>2]|0,16,2051464,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1094995529;i=h;return n|0}f=c[a+268>>2]|0;if((l|0)>(f|0)){yDb(c[a>>2]|0,16,2006016,(m=i,i=i+16|0,c[m>>2]=l,c[m+8>>2]=f,m)|0);i=m;n=-1094995529;i=h;return n|0}f=c[b>>2]|0;if((f|0)==0){yDb(c[a>>2]|0,16,1968256,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=h;return n|0}else{cf[c[a+4+(((g|0)==0)<<4)>>2]&1023](j,f+l|0,e,8);n=0;i=h;return n|0}return 0}function XHa(a,b){a=a|0;b=b|0;b=i;yDb(c[a>>2]|0,16,2307632,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function YHa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+8|0;f=e|0;g=b+232|0;h=c[g>>2]|0;j=b+236|0;k=c[j>>2]|0;l=k;m=l-h|0;if(m>>>0<4>>>0){yDb(c[b>>2]|0,16,2332e3,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=e;return o|0}if((m|0)<1){p=0;q=h}else{m=h+1|0;c[g>>2]=m;p=a[h]|0;q=m}a[f|0]=p;if((l-q|0)<1){r=0;s=q}else{m=q+1|0;c[g>>2]=m;r=d[q]|0;s=m}a[f+1|0]=r;if((p&255)>>>0>r>>>0){if((l-s|0)<2){t=0}else{c[g>>2]=s+2;l=s;t=(d[l]|d[l+1|0]<<8)<<16>>16&65535}l=b+264|0;r=b+256|0;p=0;m=t;t=c[l>>2]|0;q=c[r>>2]|0;while(1){h=a[f+(m&1)|0]|0;a[q+(t+1)|0]=h;a[(c[r>>2]|0)+(c[l>>2]|0)|0]=h;a[(c[r>>2]|0)+1|0]=h;a[c[r>>2]|0]=h;h=a[f+(m>>>1&1)|0]|0;a[(c[r>>2]|0)+((c[l>>2]|0)+3)|0]=h;a[(c[r>>2]|0)+((c[l>>2]|0)+2)|0]=h;a[(c[r>>2]|0)+3|0]=h;a[(c[r>>2]|0)+2|0]=h;h=a[f+(m>>>2&1)|0]|0;a[(c[r>>2]|0)+((c[l>>2]|0)+5)|0]=h;a[(c[r>>2]|0)+((c[l>>2]|0)+4)|0]=h;a[(c[r>>2]|0)+5|0]=h;a[(c[r>>2]|0)+4|0]=h;h=a[f+(m>>>3&1)|0]|0;a[(c[r>>2]|0)+((c[l>>2]|0)+7)|0]=h;a[(c[r>>2]|0)+((c[l>>2]|0)+6)|0]=h;a[(c[r>>2]|0)+7|0]=h;a[(c[r>>2]|0)+6|0]=h;h=c[l>>2]|0;n=(c[r>>2]|0)+(h<<1)|0;c[r>>2]=n;u=p+2|0;if((u|0)<8){p=u;m=m>>>4;t=h;q=n}else{o=0;break}}i=e;return o|0}q=b+256|0;t=b+260|0;b=1;m=k;k=s;while(1){if((m-k|0)<1){v=256}else{c[g>>2]=k+1;v=d[k]|0|256}do{s=a[f+(v&1)|0]|0;p=c[q>>2]|0;c[q>>2]=p+1;a[p]=s;v=v>>>1;}while((v|0)!=1);c[q>>2]=(c[q>>2]|0)+(c[t>>2]|0);if((b|0)>=8){o=0;break}b=b+1|0;m=c[j>>2]|0;k=c[g>>2]|0}i=e;return o|0}function ZHa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;i=i+8|0;f=e|0;g=b+232|0;h=c[g>>2]|0;j=b+236|0;k=c[j>>2]|0;l=k-h|0;if(l>>>0<12>>>0){yDb(c[b>>2]|0,16,2352128,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}if((l|0)<1){o=0;p=h}else{l=h+1|0;c[g>>2]=l;o=a[h]|0;p=l}l=f|0;a[l]=o;if((k-p|0)<1){q=0;r=p}else{h=p+1|0;c[g>>2]=h;q=d[p]|0;r=h}h=f+1|0;a[h]=q;if(!((o&255)>>>0>q>>>0)){q=b+256|0;o=b+264|0;p=0;m=0;while(1){do{if((p&3|0)==0){s=c[j>>2]|0;t=c[g>>2]|0;if((p|0)==0){u=t}else{v=s;if((v-t|0)<1){w=0;x=t}else{y=t+1|0;c[g>>2]=y;w=a[t]|0;x=y}a[l]=w;if((v-x|0)<1){z=0;A=x}else{v=x+1|0;c[g>>2]=v;z=a[x]|0;A=v}a[h]=z;u=A}if((s-u|0)<2){B=0;break}c[g>>2]=u+2;s=u;B=(d[s]|d[s+1|0]<<8)<<16>>16&65535}else{B=m}}while(0);s=a[f+(B&1)|0]|0;v=c[q>>2]|0;c[q>>2]=v+1;a[v]=s;s=a[f+(B>>>1&1)|0]|0;v=c[q>>2]|0;c[q>>2]=v+1;a[v]=s;s=a[f+(B>>>2&1)|0]|0;v=c[q>>2]|0;c[q>>2]=v+1;a[v]=s;s=a[f+(B>>>3&1)|0]|0;v=c[q>>2]|0;c[q>>2]=v+1;a[v]=s;s=B>>>4;v=c[o>>2]|0;y=c[q>>2]|0;if((p|0)==7){c[q>>2]=y+(v*-7|0);p=p+1|0;m=s;continue}else{c[q>>2]=y+(v-4);v=p+1|0;if((v|0)<16){p=v;m=s;continue}else{n=0;break}}}i=e;return n|0}if((k-r|0)<4){C=0;D=r}else{m=r+4|0;c[g>>2]=m;p=r;C=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;D=m}if((k-D|0)<1){E=0;F=D}else{m=D+1|0;c[g>>2]=m;E=a[D]|0;F=m}m=f+2|0;a[m]=E;if((k-F|0)<1){G=0}else{c[g>>2]=F+1;G=d[F]|0}F=G&255;k=f+3|0;a[k]=F;D=b+256|0;if((E&255)>>>0>G>>>0){G=b+260|0;p=0;r=C;while(1){do{if((p|0)==4){a[l]=E;a[h]=F;q=c[g>>2]|0;if(((c[j>>2]|0)-q|0)<4){H=0;break}c[g>>2]=q+4;o=q;H=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0}else{H=r}}while(0);o=a[f+(H&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>1&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>2&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>3&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>4&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>5&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>6&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>7&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;c[D>>2]=(c[D>>2]|0)+(c[G>>2]|0);o=p+1|0;if((o|0)<8){p=o;r=H>>>8}else{n=0;break}}i=e;return n|0}H=b+264|0;b=0;r=C;C=c[D>>2]|0;a:while(1){p=a[f+(r&1)|0]|0;c[D>>2]=C+1;a[C]=p;p=a[f+(r>>>1&1)|0]|0;G=c[D>>2]|0;c[D>>2]=G+1;a[G]=p;p=a[f+(r>>>2&1)|0]|0;G=c[D>>2]|0;c[D>>2]=G+1;a[G]=p;p=a[f+(r>>>3&1)|0]|0;G=c[D>>2]|0;c[D>>2]=G+1;a[G]=p;p=r>>>4;G=c[H>>2]|0;F=c[D>>2]|0;E=F+(G-4)|0;c[D>>2]=E;do{if((b|0)==7){o=F+(G*-7|0)|0;c[D>>2]=o;a[l]=a[m]|0;a[h]=a[k]|0;q=c[g>>2]|0;if(((c[j>>2]|0)-q|0)<4){b=b+1|0;r=0;C=o;continue a}else{c[g>>2]=q+4;B=q;I=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;J=o;break}}else{I=p;J=E}}while(0);E=b+1|0;if((E|0)<16){b=E;r=I;C=J}else{n=0;break}}i=e;return n|0}function _Ha(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+8|0;f=e|0;g=f;h=b+232|0;j=c[h>>2]|0;k=b+236|0;l=c[k>>2]|0;m=l;if((m-j|0)>>>0<8>>>0){yDb(c[b>>2]|0,16,1895088,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=e;return o|0}n=j;c[f>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+4|0;c[h>>2]=n;if((d[f]|0)>>>0>(d[g+1|0]|0)>>>0){if((m-n|0)<8){p=0;q=0}else{c[h>>2]=j+12;f=n;r=f|0;s=f+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0}if((d[g+2|0]|0)>>>0>(d[g+3|0]|0)>>>0){r=b+264|0;s=b+256|0;f=0;t=p;u=q;v=c[r>>2]|0;w=c[s>>2]|0;while(1){x=a[g+(u&3)|0]|0;a[w+v|0]=x;a[c[s>>2]|0]=x;x=a[g+((u>>>2|t<<30)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+1)|0]=x;a[(c[s>>2]|0)+1|0]=x;x=a[g+((u>>>4|t<<28)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+2)|0]=x;a[(c[s>>2]|0)+2|0]=x;x=a[g+((u>>>6|t<<26)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+3)|0]=x;a[(c[s>>2]|0)+3|0]=x;x=a[g+((u>>>8|t<<24)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+4)|0]=x;a[(c[s>>2]|0)+4|0]=x;x=a[g+((u>>>10|t<<22)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+5)|0]=x;a[(c[s>>2]|0)+5|0]=x;x=a[g+((u>>>12|t<<20)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+6)|0]=x;a[(c[s>>2]|0)+6|0]=x;x=a[g+((u>>>14|t<<18)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+7)|0]=x;a[(c[s>>2]|0)+7|0]=x;x=u>>>16|t<<16;y=c[r>>2]|0;z=(c[s>>2]|0)+(y<<1)|0;c[s>>2]=z;A=f+2|0;if((A|0)<8){f=A;t=t>>>16|0<<16;u=x;v=y;w=z}else{o=0;break}}i=e;return o|0}else{w=b+256|0;v=b+264|0;u=0;t=p;p=q;q=c[w>>2]|0;while(1){f=a[g+(p&3)|0]|0;a[q+1|0]=f;a[c[w>>2]|0]=f;f=a[g+((p>>>2|t<<30)&3)|0]|0;a[(c[w>>2]|0)+3|0]=f;a[(c[w>>2]|0)+2|0]=f;f=a[g+((p>>>4|t<<28)&3)|0]|0;a[(c[w>>2]|0)+5|0]=f;a[(c[w>>2]|0)+4|0]=f;f=a[g+((p>>>6|t<<26)&3)|0]|0;a[(c[w>>2]|0)+7|0]=f;a[(c[w>>2]|0)+6|0]=f;f=p>>>8|t<<24;s=(c[w>>2]|0)+(c[v>>2]|0)|0;c[w>>2]=s;r=u+1|0;if((r|0)<8){u=r;t=t>>>8|0<<24;p=f;q=s}else{o=0;break}}i=e;return o|0}}if((d[g+2|0]|0)>>>0>(d[g+3|0]|0)>>>0){if((m-n|0)<4){B=0}else{c[h>>2]=j+8;j=n;B=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0}j=b+264|0;m=b+256|0;q=0;p=B;B=c[j>>2]|0;t=c[m>>2]|0;while(1){u=a[g+(p&3)|0]|0;a[t+(B+1)|0]=u;a[(c[m>>2]|0)+(c[j>>2]|0)|0]=u;a[(c[m>>2]|0)+1|0]=u;a[c[m>>2]|0]=u;u=a[g+(p>>>2&3)|0]|0;a[(c[m>>2]|0)+((c[j>>2]|0)+3)|0]=u;a[(c[m>>2]|0)+((c[j>>2]|0)+2)|0]=u;a[(c[m>>2]|0)+3|0]=u;a[(c[m>>2]|0)+2|0]=u;u=a[g+(p>>>4&3)|0]|0;a[(c[m>>2]|0)+((c[j>>2]|0)+5)|0]=u;a[(c[m>>2]|0)+((c[j>>2]|0)+4)|0]=u;a[(c[m>>2]|0)+5|0]=u;a[(c[m>>2]|0)+4|0]=u;u=a[g+(p>>>6&3)|0]|0;a[(c[m>>2]|0)+((c[j>>2]|0)+7)|0]=u;a[(c[m>>2]|0)+((c[j>>2]|0)+6)|0]=u;a[(c[m>>2]|0)+7|0]=u;a[(c[m>>2]|0)+6|0]=u;u=c[j>>2]|0;w=(c[m>>2]|0)+(u<<1)|0;c[m>>2]=w;v=q+2|0;if((v|0)<8){q=v;p=p>>>8;B=u;t=w}else{o=0;break}}i=e;return o|0}t=b+256|0;B=b+260|0;b=1;p=l;l=n;while(1){if((p-l|0)<2){C=0}else{c[h>>2]=l+2;n=l;C=(d[n]|d[n+1|0]<<8)<<16>>16&65535}n=a[g+(C&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>2&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>4&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>6&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>8&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>10&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>12&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>14)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;c[t>>2]=(c[t>>2]|0)+(c[B>>2]|0);if((b|0)>=8){o=0;break}b=b+1|0;p=c[k>>2]|0;l=c[h>>2]|0}i=e;return o|0}function $Ha(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;i=i+8|0;f=e|0;g=f|0;h=f;j=b+232|0;k=c[j>>2]|0;l=b+236|0;m=c[l>>2]|0;if((m-k|0)>>>0<16>>>0){yDb(c[b>>2]|0,16,1915616,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=e;return o|0}n=f;p=k;c[f>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=k+4|0;c[j>>2]=p;if(!((d[n]|0)>>>0>(d[h+1|0]|0)>>>0)){q=b+256|0;r=b+264|0;s=0;t=0;while(1){do{if((s&3|0)==0){u=c[l>>2]|0;v=c[j>>2]|0;if((s|0)==0){w=v}else{x=u-v|0;y=x>>>0>4>>>0?4:x;UGb(n|0,v|0,y)|0;x=v+y|0;c[j>>2]=x;w=x}if((u-w|0)<4){z=0;break}c[j>>2]=w+4;u=w;z=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0}else{z=t}}while(0);u=a[h+(z&3)|0]|0;x=c[q>>2]|0;c[q>>2]=x+1;a[x]=u;u=a[h+(z>>>2&3)|0]|0;x=c[q>>2]|0;c[q>>2]=x+1;a[x]=u;u=a[h+(z>>>4&3)|0]|0;x=c[q>>2]|0;c[q>>2]=x+1;a[x]=u;u=a[h+(z>>>6&3)|0]|0;x=c[q>>2]|0;c[q>>2]=x+1;a[x]=u;u=z>>8;x=c[r>>2]|0;y=c[q>>2]|0;if((s|0)==7){c[q>>2]=y+(x*-7|0);s=s+1|0;t=u;continue}else{c[q>>2]=y+(x-4);x=s+1|0;if((x|0)<16){s=x;t=u;continue}else{o=0;break}}}i=e;return o|0}if((m-p|0)<8){A=0;B=0;C=p}else{t=k+12|0;c[j>>2]=t;k=p;p=k|0;s=k+4|0;A=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;B=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;C=t}t=f+4|0;f=t;p=m-C|0;m=p>>>0>4>>>0?4:p;UGb(f|0,C|0,m)|0;c[j>>2]=C+m;m=b+256|0;C=b+260|0;p=b+264|0;if((d[f]|0)>>>0>(d[h+5|0]|0)>>>0){D=0;E=A;F=B}else{f=0;b=A;A=B;a:while(1){B=a[h+(A&3)|0]|0;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=B;B=a[h+((A>>>2|b<<30)&3)|0]|0;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=B;B=a[h+((A>>>4|b<<28)&3)|0]|0;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=B;B=a[h+((A>>>6|b<<26)&3)|0]|0;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=B;B=A>>>8|b<<24;s=b>>>8|0<<24;k=c[p>>2]|0;q=c[m>>2]|0;c[m>>2]=q+(k-4);do{if((f|0)==7){c[m>>2]=q+(k*-7|0);c[g>>2]=c[t>>2];r=c[j>>2]|0;if(((c[l>>2]|0)-r|0)<8){f=f+1|0;b=0;A=0;continue a}else{c[j>>2]=r+8;z=r;r=z|0;w=z+4|0;G=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;H=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;break}}else{G=s;H=B}}while(0);B=f+1|0;if((B|0)<16){f=B;b=G;A=H}else{o=0;break}}i=e;return o|0}while(1){H=a[h+(F&3)|0]|0;A=c[m>>2]|0;c[m>>2]=A+1;a[A]=H;H=a[h+((F>>>2|E<<30)&3)|0]|0;A=c[m>>2]|0;c[m>>2]=A+1;a[A]=H;H=a[h+((F>>>4|E<<28)&3)|0]|0;A=c[m>>2]|0;c[m>>2]=A+1;a[A]=H;H=a[h+((F>>>6|E<<26)&3)|0]|0;A=c[m>>2]|0;c[m>>2]=A+1;a[A]=H;H=F>>>8|E<<24;A=E>>>8|0<<24;if((D&1|0)!=0){c[m>>2]=(c[m>>2]|0)+(c[C>>2]|0)}do{if((D|0)==7){c[g>>2]=c[t>>2];G=c[j>>2]|0;if(((c[l>>2]|0)-G|0)<8){I=0;J=0;break}c[j>>2]=G+8;b=G;G=b|0;f=b+4|0;I=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;J=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0}else{I=A;J=H}}while(0);H=D+1|0;if((H|0)<16){D=H;E=I;F=J}else{o=0;break}}i=e;return o|0}function aIa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+256|0;d=a+236|0;e=a+232|0;f=a+264|0;a=0;g=c[b>>2]|0;h=c[e>>2]|0;do{i=(c[d>>2]|0)-h|0;j=i>>>0>8>>>0?8:i;UGb(g|0,h|0,j)|0;h=(c[e>>2]|0)+j|0;c[e>>2]=h;g=(c[b>>2]|0)+(c[f>>2]|0)|0;c[b>>2]=g;a=a+1|0;}while((a|0)<8);return 0}function bIa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b+236|0;e=b+232|0;f=b+264|0;g=b+256|0;b=0;do{h=c[e>>2]|0;if(((c[d>>2]|0)-h|0)<1){i=0}else{c[e>>2]=h+1;i=a[h]|0}a[(c[g>>2]|0)+((c[f>>2]|0)+1)|0]=i;a[(c[g>>2]|0)+(c[f>>2]|0)|0]=i;a[(c[g>>2]|0)+1|0]=i;a[c[g>>2]|0]=i;h=c[e>>2]|0;if(((c[d>>2]|0)-h|0)<1){j=0}else{c[e>>2]=h+1;j=a[h]|0}a[(c[g>>2]|0)+((c[f>>2]|0)+3)|0]=j;a[(c[g>>2]|0)+((c[f>>2]|0)+2)|0]=j;a[(c[g>>2]|0)+3|0]=j;a[(c[g>>2]|0)+2|0]=j;h=c[e>>2]|0;if(((c[d>>2]|0)-h|0)<1){k=0}else{c[e>>2]=h+1;k=a[h]|0}a[(c[g>>2]|0)+((c[f>>2]|0)+5)|0]=k;a[(c[g>>2]|0)+((c[f>>2]|0)+4)|0]=k;a[(c[g>>2]|0)+5|0]=k;a[(c[g>>2]|0)+4|0]=k;h=c[e>>2]|0;if(((c[d>>2]|0)-h|0)<1){l=0}else{c[e>>2]=h+1;l=a[h]|0}a[(c[g>>2]|0)+((c[f>>2]|0)+7)|0]=l;a[(c[g>>2]|0)+((c[f>>2]|0)+6)|0]=l;a[(c[g>>2]|0)+7|0]=l;a[(c[g>>2]|0)+6|0]=l;c[g>>2]=(c[g>>2]|0)+(c[f>>2]<<1);b=b+2|0;}while((b|0)<8);return 0}function cIa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=b+232|0;f=b+236|0;if(((c[f>>2]|0)-(c[e>>2]|0)|0)>>>0<4>>>0){yDb(c[b>>2]|0,16,1939824,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=d;return h|0}g=b+256|0;j=b+264|0;b=0;k=0;l=0;while(1){do{if((b&3|0)==0){m=c[e>>2]|0;n=c[f>>2]|0;if((n-m|0)<1){o=0;p=m}else{q=m+1|0;c[e>>2]=q;o=a[m]|0;p=q}if((n-p|0)<1){r=o;s=0;break}c[e>>2]=p+1;r=o;s=a[p]|0}else{r=l;s=k}}while(0);TGb(c[g>>2]|0,r|0,4)|0;TGb((c[g>>2]|0)+4|0,s|0,4)|0;c[g>>2]=(c[g>>2]|0)+(c[j>>2]|0);n=b+1|0;if((n|0)<8){b=n;k=s;l=r}else{h=0;break}}i=d;return h|0}function dIa(b,d){b=b|0;d=d|0;var e=0,f=0;d=b+232|0;e=c[d>>2]|0;if(((c[b+236>>2]|0)-e|0)<1){f=0}else{c[d>>2]=e+1;f=a[e]|0}e=b+256|0;d=b+264|0;TGb(c[e>>2]|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;TGb(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;TGb(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;TGb(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;TGb(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;TGb(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;TGb(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;TGb(b|0,f|0,8)|0;c[e>>2]=(c[e>>2]|0)+(c[d>>2]|0);return 0}function eIa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;f=b+232|0;g=c[f>>2]|0;h=c[b+236>>2]|0;if((h-g|0)<1){j=0;k=g}else{l=g+1|0;c[f>>2]=l;j=a[g]|0;k=l}a[e|0]=j;if((h-k|0)<1){m=0}else{c[f>>2]=k+1;m=a[k]|0}a[e+1|0]=m;m=b+256|0;k=b+260|0;b=0;f=c[m>>2]|0;do{h=b&1;j=a[e+h|0]|0;l=a[e+(h^1)|0]|0;c[m>>2]=f+1;a[f]=j;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=l;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=j;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=l;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=j;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=l;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=j;j=c[m>>2]|0;c[m>>2]=j+1;a[j]=l;f=(c[m>>2]|0)+(c[k>>2]|0)|0;c[m>>2]=f;b=b+1|0;}while((b|0)<8);i=d;return 0}function fIa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=a+4|0;e=c[d>>2]|0;if((c[e+688>>2]&1|0)==0){i=b;return}f=c[a+9960>>2]|0;g=(mGb(c[a+9992>>2]|0)|0)<<24>>24;h=c[a+14132>>2]|0;j=1-(c[a+12472>>2]|0)|0;k=(c[a+13788>>2]|0)!=0?2322968:9203408;l=(c[a+13816>>2]|0)!=0?2109544:9203408;m=(c[a+10052>>2]|0)!=0?2051456:9203408;n=(c[a+40>>2]|0)!=0?2006008:9203408;o=(c[a+228>>2]|0)!=0?1968248:9203408;p=(c[a+13828>>2]|0)!=0?1939816:9203408;q=(c[a+13832>>2]|0)!=0?1915608:9203408;r=(c[a+13836>>2]|0)!=0?1895080:9203408;s=(c[a+13824>>2]|0)!=0?2352120:9203408;a=c[d>>2]|0;d=c[a+108>>2]|0;t=c[a+104>>2]|0;yDb(e,48,2272744,(e=i,i=i+120|0,c[e>>2]=f,c[e+8>>2]=g,c[e+16>>2]=h,c[e+24>>2]=j,c[e+32>>2]=k,c[e+40>>2]=l,c[e+48>>2]=m,c[e+56>>2]=n,c[e+64>>2]=o,c[e+72>>2]=p,c[e+80>>2]=q,c[e+88>>2]=r,c[e+96>>2]=s,c[e+104>>2]=d,c[e+112>>2]=t,e)|0);i=e;i=b;return}function gIa(){var a=0;if((c[1888266]|0)!=0){return}c[1850731]=7410952;c[1850733]=72;N_(7402920,6,9,1210736,1,1,1210720,1,1,0,0,0,4)|0;c[1850737]=7410160;c[1850739]=198;N_(7402944,7,28,1210784,1,1,1210752,1,1,0,0,0,4)|0;c[1888269]=7409904;c[1888271]=64;N_(7553072,6,16,1211185,2,1,1211184,2,1,0,0,0,4)|0;c[1167951]=7407752;c[1167953]=538;N_(4671800,9,33,1172137,2,1,1172136,2,1,0,0,0,4)|0;OOa(1210184,7402136);OOa(1148376,7402526);c[302558]=7405536;c[302560]=554;a=c[302548]|0;N_(1210228,9,(c[302546]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[302562]|0)==0){a=0;do{c[1210248+(a<<2)>>2]=7482152+(a*2216|0);a=a+1|0;}while((a|0)<32);POa(1210184)}c[287106]=7403320;c[287108]=554;a=c[287096]|0;N_(1148420,9,(c[287094]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[287110]|0)==0){a=0;do{c[1148440+(a<<2)>>2]=7411240+(a*2216|0);a=a+1|0;}while((a|0)<32);POa(1148376)}c[1283089]=7403e3;c[1283091]=80;N_(5132352,6,15,1210657,2,1,1210656,2,1,0,0,0,4)|0;c[2211059]=7402968;c[2211061]=8;N_(8844232,3,4,1244625,2,1,1244624,2,1,0,0,0,4)|0;c[1888266]=1;return}function hIa(a){a=a|0;var b=0,f=0,g=0,h=0,i=0;b=a+144|0;f=0;while(1){if((f|0)>=6){break}if(((c[b>>2]|0)-1|0)>(e[1191040+(f<<1)>>1]|0|0)){f=f+1|0}else{break}}b=d[1191056+f|0]|0;f=a+14128|0;g=c[f>>2]|0;h=(c[a+14120>>2]|0)+(g>>>3)|0;i=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(g&7)>>>((32-b|0)>>>0);c[f>>2]=g+b;b=c[a+116>>2]|0;c[a+12476>>2]=(i|0)%(b|0)|0;c[a+12480>>2]=(i|0)/(b|0)|0;return i|0}function iIa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+24|0;e=b|0;f=a+48|0;g=(c[f>>2]|0)==13;h=a+14128|0;j=c[h>>2]|0;do{if(g){k=j+1|0;c[h>>2]=k;l=j&7;if((l|0)==7){m=k;break}n=(l^7)+k|0;c[h>>2]=n;m=n}else{m=j}}while(0);j=a+14120|0;h=j|0;n=a+14128|0;k=(c[h>>2]|0)+(m>>>3)|0;do{if(((fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)&-65536>>>((m&7)>>>0)|0)==0){if(g){o=$Ma(c[(c[a+4>>2]|0)+60>>2]|0)|0}else{o=jIa(a)|0}if((o|0)>-1){p=m}else{break}i=b;return p|0}}while(0);m=j;j=a+13712|0;c[m>>2]=c[j>>2];c[m+4>>2]=c[j+4>>2];c[m+8>>2]=c[j+8>>2];c[m+12>>2]=c[j+12>>2];c[m+16>>2]=c[j+16>>2];j=c[n>>2]|0;o=-j&7;if((o|0)==0){q=j}else{g=o+j|0;c[n>>2]=g;q=g}g=(c[a+14132>>2]|0)-q|0;if((g|0)<=27){p=-1;i=b;return p|0}j=e;e=a+4|0;o=g;g=q;while(1){q=(c[h>>2]|0)+(g>>>3)|0;if(((fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)&-65536>>>((g&7)>>>0)|0)==0){c[j>>2]=c[m>>2];c[j+4>>2]=c[m+4>>2];c[j+8>>2]=c[m+8>>2];c[j+12>>2]=c[m+12>>2];c[j+16>>2]=c[m+16>>2];if((c[f>>2]|0)==13){r=$Ma(c[(c[e>>2]|0)+60>>2]|0)|0}else{r=jIa(a)|0}if((r|0)>-1){p=g;s=20;break}c[m>>2]=c[j>>2];c[m+4>>2]=c[j+4>>2];c[m+8>>2]=c[j+8>>2];c[m+12>>2]=c[j+12>>2];c[m+16>>2]=c[j+16>>2];t=c[n>>2]|0}else{t=g}q=t+8|0;c[n>>2]=q;k=o-8|0;if((k|0)>27){o=k;g=q}else{p=-1;s=20;break}}if((s|0)==20){i=b;return p|0}return 0}function jIa(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[a+14120>>2]|0;f=a+14128|0;g=c[f>>2]|0;h=b+(g>>>3)|0;if(((fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)&-65536>>>((g&7)>>>0)|0)!=0){i=-1;return i|0}h=g+16|0;c[f>>2]=h;g=(c[a+14132>>2]|0)-h|0;j=h;while(1){if((g|0)<=13){i=-1;k=18;break}h=d[b+(j>>>3)|0]|0;l=j+1|0;c[f>>2]=l;if((h&128>>>((j&7)>>>0)|0)==0){g=g-1|0;j=l}else{break}}if((k|0)==18){return i|0}if((g|0)<14){i=-1;return i|0}g=b+(l>>>3)|0;do{if((c[a+13824>>2]|0)==0){k=g;h=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(l&7)>>>27;c[a+12476>>2]=0;k=ba(h,c[a+13784>>2]|0)|0;c[a+12480>>2]=k;h=j+8|0;c[f>>2]=h;m=b+(h>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(h&7)>>>27;c[f>>2]=j+13;c[a+9960>>2]=n;o=k;p=n}else{n=d[g]|0;k=j+2|0;c[f>>2]=k;if((n&128>>>((l&7)>>>0)|0)==0){i=-1;return i|0}n=a+144|0;h=0;while(1){if((h|0)>=6){break}if(((c[n>>2]|0)-1|0)>(e[1191040+(h<<1)>>1]|0|0)){h=h+1|0}else{break}}m=d[1191056+h|0]|0;q=b+(k>>>3)|0;r=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(k&7)>>>((32-m|0)>>>0);q=k+m|0;c[f>>2]=q;m=c[a+116>>2]|0;c[a+12476>>2]=(r|0)%(m|0)|0;s=(r|0)/(m|0)|0;c[a+12480>>2]=s;do{if((c[n>>2]|0)>1583){m=d[b+(q>>>3)|0]|0;r=q+1|0;c[f>>2]=r;if((m&128>>>((q&7)>>>0)|0)==0){i=-1}else{t=r;break}return i|0}else{t=q}}while(0);q=b+(t>>>3)|0;n=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(t&7)>>>27;q=t+5|0;c[f>>2]=q;c[a+9960>>2]=n;k=d[b+(q>>>3)|0]|0;c[f>>2]=t+6;if((k&128>>>((q&7)>>>0)|0)==0){i=-1;return i|0}else{c[f>>2]=t+8;o=s;p=n;break}}}while(0);if((o|0)>=(c[a+120>>2]|0)){i=-1;return i|0}i=((p|0)==0)<<31>>31;return i|0}function kIa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=c[1167951]|0;h=a+14128|0;i=c[h>>2]|0;j=c[a+14120>>2]|0;k=j+(i>>>3)|0;l=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(i&7)>>>23;k=b[g+(l<<2)>>1]|0;m=b[g+(l<<2)+2>>1]|0;l=m<<16>>16;if(m<<16>>16<0){m=i+9|0;n=j+(m>>>3)|0;o=((fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(m&7)>>>((l+32|0)>>>0))+k|0;p=b[g+(o<<2)+2>>1]|0;q=m;r=b[g+(o<<2)>>1]|0}else{p=l;q=i;r=k}k=p+q|0;c[h>>2]=k;if((r|0)==0){s=e;return s|0}if((r|0)<0){s=65535;return s|0}q=d[j+(k>>>3)|0]|0;p=k+1|0;c[h>>2]=p;i=f-1|0;if((i|0)==0){t=r}else{l=j+(p>>>3)|0;j=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(p&7)>>>((33-f|0)>>>0);c[h>>2]=k+f;t=(j|r-1<<i)+1|0}i=((q&128>>>((k&7)>>>0)|0)==0?t:-t|0)+e|0;if((c[a+10052>>2]|0)==0){a=27-f|0;s=i<<a>>a;return s|0}a=(e|0)<-31&(i|0)<-63?i+64|0:i;if(!((e|0)>32&(a|0)>63)){s=a;return s|0}s=a-64|0;return s|0}function lIa(a){a=a|0;var b=0,e=0,f=0;b=a+8|0;e=c[b>>2]|0;f=(d[(c[a>>2]|0)+(e>>>3)|0]|0)<<(e&7)>>>7;c[b>>2]=e+1;return f&1|0}function mIa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;f=i;i=i+232|0;g=f|0;h=f+128|0;j=f+152|0;k=f+176|0;l=f+184|0;m=f+192|0;n=f+200|0;o=f+208|0;p=f+216|0;q=f+224|0;r=a+12476|0;s=c[r>>2]|0;t=a+12480|0;u=c[t>>2]|0;v=a+124|0;w=(ba(c[v>>2]|0,u)|0)+s|0;c[q>>2]=0;x=a+9992|0;y=c[x>>2]|0;a:do{if((y|0)==3){z=c[a+128>>2]|0;A=(ba(u,z)|0)+s<<1;B=c[a+9148>>2]|0;C=c[a+9152>>2]|0;D=z<<1;z=D+3|0;b[C+(A<<2)+(z<<1)>>1]=0;E=D|1;b[C+(A<<2)+(E<<1)>>1]=0;b[C+(A<<2)+6>>1]=0;b[C+(A<<2)+2>>1]=0;F=D+2|0;b[C+(A<<2)+(F<<1)>>1]=0;b[C+(A<<2)+(D<<1)>>1]=0;b[C+(A<<2)+4>>1]=0;b[C+(A<<2)>>1]=0;b[B+(A<<2)+(z<<1)>>1]=0;b[B+(A<<2)+(E<<1)>>1]=0;b[B+(A<<2)+6>>1]=0;b[B+(A<<2)+2>>1]=0;b[B+(A<<2)+(F<<1)>>1]=0;b[B+(A<<2)+(D<<1)>>1]=0;b[B+(A<<2)+4>>1]=0;b[B+(A<<2)>>1]=0;A=a+14128|0;B=a+14120|0;C=c[1283089]|0;G=c[B>>2]|0;H=c[A>>2]|0;do{I=G+(H>>>3)|0;J=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(H&7)>>>26;I=b[C+(J<<2)>>1]|0;K=b[C+(J<<2)+2>>1]|0;J=K<<16>>16;if(K<<16>>16<0){K=H+6|0;L=G+(K>>>3)|0;M=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(K&7)>>>((J+32|0)>>>0))+I|0;N=b[C+(M<<2)+2>>1]|0;O=K;P=b[C+(M<<2)>>1]|0}else{N=J;O=H;P=I}H=N+O|0;c[A>>2]=H;if((P|0)<0){Q=48;break}R=c[985016+(P<<2)>>2]|0;}while((P|0)==12);if((Q|0)==48){yDb(c[a+4>>2]|0,16,2200776,(S=i,i=i+16|0,c[S>>2]=s,c[S+8>>2]=u,S)|0);i=S;T=-1;i=f;return T|0}H=a+12488|0;c[H>>2]=R&7;do{if((28086>>>(P>>>0)&1|0)==0){U=0}else{me[c[a+10096>>2]&511](c[a+14340>>2]|0);C=c[2211059]|0;G=c[A>>2]|0;I=c[B>>2]|0;J=I+(G>>>3)|0;M=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(G&7)>>>29;J=b[C+(M<<2)>>1]|0;K=(b[C+(M<<2)+2>>1]|0)+G|0;c[A>>2]=K;if((c[H>>2]|0)!=0){V=J;W=R&65536;Q=71;break a}G=c[1888269]|0;M=I+(K>>>3)|0;I=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>26;M=b[G+(I<<2)>>1]|0;C=M<<16>>16;c[A>>2]=(b[G+(I<<2)+2>>1]|0)+K;if(!(M<<16>>16<0)){M=J&3;J=(c[a+13828>>2]|0)!=0&(M|0)==3;U=(J?C:C^15)<<2|(J?3:M);break}M=c[t>>2]|0;yDb(c[a+4>>2]|0,16,2192344,(S=i,i=i+16|0,c[S>>2]=c[r>>2],c[S+8>>2]=M,S)|0);i=S;T=-1;i=f;return T|0}}while(0);if((18724>>>(P>>>0)&1|0)!=0){oIa(a)}A=a+11736|0;do{if(P>>>0<3>>>0){c[A>>2]=7;X=VMa(a,0,0)|0|R}else{c[A>>2]=0;c[a+11740>>2]=0;if((3647>>>(P>>>0)&1|0)!=0){H=Bca(a,0,0,o,p)|0;c[A>>2]=1;c[o>>2]=kIa(a,c[o>>2]|0,1)|0;B=kIa(a,c[p>>2]|0,1)|0;c[p>>2]=B;M=c[o>>2]|0;c[a+11744>>2]=M;c[a+11748>>2]=B;J=M&65535;b[H+(F<<1)>>1]=J;b[H+(D<<1)>>1]=J;b[H+4>>1]=J;b[H>>1]=J;J=B&65535;b[H+(z<<1)>>1]=J;b[H+(E<<1)>>1]=J;b[H+6>>1]=J;b[H+2>>1]=J}if((4039>>>(P>>>0)&1|0)==0){X=R;break}J=Bca(a,0,1,o,p)|0;c[A>>2]=c[A>>2]|2;c[o>>2]=kIa(a,c[o>>2]|0,1)|0;H=kIa(a,c[p>>2]|0,1)|0;c[p>>2]=H;B=c[o>>2]|0;c[a+11776>>2]=B;c[a+11780>>2]=H;M=B&65535;b[J+(F<<1)>>1]=M;b[J+(D<<1)>>1]=M;b[J+4>>1]=M;b[J>>1]=M;M=H&65535;b[J+(z<<1)>>1]=M;b[J+(E<<1)>>1]=M;b[J+6>>1]=M;b[J+2>>1]=M;X=R}}while(0);c[(c[a+9160>>2]|0)+(w<<2)>>2]=X;Y=U;Q=85}else if((y|0)==2){E=a+14120|0;z=a+14128|0;D=E|0;F=c[D>>2]|0;A=c[z>>2]|0;while(1){M=d[F+(A>>>3)|0]|0;J=A+1|0;c[z>>2]=J;if((M&128>>>((A&7)>>>0)|0)!=0){Q=5;break}M=c[1850737]|0;H=F+(J>>>3)|0;B=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7)>>>25;H=b[M+(B<<2)>>1]|0;C=b[M+(B<<2)+2>>1]|0;B=C<<16>>16;if(C<<16>>16<0){C=A+8|0;K=F+(C>>>3)|0;I=((fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(C&7)>>>((B+32|0)>>>0))+H|0;Z=b[M+(I<<2)+2>>1]|0;_=C;$=b[M+(I<<2)>>1]|0}else{Z=B;_=J;$=H}H=Z+_|0;c[z>>2]=H;if(($|0)<0){Q=9;break}if(($|0)==20){A=H}else{Q=11;break}}if((Q|0)==5){c[a+12488>>2]=0;TGb(a+180|0,-1|0,24)|0;c[a+11736>>2]=1;c[a+11740>>2]=0;c[(c[a+9160>>2]|0)+(w<<2)>>2]=14344;c[a+11744>>2]=0;c[a+11748>>2]=0;c[a+9924>>2]=(c[a+13836>>2]|c[a+13788>>2]|0)==0;break}else if((Q|0)==9){yDb(c[a+4>>2]|0,16,2209416,(S=i,i=i+16|0,c[S>>2]=s,c[S+8>>2]=u,S)|0);i=S;T=-1;i=f;return T|0}else if((Q|0)==11){me[c[a+10096>>2]&511](c[a+14340>>2]|0);A=$&8;F=$&4;c[a+12488>>2]=F>>>2;if((F|0)!=0){V=$;W=A;Q=71;break}F=c[a+36>>2]|0;do{if((F|0)==0){aa=0}else{H=c[z>>2]|0;J=d[(c[D>>2]|0)+(H>>>3)|0]|0;c[z>>2]=H+1;if((J&128>>>((H&7)>>>0)|0)==0){aa=0;break}aa=nIa(E,F,q)|0}}while(0);F=c[1888269]|0;E=c[z>>2]|0;H=(c[D>>2]|0)+(E>>>3)|0;J=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(E&7)>>>26;H=b[F+(J<<2)>>1]|0;c[z>>2]=(b[F+(J<<2)+2>>1]|0)+E;E=$&3;J=(c[a+13828>>2]|0)!=0&(E|0)==3;F=(J?H:H^15)<<2|(J?3:E);if((A|0)!=0){oIa(a)}c[a+11736>>2]=1;E=(c[a+9160>>2]|0)+(w<<2)|0;if(($&16|0)==0){c[E>>2]=12296;c[a+11740>>2]=0;Bca(a,0,0,m,n)|0;J=a+13816|0;H=c[m>>2]|0;if((c[J>>2]|0)==0){ca=kIa(a,H,1)|0}else{ca=pIa(a,H)|0}c[o>>2]=ca;if((ca|0)>65534){T=-1;i=f;return T|0}H=c[n>>2]|0;if((c[J>>2]|0)==0){da=kIa(a,H,1)|0}else{da=pIa(a,H)|0}c[p>>2]=da;if((da|0)>65534){T=-1;i=f;return T|0}H=c[o>>2]|0;c[a+11744>>2]=H;c[a+11748>>2]=da;if((c[J>>2]|0)==0){ea=F;fa=aa;Q=84;break}if((H-(c[m>>2]|0)|0)!=1){ea=F;fa=aa;Q=84;break}if((da-(c[n>>2]|0)|0)!=1){ea=F;fa=aa;Q=84;break}c[z>>2]=(c[z>>2]|0)+1;ea=F;fa=aa;Q=84;break}c[E>>2]=12352;c[a+11740>>2]=1;E=a+13816|0;H=0;while(1){J=Bca(a,H,0,m,n)|0;B=c[m>>2]|0;if((c[E>>2]|0)==0){ga=kIa(a,B,1)|0}else{ga=pIa(a,B)|0}c[o>>2]=ga;if((ga|0)>65534){T=-1;Q=138;break}B=c[n>>2]|0;if((c[E>>2]|0)==0){ha=kIa(a,B,1)|0}else{ha=pIa(a,B)|0}c[p>>2]=ha;if((ha|0)>65534){T=-1;Q=138;break}B=c[o>>2]|0;c[a+11744+(H<<3)>>2]=B;c[a+11744+(H<<3)+4>>2]=ha;do{if((c[E>>2]|0)!=0){if((B-(c[m>>2]|0)|0)!=1){break}if((ha-(c[n>>2]|0)|0)!=1){break}c[z>>2]=(c[z>>2]|0)+1}}while(0);b[J>>1]=B;b[J+2>>1]=ha;I=H+1|0;if((I|0)<4){H=I}else{ea=F;fa=aa;Q=84;break a}}if((Q|0)==138){i=f;return T|0}}}else{F=a+14128|0;H=c[1850731]|0;z=c[a+14120>>2]|0;E=c[F>>2]|0;while(1){A=z+(E>>>3)|0;D=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(E&7)>>>26;A=b[H+(D<<2)>>1]|0;I=b[H+(D<<2)+2>>1]|0;D=I<<16>>16;if(I<<16>>16<0){I=E+6|0;M=z+(I>>>3)|0;C=((fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(I&7)>>>((D+32|0)>>>0))+A|0;ia=b[H+(C<<2)+2>>1]|0;ja=I;ka=b[H+(C<<2)>>1]|0}else{ia=D;ja=E;ka=A}A=ia+ja|0;c[F>>2]=A;if((ka|0)<0){break}if((ka|0)==8){E=A}else{Q=70;break}}if((Q|0)==70){me[c[a+10096>>2]&511](c[a+14340>>2]|0);c[a+12488>>2]=1;V=ka;W=ka&4;Q=71;break}yDb(c[a+4>>2]|0,16,2176048,(S=i,i=i+16|0,c[S>>2]=s,c[S+8>>2]=u,S)|0);i=S;T=-1;i=f;return T|0}}while(0);if((Q|0)==71){u=(c[a+9160>>2]|0)+(w<<2)|0;c[u>>2]=1;do{if((c[a+228>>2]|0)==0){c[a+176>>2]=0}else{w=a+14128|0;s=c[w>>2]|0;ka=c[a+14120>>2]|0;ja=d[ka+(s>>>3)|0]<<(s&7)>>>7;c[w>>2]=s+1;s=ja&1;c[a+176>>2]=s;if((s|0)==0){break}c[u>>2]=513;s=c[w>>2]|0;ja=d[ka+(s>>>3)|0]<<(s&7)>>>7;c[w>>2]=s+1;c[a+13820>>2]=ja&1}}while(0);u=a+36|0;ja=c[u>>2]|0;do{if((ja|0)==0){la=0;ma=a+14128|0}else{s=a+14120|0;w=a+14128|0;ka=c[w>>2]|0;ia=d[(c[s>>2]|0)+(ka>>>3)|0]|0;c[w>>2]=ka+1;if((ia&128>>>((ka&7)>>>0)|0)==0){la=0;ma=w;break}la=nIa(s,ja,q)|0;ma=w}}while(0);ja=c[1888269]|0;w=c[ma>>2]|0;s=(c[a+14120>>2]|0)+(w>>>3)|0;ka=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7)>>>26;s=b[ja+(ka<<2)>>1]|0;c[ma>>2]=(b[ja+(ka<<2)+2>>1]|0)+w;if(s<<16>>16<0){w=c[t>>2]|0;yDb(c[a+4>>2]|0,16,2165504,(S=i,i=i+16|0,c[S>>2]=c[r>>2],c[S+8>>2]=w,S)|0);i=S;T=-1;i=f;return T|0}if((W|0)!=0){oIa(a)}ea=s<<16>>16<<2|V&3;fa=((c[u>>2]|0)!=0)+la|0;Q=84}do{if((Q|0)==84){if((fa|0)==0){Y=ea;Q=85;break}else{na=fa}while(1){la=na-1|0;kIa(a,0,1)|0;kIa(a,0,1)|0;if((la|0)==0){Y=ea;Q=85;break}else{na=la}}}}while(0);do{if((Q|0)==85){if((qIa(a,e|0,0,Y&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,e+128|0,1,Y<<1&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,e+256|0,2,Y<<2&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,e+384|0,3,Y<<3&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,e+512|0,4,Y<<4&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,e+640|0,5,Y<<5&32)|0)<0){T=-1;i=f;return T|0}do{if((c[a+36>>2]|0)!=0){na=c[q>>2]|0;ea=h;fa=g|0;la=a+12488|0;u=c[la>>2]|0;V=a+180|0;c[ea>>2]=c[V>>2];c[ea+4>>2]=c[V+4>>2];c[ea+8>>2]=c[V+8>>2];c[ea+12>>2]=c[V+12>>2];c[ea+16>>2]=c[V+16>>2];c[ea+20>>2]=c[V+20>>2];c[la>>2]=0;if((qIa(a,fa,0,na&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,fa,1,na<<1&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,fa,2,na<<2&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,fa,3,na<<3&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,fa,4,na<<4&32)|0)<0){T=-1;i=f;return T|0}if((qIa(a,fa,5,na<<5&32)|0)<0){T=-1;i=f;return T|0}else{c[la>>2]=u;c[V>>2]=c[ea>>2];c[V+4>>2]=c[ea+4>>2];c[V+8>>2]=c[ea+8>>2];c[V+12>>2]=c[ea+12>>2];c[V+16>>2]=c[ea+16>>2];c[V+20>>2]=c[ea+20>>2];break}}}while(0);if((c[a+13788>>2]|0)==0){break}if((c[a+12488>>2]|0)!=0){break}if((c[x>>2]|0)!=2){break}ea=(c[r>>2]|0)+1|0;if((ea|0)>=(c[a+116>>2]|0)){break}if((c[a+13732>>2]|0)==1){break}V=j;u=a+14120|0;la=u;c[V>>2]=c[la>>2];c[V+4>>2]=c[la+4>>2];c[V+8>>2]=c[la+8>>2];c[V+12>>2]=c[la+12>>2];c[V+16>>2]=c[la+16>>2];na=ba(c[v>>2]|0,c[t>>2]|0)|0;fa=c[a+128>>2]|0;s=a+12496|0;W=(c[s>>2]|0)+2|0;c[s>>2]=W;S=a+12500|0;c[S>>2]=(c[S>>2]|0)+2;w=a+12504|0;c[w>>2]=(c[w>>2]|0)+2;ka=a+12508|0;c[ka>>2]=(c[ka>>2]|0)+2;ja=na+ea|0;na=fa<<1;fa=a+12512|0;c[fa>>2]=(c[fa>>2]|0)+1;ma=a+12516|0;c[ma>>2]=(c[ma>>2]|0)+1;c[r>>2]=ea;ea=a+14128|0;ia=c[u>>2]|0;u=c[ea>>2]|0;while(1){aa=d[ia+(u>>>3)|0]|0;ha=u+1|0;c[ea>>2]=ha;if((aa&128>>>((u&7)>>>0)|0)!=0){Q=102;break}aa=c[1850737]|0;n=ia+(ha>>>3)|0;m=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(ha&7)>>>25;n=b[aa+(m<<2)>>1]|0;o=b[aa+(m<<2)+2>>1]|0;m=o<<16>>16;if(o<<16>>16<0){o=u+8|0;p=ia+(o>>>3)|0;ga=((fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(o&7)>>>((m+32|0)>>>0))+n|0;oa=b[aa+(ga<<2)+2>>1]|0;pa=o;qa=b[aa+(ga<<2)>>1]|0}else{oa=m;pa=ha;qa=n}ra=oa+pa|0;c[ea>>2]=ra;if((qa|0)==20){u=ra}else{Q=106;break}}do{if((Q|0)==102){u=c[a+9148>>2]|0;b[u+(W<<2)+(na+2<<1)>>1]=0;b[u+(W<<2)+(na<<1)>>1]=0;b[u+(W<<2)+4>>1]=0;b[u+(W<<2)>>1]=0;b[u+(W<<2)+(na+3<<1)>>1]=0;b[u+(W<<2)+((na|1)<<1)>>1]=0;b[u+(W<<2)+6>>1]=0;b[u+(W<<2)+2>>1]=0;c[(c[a+9160>>2]|0)+(ja<<2)>>2]=14344}else if((Q|0)==106){if((qa&4|0)!=0){c[(c[a+9160>>2]|0)+(ja<<2)>>2]=1;break}u=c[1888269]|0;n=ia+(ra>>>3)|0;ha=(b[u+((fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(ra&7)>>>26<<2)+2>>1]|0)+ra|0;c[ea>>2]=ha;do{if((qa&8|0)!=0){if((c[a+13832>>2]|0)==0){c[ea>>2]=ha+2;break}n=d[ia+(ha>>>3)|0]|0;c[ea>>2]=ha+1;if((n&128>>>((ha&7)>>>0)|0)==0){c[ea>>2]=ha+6;break}else{c[ea>>2]=ha+2;break}}}while(0);ha=(c[a+9160>>2]|0)+(ja<<2)|0;if((qa&16|0)==0){c[ha>>2]=12296;J=Bca(a,0,0,k,l)|0;B=a+13816|0;n=c[k>>2]|0;if((c[B>>2]|0)==0){sa=(kIa(a,n,1)|0)&65535}else{sa=(pIa(a,n)|0)&65535}n=c[l>>2]|0;if((c[B>>2]|0)==0){ta=(kIa(a,n,1)|0)&65535}else{ta=(pIa(a,n)|0)&65535}b[J+(na+2<<1)>>1]=sa;b[J+(na<<1)>>1]=sa;b[J+4>>1]=sa;b[J>>1]=sa;b[J+(na+3<<1)>>1]=ta;b[J+((na|1)<<1)>>1]=ta;b[J+6>>1]=ta;b[J+2>>1]=ta;break}c[ha>>2]=12352;ha=a+13816|0;J=0;do{n=Bca(a,J,0,k,l)|0;B=c[k>>2]|0;if((c[ha>>2]|0)==0){ua=kIa(a,B,1)|0}else{ua=pIa(a,B)|0}B=c[l>>2]|0;if((c[ha>>2]|0)==0){va=kIa(a,B,1)|0}else{va=pIa(a,B)|0}do{if((c[ha>>2]|0)!=0){if((ua-(c[k>>2]|0)|0)!=1){break}if((va-(c[l>>2]|0)|0)!=1){break}c[ea>>2]=(c[ea>>2]|0)+1}}while(0);b[n>>1]=ua;b[n+2>>1]=va;J=J+1|0;}while((J|0)<4)}}while(0);c[s>>2]=(c[s>>2]|0)-2;c[S>>2]=(c[S>>2]|0)-2;c[w>>2]=(c[w>>2]|0)-2;c[ka>>2]=(c[ka>>2]|0)-2;c[fa>>2]=(c[fa>>2]|0)-1;c[ma>>2]=(c[ma>>2]|0)-1;c[r>>2]=(c[r>>2]|0)-1;c[la>>2]=c[V>>2];c[la+4>>2]=c[V+4>>2];c[la+8>>2]=c[V+8>>2];c[la+12>>2]=c[V+12>>2];c[la+16>>2]=c[V+16>>2];}}while(0);r=c[a+14128>>2]|0;va=(c[a+14120>>2]|0)+(r>>>3)|0;ua=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(r&7)>>>16;va=(c[a+14132>>2]|0)-r|0;if((va|0)<16){wa=ua>>>((16-va|0)>>>0)}else{wa=ua}T=(wa|0)==0?-2:0;i=f;return T|0}function nIa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=a+8|0;do{if((b|0)<3){g=c[f>>2]|0;h=c[a>>2]|0;i=(d[h+(g>>>3)|0]|0)<<(g&7)>>>7;j=g+1|0;c[f>>2]=j;k=i&1;if((b|0)!=2|(k|0)==0){l=1;m=k;break}i=(d[h+(j>>>3)|0]|0)<<(j&7);c[f>>2]=g+2;l=i>>>7&1^1;m=k}else{k=a|0;i=0;while(1){if((i|0)>=4){n=6;break}g=c[f>>2]|0;j=d[(c[k>>2]|0)+(g>>>3)|0]|0;c[f>>2]=g+1;h=i+1|0;if((j&128>>>((g&7)>>>0)|0)==0){o=h;break}else{i=h}}if((n|0)==6){o=i+1|0}l=o>>>1&1;m=o&1}}while(0);if((m|0)==0){return l|0}m=c[f>>2]|0;o=(c[a>>2]|0)+(m>>>3)|0;a=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(m&7)>>>26;c[f>>2]=m+6;c[e>>2]=a;return l|0}function oIa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b+14120|0;f=b+14128|0;g=c[f>>2]|0;if((c[b+13832>>2]|0)==0){h=(c[e>>2]|0)+(g>>>3)|0;i=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(g&7)>>>30;c[f>>2]=g+2;h=b+9960|0;j=(c[h>>2]|0)+(a[985128+i|0]|0)|0;c[h>>2]=j;k=j;cPa(b,k);return}j=c[e>>2]|0;e=d[j+(g>>>3)|0]|0;h=g+1|0;c[f>>2]=h;if((e&128>>>((g&7)>>>0)|0)==0){e=j+(h>>>3)|0;i=(fe(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(h&7)>>>27;c[f>>2]=g+6;c[b+9960>>2]=i;k=i;cPa(b,k);return}else{i=b+9960|0;e=c[i>>2]|0;l=d[j+(h>>>3)|0]<<(h&7)>>>7;c[f>>2]=g+2;g=d[1184288+((l&1)<<5)+e|0]|0;c[i>>2]=g;k=g;cPa(b,k);return}}function pIa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a+14120|0;f=a+14128|0;a=c[f>>2]|0;g=e|0;h=d[(c[g>>2]|0)+(a>>>3)|0]|0;c[f>>2]=a+1;if((h&128>>>((a&7)>>>0)|0)!=0){i=b;return i|0}a=(lIa(e)|0)+2|0;if((lIa(e)|0)==0){j=a}else{h=a;while(1){a=c[f>>2]|0;k=(d[(c[g>>2]|0)+(a>>>3)|0]|0)<<(a&7)>>>7;c[f>>2]=a+1;a=k&1|h<<1;if((lIa(e)|0)==0){j=a;break}else{h=a}}}h=j>>1;i=((j&1|0)!=0?-h|0:h)+b|0;return i|0}function qIa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+48|0;k=j|0;l=j+8|0;m=j+16|0;n=e+14120|0;o=j+24|0;p=n;c[o>>2]=c[p>>2];c[o+4>>2]=c[p+4>>2];c[o+8>>2]=c[p+8>>2];c[o+12>>2]=c[p+12>>2];c[o+16>>2]=c[p+16>>2];q=e+368|0;r=e+228|0;s=(c[e+12488>>2]|0)==0;do{if((c[r>>2]|0)==0){if(s){t=0;u=q;v=1210184;break}a:do{if((c[e+48>>2]|0)==6){do{if((c[e+14028>>2]|0)==3){if((c[e+9992>>2]|0)!=1){break}w=(g|0)<4?0:g-3|0;x=e+9860+(w<<2)|0;y=c[x>>2]|0;c[k>>2]=y;z=e+14032+(w<<2)|0;if((c[z>>2]|0)==0){c[z>>2]=1;A=y&65535;break a}y=aVa(e,g)|0;if((y|0)==65535){B=-1;i=j;return B|0}else{z=(c[k>>2]|0)+y&255;c[k>>2]=z;c[x>>2]=z;A=z&65535;break a}}}while(0);z=e+14128|0;x=c[z>>2]|0;y=(c[n>>2]|0)+(x>>>3)|0;w=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(x&7)>>>24;c[z>>2]=x+8;c[k>>2]=w;if((w|0)!=255){A=w&65535;break}c[k>>2]=128;A=128}else{w=e+14128|0;x=c[w>>2]|0;z=(c[n>>2]|0)+(x>>>3)|0;y=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>24;c[w>>2]=x+8;c[k>>2]=y;do{if((y&127|0)==0){x=c[e+12476>>2]|0;w=c[e+12480>>2]|0;yDb(c[e+4>>2]|0,16,2039848,(C=i,i=i+24|0,c[C>>2]=y,c[C+8>>2]=x,c[C+16>>2]=w,C)|0);i=C;if((c[e+13740>>2]&131074|0)==0){D=c[k>>2]|0;break}else{B=-1;i=j;return B|0}}else{D=y}}while(0);if((D|0)!=255){A=D&65535;break}c[k>>2]=128;A=128}}while(0);b[f>>1]=A;t=1;u=q;v=1210184}else{if(s){t=0;u=q;v=1210184;break}if((c[e+176>>2]|0)==0){t=0;u=q;v=1148376;break}if((c[e+13820>>2]|0)==0){t=0;u=e+500|0;v=1148376;break}else{t=0;u=e+632|0;v=1148376;break}}}while(0);do{if((h|0)==0){if((c[e+12488>>2]|0)!=0){if((c[r>>2]|0)!=0){E=51;break}}c[e+180+(g<<2)>>2]=t-1;B=0;i=j;return B|0}else{q=e+14128|0;s=n|0;A=e+44|0;D=e+48|0;y=e+13828|0;w=e+12488|0;x=e+10092|0;z=t;F=v;b:while(1){G=F+48|0;H=F|0;I=F+12|0;J=F+16|0;K=F+4|0;L=z;while(1){M=c[G>>2]|0;N=c[q>>2]|0;O=c[s>>2]|0;P=O+(N>>>3)|0;Q=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(N&7)>>>23;P=b[M+(Q<<2)>>1]|0;R=b[M+(Q<<2)+2>>1]|0;Q=R<<16>>16;if(R<<16>>16<0){R=N+9|0;S=O+(R>>>3)|0;T=((fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(R&7)>>>((Q+32|0)>>>0))+P|0;U=b[M+(T<<2)+2>>1]|0;V=R;W=b[M+(T<<2)>>1]|0}else{U=Q;V=N;W=P}P=U+V|0;c[q>>2]=P;if((W|0)<0){E=31;break b}do{if((W|0)==(c[H>>2]|0)){if((c[A>>2]|0)>1){dba(n,k,m,l);X=c[m>>2]|0;break}N=d[O+(P>>>3)|0]<<(P&7)>>>7;Q=P+1|0;c[q>>2]=Q;c[l>>2]=N&1;N=O+(Q>>>3)|0;T=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Q&7)>>>26;Q=P+7|0;c[q>>2]=Q;c[m>>2]=T;N=O+(Q>>>3)|0;M=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Q&7);Q=P+15|0;c[q>>2]=Q;N=M>>24;c[k>>2]=N;if(!((N|0)==-128)){X=T;break}N=(c[D>>2]|0)==6;M=O+(Q>>>3)|0;R=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Q&7);if(N){c[q>>2]=P+27;c[k>>2]=R>>20;X=T;break}else{N=R>>>27;R=P+20|0;c[q>>2]=R;c[k>>2]=N;Q=O+(R>>>3)|0;M=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(R&7)>>26;c[q>>2]=P+26;c[k>>2]=M<<5|N;X=T;break}}else{T=a[(c[I>>2]|0)+W|0]|0;c[m>>2]=T;N=a[(c[J>>2]|0)+W|0]|0;c[k>>2]=N;c[l>>2]=(W|0)>=(c[K>>2]|0);M=d[O+(P>>>3)|0]|0;c[q>>2]=P+1;if((M&128>>>((P&7)>>>0)|0)==0){X=T;break}c[k>>2]=-N;X=T}}while(0);Y=X+L|0;if((Y|0)>63){break}b[f+(d[u+Y|0]<<1)>>1]=c[k>>2];if((c[l>>2]|0)!=0){E=49;break b}L=Y+1|0}if(!((c[y>>2]|0)!=0&(F|0)==1210184)){E=46;break}if((c[w>>2]|0)!=0){E=46;break}c[p>>2]=c[o>>2];c[p+4>>2]=c[o+4>>2];c[p+8>>2]=c[o+8>>2];c[p+12>>2]=c[o+12>>2];c[p+16>>2]=c[o+16>>2];me[c[x>>2]&511](f);z=0;F=1148376}if((E|0)==31){F=c[e+12480>>2]|0;yDb(c[e+4>>2]|0,16,2036480,(C=i,i=i+16|0,c[C>>2]=c[e+12476>>2],c[C+8>>2]=F,C)|0);i=C;B=-1;i=j;return B|0}else if((E|0)==46){F=c[e+12480>>2]|0;z=c[w>>2]|0;yDb(c[e+4>>2]|0,16,2032848,(C=i,i=i+24|0,c[C>>2]=c[e+12476>>2],c[C+8>>2]=F,c[C+16>>2]=z,C)|0);i=C;B=-1;i=j;return B|0}else if((E|0)==49){if((c[w>>2]|0)==0){Z=Y;break}if((c[r>>2]|0)==0){Z=Y;break}else{E=51;break}}}}while(0);if((E|0)==51){Aca(e,f,g);Z=63}c[e+180+(g<<2)>>2]=Z;B=0;i=j;return B|0}function rIa(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;g=a+14128|0;h=c[g>>2]|0;j=-h&7;if((j|0)==0){k=h}else{l=j+h|0;c[g>>2]=l;k=l}l=a+14120|0;h=c[l>>2]|0;j=h+(k>>>3)|0;do{if(((fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(k&7)&-1073741824|0)==-2147483648){m=c[a+4>>2]|0;if((c[m+428>>2]|0)!=0){n=k;o=h;break}yDb(m,24,2158864,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=c[g>>2]|0;o=c[l>>2]|0}else{n=k;o=h}}while(0);h=o+(n>>>3)|0;k=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(n&7)>>>18;h=n+14|0;c[g>>2]=h;n=a+14132|0;j=(c[n>>2]|0)-h|0;m=k;k=h;while(1){if((j|0)<=24){q=9;break}h=o+(k>>>3)|0;r=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(k&7)>>>24;h=k+8|0;c[g>>2]=h;s=r|m<<8&4194048;if((s|0)==32){t=h;break}else{j=j-8|0;m=s;k=h}}do{if((q|0)==9){if((m|0)==32){t=k;break}yDb(c[a+4>>2]|0,16,2151808,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}}while(0);k=o+(t>>>3)|0;m=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(t&7)>>>24;k=t+8|0;c[g>>2]=k;j=a+108|0;h=c[j>>2]|0;s=h&-256;c[j>>2]=((s|m|0)<(h|0)?m|256:m)+s;s=d[o+(k>>>3)|0]|0;m=t+9|0;c[g>>2]=m;if((s&128>>>((k&7)>>>0)|0)==0){yDb(c[a+4>>2]|0,16,2144752,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}k=d[o+(m>>>3)|0]|0;c[g>>2]=t+10;if((k&128>>>((m&7)>>>0)|0)!=0){yDb(c[a+4>>2]|0,16,2139168,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}m=t+13|0;c[g>>2]=m;k=o+(m>>>3)|0;s=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(m&7)>>>29;m=t+16|0;c[g>>2]=m;k=a+40|0;do{if((s-6|0)>>>0>1>>>0){c[k>>2]=0;h=b[1210824+(s<<2)>>1]|0;r=e[1210826+(s<<2)>>1]|0;if(h<<16>>16==0){u=-1;i=f;return u|0}v=(d[o+(m>>>3)|0]|0)<<(m&7)>>>7;w=t+17|0;c[g>>2]=w;c[a+9992>>2]=(v&1)+1;v=(d[o+(w>>>3)|0]|0)<<(w&7)>>>7;w=t+18|0;c[g>>2]=w;x=v&1;c[a+10052>>2]=x;v=d[o+(w>>>3)|0]|0;y=t+19|0;c[g>>2]=y;if((v&128>>>((w&7)>>>0)|0)==0){w=(d[o+(y>>>3)|0]|0)<<(y&7)>>>7;y=t+20|0;c[g>>2]=y;v=w&1;c[a+13788>>2]=v;c[a+10048>>2]=(x|0)==0?v:1;v=(d[o+(y>>>3)|0]|0)<<(y&7)>>>7;y=t+21|0;c[g>>2]=y;c[a+36>>2]=v&1;v=o+(y>>>3)|0;x=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(y&7)>>>27;c[a+9960>>2]=x;c[a+9964>>2]=x;c[g>>2]=t+27;x=a+8|0;c[x>>2]=h&65535;c[a+12>>2]=r;r=a+4|0;h=c[r>>2]|0;c[h+224>>2]=12;c[h+228>>2]=11;h=c[r>>2]|0;c[h+104>>2]=1001;c[h+108>>2]=3e4;z=x;break}yDb(c[a+4>>2]|0,16,2132880,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}else{c[k>>2]=1;x=o+(m>>>3)|0;h=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(m&7)>>>29;x=t+19|0;c[g>>2]=x;if((h|0)==0){A=s;B=x;C=o}else if((h|0)==1){q=21}else{yDb(c[a+4>>2]|0,16,2100328,(p=i,i=i+8|0,c[p>>2]=h,p)|0);i=p;u=-1;i=f;return u|0}if((q|0)==21){r=o+(x>>>3)|0;y=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(x&7)>>>29;x=t+22|0;c[g>>2]=x;r=(d[o+(x>>>3)|0]|0)<<(x&7)>>>7;x=t+23|0;c[g>>2]=x;c[a+13840>>2]=r&1;r=(d[o+(x>>>3)|0]|0)<<(x&7)>>>7;x=t+24|0;c[g>>2]=x;v=r&1;r=a+13816|0;c[r>>2]=v;w=d[o+(x>>>3)|0]|0;D=t+25|0;c[g>>2]=D;if((w&128>>>((x&7)>>>0)|0)==0){E=D;G=o;H=v}else{yDb(c[a+4>>2]|0,16,2126448,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;E=c[g>>2]|0;G=c[l>>2]|0;H=c[r>>2]|0}r=(d[G+(E>>>3)|0]|0)<<(E&7)>>>7;v=E+1|0;c[g>>2]=v;D=r&1;c[a+13788>>2]=D;r=(d[G+(v>>>3)|0]|0)<<(v&7)>>>7;v=E+2|0;c[g>>2]=v;c[a+228>>2]=r&1;r=(d[G+(v>>>3)|0]|0)<<(v&7)>>>7;v=E+3|0;c[g>>2]=v;x=r&1;r=a+13836|0;c[r>>2]=x;if((H|0)==0){I=(D|0)==0?x:1}else{I=1}c[a+10048>>2]=I;x=a+4|0;D=c[x>>2]|0;if((c[D+800>>2]|0)!=0){c[r>>2]=0}r=(d[G+(v>>>3)|0]|0)<<(v&7)>>>7;v=E+4|0;c[g>>2]=v;c[a+13824>>2]=r&1;r=d[G+(v>>>3)|0]|0;w=E+5|0;c[g>>2]=w;if((r&128>>>((v&7)>>>0)|0)==0){J=w;K=G}else{yDb(D,16,2120672,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;J=c[g>>2]|0;K=c[l>>2]|0}D=d[K+(J>>>3)|0]|0;w=J+1|0;c[g>>2]=w;if((D&128>>>((J&7)>>>0)|0)==0){L=w;M=K}else{yDb(c[x>>2]|0,16,2114504,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=c[g>>2]|0;M=c[l>>2]|0}x=(d[M+(L>>>3)|0]|0)<<(L&7)>>>7;w=L+1|0;c[g>>2]=w;c[a+13828>>2]=x&1;x=(d[M+(w>>>3)|0]|0)<<(w&7)>>>7;c[g>>2]=L+2;w=x&1;c[a+13832>>2]=w;if((w|0)!=0){c[a+9896>>2]=1211152}w=L+6|0;c[g>>2]=w;A=y;B=w;C=M}w=C+(B>>>3)|0;y=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(B&7)>>>29;c[g>>2]=B+3;w=a+9992|0;c[w>>2]=y;switch(y|0){case 0:{c[w>>2]=1;break};case 1:{c[w>>2]=2;break};case 2:{c[w>>2]=2;c[a+36>>2]=3;break};case 3:{c[w>>2]=3;break};case 7:{c[w>>2]=1;break};default:{u=-1;i=f;return u|0}}w=B+5|0;c[g>>2]=w;c[a+12472>>2]=(d[C+(w>>>3)|0]|0)<<(w&7)>>>7&1;w=B+10|0;c[g>>2]=w;y=(h|0)!=0;do{if(y){do{if((A|0)==6){h=C+(w>>>3)|0;x=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(w&7)>>>28;h=B+14|0;c[g>>2]=h;c[a+13928>>2]=x;D=C+(h>>>3)|0;v=((fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(h&7)>>>23<<2)+4|0;h=B+24|0;c[g>>2]=h;D=C+(h>>>3)|0;r=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(h&7)>>>23;h=B+33|0;c[g>>2]=h;D=r<<2;if((x|0)==15){r=C+(h>>>3)|0;N=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(h&7)>>>24;c[g>>2]=B+41;h=c[a+4>>2]|0;c[h+224>>2]=N;N=c[g>>2]|0;r=C+(N>>>3)|0;O=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(N&7)>>>24;c[g>>2]=N+8;c[h+228>>2]=O;P=v;Q=D;break}else{O=1210392+(x<<3)|0;x=(c[a+4>>2]|0)+224|0;h=c[O+4>>2]|0;c[x>>2]=c[O>>2];c[x+4>>2]=h;P=v;Q=D;break}}else{D=e[1210824+(A<<2)>>1]|0;v=e[1210826+(A<<2)>>1]|0;h=c[a+4>>2]|0;c[h+224>>2]=12;c[h+228>>2]=11;P=D;Q=v}}while(0);v=c[a+4>>2]|0;D=v+228|0;c[D>>2]=c[D>>2]<<c[a+13812>>2];if((P|0)==0|(Q|0)==0){u=-1;i=f;return u|0}c[a+8>>2]=P;c[a+12>>2]=Q;D=a+13840|0;if((c[D>>2]|0)==0){c[v+104>>2]=1001;c[v+108>>2]=3e4;R=D;break}h=v+108|0;c[h>>2]=18e5;x=c[g>>2]|0;O=c[l>>2]|0;N=(d[O+(x>>>3)|0]|0)<<(x&7)>>>7;c[g>>2]=x+1;x=v+104|0;c[x>>2]=N&1|1e3;N=c[g>>2]|0;v=O+(N>>>3)|0;O=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(N&7)>>>25;c[g>>2]=N+7;N=ba(c[x>>2]|0,O)|0;c[x>>2]=N;if((N|0)!=0){O=c[h>>2]|0;v=GDb(O,(O|0)<0|0?-1:0,N,(N|0)<0|0?-1:0)|0;r=v;c[h>>2]=(O|0)/(r|0)|0;c[x>>2]=(N|0)/(r|0)|0;R=D;break}yDb(a,16,2093720,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}else{R=a+13840|0}}while(0);if((c[R>>2]|0)!=0){c[g>>2]=(c[g>>2]|0)+2}do{if(y){do{if((c[a+13816>>2]|0)!=0){w=c[g>>2]|0;D=d[(c[l>>2]|0)+(w>>>3)|0]|0;c[g>>2]=w+1;if((D&128>>>((w&7)>>>0)|0)!=0){break}c[g>>2]=w+2}}while(0);if((c[a+13824>>2]|0)==0){break}w=c[g>>2]|0;D=c[l>>2]|0;r=d[D+(w>>>3)|0]|0;N=w+1|0;c[g>>2]=N;if((r&128>>>((w&7)>>>0)|0)==0){S=N;T=D}else{yDb(c[a+4>>2]|0,16,2088480,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;S=c[g>>2]|0;T=c[l>>2]|0}D=d[T+(S>>>3)|0]|0;c[g>>2]=S+1;if((D&128>>>((S&7)>>>0)|0)==0){break}yDb(c[a+4>>2]|0,16,2083760,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);y=c[g>>2]|0;D=(c[l>>2]|0)+(y>>>3)|0;N=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(y&7)>>>27;c[g>>2]=y+5;c[a+9960>>2]=N;z=a+8|0}}while(0);S=c[z>>2]|0;do{if((S|0)!=0){z=c[a+12>>2]|0;if((z|0)==0){break}T=(S+15|0)/16|0;R=a+116|0;c[R>>2]=T;Q=(z+15|0)/16|0;c[a+120>>2]=Q;z=a+144|0;c[z>>2]=ba(T,Q)|0;if((c[a+36>>2]|0)!=0){Q=c[g>>2]|0;T=Q+3|0;c[g>>2]=T;if((c[a+13840>>2]|0)==0){U=T}else{T=Q+5|0;c[g>>2]=T;U=T}c[g>>2]=U+2}T=a+9992|0;Q=(c[T>>2]|0)==3;P=c[j>>2]|0;A=P;C=(P|0)<0|0?-1:0;P=a+13856|0;c[P>>2]=A;c[P+4>>2]=C;if(Q){Q=a+13872|0;P=b[Q>>1]|0;B=a+13864|0;M=ZGb(A,C,c[B>>2]|0,c[B+4>>2]|0)|0;B=YGb(M,F,P&65535,0)|0;M=a+13874|0;b[M>>1]=B;L=B&65535;if((P&65535)>>>0<=L>>>0|(L|0)==0|P<<16>>16==0){b[Q>>1]=2;b[M>>1]=1}UMa(a)}else{M=a+13864|0;Q=ZGb(A,C,c[M>>2]|0,c[M+4>>2]|0)|0;b[a+13872>>1]=Q;c[M>>2]=A;c[M+4>>2]=C}C=c[g>>2]|0;M=c[n>>2]|0;if((M-C|0)<1){u=-1094995529;i=f;return u|0}A=c[l>>2]|0;Q=C;while(1){C=d[A+(Q>>>3)|0]|0;V=Q+1|0;c[g>>2]=V;if((C&128>>>((Q&7)>>>0)|0)==0){break}C=Q+9|0;c[g>>2]=C;if((M-C|0)<1){u=-1094995529;q=101;break}else{Q=C}}if((q|0)==101){i=f;return u|0}do{if((c[a+13824>>2]|0)!=0){M=d[A+(V>>>3)|0]|0;C=Q+2|0;c[g>>2]=C;if((M&128>>>((V&7)>>>0)|0)==0){yDb(c[a+4>>2]|0,16,2073336,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}else{W=0}while(1){if((W|0)>=6){break}if(((c[z>>2]|0)-1|0)>(e[1191040+(W<<1)>>1]|0|0)){W=W+1|0}else{break}}M=d[1191056+W|0]|0;P=A+(C>>>3)|0;L=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(C&7)>>>((32-M|0)>>>0);P=C+M|0;c[g>>2]=P;M=c[R>>2]|0;c[a+12476>>2]=(L|0)%(M|0)|0;c[a+12480>>2]=(L|0)/(M|0)|0;M=d[A+(P>>>3)|0]|0;c[g>>2]=P+1;if((M&128>>>((P&7)>>>0)|0)!=0){break}yDb(c[a+4>>2]|0,16,2068800,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}}while(0);c[a+11556>>2]=1;A=a+9892|0;if((c[a+228>>2]|0)==0){c[A>>2]=1179688;c[a+9888>>2]=1179688}else{c[A>>2]=1265888;c[a+9888>>2]=1265888}fIa(a);if((c[T>>2]|0)!=1){u=0;i=f;return u|0}if((c[a+88>>2]|0)!=1330075994){u=0;i=f;return u|0}A=c[g>>2]|0;if(((c[n>>2]|0)-A|0)<=758){u=0;i=f;return u|0}R=a+4|0;z=1;Q=c[R>>2]|0;P=A;while(1){A=(d[(c[l>>2]|0)+(P>>>3)|0]|0)<<(P&7)>>>7;c[g>>2]=P+1;yDb(Q,48,2060360,(p=i,i=i+8|0,c[p>>2]=A&1,p)|0);i=p;X=c[R>>2]|0;if((z|0)>=85){break}z=z+1|0;Q=X;P=c[g>>2]|0}yDb(X,48,2055616,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;P=0;while(1){Q=c[g>>2]|0;z=c[l>>2]|0;T=z+(Q>>>3)|0;A=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(Q&7)>>>24;T=Q+8|0;c[g>>2]=T;M=z+(T>>>3)|0;z=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(T&7)>>24;c[g>>2]=Q+16;yDb(c[R>>2]|0,48,2044848,(p=i,i=i+8|0,c[p>>2]=z<<8|A,p)|0);i=p;A=c[g>>2]|0;z=c[l>>2]|0;Q=z+(A>>>3)|0;T=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(A&7)>>>24;Q=A+8|0;c[g>>2]=Q;M=z+(Q>>>3)|0;z=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Q&7)>>24;c[g>>2]=A+16;yDb(c[R>>2]|0,48,2044848,(p=i,i=i+8|0,c[p>>2]=z<<8|T,p)|0);i=p;T=c[g>>2]|0;z=c[l>>2]|0;A=z+(T>>>3)|0;Q=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(T&7)>>>24;A=T+8|0;c[g>>2]=A;M=z+(A>>>3)|0;z=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(A&7)>>24;c[g>>2]=T+16;yDb(c[R>>2]|0,48,2044848,(p=i,i=i+8|0,c[p>>2]=z<<8|Q,p)|0);i=p;yDb(c[R>>2]|0,48,2055616,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Q=P+1|0;if((Q|0)<13){P=Q}else{Y=0;break}}while(1){P=c[R>>2]|0;Q=c[g>>2]|0;z=(d[(c[l>>2]|0)+(Q>>>3)|0]|0)<<(Q&7)>>>7;c[g>>2]=Q+1;yDb(P,48,2060360,(p=i,i=i+8|0,c[p>>2]=z&1,p)|0);i=p;z=Y+1|0;if((z|0)<50){Y=z}else{u=0;break}}i=f;return u|0}}while(0);yDb(c[a+4>>2]|0,16,2078256,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}function sIa(){var b=0,d=0;if(a[1198712]|0){return}else{b=0}do{d=b<<14;c[5015260+(b*20|0)>>2]=6877824+(d<<2);c[5015268+(b*20|0)>>2]=8192;tIa(896160+(b*20|0)|0,5015256+(b*20|0)|0,1)|0;c[5015420+(b*20|0)>>2]=6877824+((d|8192)<<2);c[5015428+(b*20|0)>>2]=8192;tIa(896320+(b*20|0)|0,5015416+(b*20|0)|0,1)|0;b=b+1|0;}while((b|0)<8);a[1198712]=1;return}function tIa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+768|0;j=h|0;k=h+512|0;l=c[e>>2]|0;a:do{if((l|0)>0){m=0;n=0;while(1){o=d[e+4+m|0]|0;p=1<<o;q=(m|0)!=(l-1|0)|0;r=(1<<m)-1<<o+q;if((p|0)<1|(n|0)>255){s=n}else{t=q+m+o|0;u=t&255;o=t&255;t=8-o|0;q=16-o|0;if(o>>>0>13>>>0){break}if(o>>>0<9>>>0){o=0;v=n;while(1){w=k+v|0;a[w]=u;b[j+(v<<1)>>1]=(d[1148864+((o|r)&65535)|0]|0)>>>(t>>>0);if(u<<24>>24==0){a[w]=1}w=v+1|0;x=o+1|0;if((x|0)>=(p|0)|(w|0)>255){s=w;break}else{o=x;v=w}}}else{v=0;o=n;while(1){t=k+o|0;a[t]=u;w=v|r;b[j+(o<<1)>>1]=((d[1148864+(w&255)|0]|0)<<8|(d[1148864+(w>>>8&255)|0]|0))>>>(q>>>0);if(u<<24>>24==0){a[t]=1}t=o+1|0;w=v+1|0;if((w|0)>=(p|0)|(t|0)>255){s=t;break}else{v=w;o=t}}}}o=m+1|0;if((o|0)<(l|0)){m=o;n=s}else{y=s;break a}}a[k+n|0]=u;z=-1094995529;i=h;return z|0}else{y=0}}while(0);z=N_(f,13,y,k|0,1,1,j,2,2,0,0,0,(g|0)!=0?6:2)|0;i=h;return z|0}function uIa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+24|0;k=j|0;if((e|0)==0){c[g+4>>2]=(f|0)!=0?5015556:5015396;l=0;i=j;return l|0}e=b+8|0;m=c[e>>2]|0;n=b+16|0;o=c[n>>2]|0;p=c[b>>2]|0;b=p+(m>>>3)|0;q=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((m&7)>>>0)&7;b=m+3|0;c[e>>2]=o>>>0>b>>>0?b:o;c[g>>2]=q;if((q|0)!=7){c[g+4>>2]=((f|0)==0?5015256:5015416)+(q*20|0);l=0;i=j;return l|0}q=c[e>>2]|0;f=c[n>>2]|0;n=p+(q>>>3)|0;o=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((q&7)>>>0)&15;n=q+4|0;q=f>>>0>n>>>0?n:f;c[e>>2]=q;n=k|0;c[n>>2]=o;if((o|0)==0){yDb(h,16,2271256,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;l=-1094995529;i=j;return l|0}else{s=0;t=q}do{q=p+(t>>>3)|0;o=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((t&7)>>>0);q=t+4|0;t=f>>>0>q>>>0?q:f;c[e>>2]=t;a[k+4+s|0]=o&15;s=s+1|0;u=c[n>>2]|0;}while((s|0)<(u|0));s=g+8|0;n=s|0;do{if((u|0)==(c[n>>2]|0)){t=k+4|0;e=g+12|0;if((PGb(t,e,u)|0)!=0){v=e;w=t;x=12;break}if((c[g+32>>2]|0)==0){v=e;w=t;x=12;break}y=g+28|0}else{v=g+12|0;w=k+4|0;x=12}}while(0);do{if((x|0)==12){c[n>>2]=u;UGb(v|0,w|0,u)|0;k=g+28|0;if((c[g+32>>2]|0)!=0){Q_(k)}t=tIa(s,k,0)|0;if((t|0)==0){y=k;break}c[n>>2]=0;yDb(h,16,2322856,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;l=t;i=j;return l|0}}while(0);c[g+4>>2]=y;l=0;i=j;return l|0}function vIa(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;wIa(f);h=g|0;i=b[h>>1]|0;if(i<<16>>16==0){j=-1094995529;return j|0}k=g+2|0;if((b[k>>1]|0)==0){j=-1094995529;return j|0}l=g+12|0;if((a[l]|0)==0){j=-1094995529;return j|0}m=g+13|0;if((a[m]|0)==0){j=-1094995529;return j|0}b[f>>1]=i;b[f+2>>1]=b[k>>1]|0;i=a[l]|0;a[f+4|0]=i;g=((e[h>>1]|0)+3|0)>>>2&65535;b[f+24>>1]=g;b[f+12>>1]=g;g=((e[k>>1]|0)+3|0)>>>2&65535;b[f+26>>1]=g;b[f+14>>1]=g;g=a[m]|0;a[f+28|0]=g;a[f+16|0]=g;g=0;m=i;a:while(1){i=f+(g*12|0)+4|0;k=cEb((m&255)*332|0)|0;h=k;n=f+(g*12|0)+8|0;c[n>>2]=h;if((k|0)==0){j=-12;o=18;break}k=a[i]|0;p=e[f+(g*12|0)>>1]|0;if(k<<24>>24==1){q=e[f+(g*12|0)+2>>1]|0;r=p;s=0}else{q=((e[f+(g*12|0)+2>>1]|0)+1|0)>>>1;r=(p+1|0)>>>1;s=k<<24>>24==0}k=(g|0)!=0?8:16;p=k-1|0;t=-k|0;k=p+r&t;u=p+q&t;t=ba(u,k)|0;p=t<<1;if(!s){v=t&2147483584;t=0;w=h;do{c[w+(t*332|0)>>2]=g;c[w+(t*332|0)+4>>2]=t;c[w+(t*332|0)+8>>2]=r;c[w+(t*332|0)+12>>2]=q;c[w+(t*332|0)+48>>2]=k;c[w+(t*332|0)+16>>2]=u;h=w+(t*332|0)+36|0;c[h>>2]=cEb(p)|0;x=cEb(p)|0;c[w+(t*332|0)+40>>2]=x;c[w+(t*332|0)+312>>2]=v;if((c[h>>2]|0)==0|(x|0)==0){j=-12;o=18;break a}if((d[l]|0)>>>0>1>>>0){x=cEb(p)|0;c[w+(t*332|0)+44>>2]=x;if((x|0)==0){j=-12;o=18;break a}}w=c[n>>2]|0;c[w+104>>2]=0;t=t+1|0;}while((t|0)<(d[i]|0))}i=g+1|0;if((i|0)>=3){j=0;o=18;break}g=i;m=a[f+(i*12|0)+4|0]|0}if((o|0)==18){return j|0}return 0}function wIa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=0;do{f=b+(e*12|0)+8|0;g=c[f>>2]|0;h=b+(e*12|0)+4|0;a:do{if((g|0)!=0){if((a[h]|0)==0){break}else{i=0;j=g}while(1){$Db(j+(i*332|0)+36|0);$Db((c[f>>2]|0)+(i*332|0)+40|0);$Db((c[f>>2]|0)+(i*332|0)+44|0);k=c[f>>2]|0;if((c[k+(i*332|0)+128>>2]|0)==0){l=k}else{Q_(k+(i*332|0)+124|0);l=c[f>>2]|0}k=l+(i*332|0)+284|0;if((c[l+(i*332|0)+280>>2]|0)>0){m=0;n=k;while(1){$Db((c[n>>2]|0)+(m*40|0)+32|0);o=m+1|0;p=c[f>>2]|0;q=p+(i*332|0)+284|0;if((o|0)<(c[p+(i*332|0)+280>>2]|0)){m=o;n=q}else{r=q;break}}}else{r=k}$Db(r);n=i+1|0;if((n|0)>=(d[h]|0)){break a}i=n;j=c[f>>2]|0}}}while(0);$Db(f);a[h]=0;e=e+1|0;}while((e|0)<3);return}function xIa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;h=b+4|0;j=b+8|0;k=e+3>>2;l=f+3>>2;m=0;a:while(1){if((m|0)==0){n=(a[h]|0)==4;o=f>>(n&1);p=e>>(n&1)}else{o=l;p=k}if((p|0)<1|(o|0)<1){q=-22;r=22;break}n=b+(m*12|0)+4|0;if((a[n]|0)!=0){s=b+(m*12|0)+8|0;t=p-1|0;u=o-1|0;v=0;do{w=c[s>>2]|0;x=w+(v*332|0)+8|0;y=w+(v*332|0)+12|0;z=w+(v*332|0)+280|0;c[z>>2]=ba((u+(c[y>>2]|0)|0)/(o|0)|0,(t+(c[x>>2]|0)|0)/(p|0)|0)|0;A=w+(v*332|0)+284|0;$Db(A);B=cEb((c[z>>2]|0)*40|0)|0;z=B;c[A>>2]=z;if((B|0)==0){q=-12;r=22;break a}B=c[y>>2]|0;if((B|0)>0){A=w+(v*332|0)+56|0;w=(v|m|0)==0;C=c[(c[j>>2]|0)+284>>2]|0;D=0;E=z;z=c[x>>2]|0;F=B;while(1){if((z|0)>0){if(w){B=0;G=E;while(1){c[G>>2]=B;c[G+4>>2]=D;c[G+16>>2]=c[A>>2];H=(c[x>>2]|0)-B|0;I=(H|0)>(p|0)?p:H;c[G+8>>2]=I;H=(c[y>>2]|0)-D|0;J=(H|0)>(o|0)?o:H;c[G+12>>2]=J;c[G+24>>2]=0;c[G+20>>2]=0;H=c[A>>2]|0;K=H-1|0;L=G+28|0;c[L>>2]=ba((K+J|0)/(H|0)|0,(K+I|0)/(H|0)|0)|0;H=G+32|0;$Db(H);I=cEb(c[L>>2]<<4)|0;c[H>>2]=I;if((I|0)==0){q=-12;r=22;break a}c[G+36>>2]=0;I=G+40|0;H=B+p|0;L=c[x>>2]|0;if((H|0)<(L|0)){B=H;G=I}else{M=C;N=I;O=L;break}}}else{G=C;B=0;L=E;while(1){c[L>>2]=B;c[L+4>>2]=D;c[L+16>>2]=c[A>>2];I=(c[x>>2]|0)-B|0;H=(I|0)>(p|0)?p:I;c[L+8>>2]=H;I=(c[y>>2]|0)-D|0;K=(I|0)>(o|0)?o:I;c[L+12>>2]=K;c[L+24>>2]=0;c[L+20>>2]=0;I=c[A>>2]|0;J=I-1|0;P=L+28|0;c[P>>2]=ba((J+K|0)/(I|0)|0,(J+H|0)/(I|0)|0)|0;I=L+32|0;$Db(I);H=cEb(c[P>>2]<<4)|0;c[I>>2]=H;if((H|0)==0){q=-12;r=22;break a}H=L+36|0;c[H>>2]=0;if((c[P>>2]|0)!=(c[G+28>>2]|0)){r=16;break a}c[H>>2]=c[G+32>>2];H=G+40|0;P=L+40|0;I=B+p|0;J=c[x>>2]|0;if((I|0)<(J|0)){G=H;B=I;L=P}else{M=H;N=P;O=J;break}}}Q=M;R=N;S=O;T=c[y>>2]|0}else{Q=C;R=E;S=z;T=F}L=D+o|0;if((L|0)<(T|0)){C=Q;D=L;E=R;z=S;F=T}else{break}}}v=v+1|0;}while((v|0)<(d[n]|0))}n=m+1|0;if((n|0)<3){m=n}else{q=0;r=22;break}}if((r|0)==16){yDb(0,48,2158840,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;q=-1094995529;i=g;return q|0}else if((r|0)==22){i=g;return q|0}return 0}function yIa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0;k=i;i=i+272|0;l=k|0;m=k+8|0;n=k+264|0;o=c[f+60>>2]|0;p=o;q=c[j+24>>2]|0;r=g;s=c[j+28>>2]|0;j=s<<3;t=j>>>0>2147483639>>>0|(q|0)==0;u=t?0:q;v=t?0:j;j=o;c[j>>2]=u;t=o+12|0;c[t>>2]=v;w=o+16|0;c[w>>2]=v+8;c[o+4>>2]=u+(v>>3);v=o+8|0;c[v>>2]=0;u=o+4672|0;c[u>>2]=q;c[o+4680>>2]=s;q=Oe[c[o+4872>>2]&1023](p,f)|0;if((q|0)!=0){yDb(f,16,2186608,(x=i,i=i+8|0,c[x>>2]=q,x)|0);i=x;y=q;i=k;return y|0}if((c[o+4892>>2]|0)!=0){y=-1094995529;i=k;return y|0}if(!((a[o+4864|0]&32)==0)){EDb(f,2109488,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1163346256;i=k;return y|0}q=o+4708|0;z=q;A=q;B=o+4716|0;if((c[B>>2]|0)==0){yDb(f,16,2051376,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=k;return y|0}me[c[o+4884>>2]&511](p);C=o+4888|0;do{if((re[c[C>>2]&4095](p)|0)==0){if((c[o+4664>>2]|0)==0){D=0}else{y=-1094995529;i=k;return y|0}while(1){if((D|0)>=3){E=151;break}if((c[(c[z+(D*12|0)+8>>2]|0)+28>>2]|0)==0){y=-1094995529;E=198;break}else{D=D+1|0}}if((E|0)==151){F=o+4748|0;G=o+4896|0;break}else if((E|0)==198){i=k;return y|0}}else{H=o+4748|0;I=o+4896|0;c[I+(c[H>>2]<<2)>>2]=1;J=o+4752|0;K=o+4876|0;L=o+4880|0;M=f+48|0;N=l;O=m;P=l;Q=m|0;R=f;S=0;a:while(1){T=z+(S*12|0)+4|0;U=z+(S*12|0)+8|0;V=0;while(1){if((V|0)>=(d[T]|0)){break}W=c[U>>2]|0;X=W+(V*332|0)|0;Y=c[W+(V*332|0)+36+(c[H>>2]<<2)>>2]|0;Z=W+(V*332|0)+28|0;c[Z>>2]=Y;if((Y|0)==0){E=13;break a}Y=W+(V*332|0)+32|0;c[Y>>2]=c[W+(V*332|0)+36+(c[J>>2]<<2)>>2];c[W+(V*332|0)+20>>2]=(c[u>>2]|0)+(c[v>>2]>>3);_=ze[c[K>>2]&511](p,X,f)|0;do{if((_|0)==0){if((c[W+(V*332|0)+52>>2]|0)!=0){E=17;break a}$=p+20+((c[W+(V*332|0)+272>>2]|0)*514|0)|0;aa=W+(V*332|0)+276|0;c[aa>>2]=$;ca=W+(V*332|0)+144|0;b:do{if((c[ca>>2]|0)>0){da=0;ea=$;while(1){fa=da<<1;ga=a[W+(V*332|0)+148+fa|0]|0;ha=ga&255;ia=a[(fa|1)+(W+(V*332|0)+148)|0]|0;fa=ia&255;ja=ea+2+fa|0;ka=a[ja]|0;a[ja]=a[ea+2+ha|0]|0;a[(c[aa>>2]|0)+2+ha|0]=ka;ka=c[aa>>2]|0;ja=ka+258+fa|0;fa=a[ja]|0;a[ja]=a[ka+258+ha|0]|0;a[(c[aa>>2]|0)+258+ha|0]=fa;fa=c[aa>>2]|0;ha=fa|0;ka=a[ha]|0;if(ga<<24>>24==ka<<24>>24|ia<<24>>24==ka<<24>>24){a[ha]=ia^ga^ka;la=c[aa>>2]|0}else{la=fa}fa=la+1|0;ka=a[fa]|0;if(ga<<24>>24==ka<<24>>24|ia<<24>>24==ka<<24>>24){a[fa]=ia^ga^ka}ka=da+1|0;if((ka|0)>=(c[ca>>2]|0)){break b}da=ka;ea=c[aa>>2]|0}}}while(0);$=W+(V*332|0)+280|0;c:do{if((c[$>>2]|0)>0){ea=W+(V*332|0)+284|0;da=W+(V*332|0)+56|0;ka=W+(V*332|0)+60|0;ga=W+(V*332|0)+84|0;ia=W+(V*332|0)+324|0;fa=W+(V*332|0)+328|0;ha=W+(V*332|0)+48|0;ja=W+(V*332|0)+16|0;ma=W+(V*332|0)+296|0;na=W+(V*332|0)+316|0;oa=W+(V*332|0)+320|0;pa=W+(V*332|0)+292|0;qa=W+(V*332|0)+88|0;ra=W+(V*332|0)+100|0;sa=W+(V*332|0)+300|0;ta=W+(V*332|0)+288|0;ua=W+(V*332|0)+64|0;va=W+(V*332|0)+76|0;wa=X|0;xa=W+(V*332|0)+4|0;ya=W+(V*332|0)+72|0;za=W+(V*332|0)+68|0;Aa=c[v>>2]|0;Ba=0;d:while(1){Ca=c[ea>>2]|0;Da=Ca+(Ba*40|0)|0;Ea=c[Ca+(Ba*40|0)+16>>2]|0;Fa=c[da>>2]|0;if((Ea|0)!=(Fa|0)){E=28;break a}Ga=c[v>>2]|0;Ha=c[j>>2]|0;Ia=(d[Ha+(Ga>>>3)|0]|0)>>>((Ga&7)>>>0);c[v>>2]=((Ga|0)<(c[w>>2]|0))+Ga;Ga=Ia&1;c[Ca+(Ba*40|0)+20>>2]=Ga;e:do{if((Ga|0)==0){Ia=c[v>>2]|0;Ja=d[Ha+(Ia>>>3)|0]|0;Ka=c[w>>2]|0;La=((Ia|0)<(Ka|0))+Ia|0;c[v>>2]=La;do{if((Ja&1<<(Ia&7)|0)==0){Ma=0;Na=La}else{Oa=Ha+(La>>>3)|0;Pa=(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)>>>((La&7)>>>0)&255;Oa=La+8|0;Qa=Ka>>>0>Oa>>>0?Oa:Ka;c[v>>2]=Qa;if((Pa|0)!=255){Ma=Pa;Na=Qa;break}Pa=Ha+(Qa>>>3)|0;Oa=(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)>>>((Qa&7)>>>0)&16777215;Pa=Qa+24|0;Qa=Ka>>>0>Pa>>>0?Pa:Ka;c[v>>2]=Qa;Ma=Oa;Na=Qa}}while(0);La=-Na&7;if((La|0)!=0){Ia=La+Na|0;c[v>>2]=Ka>>>0>Ia>>>0?Ia:Ka}Ia=Ca+(Ba*40|0)+24|0;c[Ia>>2]=Ma;if((Ma|0)==0){E=75;break d}La=_e[c[L>>2]&1023](p,X,Da,f)|0;if((La|0)<0){Ra=La;break c}c[n>>2]=0;La=c[ka>>2]|0;Ja=(c[da>>2]|0)!=(La|0)?4:1;Qa=(La|0)==8;Oa=Qa?270:250;Pa=Qa?630:12;Qa=Ca+(Ba*40|0)+28|0;if((c[Qa>>2]|0)>0){Sa=La-1|0;Ta=0;Ua=0;Va=c[Ca+(Ba*40|0)+32>>2]|0;Wa=0;Xa=0;while(1){Ya=(a[Va+8|0]|0)==0;Za=d[Va+9|0]|0;_a=c[Va+4>>2]|0;$a=(a[Va+10|0]|0)+(c[ga>>2]|0)|0;ab=($a|0)<0;do{if((c[M>>2]|0)==112){if(ab){bb=0;break}bb=($a|0)>31?31:$a}else{if(ab){bb=0;break}bb=($a|0)>23?23:$a}}while(0);$a=c[(Ya?ia:fa)>>2]|0;if(($a|0)==0){cb=bb}else{cb=d[$a+bb|0]|0}if(Ya){db=Wa;eb=Ua;fb=Ta}else{$a=a[Va+11|0]|0;ab=a[Va+12|0]|0;gb=c[ua>>2]|0;if((gb|0)==0){hb=Wa;ib=ab;jb=$a}else{hb=ab<<1&2|$a&1;ib=ab>>1;jb=$a>>1}kb=(b[Va>>1]|0)+($a>>gb)|0;if((kb|0)<0){break d}lb=c[da>>2]|0;if((kb+(gb&$a)+lb|0)>(c[ha>>2]|0)){break d}$a=(b[Va+2>>1]|0)+(ab>>gb)|0;if(($a|0)<0){break d}if((lb+(ab&gb)+$a|0)>(c[ja>>2]|0)){break d}else{db=hb;eb=ib;fb=jb}}$a=Ya?na:oa;gb=Za;ab=_a;lb=0;while(1){do{if((lb&1|0)==0){if((lb|0)!=2){mb=ab;break}mb=ab-La+(ba(c[ha>>2]|0,La)|0)|0}else{mb=ab+La|0}}while(0);do{if((gb&1|0)==0){if(!Ya){AIa(X,Pa,mb,fb,eb,db);break}kb=c[ha>>2]|0;if(((ba(kb,Sa)|0)+La|0)>((ba(c[ja>>2]|0,kb)|0)-mb|0)){break d}cf[c[ma>>2]&1023](n,(c[Z>>2]|0)+(mb<<1)|0,kb,La)}else{kb=c[$a>>2]|0;nb=c[aa>>2]|0;ob=c[ka>>2]|0;pb=ba(ob,ob)|0;qb=ob-1|0;ob=c[ha>>2]|0;rb=c[pa>>2]|0;sb=(ba(rb-1|0,ob)|0)+rb|0;if((sb|0)>((ba(c[ja>>2]|0,ob)|0)-mb|0)){break d}ob=c[qa>>2]|0;if((ob|0)==0){E=101;break d}TGb(O|0,0,pb<<2|0)|0;c[l>>2]=0;c[l+4>>2]=0;sb=nb|0;rb=nb+1|0;tb=c[w>>2]|0;ub=c[j>>2]|0;vb=(c[ra>>2]|0)+4|0;wb=-1;xb=c[v>>2]|0;while(1){yb=c[vb>>2]|0;zb=ub+(xb>>>3)|0;Ab=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((xb&7)>>>0)&8191;zb=b[yb+(Ab<<2)>>1]|0;Bb=zb<<16>>16;Cb=(b[yb+(Ab<<2)+2>>1]|0)+xb|0;Ab=tb>>>0>Cb>>>0?Cb:tb;c[v>>2]=Ab;if((Bb|0)==(d[sb]|0)){Db=wb;break}if((Bb|0)==(d[rb]|0)){Cb=ub+(Ab>>>3)|0;Eb=(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)>>>((Ab&7)>>>0)&8191;Cb=b[yb+(Eb<<2)>>1]|0;Fb=(b[yb+(Eb<<2)+2>>1]|0)+Ab|0;Eb=tb>>>0>Fb>>>0?Fb:tb;c[v>>2]=Eb;Fb=ub+(Eb>>>3)|0;Gb=(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)>>>((Eb&7)>>>0)&8191;Fb=b[yb+(Gb<<2)>>1]|0;Hb=(b[yb+(Gb<<2)+2>>1]|0)+Eb|0;Eb=tb>>>0>Hb>>>0?Hb:tb;c[v>>2]=Eb;Hb=ub+(Eb>>>3)|0;Gb=(d[Hb]|d[Hb+1|0]<<8|d[Hb+2|0]<<16|d[Hb+3|0]<<24|0)>>>((Eb&7)>>>0)&8191;Hb=b[yb+(Gb<<2)>>1]|0;Ib=(b[yb+(Gb<<2)+2>>1]|0)+Eb|0;Eb=tb>>>0>Ib>>>0?Ib:tb;c[v>>2]=Eb;Jb=Cb+1|0;Kb=-((Hb<<6|Fb)>>>1^-(Fb&1))|0;Lb=Eb}else{if((zb&65535)>>>0>255>>>0){E=107;break d}Jb=d[nb+2+Bb|0]|0;Kb=a[nb+258+Bb|0]|0;Lb=Ab}Ab=Jb+wb|0;if((Ab|0)>=(pb|0)|(Ab|0)<0){Db=Ab;break}zb=d[ob+Ab|0]|0;Eb=ba(e[kb+(zb<<1)>>1]|0,cb)|0;Fb=Eb>>>9;if(Eb>>>0>1023>>>0){Eb=ba(Fb,Kb)|0;Mb=(ba(((Fb^1)-1|0)>>>1,(Kb|0)>0?1:-1)|0)+Eb|0}else{Mb=Kb}c[m+(zb<<2)>>2]=Mb;Eb=P+(zb&qb)|0;a[Eb]=(Mb|0)!=0|a[Eb];if((Ab|0)>(pb|0)){Db=Ab;break}else{wb=Ab;xb=Lb}}if((Db|0)<0){break d}if((Db|0)>=(pb|0)){if((Bb|0)!=(d[sb]|0)){break d}}do{if(Ya){if((c[sa>>2]|0)==0){break}xb=(c[n>>2]|0)+(c[Q>>2]|0)|0;c[n>>2]=xb;c[Q>>2]=xb;a[N]=(xb|0)!=0|a[N]}}while(0);if((c[pa>>2]|0)>(c[ka>>2]|0)){E=120;break d}cf[c[ta>>2]&1023](Q,(c[Z>>2]|0)+(mb<<1)|0,c[ha>>2]|0,N);if(Ya){break}AIa(X,Oa,mb,fb,eb,db)}}while(0);sb=lb+1|0;if((sb|0)<(Ja|0)){gb=gb>>>1;ab=mb;lb=sb}else{break}}lb=Xa+1|0;if((lb|0)<(c[Qa>>2]|0)){Ta=fb;Ua=eb;Va=Va+16|0;Wa=db;Xa=lb}else{break}}}Xa=c[v>>2]|0;Wa=-Xa&7;if((Wa|0)==0){Nb=Xa}else{Va=c[w>>2]|0;Ua=Wa+Xa|0;Xa=Va>>>0>Ua>>>0?Ua:Va;c[v>>2]=Xa;Nb=Xa}Xa=Nb-Aa>>3;if((Xa|0)!=(c[Ia>>2]|0)){E=133;break d}Ob=(Xa<<3)+Aa|0}else{Xa=c[(c[B>>2]|0)+56>>2]>>3;Va=c[da>>2]|0;Ua=Va>>3;Wa=Xa-Ua|0;Ta=Ca+(Ba*40|0)+28|0;Pb=c[Ta>>2]|0;Qa=Ca+(Ba*40|0)+8|0;Ja=c[Qa>>2]|0;Oa=Va-1|0;La=Ca+(Ba*40|0)+12|0;Sa=c[La>>2]|0;Qb=ba((Sa+Oa|0)/(Va|0)|0,(Ja+Oa|0)/(Va|0)|0)|0;if((Pb|0)!=(Qb|0)){E=31;break d}Oa=Ca+(Ba*40|0)+4|0;Pa=c[Oa>>2]|0;Ka=c[ha>>2]|0;lb=Da|0;ab=Ca+(Ba*40|0)+32|0;gb=ba(Ka,Va)|0;if((Sa|0)<=0){Ob=Aa;break}Ya=c[lb>>2]|0;$a=ba(Ka,Pa)|0;Ka=(Xa|0)==(Ua|0);Ua=Wa-1|0;Xa=Ya+$a|0;$a=c[ab>>2]|0;_a=c[Ca+(Ba*40|0)+36>>2]|0;Za=0;sb=Pa;pb=Ja;Ja=Va;Va=Pa;Pa=Sa;Sa=Ya;while(1){if((pb|0)>0){Ya=sb&65535;xb=Ya<<16>>16;wb=Xa;qb=$a;kb=_a;ob=Za;nb=Sa;while(1){tb=nb&65535;b[qb>>1]=tb;b[qb+2>>1]=Ya;c[qb+4>>2]=wb;a[qb+8|0]=1;a[qb+9|0]=0;do{if((c[va>>2]|0)==0){if((c[wa>>2]|0)!=0){break}if((c[xa>>2]|0)!=0){break}a[qb+10|0]=c[ga>>2];a[qb+11|0]=0;a[qb+12|0]=0}}while(0);ub=(kb|0)==0;if(!((c[ya>>2]|0)==0|ub)){a[qb+10|0]=a[kb+10|0]|0}if((c[za>>2]|0)==0|ub){Rb=ob;Sb=c[da>>2]|0}else{rb=a[kb+11|0]|0;if(Ka){a[qb+11|0]=rb;vb=a[kb+12|0]|0;a[qb+12|0]=vb;Tb=rb;Ub=vb}else{vb=(rb<<24>>24)+Ua+(rb<<24>>24>0)>>Wa&255;a[qb+11|0]=vb;rb=a[kb+12|0]|0;Ab=(rb<<24>>24)+Ua+(rb<<24>>24>0)>>Wa&255;a[qb+12|0]=Ab;Tb=vb;Ub=Ab}if(Tb<<24>>24==0){Vb=Ub<<24>>24!=0|0}else{Vb=1}Ab=Tb<<24>>24;vb=c[ua>>2]|0;rb=Ub<<24>>24;Eb=(Ab>>vb)+(tb<<16>>16)|0;if((Eb|0)<0){E=53;break d}zb=c[da>>2]|0;if((Eb+(vb&Ab)+zb|0)>(c[ha>>2]|0)){E=53;break d}Ab=(rb>>vb)+xb|0;if((Ab|0)<0){E=53;break d}if((Ab+(vb&rb)+zb|0)>(c[ja>>2]|0)){E=53;break d}else{Rb=Vb|ob;Sb=zb}}Wb=qb+16|0;Xb=ub?0:kb+16|0;ub=Sb+nb|0;Yb=c[lb>>2]|0;Zb=c[Qa>>2]|0;if((ub|0)<(Zb+Yb|0)){wb=Sb+wb|0;qb=Wb;kb=Xb;ob=Rb;nb=ub}else{break}}_b=Wb;$b=Xb;ac=Rb;bc=Zb;cc=Sb;dc=c[Oa>>2]|0;ec=c[La>>2]|0;fc=Yb}else{_b=$a;$b=_a;ac=Za;bc=pb;cc=Ja;dc=Va;ec=Pa;fc=Sa}nb=cc+sb|0;if((nb|0)<(dc+ec|0)){Xa=Xa+gb|0;$a=_b;_a=$b;Za=ac;sb=nb;pb=bc;Ja=cc;Va=dc;Pa=ec;Sa=fc}else{break}}if((c[za>>2]|0)==0|(ac|0)==0){Sa=(ba(c[ha>>2]|0,dc)|0)+fc|0;if((ec|0)<=0){Ob=Aa;break}Pa=(c[Z>>2]|0)+(Sa<<1)|0;Va=(c[Y>>2]|0)+(Sa<<1)|0;UGb(Pa|0,Va|0,bc<<1)|0;if((c[La>>2]|0)>1){gc=1;hc=Pa;ic=Va}else{Ob=Aa;break}while(1){Va=c[ha>>2]|0;Pa=hc+(Va<<1)|0;Sa=ic+(Va<<1)|0;Va=gc+1|0;UGb(Pa|0,Sa|0,c[Qa>>2]<<1)|0;if((Va|0)<(c[La>>2]|0)){gc=Va;hc=Pa;ic=Sa}else{Ob=Aa;break e}}}La=c[ka>>2]|0;Qa=(cc|0)!=(La|0)?4:1;Sa=(La|0)==8?630:12;if((c[Ta>>2]|0)<=0){Ob=Aa;break}La=c[ab>>2]|0;Pa=1;while(1){Va=a[La+11|0]|0;Ja=a[La+12|0]|0;if((c[ua>>2]|0)==0){jc=Va;kc=0;lc=Ja}else{jc=Va>>1;kc=Ja<<1&2|Va&1;lc=Ja>>1}Ja=La+4|0;Va=0;do{AIa(X,Sa,(ba((c[ha>>2]&-(Va>>>1&1))+(Va&1)|0,c[ka>>2]|0)|0)+(c[Ja>>2]|0)|0,jc,lc,kc);Va=Va+1|0;}while((Va|0)<(Qa|0));if((Pa|0)>=(c[Ta>>2]|0)){Ob=Aa;break e}La=La+16|0;Pa=Pa+1|0}}}while(0);Ca=Ba+1|0;if((Ca|0)<(c[$>>2]|0)){Aa=Ob;Ba=Ca}else{Ra=0;break c}}if((E|0)==31){E=0;yDb(R,16,2175928,(x=i,i=i+16|0,c[x>>2]=Pb,c[x+8>>2]=Qb,x)|0);i=x;Ra=-1094995529;break}else if((E|0)==53){E=0;yDb(R,16,2165480,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Ra=-1094995529;break}else if((E|0)==75){E=0;yDb(R,16,2331968,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Ra=-1094995529;break}else if((E|0)==101){E=0;yDb(R,16,2209336,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}else if((E|0)==107){E=0;yDb(R,16,2200736,(x=i,i=i+8|0,c[x>>2]=Bb,x)|0);i=x}else if((E|0)==120){E=0;yDb(0,16,2192248,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}else if((E|0)==133){E=0;yDb(R,16,2289200,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Ra=-1094995529;break}yDb(R,16,2307592,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Ra=-1094995529}else{Ra=0}}while(0);$=c[ca>>2]|0;if(($|0)>0){Ba=$;do{Ba=Ba-1|0;$=Ba<<1;Aa=a[W+(V*332|0)+148+$|0]|0;ka=Aa&255;ha=a[($|1)+(W+(V*332|0)+148)|0]|0;$=ha&255;ua=c[aa>>2]|0;za=ua+2+$|0;ja=a[za]|0;a[za]=a[ua+2+ka|0]|0;a[(c[aa>>2]|0)+2+ka|0]=ja;ja=c[aa>>2]|0;ua=ja+258+$|0;$=a[ua]|0;a[ua]=a[ja+258+ka|0]|0;a[(c[aa>>2]|0)+258+ka|0]=$;$=c[aa>>2]|0;ka=$|0;ja=a[ka]|0;if(Aa<<24>>24==ja<<24>>24|ha<<24>>24==ja<<24>>24){a[ka]=ha^Aa^ja;mc=c[aa>>2]|0}else{mc=$}$=mc+1|0;ja=a[$]|0;if(Aa<<24>>24==ja<<24>>24|ha<<24>>24==ja<<24>>24){a[$]=ha^Aa^ja}}while((Ba|0)>0)}Ba=c[v>>2]|0;aa=-Ba&7;if((aa|0)==0){nc=Ra;break}ca=c[w>>2]|0;ja=aa+Ba|0;c[v>>2]=ca>>>0>ja>>>0?ja:ca;nc=Ra}else{yDb(R,16,1915568,(x=i,i=i+8|0,c[x>>2]=_,x)|0);i=x;nc=_}}while(0);if((nc|0)<0){oc=nc;break a}else{V=V+1|0}}U=S+1|0;if((U|0)<3){S=U}else{E=147;break}}if((E|0)==13){yDb(R,16,1939752,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;oc=-1094995529}else if((E|0)==17){yDb(R,16,1895048,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;oc=-1094995529}else if((E|0)==28){yDb(R,16,2352088,(x=i,i=i+16|0,c[x>>2]=Fa,c[x+8>>2]=Ea,x)|0);i=x;oc=-1094995529}else if((E|0)==147){c[I+(c[H>>2]<<2)>>2]=0;F=H;G=I;break}yDb(R,16,2005912,(x=i,i=i+16|0,c[x>>2]=V,c[x+8>>2]=S,x)|0);i=x;y=oc;i=k;return y|0}}while(0);if((c[G+(c[F>>2]<<2)>>2]|0)!=0){y=-1;i=k;return y|0}F=f+48|0;do{if((c[F>>2]|0)==112){if((c[o+4652>>2]|0)!=0){break}G=c[w>>2]|0;oc=c[j>>2]|0;V=c[v>>2]|0;while(1){Ea=oc+(V>>>3)|0;Fa=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0;Ea=V+8|0;pc=G>>>0>Ea>>>0?Ea:G;c[v>>2]=pc;if((Fa&255<<(V&7)|0)==0){break}if(((c[t>>2]|0)-pc|0)<8){y=-1094995529;E=198;break}else{V=pc}}if((E|0)==198){i=k;return y|0}V=-pc|0;S=G-pc|0;if((V|0)>64){qc=V}else{qc=(S|0)<64?S:64}S=qc+pc|0;c[v>>2]=S;if(((c[t>>2]|0)-S|0)<=18){break}V=oc+(S>>>3)|0;if(((d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((S&7)>>>0)&262143|0)!=262136){break}yDb(f,16,1968192,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}}while(0);if((re[c[C>>2]&4095](p)|0)==0){y=s;i=k;return y|0}p=q;q=o+4710|0;C=V$a(f,e[p>>1]|0,e[q>>1]|0)|0;if((C|0)<0){y=C;i=k;return y|0}C=_$a(f,r,0)|0;if((C|0)<0){y=C;i=k;return y|0}do{if((c[o+4664>>2]|0)==0){C=c[g+32>>2]|0;r=c[B>>2]|0;f=c[r+28>>2]|0;x=c[r+48>>2]|0;if((f|0)==0){break}r=b[q>>1]|0;if(r<<16>>16==0){break}t=0;v=f;f=c[g>>2]|0;pc=b[p>>1]|0;qc=r;while(1){if(pc<<16>>16==0){rc=0;sc=qc}else{r=0;do{E=b[v+(r<<1)>>1]|0;j=E+128|0;if(j>>>0>255>>>0){tc=-128-E>>31&255}else{tc=j&255}a[f+r|0]=tc;r=r+1|0;uc=b[p>>1]|0;}while((r|0)<(uc&65535|0));rc=uc;sc=b[q>>1]|0}r=t+1|0;if((r|0)<(sc&65535|0)){t=r;v=v+(x<<1)|0;f=f+C|0;pc=rc;qc=sc}else{break}}}else{qc=c[g>>2]|0;pc=c[g+32>>2]|0;if((c[F>>2]|0)==112){CIa(A,qc,pc);break}else{BIa(A,qc,pc);break}}}while(0);A=o+4732|0;F=c[g+4>>2]|0;sc=c[g+36>>2]|0;rc=c[o+4740>>2]|0;q=c[rc+28>>2]|0;uc=c[rc+48>>2]|0;do{if((q|0)!=0){rc=o+4734|0;p=b[rc>>1]|0;if(p<<16>>16==0){break}tc=A;B=0;pc=q;qc=F;C=b[tc>>1]|0;f=p;while(1){if(C<<16>>16==0){vc=0;wc=f}else{p=0;do{x=b[pc+(p<<1)>>1]|0;v=x+128|0;if(v>>>0>255>>>0){xc=-128-x>>31&255}else{xc=v&255}a[qc+p|0]=xc;p=p+1|0;yc=b[tc>>1]|0;}while((p|0)<(yc&65535|0));vc=yc;wc=b[rc>>1]|0}p=B+1|0;if((p|0)<(wc&65535|0)){B=p;pc=pc+(uc<<1)|0;qc=qc+sc|0;C=vc;f=wc}else{break}}}}while(0);wc=o+4720|0;vc=c[g+8>>2]|0;sc=c[g+40>>2]|0;g=c[o+4728>>2]|0;uc=c[g+28>>2]|0;yc=c[g+48>>2]|0;do{if((uc|0)!=0){g=o+4722|0;xc=b[g>>1]|0;if(xc<<16>>16==0){break}F=wc;q=0;A=uc;f=vc;C=b[F>>1]|0;qc=xc;while(1){if(C<<16>>16==0){zc=0;Ac=qc}else{xc=0;do{pc=b[A+(xc<<1)>>1]|0;B=pc+128|0;if(B>>>0>255>>>0){Bc=-128-pc>>31&255}else{Bc=B&255}a[f+xc|0]=Bc;xc=xc+1|0;Cc=b[F>>1]|0;}while((xc|0)<(Cc&65535|0));zc=Cc;Ac=b[g>>1]|0}xc=q+1|0;if((xc|0)<(Ac&65535|0)){q=xc;A=A+(yc<<1)|0;f=f+sc|0;C=zc;qc=Ac}else{break}}}}while(0);c[h>>2]=1;y=s;i=k;return y|0}function zIa(a){a=a|0;var b=0;b=c[a+60>>2]|0;wIa(b+4708|0);if((c[b+4792>>2]|0)==0){return 0}Q_(b+4788|0);return 0}function AIa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;j=c[a+48>>2]|0;k=e+d+(ba(j,f)|0)|0;f=ba(c[a+16>>2]|0,j)|0;e=c[a+60>>2]|0;l=ba(e-1|0,j)|0;if(!((k|d|0)>-1)){yDb(0,0,2273096,(m=i,i=i+24|0,c[m>>2]=2257520,c[m+8>>2]=2243296,c[m+16>>2]=83,m)|0);i=m;Cd()}n=c[a+32>>2]|0;if((n|0)==0){yDb(0,0,2273096,(m=i,i=i+24|0,c[m>>2]=2257520,c[m+8>>2]=2243296,c[m+16>>2]=83,m)|0);i=m;Cd()}o=f-e-l|0;if((o|0)<(d|0)){yDb(0,0,2273096,(m=i,i=i+24|0,c[m>>2]=2230768,c[m+8>>2]=2243296,c[m+16>>2]=84,m)|0);i=m;Cd()}if((o-((j&-((g|0)>1|0))+(g&1))|0)<(k|0)){yDb(0,0,2273096,(m=i,i=i+24|0,c[m>>2]=2218704,c[m+8>>2]=2243296,c[m+16>>2]=85,m)|0);i=m;Cd()}else{cf[b&1023]((c[a+28>>2]|0)+(d<<1)|0,n+(k<<1)|0,j,g);i=h;return}}function BIa(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;g=c[d+8>>2]|0;h=d+2|0;i=b[h>>1]|0;if(i<<16>>16==0){return}j=d|0;d=f<<1;k=0;l=c[g+48>>2]|0;m=0;n=c[g+28>>2]|0;o=c[g+360>>2]|0;p=c[g+692>>2]|0;q=c[g+1024>>2]|0;g=e;e=i&65535;r=b[j>>1]|0;s=i;while(1){i=k+2|0;t=(i|0)<(e|0)?l:0;u=b[o+(m<<1)>>1]|0;v=b[o>>1]|0;w=b[p>>1]|0;x=b[p+(t<<1)>>1]|0;y=b[q+(m<<1)>>1]|0;z=b[q>>1]|0;A=(z*-6|0)+y+(b[q+(t<<1)>>1]|0)|0;if(r<<16>>16==0){B=n;C=o;D=p;E=q;F=0;G=s;H=t+1|0}else{I=t+1|0;J=m+1|0;K=u;L=v;M=(v*-6|0)+u+(b[o+(t<<1)>>1]|0)|0;u=b[n+(t<<1)>>1]|0;v=w;N=w;w=b[n>>1]|0;O=x;P=x;x=0;Q=y;R=y;y=z;S=z;z=0;T=A;U=A;A=n;V=o;W=p;X=q;Y=r&65535;while(1){Z=z+2|0;if((Z|0)<(Y|0)){_=X;$=W;aa=V;ba=A}else{_=X-2|0;$=W-2|0;aa=V-2|0;ba=A-2|0}ca=x+1|0;da=b[ba+(ca<<1)>>1]|0;ea=I+x|0;fa=b[ba+(ea<<1)>>1]|0;ga=da+w|0;ha=b[aa+(ca<<1)>>1]|0;ia=J+x|0;ja=b[aa+(ia<<1)>>1]|0;ka=(L*-6|0)+K+M|0;la=ja+(ha*-6|0)+(b[aa+(ea<<1)>>1]|0)|0;ma=L+K|0;na=b[$+(ca<<1)>>1]|0;oa=b[$+(ea<<1)>>1]|0;pa=N+v|0;qa=(N*-6|0)+v+na|0;ra=b[_+(ca<<1)>>1]|0;sa=b[_+(ia<<1)>>1]|0;ia=y+Q|0;ta=S+R|0;ua=sa+(ra*-6|0)+(b[_+(ea<<1)>>1]|0)|0;ea=(ta+ia<<2)+(w<<4)+(pa+ma<<3)>>6;va=ea+128|0;if(va>>>0>255>>>0){wa=-128-ea>>31&255}else{wa=va&255}a[g+z|0]=wa;va=((ta*-6|0)+ia+ra+sa<<1)+(ga<<3)+(ha+ma+ja+qa<<2)>>6;ma=va+128|0;if(ma>>>0>255>>>0){xa=-128-va>>31&255}else{xa=ma&255}a[g+(z|1)|0]=xa;ma=(U+T<<1)+(w+u<<3)+(pa+ka+O+P<<2)>>6;pa=ma+128|0;if(pa>>>0>255>>>0){ya=-128-ma>>31&255}else{ya=pa&255}pa=z+f|0;a[g+pa|0]=ya;ma=(U*-6|0)+T+(ga+u+fa<<2)+ua+(O+ka+(P*-6|0)+la+qa+oa<<1)>>6;qa=ma+128|0;if(qa>>>0>255>>>0){za=-128-ma>>31&255}else{za=qa&255}a[g+(pa+1)|0]=za;Aa=b[j>>1]|0;pa=Aa&65535;if((Z|0)<(pa|0)){K=ja;L=ha;M=la;u=fa;v=N;N=na;w=da;O=P;P=oa;x=ca;Q=R;R=sa;y=S;S=ra;z=Z;T=U;U=ua;A=ba;V=aa;W=$;X=_;Y=pa}else{break}}B=ba;C=aa;D=$;E=_;F=Aa;G=b[h>>1]|0;H=I}Y=G&65535;if((i|0)<(Y|0)){k=i;l=t;m=-t|0;n=B+(H<<1)|0;o=C+(H<<1)|0;p=D+(H<<1)|0;q=E+(H<<1)|0;g=g+d|0;e=Y;r=F;s=G}else{break}}return}function CIa(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=c[d+8>>2]|0;h=c[g+48>>2]|0;i=d+2|0;j=b[i>>1]|0;if(j<<16>>16==0){return}k=d|0;d=f<<1;l=0;m=c[g+28>>2]|0;n=c[g+360>>2]|0;o=c[g+692>>2]|0;p=c[g+1024>>2]|0;g=e;e=b[k>>1]|0;q=j;while(1){if(e<<16>>16==0){r=0;s=q}else{j=0;t=0;while(1){u=b[m+(j<<1)>>1]|0;v=b[n+(j<<1)>>1]|0;w=b[o+(j<<1)>>1]|0;x=b[p+(j<<1)>>1]|0;y=v+u|0;z=w+2|0;A=z+y+x>>2;B=2-w|0;w=B+y-x>>2;y=u-v|0;v=z+y-x>>2;z=B+y+x>>2;x=A+128|0;if(x>>>0>255>>>0){C=-128-A>>31&255}else{C=x&255}a[g+t|0]=C;x=w+128|0;if(x>>>0>255>>>0){D=-128-w>>31&255}else{D=x&255}a[g+(t|1)|0]=D;x=v+128|0;if(x>>>0>255>>>0){E=-128-v>>31&255}else{E=x&255}x=t+f|0;a[g+x|0]=E;v=z+128|0;if(v>>>0>255>>>0){F=-128-z>>31&255}else{F=v&255}a[g+(x+1)|0]=F;x=t+2|0;G=b[k>>1]|0;if((x|0)<(G&65535|0)){j=j+1|0;t=x}else{break}}r=G;s=b[i>>1]|0}t=l+2|0;if((t|0)<(s&65535|0)){l=t;m=m+(h<<1)|0;n=n+(h<<1)|0;o=o+(h<<1)|0;p=p+(h<<1)|0;g=g+d|0;e=r;q=s}else{break}}return}function DIa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=i;i=i+256|0;j=h|0;k=0;l=d;d=j;while(1){if((a[g+k|0]|0)==0){c[d+224>>2]=0;c[d+192>>2]=0;c[d+160>>2]=0;c[d+128>>2]=0;c[d+96>>2]=0;c[d+64>>2]=0;c[d+32>>2]=0;c[d>>2]=0}else{m=k>>>2&1^1;n=c[l+64>>2]<<m;o=c[l+96>>2]<<m;p=c[l>>2]<<m<<1;q=c[l+32>>2]<<m<<1;m=p-q>>1;r=q+p>>1;p=r-n>>1;q=r+n>>1;n=m-o>>1;r=m+o>>1;o=c[l+128>>2]|0;m=c[l+160>>2]|0;s=c[l+192>>2]|0;t=c[l+224>>2]|0;c[d>>2]=q+o>>1;c[d+32>>2]=q-o>>1;c[d+64>>2]=p+m>>1;c[d+96>>2]=p-m>>1;c[d+128>>2]=r+s>>1;c[d+160>>2]=r-s>>1;c[d+192>>2]=n+t>>1;c[d+224>>2]=n-t>>1}t=k+1|0;if((t|0)<8){k=t;l=l+4|0;d=d+4|0}else{u=0;v=e;w=j;break}}while(1){j=c[w>>2]|0;e=c[w+4>>2]|0;do{if((j|e|0)==0){if((c[w+8>>2]|0)!=0){x=0;y=14;break}if((c[w+12>>2]|0)!=0){x=0;y=14;break}if((c[w+16>>2]|0)!=0){x=0;y=14;break}if((c[w+20>>2]|0)!=0){x=0;y=14;break}if((c[w+24>>2]|0)!=0){x=0;y=14;break}if((c[w+28>>2]|0)!=0){x=0;y=14;break}TGb(v|0,0,16)|0}else{x=e;y=14}}while(0);if((y|0)==14){y=0;e=j<<1;d=x<<1;l=e-d>>1;k=d+e>>1;e=c[w+8>>2]|0;d=k-e>>1;g=k+e>>1;e=c[w+12>>2]|0;k=l-e>>1;t=l+e>>1;e=c[w+16>>2]|0;l=c[w+20>>2]|0;n=c[w+24>>2]|0;s=c[w+28>>2]|0;b[v>>1]=(g+e|0)>>>1;b[v+2>>1]=(g-e|0)>>>1;b[v+4>>1]=(d+l|0)>>>1;b[v+6>>1]=(d-l|0)>>>1;b[v+8>>1]=(t+n|0)>>>1;b[v+10>>1]=(t-n|0)>>>1;b[v+12>>1]=(s+k|0)>>>1;b[v+14>>1]=(k-s|0)>>>1}s=u+1|0;if((s|0)<8){u=s;v=v+(f<<1)|0;w=w+32|0}else{break}}i=h;return}function EIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=0;g=d;d=a;while(1){a=c[d>>2]|0;h=c[d+4>>2]|0;do{if((a|h|0)==0){if((c[d+8>>2]|0)!=0){i=0;j=10;break}if((c[d+12>>2]|0)!=0){i=0;j=10;break}if((c[d+16>>2]|0)!=0){i=0;j=10;break}if((c[d+20>>2]|0)!=0){i=0;j=10;break}if((c[d+24>>2]|0)!=0){i=0;j=10;break}if((c[d+28>>2]|0)!=0){i=0;j=10;break}TGb(g|0,0,16)|0}else{i=h;j=10}}while(0);if((j|0)==10){j=0;h=a<<1;k=i<<1;l=h-k>>1;m=k+h>>1;h=c[d+8>>2]|0;k=m-h>>1;n=m+h>>1;h=c[d+12>>2]|0;m=l-h>>1;o=l+h>>1;h=c[d+16>>2]|0;l=c[d+20>>2]|0;p=c[d+24>>2]|0;q=c[d+28>>2]|0;b[g>>1]=(n+h|0)>>>1;b[g+2>>1]=(n-h|0)>>>1;b[g+4>>1]=(k+l|0)>>>1;b[g+6>>1]=(k-l|0)>>>1;b[g+8>>1]=(o+p|0)>>>1;b[g+10>>1]=(o-p|0)>>>1;b[g+12>>1]=(q+m|0)>>>1;b[g+14>>1]=(m-q|0)>>>1}q=f+1|0;if((q|0)<8){f=q;g=g+(e<<1)|0;d=d+32|0}else{break}}return}function FIa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=f*7|0;i=f*6|0;j=f*5|0;k=f<<2;l=f*3|0;m=f<<1;n=0;o=e;e=d;while(1){if((a[g+n|0]|0)==0){b[o+(h<<1)>>1]=0;b[o+(i<<1)>>1]=0;b[o+(j<<1)>>1]=0;b[o+(k<<1)>>1]=0;b[o+(l<<1)>>1]=0;b[o+(m<<1)>>1]=0;b[o+(f<<1)>>1]=0;b[o>>1]=0}else{d=c[e>>2]<<1;p=c[e+32>>2]<<1;q=d-p>>1;r=p+d>>1;d=c[e+64>>2]|0;p=r-d>>1;s=r+d>>1;d=c[e+96>>2]|0;r=q-d>>1;t=q+d>>1;d=c[e+128>>2]|0;q=c[e+160>>2]|0;u=c[e+192>>2]|0;v=c[e+224>>2]|0;b[o>>1]=(s+d|0)>>>1;b[o+(f<<1)>>1]=(s-d|0)>>>1;b[o+(m<<1)>>1]=(p+q|0)>>>1;b[o+(l<<1)>>1]=(p-q|0)>>>1;b[o+(k<<1)>>1]=(t+u|0)>>>1;b[o+(j<<1)>>1]=(t-u|0)>>>1;b[o+(i<<1)>>1]=(v+r|0)>>>1;b[o+(h<<1)>>1]=(r-v|0)>>>1}v=n+1|0;if((v|0)<8){n=v;o=o+2|0;e=e+4|0}else{break}}return}function GIa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+64|0;j=h|0;k=0;l=d;d=j;while(1){if((a[g+k|0]|0)==0){c[d+48>>2]=0;c[d+32>>2]=0;c[d+16>>2]=0;c[d>>2]=0}else{m=k>>>1&1^1;n=c[l>>2]<<m;o=c[l+16>>2]<<m;m=n-o>>1;p=o+n>>1;n=c[l+32>>2]|0;c[d>>2]=p+n>>1;c[d+16>>2]=p-n>>1;n=c[l+48>>2]|0;c[d+32>>2]=m+n>>1;c[d+48>>2]=m-n>>1}n=k+1|0;if((n|0)<4){k=n;l=l+4|0;d=d+4|0}else{q=0;r=e;s=j;break}}while(1){j=c[s>>2]|0;e=c[s+4>>2]|0;do{if((j|e|0)==0){if((c[s+8>>2]|0)!=0){t=0;u=10;break}if((c[s+12>>2]|0)!=0){t=0;u=10;break}d=r;l=d|0;x=0;b[l>>1]=x;b[l+2>>1]=x>>16;l=d+4|0;x=0;b[l>>1]=x;b[l+2>>1]=x>>16}else{t=e;u=10}}while(0);if((u|0)==10){u=0;e=j-t>>1;l=t+j>>1;d=c[s+8>>2]|0;b[r>>1]=(l+d|0)>>>1;b[r+2>>1]=(l-d|0)>>>1;d=c[s+12>>2]|0;b[r+4>>1]=(e+d|0)>>>1;b[r+6>>1]=(e-d|0)>>>1}d=q+1|0;if((d|0)<4){q=d;r=r+(f<<1)|0;s=s+16|0}else{break}}i=h;return}function HIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;f=0;g=d;d=a;while(1){a=c[d>>2]|0;h=c[d+4>>2]|0;do{if((a|h|0)==0){if((c[d+8>>2]|0)!=0){i=0;j=6;break}if((c[d+12>>2]|0)!=0){i=0;j=6;break}k=g;l=k|0;x=0;b[l>>1]=x;b[l+2>>1]=x>>16;l=k+4|0;x=0;b[l>>1]=x;b[l+2>>1]=x>>16}else{i=h;j=6}}while(0);if((j|0)==6){j=0;h=a-i>>1;l=i+a>>1;k=c[d+8>>2]|0;b[g>>1]=(l+k|0)>>>1;b[g+2>>1]=(l-k|0)>>>1;k=c[d+12>>2]|0;b[g+4>>1]=(h+k|0)>>>1;b[g+6>>1]=(h-k|0)>>>1}k=f+1|0;if((k|0)<4){f=k;g=g+(e<<1)|0;d=d+16|0}else{break}}return}function IIa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=f*3|0;i=f<<1;j=0;k=e;e=d;while(1){if((a[g+j|0]|0)==0){b[k+(h<<1)>>1]=0;b[k+(i<<1)>>1]=0;b[k+(f<<1)>>1]=0;b[k>>1]=0}else{d=c[e>>2]|0;l=c[e+16>>2]|0;m=d-l>>1;n=l+d>>1;d=c[e+32>>2]|0;b[k>>1]=(n+d|0)>>>1;b[k+(f<<1)>>1]=(n-d|0)>>>1;d=c[e+48>>2]|0;b[k+(i<<1)>>1]=(m+d|0)>>>1;b[k+(h<<1)>>1]=(m-d|0)>>>1}d=j+1|0;if((d|0)<4){j=d;k=k+2|0;e=e+4|0}else{break}}return}function JIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=(c[a>>2]|0)>>>3&65535;if((f|0)>0){h=0;i=d}else{return}while(1){d=0;do{b[i+(d<<1)>>1]=g;d=d+1|0;}while((d|0)<(f|0));d=h+1|0;if((d|0)<(f|0)){h=d;i=i+(e<<1)|0}else{break}}return}function KIa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+256|0;j=h|0;k=0;l=d;d=j;while(1){if((a[g+k|0]|0)==0){c[d+224>>2]=0;c[d+192>>2]=0;c[d+160>>2]=0;c[d+128>>2]=0;c[d+96>>2]=0;c[d+64>>2]=0;c[d+32>>2]=0;c[d>>2]=0}else{m=c[l+96>>2]|0;n=c[l+32>>2]|0;o=(4-m+(n<<2)>>3)+m|0;p=(4-(m<<2)-n>>3)+n|0;n=c[l>>2]|0;m=n-p|0;q=p+n|0;n=c[l+128>>2]|0;p=c[l+160>>2]|0;r=n-p|0;s=p+n|0;n=c[l+224>>2]|0;p=c[l+192>>2]|0;t=n-p|0;u=p+n|0;n=c[l+64>>2]|0;p=o-n|0;v=n+o|0;o=q-s|0;n=q+s|0;s=((t<<1)+2+v>>2)+v|0;q=(2-t+(v<<1)>>2)-t|0;t=m-r|0;v=m+r|0;r=((u<<1)+2+p>>2)+p|0;m=(2-u+(p<<1)>>2)-u|0;c[d>>2]=s+n;c[d+32>>2]=q+o;c[d+64>>2]=o-q;c[d+96>>2]=n-s;c[d+128>>2]=r+v;c[d+160>>2]=m+t;c[d+192>>2]=t-m;c[d+224>>2]=v-r}r=k+1|0;if((r|0)<8){k=r;l=l+4|0;d=d+4|0}else{w=e;x=0;y=j;break}}while(1){j=c[y>>2]|0;e=c[y+4>>2]|0;do{if((j|e|0)==0){if((c[y+8>>2]|0)!=0){z=0;A=14;break}if((c[y+12>>2]|0)!=0){z=0;A=14;break}if((c[y+16>>2]|0)!=0){z=0;A=14;break}if((c[y+20>>2]|0)!=0){z=0;A=14;break}if((c[y+24>>2]|0)!=0){z=0;A=14;break}if((c[y+28>>2]|0)!=0){z=0;A=14;break}TGb(w|0,0,16)|0}else{z=e;A=14}}while(0);if((A|0)==14){A=0;e=c[y+12>>2]|0;d=(4-e+(z<<2)>>3)+e|0;l=(4-(e<<2)-z>>3)+z|0;e=j-l|0;k=l+j|0;l=c[y+16>>2]|0;g=c[y+20>>2]|0;r=l-g|0;v=g+l|0;l=c[y+28>>2]|0;g=c[y+24>>2]|0;m=l-g|0;t=g+l|0;l=c[y+8>>2]|0;g=d-l|0;s=l+d|0;d=((m<<1)+2+s>>2)+s|0;l=(2-m+(s<<1)>>2)-m|0;m=((t<<1)+2+g>>2)+g|0;s=(2-t+(g<<1)>>2)-t|0;t=k+v+1|0;b[w>>1]=(t+d|0)>>>1;g=k-v+1|0;b[w+2>>1]=(g+l|0)>>>1;b[w+4>>1]=(g-l|0)>>>1;b[w+6>>1]=(t-d|0)>>>1;d=e+r+1|0;b[w+8>>1]=(d+m|0)>>>1;t=e-r+1|0;b[w+10>>1]=(t+s|0)>>>1;b[w+12>>1]=(t-s|0)>>>1;b[w+14>>1]=(d-m|0)>>>1}m=x+1|0;if((m|0)<8){w=w+(f<<1)|0;x=m;y=y+32|0}else{break}}i=h;return}function LIa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;h=i;i=i+64|0;j=h|0;k=j|0;if((a[g]|0)==0){c[j+48>>2]=0;c[j+32>>2]=0;c[j+16>>2]=0;c[k>>2]=0;l=0}else{m=c[d>>2]|0;n=c[d+32>>2]|0;o=m-n|0;p=n+m|0;m=c[d+16>>2]|0;n=c[d+48>>2]|0;q=(m+2+(n<<1)>>2)+m|0;r=(2-n+(m<<1)>>2)-n|0;n=q+p|0;c[k>>2]=n;c[j+16>>2]=r+o;c[j+32>>2]=o-r;c[j+48>>2]=p-q;l=n}n=j+4|0;if((a[g+1|0]|0)==0){c[j+52>>2]=0;c[j+36>>2]=0;c[j+20>>2]=0;c[n>>2]=0}else{q=c[d+4>>2]|0;p=c[d+36>>2]|0;r=q-p|0;o=p+q|0;q=c[d+20>>2]|0;p=c[d+52>>2]|0;m=(q+2+(p<<1)>>2)+q|0;s=(2-p+(q<<1)>>2)-p|0;c[n>>2]=m+o;c[j+20>>2]=s+r;c[j+36>>2]=r-s;c[j+52>>2]=o-m}m=j+8|0;if((a[g+2|0]|0)==0){c[j+56>>2]=0;c[j+40>>2]=0;c[j+24>>2]=0;c[m>>2]=0}else{o=c[d+8>>2]|0;s=c[d+40>>2]|0;r=o-s|0;n=s+o|0;o=c[d+24>>2]|0;s=c[d+56>>2]|0;p=(o+2+(s<<1)>>2)+o|0;q=(2-s+(o<<1)>>2)-s|0;c[m>>2]=p+n;c[j+24>>2]=q+r;c[j+40>>2]=r-q;c[j+56>>2]=n-p}p=j+12|0;if((a[g+3|0]|0)==0){c[j+60>>2]=0;c[j+44>>2]=0;c[j+28>>2]=0;c[p>>2]=0;t=e;u=1;v=k;w=l}else{g=c[d+12>>2]|0;n=c[d+44>>2]|0;q=g-n|0;r=n+g|0;g=c[d+28>>2]|0;n=c[d+60>>2]|0;d=(g+2+(n<<1)>>2)+g|0;m=(2-n+(g<<1)>>2)-n|0;c[p>>2]=d+r;c[j+28>>2]=m+q;c[j+44>>2]=q-m;c[j+60>>2]=r-d;t=e;u=1;v=k;w=l}while(1){l=c[v+4>>2]|0;do{if((w|l|0)==0){if((c[v+8>>2]|0)!=0){y=0;z=9;break}if((c[v+12>>2]|0)!=0){y=0;z=9;break}k=t;e=k|0;x=0;b[e>>1]=x;b[e+2>>1]=x>>16;e=k+4|0;x=0;b[e>>1]=x;b[e+2>>1]=x>>16}else{y=l;z=9}}while(0);if((z|0)==9){z=0;l=c[v+8>>2]|0;e=c[v+12>>2]|0;k=(y+2+(e<<1)>>2)+y|0;d=(2-e+(y<<1)>>2)-e|0;e=l+w+1|0;b[t>>1]=(e+k|0)>>>1;r=w-l+1|0;b[t+2>>1]=(r+d|0)>>>1;b[t+4>>1]=(r-d|0)>>>1;b[t+6>>1]=(e-k|0)>>>1}k=v+16|0;if((u|0)>=4){break}t=t+(f<<1)|0;u=u+1|0;v=k;w=c[k>>2]|0}i=h;return}function MIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=((c[a>>2]|0)+1|0)>>>1&65535;if((f|0)>0){h=0;i=d}else{return}while(1){d=0;do{b[i+(d<<1)>>1]=g;d=d+1|0;}while((d|0)<(f|0));d=h+1|0;if((d|0)<(f|0)){h=d;i=i+(e<<1)|0}else{break}}return}function NIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=0;g=d;d=a;while(1){a=c[d>>2]|0;h=c[d+4>>2]|0;do{if((a|h|0)==0){if((c[d+8>>2]|0)!=0){i=0;j=10;break}if((c[d+12>>2]|0)!=0){i=0;j=10;break}if((c[d+16>>2]|0)!=0){i=0;j=10;break}if((c[d+20>>2]|0)!=0){i=0;j=10;break}if((c[d+24>>2]|0)!=0){i=0;j=10;break}if((c[d+28>>2]|0)!=0){i=0;j=10;break}TGb(g|0,0,16)|0}else{i=h;j=10}}while(0);if((j|0)==10){j=0;h=c[d+12>>2]|0;k=(4-h+(i<<2)>>3)+h|0;l=(4-(h<<2)-i>>3)+i|0;h=a-l|0;m=l+a|0;l=c[d+16>>2]|0;n=c[d+20>>2]|0;o=l-n|0;p=n+l|0;l=c[d+28>>2]|0;n=c[d+24>>2]|0;q=l-n|0;r=n+l|0;l=c[d+8>>2]|0;n=k-l|0;s=l+k|0;k=((q<<1)+2+s>>2)+s|0;l=(2-q+(s<<1)>>2)-q|0;q=((r<<1)+2+n>>2)+n|0;s=(2-r+(n<<1)>>2)-r|0;r=m+p+1|0;b[g>>1]=(r+k|0)>>>1;n=m-p+1|0;b[g+2>>1]=(n+l|0)>>>1;b[g+4>>1]=(n-l|0)>>>1;b[g+6>>1]=(r-k|0)>>>1;k=h+o+1|0;b[g+8>>1]=(k+q|0)>>>1;r=h-o+1|0;b[g+10>>1]=(r+s|0)>>>1;b[g+12>>1]=(r-s|0)>>>1;b[g+14>>1]=(k-q|0)>>>1}q=f+1|0;if((q|0)<8){f=q;g=g+(e<<1)|0;d=d+32|0}else{break}}return}function OIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=((c[a>>2]|0)+1|0)>>>1&65535;if((f|0)>0){h=0}else{return}do{b[d+(h<<1)>>1]=g;h=h+1|0;}while((h|0)<(f|0));if((f|0)<=1){return}h=f<<1;g=1;a=0;while(1){TGb(d+((ba(a,e)|0)+e<<1)|0,0,h|0)|0;i=g+1|0;if((i|0)<(f|0)){g=i;a=a+1|0}else{break}}return}function PIa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=f<<1;i=f<<2;j=f*7|0;k=i+h|0;l=i+f|0;m=h+f|0;n=0;o=e;e=d;while(1){if((a[g+n|0]|0)==0){b[o+(j<<1)>>1]=0;b[o+(k<<1)>>1]=0;b[o+(l<<1)>>1]=0;b[o+(i<<1)>>1]=0;b[o+(m<<1)>>1]=0;b[o+(h<<1)>>1]=0;b[o+(f<<1)>>1]=0;b[o>>1]=0}else{d=c[e+96>>2]|0;p=c[e+32>>2]|0;q=(4-d+(p<<2)>>3)+d|0;r=(4-(d<<2)-p>>3)+p|0;p=c[e>>2]|0;d=p-r|0;s=r+p|0;p=c[e+128>>2]|0;r=c[e+160>>2]|0;t=p-r|0;u=r+p|0;p=c[e+224>>2]|0;r=c[e+192>>2]|0;v=p-r|0;w=r+p|0;p=c[e+64>>2]|0;r=q-p|0;x=p+q|0;q=((v<<1)+2+x>>2)+x|0;p=(2-v+(x<<1)>>2)-v|0;v=((w<<1)+2+r>>2)+r|0;x=(2-w+(r<<1)>>2)-w|0;w=s+u+1|0;b[o>>1]=(w+q|0)>>>1;r=s-u+1|0;b[o+(f<<1)>>1]=(r+p|0)>>>1;b[o+(h<<1)>>1]=(r-p|0)>>>1;b[o+(m<<1)>>1]=(w-q|0)>>>1;q=d+t+1|0;b[o+(i<<1)>>1]=(q+v|0)>>>1;w=d-t+1|0;b[o+(l<<1)>>1]=(w+x|0)>>>1;b[o+(k<<1)>>1]=(w-x|0)>>>1;b[o+(j<<1)>>1]=(q-v|0)>>>1}v=n+1|0;if((v|0)<8){n=v;o=o+2|0;e=e+4|0}else{break}}return}function QIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=((c[a>>2]|0)+1|0)>>>1&65535;if((f|0)<=0){return}if((f|0)<=1){a=0;h=d;while(1){b[h>>1]=g;i=a+1|0;if((i|0)<(f|0)){a=i;h=h+(e<<1)|0}else{break}}return}h=(f<<1)-2|0;a=0;i=d;while(1){b[i>>1]=g;TGb(d+((ba(a,e)|0)+1<<1)|0,0,h|0)|0;j=a+1|0;if((j|0)<(f|0)){a=j;i=i+(e<<1)|0}else{break}}return}function RIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=0;g=d;d=a;while(1){a=c[d>>2]|0;h=c[d+4>>2]|0;do{if((a|h|0)==0){if((c[d+8>>2]|0)!=0){i=0;j=6;break}if((c[d+12>>2]|0)!=0){i=0;j=6;break}k=g;l=k|0;x=0;b[l>>1]=x;b[l+2>>1]=x>>16;l=k+4|0;x=0;b[l>>1]=x;b[l+2>>1]=x>>16}else{i=h;j=6}}while(0);if((j|0)==6){j=0;h=c[d+8>>2]|0;l=c[d+12>>2]|0;k=(i+2+(l<<1)>>2)+i|0;m=(2-l+(i<<1)>>2)-l|0;l=h+a+1|0;b[g>>1]=(l+k|0)>>>1;n=a-h+1|0;b[g+2>>1]=(n+m|0)>>>1;b[g+4>>1]=(n-m|0)>>>1;b[g+6>>1]=(l-k|0)>>>1}k=f+1|0;if((k|0)<4){f=k;g=g+(e<<1)|0;d=d+16|0}else{break}}return}function SIa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=f<<1;i=h+f|0;j=0;k=e;e=d;while(1){if((a[g+j|0]|0)==0){b[k+(i<<1)>>1]=0;b[k+(h<<1)>>1]=0;b[k+(f<<1)>>1]=0;b[k>>1]=0}else{d=c[e>>2]|0;l=c[e+32>>2]|0;m=c[e+16>>2]|0;n=c[e+48>>2]|0;o=(m+2+(n<<1)>>2)+m|0;p=(2-n+(m<<1)>>2)-n|0;n=l+d+1|0;b[k>>1]=(n+o|0)>>>1;m=d-l+1|0;b[k+(f<<1)>>1]=(m+p|0)>>>1;b[k+(h<<1)>>1]=(m-p|0)>>>1;b[k+(i<<1)>>1]=(n-o|0)>>>1}o=j+1|0;if((o|0)<4){j=o;k=k+2|0;e=e+4|0}else{break}}return}function TIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0;f=d;d=a;a=0;while(1){b[f>>1]=c[d>>2];b[f+2>>1]=c[d+4>>2];b[f+4>>1]=c[d+8>>2];b[f+6>>1]=c[d+12>>2];b[f+8>>1]=c[d+16>>2];b[f+10>>1]=c[d+20>>2];b[f+12>>1]=c[d+24>>2];b[f+14>>1]=c[d+28>>2];g=a+1|0;if((g|0)<8){f=f+(e<<1)|0;d=d+32|0;a=g}else{break}}return}function UIa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;b[d>>1]=c[a>>2];TGb(d+2|0,0,14)|0;TGb(d+(e<<1)|0,0,16)|0;a=e<<1;TGb(d+(a<<1)|0,0,16)|0;f=a+e|0;TGb(d+(f<<1)|0,0,16)|0;a=f+e|0;TGb(d+(a<<1)|0,0,16)|0;f=a+e|0;TGb(d+(f<<1)|0,0,16)|0;a=f+e|0;TGb(d+(a<<1)|0,0,16)|0;TGb(d+(a+e<<1)|0,0,16)|0;return}function VIa(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((e|0)==1){f=c;g=a;h=0;while(1){i=f+2|0;b[g>>1]=((b[i>>1]|0)+(b[f>>1]|0)|0)>>>1;j=f+4|0;b[g+2>>1]=((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1;i=f+6|0;b[g+4>>1]=((b[i>>1]|0)+(b[j>>1]|0)|0)>>>1;j=f+8|0;b[g+6>>1]=((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1;i=f+10|0;b[g+8>>1]=((b[i>>1]|0)+(b[j>>1]|0)|0)>>>1;j=f+12|0;b[g+10>>1]=((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1;i=f+14|0;b[g+12>>1]=((b[i>>1]|0)+(b[j>>1]|0)|0)>>>1;b[g+14>>1]=((b[f+16>>1]|0)+(b[i>>1]|0)|0)>>>1;i=h+1|0;if((i|0)<8){f=f+(d<<1)|0;g=g+(d<<1)|0;h=i}else{break}}return}else if((e|0)==3){h=a;g=0;f=c;while(1){i=0;while(1){j=i+1|0;b[h+(i<<1)>>1]=((b[f+(j<<1)>>1]|0)+(b[f+(i<<1)>>1]|0)+(b[f+(i+d<<1)>>1]|0)+(b[f+(j+d<<1)>>1]|0)|0)>>>2;if((j|0)<8){i=j}else{break}}i=g+1|0;if((i|0)<8){h=h+(d<<1)|0;g=i;f=f+(d<<1)|0}else{break}}return}else if((e|0)==2){f=a;g=0;h=c;while(1){i=h+(d<<1)|0;b[f>>1]=((b[i>>1]|0)+(b[h>>1]|0)|0)>>>1;b[f+2>>1]=((b[h+(d+1<<1)>>1]|0)+(b[h+2>>1]|0)|0)>>>1;b[f+4>>1]=((b[h+(d+2<<1)>>1]|0)+(b[h+4>>1]|0)|0)>>>1;b[f+6>>1]=((b[h+(d+3<<1)>>1]|0)+(b[h+6>>1]|0)|0)>>>1;b[f+8>>1]=((b[h+(d+4<<1)>>1]|0)+(b[h+8>>1]|0)|0)>>>1;b[f+10>>1]=((b[h+(d+5<<1)>>1]|0)+(b[h+10>>1]|0)|0)>>>1;b[f+12>>1]=((b[h+(d+6<<1)>>1]|0)+(b[h+12>>1]|0)|0)>>>1;b[f+14>>1]=((b[h+(d+7<<1)>>1]|0)+(b[h+14>>1]|0)|0)>>>1;j=g+1|0;if((j|0)<8){f=f+(d<<1)|0;g=j;h=i}else{break}}return}else if((e|0)==0){e=c;c=a;a=0;while(1){b[c>>1]=b[e>>1]|0;b[c+2>>1]=b[e+2>>1]|0;b[c+4>>1]=b[e+4>>1]|0;b[c+6>>1]=b[e+6>>1]|0;b[c+8>>1]=b[e+8>>1]|0;b[c+10>>1]=b[e+10>>1]|0;b[c+12>>1]=b[e+12>>1]|0;b[c+14>>1]=b[e+14>>1]|0;h=a+1|0;if((h|0)<8){e=e+(d<<1)|0;c=c+(d<<1)|0;a=h}else{break}}return}else{return}}function WIa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)==3){g=a;h=0;i=c;while(1){j=0;while(1){k=j+1|0;l=g+(j<<1)|0;b[l>>1]=(((b[i+(k<<1)>>1]|0)+(b[i+(j<<1)>>1]|0)+(b[i+(j+d<<1)>>1]|0)+(b[i+(k+d<<1)>>1]|0)|0)>>>2)+(e[l>>1]|0);if((k|0)<8){j=k}else{break}}j=h+1|0;if((j|0)<8){g=g+(d<<1)|0;h=j;i=i+(d<<1)|0}else{break}}return}else if((f|0)==1){i=c;h=a;g=0;while(1){j=i+2|0;b[h>>1]=(((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1)+(e[h>>1]|0);k=i+4|0;l=h+2|0;b[l>>1]=(((b[k>>1]|0)+(b[j>>1]|0)|0)>>>1)+(e[l>>1]|0);l=i+6|0;j=h+4|0;b[j>>1]=(((b[l>>1]|0)+(b[k>>1]|0)|0)>>>1)+(e[j>>1]|0);j=i+8|0;k=h+6|0;b[k>>1]=(((b[j>>1]|0)+(b[l>>1]|0)|0)>>>1)+(e[k>>1]|0);k=i+10|0;l=h+8|0;b[l>>1]=(((b[k>>1]|0)+(b[j>>1]|0)|0)>>>1)+(e[l>>1]|0);l=i+12|0;j=h+10|0;b[j>>1]=(((b[l>>1]|0)+(b[k>>1]|0)|0)>>>1)+(e[j>>1]|0);j=i+14|0;k=h+12|0;b[k>>1]=(((b[j>>1]|0)+(b[l>>1]|0)|0)>>>1)+(e[k>>1]|0);k=h+14|0;b[k>>1]=(((b[i+16>>1]|0)+(b[j>>1]|0)|0)>>>1)+(e[k>>1]|0);k=g+1|0;if((k|0)<8){i=i+(d<<1)|0;h=h+(d<<1)|0;g=k}else{break}}return}else if((f|0)==0){g=c;h=a;i=0;while(1){b[h>>1]=(b[h>>1]|0)+(b[g>>1]|0);k=h+2|0;b[k>>1]=(b[k>>1]|0)+(b[g+2>>1]|0);k=h+4|0;b[k>>1]=(b[k>>1]|0)+(b[g+4>>1]|0);k=h+6|0;b[k>>1]=(b[k>>1]|0)+(b[g+6>>1]|0);k=h+8|0;b[k>>1]=(b[k>>1]|0)+(b[g+8>>1]|0);k=h+10|0;b[k>>1]=(b[k>>1]|0)+(b[g+10>>1]|0);k=h+12|0;b[k>>1]=(b[k>>1]|0)+(b[g+12>>1]|0);k=h+14|0;b[k>>1]=(b[k>>1]|0)+(b[g+14>>1]|0);k=i+1|0;if((k|0)<8){g=g+(d<<1)|0;h=h+(d<<1)|0;i=k}else{break}}return}else if((f|0)==2){f=a;a=0;i=c;while(1){c=i+(d<<1)|0;b[f>>1]=(((b[c>>1]|0)+(b[i>>1]|0)|0)>>>1)+(e[f>>1]|0);h=f+2|0;b[h>>1]=(((b[i+(d+1<<1)>>1]|0)+(b[i+2>>1]|0)|0)>>>1)+(e[h>>1]|0);h=f+4|0;b[h>>1]=(((b[i+(d+2<<1)>>1]|0)+(b[i+4>>1]|0)|0)>>>1)+(e[h>>1]|0);h=f+6|0;b[h>>1]=(((b[i+(d+3<<1)>>1]|0)+(b[i+6>>1]|0)|0)>>>1)+(e[h>>1]|0);h=f+8|0;b[h>>1]=(((b[i+(d+4<<1)>>1]|0)+(b[i+8>>1]|0)|0)>>>1)+(e[h>>1]|0);h=f+10|0;b[h>>1]=(((b[i+(d+5<<1)>>1]|0)+(b[i+10>>1]|0)|0)>>>1)+(e[h>>1]|0);h=f+12|0;b[h>>1]=(((b[i+(d+6<<1)>>1]|0)+(b[i+12>>1]|0)|0)>>>1)+(e[h>>1]|0);h=f+14|0;b[h>>1]=(((b[i+(d+7<<1)>>1]|0)+(b[i+14>>1]|0)|0)>>>1)+(e[h>>1]|0);h=a+1|0;if((h|0)<8){f=f+(d<<1)|0;a=h;i=c}else{break}}return}else{return}}function XIa(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((e|0)==3){f=a;g=0;h=c;while(1){i=h+2|0;j=h+(d<<1)|0;k=h+(d+1<<1)|0;b[f>>1]=((b[i>>1]|0)+(b[h>>1]|0)+(b[j>>1]|0)+(b[k>>1]|0)|0)>>>2;l=h+4|0;m=h+(d+2<<1)|0;b[f+2>>1]=((b[l>>1]|0)+(b[i>>1]|0)+(b[k>>1]|0)+(b[m>>1]|0)|0)>>>2;k=h+6|0;i=h+(d+3<<1)|0;b[f+4>>1]=((b[k>>1]|0)+(b[l>>1]|0)+(b[m>>1]|0)+(b[i>>1]|0)|0)>>>2;b[f+6>>1]=((b[h+8>>1]|0)+(b[k>>1]|0)+(b[i>>1]|0)+(b[h+(d+4<<1)>>1]|0)|0)>>>2;i=g+1|0;if((i|0)<4){f=f+(d<<1)|0;g=i;h=j}else{break}}return}else if((e|0)==1){h=c;g=a;f=0;while(1){j=h+2|0;b[g>>1]=((b[j>>1]|0)+(b[h>>1]|0)|0)>>>1;i=h+4|0;b[g+2>>1]=((b[i>>1]|0)+(b[j>>1]|0)|0)>>>1;j=h+6|0;b[g+4>>1]=((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1;b[g+6>>1]=((b[h+8>>1]|0)+(b[j>>1]|0)|0)>>>1;j=f+1|0;if((j|0)<4){h=h+(d<<1)|0;g=g+(d<<1)|0;f=j}else{break}}return}else if((e|0)==0){b[a>>1]=b[c>>1]|0;b[a+2>>1]=b[c+2>>1]|0;b[a+4>>1]=b[c+4>>1]|0;b[a+6>>1]=b[c+6>>1]|0;b[a+(d<<1)>>1]=b[c+(d<<1)>>1]|0;b[a+(d+1<<1)>>1]=b[c+(d+1<<1)>>1]|0;b[a+(d+2<<1)>>1]=b[c+(d+2<<1)>>1]|0;b[a+(d+3<<1)>>1]=b[c+(d+3<<1)>>1]|0;f=d<<1;g=d<<1;b[a+(f<<1)>>1]=b[c+(g<<1)>>1]|0;b[a+((f|1)<<1)>>1]=b[c+((g|1)<<1)>>1]|0;b[a+(f+2<<1)>>1]=b[c+(g+2<<1)>>1]|0;b[a+(f+3<<1)>>1]=b[c+(g+3<<1)>>1]|0;h=f+d|0;f=g+d|0;b[a+(h<<1)>>1]=b[c+(f<<1)>>1]|0;b[a+(h+1<<1)>>1]=b[c+(f+1<<1)>>1]|0;b[a+(h+2<<1)>>1]=b[c+(f+2<<1)>>1]|0;b[a+(h+3<<1)>>1]=b[c+(f+3<<1)>>1]|0;return}else if((e|0)==2){e=a;a=0;f=c;while(1){c=f+(d<<1)|0;b[e>>1]=((b[c>>1]|0)+(b[f>>1]|0)|0)>>>1;b[e+2>>1]=((b[f+(d+1<<1)>>1]|0)+(b[f+2>>1]|0)|0)>>>1;b[e+4>>1]=((b[f+(d+2<<1)>>1]|0)+(b[f+4>>1]|0)|0)>>>1;b[e+6>>1]=((b[f+(d+3<<1)>>1]|0)+(b[f+6>>1]|0)|0)>>>1;h=a+1|0;if((h|0)<4){e=e+(d<<1)|0;a=h;f=c}else{break}}return}else{return}}function YIa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)==3){g=a;h=0;i=c;while(1){j=i+2|0;k=i+(d<<1)|0;l=i+(d+1<<1)|0;b[g>>1]=(((b[j>>1]|0)+(b[i>>1]|0)+(b[k>>1]|0)+(b[l>>1]|0)|0)>>>2)+(e[g>>1]|0);m=i+4|0;n=i+(d+2<<1)|0;o=g+2|0;b[o>>1]=(((b[m>>1]|0)+(b[j>>1]|0)+(b[l>>1]|0)+(b[n>>1]|0)|0)>>>2)+(e[o>>1]|0);o=i+6|0;l=i+(d+3<<1)|0;j=g+4|0;b[j>>1]=(((b[o>>1]|0)+(b[m>>1]|0)+(b[n>>1]|0)+(b[l>>1]|0)|0)>>>2)+(e[j>>1]|0);j=g+6|0;b[j>>1]=(((b[i+8>>1]|0)+(b[o>>1]|0)+(b[l>>1]|0)+(b[i+(d+4<<1)>>1]|0)|0)>>>2)+(e[j>>1]|0);j=h+1|0;if((j|0)<4){g=g+(d<<1)|0;h=j;i=k}else{break}}return}else if((f|0)==0){b[a>>1]=(b[a>>1]|0)+(b[c>>1]|0);i=a+2|0;b[i>>1]=(b[i>>1]|0)+(b[c+2>>1]|0);i=a+4|0;b[i>>1]=(b[i>>1]|0)+(b[c+4>>1]|0);i=a+6|0;b[i>>1]=(b[i>>1]|0)+(b[c+6>>1]|0);i=a+(d<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(d<<1)>>1]|0);i=a+(d+1<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(d+1<<1)>>1]|0);i=a+(d+2<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(d+2<<1)>>1]|0);i=a+(d+3<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(d+3<<1)>>1]|0);i=d<<1;h=a+(i<<1)|0;g=d<<1;b[h>>1]=(b[h>>1]|0)+(b[c+(g<<1)>>1]|0);h=a+((i|1)<<1)|0;b[h>>1]=(b[h>>1]|0)+(b[c+((g|1)<<1)>>1]|0);h=a+(i+2<<1)|0;b[h>>1]=(b[h>>1]|0)+(b[c+(g+2<<1)>>1]|0);h=a+(i+3<<1)|0;b[h>>1]=(b[h>>1]|0)+(b[c+(g+3<<1)>>1]|0);h=i+d|0;i=a+(h<<1)|0;k=g+d|0;b[i>>1]=(b[i>>1]|0)+(b[c+(k<<1)>>1]|0);i=a+(h+1<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(k+1<<1)>>1]|0);i=a+(h+2<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(k+2<<1)>>1]|0);i=a+(h+3<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(k+3<<1)>>1]|0);return}else if((f|0)==1){k=c;i=a;h=0;while(1){g=k+2|0;b[i>>1]=(((b[g>>1]|0)+(b[k>>1]|0)|0)>>>1)+(e[i>>1]|0);j=k+4|0;l=i+2|0;b[l>>1]=(((b[j>>1]|0)+(b[g>>1]|0)|0)>>>1)+(e[l>>1]|0);l=k+6|0;g=i+4|0;b[g>>1]=(((b[l>>1]|0)+(b[j>>1]|0)|0)>>>1)+(e[g>>1]|0);g=i+6|0;b[g>>1]=(((b[k+8>>1]|0)+(b[l>>1]|0)|0)>>>1)+(e[g>>1]|0);g=h+1|0;if((g|0)<4){k=k+(d<<1)|0;i=i+(d<<1)|0;h=g}else{break}}return}else if((f|0)==2){f=a;a=0;h=c;while(1){c=h+(d<<1)|0;b[f>>1]=(((b[c>>1]|0)+(b[h>>1]|0)|0)>>>1)+(e[f>>1]|0);i=f+2|0;b[i>>1]=(((b[h+(d+1<<1)>>1]|0)+(b[h+2>>1]|0)|0)>>>1)+(e[i>>1]|0);i=f+4|0;b[i>>1]=(((b[h+(d+2<<1)>>1]|0)+(b[h+4>>1]|0)|0)>>>1)+(e[i>>1]|0);i=f+6|0;b[i>>1]=(((b[h+(d+3<<1)>>1]|0)+(b[h+6>>1]|0)|0)>>>1)+(e[i>>1]|0);i=a+1|0;if((i|0)<4){f=f+(d<<1)|0;a=i;h=c}else{break}}return}else{return}}function ZIa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;f=i;g=c[e+60>>2]|0;h=g+80|0;j=g;c[j>>2]=e;yDb(e,48,2352080,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=h;TGb(g+96|0,15,66)|0;c[l>>2]=7;c[g+84>>2]=7;a[g+88|0]=4;a[g+89|0]=4;m=(c[e+216>>2]|0)!=0;n=g+90|0;a[n]=m?1:2;a[g+453|0]=1;o=g+36|0;c[o>>2]=256;p=g+40|0;c[p>>2]=256;a[g+452|0]=m?0:2;m=g+8|0;c[m>>2]=c[e+120>>2];q=g+12|0;c[q>>2]=c[e+124>>2];TGb(g+16|0,8,3)|0;r=g;s=e+140|0;e=c[s>>2]|0;if((e|0)==8){c[g+32>>2]=1}else if((e|0)==2){c[g+32>>2]=3}else{a[g+28|0]=1;c[g+32>>2]=3;_Ga(c[s>>2]|0,g+20|0,g+24|0)}mJa();GPa();s=0;do{e=(s*384|0)-18432|0;c[4977752+(s<<2)>>2]=(e|0)>0?e:0;e=ba(s,s)|0;t=(e<<1)+64&-128;c[4977240+(s<<2)>>2]=(t|0)>0?t:0;t=s>>>5&2|1;u=64-(ba(t<<4,t)|0)+(ba(t-2|0,s)|0)<<7;c[4978776+(s<<2)>>2]=(u|0)>0?u:0;u=((1-(s<<2)<<5)+e<<1)+8192&-128;c[4978264+(s<<2)>>2]=(u|0)>0?u:0;s=s+1|0;}while((s|0)<128);s=g+32|0;u=c[s>>2]|0;if((u|0)>0){e=0;t=0;v=c[l>>2]|0;w=u;while(1){if((v|0)>0){u=r+16+t|0;x=0;y=e;z=0;A=v;while(1){B=A+~z|0;C=(z|0)!=0?3:1;D=(z|0)>0|0;E=x;F=y;G=0;while(1){if((a[n]|0)==2){H=8192e4/(c[1344936+((G+D|0)*40|0)+(B<<2)>>2]|0)|0;I=H>>>0>65535>>>0;J=I?H>>>16:H;K=I?16:0;if((J&65280|0)==0){L=K;M=J}else{L=K|8;M=J>>>8}J=(d[1191992+M|0]|0)+L|0;K=11-J|0;if((K|0)<0){N=H>>J-11&65535}else{N=H<<K&65535}O=N&2047;P=13-J+(d[u]|0)&255}else{O=F;P=(G>>>1&1)+D+(d[u]|0)&255}a[r+164+E|0]=P;b[r+260+(E<<1)>>1]=O;J=G+1|0;if((J|0)<(C|0)){E=E+1|0;F=O;G=J}else{break}}G=z+1|0;Q=c[l>>2]|0;if((G|0)<(Q|0)){x=x+C|0;y=O;z=G;A=Q}else{break}}R=O;S=Q;T=c[s>>2]|0}else{R=e;S=v;T=w}A=t+1|0;if((A|0)<(T|0)){e=R;t=A;v=S;w=T}else{break}}}T=h;h=g+164|0;w=c[o>>2]|0;S=((c[m>>2]|0)-1+w|0)/(w|0)|0;w=g+44|0;c[w>>2]=S;v=c[p>>2]|0;t=((c[q>>2]|0)-1+v|0)/(v|0)|0;v=g+48|0;c[v>>2]=t;R=WDb(ba(S<<2,t)|0)|0;t=g+456|0;c[t>>2]=R;if((R|0)==0){U=-12;i=f;return U|0}R=c[v>>2]|0;a:do{if((R|0)>0){S=g+20|0;e=g+24|0;Q=0;O=0;l=c[w>>2]|0;P=R;b:while(1){N=Q+1|0;if((l|0)>0){L=0;M=O;n=c[s>>2]|0;while(1){A=c[t>>2]|0;z=cEb(n*232|0)|0;y=A+(M<<2)|0;c[y>>2]=z;if((z|0)==0){U=-12;V=42;break b}z=L+1|0;A=0;while(1){W=c[s>>2]|0;if((A|0)>=(W|0)){break}x=c[y>>2]|0;u=x+(A*232|0)|0;G=c[o>>2]|0;F=ba(G,L)|0;E=F&65535;D=x+(A*232|0)+224|0;b[D>>1]=E;B=x+(A*232|0)+216|0;b[B>>1]=E;E=ba(G,z)|0;G=c[m>>2]|0;J=(E|0)>(G|0)?G:E;E=J&65535;G=x+(A*232|0)+226|0;b[G>>1]=E;K=x+(A*232|0)+218|0;b[K>>1]=E;E=c[p>>2]|0;H=ba(E,Q)|0;I=H&65535;X=x+(A*232|0)+228|0;b[X>>1]=I;Y=x+(A*232|0)+220|0;b[Y>>1]=I;I=ba(E,N)|0;E=c[q>>2]|0;Z=(I|0)>(E|0)?E:I;I=Z&65535;E=x+(A*232|0)+230|0;b[E>>1]=I;_=x+(A*232|0)+222|0;b[_>>1]=I;do{if((A|0)>0){I=c[S>>2]|0;x=1<<I;$=(F&65535)-1+x>>I&65535;b[D>>1]=$;b[B>>1]=$;$=(J&65535)-1+x>>I&65535;b[G>>1]=$;b[K>>1]=$;$=c[e>>2]|0;x=1<<$;aa=(H&65535)-1+x>>$&65535;b[X>>1]=aa;b[Y>>1]=aa;aa=(Z&65535)-1+x>>$&65535;b[E>>1]=aa;b[_>>1]=aa;ca=d[r+16+A|0]|0;da=I;ea=$;V=36}else{$=d[r+16+A|0]|0;if((A|0)==0){fa=1;ga=1;ha=$;break}ca=$;da=c[S>>2]|0;ea=c[e>>2]|0;V=36}}while(0);if((V|0)==36){V=0;fa=1<<ea;ga=1<<da;ha=ca}_=oJa(u,T,h,ha,ga,fa,c[j>>2]|0)|0;if((_|0)==0){A=A+1|0}else{U=_;V=42;break b}}ia=M+1|0;ja=c[w>>2]|0;if((z|0)<(ja|0)){L=z;M=ia;n=W}else{break}}ka=ia;la=ja;ma=c[v>>2]|0}else{ka=O;la=l;ma=P}if((N|0)<(ma|0)){Q=N;O=ka;l=la;P=ma}else{break a}}if((V|0)==42){i=f;return U|0}}}while(0);yDb(c[j>>2]|0,48,2331952,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;U=0;i=f;return U|0}function _Ia(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0;k=i;i=i+33848|0;l=k|0;m=c[f+60>>2]|0;n=m;o=(ba((c[f+120>>2]|0)*9|0,c[f+124>>2]|0)|0)+16384|0;p=r0a(f,g,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=k;return q|0}p=g+24|0;o=c[p>>2]|0;f=m+52|0;c[f>>2]=o;r=m+56|0;c[r>>2]=o;s=g+28|0;t=(c[p>>2]|0)+(c[s>>2]|0)|0;p=m+60|0;c[p>>2]=t;c[m+4>>2]=h;u=c[h+168>>2]|0;v=gHb(u,(u|0)<0|0?-1:0,1e8,0)|0;u=m+72|0;c[u>>2]=v;c[u+4>>2]=F;v=m+44|0;w=c[v>>2]|0;y=m+48|0;z=c[y>>2]|0;if((ba(z,w)|0)>0){A=m+28|0;B=m+32|0;C=c[m+456>>2]|0;D=0;while(1){E=C+(D<<2)|0;a:do{if((a[A]|0)==0){G=c[E>>2]|0;H=b[G+220>>1]|0;I=H&65535;J=b[G+222>>1]|0;if(!((H&65535)>>>0<(J&65535)>>>0)){break}H=b[G+216>>1]|0;K=h+32|0;L=c[B>>2]|0;M=H&65535;N=c[K>>2]|0;O=(ba(N,I)|0)+(ba(M,L)|0)|0;P=b[G+218>>1]|0;Q=(H&65535)>>>0<(P&65535)>>>0;H=J&65535;J=P&65535;P=M+1|0;R=(P>>>0>J>>>0?P:J)-M|0;P=0;S=I;I=(c[h>>2]|0)+O|0;O=N;N=L;while(1){if(Q){L=P;T=M;U=I;V=N;while(1){if((V|0)>0){W=0;X=U;while(1){Y=X+1|0;c[(c[G+(W*232|0)+212>>2]|0)+(L<<2)>>2]=(d[X]|0)-128;Z=W+1|0;_=c[B>>2]|0;if((Z|0)<(_|0)){W=Z;X=Y}else{$=Y;aa=_;break}}}else{$=U;aa=V}X=T+1|0;if((X|0)<(J|0)){L=L+1|0;T=X;U=$;V=aa}else{break}}ca=R+P|0;da=c[K>>2]|0;ea=aa}else{ca=P;da=O;ea=N}V=S+1|0;if((V|0)>=(H|0)){break a}P=ca;S=V;I=I+da|0;O=da;N=ea}}else{N=c[B>>2]|0;if((N|0)<=0){break}O=c[E>>2]|0;I=0;S=N;while(1){N=b[O+(I*232|0)+220>>1]|0;P=N&65535;H=b[O+(I*232|0)+222>>1]|0;if((N&65535)>>>0<(H&65535)>>>0){N=h+32+(I<<2)|0;K=b[O+(I*232|0)+216>>1]|0;R=c[N>>2]|0;J=K&65535;G=(ba(R,P)|0)+J|0;M=b[O+(I*232|0)+218>>1]|0;Q=(K&65535)>>>0<(M&65535)>>>0;K=H&65535;H=M&65535;M=J+1|0;V=(M>>>0>H>>>0?M:H)-J|0;M=P;P=(c[h+(I<<2)>>2]|0)+G|0;G=c[O+(I*232|0)+212>>2]|0;U=R;while(1){if(Q){R=J;T=G;L=P;while(1){c[T>>2]=(d[L]|0)-128;X=R+1|0;if((X|0)<(H|0)){R=X;T=T+4|0;L=L+1|0}else{break}}fa=G+(V<<2)|0;ga=c[N>>2]|0}else{fa=G;ga=U}L=M+1|0;if((L|0)<(K|0)){M=L;P=P+ga|0;G=fa;U=ga}else{break}}ha=c[B>>2]|0}else{ha=S}U=I+1|0;if((U|0)<(ha|0)){I=U;S=ha}else{break}}}}while(0);E=D+1|0;S=c[v>>2]|0;I=c[y>>2]|0;if((E|0)<(ba(I,S)|0)){D=E}else{ia=S;ja=I;break}}}else{ia=w;ja=z}if((ba(ja,ia)|0)>0){z=m+456|0;w=m+32|0;D=m+80|0;ha=0;B=c[w>>2]|0;ga=ia;ia=ja;while(1){if((B|0)>0){ja=(c[z>>2]|0)+(ha<<2)|0;fa=0;do{qJa((c[ja>>2]|0)+(fa*232|0)|0,D);fa=fa+1|0;ka=c[w>>2]|0;}while((fa|0)<(ka|0));la=ka;ma=c[v>>2]|0;na=c[y>>2]|0}else{la=B;ma=ga;na=ia}fa=ha+1|0;if((fa|0)<(ba(ma,na)|0)){ha=fa;B=la;ga=ma;ia=na}else{break}}oa=c[p>>2]|0;pa=c[r>>2]|0}else{oa=t;pa=o}if((oa-pa|0)<2){q=-1;i=k;return q|0}oa=pa;x=20479;a[oa]=x;x=x>>8;a[oa+1|0]=x;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;pa=m+32|0;if(((c[p>>2]|0)-oa|0)<(((c[pa>>2]|0)*3|0)+40|0)){q=-1;i=k;return q|0}o=oa;x=20991;a[o]=x;x=x>>8;a[o+1|0]=x;o=(c[r>>2]|0)+2|0;c[r>>2]=o;oa=o;x=de(((c[pa>>2]|0)*3|0)+38&65535|0)|0;a[oa]=x;x=x>>8;a[oa+1|0]=x;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;o=oa;x=0;a[o]=x;x=x>>8;a[o+1|0]=x;o=(c[r>>2]|0)+2|0;c[r>>2]=o;oa=o;x=fe(c[m+8>>2]|0)|0;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;oa=(c[r>>2]|0)+4|0;c[r>>2]=oa;o=oa;x=fe(c[m+12>>2]|0)|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=(c[r>>2]|0)+4|0;c[r>>2]=o;oa=o;x=0;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;oa=(c[r>>2]|0)+4|0;c[r>>2]=oa;o=oa;x=0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=(c[r>>2]|0)+4|0;c[r>>2]=o;oa=o;x=fe(c[m+36>>2]|0)|0;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;oa=(c[r>>2]|0)+4|0;c[r>>2]=oa;o=oa;x=fe(c[m+40>>2]|0)|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=(c[r>>2]|0)+4|0;c[r>>2]=o;oa=o;x=0;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;oa=(c[r>>2]|0)+4|0;c[r>>2]=oa;o=oa;x=0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=(c[r>>2]|0)+4|0;c[r>>2]=o;oa=o;x=de(c[pa>>2]&65535|0)|0;a[oa]=x;x=x>>8;a[oa+1|0]=x;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;if((c[pa>>2]|0)>0){o=m+20|0;t=m+24|0;na=0;ia=oa;while(1){a[ia]=7;ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;if((na|0)==0){a[ma]=1;ga=(c[r>>2]|0)+1|0;c[r>>2]=ga;qa=1;ra=ga}else{a[ma]=1<<c[o>>2];ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;qa=1<<c[t>>2]&255;ra=ma}a[ra]=qa;ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;ga=na+1|0;if((ga|0)<(c[pa>>2]|0)){na=ga;ia=ma}else{sa=ma;break}}}else{sa=oa}if(((c[p>>2]|0)-sa|0)<14){q=-1;i=k;return q|0}oa=sa;x=21247;a[oa]=x;x=x>>8;a[oa+1|0]=x;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;sa=oa;x=3072;a[sa]=x;x=x>>8;a[sa+1|0]=x;sa=(c[r>>2]|0)+2|0;c[r>>2]=sa;a[sa]=0;sa=(c[r>>2]|0)+1|0;c[r>>2]=sa;a[sa]=0;sa=(c[r>>2]|0)+1|0;c[r>>2]=sa;oa=sa;x=256;a[oa]=x;x=x>>8;a[oa+1|0]=x;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;sa=m;a[oa]=(c[(c[sa>>2]|0)+140>>2]|0)==5?2:0;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;ia=m+80|0;a[oa]=(c[ia>>2]|0)+255;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;a[oa]=(a[m+88|0]|0)-2;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;a[oa]=(a[m+89|0]|0)-2;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;a[oa]=0;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;na=m+90|0;a[oa]=(a[na]|0)==1|0;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;qa=m+452|0;ra=(c[ia>>2]|0)-1|0;if((a[qa]|0)==0){ta=(ra*3|0)+4|0}else{ta=(ra*6|0)+5|0}if(((c[p>>2]|0)-oa|0)<(ta+2|0)){q=-1;i=k;return q|0}ra=oa;x=23807;a[ra]=x;x=x>>8;a[ra+1|0]=x;ra=(c[r>>2]|0)+2|0;c[r>>2]=ra;oa=ra;x=de(ta&65535|0)|0;a[oa]=x;x=x>>8;a[oa+1|0]=x;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;ta=m+453|0;a[oa]=a[ta]<<5|a[qa];oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;ra=(((c[ia>>2]|0)*3|0)-2|0)>0;do{if((a[qa]|0)==0){if(ra){ua=0;va=oa}else{wa=oa;break}while(1){a[va]=a[n+164+ua|0]<<3;t=(c[r>>2]|0)+1|0;c[r>>2]=t;o=ua+1|0;if((o|0)<(((c[ia>>2]|0)*3|0)-2|0)){ua=o;va=t}else{wa=t;break}}}else{if(ra){xa=0;ya=oa}else{wa=oa;break}while(1){t=ya;x=de(d[n+164+xa|0]<<11|b[n+260+(xa<<1)>>1]|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;t=(c[r>>2]|0)+2|0;c[r>>2]=t;o=xa+1|0;if((o|0)<(((c[ia>>2]|0)*3|0)-2|0)){xa=o;ya=t}else{wa=t;break}}}}while(0);b:do{if((ba(c[y>>2]|0,c[v>>2]|0)|0)>0){ya=m+456|0;xa=l+33808|0;oa=l+33846|0;ra=l+33845|0;va=m+64|0;ua=0;qa=wa;c:while(1){if(((c[p>>2]|0)-qa|0)<12){q=-1;za=299;break}t=qa;x=-28417;a[t]=x;x=x>>8;a[t+1|0]=x;t=(c[r>>2]|0)+2|0;c[r>>2]=t;o=t;x=2560;a[o]=x;x=x>>8;a[o+1|0]=x;o=(c[r>>2]|0)+2|0;c[r>>2]=o;t=o;x=de(ua&65535|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;t=(c[r>>2]|0)+2|0;c[r>>2]=t;o=t;x=0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;ma=(c[r>>2]|0)+4|0;c[r>>2]=ma;a[ma]=0;ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;a[ma]=1;ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;if((t|0)==0){q=-1;za=299;break}if(((c[p>>2]|0)-ma|0)<2){q=-1;za=299;break}ga=ma;x=-27649;a[ga]=x;x=x>>8;a[ga+1|0]=x;c[r>>2]=(c[r>>2]|0)+2;ga=c[ya>>2]|0;d:do{if((c[pa>>2]|0)>0){ma=0;la=ga;while(1){B=c[la+(ua<<2)>>2]|0;yDb(c[sa>>2]|0,48,2109472,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;ha=B+(ma*232|0)+212|0;ka=BJa(B+(ma*232|0)+4|0,c[ha>>2]|0)|0;if((ka|0)!=0){q=ka;za=299;break c}yDb(c[sa>>2]|0,48,2051336,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;ka=c[ia>>2]|0;if((ka|0)>0){w=B+(ma*232|0)|0;D=B+(ma*232|0)+218|0;z=B+(ma*232|0)+216|0;B=0;fa=ka;while(1){ka=c[w>>2]|0;ja=ka+(B*20|0)|0;h=a[ja]|0;if(h<<24>>24==0){Ba=fa}else{ea=ka+(B*20|0)+16|0;ka=(B|0)>0|0;da=(B|0)==0;ca=B-1|0;aa=0;$=h;while(1){h=c[ea>>2]|0;A=c[h+(aa*24|0)+20>>2]|0;if((aa|0)==0){Ca=0}else{C=c[w>>2]|0;Ca=(e[C+(ca*20|0)+8>>1]|0)-(e[C+(ca*20|0)+6>>1]|0)|0}C=h+(aa*24|0)+4|0;I=b[C>>1]|0;S=I&65535;E=h+(aa*24|0)+10|0;O=b[E>>1]|0;U=O&65535;G=(1<<U)+S>>U<<U;U=h+(aa*24|0)+6|0;P=b[U>>1]|0;M=P&65535;K=Ca-S+((G|0)>(M|0)?M:G)|0;G=h+(aa*24|0)|0;M=b[G>>1]|0;S=h+(aa*24|0)+2|0;N=b[S>>1]|0;do{if(M<<16>>16==N<<16>>16|I<<16>>16==P<<16>>16){Da=$}else{V=aa+ka|0;H=A+2|0;J=b[H>>1]|0;if(J<<16>>16==0){Da=$;break}Q=da|(aa|0)==1;L=h+(aa*24|0)+8|0;T=A|0;R=A+12|0;X=h+(aa*24|0)+12|0;W=0;_=0;Y=Ca;Z=K;Ea=M;Fa=N;Ga=O;Ha=P;Ia=I;Ja=J;while(1){if(Q){Ka=0}else{J=c[w>>2]|0;Ka=(e[J+(ca*20|0)+4>>1]|0)-(e[J+(ca*20|0)+2>>1]|0)|0}J=Ea&65535;La=e[L>>1]|0;Ma=(1<<La)+J>>La<<La;La=Fa&65535;if((b[T>>1]|0)==0){Na=_;Oa=Ea;Pa=Fa;Qa=Ga;Ra=Ha;Sa=Ia;Ta=Ja}else{Ua=Z-Y|0;Va=Ua+2|0;Wa=(Va|0)>0;Xa=(Ua|0)>0;Ya=(Y|0)<(Z|0);Za=0;_a=_;$a=Ka;ab=Ka-J+((Ma|0)>(La|0)?La:Ma)|0;while(1){do{if((a[na]|0)==1){if(!Ya){break}Ma=($a|0)<(ab|0);La=Y;do{if(Ma){J=ba((e[D>>1]|0)-(e[z>>1]|0)|0,La)|0;bb=c[ha>>2]|0;cb=$a;db=l+(La-Y<<8)|0;while(1){c[db>>2]=c[bb+(cb+J<<2)>>2]<<6;eb=cb+1|0;if((eb|0)<(ab|0)){cb=eb;db=db+4|0}else{break}}}La=La+1|0;}while((La|0)<(Z|0))}else{if(!Ya){break}La=($a|0)<(ab|0);Ma=Y;do{if(La){db=ba((e[D>>1]|0)-(e[z>>1]|0)|0,Ma)|0;cb=c[ha>>2]|0;J=$a;bb=l+(Ma-Y<<8)|0;while(1){eb=c[cb+(J+db<<2)>>2]|0;c[bb>>2]=eb;fb=1073741824/(c[X>>2]|0)|0;gb=gHb(fb,(fb|0)<0|0?-1:0,eb,(eb|0)<0|0?-1:0)|0;c[bb>>2]=gb>>>9|F<<23;gb=J+1|0;if((gb|0)<(ab|0)){J=gb;bb=bb+4|0}else{break}}}Ma=Ma+1|0;}while((Ma|0)<(Z|0))}}while(0);Ma=c[R>>2]|0;La=ab-$a|0;if(Wa){bb=(La<<2)+8|0;J=0;do{TGb(l+16384+(J*264|0)|0,0,bb|0)|0;J=J+1|0;}while((J|0)<(Va|0))}J=(La|0)>0;do{if(Xa&J){bb=0;db=0;while(1){cb=bb+1|0;gb=0;hb=db;do{eb=l+(bb<<8)+(gb<<2)|0;fb=c[eb>>2]|0;gb=gb+1|0;if((fb|0)<0){ib=l+16384+(cb*264|0)+(gb<<2)|0;c[ib>>2]=c[ib>>2]|32768;ib=-fb|0;c[eb>>2]=ib;jb=ib}else{jb=fb}hb=(hb|0)>(jb|0)?hb:jb;}while((gb|0)<(La|0));if((cb|0)<(Ua|0)){bb=cb;db=hb}else{break}}if((hb|0)==0){za=94;break}db=hb>>>0>65535>>>0;bb=db?hb>>>16:hb;gb=db?16:0;if((bb&65280|0)==0){kb=gb;lb=bb}else{kb=gb|8;lb=bb>>>8}bb=kb+251+(d[1191992+lb|0]|0)|0;a[Ma+(_a*9816|0)+2|0]=bb;gb=bb&255;LPa(xa,Ma+(_a*9816|0)+10|0);if((gb|0)==0){mb=0}else{nb=2;ob=0;pb=gb-1|0;qb=0;rb=0;za=98}}else{za=94}}while(0);if((za|0)==94){za=0;a[Ma+(_a*9816|0)+2|0]=0;LPa(xa,Ma+(_a*9816|0)+10|0);nb=2;ob=0;pb=0;qb=0;rb=0;za=98}if((za|0)==98){while(1){za=0;do{if((nb|0)==0){gb=1<<pb+6;if(!Xa){sb=0;break}bb=(pb|0)>0;db=0;fb=0;while(1){ib=db+4|0;if(J){eb=0;tb=fb;while(1){ub=eb+1|0;if(bb){vb=db;wb=tb;while(1){xb=vb+1|0;yb=l+16384+(xb*264|0)+(ub<<2)|0;zb=c[yb>>2]|0;Ab=zb&255;if((zb&8192|0)!=0|(Ab|0)==0){Bb=wb}else{zb=l+(vb<<8)+(eb<<2)|0;Cb=(c[zb>>2]&gb|0)!=0;MPa(xa,(d[6876544+(Ab<<2)+V|0]|0)+(l+33828)|0,Cb&1);if(Cb){Cb=c[yb>>2]|0;Ab=Cb>>>8&15;Db=Cb&15;MPa(xa,(d[6877568+(Db<<4)+Ab|0]|0)+(l+33828)|0,d[6876288+(Db<<4)+Ab|0]^Cb>>15);Cb=(c[4977752+((c[zb>>2]>>pb&127)<<2)>>2]|0)+wb|0;nJa(l,eb,vb,c[yb>>2]>>15);Eb=Cb}else{Eb=wb}c[yb>>2]=c[yb>>2]|4096;Bb=Eb}if((xb|0)<(Ua|0)&(xb|0)<(ib|0)){vb=xb;wb=Bb}else{Fb=Bb;break}}}else{wb=db;vb=tb;while(1){xb=wb+1|0;yb=l+16384+(xb*264|0)+(ub<<2)|0;Cb=c[yb>>2]|0;zb=Cb&255;if((Cb&8192|0)!=0|(zb|0)==0){Gb=vb}else{Cb=l+(wb<<8)+(eb<<2)|0;Ab=(c[Cb>>2]&gb|0)!=0;MPa(xa,(d[6876544+(zb<<2)+V|0]|0)+(l+33828)|0,Ab&1);if(Ab){Ab=c[yb>>2]|0;zb=Ab>>>8&15;Db=Ab&15;MPa(xa,(d[6877568+(Db<<4)+zb|0]|0)+(l+33828)|0,d[6876288+(Db<<4)+zb|0]^Ab>>15);Ab=(c[4977240+((c[Cb>>2]&127)<<2)>>2]|0)+vb|0;nJa(l,eb,wb,c[yb>>2]>>15);Hb=Ab}else{Hb=vb}c[yb>>2]=c[yb>>2]|4096;Gb=Hb}if((xb|0)<(Ua|0)&(xb|0)<(ib|0)){wb=xb;vb=Gb}else{Fb=Gb;break}}}if((ub|0)<(La|0)){eb=ub;tb=Fb}else{Ib=Fb;break}}}else{Ib=fb}if((ib|0)<(Ua|0)){db=ib;fb=Ib}else{sb=Ib;break}}}else if((nb|0)==2){fb=1<<pb+6;if(!Xa){sb=0;break}db=(pb|0)>0;gb=0;bb=0;while(1){if(J){cb=gb|3;tb=(cb|0)<(Ua|0);eb=gb|1;vb=gb|2;wb=gb+4|0;xb=0;yb=bb;while(1){Ab=xb+1|0;do{if(tb){if((c[l+16384+(eb*264|0)+(Ab<<2)>>2]&12543|0)!=0){Jb=gb;Kb=yb;za=151;break}if((c[l+16384+(vb*264|0)+(Ab<<2)>>2]&12543|0)!=0){Jb=gb;Kb=yb;za=151;break}if((c[l+16384+(cb*264|0)+(Ab<<2)>>2]&12543|0)!=0){Jb=gb;Kb=yb;za=151;break}if((c[l+16384+(wb*264|0)+(Ab<<2)>>2]&12543|0)==0){Lb=0}else{Jb=gb;Kb=yb;za=151;break}while(1){if((Lb|0)>=4){break}if((c[l+(Lb+gb<<8)+(xb<<2)>>2]&fb|0)==0){Lb=Lb+1|0}else{break}}MPa(xa,oa,(Lb|0)!=4|0);if((Lb|0)==4){Mb=yb;break}MPa(xa,ra,Lb>>1);MPa(xa,ra,Lb&1);Cb=Lb+gb|0;if((Cb|0)<(wb|0)){Nb=Cb;Ob=yb}else{Mb=yb;break}while(1){zb=Nb+1|0;Db=l+16384+(zb*264|0)+(Ab<<2)|0;Pb=c[Db>>2]|0;do{if((Pb&12288|0)==0){if((Nb|0)>(Cb|0)){Qb=l+(Nb<<8)+(xb<<2)|0;MPa(xa,(d[6876544+((Pb&255)<<2)+V|0]|0)+(l+33828)|0,(c[Qb>>2]&fb|0)!=0|0);Rb=Qb}else{Rb=l+(Nb<<8)+(xb<<2)|0}Qb=c[Rb>>2]|0;if((Qb&fb|0)==0){Sb=Ob;break}Tb=c[Db>>2]|0;Ub=Tb>>>8&15;Vb=Tb&15;if(db){Wb=4977752+((Qb>>pb&127)<<2)|0}else{Wb=4977240+((Qb&127)<<2)|0}Qb=(c[Wb>>2]|0)+Ob|0;MPa(xa,(d[6877568+(Vb<<4)+Ub|0]|0)+(l+33828)|0,d[6876288+(Vb<<4)+Ub|0]^Tb>>15);nJa(l,xb,Nb,c[Db>>2]>>15);Sb=Qb}else{Sb=Ob}}while(0);c[Db>>2]=c[Db>>2]&-4097;if((zb|0)<(wb|0)){Nb=zb;Ob=Sb}else{Mb=Sb;break}}}else{Jb=gb;Kb=yb;za=151}}while(0);if((za|0)==151){while(1){za=0;ub=Jb+1|0;Cb=l+16384+(ub*264|0)+(Ab<<2)|0;Pb=c[Cb>>2]|0;do{if((Pb&12288|0)==0){Qb=l+(Jb<<8)+(xb<<2)|0;MPa(xa,(d[6876544+((Pb&255)<<2)+V|0]|0)+(l+33828)|0,(c[Qb>>2]&fb|0)!=0|0);Tb=c[Qb>>2]|0;if((Tb&fb|0)==0){Xb=Kb;break}Qb=c[Cb>>2]|0;Ub=Qb>>>8&15;Vb=Qb&15;if(db){Yb=4977752+((Tb>>pb&127)<<2)|0}else{Yb=4977240+((Tb&127)<<2)|0}Tb=(c[Yb>>2]|0)+Kb|0;MPa(xa,(d[6877568+(Vb<<4)+Ub|0]|0)+(l+33828)|0,d[6876288+(Vb<<4)+Ub|0]^Qb>>15);nJa(l,xb,Jb,c[Cb>>2]>>15);Xb=Tb}else{Xb=Kb}}while(0);c[Cb>>2]=c[Cb>>2]&-4097;if((ub|0)<(wb|0)&(ub|0)<(Ua|0)){Jb=ub;Kb=Xb;za=151}else{Mb=Xb;break}}}if((Ab|0)<(La|0)){xb=Ab;yb=Mb}else{Zb=wb;_b=Mb;break}}}else{Zb=gb+4|0;_b=bb}if((Zb|0)<(Ua|0)){gb=Zb;bb=_b}else{sb=_b;break}}}else if((nb|0)==1){bb=1<<pb+6;if(!Xa){sb=0;break}gb=(pb|0)>0;db=0;fb=0;while(1){wb=db+4|0;if(J){yb=0;xb=fb;while(1){cb=yb+1|0;if(gb){vb=db;eb=xb;while(1){tb=vb+1|0;ib=l+16384+(tb*264|0)+(cb<<2)|0;Pb=c[ib>>2]|0;if((Pb&12288|0)==8192){Tb=c[l+(vb<<8)+(yb<<2)>>2]|0;Qb=(c[4978776+((Tb>>pb&127)<<2)>>2]|0)+eb|0;MPa(xa,(d[((Pb&255|0)!=0)+(549232+((Pb>>>14&1)<<1))|0]|0)+(l+33828)|0,(Tb&bb|0)!=0|0);c[ib>>2]=c[ib>>2]|16384;$b=Qb}else{$b=eb}if((tb|0)<(Ua|0)&(tb|0)<(wb|0)){vb=tb;eb=$b}else{ac=$b;break}}}else{eb=db;vb=xb;while(1){Ab=eb+1|0;tb=l+16384+(Ab*264|0)+(cb<<2)|0;Qb=c[tb>>2]|0;if((Qb&12288|0)==8192){ib=c[l+(eb<<8)+(yb<<2)>>2]|0;Tb=(c[4978264+((ib&127)<<2)>>2]|0)+vb|0;MPa(xa,(d[((Qb&255|0)!=0)+(549232+((Qb>>>14&1)<<1))|0]|0)+(l+33828)|0,(ib&bb|0)!=0|0);c[tb>>2]=c[tb>>2]|16384;bc=Tb}else{bc=vb}if((Ab|0)<(Ua|0)&(Ab|0)<(wb|0)){eb=Ab;vb=bc}else{ac=bc;break}}}if((cb|0)<(La|0)){yb=cb;xb=ac}else{cc=ac;break}}}else{cc=fb}if((wb|0)<(Ua|0)){db=wb;fb=cc}else{sb=cc;break}}}else{sb=0}}while(0);b[Ma+(_a*9816|0)+8208+(ob<<4)>>1]=(NPa(xa)|0)+3;fb=_Gb(sb|0,((sb|0)<0|0?-1:0)|0,pb<<1|0)|0;db=YGb(fb,F,rb,qb)|0;fb=F;bb=Ma+(_a*9816|0)+8208+(ob<<4)+8|0;c[bb>>2]=db;c[bb+4>>2]=fb;bb=nb+1|0;gb=(bb|0)==3;xb=(gb<<31>>31)+pb|0;yb=ob+1|0;if((xb|0)>-1){nb=gb?0:bb;ob=yb;pb=xb;qb=fb;rb=db;za=98}else{mb=yb;break}}}La=mb&255;a[Ma+(_a*9816|0)|0]=La;a[Ma+(_a*9816|0)+1|0]=La;b[Ma+(_a*9816|0)+8208+(mb-1<<4)>>1]=OPa(xa)|0;La=(1<<e[L>>1])+ab|0;dc=b[S>>1]|0;ec=b[G>>1]|0;J=(dc&65535)-(ec&65535)+Ka|0;yb=Za+1|0;fc=_a+1|0;if((yb|0)<(e[T>>1]|0)){Za=yb;_a=fc;$a=ab;ab=(La|0)>(J|0)?J:La}else{break}}Na=fc;Oa=ec;Pa=dc;Qa=b[E>>1]|0;Ra=b[U>>1]|0;Sa=b[C>>1]|0;Ta=b[H>>1]|0}ab=(1<<(Qa&65535))+Z|0;$a=(Ra&65535)-(Sa&65535)+Ca|0;_a=W+1|0;if((_a|0)<(Ta&65535|0)){W=_a;_=Na;Y=Z;Z=(ab|0)>($a|0)?$a:ab;Ea=Oa;Fa=Pa;Ga=Qa;Ha=Ra;Ia=Sa;Ja=Ta}else{break}}Da=a[ja]|0}}while(0);C=aa+1|0;if((C|0)<(Da&255|0)){aa=C;$=Da}else{break}}Ba=c[ia>>2]|0}$=B+1|0;if(($|0)<(Ba|0)){B=$;fa=Ba}else{break}}}yDb(c[sa>>2]|0,48,2005896,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;fa=ma+1|0;if((fa|0)>=(c[pa>>2]|0)){break d}ma=fa;la=c[ya>>2]|0}}}while(0);yDb(c[sa>>2]|0,48,1968176,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;la=c[pa>>2]|0;if((la|0)>0){ma=ga+(ua<<2)|0;fa=0;B=c[ia>>2]|0;ha=la;while(1){if((B|0)>0){la=(c[ma>>2]|0)+(fa*232|0)|0;z=0;D=B;w=B;while(1){$=D-1|0;aa=c[la>>2]|0;ja=aa+(z*20|0)+10|0;ca=b[ja>>1]|0;da=aa+(z*20|0)+12|0;ka=b[da>>1]|0;if((ba(ka&65535,ca&65535)|0)==0){gc=w}else{ea=aa+(z*20|0)|0;C=(z|0)>0|0;U=aa+(z*20|0)+16|0;aa=a[ea]|0;E=0;G=aa;S=ca;ca=ka;ka=aa;while(1){if(G<<24>>24==0){hc=0;ic=S;jc=ca;kc=ka}else{aa=0;I=ka;while(1){P=aa+C|0;O=c[U>>2]|0;N=c[O+(aa*24|0)+20>>2]|0;M=N+(E*24|0)+2|0;K=N+(E*24|0)|0;if((ba(e[K>>1]|0,e[M>>1]|0)|0)==0){lc=I}else{h=N+(E*24|0)+12|0;N=O+(aa*24|0)+12|0;O=0;do{A=c[h>>2]|0;Ja=c[u>>2]|0;Ia=c[u+4>>2]|0;Ha=a[A+(O*9816|0)|0]|0;if(Ha<<24>>24==0){mc=0}else{Ga=c[N>>2]|0;Fa=c[1344936+(((a[na]|0)==1|0)*160|0)+(P*40|0)+($<<2)>>2]|0;Ea=gHb(Fa,(Fa|0)<0|0?-1:0,Ga,(Ga|0)<0|0?-1:0)|0;Ga=Ea>>>15|F<<17;Ea=Ga;Fa=(Ga|0)<0|0?-1:0;Ga=Ha&255;Ha=0;Z=0;do{Y=e[A+(O*9816|0)+8208+(Z<<4)>>1]|0;if((Ha|0)==0){nc=0;oc=0;pc=Y}else{_=Ha-1|0;W=A+(O*9816|0)+8208+(_<<4)+8|0;nc=c[W+4>>2]|0;oc=c[W>>2]|0;pc=Y-(e[A+(O*9816|0)+8208+(_<<4)>>1]|0)|0}_=A+(O*9816|0)+8208+(Z<<4)+8|0;Y=ZGb(c[_>>2]|0,c[_+4>>2]|0,oc,nc)|0;_=gHb(Y,F,Ea,Fa)|0;Y=F;W=gHb(_>>>13|Y<<19,Y>>13|((Y|0)<0|0?-1:0)<<19,Ea,Fa)|0;Y=F;_=gHb(pc,(pc|0)<0|0?-1:0,Ja,Ia)|0;H=F;Z=Z+1|0;Ha=(Y|0)<(H|0)|(Y|0)==(H|0)&W>>>0<_>>>0?Ha:Z;}while((Z|0)<(Ga|0));mc=Ha&255}a[A+(O*9816|0)+1|0]=mc;O=O+1|0;}while((O|0)<(ba(e[K>>1]|0,e[M>>1]|0)|0));lc=a[ea]|0}M=aa+1|0;if((M|0)<(lc&255|0)){aa=M;I=lc}else{break}}hc=lc;ic=b[ja>>1]|0;jc=b[da>>1]|0;kc=lc}I=E+1|0;if((I|0)<(ba(ic&65535,jc&65535)|0)){E=I;G=hc;S=ic;ca=jc;ka=kc}else{break}}gc=c[ia>>2]|0}ka=z+1|0;if((ka|0)<(gc|0)){z=ka;D=$;w=gc}else{break}}qc=gc;rc=c[pa>>2]|0}else{qc=B;rc=ha}w=fa+1|0;if((w|0)<(rc|0)){fa=w;B=qc;ha=rc}else{break}}}yDb(c[sa>>2]|0,48,1915560,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;ha=c[ia>>2]|0;if((ha|0)>0){B=0;fa=c[pa>>2]|0;ma=ha;while(1){if((fa|0)>0){ha=(B|0)==0?0:(B*3|0)-2|0;ga=0;w=fa;while(1){D=c[(c[(c[ya>>2]|0)+(ua<<2)>>2]|0)+(ga*232|0)>>2]|0;z=D+(B*20|0)+10|0;la=D+(B*20|0)+12|0;if((ba(e[la>>1]|0,e[z>>1]|0)|0)==0){sc=w}else{ka=D+(B*20|0)|0;ca=D+(B*20|0)+16|0;D=0;do{S=a[ta]|0;a[c[r>>2]|0]=0;c[va>>2]=0;G=a[ka]|0;e:do{if(G<<24>>24==0){tc=1}else{E=c[ca>>2]|0;da=G&255;ja=0;while(1){if((e[E+(ja*24|0)>>1]|0)>>>0<(e[E+(ja*24|0)+2>>1]|0)>>>0){if((e[E+(ja*24|0)+4>>1]|0)>>>0<(e[E+(ja*24|0)+6>>1]|0)>>>0){tc=0;break e}}ea=ja+1|0;if((ea|0)<(da|0)){ja=ea}else{tc=1;break}}}}while(0);c[va>>2]=1;G=c[r>>2]|0;a[G]=(tc&1)<<7^-128|a[G];do{if(tc){if((c[va>>2]|0)==0){break}c[va>>2]=0;c[r>>2]=(c[r>>2]|0)+1}else{G=a[ka]|0;if(G<<24>>24==0){uc=0}else{ja=S-1&255;da=0;E=G;while(1){G=c[ca>>2]|0;ea=c[G+(da*24|0)+20>>2]|0;U=b[ea+(D*24|0)>>1]|0;C=U&65535;do{if((b[G+(da*24|0)>>1]|0)==(b[G+(da*24|0)+2>>1]|0)){vc=E}else{if((b[G+(da*24|0)+4>>1]|0)==(b[G+(da*24|0)+6>>1]|0)){vc=E;break}I=ea+(D*24|0)+2|0;aa=b[I>>1]|0;do{if(!(aa<<16>>16==0)){M=U<<16>>16==0;K=ea+(D*24|0)+12|0;O=ea+(D*24|0)+8|0;P=da+ha+(n+164)|0;N=ea+(D*24|0)+4|0;h=C>>>0>1>>>0?C:1;Ga=0;Z=0;Ia=aa;while(1){if(M){wc=Ga;xc=Ia}else{Ja=ba(Z,C)|0;Fa=Ga;Ea=0;while(1){_=Ea+Ja|0;a[(c[O>>2]|0)+(Fa<<3)|0]=(a[(c[K>>2]|0)+(_*9816|0)+1|0]|0)==0|0;W=c[O>>2]|0;H=W+(Fa<<3)+4|0;Y=c[H>>2]|0;f:do{if((Y|0)!=0){T=W+(Fa<<3)|0;L=H;V=Y;do{R=V|0;X=a[T|0]|0;if(!((d[R]|0)>>>0>(X&255)>>>0)){break f}a[R]=X;T=c[L>>2]|0;L=T+4|0;V=c[L>>2]|0;}while((V|0)!=0)}}while(0);a[(c[N>>2]|0)+(Fa<<3)|0]=(ja+(a[P]|0)&255)-(a[(c[K>>2]|0)+(_*9816|0)+2|0]|0);Y=c[N>>2]|0;H=Y+(Fa<<3)+4|0;W=c[H>>2]|0;g:do{if((W|0)!=0){V=Y+(Fa<<3)|0;L=H;T=W;do{wb=T|0;X=a[V|0]|0;if(!((d[wb]|0)>>>0>(X&255)>>>0)){break g}a[wb]=X;V=c[L>>2]|0;L=V+4|0;T=c[L>>2]|0;}while((T|0)!=0)}}while(0);W=Ea+1|0;if((W|0)<(C|0)){Fa=Fa+1|0;Ea=W}else{break}}wc=Ga+h|0;xc=b[I>>1]|0}Ea=Z+1|0;if((Ea|0)<(xc&65535|0)){Ga=wc;Z=Ea;Ia=xc}else{break}}if(xc<<16>>16==0){break}else{yc=0;zc=0;Ac=xc}while(1){if(M){Bc=yc;Cc=Ac}else{Ia=ba(zc,C)|0;Z=yc;Ga=0;do{h=c[K>>2]|0;P=Ga+Ia|0;if(((c[p>>2]|0)-(c[r>>2]|0)|0)<20){q=-1;za=299;break c}aJa(n,(c[O>>2]|0)+(Z<<3)|0,1);Ma=h+(P*9816|0)+1|0;h:do{if((a[Ma]|0)!=0){aJa(n,(c[N>>2]|0)+(Z<<3)|0,100);Ea=a[Ma]|0;Fa=Ea&255;do{if((Fa|0)==1){Ja=c[va>>2]|0;if((Ja|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;H=W+1|0;c[r>>2]=H;a[H]=0;Dc=c[va>>2]|0}else{Dc=Ja}c[va>>2]=Dc+1}else if((Fa|0)==2){Ja=c[va>>2]|0;if((Ja|0)==8){H=c[r>>2]|0;c[va>>2]=(a[H]|0)==-1;W=H+1|0;c[r>>2]=W;a[W]=0;Ec=c[va>>2]|0}else{Ec=Ja}c[va>>2]=Ec+1;Ja=c[r>>2]|0;a[Ja]=d[Ja]|1<<7-Ec;Ja=c[va>>2]|0;if((Ja|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;H=W+1|0;c[r>>2]=H;a[H]=0;Fc=c[va>>2]|0}else{Fc=Ja}c[va>>2]=Fc+1}else{if((Ea&255)>>>0<6>>>0){Ja=Fa-3|0;H=c[va>>2]|0;if((H|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;Y=W+1|0;c[r>>2]=Y;a[Y]=0;Gc=c[va>>2]|0}else{Gc=H}c[va>>2]=Gc+1;H=c[r>>2]|0;a[H]=d[H]|1<<7-Gc;H=c[va>>2]|0;if((H|0)==8){Y=c[r>>2]|0;c[va>>2]=(a[Y]|0)==-1;W=Y+1|0;c[r>>2]=W;a[W]=0;Hc=c[va>>2]|0}else{Hc=H}c[va>>2]=Hc+1;H=c[r>>2]|0;a[H]=d[H]|1<<7-Hc;H=c[va>>2]|0;if((H|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;Y=W+1|0;c[r>>2]=Y;a[Y]=0;Ic=c[va>>2]|0}else{Ic=H}c[va>>2]=Ic+1;H=c[r>>2]|0;a[H]=d[H]|(Ja>>>1&1)<<7-Ic;H=c[va>>2]|0;if((H|0)==8){Y=c[r>>2]|0;c[va>>2]=(a[Y]|0)==-1;W=Y+1|0;c[r>>2]=W;a[W]=0;Jc=c[va>>2]|0}else{Jc=H}c[va>>2]=Jc+1;H=c[r>>2]|0;a[H]=d[H]|(Ja&1)<<7-Jc;break}else{if((Ea&255)>>>0<37>>>0){Ja=Fa-6|480;H=9;do{H=H-1|0;W=c[va>>2]|0;if((W|0)==8){Y=c[r>>2]|0;c[va>>2]=(a[Y]|0)==-1;_=Y+1|0;c[r>>2]=_;a[_]=0;Kc=c[va>>2]|0}else{Kc=W}c[va>>2]=Kc+1;W=c[r>>2]|0;a[W]=d[W]|(Ja>>>(H>>>0)&1)<<7-Kc;}while((H|0)>0)}else{H=Fa-37|65408;Ja=16;do{Ja=Ja-1|0;cb=c[va>>2]|0;if((cb|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;_=W+1|0;c[r>>2]=_;a[_]=0;Lc=c[va>>2]|0}else{Lc=cb}c[va>>2]=Lc+1;cb=c[r>>2]|0;a[cb]=d[cb]|(H>>>(Ja>>>0)&1)<<7-Lc;}while((Ja|0)>0)}}}}while(0);Fa=d[Ma]|0;Ea=e[h+(P*9816|0)+8208+(Fa-1<<4)>>1]|0;Ja=(Ea&65280|0)==0;H=(Ja?0:8)+(d[1191992+(Ja?Ea:Ea>>>8)|0]|0)|0;Ja=H-(d[1191992+Fa|0]|0)|0;Fa=Ja-2|0;cb=(Fa|0)<0;_=cb?2-Ja|0:0;Ja=cb?0:Fa;if((Ja|0)>0){Fa=Ja;do{Fa=Fa-1|0;Ja=c[va>>2]|0;if((Ja|0)==8){cb=c[r>>2]|0;c[va>>2]=(a[cb]|0)==-1;W=cb+1|0;c[r>>2]=W;a[W]=0;Mc=c[va>>2]|0}else{Mc=Ja}c[va>>2]=Mc+1;Ja=c[r>>2]|0;a[Ja]=d[Ja]|1<<7-Mc;}while((Fa|0)>0)}Fa=c[va>>2]|0;if((Fa|0)==8){Ja=c[r>>2]|0;c[va>>2]=(a[Ja]|0)==-1;W=Ja+1|0;c[r>>2]=W;a[W]=0;Nc=c[va>>2]|0}else{Nc=Fa}Fa=Nc+1|0;c[va>>2]=Fa;W=H+1+_|0;if((W|0)>0){Oc=W;Pc=Fa}else{break}while(1){Fa=Oc-1|0;if((Pc|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;Ja=W+1|0;c[r>>2]=Ja;a[Ja]=0;Qc=c[va>>2]|0}else{Qc=Pc}c[va>>2]=Qc+1;Ja=c[r>>2]|0;a[Ja]=d[Ja]|(Ea>>>(Fa>>>0)&1)<<7-Qc;if((Fa|0)<=0){break h}Oc=Fa;Pc=c[va>>2]|0}}}while(0);Ga=Ga+1|0;Z=Z+1|0;}while((Ga|0)<(C|0));Bc=Z;Cc=b[I>>1]|0}Ga=zc+1|0;if((Ga|0)<(Cc&65535|0)){yc=Bc;zc=Ga;Ac=Cc}else{break}}}}while(0);vc=a[ka]|0}}while(0);C=da+1|0;if((C|0)<(vc&255|0)){da=C;E=vc}else{uc=vc;break}}}if((c[va>>2]|0)==0){Rc=uc}else{c[va>>2]=0;c[r>>2]=(c[r>>2]|0)+1;Rc=a[ka]|0}if(Rc<<24>>24==0){break}else{Sc=0;Tc=Rc}while(1){E=c[(c[ca>>2]|0)+(Sc*24|0)+20>>2]|0;da=b[E+(D*24|0)>>1]|0;ja=da&65535;C=E+(D*24|0)+2|0;ea=b[C>>1]|0;if(ea<<16>>16==0){Uc=Tc}else{U=da<<16>>16==0;da=E+(D*24|0)+12|0;E=0;G=ea;while(1){if(U){Vc=G}else{ea=ba(E,ja)|0;A=0;do{Ha=c[da>>2]|0;I=A+ea|0;aa=a[Ha+(I*9816|0)+1|0]|0;if(!(aa<<24>>24==0)){N=c[r>>2]|0;O=e[Ha+(I*9816|0)+8208+((aa&255)-1<<4)>>1]|0;if(((c[p>>2]|0)-N|0)<(O|0)){q=-1;za=299;break c}UGb(N|0,Ha+(I*9816|0)+10|0,O)|0;c[r>>2]=(c[r>>2]|0)+O}A=A+1|0;}while((A|0)<(ja|0));Vc=b[C>>1]|0}A=E+1|0;if((A|0)<(Vc&65535|0)){E=A;G=Vc}else{break}}Uc=a[ka]|0}G=Sc+1|0;if((G|0)<(Uc&255|0)){Sc=G;Tc=Uc}else{break}}}}while(0);D=D+1|0;}while((D|0)<(ba(e[la>>1]|0,e[z>>1]|0)|0));sc=c[pa>>2]|0}z=ga+1|0;if((z|0)<(sc|0)){ga=z;w=sc}else{break}}Wc=sc;Xc=c[ia>>2]|0}else{Wc=fa;Xc=ma}w=B+1|0;if((w|0)<(Xc|0)){B=w;fa=Wc;ma=Xc}else{break}}}yDb(c[sa>>2]|0,48,1895032,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;yDb(c[sa>>2]|0,48,1939728,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;x=fe(6-t+(c[r>>2]|0)|0)|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;ma=ua+1|0;fa=(ma|0)<(ba(c[y>>2]|0,c[v>>2]|0)|0);B=c[r>>2]|0;if(fa){ua=ma;qa=B}else{Yc=B;break b}}if((za|0)==299){i=k;return q|0}}else{Yc=wa}}while(0);if(((c[p>>2]|0)-Yc|0)<2){q=-1;i=k;return q|0}p=Yc;x=-9729;a[p]=x;x=x>>8;a[p+1|0]=x;c[r>>2]=(c[r>>2]|0)+2;yDb(c[sa>>2]|0,48,2186592,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;c[s>>2]=(c[r>>2]|0)-(c[f>>2]|0);f=g+36|0;c[f>>2]=c[f>>2]|1;c[j>>2]=1;q=0;i=k;return q|0}function $Ia(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a+60>>2]|0;a=b+80|0;d=b+44|0;e=b+48|0;if((ba(c[e>>2]|0,c[d>>2]|0)|0)<=0){f=b+456|0;g=f;$Db(g);return 0}h=b+32|0;i=b+456|0;b=0;while(1){j=(c[i>>2]|0)+(b<<2)|0;if((c[h>>2]|0)>0){k=0;l=j;while(1){rJa((c[l>>2]|0)+(k*232|0)|0,a);m=k+1|0;n=(c[i>>2]|0)+(b<<2)|0;if((m|0)<(c[h>>2]|0)){k=m;l=n}else{o=n;break}}}else{o=j}$Db(o);l=b+1|0;if((l|0)<(ba(c[e>>2]|0,c[d>>2]|0)|0)){b=l}else{f=i;break}}g=f;$Db(g);return 0}function aJa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+120|0;h=g|0;c[h>>2]=e;j=c[e+4>>2]|0;do{if((j|0)==0){k=1;l=0}else{e=1;m=j;while(1){n=m+1|0;if((a[n]|0)!=0){o=5;break}a[n]=1;n=e+1|0;c[h+(e<<2)>>2]=m;p=c[m+4>>2]|0;if((p|0)==0){q=0;r=n;break}else{e=n;m=p}}if((o|0)==5){q=d[m|0]|0;r=e}if((r|0)>0){k=r;l=q;break}i=g;return}}while(0);q=b+64|0;r=b+56|0;b=l;l=k;while(1){k=l-1|0;j=c[h+(k<<2)>>2]|0;p=d[j]|0;if((p|0)>=(f|0)){break}n=p-b|0;p=c[q>>2]|0;if((n|0)>0){s=n;n=p;while(1){t=s-1|0;if((n|0)==8){u=c[r>>2]|0;c[q>>2]=(a[u]|0)==-1;v=u+1|0;c[r>>2]=v;a[v]=0;w=c[q>>2]|0}else{w=n}v=w+1|0;c[q>>2]=v;if((t|0)>0){s=t;n=v}else{x=v;break}}}else{x=p}if((x|0)==8){n=c[r>>2]|0;c[q>>2]=(a[n]|0)==-1;s=n+1|0;c[r>>2]=s;a[s]=0;y=c[q>>2]|0}else{y=x}c[q>>2]=y+1;s=c[r>>2]|0;a[s]=d[s]|1<<7-y;if((k|0)>0){b=d[j]|0;l=k}else{o=20;break}}if((o|0)==20){i=g;return}o=f-b|0;if((o|0)<=0){i=g;return}b=o;o=c[q>>2]|0;do{b=b-1|0;if((o|0)==8){f=c[r>>2]|0;c[q>>2]=(a[f]|0)==-1;l=f+1|0;c[r>>2]=l;a[l]=0;z=c[q>>2]|0}else{z=o}o=z+1|0;c[q>>2]=o;}while((b|0)>0);i=g;return}function bJa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;b=i;i=i+1160|0;g=b|0;h=b+128|0;j=b+1152|0;k=d;l=c[f+24>>2]|0;m=f+28|0;if((c[m>>2]|0)<1){n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}t=a[l]|0;if(t<<24>>24==0){n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}else{u=l;v=t}while(1){t=u+1|0;if(!(v<<24>>24==32|(v-9&255)>>>0<5>>>0)){break}u=t;v=a[t]|0}v=Vb(u|0,32)|0;if((v|0)==0){n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}u=Vb(v+1|0,32)|0;if((u|0)==0){n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}v=u+1|0;IAb(h,512,512);u=g|0;t=a[v]|0;l=t<<24>>24;TGb(u|0,0,128)|0;do{if(((((l-97|0)>>>0<26>>>0?l^32:l)<<24)-1073741825|0)>>>0<452984832>>>0){w=g+127|0;x=v;y=u;z=t;while(1){A=x+1|0;B=y+1|0;a[y]=((z<<24>>24)-97|0)>>>0<26>>>0?z^32:z;C=a[A]|0;if((C<<24>>24|0)==0|(C<<24>>24|0)==32){break}if((C-9&255)>>>0>4>>>0&B>>>0<w>>>0){x=A;y=B;z=C}else{break}}a[B]=0;if(!(C<<24>>24==32|(C-9&255)>>>0<5>>>0)){D=A;break}z=x+2|0;while(1){y=a[z]|0;if(y<<24>>24==32|(y-9&255)>>>0<5>>>0){z=z+1|0}else{D=z;break}}}else{D=v}}while(0);do{if((yb(u|0,2186584)|0)==0){if((yb(u|0,2109464)|0)!=0){E=2;break}v=(yb(u|0,2051328)|0)==0;E=v?0:4}else{E=1}}while(0);do{if((yb(u|0,2005872)|0)==0){if((yb(u|0,1968168)|0)!=0){F=16;G=19;break}v=(yb(u|0,1939720)|0)==0;A=(E|0)!=0;if(!(v&(A^1))){H=v?0:32;I=A;J=v;G=21}}else{F=8;G=19}}while(0);if((G|0)==19){H=F;I=(E|0)!=0;J=0;G=21}a:do{if((G|0)==21){switch((J?8:H)|(I?E:1)|0){case 34:{KAb(h,2289192,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 18:{KAb(h,2331944,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 12:{KAb(h,2257512,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 33:{KAb(h,2352072,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 36:{KAb(h,2243288,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 9:{KAb(h,1895024,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 20:{KAb(h,2273088,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 17:{KAb(h,1915552,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 10:{KAb(h,2307584,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};default:{break a}}}}while(0);E=a[D]|0;b:do{if(!(E<<24>>24==0)){I=E;H=D;while(1){J=H+1|0;c:do{if((I<<24>>24|0)==10|(I<<24>>24|0)==0){break b}else if((I<<24>>24|0)==92){while(1){if((a[J]|0)==10){break}else{L=0}while(1){if(!(L>>>0<14>>>0)){break}F=c[1790472+(L*12|0)>>2]|0;u=SGb(F|0)|0;if((RGb(H,F,u)|0)==0){M=L;N=u;G=42;break c}else{L=L+1|0}}if((L|0)==14){G=44;break c}}u=H+2|0;while(1){F=a[u]|0;if(F<<24>>24==32|(F-9&255)>>>0<5>>>0){u=u+1|0}else{O=u;break}}}else{u=0;while(1){if(u>>>0<14>>>0){F=c[1790472+(u*12|0)>>2]|0;v=SGb(F|0)|0;if((RGb(H,F,v)|0)==0){M=u;N=v;G=42;break}else{u=u+1|0;continue}}if((u|0)==14){G=44;break c}if((I<<24>>24|0)==0|(I<<24>>24|0)==10){break b}else{u=0}}}}while(0);if((G|0)==42){G=0;O=H+((ze[c[1790480+(M*12|0)>>2]&511](h,H+N|0,c[1790476+(M*12|0)>>2]|0)|0)+N)|0}else if((G|0)==44){G=0;KAb(h,2230760,(K=i,i=i+8|0,c[K>>2]=I<<24>>24,K)|0);i=K;O=H+1|0}J=a[O]|0;if(J<<24>>24==0){break}else{I=J;H=O}}}}while(0);KAb(h,2218696,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;QAb(h,j)|0;shb(k,c[j>>2]|0,c[f+8>>2]|0,c[f+48>>2]|0,0)|0;ZDb(c[j>>2]|0);n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}function cJa(a,b,d){a=a|0;b=b|0;d=d|0;b=i;KAb(a,2036472,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;i=b;return 0}function dJa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+72|0;e=b+16|0;f=b+24|0;g=b|0;TGb(g|0,0,16)|0;c[e>>2]=ee(0)|0;nc(e|0,f|0)|0;Ac(g|0,16,d|0,f|0)|0;KAb(a,2036472,(a=i,i=i+8|0,c[a>>2]=g,a)|0);i=a;i=b;return 0}function eJa(a,b,c){a=a|0;b=b|0;c=c|0;return 1}function fJa(a,b,c){a=a|0;b=b|0;c=c|0;return 1}function gJa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=t+h|0;v=h-t|0;t=p+l|0;b[c>>1]=u+t;b[r>>1]=u-t;t=((l-p+v|0)*181|0)>>>8<<16>>16;b[k>>1]=t+v;b[j>>1]=v-t;t=e-s+q|0;s=m+i|0;e=((t-s|0)*98|0)>>>8<<16>>16;v=e+((t*139|0)>>>8<<16>>16)|0;t=e+((s*334|0)>>>8<<16>>16)|0;s=((q+m|0)*181|0)>>>8<<16>>16;m=s+i|0;q=i-s|0;b[n>>1]=v+q;b[o>>1]=q-v;b[g>>1]=t+m;b[f>>1]=m-t;if((d|0)>0){c=c+16|0;d=d-1|0}else{w=a;x=7;break}}while(1){a=b[w>>1]|0;d=w+112|0;c=b[d>>1]|0;t=c+a|0;m=a-c|0;c=w+16|0;a=b[c>>1]|0;f=w+96|0;g=b[f>>1]|0;v=g+a|0;q=a-g|0;g=w+32|0;a=b[g>>1]|0;o=w+80|0;n=b[o>>1]|0;s=n+a|0;i=a-n|0;n=w+48|0;a=b[n>>1]|0;e=w+64|0;j=b[e>>1]|0;k=j+a|0;p=k+t|0;l=t-k|0;k=s+v|0;b[w>>1]=p+k;b[e>>1]=p-k;k=((v-s+l|0)*181|0)>>>8<<16>>16;b[g>>1]=k+l;b[f>>1]=l-k;k=a-j+i|0;j=q+m|0;a=((k-j|0)*98|0)>>>8<<16>>16;l=a+((k*139|0)>>>8<<16>>16)|0;k=a+((j*334|0)>>>8<<16>>16)|0;j=((i+q|0)*181|0)>>>8<<16>>16;q=j+m|0;i=m-j|0;b[o>>1]=l+i;b[n>>1]=i-l;b[c>>1]=k+q;b[d>>1]=q-k;if((x|0)>0){w=w+2|0;x=x-1|0}else{break}}return}function hJa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=t+h|0;v=h-t|0;t=p+l|0;b[c>>1]=u+t;b[r>>1]=u-t;t=((l-p+v|0)*181|0)>>>8<<16>>16;b[k>>1]=t+v;b[j>>1]=v-t;t=e-s+q|0;s=m+i|0;e=((t-s|0)*98|0)>>>8<<16>>16;v=e+((t*139|0)>>>8<<16>>16)|0;t=e+((s*334|0)>>>8<<16>>16)|0;s=((q+m|0)*181|0)>>>8<<16>>16;m=s+i|0;q=i-s|0;b[n>>1]=v+q;b[o>>1]=q-v;b[g>>1]=t+m;b[f>>1]=m-t;if((d|0)>0){c=c+16|0;d=d-1|0}else{w=a;x=7;break}}while(1){a=b[w>>1]|0;d=w+16|0;c=b[d>>1]|0;t=c+a|0;m=w+32|0;f=b[m>>1]|0;g=w+48|0;v=b[g>>1]|0;q=v+f|0;o=w+64|0;n=b[o>>1]|0;s=w+80|0;i=b[s>>1]|0;e=i+n|0;j=w+96|0;k=b[j>>1]|0;p=w+112|0;l=b[p>>1]|0;u=l+k|0;r=a-c|0;c=f-v|0;v=n-i|0;i=k-l|0;l=u+t|0;k=e+q|0;n=t-u|0;b[w>>1]=l+k;b[o>>1]=l-k;k=((q-e+n|0)*181|0)>>>8<<16>>16;b[m>>1]=k+n;b[j>>1]=n-k;k=i+r|0;n=v+c|0;j=r-i|0;b[d>>1]=k+n;b[s>>1]=k-n;n=((c-v+j|0)*181|0)>>>8<<16>>16;b[g>>1]=n+j;b[p>>1]=j-n;if((x|0)>0){w=w+2|0;x=x-1|0}else{break}}return}function iJa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=e-s|0;s=t+h|0;e=h-t|0;t=p+l|0;h=l-p|0;b[c>>1]=s+t<<4;b[r>>1]=s-t<<4;t=(e+h|0)*4433|0;b[k>>1]=((e*6270|0)+256+t|0)>>>9;b[j>>1]=((h*-15137|0)+256+t|0)>>>9;t=u+m|0;h=q+i|0;j=(t+h|0)*9633|0;e=(u+i|0)*-7373|0;k=(q+m|0)*-20995|0;s=j+(t*-16069|0)|0;t=j+(h*-3196|0)|0;b[f>>1]=((u*2446|0)+256+e+s|0)>>>9;b[n>>1]=((q*16819|0)+256+k+t|0)>>>9;b[o>>1]=((m*25172|0)+256+k+s|0)>>>9;b[g>>1]=((i*12299|0)+256+e+t|0)>>>9;if((d|0)>0){c=c+16|0;d=d-1|0}else{v=a;w=7;break}}while(1){a=b[v>>1]|0;d=v+112|0;c=b[d>>1]|0;t=c+a|0;e=a-c|0;c=v+16|0;a=b[c>>1]|0;i=v+96|0;g=b[i>>1]|0;s=g+a|0;k=a-g|0;g=v+32|0;a=b[g>>1]|0;m=v+80|0;o=b[m>>1]|0;q=o+a|0;n=a-o|0;o=v+48|0;a=b[o>>1]|0;u=v+64|0;f=b[u>>1]|0;h=f+a|0;j=a-f|0;f=h+t|0;a=t-h|0;h=q+s|0;t=s-q|0;b[v>>1]=(h+8+f|0)>>>4;b[u>>1]=(8-h+f|0)>>>4;f=(a+t|0)*4433|0;b[g>>1]=(a*6270|0)+65536+f>>17;b[i>>1]=(t*-15137|0)+65536+f>>17;f=j+k|0;t=n+e|0;i=(f+t|0)*9633|0;a=(j+e|0)*-7373|0;g=(n+k|0)*-20995|0;h=i+(f*-16069|0)|0;f=i+(t*-3196|0)|0;b[d>>1]=(j*2446|0)+65536+a+h>>17;b[m>>1]=(n*16819|0)+65536+g+f>>17;b[o>>1]=(k*25172|0)+65536+g+h>>17;b[c>>1]=(e*12299|0)+65536+a+f>>17;if((w|0)>0){v=v+2|0;w=w-1|0}else{break}}return}function jJa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=e-s|0;s=t+h|0;e=h-t|0;t=p+l|0;h=l-p|0;b[c>>1]=s+t<<4;b[r>>1]=s-t<<4;t=(e+h|0)*4433|0;b[k>>1]=((e*6270|0)+256+t|0)>>>9;b[j>>1]=((h*-15137|0)+256+t|0)>>>9;t=u+m|0;h=q+i|0;j=(t+h|0)*9633|0;e=(u+i|0)*-7373|0;k=(q+m|0)*-20995|0;s=j+(t*-16069|0)|0;t=j+(h*-3196|0)|0;b[f>>1]=((u*2446|0)+256+e+s|0)>>>9;b[n>>1]=((q*16819|0)+256+k+t|0)>>>9;b[o>>1]=((m*25172|0)+256+k+s|0)>>>9;b[g>>1]=((i*12299|0)+256+e+t|0)>>>9;if((d|0)>0){c=c+16|0;d=d-1|0}else{v=a;w=7;break}}while(1){a=b[v>>1]|0;d=v+16|0;c=b[d>>1]|0;t=c+a|0;e=v+32|0;i=b[e>>1]|0;g=v+48|0;s=b[g>>1]|0;k=s+i|0;m=v+64|0;o=b[m>>1]|0;q=v+80|0;n=b[q>>1]|0;u=n+o|0;f=v+96|0;h=b[f>>1]|0;j=v+112|0;r=b[j>>1]|0;p=r+h|0;l=a-c|0;c=i-s|0;s=o-n|0;n=h-r|0;r=p+t|0;h=u+k|0;o=k-u|0;u=t-p|0;b[v>>1]=(h+8+r|0)>>>4;b[m>>1]=(8-h+r|0)>>>4;r=(u+o|0)*4433|0;b[e>>1]=(u*6270|0)+65536+r>>17;b[f>>1]=(o*-15137|0)+65536+r>>17;r=n+l|0;o=s+c|0;f=c-s|0;s=l-n|0;b[d>>1]=(o+8+r|0)>>>4;b[q>>1]=(8-o+r|0)>>>4;r=(s+f|0)*4433|0;b[g>>1]=(s*6270|0)+65536+r>>17;b[j>>1]=(f*-15137|0)+65536+r>>17;if((w|0)>0){v=v+2|0;w=w-1|0}else{break}}return}function kJa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=e-s|0;s=t+h|0;e=h-t|0;t=p+l|0;h=l-p|0;b[c>>1]=s+t<<1;b[r>>1]=s-t<<1;t=(e+h|0)*4433|0;b[k>>1]=((e*6270|0)+2048+t|0)>>>12;b[j>>1]=((h*-15137|0)+2048+t|0)>>>12;t=u+m|0;h=q+i|0;j=(t+h|0)*9633|0;e=(u+i|0)*-7373|0;k=(q+m|0)*-20995|0;s=j+(t*-16069|0)|0;t=j+(h*-3196|0)|0;b[f>>1]=((u*2446|0)+2048+e+s|0)>>>12;b[n>>1]=((q*16819|0)+2048+k+t|0)>>>12;b[o>>1]=((m*25172|0)+2048+k+s|0)>>>12;b[g>>1]=((i*12299|0)+2048+e+t|0)>>>12;if((d|0)>0){c=c+16|0;d=d-1|0}else{v=a;w=7;break}}while(1){a=b[v>>1]|0;d=v+112|0;c=b[d>>1]|0;t=c+a|0;e=a-c|0;c=v+16|0;a=b[c>>1]|0;i=v+96|0;g=b[i>>1]|0;s=g+a|0;k=a-g|0;g=v+32|0;a=b[g>>1]|0;m=v+80|0;o=b[m>>1]|0;q=o+a|0;n=a-o|0;o=v+48|0;a=b[o>>1]|0;u=v+64|0;f=b[u>>1]|0;h=f+a|0;j=a-f|0;f=h+t|0;a=t-h|0;h=q+s|0;t=s-q|0;b[v>>1]=(h+2+f|0)>>>2;b[u>>1]=(2-h+f|0)>>>2;f=(a+t|0)*4433|0;b[g>>1]=((a*6270|0)+16384+f|0)>>>15;b[i>>1]=((t*-15137|0)+16384+f|0)>>>15;f=j+k|0;t=n+e|0;i=(f+t|0)*9633|0;a=(j+e|0)*-7373|0;g=(n+k|0)*-20995|0;h=i+(f*-16069|0)|0;f=i+(t*-3196|0)|0;b[d>>1]=((j*2446|0)+16384+a+h|0)>>>15;b[m>>1]=((n*16819|0)+16384+g+f|0)>>>15;b[o>>1]=((k*25172|0)+16384+g+h|0)>>>15;b[c>>1]=((e*12299|0)+16384+a+f|0)>>>15;if((w|0)>0){v=v+2|0;w=w-1|0}else{break}}return}function lJa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=e-s|0;s=t+h|0;e=h-t|0;t=p+l|0;h=l-p|0;b[c>>1]=s+t<<1;b[r>>1]=s-t<<1;t=(e+h|0)*4433|0;b[k>>1]=((e*6270|0)+2048+t|0)>>>12;b[j>>1]=((h*-15137|0)+2048+t|0)>>>12;t=u+m|0;h=q+i|0;j=(t+h|0)*9633|0;e=(u+i|0)*-7373|0;k=(q+m|0)*-20995|0;s=j+(t*-16069|0)|0;t=j+(h*-3196|0)|0;b[f>>1]=((u*2446|0)+2048+e+s|0)>>>12;b[n>>1]=((q*16819|0)+2048+k+t|0)>>>12;b[o>>1]=((m*25172|0)+2048+k+s|0)>>>12;b[g>>1]=((i*12299|0)+2048+e+t|0)>>>12;if((d|0)>0){c=c+16|0;d=d-1|0}else{v=a;w=7;break}}while(1){a=b[v>>1]|0;d=v+16|0;c=b[d>>1]|0;t=c+a|0;e=v+32|0;i=b[e>>1]|0;g=v+48|0;s=b[g>>1]|0;k=s+i|0;m=v+64|0;o=b[m>>1]|0;q=v+80|0;n=b[q>>1]|0;u=n+o|0;f=v+96|0;h=b[f>>1]|0;j=v+112|0;r=b[j>>1]|0;p=r+h|0;l=a-c|0;c=i-s|0;s=o-n|0;n=h-r|0;r=p+t|0;h=u+k|0;o=k-u|0;u=t-p|0;b[v>>1]=(h+2+r|0)>>>2;b[m>>1]=(2-h+r|0)>>>2;r=(u+o|0)*4433|0;b[e>>1]=((u*6270|0)+16384+r|0)>>>15;b[f>>1]=((o*-15137|0)+16384+r|0)>>>15;r=n+l|0;o=s+c|0;f=c-s|0;s=l-n|0;b[d>>1]=(o+2+r|0)>>>2;b[q>>1]=(2-o+r|0)>>>2;r=(s+f|0)*4433|0;b[g>>1]=((s*6270|0)+16384+r|0)>>>15;b[j>>1]=((f*-15137|0)+16384+r|0)>>>15;if((w|0)>0){v=v+2|0;w=w-1|0}else{break}}return}function mJa(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=0;while(1){d=(b>>>1&1)+(b>>>2&1)|0;e=(b>>>3&1)+(b&1)|0;f=(b>>>4&1)+(b>>>5&1)+(b>>>6&1)+(b>>>7&1)|0;g=(f|0)>1;h=(f|0)==1;i=(f|0)>0?6:5;j=d+e|0;k=(j|0)>0?7:6;l=(j|0)>1;m=(j|0)==1;j=m?4:3;do{if((f|0)>2){do{if((d|0)==1){if((e|0)!=0){n=7;o=62;break}a[6876544+(b<<2)|0]=i;o=65}else if((d|0)==2){n=8;o=62}else{if((e|0)==1){a[6876544+(b<<2)|0]=3;o=63;break}else if((e|0)==2){a[6876544+(b<<2)|0]=4;p=8;o=70;break}else{if(g){n=2;o=62;break}n=h&1;o=62;break}}}while(0);if((o|0)==62){o=0;a[6876544+(b<<2)|0]=n;if((e|0)==2){p=8;o=70}else if((e|0)==1){o=63}else{o=65}}do{if((o|0)==63){o=0;if((d|0)!=0){p=7;o=70;break}a[6876545+(b<<2)|0]=i;o=72}else if((o|0)==65){o=0;if((d|0)==2){a[6876545+(b<<2)|0]=4;q=8;break}else if((d|0)==1){a[6876545+(b<<2)|0]=3;o=71;break}else{if(g){p=2;o=70;break}p=h&1;o=70;break}}}while(0);if((o|0)==70){o=0;a[6876545+(b<<2)|0]=p;if((d|0)==1){o=71}else if((d|0)==2){q=8}else{o=72}}do{if((o|0)==71){o=0;q=(e|0)==0?i:7}else if((o|0)==72){o=0;if((e|0)==1){q=3;break}else if((e|0)==2){q=4;break}if(g){q=2;break}q=h&1}}while(0);a[6876546+(b<<2)|0]=q;a[6876547+(b<<2)|0]=8}else{if((f|0)==2){do{if((d|0)==1){if((e|0)!=0){r=7;o=77;break}a[6876544+(b<<2)|0]=i;o=80}else if((d|0)==2){r=8;o=77}else{if((e|0)==2){a[6876544+(b<<2)|0]=4;s=8;o=85;break}else if((e|0)==1){a[6876544+(b<<2)|0]=3;o=78;break}else{if(g){r=2;o=77;break}r=h&1;o=77;break}}}while(0);if((o|0)==77){o=0;a[6876544+(b<<2)|0]=r;if((e|0)==1){o=78}else if((e|0)==2){s=8;o=85}else{o=80}}do{if((o|0)==78){o=0;if((d|0)!=0){s=7;o=85;break}a[6876545+(b<<2)|0]=i;o=87}else if((o|0)==80){o=0;if((d|0)==2){a[6876545+(b<<2)|0]=4;t=8;break}else if((d|0)==1){a[6876545+(b<<2)|0]=3;o=86;break}else{if(g){s=2;o=85;break}s=h&1;o=85;break}}}while(0);if((o|0)==85){o=0;a[6876545+(b<<2)|0]=s;if((d|0)==1){o=86}else if((d|0)==2){t=8}else{o=87}}do{if((o|0)==86){o=0;t=(e|0)==0?i:7}else if((o|0)==87){o=0;if((e|0)==1){t=3;break}else if((e|0)==2){t=4;break}if(g){t=2;break}t=h&1}}while(0);a[6876546+(b<<2)|0]=t;a[6876547+(b<<2)|0]=k;break}do{if((d|0)==2){u=8;o=41}else if((d|0)==1){if((e|0)!=0){u=7;o=41;break}a[6876544+(b<<2)|0]=i;o=44}else{if((e|0)==1){a[6876544+(b<<2)|0]=3;o=42;break}else if((e|0)==2){a[6876544+(b<<2)|0]=4;v=8;o=49;break}else{if(g){u=2;o=41;break}u=h&1;o=41;break}}}while(0);if((o|0)==41){o=0;a[6876544+(b<<2)|0]=u;if((e|0)==1){o=42}else if((e|0)==2){v=8;o=49}else{o=44}}do{if((o|0)==42){o=0;if((d|0)!=0){v=7;o=49;break}a[6876545+(b<<2)|0]=i;o=51}else if((o|0)==44){o=0;if((d|0)==1){a[6876545+(b<<2)|0]=3;o=50;break}else if((d|0)==2){a[6876545+(b<<2)|0]=4;w=8;o=57;break}else{if(g){v=2;o=49;break}v=h&1;o=49;break}}}while(0);if((o|0)==49){o=0;a[6876545+(b<<2)|0]=v;if((d|0)==2){w=8;o=57}else if((d|0)==1){o=50}else{o=51}}do{if((o|0)==50){o=0;w=(e|0)==0?i:7;o=57}else if((o|0)==51){o=0;if((e|0)==2){w=4;o=57;break}else if((e|0)==1){w=3;o=57;break}if(g){w=2;o=57;break}x=6876546+(b<<2)|0;if(h){a[x]=1;o=60;break}else{a[x]=0;o=58;break}}}while(0);if((o|0)==57){o=0;a[6876546+(b<<2)|0]=w;if(h){o=60}else{o=58}}do{if((o|0)==58){o=0;if(l){y=2;break}y=m&1}else if((o|0)==60){o=0;y=l?5:j}}while(0);a[6876547+(b<<2)|0]=y}}while(0);j=b+1|0;if((j|0)<256){b=j}else{z=0;break}}do{b=0;do{y=(b<<8)+z|0;if((y&4|0)==0){A=0}else{A=2-(y>>>10&1)|0}if((y&2|0)==0){B=0}else{B=2-(y>>>11&1)|0}o=(c[1420368+(B*12|0)+(A<<2)>>2]|0)+1|0;if((y&1|0)==0){C=0}else{C=2-(y>>>8&1)|0}if((y&8|0)==0){D=0}else{D=2-(y>>>9&1)|0}y=(c[1420368+(D*12|0)+(C<<2)>>2]|0)+1|0;a[6876288+(z<<4)+b|0]=c[1672+(o*12|0)+(y<<2)>>2];a[6877568+(z<<4)+b|0]=c[1417336+(o*12|0)+(y<<2)>>2];b=b+1|0;}while((b|0)<16);z=z+1|0;}while((z|0)<16);return}function nJa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b+1|0;g=d+1|0;h=a+16384+(g*264|0)+(f<<2)|0;c[h>>2]=c[h>>2]|8192;h=b+2|0;i=a+16384+(g*264|0)+(h<<2)|0;j=c[i>>2]|0;if((e|0)==0){c[i>>2]=j|4;e=a+16384+(g*264|0)+(b<<2)|0;c[e>>2]=c[e>>2]|2;e=a+16384+((d+2|0)*264|0)+(f<<2)|0;c[e>>2]=c[e>>2]|1;e=a+16384+(d*264|0)+(f<<2)|0;c[e>>2]=c[e>>2]|8}else{c[i>>2]=j|1028;j=a+16384+(g*264|0)+(b<<2)|0;c[j>>2]=c[j>>2]|2050;j=a+16384+((d+2|0)*264|0)+(f<<2)|0;c[j>>2]=c[j>>2]|257;j=a+16384+(d*264|0)+(f<<2)|0;c[j>>2]=c[j>>2]|520}j=d+2|0;f=a+16384+(j*264|0)+(h<<2)|0;c[f>>2]=c[f>>2]|32;f=a+16384+(j*264|0)+(b<<2)|0;c[f>>2]=c[f>>2]|16;f=a+16384+(d*264|0)+(h<<2)|0;c[f>>2]=c[f>>2]|128;f=a+16384+(d*264|0)+(b<<2)|0;c[f>>2]=c[f>>2]|64;return}function oJa(f,h,j,k,l,m,n){f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0.0,ha=0.0,ia=0.0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;o=i;p=c[h+4>>2]|0;if((p|0)<1){yDb(n,16,2268016,(q=i,i=i+8|0,c[q>>2]=p,q)|0);i=q;r=-1094995529;i=o;return r|0}s=f+216|0;t=h+10|0;u=AJa(f+4|0,s|0,p-1|0,d[t]|0)|0;if((u|0)!=0){r=u;i=o;return r|0}u=ba((e[f+222>>1]|0)-(e[f+220>>1]|0)|0,(e[f+218>>1]|0)-(e[s>>1]|0)|0)|0;do{if((a[t]|0)==0){c[f+212>>2]=0;if(u>>>0<536870911>>>0){s=cEb(u<<2)|0;c[f+208>>2]=s;if((s|0)==0){r=-12}else{break}i=o;return r|0}else{c[f+208>>2]=0;r=-12;i=o;return r|0}}else{c[f+208>>2]=0;if(u>>>0<536870911>>>0){s=cEb(u<<2)|0;c[f+212>>2]=s;if((s|0)==0){r=-12}else{break}i=o;return r|0}else{c[f+212>>2]=0;r=-12;i=o;return r|0}}}while(0);u=h|0;s=dEb(c[u>>2]|0,20)|0;p=s;v=f|0;c[v>>2]=p;if((s|0)==0){r=-12;i=o;return r|0}s=c[u>>2]|0;if((s|0)<=0){r=0;i=o;return r|0}w=j+288|0;x=n;y=n+12|0;n=l-1|0;z=m-1|0;A=h+8|0;B=h+9|0;C=k+2|0;D=k&255;k=0;E=0;F=s;s=p;a:while(1){p=F-E|0;G=p-1|0;H=(1<<G)-1|0;I=f+224|0;J=H+(e[I>>1]|0)>>G;K=J&65535;b[s+(E*20|0)+2>>1]=K;L=f+226|0;M=H+(e[L>>1]|0)>>G;N=M&65535;b[s+(E*20|0)+4>>1]=N;O=f+228|0;P=H+(e[O>>1]|0)>>G;Q=P&65535;b[s+(E*20|0)+6>>1]=Q;R=f+230|0;S=H+(e[R>>1]|0)>>G;T=S&65535;b[s+(E*20|0)+8>>1]=T;U=a[h+16+E|0]|0;V=s+(E*20|0)+14|0;a[V]=U;W=a[h+49+E|0]|0;X=s+(E*20|0)+15|0;a[X]=W;Y=(E|0)==0;Z=s+(E*20|0)|0;_=Y?1:3;a[Z]=_;if(N<<16>>16==K<<16>>16){b[s+(E*20|0)+10>>1]=0}else{K=U&255;b[s+(E*20|0)+10>>1]=((M&65535)-1+(1<<K)>>K)-((J&65535)>>>(K>>>0))}if(T<<16>>16==Q<<16>>16){b[s+(E*20|0)+12>>1]=0}else{Q=W&255;b[s+(E*20|0)+12>>1]=((S&65535)-1+(1<<Q)>>Q)-((P&65535)>>>(Q>>>0))}Q=dEb(_&255,24)|0;_=Q;P=s+(E*20|0)+16|0;c[P>>2]=_;if((Q|0)==0){r=-12;$=57;break}b:do{if((a[Z]|0)==0){aa=k}else{Q=s+(E*20|0)+10|0;S=s+(E*20|0)+12|0;W=(E|0)!=0|0;T=E-1|0;K=(1<<p)-1|0;J=(E|0)>0|0;M=k;U=0;N=_;while(1){ca=d[w]|0;if((ca|0)==0){g[N+(U*24|0)+16>>2]=1.0}else if((ca|0)==1){da=C+(d[U+J+(687568+(((a[t]|0)==1)<<2))|0]|0)-(d[j+M|0]|0)|0;ea=(e[j+96+(M<<1)>>1]|0)+2048|0;if((da|0)>-1){fa=ea<<da}else{fa=ea>>>((-da|0)>>>0)}g[N+(U*24|0)+16>>2]=+(fa|0)}else if((ca|0)==2){ga=+sGb(1.0,D-(d[j+M|0]|0)|0);g[N+(U*24|0)+16>>2]=ga*(+(e[j+96+(M<<1)>>1]|0)*.00048828125+1.0)}else{g[N+(U*24|0)+16>>2]=0.0;yDb(x,16,2322568,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}ca=(R$a(c[y>>2]|0)|0)==0;da=N+(U*24|0)+16|0;ga=+g[da>>2];if(ca){ha=ga*.5;g[da>>2]=ha;ia=ha}else{ia=ga}c[N+(U*24|0)+12>>2]=~~(ia*32768.0);if(Y){da=H>>G&65535;b[N+(U*24|0)>>1]=da;ca=H+(e[L>>1]|0)-(e[I>>1]|0)>>G&65535;b[N+(U*24|0)+2>>1]=ca;b[N+(U*24|0)+4>>1]=da;ea=H+(e[R>>1]|0)-(e[O>>1]|0)>>G&65535;b[N+(U*24|0)+6>>1]=ea;ja=a[V]|0;ka=a[X]|0;la=a[A]|0;b[N+(U*24|0)+8>>1]=((la&255)>>>0>(ja&255)>>>0?ja:la)&255;la=a[B]|0;ma=a[X]|0;b[N+(U*24|0)+10>>1]=((la&255)>>>0>(ma&255)>>>0?ma:la)&255;na=ja;oa=ka;pa=da;qa=ca;ra=da;sa=ea}else{ea=U+1|0;da=K-((ea&1)<<G)|0;ca=da>>p&65535;b[N+(U*24|0)>>1]=ca;ka=da+(e[L>>1]|0)-(e[I>>1]|0)>>p&65535;b[N+(U*24|0)+2>>1]=ka;da=K-((ea>>>1&1)<<G)|0;ea=da>>p&65535;b[N+(U*24|0)+4>>1]=ea;ja=da+(e[R>>1]|0)-(e[O>>1]|0)>>p&65535;b[N+(U*24|0)+6>>1]=ja;da=a[A]|0;la=(d[V]|0)-1|0;b[N+(U*24|0)+8>>1]=(da&255|0)>(la|0)?la&65535:da&255;da=a[B]|0;la=(d[X]|0)-1|0;b[N+(U*24|0)+10>>1]=(da&255|0)>(la|0)?la&65535:da&255;na=(a[V]|0)-1&255;oa=(a[X]|0)-1&255;pa=ca;qa=ka;ra=ea;sa=ja}ja=N+(U*24|0)|0;b[ja>>1]=(n+(pa&65535)|0)/(l|0)|0;ea=N+(U*24|0)+2|0;b[ea>>1]=(n+(qa&65535)|0)/(l|0)|0;ka=N+(U*24|0)+4|0;b[ka>>1]=(z+(ra&65535)|0)/(m|0)|0;ca=N+(U*24|0)+6|0;b[ca>>1]=(z+(sa&65535)|0)/(m|0)|0;da=dEb(ba(e[S>>1]|0,e[Q>>1]|0)|0,24)|0;la=da;ma=N+(U*24|0)+20|0;c[ma>>2]=la;if((da|0)==0){r=-12;$=57;break a}da=b[Q>>1]|0;ta=ba(e[S>>1]|0,da&65535)|0;c:do{if((ta|0)!=0){ua=na&255;va=1<<ua;wa=oa&255;xa=1<<wa;ya=N+(U*24|0)+8|0;za=N+(U*24|0)+10|0;Aa=U+W|0;Ba=(Aa&1|0)==0;Ca=(Aa&2|0)==0;Da=0;Ea=la;Aa=da;while(1){Fa=((Da|0)%(Aa&65535|0)|0)<<ua;Ga=Fa&65535;Ha=Ea+(Da*24|0)+16|0;b[Ha>>1]=Ga;Ia=b[ja>>1]|0;Ja=(Fa&65535)>>>0>(Ia&65535)>>>0?Ga:Ia;b[Ha>>1]=Ja;Ia=((Da|0)/(e[Q>>1]|0)|0)<<wa;Ga=Ia&65535;Fa=Ea+(Da*24|0)+20|0;b[Fa>>1]=Ga;Ka=b[ka>>1]|0;La=(Ia&65535)>>>0>(Ka&65535)>>>0?Ga:Ka;b[Fa>>1]=La;Ka=Ja&65535;Ja=Ka+va|0;Ga=Ja&65535;Ia=Ea+(Da*24|0)+18|0;b[Ia>>1]=Ga;Ma=b[ea>>1]|0;Na=(Ja&65535)>>>0>(Ma&65535)>>>0?Ma:Ga;b[Ia>>1]=Na;Ga=La&65535;La=Ga+xa|0;Ma=La&65535;Ja=Ea+(Da*24|0)+22|0;b[Ja>>1]=Ma;Oa=b[ca>>1]|0;Pa=(La&65535)>>>0>(Oa&65535)>>>0?Oa:Ma;b[Ja>>1]=Pa;Ma=e[ya>>1]|0;Oa=(Na&65535)-1-Ka+(1<<Ma)>>Ma;Ma=Ea+(Da*24|0)|0;b[Ma>>1]=Oa;Ka=e[za>>1]|0;Na=(Pa&65535)-1-Ga+(1<<Ka)>>Ka;Ka=Ea+(Da*24|0)+2|0;b[Ka>>1]=Na;Ga=pJa(Oa&65535,Na&65535)|0;c[Ea+(Da*24|0)+8>>2]=Ga;if((Ga|0)==0){r=-12;$=57;break a}Ga=pJa(e[Ma>>1]|0,e[Ka>>1]|0)|0;c[Ea+(Da*24|0)+4>>2]=Ga;if((Ga|0)==0){r=-12;$=57;break a}Ga=ba(e[Ka>>1]|0,e[Ma>>1]|0)|0;if(!(Ga>>>0<218773>>>0)){$=42;break a}Na=cEb(Ga*9816|0)|0;Ga=Na;Oa=Ea+(Da*24|0)+12|0;c[Oa>>2]=Ga;if((Na|0)==0){r=-12;$=57;break a}Na=e[Ma>>1]|0;d:do{if((ba(e[Ka>>1]|0,Na)|0)!=0){Pa=0;La=Na;Qa=Ga;while(1){Ra=b[Ha>>1]|0;Sa=Ra&65535;Ta=e[ya>>1]|0;Ua=(Sa>>>(Ta>>>0)<<Ta)+(((Pa|0)%(La|0)|0)<<Ta)|0;Ta=Ua&65535;Va=Ta>>>0>Sa>>>0?Ua&65535:Ra;Ra=Qa+(Pa*9816|0)+9808|0;b[Ra>>1]=Va;Ua=b[Fa>>1]|0;Sa=Ua&65535;Wa=e[za>>1]|0;Xa=(Sa>>>(Wa>>>0)<<Wa)+(((Pa|0)/(e[Ma>>1]|0)|0)<<Wa)|0;Wa=Xa&65535;Ya=Wa>>>0>Sa>>>0?Xa&65535:Ua;Ua=Qa+(Pa*9816|0)+9812|0;b[Ua>>1]=Ya;Xa=(1<<e[ya>>1])+Ta|0;Ta=b[Ia>>1]|0;Sa=(Xa|0)>(Ta&65535|0)?Ta:Xa&65535;Xa=Qa+(Pa*9816|0)+9810|0;b[Xa>>1]=Sa;Ta=(1<<e[za>>1])+Wa|0;Wa=b[Ja>>1]|0;Za=(Ta|0)>(Wa&65535|0)?Wa:Ta&65535;Ta=Qa+(Pa*9816|0)+9814|0;b[Ta>>1]=Za;if(!Ba){Wa=c[v>>2]|0;_a=Wa+(T*20|0)+4|0;$a=Wa+(T*20|0)+2|0;b[Ra>>1]=((b[_a>>1]|0)-(b[$a>>1]|0)&65535)+Va;b[Xa>>1]=((b[_a>>1]|0)-(b[$a>>1]|0)&65535)+Sa}if(!Ca){Sa=c[v>>2]|0;$a=Sa+(T*20|0)+8|0;_a=Sa+(T*20|0)+6|0;b[Ua>>1]=((b[$a>>1]|0)-(b[_a>>1]|0)&65535)+Ya;b[Ta>>1]=((b[$a>>1]|0)-(b[_a>>1]|0)&65535)+Za}a[Qa+(Pa*9816|0)+9|0]=0;a[Qa+(Pa*9816|0)+8|0]=3;b[Qa+(Pa*9816|0)+4>>1]=0;b[Qa+(Pa*9816|0)+6>>1]=0;a[Qa+(Pa*9816|0)|0]=0;Za=Pa+1|0;_a=e[Ma>>1]|0;if((Za|0)>=(ba(e[Ka>>1]|0,_a)|0)){break d}Pa=Za;La=_a;Qa=c[Oa>>2]|0}}}while(0);Oa=Da+1|0;if((Oa|0)>=(ta|0)){break c}Da=Oa;Ea=c[ma>>2]|0;Aa=b[Q>>1]|0}}}while(0);ma=U+1|0;ta=M+1|0;if((ma|0)>=(d[Z]|0)){aa=ta;break b}M=ta;U=ma;N=c[P>>2]|0}}}while(0);P=E+1|0;Z=c[u>>2]|0;if((P|0)>=(Z|0)){r=0;$=57;break}k=aa;E=P;F=Z;s=c[v>>2]|0}if(($|0)==42){c[Ea+(Da*24|0)+12>>2]=0;r=-12;i=o;return r|0}else if(($|0)==57){i=o;return r|0}return 0}function pJa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=sJa(a&65535,b&65535)|0;if(!(d>>>0<268435455>>>0)){e=0;return e|0}f=cEb(d<<3)|0;d=f;if((f|0)==0){e=0;return e|0}if((a|0)>1|(b|0)>1){f=b;b=d;g=a;while(1){a=g+1>>1;h=f+1>>1;i=ba(g,f)|0;j=b+(i<<3)|0;if((f|0)>0&(g|0)>0){k=0;do{l=(ba(k>>1,a)|0)+i|0;m=ba(k,g)|0;n=0;do{c[b+(n+m<<3)+4>>2]=b+(l+(n>>1)<<3);n=n+1|0;}while((n|0)<(g|0));k=k+1|0;}while((k|0)<(f|0))}if((a|0)>1|(h|0)>1){f=h;b=j;g=a}else{o=j;break}}}else{o=d}c[o+4>>2]=0;e=d;return e|0}function qJa(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=i;h=f|0;f=c[h>>2]|0;if((f|0)<=0){i=g;return}j=d|0;d=0;k=f;a:while(1){f=c[j>>2]|0;l=f+(d*20|0)|0;m=a[l]|0;if(m<<24>>24==0){n=k}else{o=f+(d*20|0)+16|0;p=f+(d*20|0)+10|0;q=f+(d*20|0)+12|0;f=0;r=b[p>>1]|0;s=b[q>>1]|0;t=m;while(1){if((ba(s&65535,r&65535)|0)==0){u=r;v=s;w=t}else{m=(c[o>>2]|0)+(f*24|0)+20|0;x=0;do{y=c[m>>2]|0;z=c[y+(x*24|0)+4>>2]|0;A=y+(x*24|0)|0;B=b[A>>1]|0;C=y+(x*24|0)+2|0;D=b[C>>1]|0;if((B&65535)>>>0>1>>>0|(D&65535)>>>0>1>>>0){E=D;F=0;G=B;do{H=G&65535;I=E&65535;F=(ba(I,H)|0)+F|0;J=F+1|0;if(!(J>>>0<2147483647>>>0)){K=9;break a}G=(H+1|0)>>>1&65535;E=(I+1|0)>>>1&65535;}while((G&65535)>>>0>1>>>0|(E&65535)>>>0>1>>>0);if((J|0)>0){L=J;K=12}else{M=B;N=D}}else{L=1;K=12}if((K|0)==12){K=0;E=0;do{a[z+(E<<3)|0]=0;a[z+(E<<3)+1|0]=0;E=E+1|0;}while((E|0)<(L|0));M=b[A>>1]|0;N=b[C>>1]|0}E=c[y+(x*24|0)+8>>2]|0;if((M&65535)>>>0>1>>>0|(N&65535)>>>0>1>>>0){z=N;D=0;B=M;do{G=B&65535;F=z&65535;D=(ba(F,G)|0)+D|0;O=D+1|0;if(!(O>>>0<2147483647>>>0)){K=17;break a}B=(G+1|0)>>>1&65535;z=(F+1|0)>>>1&65535;}while((B&65535)>>>0>1>>>0|(z&65535)>>>0>1>>>0);if((O|0)>0){P=O;K=20}else{Q=M;R=N}}else{P=1;K=20}if((K|0)==20){K=0;z=0;do{a[E+(z<<3)|0]=0;a[E+(z<<3)+1|0]=0;z=z+1|0;}while((z|0)<(P|0));Q=b[A>>1]|0;R=b[C>>1]|0}if((ba(R&65535,Q&65535)|0)!=0){z=y+(x*24|0)+12|0;E=0;do{B=c[z>>2]|0;b[B+(E*9816|0)+4>>1]=0;a[B+(E*9816|0)+8|0]=3;E=E+1|0;}while((E|0)<(ba(e[C>>1]|0,e[A>>1]|0)|0))}x=x+1|0;S=b[p>>1]|0;T=b[q>>1]|0;}while((x|0)<(ba(T&65535,S&65535)|0));u=S;v=T;w=a[l]|0}x=f+1|0;if((x|0)<(w&255|0)){f=x;r=u;s=v;t=w}else{break}}n=c[h>>2]|0}t=d+1|0;if((t|0)<(n|0)){d=t;k=n}else{K=31;break}}if((K|0)==9){yDb(0,0,2186464,(U=i,i=i+24|0,c[U>>2]=2109440,c[U+8>>2]=2051304,c[U+16>>2]=44,U)|0);i=U;Cd()}else if((K|0)==17){yDb(0,0,2186464,(U=i,i=i+24|0,c[U>>2]=2109440,c[U+8>>2]=2051304,c[U+16>>2]=44,U)|0);i=U;Cd()}else if((K|0)==31){i=g;return}}function rJa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=e|0;e=d|0;g=c[e>>2]|0;a:do{if((g|0)!=0){h=0;i=g;while(1){if((h|0)>=(c[f>>2]|0)){break a}j=i+(h*20|0)|0;k=a[j]|0;l=i+(h*20|0)+16|0;if(!(k<<24>>24==0)){m=i+(h*20|0)+10|0;n=i+(h*20|0)+12|0;o=0;p=k;while(1){k=c[l>>2]|0;if((k|0)==0){q=p}else{r=b[m>>1]|0;s=b[n>>1]|0;t=k+(o*24|0)+20|0;if((ba(s&65535,r&65535)|0)!=0){k=0;u=r;r=s;while(1){s=c[t>>2]|0;if((s|0)==0){v=u;w=r}else{$Db(s+(k*24|0)+4|0);$Db(s+(k*24|0)+8|0);$Db(s+(k*24|0)+12|0);v=b[m>>1]|0;w=b[n>>1]|0}s=k+1|0;if((s|0)<(ba(w&65535,v&65535)|0)){k=s;u=v;r=w}else{break}}}$Db(t);q=a[j]|0}r=o+1|0;if((r|0)<(q&255|0)){o=r;p=q}else{break}}}$Db(l);p=c[e>>2]|0;if((p|0)==0){break}else{h=h+1|0;i=p}}}}while(0);DJa(d+4|0);$Db(d);$Db(d+212|0);$Db(d+208|0);return}function sJa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a&65535)>>>0>1>>>0|(b&65535)>>>0>1>>>0){e=b;f=0;g=a}else{h=1;i=d;return h|0}while(1){a=g&65535;b=e&65535;j=(ba(b,a)|0)+f|0;k=j+1|0;if(!(k>>>0<2147483647>>>0)){l=3;break}m=(a+1|0)>>>1&65535;a=(b+1|0)>>>1&65535;if((m&65535)>>>0>1>>>0|(a&65535)>>>0>1>>>0){e=a;f=j;g=m}else{h=k;l=5;break}}if((l|0)==3){yDb(0,0,2186464,(g=i,i=i+24|0,c[g>>2]=2109440,c[g+8>>2]=2051304,c[g+16>>2]=44,g)|0);i=g;Cd();return 0}else if((l|0)==5){i=d;return h|0}return 0}function tJa(a){a=a|0;mJa();GPa();return}function uJa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0.0,Ed=0.0,Fd=0.0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,ee=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0;l=i;i=i+34248|0;m=l|0;n=l+88|0;o=l+384|0;p=l+34232|0;q=c[f+60>>2]|0;r=q;s=h;c[p>>2]=s;c[p+4>>2]=0;c[p+8>>2]=0;t=q+4|0;c[t>>2]=f;u=q+8|0;v=c[k+24>>2]|0;w=c[k+28>>2]|0;if(!((w|0)>-1)){yDb(0,0,2005840,(x=i,i=i+24|0,c[x>>2]=2068720,c[x+8>>2]=2064232,c[x+16>>2]=135,x)|0);i=x;Cd();return 0}k=u;c[k>>2]=v;y=q+16|0;c[y>>2]=v;z=v+w|0;A=q+12|0;c[A>>2]=z;B=q+2664|0;c[B>>2]=-1;C=q+1128|0;TGb(C|0,-1|0,16)|0;a:do{if(w>>>0<2>>>0){D=-1094995529}else{b:do{if(w>>>0>11>>>0){E=v+4|0;c[k>>2]=E;G=v;if((d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)!=201326592){H=65;break}G=v+8|0;c[k>>2]=G;I=E;if((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)!=538988650){H=65;break}I=v+12|0;c[k>>2]=I;E=G;if((d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)!=176622093){H=65;break}E=q+96|0;G=q+1124|0;J=10;K=I;I=z;L=v;while(1){M=I;if(!((M-K|0)>>>0>7>>>0)){break}N=K+4|0;c[k>>2]=N;O=K;P=fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;O=K+8|0;c[k>>2]=O;Q=N;N=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=O;R=Q-8+P-L|0;if((N|0)==1664249962){S=O;T=I;U=L;break b}if((M-Q|0)>>>0<P>>>0|R>>>0<P>>>0){break}c:do{if((N|0)==1748136042&P>>>0>15>>>0){Q=I;M=O;V=L;while(1){W=M+4|0;c[k>>2]=W;X=M;Y=fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0;X=M+8|0;c[k>>2]=X;Z=lc(-8-V+X|0,Y|0)|0;_=Z;if(Y>>>0<8>>>0|_>>>0>R>>>0|F){$=J;aa=Q;ca=V;break c}Z=W;W=fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0;d:do{if((W|0)==1785737827){S=X;T=Q;U=V;break b}else if((W|0)==1885564018){if(!(Y>>>0>5>>>0)){H=56;break}Z=M+10|0;c[k>>2]=Z;da=X;ea=(d[da]|d[da+1|0]<<8)<<16>>16;da=de(ea|0)|0;fa=da&65535;ga=M+11|0;c[k>>2]=ga;ha=a[Z]|0;Z=M+12|0;c[k>>2]=Z;ia=a[ga]&127;ga=ia+1|0;ja=M+13|0;c[k>>2]=ja;ka=a[Z]&127;Z=ka+1|0;la=M+14|0;c[k>>2]=la;ma=a[ja]&127;ja=ma+1|0;if(ha<<24>>24!=3|(da&65535)>>>0>256>>>0|ga>>>0>16>>>0|Z>>>0>16>>>0|ja>>>0>16>>>0|Y>>>0<(ba(((ka+8|0)>>>3)+((ia+8|0)>>>3)+((ma+8|0)>>>3)|0,fa)|0)>>>0){DDb(c[t>>2]|0,2073216,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;da=c[A>>2]|0;ha=c[y>>2]|0;na=da-ha|0;if((_|0)<0){oa=0}else{oa=(na|0)<(_|0)?na:_}pa=ha+oa|0;qa=da;ra=ha;break}a[G]=1;if(ea<<16>>16==0){H=56;break}ea=7-ia|0;ha=Z>>>0<9>>>0;da=7-ka|0;na=ja>>>0<9>>>0;sa=7-ma|0;ta=ma-7|0;ma=ka-7|0;ka=ia-7|0;if(ga>>>0<9>>>0){ia=0;ua=la;while(1){va=ua+1|0;c[k>>2]=va;wa=d[ua]<<ea;xa=wa>>>(ga>>>0)|wa;if(ha){wa=ua+2|0;c[k>>2]=wa;ya=d[va]<<da;za=xa>>>(Z>>>0)|xa;Aa=wa}else{wa=ua+3|0;c[k>>2]=wa;Ba=va;ya=((de((d[Ba]|d[Ba+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ma>>>0);za=xa;Aa=wa}if(na){c[k>>2]=Aa+1;Ca=d[Aa]<<sa;Da=za>>>(ja>>>0)|za}else{c[k>>2]=Aa+2;wa=Aa;Ca=((de((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ta>>>0);Da=za}c[r+100+(ia<<2)>>2]=ya<<8|Da<<16|Ca|-16777216;wa=ia+1|0;if((wa|0)>=(fa|0)){H=56;break d}ia=wa;ua=c[k>>2]|0}}if(ha){ua=0;ia=la;while(1){ga=ia+2|0;c[k>>2]=ga;ea=ia;wa=((de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ka>>>0);ea=ia+3|0;c[k>>2]=ea;xa=wa>>>(Z>>>0)|wa;wa=d[ga]<<da<<8;if(na){c[k>>2]=ia+4;Ea=d[ea]<<sa;Fa=xa>>>(ja>>>0)|xa}else{c[k>>2]=ia+5;ga=ea;Ea=((de((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ta>>>0);Fa=xa}c[r+100+(ua<<2)>>2]=wa|Fa<<16|Ea|-16777216;wa=ua+1|0;if((wa|0)>=(fa|0)){H=56;break d}ua=wa;ia=c[k>>2]|0}}else{ia=0;ua=la;while(1){da=ua+2|0;c[k>>2]=da;Z=ua;ha=((de((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ka>>>0);Z=ua+4|0;c[k>>2]=Z;wa=da;da=((de((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ma>>>0)<<8;if(na){c[k>>2]=ua+5;Ga=d[Z]<<sa;Ha=ha>>>(ja>>>0)|ha}else{c[k>>2]=ua+6;wa=Z;Ga=((de((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ta>>>0);Ha=ha}c[r+100+(ia<<2)>>2]=da|Ha<<16|Ga|-16777216;da=ia+1|0;if((da|0)>=(fa|0)){H=56;break d}ia=da;ua=c[k>>2]|0}}}else if((W|0)==1667523942){if(!(Y>>>0>1>>>0)){H=56;break}ua=M+10|0;c[k>>2]=ua;ia=X;fa=(d[ia]|d[ia+1|0]<<8)<<16>>16;if(fa<<16>>16==0){H=56;break}ia=(de(fa|0)|0)&65535;fa=Q;ta=ua;while(1){ua=fa;if((ua-ta|0)<2){Ia=0;Ja=ta}else{ja=ta+2|0;c[k>>2]=ja;sa=ta;Ia=(de((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535;Ja=ja}if((ua-Ja|0)<2){Ka=Ja}else{ja=Ja+2|0;c[k>>2]=ja;Ka=ja}if((ua-Ka|0)<2){La=0;H=53}else{c[k>>2]=Ka+2;ua=Ka;ja=de((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0;if(Ia>>>0<4>>>0|(ja&65535)>>>0<4>>>0){La=ja&65535;H=53}}if((H|0)==53){H=0;c[r+1128+(Ia<<2)>>2]=La}ja=ia-1|0;if((ja|0)<=0){H=56;break d}ia=ja;fa=c[A>>2]|0;ta=c[k>>2]|0}}else if((W|0)==1668246642){if(!(Y>>>0>6>>>0)){H=56;break}c[k>>2]=M+9;ta=a[X]|0;fa=M+11|0;c[k>>2]=fa;if(!(ta<<24>>24==1)){H=56;break}c[k>>2]=M+15;ta=fa;c[E>>2]=fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0;H=56}else{H=56}}while(0);if((H|0)==56){H=0;X=c[A>>2]|0;Y=c[y>>2]|0;W=X-Y|0;if((_|0)<0){Ma=0}else{Ma=(W|0)<(_|0)?W:_}pa=Y+Ma|0;qa=X;ra=Y}c[k>>2]=pa;if((R-_|0)>>>0>7>>>0){Q=qa;M=pa;V=ra}else{$=J;aa=qa;ca=ra;break}}}else{$=J-1|0;aa=I;ca=L}}while(0);O=aa-ca|0;if((R|0)<0){Na=0}else{Na=(O|0)<(R|0)?O:R}O=ca+Na|0;c[k>>2]=O;if(($|0)==0){break}else{J=$;K=O;I=aa;L=ca}}yDb(f,16,2186384,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break a}else{H=65}}while(0);if((H|0)==65){L=v+((w|0)<0?w:0)|0;c[k>>2]=L;S=L;T=z;U=v}L=T;I=L-S|0;e:do{if(I>>>0>2>>>0){K=S;J=I;while(1){if((J|0)>=2){E=K;if((d[E]|d[E+1|0]<<8)<<16>>16<<16>>16==20479){Oa=K;break e}}E=L-K|0;G=K+(E>>>0>1>>>0?1:E)|0;c[k>>2]=G;E=L-G|0;if(E>>>0>2>>>0){K=G;J=E}else{Oa=G;break}}}else{Oa=S}}while(0);L=Oa+2|0;c[k>>2]=L;I=Oa;if(!((d[I]|d[I+1|0]<<8)<<16>>16<<16>>16==20479)){yDb(f,16,2109416,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break}I=q+1164|0;J=q+1500|0;K=q+2668|0;G=q+1156|0;E=q+1152|0;O=q+20|0;P=q+24|0;N=q+28|0;V=q+32|0;M=q+1144|0;Q=q+1148|0;Y=q+36|0;X=q+40|0;W=q+92|0;ta=q+2672|0;fa=q+88|0;ia=q+1124|0;ja=q+96|0;ua=q+60|0;sa=q+76|0;na=q+64|0;ma=q+80|0;ka=m;la=m+11|0;da=m+15|0;ha=m+12|0;wa=m+13|0;Z=n|0;xa=I;ga=J;ea=q+52|0;Ba=L;L=T;va=U;f:while(1){if((L-Ba|0)>>>0<2>>>0){H=74;break}else{Pa=Ba;Qa=L;Ra=va}while(1){Sa=Pa+2|0;c[k>>2]=Sa;Ta=Pa;Ua=(de((d[Ta]|d[Ta+1|0]<<8)<<16>>16|0)|0)&65535;Va=Sa;Wa=Ra;if((Ua|0)==65497){break f}else if((Ua|0)!=65427){break}Ta=c[K>>2]|0;if((Ta|0)==0){H=77;break f}Xa=c[B>>2]|0;if((Xa|0)<0){H=79;break f}Ya=e[Ta+(Xa*1588|0)+1584>>1]|0;Za=c[Ta+(Xa*1588|0)+1504+(Ya*20|0)+4>>2]|0;if(Za>>>0<Sa>>>0){H=81;break f}_a=Za;Za=_a-Va|0;if(!((Za|0)>-1)){H=83;break f}c[Ta+(Xa*1588|0)+1504+(Ya*20|0)+8>>2]=Sa;c[Ta+(Xa*1588|0)+1504+(Ya*20|0)+16>>2]=Sa;c[Ta+(Xa*1588|0)+1504+(Ya*20|0)+12>>2]=Pa+(Za+2);Za=c[k>>2]|0;Ya=Za;Xa=_a-Ya|0;_a=c[A>>2]|0;Ta=_a;$a=Ta-Ya|0;Ya=Za+($a>>>0>Xa>>>0?Xa:$a)|0;c[k>>2]=Ya;if((Ta-Ya|0)>>>0<2>>>0){H=74;break f}Pa=Ya;Qa=_a;Ra=c[y>>2]|0}_a=Qa;if((_a-Va|0)<2){D=-1094995529;break a}Ya=Pa+4|0;c[k>>2]=Ya;Ta=Sa;$a=de((d[Ta]|d[Ta+1|0]<<8)<<16>>16|0)|0;Ta=$a&65535;if(($a&65535)>>>0<2>>>0){D=-1094995529;break a}$a=Ya;Xa=_a-$a|0;Za=Ta-2|0;if(Xa>>>0<Za>>>0){D=-1094995529;break a}g:do{switch(Ua|0){case 65363:{if(Xa>>>0<2>>>0){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}eb=Pa+5|0;c[k>>2]=eb;fb=d[Ya]|0;gb=c[W>>2]|0;if((fb|0)>=(gb|0)){yDb(c[t>>2]|0,16,2151672,(x=i,i=i+16|0,c[x>>2]=fb,c[x+8>>2]=gb,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1094995529;break g}c[k>>2]=Pa+6;a[xa+(fb*84|0)+11|0]=a[eb]|0;eb=zJa(r,xa+(fb*84|0)|0)|0;if((eb|0)<0){ab=xa;bb=ga;cb=ea;db=eb;break g}eb=ea+fb|0;a[eb]=a[eb]|1;ab=xa;bb=ga;cb=ea;db=0;break};case 65373:{if((Qa|0)==(Ya|0)){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}c[k>>2]=Pa+5;eb=d[Ya]|0;fb=c[W>>2]|0;if((eb|0)<(fb|0)){gb=ea+eb|0;a[gb]=a[gb]|2;ab=xa;bb=ga;cb=ea;db=yJa(r,Ta-1|0,ga+(eb*290|0)|0)|0;break g}else{yDb(c[t>>2]|0,16,2151672,(x=i,i=i+16|0,c[x>>2]=eb,c[x+8>>2]=fb,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1094995529;break g}break};case 65380:{c[k>>2]=Pa+((Xa>>>0>Za>>>0?Za:Xa)+4);ab=xa;bb=ga;cb=ea;db=0;break};case 65365:{if((Xa|0)<1){hb=Ya}else{fb=Pa+5|0;c[k>>2]=fb;hb=fb}if((_a-hb|0)<1){ib=0;jb=hb}else{fb=hb+1|0;c[k>>2]=fb;ib=d[hb]|0;jb=fb}fb=ib>>>6&1;eb=ib>>>4&3;gb=((Ta-4|0)/(eb+2+(fb<<1)|0)|0)&255;if((gb|0)==0){ab=xa;bb=ga;cb=ea;db=0;break g}kb=(fb|0)==0;fb=0;lb=jb;while(1){do{if((eb|0)==1){if((_a-lb|0)<1){mb=lb;break}nb=lb+1|0;c[k>>2]=nb;mb=nb}else if((eb|0)==2){if((_a-lb|0)<2){mb=lb;break}nb=lb+2|0;c[k>>2]=nb;mb=nb}else if((eb|0)==3){if((_a-lb|0)<4){mb=lb;break}nb=lb+4|0;c[k>>2]=nb;mb=nb}else{mb=lb}}while(0);nb=_a-mb|0;do{if(kb){if((nb|0)<2){ob=mb;break}pb=mb+2|0;c[k>>2]=pb;ob=pb}else{if((nb|0)<4){ob=mb;break}pb=mb+4|0;c[k>>2]=pb;ob=pb}}while(0);nb=fb+1&255;if((nb&255)>>>0<gb>>>0){fb=nb;lb=ob}else{ab=xa;bb=ga;cb=ea;db=0;break}}break};case 65361:{h:do{if(Xa>>>0<36>>>0){qb=-1094995529}else{lb=Pa+6|0;c[k>>2]=lb;fb=Ya;gb=(de((d[fb]|d[fb+1|0]<<8)<<16>>16|0)|0)&65535;fb=c[t>>2]|0;c[fb+840>>2]=gb;gb=Pa+10|0;c[k>>2]=gb;kb=lb;c[O>>2]=fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0;kb=Pa+14|0;c[k>>2]=kb;lb=gb;c[P>>2]=fe(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0;lb=Pa+18|0;c[k>>2]=lb;gb=kb;kb=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;c[N>>2]=fe(kb|0)|0;gb=Pa+22|0;c[k>>2]=gb;eb=lb;lb=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;c[V>>2]=fe(lb|0)|0;eb=Pa+26|0;c[k>>2]=eb;R=gb;gb=fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0;c[M>>2]=gb;R=Pa+30|0;c[k>>2]=R;nb=eb;eb=fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0;c[Q>>2]=eb;nb=Pa+34|0;c[k>>2]=nb;pb=R;c[Y>>2]=fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0;pb=Pa+38|0;c[k>>2]=pb;R=nb;c[X>>2]=fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0;R=Pa+40|0;c[k>>2]=R;nb=pb;pb=(d[nb]|d[nb+1|0]<<8)<<16>>16;nb=de(pb|0)|0;rb=nb&65535;if((lb|kb|0)!=0){DDb(fb,2100256,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;qb=-1163346256;break}if(pb<<16>>16==0){yDb(fb,16,2093624,(x=i,i=i+8|0,c[x>>2]=c[W>>2],x)|0);i=x;qb=-1094995529;break}if((nb&65535)>>>0>4>>>0){DDb(fb,2158792,(x=i,i=i+8|0,c[x>>2]=c[W>>2],x)|0);i=x;qb=-1163346256;break}c[W>>2]=rb;if((gb|0)<1|(eb|0)<1){yDb(fb,16,2088432,(x=i,i=i+16|0,c[x>>2]=gb,c[x+8>>2]=eb,x)|0);i=x;qb=-1094995529;break}if((_a-R|0)>>>0<(rb*3|0)>>>0){qb=-1094995529;break}else{sb=0;tb=0;ub=R}while(1){c[k>>2]=ub+1;R=a[ub]|0;eb=(R&127)+1|0;a[r+44+tb|0]=eb;gb=eb&255;eb=c[fa>>2]|0;c[fa>>2]=(gb|0)>(eb|0)?gb:eb;a[r+48+tb|0]=(R&255)>>>7;R=c[k>>2]|0;c[k>>2]=R+1;eb=r+56+(tb<<2)|0;c[eb>>2]=d[R]|0;R=c[k>>2]|0;c[k>>2]=R+1;gb=a[R]|0;vb=gb&255;c[r+72+(tb<<2)>>2]=vb;wb=c[eb>>2]|0;if((wb|0)==0|(wb|0)==3){H=102;break}if((wb|0)>4|gb<<24>>24==0|gb<<24>>24==3|(gb&255)>>>0>4>>>0){H=102;break}gb=tb<<2;xb=wb>>1<<(gb|2)|sb|vb>>>1<<gb;gb=tb+1|0;if((gb|0)>=(c[W>>2]|0)){break}sb=xb;tb=gb;ub=c[k>>2]|0}if((H|0)==102){H=0;yDb(c[t>>2]|0,16,2083656,(x=i,i=i+16|0,c[x>>2]=wb,c[x+8>>2]=vb,x)|0);i=x;qb=-1094995529;break}gb=c[M>>2]|0;eb=c[P>>2]|0;R=c[X>>2]|0;fb=c[Q>>2]|0;pb=((c[O>>2]|0)-1-(c[Y>>2]|0)+gb|0)/(gb|0)|0;c[E>>2]=pb;gb=(eb-1-R+fb|0)/(fb|0)|0;c[G>>2]=gb;fb=gHb(gb,0,pb,0)|0;R=F;eb=0;if(R>>>0>eb>>>0|R>>>0==eb>>>0&fb>>>0>1352319>>>0){c[G>>2]=0;c[E>>2]=0;qb=-22;break}fb=ba(gb,pb)|0;do{if(fb>>>0>1352318>>>0){c[K>>2]=0}else{pb=cEb(fb*1588|0)|0;c[K>>2]=pb;if((pb|0)==0){break}else{yb=0}while(1){if(!(yb>>>0<(ba(c[G>>2]|0,c[E>>2]|0)|0)>>>0)){break}pb=c[K>>2]|0;gb=cEb((c[W>>2]|0)*232|0)|0;c[pb+(yb*1588|0)>>2]=gb;if((gb|0)==0){qb=-12;break h}else{yb=yb+1|0}}_=c[ta>>2]|0;gb=c[t>>2]|0;c[gb+120>>2]=(c[O>>2]|0)-1-(c[N>>2]|0)+(1<<_)>>_;_=c[ta>>2]|0;c[gb+124>>2]=(c[P>>2]|0)-1-(c[V>>2]|0)+(1<<_)>>_;do{if(((c[gb+840>>2]|0)-3|0)>>>0<2>>>0){zb=1;Ab=1664}else{_=c[ja>>2]|0;if((_|0)==17){zb=3;Ab=986128;break}else if((_|0)==18){zb=33;Ab=704;break}else if((_|0)==16){zb=5;Ab=547776;break}else{zb=42;Ab=1798440;break}}}while(0);gb=xb>>>10&3;_=xb>>>8&3;pb=xb>>>6&3;eb=xb>>>4&3;R=(xb&61440|0)!=0;kb=(xb&15|0)!=0;lb=0;i:while(1){Bb=c[Ab+(lb<<2)>>2]|0;Cb=c[fa>>2]|0;Db=a[ia]|0;Eb=bFb(Bb)|0;do{if((d[Eb+4|0]|0)==(rb|0)){if((rb|0)==2){H=125}else if((rb|0)==4){if((((e[Eb+14>>1]|0)>>>11&15)+1|0)<(Cb|0)|R){break}else{H=122}}else if((rb|0)==3){H=122}else if((rb|0)!=1){H=130;break i}if((H|0)==122){H=0;if((((e[Eb+12>>1]|0)>>>11&15)+1|0)<(Cb|0)){break}if((gb|0)!=(d[Eb+5|0]|0)){break}if((_|0)==(d[Eb+6|0]|0)){H=125}else{break}}if((H|0)==125){H=0;if((((e[Eb+10>>1]|0)>>>11&15)+1|0)<(Cb|0)){break}if((pb|0)!=(d[Eb+5|0]|0)){break}if((eb|0)!=(d[Eb+6|0]|0)){break}}if((((e[Eb+8>>1]|0)>>>11&15)+1|0)<(Cb|0)|kb){break}if((a[Eb+7|0]&2|0)==(Db<<1|0)){H=130;break i}}}while(0);Db=lb+1|0;if((Db|0)<(zb|0)){lb=Db}else{Fb=Db;break}}if((H|0)==130){H=0;c[(c[t>>2]|0)+140>>2]=Bb;Fb=lb}if((Fb|0)!=(zb|0)){c[(c[t>>2]|0)+796>>2]=c[fa>>2];qb=0;break h}kb=c[t>>2]|0;eb=c[ja>>2]|0;pb=c[fa>>2]|0;if((nb&65535)>>>0>2>>>0){Gb=c[ma>>2]|0;Hb=c[sa>>2]|0;Ib=c[ua>>2]|0;Jb=c[na>>2]|0}else{Gb=0;Hb=0;Ib=0;Jb=0}yDb(kb,16,2078016,(x=i,i=i+64|0,c[x>>2]=c[kb+840>>2],c[x+8>>2]=eb,c[x+16>>2]=rb,c[x+24>>2]=pb,c[x+32>>2]=Ib,c[x+40>>2]=Hb,c[x+48>>2]=Jb,c[x+56>>2]=Gb,x)|0);i=x;qb=-1163346256;break h}}while(0);c[G>>2]=0;c[E>>2]=0;qb=-12}}while(0);if((c[K>>2]|0)!=0){ab=xa;bb=ga;cb=ea;db=qb;break g}c[G>>2]=0;c[E>>2]=0;ab=xa;bb=ga;cb=ea;db=qb;break};case 65362:{if(Xa>>>0<5>>>0){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}rb=Pa+5|0;c[k>>2]=rb;a[la]=a[Ya]|0;nb=Pa+6|0;c[k>>2]=nb;a[da]=a[rb]|0;rb=Pa+8|0;c[k>>2]=rb;fb=nb;a[ha]=((d[fb]|d[fb+1|0]<<8)<<16>>16&65535)>>>8;c[k>>2]=Pa+9;fb=a[rb]|0;rb=fb&255;a[wa]=fb;do{if(!(fb<<24>>24==0)){nb=c[W>>2]|0;if((nb|0)>=3){break}yDb(c[t>>2]|0,16,2144648,(x=i,i=i+16|0,c[x>>2]=rb,c[x+8>>2]=nb,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1094995529;break g}}while(0);rb=zJa(r,m)|0;if((rb|0)<0){ab=xa;bb=ga;cb=ea;db=rb;break g}rb=c[W>>2]|0;if((rb|0)>0){Kb=0;Lb=rb}else{ab=xa;bb=ga;cb=ea;db=0;break g}while(1){if((a[ea+Kb|0]&1)==0){UGb(xa+(Kb*84|0)|0,ka|0,84)|0;Mb=c[W>>2]|0}else{Mb=Lb}rb=Kb+1|0;if((rb|0)<(Mb|0)){Kb=rb;Lb=Mb}else{ab=xa;bb=ga;cb=ea;db=0;break}}break};case 65424:{if(Xa>>>0<8>>>0){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}c[B>>2]=0;rb=Pa+6|0;c[k>>2]=rb;fb=Ya;nb=de((d[fb]|d[fb+1|0]<<8)<<16>>16|0)|0;fb=nb&65535;if(!(fb>>>0<(ba(c[G>>2]|0,c[E>>2]|0)|0)>>>0)){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}c[B>>2]=fb;pb=Pa+10|0;c[k>>2]=pb;eb=rb;rb=fe(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0;c[k>>2]=Pa+11;eb=a[pb]|0;pb=eb&255;kb=Pa+12|0;c[k>>2]=kb;if(rb>>>0>(_a+2-kb+Ta|0)>>>0){yDb(c[t>>2]|0,16,2165440,(x=i,i=i+8|0,c[x>>2]=rb,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1094995529;break g}if((eb&255)>>>0>3>>>0){DDb(c[t>>2]|0,2158792,(x=i,i=i+8|0,c[x>>2]=pb,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1163346256;break g}kb=c[K>>2]|0;b[kb+(fb*1588|0)+1584>>1]=eb&255;a[kb+(fb*1588|0)+1504+(pb*20|0)|0]=nb;c[kb+(fb*1588|0)+1504+(pb*20|0)+4>>2]=(c[k>>2]|0)+(-2-Ta+rb);if(eb<<24>>24==0){eb=c[K>>2]|0;rb=c[B>>2]|0;UGb(eb+(rb*1588|0)+8|0,I|0,(c[W>>2]|0)*84|0)|0;UGb(eb+(rb*1588|0)+344|0,J|0,(c[W>>2]|0)*290|0)|0}rb=c[B>>2]|0;eb=c[K>>2]|0;ab=eb+(rb*1588|0)+8|0;bb=eb+(rb*1588|0)+344|0;cb=eb+(rb*1588|0)+4|0;db=0;break};case 65372:{TGb(Z|0,0,290)|0;rb=yJa(r,Ta,n)|0;if((rb|0)<0){ab=xa;bb=ga;cb=ea;db=rb;break g}rb=c[W>>2]|0;if((rb|0)>0){Nb=0;Ob=rb}else{ab=xa;bb=ga;cb=ea;db=0;break g}while(1){if((a[ea+Nb|0]&2)==0){UGb(ga+(Nb*290|0)|0,Z|0,290)|0;Pb=c[W>>2]|0}else{Pb=Ob}rb=Nb+1|0;if((rb|0)<(Pb|0)){Nb=rb;Ob=Pb}else{ab=xa;bb=ga;cb=ea;db=0;break}}break};default:{yDb(c[t>>2]|0,16,2192200,(x=i,i=i+16|0,c[x>>2]=Ua,c[x+8>>2]=$a-4-Wa,x)|0);i=x;rb=c[k>>2]|0;eb=(c[A>>2]|0)-rb|0;c[k>>2]=rb+(eb>>>0>Za>>>0?Za:eb);ab=xa;bb=ga;cb=ea;db=0}}}while(0);Za=c[k>>2]|0;$a=c[y>>2]|0;if(!((Wa-Va+Za-$a|0)==(Ta|0)&(db|0)==0)){H=194;break}xa=ab;ga=bb;ea=cb;Ba=Za;L=c[A>>2]|0;va=$a}if((H|0)==74){yDb(c[t>>2]|0,16,2230744,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}else if((H|0)==77){yDb(c[t>>2]|0,16,2218680,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break}else if((H|0)==79){yDb(c[t>>2]|0,16,2209312,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break}else if((H|0)==81){yDb(c[t>>2]|0,16,2200712,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break}else if((H|0)==83){yDb(0,0,2005840,(x=i,i=i+24|0,c[x>>2]=2068720,c[x+8>>2]=2064232,c[x+16>>2]=135,x)|0);i=x;Cd();return 0}else if((H|0)==194){yDb(c[t>>2]|0,16,2175864,(x=i,i=i+8|0,c[x>>2]=Ua,x)|0);i=x;va=(db|0)!=0?db:-1;if((va|0)!=0){D=va;break}}va=W0a(f,p,0)|0;if((va|0)<0){D=va;break}c[h+88>>2]=1;c[h+84>>2]=1;va=q+2660|0;L=0;while(1){Ba=c[E>>2]|0;Qb=ba(c[G>>2]|0,Ba)|0;if(!(L>>>0<Qb>>>0)){break}ea=c[K>>2]|0;ga=(L>>>0)%(Ba>>>0)|0;xa=(L>>>0)/(Ba>>>0)|0;Ba=ea+(L*1588|0)|0;if((c[Ba>>2]|0)==0){D=-12;break a}Z=ga+1|0;J=xa+1|0;I=0;while(1){Rb=c[W>>2]|0;if((I|0)>=(Rb|0)){break}ka=c[Ba>>2]|0;wa=c[M>>2]|0;ha=ba(wa,ga)|0;da=c[Y>>2]|0;la=ha+da|0;ha=c[N>>2]|0;na=(la|0)>(ha|0)?la:ha;b[ka+(I*232|0)+224>>1]=na;ha=(ba(wa,Z)|0)+da|0;da=c[O>>2]|0;wa=(ha|0)>(da|0)?da:ha;b[ka+(I*232|0)+226>>1]=wa;ha=c[Q>>2]|0;da=ba(ha,xa)|0;la=c[X>>2]|0;ua=da+la|0;da=c[V>>2]|0;sa=(ua|0)>(da|0)?ua:da;b[ka+(I*232|0)+228>>1]=sa;da=(ba(ha,J)|0)+la|0;la=c[P>>2]|0;ha=(da|0)>(la|0)?la:da;b[ka+(I*232|0)+230>>1]=ha;da=c[ta>>2]|0;la=1<<da;b[ka+(I*232|0)+216>>1]=(na&65535)-1+la>>da;b[ka+(I*232|0)+218>>1]=(wa&65535)-1+la>>da;b[ka+(I*232|0)+220>>1]=(sa&65535)-1+la>>da;b[ka+(I*232|0)+222>>1]=la-1+(ha&65535)>>da;da=oJa(ka+(I*232|0)|0,ea+(L*1588|0)+8+(I*84|0)|0,ea+(L*1588|0)+344+(I*290|0)|0,d[r+44+I|0]|0,c[r+56+(I<<2)>>2]|0,c[r+72+(I<<2)>>2]|0,c[t>>2]|0)|0;if((da|0)!=0){D=da;break a}I=I+1|0}I=ea+(L*1588|0)|0;J=ea+(L*1588|0)+1512|0;c[u>>2]=c[J>>2];c[u+4>>2]=c[J+4>>2];c[u+8>>2]=c[J+8>>2];c[va>>2]=8;j:do{switch(d[ea+(L*1588|0)+23|0]|0){case 1:{DDb(c[t>>2]|0,2352048,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;H=209;break};case 2:{DDb(c[t>>2]|0,2331920,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Sb=-1163346256;break};case 3:{DDb(c[t>>2]|0,2307504,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Sb=-1163346256;break};case 0:{H=209;break};case 4:{if((Rb|0)<=0){Sb=0;break j}J=I|0;xa=ea+(L*1588|0)+20|0;Z=0;ga=0;Ba=c[P>>2]|0;Ta=Rb;while(1){da=ea+(L*1588|0)+8+(Z*84|0)|0;ka=ea+(L*1588|0)+1504+(Z*20|0)+8|0;c[u>>2]=c[ka>>2];c[u+4>>2]=c[ka+4>>2];c[u+8>>2]=c[ka+8>>2];if((Ba|0)>0){ka=da|0;ha=ea+(L*1588|0)+344+(Z*290|0)+289|0;la=0;sa=ga;wa=c[O>>2]|0;na=Ba;while(1){if((wa|0)>0){ua=(la|0)==0;ma=la-1|0;ja=0;ia=sa;$a=c[ka>>2]|0;Za=wa;while(1){if(($a|0)>0){_a=(ja|0)==0;Ya=ja-1|0;Xa=0;eb=ia;rb=$a;while(1){pb=c[(c[J>>2]|0)+(Z*232|0)>>2]|0;fb=pb+(Xa*20|0)|0;kb=d[pb+(Xa*20|0)+15|0]|0;nb=rb+255-Xa&255;do{if(((la|0)%(1<<kb+nb|0)|0|0)==0|ua){_=d[pb+(Xa*20|0)+14|0]|0;if(!(((ja|0)%(1<<_+nb|0)|0|0)==0|_a)){Tb=eb;Ub=rb;break}gb=1<<nb;R=Ya+gb>>nb>>_&65535;_=e[pb+(Xa*20|0)+10>>1]|0;Db=ma+gb>>nb>>kb&65535;gb=(ba(_,Db)|0)+R|0;if(!(R>>>0<_>>>0)){D=-1163346256;break a}if(!(Db>>>0<(e[pb+(Xa*20|0)+12>>1]|0)>>>0)){D=-1163346256;break a}Db=((Xa|0)==0?0:(Xa*3|0)-2|0)+(ea+(L*1588|0)+344+(Z*290|0))|0;_=eb;R=0;while(1){if((R|0)>=(d[xa]|0)){break}Eb=wJa(r,da,fb,gb,R,Db,d[ha]|0)|0;if((Eb|0)<0){D=Eb;break a}_=Eb;R=R+1|0}Tb=_;Ub=c[ka>>2]|0}else{Tb=eb;Ub=rb}}while(0);fb=Xa+1|0;if((fb|0)<(Ub|0)){Xa=fb;eb=Tb;rb=Ub}else{break}}Vb=Tb;Wb=Ub;Xb=c[O>>2]|0}else{Vb=ia;Wb=$a;Xb=Za}rb=ja+256|0;if((rb|0)<(Xb|0)){ja=rb;ia=Vb;$a=Wb;Za=Xb}else{break}}Yb=Vb;Zb=Xb;_b=c[P>>2]|0}else{Yb=sa;Zb=wa;_b=na}Za=la+256|0;if((Za|0)<(_b|0)){la=Za;sa=Yb;wa=Zb;na=_b}else{break}}$b=Yb;ac=_b;bc=c[W>>2]|0}else{$b=ga;ac=Ba;bc=Ta}na=Z+1|0;if((na|0)<(bc|0)){Z=na;ga=$b;Ba=ac;Ta=bc}else{Sb=$b;break}}break};default:{Sb=0}}}while(0);do{if((H|0)==209){H=0;Ta=ea+(L*1588|0)+20|0;if((a[Ta]|0)==0){Sb=0;break}Ba=I|0;ga=0;Z=0;xa=c[W>>2]|0;while(1){J=0;na=Z;wa=xa;while(1){if((wa|0)<=0){cc=wa;dc=na;break}sa=(J|0)==0?0:(J*3|0)-2|0;la=0;ka=0;ha=na;da=wa;while(1){Za=ea+(L*1588|0)+8+(ka*84|0)|0;if((J|0)<(c[Za>>2]|0)){$a=c[(c[Ba>>2]|0)+(ka*232|0)>>2]|0;ia=$a+(J*20|0)|0;ja=$a+(J*20|0)+10|0;ma=$a+(J*20|0)+12|0;$a=ea+(L*1588|0)+344+(ka*290|0)+289|0;ua=ea+(L*1588|0)+344+(ka*290|0)+sa|0;lb=ha;rb=0;while(1){if((rb|0)>=(ba(e[ma>>1]|0,e[ja>>1]|0)|0)){break}eb=wJa(r,Za,ia,rb,ga,ua,d[$a]|0)|0;if((eb|0)<0){D=eb;break a}else{lb=eb;rb=rb+1|0}}ec=lb;fc=1;gc=c[W>>2]|0}else{ec=ha;fc=la;gc=da}rb=ka+1|0;if((rb|0)<(gc|0)){la=fc;ka=rb;ha=ec;da=gc}else{break}}if((fc|0)==0){cc=gc;dc=ec;break}else{J=J+1|0;na=ec;wa=gc}}wa=ga+1|0;if((wa|0)<(d[Ta]|0)){ga=wa;Z=dc;xa=cc}else{Sb=dc;break}}}}while(0);ea=c[k>>2]|0;I=(c[A>>2]|0)-ea|0;c[k>>2]=ea+(I>>>0>2>>>0?2:I);if((Sb|0)!=0){D=Sb;break a}L=L+1|0}k:do{if((Qb|0)!=0){L=o+33808|0;P=o+33846|0;O=o+33845|0;va=C;ta=0;l:while(1){X=c[K>>2]|0;Q=X+(ta*1588|0)|0;Y=bFb(c[(c[t>>2]|0)+140>>2]|0)|0;M=(a[Y+7|0]&16)!=0;I=M^1;if(M){hc=1}else{hc=d[Y+4|0]|0}if((c[W>>2]|0)>0){Y=Q|0;ea=0;do{xa=c[Y>>2]|0;Z=X+(ta*1588|0)+8+(ea*84|0)+4|0;ga=c[Z>>2]|0;if((ga|0)>0){Ta=xa+(ea*232|0)|0;Ba=X+(ta*1588|0)+8+(ea*84|0)+14|0;wa=X+(ta*1588|0)+8+(ea*84|0)+10|0;na=xa+(ea*232|0)+218|0;J=xa+(ea*232|0)+216|0;da=xa+(ea*232|0)+208|0;ha=xa+(ea*232|0)+212|0;ka=0;la=ga;while(1){ga=c[Ta>>2]|0;sa=ga+(ka*20|0)|0;rb=a[sa]|0;if(rb<<24>>24==0){ic=la}else{$a=ga+(ka*20|0)+16|0;ua=(ka|0)>0|0;ia=ga+(ka*20|0)+10|0;Za=ga+(ka*20|0)+12|0;ga=0;ja=rb;while(1){rb=c[$a>>2]|0;ma=ga+ua|0;do{if((b[rb+(ga*24|0)>>1]|0)==(b[rb+(ga*24|0)+2>>1]|0)){jc=ja}else{if((b[rb+(ga*24|0)+4>>1]|0)==(b[rb+(ga*24|0)+6>>1]|0)){jc=ja;break}eb=ba(e[Za>>1]|0,e[ia>>1]|0)|0;if((eb|0)==0){jc=ja;break}Xa=rb+(ga*24|0)+20|0;Ya=rb+(ga*24|0)+16|0;_a=rb+(ga*24|0)+12|0;fb=0;do{pb=c[Xa>>2]|0;kb=pb+(fb*24|0)|0;nb=pb+(fb*24|0)+2|0;if((ba(e[nb>>1]|0,e[kb>>1]|0)|0)!=0){R=pb+(fb*24|0)+12|0;pb=0;do{Db=c[R>>2]|0;gb=Db+(pb*9816|0)+9810|0;Eb=Db+(pb*9816|0)+9808|0;Cb=(e[gb>>1]|0)-(e[Eb>>1]|0)|0;kc=Db+(pb*9816|0)+9814|0;mc=Db+(pb*9816|0)+9812|0;nc=(e[kc>>1]|0)-(e[mc>>1]|0)|0;oc=a[Db+(pb*9816|0)|0]|0;pc=oc&255;qc=(d[Db+(pb*9816|0)+2|0]|0)-1|0;rc=d[Ba]|0;sc=rc&1;tc=rc&8;if((Cb|0)>=65){H=264;break l}if((nc|0)>=65){H=268;break l}rc=(nc|0)>0;if(rc){uc=Cb<<2;vc=0;do{TGb(o+(vc<<8)|0,0,uc|0)|0;vc=vc+1|0;}while((vc|0)<(nc|0))}vc=Db+(pb*9816|0)+4|0;uc=b[vc>>1]|0;do{if(!(uc<<16>>16==0)){wc=nc+2|0;if((wc|0)>0){xc=(Cb<<2)+8|0;yc=0;do{TGb(o+16384+(yc*264|0)|0,0,xc|0)|0;yc=yc+1|0;}while((yc|0)<(wc|0));zc=b[vc>>1]|0}else{zc=uc}a[(zc&65535)+(Db+(pb*9816|0)+10)|0]=-1;a[(e[vc>>1]|0)+1+(Db+(pb*9816|0)+10)|0]=-1;wc=Db+(pb*9816|0)+10|0;IPa(L,wc);if(oc<<24>>24==0){break}yc=(sc|0)==0;xc=(Cb|0)>0;Ac=(tc|0)==0;Bc=(sc|0)!=0;Cc=(tc|0)!=0;Dc=2;Ec=qc;Fc=0;Hc=pc;while(1){Ic=Hc-1|0;do{if((Dc|0)==0){if(yc){Jc=0}else{Jc=(Fc|0)>3|0}Kc=3<<Ec;if(!rc){Lc=Fc;break}Mc=(Jc|0)==0;Nc=-Kc|0;Oc=0;while(1){Pc=Oc+4|0;if(xc){Qc=Oc|3;Rc=0;while(1){Sc=Rc+1|0;Tc=Oc;while(1){Uc=Tc+1|0;Vc=o+16384+(Uc*264|0)+(Sc<<2)|0;Wc=c[Vc>>2]|0;if((Wc&255|0)!=0&(Wc&12288|0)==0){if(Ac){Xc=255}else{Xc=(Tc|0)==(Qc|0)?55:255}if((JPa(L,(d[6876544+((Xc&Wc)<<2)+ma|0]|0)+(o+33828)|0)|0)!=0){Wc=c[Vc>>2]|0;Yc=Wc>>>8&15;Zc=Wc&15;Wc=a[6876288+(Zc<<4)+Yc|0]|0;_c=JPa(L,(d[6877568+(Zc<<4)+Yc|0]|0)+(o+33828)|0)|0;if(Mc){Yc=(_c|0)!=(Wc&255|0)?Nc:Kc;c[o+(Tc<<8)+(Rc<<2)>>2]=Yc;$c=Yc}else{Yc=(_c|0)!=0?Nc:Kc;c[o+(Tc<<8)+(Rc<<2)>>2]=Yc;$c=Yc}nJa(o,Rc,Tc,$c>>>31)}c[Vc>>2]=c[Vc>>2]|4096}if((Uc|0)<(nc|0)&(Uc|0)<(Pc|0)){Tc=Uc}else{break}}if((Sc|0)<(Cb|0)){Rc=Sc}else{break}}}if((Pc|0)<(nc|0)){Oc=Pc}else{Lc=Fc;break}}}else if((Dc|0)==1){Oc=1<<Ec;Kc=-Oc|0;if(rc){Nc=0;while(1){Mc=Nc+4|0;if(xc){Rc=0;while(1){Qc=Rc+1|0;Tc=Nc;while(1){Uc=Tc+1|0;Vc=o+16384+(Uc*264|0)+(Qc<<2)|0;Yc=c[Vc>>2]|0;if((Yc&12288|0)==8192){_c=(JPa(L,(d[((Yc&255|0)!=0)+(549224+((Yc>>>14&1)<<1))|0]|0)+(o+33828)|0)|0)!=0;Yc=_c?Oc:Kc;_c=o+(Tc<<8)+(Rc<<2)|0;Wc=c[_c>>2]|0;c[_c>>2]=((Wc|0)<0?-Yc|0:Yc)+Wc;c[Vc>>2]=c[Vc>>2]|16384}if((Uc|0)<(nc|0)&(Uc|0)<(Mc|0)){Tc=Uc}else{break}}if((Qc|0)<(Cb|0)){Rc=Qc}else{break}}}if((Mc|0)<(nc|0)){Nc=Mc}else{break}}}if(!(Bc&(Fc|0)>3)){Lc=Fc;break}IPa(L,wc);Lc=Fc}else if((Dc|0)==2){Nc=a[Ba]|0;Kc=3<<Ec;if(rc){Oc=-Kc|0;Rc=0;while(1){if(xc){Pc=Rc|3;Tc=(Pc|0)<(nc|0);Sc=Rc|1;Uc=Rc|2;Vc=Rc+4|0;Wc=0;while(1){Yc=Wc+1|0;do{if(Tc){if((c[o+16384+(Sc*264|0)+(Yc<<2)>>2]&12543|0)!=0){ad=0;bd=0;H=319;break}if((c[o+16384+(Uc*264|0)+(Yc<<2)>>2]&12543|0)!=0){ad=0;bd=0;H=319;break}if((c[o+16384+(Pc*264|0)+(Yc<<2)>>2]&12543|0)!=0){ad=0;bd=0;H=319;break}if((c[o+16384+(Vc*264|0)+(Yc<<2)>>2]&12543|0)!=0){ad=0;bd=0;H=319;break}if((JPa(L,P)|0)==0){break}_c=(JPa(L,O)|0)<<1;ad=1;bd=_c|(JPa(L,O)|0);H=319}else{ad=0;bd=0;H=319}}while(0);do{if((H|0)==319){H=0;Qc=bd+Rc|0;if((Qc|0)<(Vc|0)&(Qc|0)<(nc|0)){cd=Qc;dd=ad}else{break}while(1){Qc=cd+1|0;_c=o+16384+(Qc*264|0)+(Yc<<2)|0;do{if((dd|0)==0){Zc=c[_c>>2]|0;if((Zc&12288|0)!=0){break}if((JPa(L,(d[6876544+((Zc&(Cc&(cd|0)==(Pc|0)?55:255))<<2)+ma|0]|0)+(o+33828)|0)|0)!=0){H=323}}else{H=323}}while(0);if((H|0)==323){H=0;Zc=c[_c>>2]|0;ed=Zc>>>8&15;fd=Zc&15;Zc=d[6876288+(fd<<4)+ed|0]|0;gd=(JPa(L,(d[6877568+(fd<<4)+ed|0]|0)+(o+33828)|0)|0)!=(Zc|0);Zc=gd?Oc:Kc;c[o+(cd<<8)+(Wc<<2)>>2]=Zc;nJa(o,Wc,cd,Zc>>>31)}c[_c>>2]=c[_c>>2]&-4097;if((Qc|0)<(Vc|0)&(Qc|0)<(nc|0)){cd=Qc;dd=0}else{break}}}}while(0);if((Yc|0)<(Cb|0)){Wc=Yc}else{hd=Vc;break}}}else{hd=Rc+4|0}if((hd|0)<(nc|0)){Rc=hd}else{break}}}do{if(!((Nc&32)==0)){Rc=(JPa(L,O)|0)<<1;Kc=Rc+(JPa(L,O)|0)<<1;Rc=Kc+(JPa(L,O)|0)<<1;if((Rc+(JPa(L,O)|0)|0)==10){break}yDb(c[t>>2]|0,16,1894984,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}}while(0);Nc=Fc+1|0;if(!(Bc&(Nc|0)>3)){Lc=Nc;break}IPa(L,wc);Lc=Nc}else{Lc=Fc}}while(0);Nc=Dc+1|0;Rc=(Nc|0)==3;if((Ic|0)==0){break}else{Dc=Rc?0:Nc;Ec=(Rc<<31>>31)+Ec|0;Fc=Lc;Hc=Ic}}}}while(0);nc=e[Eb>>1]|0;Cb=e[mc>>1]|0;rc=(e[gb>>1]|0)-nc|0;pc=(e[kc>>1]|0)-Cb|0;qc=(pc|0)>0;do{if((a[wa]|0)==0){if(!qc){break}tc=(e[na>>1]|0)-(e[J>>1]|0)|0;sc=c[da>>2]|0;oc=(rc|0)>0;Db=0;do{vc=(ba(Db+Cb|0,tc)|0)+nc|0;if(oc){uc=0;do{g[sc+(vc+uc<<2)>>2]=+(c[o+(Db<<8)+(uc<<2)>>2]|0)*+g[Ya>>2];uc=uc+1|0;}while((uc|0)<(rc|0))}Db=Db+1|0;}while((Db|0)<(pc|0))}else{if(!qc){break}Db=(e[na>>1]|0)-(e[J>>1]|0)|0;sc=c[ha>>2]|0;oc=(rc|0)>0;tc=0;do{uc=(ba(tc+Cb|0,Db)|0)+nc|0;if(oc){vc=0;do{c[sc+(uc+vc<<2)>>2]=(ba(c[_a>>2]|0,c[o+(tc<<8)+(vc<<2)>>2]|0)|0)+16384>>15;vc=vc+1|0;}while((vc|0)<(rc|0))}tc=tc+1|0;}while((tc|0)<(pc|0))}}while(0);pb=pb+1|0;}while((pb|0)<(ba(e[nb>>1]|0,e[kb>>1]|0)|0))}fb=fb+1|0;}while((fb|0)<(eb|0));jc=a[sa]|0}}while(0);ma=ga+1|0;if((ma|0)<(jc&255|0)){ga=ma;ja=jc}else{break}}ic=c[Z>>2]|0}ja=ka+1|0;if((ja|0)<(ic|0)){ka=ja;la=ic}else{id=wa;break}}}else{id=X+(ta*1588|0)+8+(ea*84|0)+10|0}if((a[id]|0)==0){jd=c[xa+(ea*232|0)+208>>2]|0}else{jd=c[xa+(ea*232|0)+212>>2]|0}CJa(xa+(ea*232|0)+4|0,jd)|0;ea=ea+1|0;}while((ea|0)<(c[W>>2]|0))}do{if((a[X+(ta*1588|0)+21|0]|0)!=0){ea=a[X+(ta*1588|0)+18|0]|0;Y=1;while(1){if((Y|0)>=3){break}if(ea<<24>>24==(a[X+(ta*1588|0)+8+(Y*84|0)+10|0]|0)){Y=Y+1|0}else{H=359;break}}if((H|0)==359){H=0;yDb(c[t>>2]|0,16,2051264,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;break}Y=c[Q>>2]|0;if(ea<<24>>24==0){kd=c[Y+672>>2]|0;ld=0;md=c[Y+208>>2]|0;nd=0;od=0;pd=c[Y+440>>2]|0}else{kd=0;ld=c[Y+676>>2]|0;md=0;nd=c[Y+212>>2]|0;od=c[Y+444>>2]|0;pd=0}xa=ba((e[Y+222>>1]|0)-(e[Y+220>>1]|0)|0,(e[Y+218>>1]|0)-(e[Y+216>>1]|0)|0)|0;Y=ea&255;if((Y|0)==1){if((xa|0)>0){qd=0;rd=nd;sd=ld;td=od}else{break}while(1){wa=c[sd>>2]|0;la=c[td>>2]|0;ka=(c[rd>>2]|0)-(la+wa>>2)|0;c[rd>>2]=ka+wa;c[td>>2]=ka;c[sd>>2]=ka+la;la=qd+1|0;if((la|0)<(xa|0)){qd=la;rd=rd+4|0;sd=sd+4|0;td=td+4|0}else{break}}}else if((Y|0)==2){if((xa|0)>0){ud=0;vd=nd;wd=ld;xd=od}else{break}while(1){ea=c[vd>>2]|0;la=c[wd>>2]|0;ka=c[xd>>2]|0;c[vd>>2]=((la*91881|0)+32768>>16)+ea;c[xd>>2]=ea-((la*46802|0)+32768>>16)-((ka*22553|0)+32768>>16);c[wd>>2]=((ka*116130|0)+32768>>16)+ea;ea=ud+1|0;if((ea|0)<(xa|0)){ud=ea;vd=vd+4|0;wd=wd+4|0;xd=xd+4|0}else{break}}}else if((Y|0)==0){if((xa|0)>0){yd=0;zd=md;Ad=kd;Bd=pd}else{break}while(1){Dd=+g[zd>>2];Ed=+g[Ad>>2];Fd=+g[Bd>>2];g[zd>>2]=Dd+Ed*1.4019999504089355;g[Bd>>2]=Dd-Fd*.3441300094127655-Ed*.714139997959137;g[Ad>>2]=Dd+Fd*1.7719999551773071;ea=yd+1|0;if((ea|0)<(xa|0)){yd=ea;zd=zd+4|0;Ad=Ad+4|0;Bd=Bd+4|0}else{break}}}else{break}}}while(0);do{if((c[va>>2]|0)<0){xa=c[W>>2]|0;if((xa|0)>0){Y=0;while(1){ea=Y+1|0;c[r+1128+(Y<<2)>>2]=ea;ka=c[W>>2]|0;if((ea|0)<(ka|0)){Y=ea}else{Gd=ka;break}}}else{Gd=xa}if((Gd&1|0)!=0){break}c[r+1128+(Gd-1<<2)>>2]=0}}while(0);Y=c[W>>2]|0;ka=(Y|0)>0;do{if((c[fa>>2]|0)<9){if(!ka){break}ea=Q|0;la=-(I&1)|0;wa=0;Z=Y;ha=c[ea>>2]|0;while(1){J=d[r+44+wa|0]|0;na=c[N>>2]|0;da=(e[ha+(wa*232|0)+218>>1]|0)-na|0;if(M){Ba=c[r+1128+(wa<<2)>>2]|0;Hd=((Ba|0)==0?Z:Ba)-1|0}else{Hd=0}Ba=c[V>>2]|0;Ta=(e[ha+(wa*232|0)+220>>1]|0)-Ba|0;ja=r+72+(wa<<2)|0;ga=s+32+(Hd<<2)|0;if((Ta|0)<((e[ha+(wa*232|0)+222>>1]|0)-Ba|0)){Ba=ba((Ta|0)/(c[ja>>2]|0)|0,c[ga>>2]|0)|0;sa=r+56+(wa<<2)|0;ia=wa&la;Za=X+(ta*1588|0)+8+(wa*84|0)+10|0;ua=1<<J-1;$a=(1<<J)-1|0;ma=8-J|0;J=c[ha+(wa*232|0)+212>>2]|0;rb=c[ha+(wa*232|0)+208>>2]|0;lb=(c[s+(Hd<<2)>>2]|0)+Ba|0;Ba=Ta;Ta=ha;eb=c[sa>>2]|0;fb=na;while(1){na=(e[Ta+(wa*232|0)+216>>1]|0)-fb|0;_a=lb+((ba((na|0)/(eb|0)|0,hc)|0)+ia)|0;Ya=(na|0)<(da|0);do{if((a[Za]|0)==0){if(Ya){Id=rb;Jd=_a;Kd=na}else{Ld=rb;Md=J;Nd=eb;break}while(1){Xa=(Gc(+(+g[Id>>2]))|0)+ua|0;if((Xa|0)<0){Od=0}else{Od=(Xa|0)>($a|0)?$a:Xa}a[Jd]=Od<<ma;Xa=Id+4|0;kb=c[sa>>2]|0;nb=kb+Kd|0;if((nb|0)<(da|0)){Id=Xa;Jd=Jd+hc|0;Kd=nb}else{Ld=Xa;Md=J;Nd=kb;break}}}else{if(Ya){Pd=J;Qd=_a;Rd=na}else{Ld=rb;Md=J;Nd=eb;break}while(1){kb=(c[Pd>>2]|0)+ua|0;if((kb|0)<0){Sd=0}else{Sd=(kb|0)>($a|0)?$a:kb}a[Qd]=Sd<<ma;kb=Pd+4|0;Xa=c[sa>>2]|0;nb=Xa+Rd|0;if((nb|0)<(da|0)){Pd=kb;Qd=Qd+hc|0;Rd=nb}else{Ld=rb;Md=kb;Nd=Xa;break}}}}while(0);na=(c[ja>>2]|0)+Ba|0;Td=c[ea>>2]|0;if((na|0)>=((e[Td+(wa*232|0)+222>>1]|0)-(c[V>>2]|0)|0)){break}J=Md;rb=Ld;lb=lb+(c[ga>>2]|0)|0;Ba=na;Ta=Td;eb=Nd;fb=c[N>>2]|0}Ud=Td;Vd=c[W>>2]|0}else{Ud=ha;Vd=Z}fb=wa+1|0;if((fb|0)<(Vd|0)){wa=fb;Z=Vd;ha=Ud}else{break}}}else{if(!ka){break}ha=Q|0;Z=-(I&1)|0;wa=0;ea=Y;la=c[ha>>2]|0;while(1){xa=d[r+44+wa|0]|0;fb=c[N>>2]|0;eb=(e[la+(wa*232|0)+218>>1]|0)-fb|0;if(M){Ta=c[r+1128+(wa<<2)>>2]|0;Wd=((Ta|0)==0?ea:Ta)-1|0}else{Wd=0}Ta=c[V>>2]|0;Ba=(e[la+(wa*232|0)+220>>1]|0)-Ta|0;ga=r+72+(wa<<2)|0;lb=s+32+(Wd<<2)|0;if((Ba|0)<((e[la+(wa*232|0)+222>>1]|0)-Ta|0)){rb=c[lb>>2]|0;J=c[ga>>2]|0;ja=(c[s+(Wd<<2)>>2]|0)+((ba((Ba|0)/(J|0)|0,rb>>1)|0)<<1)|0;da=r+56+(wa<<2)|0;sa=wa&Z;ma=X+(ta*1588|0)+8+(wa*84|0)+10|0;$a=1<<xa-1;ua=(1<<xa)-1|0;Za=16-xa|0;xa=Ba;Ba=c[la+(wa*232|0)+208>>2]|0;ia=c[la+(wa*232|0)+212>>2]|0;na=ja;ja=la;_a=c[da>>2]|0;Ya=rb;rb=J;J=Ta;Ta=fb;while(1){fb=(e[ja+(wa*232|0)+216>>1]|0)-Ta|0;Xa=na+((ba((fb|0)/(_a|0)|0,hc)|0)+sa<<1)|0;kb=(fb|0)<(eb|0);do{if((a[ma]|0)==0){if(kb){Xd=Ba;Yd=fb;Zd=Xa}else{_d=ia;$d=Ba;ae=_a;be=Ya;ce=rb;ee=ja;ge=J;break}while(1){nb=(Gc(+(+g[Xd>>2]))|0)+$a|0;if((nb|0)<0){he=0}else{he=(nb|0)>(ua|0)?ua:nb}b[Zd>>1]=he<<Za;ie=Xd+4|0;je=c[da>>2]|0;nb=je+Yd|0;if((nb|0)<(eb|0)){Xd=ie;Yd=nb;Zd=Zd+(hc<<1)|0}else{break}}_d=ia;$d=ie;ae=je;be=c[lb>>2]|0;ce=c[ga>>2]|0;ee=c[ha>>2]|0;ge=c[V>>2]|0}else{if(kb){ke=ia;le=fb;me=Xa}else{_d=ia;$d=Ba;ae=_a;be=Ya;ce=rb;ee=ja;ge=J;break}while(1){nb=(c[ke>>2]|0)+$a|0;if((nb|0)<0){ne=0}else{ne=(nb|0)>(ua|0)?ua:nb}b[me>>1]=ne<<Za;nb=ke+4|0;pb=le+_a|0;if((pb|0)<(eb|0)){ke=nb;le=pb;me=me+(hc<<1)|0}else{_d=nb;$d=Ba;ae=_a;be=Ya;ce=rb;ee=ja;ge=J;break}}}}while(0);Xa=ce+xa|0;if((Xa|0)>=((e[ee+(wa*232|0)+222>>1]|0)-ge|0)){break}xa=Xa;Ba=$d;ia=_d;na=na+(be>>1<<1)|0;ja=ee;_a=ae;Ya=be;rb=ce;J=ge;Ta=c[N>>2]|0}oe=ee;pe=c[W>>2]|0}else{oe=la;pe=ea}Ta=wa+1|0;if((Ta|0)<(pe|0)){wa=Ta;ea=pe;la=oe}else{break}}}}while(0);ta=ta+1|0;if(!(ta>>>0<(ba(c[G>>2]|0,c[E>>2]|0)|0)>>>0)){break k}}if((H|0)==264){yDb(0,0,2005840,(x=i,i=i+24|0,c[x>>2]=1968152,c[x+8>>2]=1939688,c[x+16>>2]=1057,x)|0);i=x;Cd();return 0}else if((H|0)==268){yDb(0,0,2005840,(x=i,i=i+24|0,c[x>>2]=1915536,c[x+8>>2]=1939688,c[x+16>>2]=1058,x)|0);i=x;Cd();return 0}}}while(0);vJa(r);c[j>>2]=1;if((c[(c[t>>2]|0)+140>>2]|0)==11){UGb(c[h+4>>2]|0,q+100|0,1024)|0}qe=(c[k>>2]|0)-(c[y>>2]|0)|0;i=l;return qe|0}}while(0);vJa(r);qe=D;i=l;return qe|0}function vJa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=a+1152|0;d=c[b>>2]|0;e=a+1156|0;f=c[e>>2]|0;g=a+2668|0;if((ba(f,d)|0)==0){h=g;$Db(h);i=a+1164|0;c[e>>2]=0;c[b>>2]=0;j=i;TGb(j|0,0,1496)|0;return}k=a+92|0;l=0;m=d;d=f;while(1){f=c[g>>2]|0;if((c[f+(l*1588|0)>>2]|0)==0){n=m;o=d}else{p=f+(l*1588|0)|0;if((c[k>>2]|0)>0){q=0;r=f;f=p;while(1){rJa((c[f>>2]|0)+(q*232|0)|0,r+(l*1588|0)+8+(q*84|0)|0);s=q+1|0;t=c[g>>2]|0;u=t+(l*1588|0)|0;if((s|0)<(c[k>>2]|0)){q=s;r=t;f=u}else{v=u;break}}}else{v=p}$Db(v);n=c[b>>2]|0;o=c[e>>2]|0}f=l+1|0;if(f>>>0<(ba(o,n)|0)>>>0){l=f;m=n;d=o}else{break}}h=g;$Db(h);i=a+1164|0;c[e>>2]=0;c[b>>2]=0;j=i;TGb(j|0,0,1496)|0;return}function wJa(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0;n=i;o=f+2660|0;p=f+12|0;q=f+8|0;r=c[o>>2]|0;if((r|0)==0){s=c[p>>2]|0;t=c[q>>2]|0;if((s-t|0)<1){u=8;v=t}else{w=t+1|0;c[q>>2]=w;u=(a[t]|0)!=-1?8:7;v=w}c[o>>2]=u;x=u;y=v;z=s}else{x=r;y=c[q>>2]|0;z=c[p>>2]|0}r=x-1|0;c[o>>2]=r;x=z;s=(x-y|0)<1;if(s){A=0}else{A=d[y]|0}if((A&1<<r|0)==0){do{if(!s){r=y+1|0;c[q>>2]=r;if(!((a[y]|0)==-1)){break}A=x-r|0;c[q>>2]=y+(A>>>0>1>>>0?2:A+1|0)}}while(0);c[o>>2]=8;B=0;i=n;return B|0}x=h|0;s=a[x]|0;do{if(s<<24>>24==0){C=z;D=y}else{A=h+16|0;r=k+1|0;v=m-1|0;u=0;w=s;a:while(1){t=c[A>>2]|0;E=c[t+(u*24|0)+20>>2]|0;do{if((b[t+(u*24|0)>>1]|0)==(b[t+(u*24|0)+2>>1]|0)){F=w}else{if((b[t+(u*24|0)+4>>1]|0)==(b[t+(u*24|0)+6>>1]|0)){F=w;break}G=ba(e[E+(j*24|0)>>1]|0,e[E+(j*24|0)+2>>1]|0)|0;if((G|0)==0){F=w;break}H=E+(j*24|0)+12|0;I=E+(j*24|0)+8|0;J=l+u|0;K=E+(j*24|0)+4|0;L=0;do{M=c[H>>2]|0;N=M+(L*9816|0)|0;if((a[N]|0)==0){O=(xJa(f,(c[I>>2]|0)+(L<<3)|0,r)|0)==(k|0)|0}else{P=c[o>>2]|0;if((P|0)==0){Q=c[p>>2]|0;R=c[q>>2]|0;if((Q-R|0)<1){S=8;T=R}else{U=R+1|0;c[q>>2]=U;S=(a[R]|0)!=-1?8:7;T=U}c[o>>2]=S;V=S;W=T;X=Q}else{V=P;W=c[q>>2]|0;X=c[p>>2]|0}P=V-1|0;c[o>>2]=P;if((X-W|0)<1){Y=0}else{Y=d[W]|0}O=Y>>>(P>>>0)&1}if((O|0)!=0){if((a[N]|0)==0){P=d[J]|0;Z=v+P-(xJa(f,(c[K>>2]|0)+(L<<3)|0,100)|0)|0;if((Z|0)<0){_=32;break a}a[M+(L*9816|0)+2|0]=Z}P=c[o>>2]|0;if((P|0)==0){Q=c[p>>2]|0;U=c[q>>2]|0;if((Q-U|0)<1){$=8;aa=U}else{R=U+1|0;c[q>>2]=R;$=(a[U]|0)!=-1?8:7;aa=R}c[o>>2]=$;ca=$;da=aa;ea=Q}else{ca=P;da=c[q>>2]|0;ea=c[p>>2]|0}P=ca-1|0;c[o>>2]=P;Q=ea;R=(Q-da|0)<1;if(R){fa=0}else{fa=d[da]|0}do{if((fa&1<<P|0)==0){ga=1;ha=P;ia=da}else{if((P|0)==0){if(R){ja=8;ka=da}else{U=da+1|0;c[q>>2]=U;ja=(a[da]|0)!=-1?8:7;ka=U}c[o>>2]=ja;la=ja;ma=ka}else{la=P;ma=da}U=la-1|0;c[o>>2]=U;na=(Q-ma|0)<1;if(na){oa=0}else{oa=d[ma]|0}if((oa&1<<U|0)==0){ga=2;ha=U;ia=ma;break}if((U|0)==0){if(na){pa=8;qa=ma}else{na=ma+1|0;c[q>>2]=na;pa=(a[ma]|0)!=-1?8:7;qa=na}c[o>>2]=pa;ra=pa;sa=qa}else{ra=U;sa=ma}U=ra-1|0;c[o>>2]=U;na=(Q-sa|0)<1;if(na){ta=0}else{ta=d[sa]|0}ua=ta>>>(U>>>0)<<1&2;if((U|0)==0){if(na){va=8;wa=sa}else{na=sa+1|0;c[q>>2]=na;va=(a[sa]|0)!=-1?8:7;wa=na}c[o>>2]=va;xa=va;ya=wa}else{xa=U;ya=sa}U=xa-1|0;c[o>>2]=U;na=(Q-ya|0)<1;if(na){za=0}else{za=d[ya]|0}Aa=za>>>(U>>>0)&1|ua;if((Aa|0)!=3){ga=Aa+3|0;ha=U;ia=ya;break}if((U|0)==0){if(na){Ba=8;Ca=ya}else{na=ya+1|0;c[q>>2]=na;Ba=(a[ya]|0)!=-1?8:7;Ca=na}c[o>>2]=Ba;Da=Ba;Ea=Ca}else{Da=U;Ea=ya}U=Da-1|0;c[o>>2]=U;na=(Q-Ea|0)<1;if(na){Fa=0}else{Fa=d[Ea]|0}Aa=Fa>>>(U>>>0)<<1&2;if((U|0)==0){if(na){Ga=8;Ha=Ea}else{na=Ea+1|0;c[q>>2]=na;Ga=(a[Ea]|0)!=-1?8:7;Ha=na}c[o>>2]=Ga;Ia=Ga;Ja=Ha}else{Ia=U;Ja=Ea}U=Ia-1|0;c[o>>2]=U;na=(Q-Ja|0)<1;if(na){Ka=0}else{Ka=d[Ja]|0}ua=(Ka>>>(U>>>0)&1|Aa)<<1;if((U|0)==0){if(na){La=8;Ma=Ja}else{na=Ja+1|0;c[q>>2]=na;La=(a[Ja]|0)!=-1?8:7;Ma=na}c[o>>2]=La;Na=La;Oa=Ma}else{Na=U;Oa=Ja}U=Na-1|0;c[o>>2]=U;na=(Q-Oa|0)<1;if(na){Pa=0}else{Pa=d[Oa]|0}Aa=(Pa>>>(U>>>0)&1|ua)<<1;if((U|0)==0){if(na){Qa=8;Ra=Oa}else{na=Oa+1|0;c[q>>2]=na;Qa=(a[Oa]|0)!=-1?8:7;Ra=na}c[o>>2]=Qa;Sa=Qa;Ta=Ra}else{Sa=U;Ta=Oa}U=Sa-1|0;c[o>>2]=U;na=(Q-Ta|0)<1;if(na){Ua=0}else{Ua=d[Ta]|0}ua=(Ua>>>(U>>>0)&1|Aa)<<1;if((U|0)==0){if(na){Va=8;Wa=Ta}else{na=Ta+1|0;c[q>>2]=na;Va=(a[Ta]|0)!=-1?8:7;Wa=na}c[o>>2]=Va;Xa=Va;Ya=Wa}else{Xa=U;Ya=Ta}U=Xa-1|0;c[o>>2]=U;if((Q-Ya|0)<1){Za=0}else{Za=d[Ya]|0}na=Za>>>(U>>>0)&1|ua;if((na|0)==31){ua=0;Aa=7;_a=U;$a=Ya;while(1){ab=Aa-1|0;bb=ua<<1;if((_a|0)==0){if((Q-$a|0)<1){cb=8;db=$a}else{eb=$a+1|0;c[q>>2]=eb;cb=(a[$a]|0)!=-1?8:7;db=eb}c[o>>2]=cb;fb=cb;gb=db}else{fb=_a;gb=$a}hb=fb-1|0;c[o>>2]=hb;if((Q-gb|0)<1){ib=0}else{ib=d[gb]|0}jb=ib>>>(hb>>>0)&1|bb;if((ab|0)>0){ua=jb;Aa=ab;_a=hb;$a=gb}else{break}}kb=(jb|0)<0?jb:jb+37|0;lb=hb;mb=gb}else{kb=(na|0)<0?na:na+6|0;lb=U;mb=Ya}if((kb|0)<0){B=kb;_=127;break a}else{ga=kb;ha=lb;ia=mb}}}while(0);P=0;R=ha;$a=ia;while(1){if((R|0)==0){if((Q-$a|0)<1){nb=8;ob=$a}else{_a=$a+1|0;c[q>>2]=_a;nb=(a[$a]|0)!=-1?8:7;ob=_a}c[o>>2]=nb;pb=nb;qb=ob}else{pb=R;qb=$a}_a=pb-1|0;c[o>>2]=_a;if((Q-qb|0)<1){rb=0}else{rb=d[qb]|0}if((rb&1<<_a|0)==0){break}else{P=P+1|0;R=_a;$a=qb}}if((P|0)<0){B=P;_=127;break a}$a=M+(L*9816|0)+8|0;R=(d[$a]|0)+P|0;a[$a]=R;$a=ga>>>0>65535>>>0;Q=$a?ga>>>16:ga;_a=$a?16:0;if((Q&65280|0)==0){sb=_a;tb=Q}else{sb=_a|8;tb=Q>>>8}Q=sb+(R&255)+(d[1191992+tb|0]|0)|0;if((Q|0)>0){R=0;_a=Q;Q=c[o>>2]|0;do{_a=_a-1|0;$a=R<<1;if((Q|0)==0){Aa=c[p>>2]|0;ua=c[q>>2]|0;if((Aa-ua|0)<1){ub=8;vb=ua}else{ab=ua+1|0;c[q>>2]=ab;ub=(a[ua]|0)!=-1?8:7;vb=ab}c[o>>2]=ub;wb=ub;xb=vb;yb=Aa}else{wb=Q;xb=c[q>>2]|0;yb=c[p>>2]|0}Q=wb-1|0;c[o>>2]=Q;if((yb-xb|0)<1){zb=0}else{zb=d[xb]|0}R=zb>>>(Q>>>0)&1|$a;}while((_a|0)>0);if((R|0)<0){B=R;_=127;break a}if(R>>>0>8192>>>0){_=103;break a}else{Ab=R&65535}}else{Ab=0}b[M+(L*9816|0)+6>>1]=Ab;a[N]=(d[N]|0)+ga}L=L+1|0;}while((L|0)<(G|0));F=a[x]|0}}while(0);E=u+1|0;if((E|0)<(F&255|0)){u=E;w=F}else{_=108;break}}if((_|0)==32){yDb(c[f+4>>2]|0,16,2289168,(Bb=i,i=i+8|0,c[Bb>>2]=Z,Bb)|0);i=Bb;B=-1094995529;i=n;return B|0}else if((_|0)==103){DDb(c[f+4>>2]|0,2273048,(Bb=i,i=i+8|0,c[Bb>>2]=8192,Bb)|0);i=Bb;B=-1163346256;i=n;return B|0}else if((_|0)==108){C=c[p>>2]|0;D=c[q>>2]|0;break}else if((_|0)==127){i=n;return B|0}}}while(0);Z=C;do{if((Z-D|0)<1){Cb=D}else{C=D+1|0;c[q>>2]=C;if(!((a[D]|0)==-1)){Cb=C;break}F=Z-C|0;C=D+(F>>>0>1>>>0?2:F+1|0)|0;c[q>>2]=C;Cb=C}}while(0);c[o>>2]=8;b:do{if(!((a[g+11|0]&4)==0)){o=f+8|0;q=Z-Cb|0;do{if((q|0)>=2){D=Cb;if(!((d[D]|d[D+1|0]<<8)<<16>>16<<16>>16==-27905)){break}c[o>>2]=Cb+(q>>>0>2>>>0?2:q);break b}}while(0);yDb(c[f+4>>2]|0,16,2257488,(Bb=i,i=i+1|0,i=i+7&-8,c[Bb>>2]=0,Bb)|0);i=Bb}}while(0);Cb=a[x]|0;if(Cb<<24>>24==0){B=0;i=n;return B|0}Z=h+16|0;h=f+8|0;g=0;q=Cb;c:while(1){Cb=c[(c[Z>>2]|0)+(g*24|0)+20>>2]|0;o=ba(e[Cb+(j*24|0)>>1]|0,e[Cb+(j*24|0)+2>>1]|0)|0;if((o|0)==0){Db=q}else{D=Cb+(j*24|0)+12|0;Cb=0;C=c[h>>2]|0;do{F=c[D>>2]|0;ga=F+(Cb*9816|0)+6|0;Eb=e[ga>>1]|0;Ab=F+(Cb*9816|0)+4|0;Fb=b[Ab>>1]|0;if(((c[p>>2]|0)-C|0)>>>0<Eb>>>0){break c}zb=Fb&65535;if((Eb+2+zb|0)>>>0>8192>>>0){break c}UGb(F+(Cb*9816|0)+10+zb|0,C|0,Eb)|0;C=(c[h>>2]|0)+Eb|0;c[h>>2]=C;b[Ab>>1]=(b[Ab>>1]|0)+(b[ga>>1]|0);b[ga>>1]=0;Cb=Cb+1|0;}while((Cb|0)<(o|0));Db=a[x]|0}o=g+1|0;if((o|0)<(Db&255|0)){g=o;q=Db}else{B=0;_=127;break}}if((_|0)==127){i=n;return B|0}yDb(c[f+4>>2]|0,16,2243240,(Bb=i,i=i+16|0,c[Bb>>2]=Fb&65535,c[Bb+8>>2]=Eb,Bb)|0);i=Bb;B=-1094995529;i=n;return B|0}function xJa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+120|0;h=g|0;if((e|0)==0){j=-1094995529;i=g;return j|0}else{k=e;l=-1}while(1){if((a[k+1|0]|0)!=0){m=l;break}e=l+1|0;c[h+(e<<2)>>2]=k;n=c[k+4>>2]|0;if((n|0)==0){m=e;break}else{k=n;l=e}}l=d[k|0]|0;if(!((l|0)<(f|0)&(m|0)>-1)){j=l;i=g;return j|0}k=b+2660|0;e=b+12|0;n=b+8|0;b=m;m=l;a:while(1){l=c[h+(b<<2)>>2]|0;o=l|0;p=d[o]|0;q=(m|0)<(p|0)?p:m;while(1){r=(q|0)<(f|0);if(!r){break a}p=c[k>>2]|0;if((p|0)==0){s=c[e>>2]|0;t=c[n>>2]|0;if((s-t|0)<1){u=8;v=t}else{w=t+1|0;c[n>>2]=w;u=(a[t]|0)!=-1?8:7;v=w}c[k>>2]=u;x=u;y=v;z=s}else{x=p;y=c[n>>2]|0;z=c[e>>2]|0}p=x-1|0;c[k>>2]=p;if((z-y|0)<1){A=0}else{A=d[y]|0}if((A&1<<p|0)!=0){break}q=q+1|0}p=l+1|0;a[p]=(a[p]|0)+1;a[o]=q;if(r&(b|0)>0){b=b-1|0;m=q}else{j=q;B=19;break}}if((B|0)==19){i=g;return j|0}a[o]=q;j=q;i=g;return j|0}function yJa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=e+8|0;i=c[h>>2]|0;j=e+12|0;if((c[j>>2]|0)==(i|0)){k=-1094995529;return k|0}c[h>>2]=i+1;e=a[i]|0;a[g+289|0]=(e&255)>>>5;i=e&31;a[g+288|0]=i;if((i<<24>>24|0)==1){e=c[h>>2]|0;if(((c[j>>2]|0)-e|0)>>>0<2>>>0){k=-1094995529;return k|0}c[h>>2]=e+2;l=e;e=de((d[l]|d[l+1|0]<<8)<<16>>16|0)|0;l=(e&65535)>>>11&255;m=g|0;a[m]=l;n=g+96|0;b[n>>1]=e&2047;e=1;o=l;while(1){l=(o&255)-((e-1|0)/3|0)|0;a[g+e|0]=(l|0)<0?0:l&255;b[g+96+(e<<1)>>1]=b[n>>1]|0;l=e+1|0;if((l|0)>=96){k=0;break}e=l;o=a[m]|0}return k|0}else if((i<<24>>24|0)==0){i=f-3|0;m=c[h>>2]|0;if(((c[j>>2]|0)-m|0)>>>0<i>>>0|(i|0)>96){k=-1094995529;return k|0}if((i|0)>0){p=0;q=m}else{k=0;return k|0}while(1){c[h>>2]=q+1;a[g+p|0]=(d[q]|0)>>>3;m=p+1|0;if((m|0)>=(i|0)){k=0;break}p=m;q=c[h>>2]|0}return k|0}else{q=f-3>>1;f=c[h>>2]|0;if(((c[j>>2]|0)-f|0)>>>0<q<<1>>>0|(q|0)>96){k=-1094995529;return k|0}if((q|0)>0){r=0;s=f}else{k=0;return k|0}while(1){c[h>>2]=s+2;f=s;j=de((d[f]|d[f+1|0]<<8)<<16>>16|0)|0;a[g+r|0]=(j&65535)>>>11;b[g+96+(r<<1)>>1]=j&2047;j=r+1|0;if((j|0)>=(q|0)){k=0;break}r=j;s=c[h>>2]|0}return k|0}return 0}function zJa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;g=b+8|0;h=c[g>>2]|0;j=b+12|0;if(((c[j>>2]|0)-h|0)>>>0<5>>>0){k=-1094995529;i=f;return k|0}l=h+1|0;c[g>>2]=l;m=d[h]|0;n=m+1|0;o=e|0;c[o>>2]=n;if(n>>>0>32>>>0){yDb(c[b+4>>2]|0,16,2139040,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;k=-1094995529;i=f;return k|0}q=b+2672|0;r=c[q>>2]|0;if((n|0)<=(r|0)){yDb(c[b+4>>2]|0,16,2132768,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;c[q>>2]=(c[o>>2]|0)-1;k=-22;i=f;return k|0}c[e+4>>2]=n-r;c[g>>2]=h+2;h=e+8|0;a[h]=(a[l]&15)+2;l=c[g>>2]|0;c[g>>2]=l+1;r=(a[l]&15)+2|0;a[e+9|0]=r;l=a[h]|0;h=l&255;do{if(!((l&255)>>>0>10>>>0)){n=r&255;if(n>>>0>10>>>0){break}if((n+h|0)>12){break}if((l&255)>>>0>6>>>0|n>>>0>6>>>0){DDb(c[b+4>>2]|0,2120560,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=-1163346256;i=f;return k|0}n=c[g>>2]|0;c[g>>2]=n+1;q=a[n]|0;a[e+14|0]=q;if(q<<24>>24==0){s=b+4|0}else{n=b+4|0;yDb(c[n>>2]|0,24,2114408,(p=i,i=i+8|0,c[p>>2]=q&255,p)|0);i=p;s=n}n=c[g>>2]|0;c[g>>2]=n+1;q=a[n]|0;n=e+10|0;a[n]=q;if((c[(c[s>>2]|0)+88>>2]&8388608|0)!=0&q<<24>>24==0){a[n]=2}if((a[e+11|0]&1)==0){TGb(e+16|0,15,66)|0;k=0;i=f;return k|0}if((c[o>>2]|0)>0){t=0}else{k=0;i=f;return k|0}while(1){n=c[g>>2]|0;if(((c[j>>2]|0)-n|0)<1){u=0;v=0}else{c[g>>2]=n+1;q=a[n]|0;u=(q&255)>>>4;v=q&15}a[e+16+t|0]=v;a[e+49+t|0]=u;q=t+1|0;if((q|0)<(c[o>>2]|0)){t=q}else{k=0;break}}i=f;return k|0}}while(0);yDb(c[b+4>>2]|0,16,2126376,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=-1094995529;i=f;return k|0}function AJa(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;a[d+192|0]=g;a[d+193|0]=h;i=e[f>>1]|0;j=e[f+2>>1]|0;k=e[f+4>>1]|0;l=e[f+6>>1]|0;f=j-i|0;m=l-k|0;n=(f|0)>(m|0)?f:m;if((g|0)>0){m=g;g=j;j=i;i=l;l=k;while(1){k=m-1|0;b[d+(k<<2)>>1]=g-j;a[d+128+(k<<1)|0]=j&1;b[d+(k<<2)+2>>1]=i-l;a[d+128+(k<<1)+1|0]=l&1;if((k|0)>0){m=k;g=g+1>>1;j=j+1>>1;i=i+1>>1;l=l+1>>1}else{break}}}do{if((h|0)==2){l=WDb((n<<2)+48|0)|0;c[d+196>>2]=l;if((l|0)==0){o=-12}else{break}return o|0}else if((h|0)==0){l=WDb((n<<2)+48|0)|0;c[d+200>>2]=l;if((l|0)==0){o=-12}else{break}return o|0}else if((h|0)==1){l=WDb((n<<2)+24|0)|0;c[d+196>>2]=l;if((l|0)==0){o=-12}else{break}return o|0}else{o=-1;return o|0}}while(0);o=0;return o|0}function BJa(e,f){e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;h=d[e+193|0]|0;if((h|0)==0){i=f;j=a[e+192|0]|0;k=(j&255)-1|0;l=b[e+(k<<2)>>1]|0;m=l&65535;n=c[e+200>>2]|0;o=n+20|0;if(j<<24>>24==0){p=0;return p|0}else{q=k;r=l}while(1){l=r&65535;k=b[e+(q<<2)+2>>1]|0;j=k&65535;s=d[e+128+(q<<1)|0]|0;t=d[e+128+(q<<1)+1|0]|0;u=s+5|0;v=k<<16>>16==0;a:do{if(!v){k=s+l|0;w=s>>>0<l>>>0;x=1-s|0;y=(x|0)<(l|0);if(r<<16>>16==0){z=0;while(1){IJa(o,s,k);if(w){A=ba(z,m)|0;B=s;C=0;while(1){g[i+(C+A<<2)>>2]=+g[n+(B+u<<2)>>2]*1.625732421875*.5;D=B+2|0;if((D|0)<(l|0)){B=D;C=C+1|0}else{E=1;break}}}else{E=0}if(y){C=ba(z,m)|0;B=x;A=E;while(1){g[i+(A+C<<2)>>2]=+g[n+(B+u<<2)>>2]*1.2301740646362305*.5;D=B+2|0;if((D|0)<(l|0)){B=D;A=A+1|0}else{break}}}z=z+1|0;if((z|0)>=(j|0)){break a}}}z=s+2|0;A=((z>>>0>l>>>0?z:l)+~s|0)>>>1;if(w){F=0}else{z=0;while(1){B=ba(z,m)|0;C=0;do{g[n+(C+u<<2)>>2]=+g[i+(C+B<<2)>>2];C=C+1|0;}while((C|0)<(l|0));IJa(o,s,k);if(y){C=x;D=0;while(1){g[i+(D+B<<2)>>2]=+g[n+(C+u<<2)>>2]*1.2301740646362305*.5;G=C+2|0;if((G|0)<(l|0)){C=G;D=D+1|0}else{break}}}z=z+1|0;if((z|0)>=(j|0)){break a}}}do{z=ba(F,m)|0;w=0;do{g[n+(w+u<<2)>>2]=+g[i+(w+z<<2)>>2];w=w+1|0;}while((w|0)<(l|0));IJa(o,s,k);w=s;D=0;while(1){g[i+(D+z<<2)>>2]=+g[n+(w+u<<2)>>2]*1.625732421875*.5;C=w+2|0;if((C|0)<(l|0)){w=C;D=D+1|0}else{break}}if(y){D=x;w=A;do{w=w+1|0;g[i+(w+z<<2)>>2]=+g[n+(D+u<<2)>>2]*1.2301740646362305*.5;D=D+2|0;}while((D|0)<(l|0))}F=F+1|0;}while((F|0)<(j|0))}}while(0);u=t+5|0;if(!(r<<16>>16==0)){s=t+j|0;A=t>>>0<j>>>0;x=1-t|0;y=(x|0)<(j|0);k=t+2|0;D=(((k>>>0>j>>>0?k:j)+~t|0)>>>1)+1|0;k=0;do{if(!v){z=0;do{g[n+(z+u<<2)>>2]=+g[i+((ba(z,m)|0)+k<<2)>>2];z=z+1|0;}while((z|0)<(j|0))}IJa(o,t,s);if(A){z=t;w=0;while(1){g[i+((ba(w,m)|0)+k<<2)>>2]=+g[n+(z+u<<2)>>2]*1.625732421875*.5;C=z+2|0;if((C|0)<(j|0)){z=C;w=w+1|0}else{H=D;break}}}else{H=0}if(y){w=x;z=H;while(1){g[i+((ba(z,m)|0)+k<<2)>>2]=+g[n+(w+u<<2)>>2]*1.2301740646362305*.5;C=w+2|0;if((C|0)<(j|0)){w=C;z=z+1|0}else{break}}}k=k+1|0;}while((k|0)<(l|0))}l=q-1|0;if((q|0)<=0){p=0;break}q=l;r=b[e+(l<<2)>>1]|0}return p|0}else if((h|0)==2){r=f;q=a[e+192|0]|0;n=(q&255)-1|0;m=b[e+(n<<2)>>1]|0;i=m&65535;H=c[e+196>>2]|0;o=H+20|0;if(q<<24>>24==0){p=0;return p|0}else{I=n;J=m}while(1){m=J&65535;n=b[e+(I<<2)+2>>1]|0;q=n&65535;F=d[e+128+(I<<1)|0]|0;E=d[e+128+(I<<1)+1|0]|0;l=F+5|0;k=n<<16>>16==0;if(!k){n=J<<16>>16==0;j=F+m|0;u=F>>>0<m>>>0;x=1-F|0;y=(x|0)<(m|0);D=F+2|0;t=(((D>>>0>m>>>0?D:m)+~F|0)>>>1)+1|0;D=0;do{if(!n){A=ba(D,i)|0;s=0;do{c[H+(s+l<<2)>>2]=c[r+(s+A<<2)>>2];s=s+1|0;}while((s|0)<(m|0))}HJa(o,F,j);if(u){s=ba(D,i)|0;A=F;v=0;while(1){c[r+(v+s<<2)>>2]=((c[H+(A+l<<2)>>2]|0)*106544|0)+65536>>17;z=A+2|0;if((z|0)<(m|0)){A=z;v=v+1|0}else{K=t;break}}}else{K=0}if(y){v=ba(D,i)|0;A=x;s=K;while(1){c[r+(s+v<<2)>>2]=((c[H+(A+l<<2)>>2]|0)*80621|0)+65536>>17;z=A+2|0;if((z|0)<(m|0)){A=z;s=s+1|0}else{break}}}D=D+1|0;}while((D|0)<(q|0))}D=E+5|0;if(!(J<<16>>16==0)){l=E+q|0;x=E>>>0<q>>>0;y=1-E|0;t=(y|0)<(q|0);F=E+2|0;u=(((F>>>0>q>>>0?F:q)+~E|0)>>>1)+1|0;F=0;do{if(!k){j=0;do{c[H+(j+D<<2)>>2]=c[r+((ba(j,i)|0)+F<<2)>>2];j=j+1|0;}while((j|0)<(q|0))}HJa(o,E,l);if(x){j=E;n=0;while(1){c[r+((ba(n,i)|0)+F<<2)>>2]=((c[H+(j+D<<2)>>2]|0)*106544|0)+65536>>17;s=j+2|0;if((s|0)<(q|0)){j=s;n=n+1|0}else{L=u;break}}}else{L=0}if(t){n=y;j=L;while(1){c[r+((ba(j,i)|0)+F<<2)>>2]=((c[H+(n+D<<2)>>2]|0)*80621|0)+65536>>17;s=n+2|0;if((s|0)<(q|0)){n=s;j=j+1|0}else{break}}}F=F+1|0;}while((F|0)<(m|0))}m=I-1|0;if((I|0)<=0){p=0;break}I=m;J=b[e+(m<<2)>>1]|0}return p|0}else if((h|0)==1){h=f;f=a[e+192|0]|0;J=(f&255)-1|0;I=b[e+(J<<2)>>1]|0;H=I&65535;i=c[e+196>>2]|0;if(f<<24>>24==0){p=0;return p|0}else{M=J;N=I}while(1){I=N&65535;J=b[e+(M<<2)+2>>1]|0;f=J&65535;r=d[e+128+(M<<1)|0]|0;L=d[e+128+(M<<1)+1|0]|0;o=r+3|0;K=J<<16>>16==0;if(!K){J=N<<16>>16==0;m=r+I|0;F=r+1|0;q=(F|0)==(m|0);D=i+(r+4<<2)|0;y=r+2|0;t=i+(y<<2)|0;u=m+1|0;E=i+(u<<2)|0;x=i+(m+3<<2)|0;l=i+(r+5<<2)|0;k=i+(F<<2)|0;j=i+(m<<2)|0;n=i+(m+4<<2)|0;m=F>>>1;F=m-1|0;s=u>>>1;u=(F|0)<(s|0);A=m>>>0<s>>>0;v=r>>>0<I>>>0;z=1-r|0;w=(z|0)<(I|0);C=(((y>>>0>I>>>0?y:I)+~r|0)>>>1)+1|0;y=0;do{if(!J){B=ba(y,H)|0;G=0;do{c[i+(G+o<<2)>>2]=c[h+(G+B<<2)>>2];G=G+1|0;}while((G|0)<(I|0))}do{if(!q){c[t>>2]=c[D>>2];c[x>>2]=c[E>>2];c[k>>2]=c[l>>2];c[n>>2]=c[j>>2];if(u){G=F;do{B=G<<1;O=i+((B|1)+3<<2)|0;c[O>>2]=(c[O>>2]|0)-((c[i+(B+5<<2)>>2]|0)+(c[i+(B+3<<2)>>2]|0)>>1);G=G+1|0;}while((G|0)<(s|0))}if(A){P=m}else{break}do{G=P<<1;B=i+(G+3<<2)|0;c[B>>2]=((c[i+(G+2<<2)>>2]|0)+2+(c[i+((G|1)+3<<2)>>2]|0)>>2)+(c[B>>2]|0);P=P+1|0;}while((P|0)<(s|0))}}while(0);if(v){B=ba(y,H)|0;G=r;O=0;while(1){c[h+(O+B<<2)>>2]=c[i+(G+o<<2)>>2];Q=G+2|0;if((Q|0)<(I|0)){G=Q;O=O+1|0}else{R=C;break}}}else{R=0}if(w){O=ba(y,H)|0;G=z;B=R;while(1){c[h+(B+O<<2)>>2]=c[i+(G+o<<2)>>2];Q=G+2|0;if((Q|0)<(I|0)){G=Q;B=B+1|0}else{break}}}y=y+1|0;}while((y|0)<(f|0))}y=L+3|0;if(!(N<<16>>16==0)){o=L+f|0;z=L+1|0;w=(z|0)==(o|0);C=i+(L+4<<2)|0;r=L+2|0;v=i+(r<<2)|0;s=o+1|0;m=i+(s<<2)|0;A=i+(o+3<<2)|0;F=i+(L+5<<2)|0;u=i+(z<<2)|0;j=i+(o<<2)|0;n=i+(o+4<<2)|0;o=z>>>1;z=o-1|0;l=s>>>1;s=(z|0)<(l|0);k=o>>>0<l>>>0;E=L>>>0<f>>>0;x=1-L|0;D=(x|0)<(f|0);t=(((r>>>0>f>>>0?r:f)+~L|0)>>>1)+1|0;r=0;do{if(!K){q=0;do{c[i+(q+y<<2)>>2]=c[h+((ba(q,H)|0)+r<<2)>>2];q=q+1|0;}while((q|0)<(f|0))}do{if(!w){c[v>>2]=c[C>>2];c[A>>2]=c[m>>2];c[u>>2]=c[F>>2];c[n>>2]=c[j>>2];if(s){q=z;do{J=q<<1;B=i+((J|1)+3<<2)|0;c[B>>2]=(c[B>>2]|0)-((c[i+(J+5<<2)>>2]|0)+(c[i+(J+3<<2)>>2]|0)>>1);q=q+1|0;}while((q|0)<(l|0))}if(k){S=o}else{break}do{q=S<<1;J=i+(q+3<<2)|0;c[J>>2]=((c[i+(q+2<<2)>>2]|0)+2+(c[i+((q|1)+3<<2)>>2]|0)>>2)+(c[J>>2]|0);S=S+1|0;}while((S|0)<(l|0))}}while(0);if(E){J=L;q=0;while(1){c[h+((ba(q,H)|0)+r<<2)>>2]=c[i+(J+y<<2)>>2];B=J+2|0;if((B|0)<(f|0)){J=B;q=q+1|0}else{T=t;break}}}else{T=0}if(D){q=x;J=T;while(1){c[h+((ba(J,H)|0)+r<<2)>>2]=c[i+(q+y<<2)>>2];B=q+2|0;if((B|0)<(f|0)){q=B;J=J+1|0}else{break}}}r=r+1|0;}while((r|0)<(I|0))}I=M-1|0;if((M|0)<=0){p=0;break}M=I;N=b[e+(I<<2)>>1]|0}return p|0}else{p=-1;return p|0}return 0}function CJa(f,h){f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;i=d[f+193|0]|0;if((i|0)==1){j=h;k=f+192|0;l=a[k]|0;m=e[f+((l&255)-1<<2)>>1]|0;n=c[f+196>>2]|0;o=n+12|0;if(l<<24>>24==0){p=0;return p|0}else{q=0}while(1){l=b[f+(q<<2)>>1]|0;r=l&65535;s=b[f+(q<<2)+2>>1]|0;t=s&65535;u=d[f+128+(q<<1)|0]|0;v=d[f+128+(q<<1)+1|0]|0;w=u+3|0;x=s<<16>>16==0;if(!x){s=u>>>0<r>>>0;y=1-u|0;z=(y|0)<(r|0);A=u+r|0;B=l<<16>>16==0;C=u+2|0;D=(((C>>>0>r>>>0?C:r)+~u|0)>>>1)+1|0;C=0;do{if(s){E=ba(C,m)|0;F=u;G=0;while(1){c[n+(F+w<<2)>>2]=c[j+(G+E<<2)>>2];H=F+2|0;if((H|0)<(r|0)){F=H;G=G+1|0}else{I=D;break}}}else{I=0}if(z){G=ba(C,m)|0;F=y;E=I;while(1){c[n+(F+w<<2)>>2]=c[j+(E+G<<2)>>2];H=F+2|0;if((H|0)<(r|0)){F=H;E=E+1|0}else{break}}}EJa(o,u,A);if(!B){E=ba(C,m)|0;F=0;do{c[j+(F+E<<2)>>2]=c[n+(F+w<<2)>>2];F=F+1|0;}while((F|0)<(r|0))}C=C+1|0;}while((C|0)<(t|0))}C=v+3|0;if(!(l<<16>>16==0)){w=v>>>0<t>>>0;B=1-v|0;A=(B|0)<(t|0);u=v+t|0;y=v+2|0;z=(((y>>>0>t>>>0?y:t)+~v|0)>>>1)+1|0;y=0;do{if(w){D=v;s=0;while(1){c[n+(D+C<<2)>>2]=c[j+((ba(s,m)|0)+y<<2)>>2];F=D+2|0;if((F|0)<(t|0)){D=F;s=s+1|0}else{J=z;break}}}else{J=0}if(A){s=B;D=J;while(1){c[n+(s+C<<2)>>2]=c[j+((ba(D,m)|0)+y<<2)>>2];F=s+2|0;if((F|0)<(t|0)){s=F;D=D+1|0}else{break}}}EJa(o,v,u);if(!x){D=0;do{c[j+((ba(D,m)|0)+y<<2)>>2]=c[n+(D+C<<2)>>2];D=D+1|0;}while((D|0)<(t|0))}y=y+1|0;}while((y|0)<(r|0))}r=q+1|0;if((r|0)<(d[k]|0|0)){q=r}else{p=0;break}}return p|0}else if((i|0)==0){q=h;k=f+192|0;n=a[k]|0;m=e[f+((n&255)-1<<2)>>1]|0;j=c[f+200>>2]|0;o=j+20|0;if(n<<24>>24==0){p=0;return p|0}else{K=0}while(1){n=b[f+(K<<2)>>1]|0;J=n&65535;I=b[f+(K<<2)+2>>1]|0;r=I&65535;y=d[f+128+(K<<1)|0]|0;t=d[f+128+(K<<1)+1|0]|0;C=y+5|0;x=I<<16>>16==0;if(!x){I=y>>>0<J>>>0;u=1-y|0;v=(u|0)<(J|0);B=y+J|0;A=n<<16>>16==0;z=y+2|0;w=(((z>>>0>J>>>0?z:J)+~y|0)>>>1)+1|0;z=0;do{if(I){l=ba(z,m)|0;D=y;s=0;while(1){g[j+(D+C<<2)>>2]=+g[q+(s+l<<2)>>2]*1.2301740646362305;F=D+2|0;if((F|0)<(J|0)){D=F;s=s+1|0}else{L=w;break}}}else{L=0}if(v){s=ba(z,m)|0;D=u;l=L;while(1){g[j+(D+C<<2)>>2]=+g[q+(l+s<<2)>>2]*1.625732421875;F=D+2|0;if((F|0)<(J|0)){D=F;l=l+1|0}else{break}}}GJa(o,y,B);if(!A){l=ba(z,m)|0;D=0;do{g[q+(D+l<<2)>>2]=+g[j+(D+C<<2)>>2];D=D+1|0;}while((D|0)<(J|0))}z=z+1|0;}while((z|0)<(r|0))}z=t+5|0;if(!(n<<16>>16==0)){C=t>>>0<r>>>0;A=1-t|0;B=(A|0)<(r|0);y=t+r|0;u=t+2|0;v=(((u>>>0>r>>>0?u:r)+~t|0)>>>1)+1|0;u=0;do{if(C){w=t;I=0;while(1){g[j+(w+z<<2)>>2]=+g[q+((ba(I,m)|0)+u<<2)>>2]*1.2301740646362305;D=w+2|0;if((D|0)<(r|0)){w=D;I=I+1|0}else{M=v;break}}}else{M=0}if(B){I=A;w=M;while(1){g[j+(I+z<<2)>>2]=+g[q+((ba(w,m)|0)+u<<2)>>2]*1.625732421875;D=I+2|0;if((D|0)<(r|0)){I=D;w=w+1|0}else{break}}}GJa(o,t,y);if(!x){w=0;do{g[q+((ba(w,m)|0)+u<<2)>>2]=+g[j+(w+z<<2)>>2];w=w+1|0;}while((w|0)<(r|0))}u=u+1|0;}while((u|0)<(J|0))}J=K+1|0;if((J|0)<(d[k]|0|0)){K=J}else{p=0;break}}return p|0}else if((i|0)==2){i=h;h=f+192|0;K=a[h]|0;k=e[f+((K&255)-1<<2)>>1]|0;j=c[f+196>>2]|0;m=j+20|0;if(K<<24>>24==0){p=0;return p|0}else{N=0}while(1){K=b[f+(N<<2)>>1]|0;q=K&65535;o=b[f+(N<<2)+2>>1]|0;M=o&65535;L=d[f+128+(N<<1)|0]|0;J=d[f+128+(N<<1)+1|0]|0;u=L+5|0;r=o<<16>>16==0;if(!r){o=L>>>0<q>>>0;z=1-L|0;x=(z|0)<(q|0);y=L+q|0;t=K<<16>>16==0;A=L+2|0;B=(((A>>>0>q>>>0?A:q)+~L|0)>>>1)+1|0;A=0;do{if(o){v=ba(A,k)|0;C=L;n=0;while(1){c[j+(C+u<<2)>>2]=((c[i+(n+v<<2)>>2]|0)*80621|0)+32768>>16;w=C+2|0;if((w|0)<(q|0)){C=w;n=n+1|0}else{O=B;break}}}else{O=0}if(x){n=ba(A,k)|0;C=z;v=O;while(1){c[j+(C+u<<2)>>2]=((c[i+(v+n<<2)>>2]|0)*106544|0)+32768>>16;w=C+2|0;if((w|0)<(q|0)){C=w;v=v+1|0}else{break}}}FJa(m,L,y);if(!t){v=ba(A,k)|0;C=0;do{c[i+(C+v<<2)>>2]=c[j+(C+u<<2)>>2];C=C+1|0;}while((C|0)<(q|0))}A=A+1|0;}while((A|0)<(M|0))}A=J+5|0;if(!(K<<16>>16==0)){u=J>>>0<M>>>0;t=1-J|0;y=(t|0)<(M|0);L=J+M|0;z=J+2|0;x=(((z>>>0>M>>>0?z:M)+~J|0)>>>1)+1|0;z=0;do{if(u){B=J;o=0;while(1){c[j+(B+A<<2)>>2]=((c[i+((ba(o,k)|0)+z<<2)>>2]|0)*80621|0)+32768>>16;C=B+2|0;if((C|0)<(M|0)){B=C;o=o+1|0}else{P=x;break}}}else{P=0}if(y){o=t;B=P;while(1){c[j+(o+A<<2)>>2]=((c[i+((ba(B,k)|0)+z<<2)>>2]|0)*106544|0)+32768>>16;C=o+2|0;if((C|0)<(M|0)){o=C;B=B+1|0}else{break}}}FJa(m,J,L);if(!r){B=0;do{c[i+((ba(B,k)|0)+z<<2)>>2]=c[j+(B+A<<2)>>2];B=B+1|0;}while((B|0)<(M|0))}z=z+1|0;}while((z|0)<(q|0))}q=N+1|0;if((q|0)<(d[h]|0|0)){N=q}else{p=0;break}}return p|0}else{p=-1;return p|0}return 0}function DJa(a){a=a|0;$Db(a+200|0);$Db(a+196|0);return}function EJa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+1|0;if((e|0)==(d|0)){return}c[a+(b-1<<2)>>2]=c[a+(e<<2)>>2];c[a+(d<<2)>>2]=c[a+(d-2<<2)>>2];c[a+(b-2<<2)>>2]=c[a+(b+2<<2)>>2];c[a+(d+1<<2)>>2]=c[a+(d-3<<2)>>2];e=(b|0)/2|0;b=(d|0)/2|0;d=b+1|0;if((e|0)<(d|0)){f=e;do{g=f<<1;h=a+(g<<2)|0;c[h>>2]=(c[h>>2]|0)-((c[a+(g-1<<2)>>2]|0)+2+(c[a+((g|1)<<2)>>2]|0)>>2);f=f+1|0;}while((f|0)<(d|0))}if((e|0)<(b|0)){i=e}else{return}do{e=i<<1;d=a+((e|1)<<2)|0;c[d>>2]=((c[a+(e+2<<2)>>2]|0)+(c[a+(e<<2)>>2]|0)>>1)+(c[d>>2]|0);i=i+1|0;}while((i|0)<(b|0));return}function FJa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+1|0;if((e|0)==(d|0)){return}c[a+(b-1<<2)>>2]=c[a+(e<<2)>>2];c[a+(d<<2)>>2]=c[a+(d-2<<2)>>2];c[a+(b-2<<2)>>2]=c[a+(b+2<<2)>>2];c[a+(d+1<<2)>>2]=c[a+(d-3<<2)>>2];c[a+(b-3<<2)>>2]=c[a+(b+3<<2)>>2];c[a+(d+2<<2)>>2]=c[a+(d-4<<2)>>2];c[a+(b-4<<2)>>2]=c[a+(b+4<<2)>>2];c[a+(d+3<<2)>>2]=c[a+(d-5<<2)>>2];e=(b|0)/2|0;b=e-1|0;f=(d|0)/2|0;d=f+2|0;if((b|0)<(d|0)){g=b;do{h=g<<1;i=a+(h<<2)|0;c[i>>2]=(c[i>>2]|0)-((((c[a+((h|1)<<2)>>2]|0)+(c[a+(h-1<<2)>>2]|0)|0)*29066|0)+32768>>16);g=g+1|0;}while((g|0)<(d|0))}d=f+1|0;if((b|0)<(d|0)){g=b;do{b=g<<1;h=a+((b|1)<<2)|0;c[h>>2]=(c[h>>2]|0)-((((c[a+(b+2<<2)>>2]|0)+(c[a+(b<<2)>>2]|0)|0)*57862|0)+32768>>16);g=g+1|0;}while((g|0)<(d|0))}if((e|0)<(d|0)){g=e;do{b=g<<1;h=a+(b<<2)|0;c[h>>2]=((((c[a+((b|1)<<2)>>2]|0)+(c[a+(b-1<<2)>>2]|0)|0)*3472|0)+32768>>16)+(c[h>>2]|0);g=g+1|0;}while((g|0)<(d|0))}if((e|0)<(f|0)){j=e}else{return}do{e=j<<1;d=a+((e|1)<<2)|0;c[d>>2]=((((c[a+(e+2<<2)>>2]|0)+(c[a+(e<<2)>>2]|0)|0)*103949|0)+32768>>16)+(c[d>>2]|0);j=j+1|0;}while((j|0)<(f|0));return}function GJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0,j=0;d=b+1|0;if((d|0)==(c|0)){return}g[a+(b-1<<2)>>2]=+g[a+(d<<2)>>2];g[a+(c<<2)>>2]=+g[a+(c-2<<2)>>2];g[a+(b-2<<2)>>2]=+g[a+(b+2<<2)>>2];g[a+(c+1<<2)>>2]=+g[a+(c-3<<2)>>2];g[a+(b-3<<2)>>2]=+g[a+(b+3<<2)>>2];g[a+(c+2<<2)>>2]=+g[a+(c-4<<2)>>2];g[a+(b-4<<2)>>2]=+g[a+(b+4<<2)>>2];g[a+(c+3<<2)>>2]=+g[a+(c-5<<2)>>2];d=(b|0)/2|0;b=d-1|0;e=(c|0)/2|0;c=e+2|0;if((b|0)<(c|0)){f=b;do{h=f<<1;i=a+(h<<2)|0;g[i>>2]=+g[i>>2]-(+g[a+(h-1<<2)>>2]+ +g[a+((h|1)<<2)>>2])*.4435068666934967;f=f+1|0;}while((f|0)<(c|0))}c=e+1|0;if((b|0)<(c|0)){f=b;do{b=f<<1;h=a+((b|1)<<2)|0;g[h>>2]=+g[h>>2]-(+g[a+(b<<2)>>2]+ +g[a+(b+2<<2)>>2])*.8829110860824585;f=f+1|0;}while((f|0)<(c|0))}if((d|0)<(c|0)){f=d;do{b=f<<1;h=a+(b<<2)|0;g[h>>2]=+g[h>>2]+(+g[a+(b-1<<2)>>2]+ +g[a+((b|1)<<2)>>2])*.05298011749982834;f=f+1|0;}while((f|0)<(c|0))}if((d|0)<(e|0)){j=d}else{return}do{d=j<<1;c=a+((d|1)<<2)|0;g[c>>2]=+g[c>>2]+(+g[a+(d<<2)>>2]+ +g[a+(d+2<<2)>>2])*1.5861343145370483;j=j+1|0;}while((j|0)<(e|0));return}function HJa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+1|0;if((e|0)==(d|0)){return}c[a+(b-1<<2)>>2]=c[a+(e<<2)>>2];c[a+(d<<2)>>2]=c[a+(d-2<<2)>>2];c[a+(b-2<<2)>>2]=c[a+(b+2<<2)>>2];f=d+1|0;c[a+(f<<2)>>2]=c[a+(d-3<<2)>>2];c[a+(b-3<<2)>>2]=c[a+(b+3<<2)>>2];c[a+(d+2<<2)>>2]=c[a+(d-4<<2)>>2];c[a+(b-4<<2)>>2]=c[a+(b+4<<2)>>2];c[a+(d+3<<2)>>2]=c[a+(d-5<<2)>>2];d=(e|0)/2|0;e=d-2|0;b=(f|0)/2|0;f=b+1|0;if((e|0)<(f|0)){g=e;do{e=g<<1;h=a+((e|1)<<2)|0;c[h>>2]=(c[h>>2]|0)-((((c[a+(e+2<<2)>>2]|0)+(c[a+(e<<2)>>2]|0)|0)*103949|0)+32768>>16);g=g+1|0;}while((g|0)<(f|0))}g=d-1|0;if((g|0)<(f|0)){e=g;do{h=e<<1;i=a+(h<<2)|0;c[i>>2]=(c[i>>2]|0)-((((c[a+((h|1)<<2)>>2]|0)+(c[a+(h-1<<2)>>2]|0)|0)*3472|0)+32768>>16);e=e+1|0;}while((e|0)<(f|0))}if((g|0)<(b|0)){f=g;do{g=f<<1;e=a+((g|1)<<2)|0;c[e>>2]=((((c[a+(g+2<<2)>>2]|0)+(c[a+(g<<2)>>2]|0)|0)*57862|0)+32768>>16)+(c[e>>2]|0);f=f+1|0;}while((f|0)<(b|0))}if((d|0)<(b|0)){j=d}else{return}do{d=j<<1;f=a+(d<<2)|0;c[f>>2]=((((c[a+((d|1)<<2)>>2]|0)+(c[a+(d-1<<2)>>2]|0)|0)*29066|0)+32768>>16)+(c[f>>2]|0);j=j+1|0;}while((j|0)<(b|0));return}function IJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0,j=0;d=b+1|0;if((d|0)==(c|0)){return}g[a+(b-1<<2)>>2]=+g[a+(d<<2)>>2];g[a+(c<<2)>>2]=+g[a+(c-2<<2)>>2];g[a+(b-2<<2)>>2]=+g[a+(b+2<<2)>>2];e=c+1|0;g[a+(e<<2)>>2]=+g[a+(c-3<<2)>>2];g[a+(b-3<<2)>>2]=+g[a+(b+3<<2)>>2];g[a+(c+2<<2)>>2]=+g[a+(c-4<<2)>>2];g[a+(b-4<<2)>>2]=+g[a+(b+4<<2)>>2];g[a+(c+3<<2)>>2]=+g[a+(c-5<<2)>>2];c=(d|0)/2|0;d=c-2|0;b=(e|0)/2|0;e=b+1|0;if((d|0)<(e|0)){f=d;do{d=f<<1;h=a+((d|1)<<2)|0;g[h>>2]=+g[h>>2]-(+g[a+(d<<2)>>2]+ +g[a+(d+2<<2)>>2])*1.586134;f=f+1|0;}while((f|0)<(e|0))}f=c-1|0;if((f|0)<(e|0)){d=f;do{h=d<<1;i=a+(h<<2)|0;g[i>>2]=+g[i>>2]-(+g[a+(h-1<<2)>>2]+ +g[a+((h|1)<<2)>>2])*.05298;d=d+1|0;}while((d|0)<(e|0))}if((f|0)<(b|0)){e=f;do{f=e<<1;d=a+((f|1)<<2)|0;g[d>>2]=+g[d>>2]+(+g[a+(f<<2)>>2]+ +g[a+(f+2<<2)>>2])*.882911;e=e+1|0;}while((e|0)<(b|0))}if((c|0)<(b|0)){j=c}else{return}do{c=j<<1;e=a+(c<<2)|0;g[e>>2]=+g[e>>2]+(+g[a+(c-1<<2)>>2]+ +g[a+((c|1)<<2)>>2])*.443506;j=j+1|0;}while((j|0)<(b|0));return}function JJa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;e=a+16|0;f=c[a+24>>2]|0;g=(c[e>>2]|0)+16|0;h=f>>>0>g>>>0?g:f;c[e>>2]=h;g=c[a+8>>2]|0;j=g+(h>>>3)|0;k=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(h&7)>>>24;j=h+8|0;h=f>>>0>j>>>0?j:f;c[e>>2]=h;if((k|0)==2|(k|0)==3){yDb(c[a+4>>2]|0,16,2266824,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-38;i=b;return m|0}else if((k|0)==4){yDb(c[a+4>>2]|0,16,2322368,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-38;i=b;return m|0}else if((k|0)==1){j=g+(h>>>3)|0;n=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(h&7)>>>16;j=h+16|0;h=f>>>0>j>>>0?j:f;c[e>>2]=h;c[a+876>>2]=n;n=g+(h>>>3)|0;j=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>16;n=h+16|0;h=f>>>0>n>>>0?n:f;c[e>>2]=h;c[a+884>>2]=j;j=g+(h>>>3)|0;n=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(h&7)>>>16;j=h+16|0;h=f>>>0>j>>>0?j:f;c[e>>2]=h;c[a+888>>2]=n;n=g+(h>>>3)|0;j=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>16;n=h+16|0;h=f>>>0>n>>>0?n:f;c[e>>2]=h;c[a+892>>2]=j;j=g+(h>>>3)|0;g=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(h&7)>>>16;j=h+16|0;c[e>>2]=f>>>0>j>>>0?j:f;c[a+896>>2]=g;m=0;i=b;return m|0}else{yDb(c[a+4>>2]|0,16,2186352,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;m=-1094995529;i=b;return m|0}return 0}function KJa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;k=i;i=i+16|0;l=k|0;m=f+1140|0;n=cEb(c[(c[m>>2]|0)+32>>2]|0)|0;o=c[c[m>>2]>>2]|0;p=cEb(5924)|0;q=p;r=p+5900|0;c[r>>2]=g;g=f+860|0;s=c[g>>2]|0;c[p+5884>>2]=(s|0)<2?2:s;s=p+5892|0;c[s>>2]=c[f+876>>2];t=p;c[t>>2]=c[f+884>>2];u=p+4|0;c[u>>2]=c[f+888>>2];v=p+8|0;c[v>>2]=c[f+892>>2];w=p+5880|0;c[w>>2]=c[f+896>>2];Rlb(q,0);Qlb(q);x=c[g>>2]|0;y=((x|0)<9?8:16)-x+h|0;x=f+4|0;z=c[x>>2]|0;if((c[z+688>>2]&1|0)!=0){A=c[f+904>>2]|0;B=c[r>>2]|0;r=c[s>>2]|0;s=c[t>>2]|0;t=c[u>>2]|0;u=c[v>>2]|0;v=c[w>>2]|0;w=c[p+5876>>2]|0;C=c[p+5888>>2]|0;D=c[p+5896>>2]|0;yDb(z,48,2109328,(E=i,i=i+88|0,c[E>>2]=c[f+900>>2],c[E+8>>2]=A,c[E+16>>2]=B,c[E+24>>2]=r,c[E+32>>2]=s,c[E+40>>2]=t,c[E+48>>2]=u,c[E+56>>2]=v,c[E+64>>2]=w,c[E+72>>2]=C,c[E+80>>2]=D,E)|0);i=E;D=c[g>>2]|0;C=c[f+2968>>2]|0;yDb(c[x>>2]|0,48,2051216,(E=i,i=i+32|0,c[E>>2]=j,c[E+8>>2]=h,c[E+16>>2]=D,c[E+24>>2]=C,E)|0);i=E}a:do{if((j|0)==1){TGb(l|0,0,12)|0;C=(c[f+916>>2]|0)>1?3:1;TGb(o|0,0,c[(c[m>>2]|0)+32>>2]|0)|0;D=ba(c[f+900>>2]|0,C)|0;h=f+904|0;if((c[h>>2]|0)<=0){F=0;G=C;break}w=f+2944|0;v=f+2948|0;u=f+16|0;t=f+24|0;s=o;r=n;B=0;while(1){A=0;do{z=r+A|0;H=l+(A<<2)|0;LJa(q,f,z,s+A|0,c[H>>2]|0,D,C,A,8);c[H>>2]=d[z]|0;do{if((c[w>>2]|0)!=0){z=(c[v>>2]|0)-1|0;c[v>>2]=z;if((z|0)!=0){break}z=c[u>>2]|0;H=-z&7;I=c[t>>2]|0;if((H|0)==0){J=z}else{K=H+z|0;z=I>>>0>K>>>0?K:I;c[u>>2]=z;J=z}z=J+16|0;c[u>>2]=I>>>0>z>>>0?z:I}}while(0);A=A+1|0;}while((A|0)<(C|0));A=B+1|0;if((A|0)<(c[h>>2]|0)){r=s;s=s+(c[(c[m>>2]|0)+32>>2]|0)|0;B=A}else{F=0;G=C;break}}}else if((j|0)==0){C=c[f+2968>>2]|0;B=c[f+916>>2]|0;if((C|0)>(B|0)){L=-1094995529;ZDb(p);ZDb(n);i=k;return L|0}s=(B|0)>1?3:1;B=C-1|0;C=s-1|0;if((B|0)<0){M=0}else{M=(B|0)>(C|0)?C:B}B=ba(c[f+900>>2]|0,s)|0;C=f+904|0;if((c[C>>2]|0)<=0){F=M;G=s;break}r=f+2944|0;h=f+2948|0;u=f+16|0;t=f+24|0;v=o+M|0;w=n;D=0;A=1;while(1){if((c[g>>2]|0)<9){LJa(q,f,w,v,D,B,s,M,8);N=d[w]|0}else{LJa(q,f,w,v,D,B,s,M,16);N=e[w>>1]|0}I=v+(c[(c[m>>2]|0)+32>>2]|0)|0;do{if((c[r>>2]|0)!=0){z=(c[h>>2]|0)-1|0;c[h>>2]=z;if((z|0)!=0){break}z=c[u>>2]|0;K=-z&7;H=c[t>>2]|0;if((K|0)==0){O=z}else{P=K+z|0;z=H>>>0>P>>>0?P:H;c[u>>2]=z;O=z}z=O+16|0;c[u>>2]=H>>>0>z>>>0?z:H}}while(0);if((A|0)>=(c[C>>2]|0)){F=M;G=s;break a}w=v;v=I;D=N;A=A+1|0}}else if((j|0)==2){EDb(c[x>>2]|0,2005808,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;L=-1163346256;ZDb(p);ZDb(n);i=k;return L|0}else{F=0;G=1}}while(0);j=f+868|0;N=c[j>>2]|0;b:do{if((N|0)!=0){if((c[f+916>>2]|0)!=3){break}M=(c[f+900>>2]|0)*3|0;if((c[g>>2]|0)>=9){EDb(c[x>>2]|0,1968136,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;break}O=f+904|0;if((c[O>>2]|0)<=0){break}q=(F|0)<(M|0);o=c[c[m>>2]>>2]|0;J=1;l=N;while(1){do{if((l|0)==3){if(q){Q=F}else{break}do{A=o+Q|0;D=o+(Q+2)|0;v=d[D]|0;w=o+(Q+1)|0;s=d[w]|0;C=(d[A]|0)-((s+v|0)>>>2)+64|0;a[A]=v+128+C;a[D]=s+128+C;a[w]=C;Q=Q+3|0;}while((Q|0)<(M|0))}else if((l|0)==2){if(q){R=F}else{break}do{C=a[o+(R+1)|0]|0;w=o+R|0;s=(a[w]|0)+(C^-128)&255;a[w]=s;w=o+(R+2)|0;a[w]=(d[w]|0)+128+(((s&255)+(C&255)|0)>>>1);R=R+3|0;}while((R|0)<(M|0))}else if((l|0)==4){if(q){S=F}else{break}do{C=o+S|0;s=d[C]|0;w=o+(S+2)|0;D=(d[w]|0)-128|0;v=s-((D*359|0)+490>>8)|0;A=o+(S+1)|0;u=(d[A]|0)-128|0;t=s-((D*-183|0)+30+(u*88|0)>>8)|0;D=((u*454|0)+574>>8)+s|0;if(v>>>0>255>>>0){T=-v>>31&255}else{T=v&255}a[C]=T;if(t>>>0>255>>>0){U=-t>>31&255}else{U=t&255}a[A]=U;if(D>>>0>255>>>0){V=-D>>31&255}else{V=D&255}a[w]=V;S=S+3|0;}while((S|0)<(M|0))}else if((l|0)==1){if(q){W=F}else{break}do{w=a[o+(W+1)|0]^-128;D=o+W|0;a[D]=(a[D]|0)+w;D=o+(W+2)|0;a[D]=(a[D]|0)+w;W=W+3|0;}while((W|0)<(M|0))}}while(0);if((J|0)>=(c[O>>2]|0)){break b}o=o+(c[(c[m>>2]|0)+32>>2]|0)|0;J=J+1|0;l=c[j>>2]|0}}}while(0);if((y|0)==0){L=0;ZDb(p);ZDb(n);i=k;return L|0}j=ba(c[f+916>>2]|0,c[f+900>>2]|0)|0;W=c[m>>2]|0;S=c[W>>2]|0;V=f+904|0;f=c[V>>2]|0;U=(f|0)>0;if((c[g>>2]|0)>=9){if(!U){L=0;ZDb(p);ZDb(n);i=k;return L|0}g=(j|0)>0;T=(c[W+32>>2]|0)/2|0;R=0;Q=S;while(1){if(g){N=0;do{E=Q+(N<<1)|0;b[E>>1]=(e[E>>1]|0)<<y;N=N+1|0;}while((N|0)<(j|0))}N=R+1|0;if((N|0)<(f|0)){R=N;Q=Q+(T<<1)|0}else{L=0;break}}ZDb(p);ZDb(n);i=k;return L|0}if(!U){L=0;ZDb(p);ZDb(n);i=k;return L|0}U=(F|0)<(j|0);T=0;Q=S;S=W;W=f;while(1){if(U){f=F;do{R=Q+f|0;a[R]=(d[R]|0)<<y;f=f+G|0;}while((f|0)<(j|0));X=c[m>>2]|0;Y=c[V>>2]|0}else{X=S;Y=W}f=T+1|0;if((f|0)<(Y|0)){T=f;Q=Q+(c[X+32>>2]|0)|0;S=X;W=Y}else{L=0;break}}ZDb(p);ZDb(n);i=k;return L|0}function LJa(f,g,h,i,j,k,l,m,n){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;if((k|0)<=0){return}o=(n|0)==8;n=i;p=h;q=k-l|0;r=f+5900|0;s=f+5892|0;t=g+8|0;u=f+8|0;v=f+4|0;w=f|0;x=f+5896|0;y=f+5904|0;z=g+16|0;A=t|0;B=g+24|0;g=f+5908+(m<<2)|0;m=f+5876|0;C=f+5888|0;D=f+5880|0;E=0;a:while(1){F=(E|0)!=0;do{if(F){G=E-l|0;if(o){H=i+G|0;I=8;break}else{J=n+(G<<1)|0;I=9;break}}else{if(o){H=h;I=8}else{J=p;I=9}}}while(0);if((I|0)==8){I=0;K=d[h+E|0]|0;L=d[H]|0}else if((I|0)==9){I=0;K=e[p+(E<<1)>>1]|0;L=e[J>>1]|0}do{if(F){G=E-l|0;if(o){M=d[h+G|0]|0;break}else{M=e[p+(G<<1)>>1]|0;break}}else{M=j}}while(0);do{if((E|0)<(q|0)){F=E+l|0;if(o){N=d[h+F|0]|0;break}else{N=e[p+(F<<1)>>1]|0;break}}else{if(o){N=d[h+E|0]|0;break}else{N=e[p+(E<<1)>>1]|0;break}}}while(0);F=N-K|0;G=K-M|0;O=M-L|0;P=c[r>>2]|0;do{if((((F|0)>-1?F:-F|0)|0)>(P|0)){I=83}else{if((((G|0)>-1?G:-G|0)|0)>(P|0)){I=83;break}if((((O|0)>-1?O:-O|0)|0)>(P|0)){I=83;break}Q=L&255;R=L&65535;b:do{if(o){S=E;while(1){T=c[z>>2]|0;U=c[A>>2]|0;V=d[U+(T>>>3)|0]|0;W=c[B>>2]|0;X=((T|0)<(W|0))+T|0;c[z>>2]=X;Y=c[g>>2]|0;Z=a[1192248+Y|0]|0;_=Z&255;if((V&128>>>((T&7)>>>0)|0)==0){$=S;aa=X;ca=Z;da=_;ea=W;fa=U;break b}if(((l<<_)+S|0)>(k|0)){ga=(k-S|0)/(l|0)|0}else{ga=1<<_}if((ga|0)>0){_=ba(ga,l)|0;U=S;W=0;while(1){a[i+U|0]=Q;X=W+1|0;if((X|0)<(ga|0)){U=U+l|0;W=X}else{break}}W=c[g>>2]|0;ha=S+_|0;ia=W;ja=a[1192248+W|0]|0}else{ha=S;ia=Y;ja=Z}if((ga|0)!=(1<<(ja&255)|0)){I=138;break a}if((ia|0)<31){c[g>>2]=ia+1}if((ha+l|0)>(k|0)){I=138;break a}else{S=ha}}}else{S=c[A>>2]|0;W=E;while(1){U=c[z>>2]|0;X=d[S+(U>>>3)|0]|0;T=c[B>>2]|0;V=((U|0)<(T|0))+U|0;c[z>>2]=V;ka=c[g>>2]|0;la=a[1192248+ka|0]|0;ma=la&255;if((X&128>>>((U&7)>>>0)|0)==0){$=W;aa=V;ca=la;da=ma;ea=T;fa=S;break b}T=1<<ma;if(((l<<ma)+W|0)>(k|0)){na=(k-W|0)/(l|0)|0}else{na=T}if((na|0)>0){ma=ba(na,l)|0;la=W;V=0;while(1){b[n+(la<<1)>>1]=R;U=V+1|0;if((U|0)<(na|0)){la=la+l|0;V=U}else{break}}oa=W+ma|0}else{oa=W}if((na|0)!=(T|0)){I=138;break a}if((ka|0)<31){c[g>>2]=ka+1}if((oa+l|0)>(k|0)){I=138;break a}else{W=oa}}}}while(0);do{if(ca<<24>>24==0){pa=da}else{W=fa+(aa>>>3)|0;S=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(aa&7);if((ca&255)>>>0<26>>>0){W=aa+da|0;c[z>>2]=ea>>>0>W>>>0?W:ea;pa=S>>>((32-da|0)>>>0);break}else{W=aa+16|0;V=ea>>>0>W>>>0?W:ea;c[z>>2]=V;W=da-16|0;la=fa+(V>>>3)|0;Z=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(V&7)>>>((48-da|0)>>>0);la=V+W|0;c[z>>2]=ea>>>0>la>>>0?la:ea;pa=Z|S>>>16<<W;break}}}while(0);if(((ba(pa,l)|0)+$|0)>(k|0)){qa=(k-$|0)/(l|0)|0}else{qa=pa}if((qa|0)>0){if(o){W=$;S=0;while(1){a[i+W|0]=Q;Z=S+1|0;if((Z|0)<(qa|0)){W=W+l|0;S=Z}else{break}}}else{S=$;W=0;while(1){b[n+(S<<1)>>1]=R;Q=W+1|0;if((Q|0)<(qa|0)){S=S+l|0;W=Q}else{break}}}ra=$+(ba(qa,l)|0)|0}else{ra=$}if(o){sa=d[h+ra|0]|0}else{sa=e[p+(ra<<1)>>1]|0}W=L-sa|0;S=(((W|0)>-1?W:-W|0)|0)<=(c[r>>2]|0);W=S&1;R=d[1192248+(c[g>>2]|0)|0]|0;Q=S?366:365;Z=f+12+(Q<<2)|0;la=c[Z>>2]|0;V=f+4408+(Q<<2)|0;Y=c[V>>2]|0;if(S){ta=(Y>>1)+la|0}else{ta=la}la=0;while(1){if((Y<<la|0)<(ta|0)){la=la+1|0}else{break}}Y=NJa(t,la,(c[m>>2]|0)+~R|0,c[C>>2]|0)|0;do{if((la|0)==0){if((Y|0)==0&(S^1)){ua=0;break}ua=(c[f+1480+(Q<<2)>>2]<<1|0)<(c[V>>2]|0)|0}else{ua=0}}while(0);la=Y+W+ua|0;if((la&1|0)==0){va=la>>1}else{R=f+1480+(Q<<2)|0;c[R>>2]=(c[R>>2]|0)+1;va=ua-(la+1>>1)|0}la=(va|0)>-1?va:-va|0;if((la|0)>65535){wa=-65536}else{R=(c[Z>>2]|0)+(la-W)|0;c[Z>>2]=R;la=ba(c[y>>2]|0,va)|0;_=c[V>>2]|0;if((_|0)==(c[D>>2]|0)){c[Z>>2]=R>>1;R=f+1480+(Q<<2)|0;c[R>>2]=c[R>>2]>>1;R=_>>1;c[V>>2]=R;xa=R}else{xa=_}c[V>>2]=xa+1;wa=la}la=c[g>>2]|0;if((la|0)!=0){c[g>>2]=la-1}la=c[r>>2]|0;if(!((la|0)==0|S^1)){ya=wa+L|0;za=ra;Aa=la;break}if(sa>>>0<L>>>0){ya=sa-wa|0;za=ra;Aa=la;break}else{ya=wa+sa|0;za=ra;Aa=la;break}}}while(0);if((I|0)==83){I=0;do{if((N|0)==(K|0)){Ba=0}else{if((F|0)<0){if((F|0)<=(-(c[u>>2]|0)|0)){Ba=-4;break}if((F|0)<=(-(c[v>>2]|0)|0)){Ba=-3;break}if((F|0)<=(-(c[w>>2]|0)|0)){Ba=-2;break}Ba=((F|0)<(-P|0))<<31>>31;break}else{if((P|0)>=(F|0)){Ba=0;break}if((c[w>>2]|0)>(F|0)){Ba=1;break}if((c[v>>2]|0)>(F|0)){Ba=2;break}Ba=(c[u>>2]|0)>(F|0)?3:4;break}}}while(0);F=Ba*81|0;do{if((K|0)==(M|0)){Ca=0}else{if((G|0)<0){if((G|0)<=(-(c[u>>2]|0)|0)){Ca=-4;break}if((G|0)<=(-(c[v>>2]|0)|0)){Ca=-3;break}if((G|0)<=(-(c[w>>2]|0)|0)){Ca=-2;break}Ca=((G|0)<(-P|0))<<31>>31;break}else{if((P|0)>=(G|0)){Ca=0;break}if((c[w>>2]|0)>(G|0)){Ca=1;break}if((c[v>>2]|0)>(G|0)){Ca=2;break}Ca=(c[u>>2]|0)>(G|0)?3:4;break}}}while(0);G=(Ca*9|0)+F|0;do{if((M|0)==(L|0)){Da=0}else{if((O|0)<0){if((O|0)<=(-(c[u>>2]|0)|0)){Da=-4;break}if((O|0)<=(-(c[v>>2]|0)|0)){Da=-3;break}if((O|0)<=(-(c[w>>2]|0)|0)){Da=-2;break}Da=((O|0)<(-P|0))<<31>>31;break}else{if((P|0)>=(O|0)){Da=0;break}if((c[w>>2]|0)>(O|0)){Da=1;break}if((c[v>>2]|0)>(O|0)){Da=2;break}Da=(c[u>>2]|0)>(O|0)?3:4;break}}}while(0);O=G+Da|0;P=K+L-M|0;do{if((L|0)>(P|0)){if((K|0)<=(P|0)){Ea=P;break}Ea=K>>>0>L>>>0?L:K}else{if((P|0)<=(K|0)){Ea=P;break}Ea=K>>>0>L>>>0?K:L}}while(0);P=(O|0)<0;G=P?-O|0:O;F=c[f+2948+(G<<2)>>2]|0;if(P){P=Ea-F|0;la=c[s>>2]|0;if((P|0)<0){Fa=0}else{Fa=(P|0)>(la|0)?la:P}Ga=Fa;Ha=-(MJa(t,f,G)|0)|0}else{P=F+Ea|0;F=c[s>>2]|0;if((P|0)<0){Ia=0}else{Ia=(P|0)>(F|0)?F:P}Ga=Ia;Ha=MJa(t,f,G)|0}ya=Ga+Ha|0;za=E;Aa=c[r>>2]|0}do{if((Aa|0)==0){Ja=ya;Ka=c[s>>2]|0}else{do{if((ya|0)<(-Aa|0)){G=(ba(c[y>>2]|0,c[x>>2]|0)|0)+ya|0;La=G;Ma=c[s>>2]|0}else{G=c[s>>2]|0;if((ya|0)<=(G+Aa|0)){La=ya;Ma=G;break}La=ya-(ba(c[y>>2]|0,c[x>>2]|0)|0)|0;Ma=G}}while(0);if((La|0)<0){Ja=0;Ka=Ma;break}Ja=(La|0)>(Ma|0)?Ma:La;Ka=Ma}}while(0);O=Ka&Ja;if(o){a[i+za|0]=O}else{b[n+(za<<1)>>1]=O}O=za+l|0;if((O|0)<(k|0)){E=O}else{I=138;break}}if((I|0)==138){return}}function MJa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b+4408+(d<<2)|0;f=c[e>>2]|0;g=b+12+(d<<2)|0;h=c[g>>2]|0;i=0;while(1){if((f<<i|0)<(h|0)){i=i+1|0}else{break}}h=NJa(a,i,c[b+5876>>2]|0,c[b+5888>>2]|0)|0;if((h&1|0)==0){j=h>>1}else{j=-(h+1>>1)|0}if((c[b+5900>>2]|i|0)==0){k=((c[b+1480+(d<<2)>>2]<<1|0)<=(-(c[e>>2]|0)|0))<<31>>31^j}else{k=j}j=(k|0)>-1?k:-k|0;if((j|0)>65535){l=-65536;return l|0}i=(c[g>>2]|0)+j|0;c[g>>2]=i;j=ba(c[b+5904>>2]|0,k)|0;k=b+1480+(d<<2)|0;h=(c[k>>2]|0)+j|0;c[k>>2]=h;a=c[e>>2]|0;if((a|0)==(c[b+5880>>2]|0)){c[g>>2]=i>>1;i=h>>1;c[k>>2]=i;g=a>>1;c[e>>2]=g;m=g;n=i}else{m=a;n=h}h=m+1|0;c[e>>2]=h;if((n|0)<=(~m|0)){e=h+n|0;a=-m|0;c[k>>2]=(e|0)>(a|0)?e:a;a=b+2948+(d<<2)|0;e=c[a>>2]|0;if(!((e|0)>-128)){l=j;return l|0}c[a>>2]=e-1;l=j;return l|0}if((n|0)<=0){l=j;return l|0}e=n-h|0;c[k>>2]=(e|0)>0?0:e;e=b+2948+(d<<2)|0;d=c[e>>2]|0;if((d|0)>=127){l=j;return l|0}c[e>>2]=d+1;l=j;return l|0}function NJa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=a+8|0;h=c[g>>2]|0;i=c[a+16>>2]|0;j=c[a>>2]|0;k=j+(h>>>3)|0;l=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(h&7);k=l>>>0>65535>>>0;m=k?l>>>16:l;n=k?16:0;if((m&65280|0)==0){o=n;p=m}else{o=n|8;p=m>>>8}m=(d[1191992+p|0]|0)+o|0;o=m-b|0;if((o|0)>6&(32-m|0)<(e|0)){p=b+32+h-m|0;c[g>>2]=i>>>0>p>>>0?p:i;q=(l>>>(o>>>0))+(30-m<<b)|0;return q|0}a:do{if((e|0)>0&(l|0)>-1){m=c[a+12>>2]|0;o=h;p=0;while(1){if(!(m>>>0>o>>>0)){q=-1;break}n=o+1|0;k=i>>>0>n>>>0?n:i;n=j+(k>>>3)|0;r=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7);n=p+1|0;if((n|0)<(e|0)&(r|0)>-1){o=k;p=n}else{s=k;t=r;u=n;break a}}return q|0}else{s=h;t=l;u=0}}while(0);l=t<<1;t=s+1|0;s=i>>>0>t>>>0?t:i;t=e-1|0;if((u|0)<(t|0)){if((b|0)==0){v=s;w=0}else{e=s+b|0;v=i>>>0>e>>>0?e:i;w=l>>>((32-b|0)>>>0)}c[g>>2]=v;q=w+(u<<b)|0;return q|0}else{if((u|0)!=(t|0)){q=-1;return q|0}t=s+f|0;c[g>>2]=i>>>0>t>>>0?t:i;q=(l>>>((32-f|0)>>>0))+1|0;return q|0}return 0}function OJa(a){a=a|0;var b=0,d=0,e=0;b=i;d=ICb()|0;c[a+804>>2]=d;if((d|0)==0){e=-12;i=b;return e|0}c[d+88>>2]=1;c[d+84>>2]=1;d=c[a+140>>2]|0;if((d|0)==8|(d|0)==32|(d|0)==2|(d|0)==3){e=0;i=b;return e|0}yDb(a,16,2186296,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1;i=b;return e|0}function PJa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0;j=i;i=i+6024|0;k=j|0;l=j+5928|0;m=j+5952|0;n=j+5976|0;o=j+5984|0;p=j+5992|0;q=j+6008|0;r=c[b+216>>2]|0;s=b+140|0;t=c[s>>2]|0;if((t|0)==8|(t|0)==32){u=1}else{u=3}t=b+120|0;v=b+124|0;w=(ba(ba(u<<2,c[t>>2]|0)|0,c[v>>2]|0)|0)+16384|0;y=r0a(b,f,w,(w|0)<0|0?-1:0)|0;if((y|0)<0){z=y;i=j;return z|0}y=f+28|0;w=WDb(c[y>>2]|0)|0;b=c[y>>2]|0;A=(b|0)<0;B=A?0:c[f+24>>2]|0;C=A?0:b;b=C<<3;c[l+20>>2]=b;D=l+8|0;c[D>>2]=B;c[l+16>>2]=B+C;E=l+12|0;c[E>>2]=B;F=l+4|0;G=l|0;H=A?0:w;c[m+20>>2]=b;b=m+8|0;c[b>>2]=H;c[m+16>>2]=H+C;C=m+12|0;c[C>>2]=H;H=m+4|0;c[H>>2]=32;A=m|0;c[A>>2]=0;I=B;x=-134227713;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;I=(c[E>>2]|0)+4|0;c[E>>2]=I;B=c[v>>2]|0;J=I;x=fe(((u*768|0)+2048|((c[s>>2]|0)==32?16:8))<<8|B>>>8|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;J=(c[E>>2]|0)+4|0;c[E>>2]=J;I=J;x=fe(u|(B<<16|c[t>>2])<<8|0)|0;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;I=(c[E>>2]|0)+4|0;c[E>>2]=I;c[G>>2]=u;c[F>>2]=32;B=1;J=u;K=32;L=1;M=I;while(1){if(L){N=K-8|0;O=J<<8|B;P=M}else{I=M;x=fe(B>>>((8-K|0)>>>0)|J<<K|0)|0;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;I=(c[E>>2]|0)+4|0;c[E>>2]=I;N=K+24|0;O=B;P=I}c[G>>2]=O;c[F>>2]=N;if((N|0)>8){Q=N-8|0;R=O<<8|17;S=P}else{I=P;x=fe(17>>>((8-N|0)>>>0)|O<<N|0)|0;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;I=(c[E>>2]|0)+4|0;c[E>>2]=I;Q=N+24|0;R=17;S=I}c[G>>2]=R;c[F>>2]=Q;if((Q|0)>8){T=Q-8|0;U=R<<8;V=S}else{I=S;x=fe(R<<Q|0)|0;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;I=(c[E>>2]|0)+4|0;c[E>>2]=I;T=Q+24|0;U=0;V=I}c[G>>2]=U;c[F>>2]=T;I=B+1|0;W=(T|0)>8;if((I|0)>(u|0)){break}else{B=I;J=U;K=T;L=W;M=V}}if(W){X=T-8|0;Y=U<<8|255;Z=V}else{W=V;x=fe(255>>>((8-T|0)>>>0)|U<<T|0)|0;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;W=(c[E>>2]|0)+4|0;c[E>>2]=W;X=T+24|0;Y=255;Z=W}c[G>>2]=Y;c[F>>2]=X;if((X|0)>8){_=X-8|0;$=Y<<8|218;aa=Z}else{W=Z;x=fe(218>>>((8-X|0)>>>0)|Y<<X|0)|0;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;W=(c[E>>2]|0)+4|0;c[E>>2]=W;_=X+24|0;$=218;aa=W}c[G>>2]=$;c[F>>2]=_;W=(u<<1)+6|0;if((_|0)>16){ca=_-16|0;da=$<<16|W;ea=aa}else{X=aa;x=fe(W>>>((16-_|0)>>>0)|$<<_|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=(c[E>>2]|0)+4|0;c[E>>2]=X;ca=_+16|0;da=W;ea=X}c[G>>2]=da;c[F>>2]=ca;if((ca|0)>8){fa=ca-8|0;ga=da<<8|u;ha=ea}else{X=ea;x=fe(u>>>((8-ca|0)>>>0)|da<<ca|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;X=(c[E>>2]|0)+4|0;c[E>>2]=X;fa=ca+24|0;ga=u;ha=X}c[G>>2]=ga;c[F>>2]=fa;X=1;ca=ga;ga=fa;da=(fa|0)>8;fa=ha;while(1){if(da){ia=ga-8|0;ja=ca<<8|X;ka=fa}else{ha=fa;x=fe(X>>>((8-ga|0)>>>0)|ca<<ga|0)|0;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;ha=(c[E>>2]|0)+4|0;c[E>>2]=ha;ia=ga+24|0;ja=X;ka=ha}c[G>>2]=ja;c[F>>2]=ia;if((ia|0)>8){la=ia-8|0;ma=ja<<8;na=ka}else{ha=ka;x=fe(ja<<ia|0)|0;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;ha=(c[E>>2]|0)+4|0;c[E>>2]=ha;la=ia+24|0;ma=0;na=ha}c[G>>2]=ma;c[F>>2]=la;ha=X+1|0;oa=(la|0)>8;if((ha|0)>(u|0)){break}else{X=ha;ca=ma;ga=la;da=oa;fa=na}}if(oa){pa=la-8|0;qa=ma<<8|r;ra=na}else{oa=na;x=fe(r>>>((8-la|0)>>>0)|ma<<la|0)|0;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;oa=(c[E>>2]|0)+4|0;c[E>>2]=oa;pa=la+24|0;qa=r;ra=oa}c[G>>2]=qa;c[F>>2]=pa;oa=(u|0)!=1|0;if((pa|0)>8){sa=pa-8|0;ta=qa<<8|oa;ua=ra}else{u=ra;x=fe(oa>>>((8-pa|0)>>>0)|qa<<pa|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;u=(c[E>>2]|0)+4|0;c[E>>2]=u;sa=pa+24|0;ta=oa;ua=u}c[G>>2]=ta;c[F>>2]=sa;if((sa|0)>8){va=sa-8|0;wa=ta<<8;xa=ua}else{u=ua;x=fe(ta<<sa|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;u=(c[E>>2]|0)+4|0;c[E>>2]=u;va=sa+24|0;wa=0;xa=u}c[G>>2]=wa;c[F>>2]=va;u=cEb(5924)|0;sa=u;c[o>>2]=sa;c[u+5900>>2]=r;r=u+5884|0;c[r>>2]=(c[s>>2]|0)==32?16:8;Rlb(sa,0);Qlb(sa);TGb(k|0,0,5924)|0;c[k+5884>>2]=c[r>>2];c[k+5900>>2]=c[u+5900>>2];Rlb(k,1);r=u;do{if((c[r>>2]|0)==(c[k>>2]|0)){if((c[u+4>>2]|0)!=(c[k+4>>2]|0)){ya=48;break}if((c[u+8>>2]|0)!=(c[k+8>>2]|0)){ya=48;break}if((c[u+5880>>2]|0)!=(c[k+5880>>2]|0)){ya=48}}else{ya=48}}while(0);if((ya|0)==48){if((va|0)>8){za=va-8|0;Aa=wa<<8|255;Ba=xa}else{ya=xa;x=fe(255>>>((8-va|0)>>>0)|wa<<va|0)|0;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;ya=(c[E>>2]|0)+4|0;c[E>>2]=ya;za=va+24|0;Aa=255;Ba=ya}c[G>>2]=Aa;c[F>>2]=za;if((za|0)>8){Ca=za-8|0;Da=Aa<<8|248;Ea=Ba}else{ya=Ba;x=fe(248>>>((8-za|0)>>>0)|Aa<<za|0)|0;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;ya=(c[E>>2]|0)+4|0;c[E>>2]=ya;Ca=za+24|0;Da=248;Ea=ya}c[G>>2]=Da;c[F>>2]=Ca;if((Ca|0)>16){Fa=Ca-16|0;Ga=Da<<16|13;Ha=Ea}else{ya=Ea;x=fe(13>>>((16-Ca|0)>>>0)|Da<<Ca|0)|0;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;ya=(c[E>>2]|0)+4|0;c[E>>2]=ya;Fa=Ca+16|0;Ga=13;Ha=ya}c[G>>2]=Ga;c[F>>2]=Fa;if((Fa|0)>8){Ia=Fa-8|0;Ja=Ga<<8|1;Ka=Ha}else{ya=Ha;x=fe(1>>>((8-Fa|0)>>>0)|Ga<<Fa|0)|0;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;ya=(c[E>>2]|0)+4|0;c[E>>2]=ya;Ia=Fa+24|0;Ja=1;Ka=ya}c[G>>2]=Ja;c[F>>2]=Ia;ya=c[u+5892>>2]|0;if((Ia|0)>16){La=Ia-16|0;Ma=ya|Ja<<16;Na=Ka}else{Fa=Ka;x=fe(ya>>>((16-Ia|0)>>>0)|Ja<<Ia|0)|0;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;Fa=(c[E>>2]|0)+4|0;c[E>>2]=Fa;La=Ia+16|0;Ma=ya;Na=Fa}c[G>>2]=Ma;c[F>>2]=La;Fa=c[r>>2]|0;if((La|0)>16){Oa=La-16|0;Pa=Fa|Ma<<16;Qa=Na}else{r=Na;x=fe(Fa>>>((16-La|0)>>>0)|Ma<<La|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[E>>2]|0)+4|0;c[E>>2]=r;Oa=La+16|0;Pa=Fa;Qa=r}c[G>>2]=Pa;c[F>>2]=Oa;r=c[u+4>>2]|0;if((Oa|0)>16){Ra=Oa-16|0;Sa=r|Pa<<16;Ta=Qa}else{Fa=Qa;x=fe(r>>>((16-Oa|0)>>>0)|Pa<<Oa|0)|0;a[Fa]=x;x=x>>8;a[Fa+1|0]=x;x=x>>8;a[Fa+2|0]=x;x=x>>8;a[Fa+3|0]=x;Fa=(c[E>>2]|0)+4|0;c[E>>2]=Fa;Ra=Oa+16|0;Sa=r;Ta=Fa}c[G>>2]=Sa;c[F>>2]=Ra;Fa=c[u+8>>2]|0;if((Ra|0)>16){Ua=Ra-16|0;Va=Fa|Sa<<16;Wa=Ta}else{r=Ta;x=fe(Fa>>>((16-Ra|0)>>>0)|Sa<<Ra|0)|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=(c[E>>2]|0)+4|0;c[E>>2]=r;Ua=Ra+16|0;Va=Fa;Wa=r}c[G>>2]=Va;c[F>>2]=Ua;r=c[u+5880>>2]|0;if((Ua|0)>16){Xa=Ua-16|0;Ya=r|Va<<16}else{u=Wa;x=fe(r>>>((16-Ua|0)>>>0)|Va<<Ua|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;Xa=Ua+16|0;Ya=r}c[G>>2]=Ya;c[F>>2]=Xa}Xa=g+32|0;Ya=c[Xa>>2]|0;r=cEb((Ya|0)>-1?Ya:-Ya|0)|0;c[n>>2]=r;if((r|0)==0){ZDb(c[o>>2]|0);z=-12;i=j;return z|0}Ya=c[g>>2]|0;g=c[s>>2]|0;a:do{if((g|0)==3){TGb(q|0,0,12)|0;s=(c[t>>2]|0)*3|0;if((c[v>>2]|0)>0){Za=1;_a=r;$a=Ya;ab=0}else{break}while(1){Ua=_a+2|0;u=q+8|0;RJa(c[o>>2]|0,m,Ua,$a+2|0,ab,s,3,2,8);c[u>>2]=d[Ua]|0;Ua=_a+1|0;Va=q+4|0;RJa(c[o>>2]|0,m,Ua,$a+1|0,c[Va>>2]|0,s,3,1,8);c[Va>>2]=d[Ua]|0;Ua=q|0;RJa(c[o>>2]|0,m,_a,$a,c[Ua>>2]|0,s,3,0,8);c[Ua>>2]=d[_a]|0;if((Za|0)>=(c[v>>2]|0)){break a}Za=Za+1|0;_a=$a;$a=$a+(c[Xa>>2]|0)|0;ab=c[u>>2]|0}}else if((g|0)==8){if((c[v>>2]|0)>0){bb=1;cb=r;db=0;eb=Ya}else{break}while(1){RJa(c[o>>2]|0,m,cb,eb,db,c[t>>2]|0,1,0,8);if((bb|0)>=(c[v>>2]|0)){break a}s=d[cb]|0;bb=bb+1|0;cb=eb;db=s;eb=eb+(c[Xa>>2]|0)|0}}else if((g|0)==32){if((c[v>>2]|0)>0){fb=1;gb=r;hb=0;ib=Ya}else{break}while(1){RJa(c[o>>2]|0,m,gb,ib,hb,c[t>>2]|0,1,0,16);if((fb|0)>=(c[v>>2]|0)){break a}s=e[gb>>1]|0;fb=fb+1|0;gb=ib;hb=s;ib=ib+(c[Xa>>2]|0)|0}}else if((g|0)==2){TGb(p|0,0,12)|0;s=(c[t>>2]|0)*3|0;if((c[v>>2]|0)>0){jb=1;kb=r;lb=Ya;mb=0}else{break}while(1){u=p|0;RJa(c[o>>2]|0,m,kb,lb,mb,s,3,0,8);c[u>>2]=d[kb]|0;Ua=kb+1|0;Va=p+4|0;RJa(c[o>>2]|0,m,Ua,lb+1|0,c[Va>>2]|0,s,3,1,8);c[Va>>2]=d[Ua]|0;Ua=kb+2|0;Va=p+8|0;RJa(c[o>>2]|0,m,Ua,lb+2|0,c[Va>>2]|0,s,3,2,8);c[Va>>2]=d[Ua]|0;if((jb|0)>=(c[v>>2]|0)){break a}jb=jb+1|0;kb=lb;lb=lb+(c[Xa>>2]|0)|0;mb=c[u>>2]|0}}}while(0);$Db(n);$Db(o);o=c[A>>2]|0;n=c[H>>2]|0;if((n|0)>7){nb=n-7|0;ob=o<<7;pb=c[C>>2]|0}else{mb=fe(o<<n|0)|0;o=c[C>>2]|0;Xa=o;x=mb;a[Xa]=x;x=x>>8;a[Xa+1|0]=x;x=x>>8;a[Xa+2|0]=x;x=x>>8;a[Xa+3|0]=x;Xa=o+4|0;c[C>>2]=Xa;nb=n+25|0;ob=0;pb=Xa}c[A>>2]=ob;c[H>>2]=nb;Xa=(pb-(c[b>>2]|0)<<3)+(32-nb)|0;if((nb|0)<32){b=ob<<nb;c[A>>2]=b;ob=(((nb+8|0)>32?nb+7|0:31)-nb|0)>>>3;n=nb+(ob<<3)|0;o=ob+1|0;ob=b>>>24&255;mb=pb;lb=b;b=nb;while(1){a[mb]=ob;qb=lb<<8;nb=b+8|0;if((nb|0)<32){ob=lb>>>16&255;mb=mb+1|0;lb=qb;b=nb}else{break}}c[C>>2]=pb+o;c[A>>2]=qb;c[H>>2]=n+8}c[H>>2]=32;c[A>>2]=0;A=Xa>>>0>2147483639>>>0|(w|0)==0;H=A?0:w;n=A?8:Xa+8|0;A=Xa-7|0;if((A|0)>0){Xa=0;qb=c[G>>2]|0;o=c[F>>2]|0;while(1){pb=H+(Xa>>>3)|0;C=(fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(Xa&7)>>>24;pb=Xa+8|0;b=n>>>0>pb>>>0?pb:n;if((o|0)>8){rb=o-8|0;sb=qb<<8|C}else{pb=fe(C>>>((8-o|0)>>>0)|qb<<o|0)|0;lb=c[E>>2]|0;x=pb;a[lb]=x;x=x>>8;a[lb+1|0]=x;x=x>>8;a[lb+2|0]=x;x=x>>8;a[lb+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;rb=o+24|0;sb=C}c[G>>2]=sb;c[F>>2]=rb;if((C|0)==255){C=H+(b>>>3)|0;lb=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(b&7)>>>25;C=b+7|0;if((rb|0)>8){tb=rb-8|0;ub=sb<<8|lb}else{pb=fe(lb>>>((8-rb|0)>>>0)|sb<<rb|0)|0;mb=c[E>>2]|0;x=pb;a[mb]=x;x=x>>8;a[mb+1|0]=x;x=x>>8;a[mb+2|0]=x;x=x>>8;a[mb+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;tb=rb+24|0;ub=lb}c[G>>2]=ub;c[F>>2]=tb;vb=n>>>0>C>>>0?C:n;wb=ub;xb=tb}else{vb=b;wb=sb;xb=rb}if((vb|0)<(A|0)){Xa=vb;qb=wb;o=xb}else{break}}}K_(l);ZDb(w);w=c[G>>2]|0;l=c[F>>2]|0;if((l|0)>8){yb=l-8|0;zb=w<<8|255}else{xb=fe(255>>>((8-l|0)>>>0)|w<<l|0)|0;w=c[E>>2]|0;x=xb;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;yb=l+24|0;zb=255}c[G>>2]=zb;c[F>>2]=yb;if((yb|0)>8){Ab=yb-8|0;Bb=zb<<8|217}else{l=fe(217>>>((8-yb|0)>>>0)|zb<<yb|0)|0;zb=c[E>>2]|0;x=l;a[zb]=x;x=x>>8;a[zb+1|0]=x;x=x>>8;a[zb+2|0]=x;x=x>>8;a[zb+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;Ab=yb+24|0;Bb=217}c[G>>2]=Bb;c[F>>2]=Ab;b:do{if((Ab|0)<32){yb=Bb<<Ab;c[G>>2]=yb;zb=yb>>>24&255;while(1){yb=c[E>>2]|0;c[E>>2]=yb+1;a[yb]=zb;yb=c[G>>2]|0;c[G>>2]=yb<<8;l=(c[F>>2]|0)+8|0;c[F>>2]=l;if((l|0)>=32){break b}zb=yb>>>16&255}}}while(0);c[F>>2]=32;c[G>>2]=0;c[y>>2]=(c[E>>2]|0)-(c[D>>2]|0)<<3>>3;D=f+36|0;c[D>>2]=c[D>>2]|1;c[h>>2]=1;z=0;i=j;return z|0}function QJa(a){a=a|0;JCb(a+804|0);return 0}function RJa(f,g,h,i,j,k,l,m,n){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0;if((k|0)<=0){return}o=(n|0)==8;n=i;p=h;q=k-l|0;r=f+5900|0;s=f+5892|0;t=f+5896|0;u=f+5876|0;v=f+5888|0;w=f+5904|0;y=f+5880|0;z=f+8|0;A=f+4|0;B=f|0;C=f+5908+(m<<2)|0;m=g|0;D=g+4|0;E=g+12|0;F=0;a:while(1){G=(F|0)!=0;do{if(G){H=F-l|0;if(o){I=i+H|0;J=8;break}else{K=n+(H<<1)|0;J=9;break}}else{if(o){I=h;J=8}else{K=p;J=9}}}while(0);if((J|0)==8){J=0;L=d[h+F|0]|0;M=d[I]|0}else if((J|0)==9){J=0;L=e[p+(F<<1)>>1]|0;M=e[K>>1]|0}do{if(G){H=F-l|0;if(o){N=d[h+H|0]|0;break}else{N=e[p+(H<<1)>>1]|0;break}}else{N=j}}while(0);do{if((F|0)<(q|0)){G=F+l|0;if(o){O=d[h+G|0]|0;break}else{O=e[p+(G<<1)>>1]|0;break}}else{if(o){O=d[h+F|0]|0;break}else{O=e[p+(F<<1)>>1]|0;break}}}while(0);G=O-L|0;H=L-N|0;P=N-M|0;Q=c[r>>2]|0;do{if((((G|0)>-1?G:-G|0)|0)>(Q|0)){J=85}else{if((((H|0)>-1?H:-H|0)|0)>(Q|0)){J=85;break}if((((P|0)>-1?P:-P|0)|0)>(Q|0)){J=85;break}b:do{if((F|0)<(k|0)){R=M&255;S=M&65535;if(o){T=F;U=0;while(1){V=a[i+T|0]|0;W=V&255;if(((((V&255)-M|0)>-1?W-M|0:M-W|0)|0)>(c[r>>2]|0)){X=T;Y=U;Z=1;break b}W=U+1|0;a[i+T|0]=R;V=T+l|0;if((V|0)<(k|0)){T=V;U=W}else{X=V;Y=W;Z=0;break}}}else{U=F;T=0;while(1){R=b[n+(U<<1)>>1]|0;W=R&65535;if(((((R&65535)-M|0)>-1?W-M|0:M-W|0)|0)>(Q|0)){X=U;Y=T;Z=1;break b}W=T+1|0;b[n+(U<<1)>>1]=S;R=U+l|0;if((R|0)<(k|0)){U=R;T=W}else{X=R;Y=W;Z=0;break}}}}else{X=F;Y=0;Z=0}}while(0);if((1<<(d[1192248+(c[C>>2]|0)|0]|0)|0)>(Y|0)){_=Y}else{T=Y;while(1){U=c[m>>2]|0;S=c[D>>2]|0;if((S|0)>1){$=S-1|0;aa=U<<1|1}else{W=fe(1>>>((1-S|0)>>>0)|U<<S|0)|0;U=c[E>>2]|0;x=W;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;$=S+31|0;aa=1}c[m>>2]=aa;c[D>>2]=$;S=c[C>>2]|0;U=a[1192248+S|0]|0;W=T-(1<<(U&255))|0;if((S|0)<31){R=S+1|0;c[C>>2]=R;ca=a[1192248+R|0]|0}else{ca=U}if((W|0)<(1<<(ca&255)|0)){_=W;break}else{T=W}}}do{if(Z|(_|0)==0){if(!Z){J=164;break a}T=c[m>>2]|0;W=c[D>>2]|0;if((W|0)>1){da=W-1|0;ea=T<<1}else{U=fe(T<<W|0)|0;T=c[E>>2]|0;x=U;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;da=W+31|0;ea=0}c[m>>2]=ea;c[D>>2]=da;W=a[1192248+(c[C>>2]|0)|0]|0;if(W<<24>>24==0){break}T=W&255;if((da|0)>(T|0)){fa=da;ga=ea<<T|_}else{W=fe(_>>>((T-da|0)>>>0)|ea<<da|0)|0;U=c[E>>2]|0;x=W;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;fa=da+32|0;ga=_}c[m>>2]=ga;c[D>>2]=fa-T}else{T=c[m>>2]|0;U=c[D>>2]|0;if((U|0)>1){ha=U-1|0;ia=T<<1|1}else{W=fe(1>>>((1-U|0)>>>0)|T<<U|0)|0;T=c[E>>2]|0;x=W;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;ha=U+31|0;ia=1}c[m>>2]=ia;c[D>>2]=ha}}while(0);if(!Z){J=164;break a}if(o){ja=d[h+X|0]|0}else{ja=e[p+(X<<1)>>1]|0}U=M-ja|0;T=c[r>>2]|0;W=(((U|0)>-1?U:-U|0)|0)<=(T|0);U=W&1;R=W?M:ja;if(o){ka=d[i+X|0]|0}else{ka=e[n+(X<<1)>>1]|0}S=ka-R|0;V=M>>>0>ja>>>0&(W^1);la=V?-S|0:S;do{if((T|0)==0){ma=la}else{if((la|0)>0){S=c[w>>2]|0;na=(la+T|0)/(S|0)|0;oa=S}else{S=c[w>>2]|0;na=(la-T|0)/(S|0)|0;oa=S}S=ba(oa,na)|0;do{if(V){pa=R-S|0;qa=c[s>>2]|0;if((pa|0)<0){ra=0;sa=0;break}ta=(pa|0)>(qa|0)?qa:pa;ra=ta&255;sa=ta&65535}else{ta=S+R|0;pa=c[s>>2]|0;if((ta|0)<0){ra=0;sa=0;break}qa=(ta|0)>(pa|0)?pa:ta;ra=qa&255;sa=qa&65535}}while(0);if(o){a[i+X|0]=ra;ma=na;break}else{b[n+(X<<1)>>1]=sa;ma=na;break}}}while(0);R=c[t>>2]|0;V=ma+((ma|0)<0?R:0)|0;T=(V|0)<(R+1>>1|0)?0:R;R=V-T|0;la=d[1192248+(c[C>>2]|0)|0]|0;S=W?366:365;qa=f+12+(S<<2)|0;ta=c[qa>>2]|0;pa=f+4408+(S<<2)|0;ua=c[pa>>2]|0;if(W){va=(ua>>1)+ta|0}else{va=ta}ta=0;while(1){if((ua<<ta|0)<(va|0)){ta=ta+1|0}else{break}}if((ta|0)!=0|(V|0)==(T|0)){wa=0}else{wa=(c[f+1480+(S<<2)>>2]<<1|0)<(ua|0)|0}W=(R|0)<0;xa=R<<1;if(W){ya=~xa-U+wa|0}else{ya=xa-U-wa|0}SJa(g,ya,ta,(c[u>>2]|0)+~la|0,c[v>>2]|0);if(W){W=f+1480+(S<<2)|0;c[W>>2]=(c[W>>2]|0)+1}W=(c[qa>>2]|0)+(ya+(U^1)>>1)|0;c[qa>>2]=W;xa=c[pa>>2]|0;if((xa|0)==(c[y>>2]|0)){c[qa>>2]=W>>1;W=f+1480+(S<<2)|0;c[W>>2]=c[W>>2]>>1;W=xa>>1;c[pa>>2]=W;za=W}else{za=xa}c[pa>>2]=za+1;xa=c[C>>2]|0;if((xa|0)<=0){Aa=X;break}c[C>>2]=xa-1;Aa=X}}while(0);do{if((J|0)==85){J=0;do{if((O|0)==(L|0)){Ba=0}else{if((G|0)<0){if((G|0)<=(-(c[z>>2]|0)|0)){Ba=-4;break}if((G|0)<=(-(c[A>>2]|0)|0)){Ba=-3;break}if((G|0)<=(-(c[B>>2]|0)|0)){Ba=-2;break}Ba=((G|0)<(-Q|0))<<31>>31;break}else{if((Q|0)>=(G|0)){Ba=0;break}if((c[B>>2]|0)>(G|0)){Ba=1;break}if((c[A>>2]|0)>(G|0)){Ba=2;break}Ba=(c[z>>2]|0)>(G|0)?3:4;break}}}while(0);pa=Ba*81|0;do{if((L|0)==(N|0)){Ca=0}else{if((H|0)<0){if((H|0)<=(-(c[z>>2]|0)|0)){Ca=-4;break}if((H|0)<=(-(c[A>>2]|0)|0)){Ca=-3;break}if((H|0)<=(-(c[B>>2]|0)|0)){Ca=-2;break}Ca=((H|0)<(-Q|0))<<31>>31;break}else{if((Q|0)>=(H|0)){Ca=0;break}if((c[B>>2]|0)>(H|0)){Ca=1;break}if((c[A>>2]|0)>(H|0)){Ca=2;break}Ca=(c[z>>2]|0)>(H|0)?3:4;break}}}while(0);S=(Ca*9|0)+pa|0;do{if((N|0)==(M|0)){Da=0}else{if((P|0)<0){if((P|0)<=(-(c[z>>2]|0)|0)){Da=-4;break}if((P|0)<=(-(c[A>>2]|0)|0)){Da=-3;break}if((P|0)<=(-(c[B>>2]|0)|0)){Da=-2;break}Da=((P|0)<(-Q|0))<<31>>31;break}else{if((Q|0)>=(P|0)){Da=0;break}if((c[B>>2]|0)>(P|0)){Da=1;break}if((c[A>>2]|0)>(P|0)){Da=2;break}Da=(c[z>>2]|0)>(P|0)?3:4;break}}}while(0);pa=S+Da|0;qa=L+M-N|0;do{if((M|0)>(qa|0)){if((L|0)<=(qa|0)){Ea=qa;break}Ea=L>>>0>M>>>0?M:L}else{if((qa|0)<=(L|0)){Ea=qa;break}Ea=L>>>0>M>>>0?L:M}}while(0);if((pa|0)<0){qa=-pa|0;S=Ea-(c[f+2948+(qa<<2)>>2]|0)|0;U=c[s>>2]|0;if((S|0)<0){Fa=0}else{Fa=(S|0)>(U|0)?U:S}if(o){Ga=d[i+F|0]|0}else{Ga=e[n+(F<<1)>>1]|0}Ha=qa;Ia=1;Ja=Fa;Ka=Fa-Ga|0;La=U}else{U=(c[f+2948+(pa<<2)>>2]|0)+Ea|0;qa=c[s>>2]|0;if((U|0)<0){Ma=0}else{Ma=(U|0)>(qa|0)?qa:U}if(o){Na=d[i+F|0]|0}else{Na=e[n+(F<<1)>>1]|0}Ha=pa;Ia=0;Ja=Ma;Ka=Na-Ma|0;La=qa}do{if((Q|0)==0){Oa=Ka}else{if((Ka|0)>0){qa=c[w>>2]|0;Pa=(Q+Ka|0)/(qa|0)|0;Qa=qa}else{qa=c[w>>2]|0;Pa=(Ka-Q|0)/(qa|0)|0;Qa=qa}qa=ba(Qa,Pa)|0;do{if((Ia|0)==0){U=qa+Ja|0;if((U|0)<0){Ra=0;Sa=0;break}S=(U|0)>(La|0)?La:U;Ra=S&255;Sa=S&65535}else{S=Ja-qa|0;if((S|0)<0){Ra=0;Sa=0;break}U=(S|0)>(La|0)?La:S;Ra=U&255;Sa=U&65535}}while(0);if(o){a[i+F|0]=Ra;Oa=Pa;break}else{b[n+(F<<1)>>1]=Sa;Oa=Pa;break}}}while(0);pa=f+4408+(Ha<<2)|0;qa=c[pa>>2]|0;U=f+12+(Ha<<2)|0;S=c[U>>2]|0;la=0;while(1){if((qa<<la|0)<(S|0)){la=la+1|0}else{break}}if((c[r>>2]|la|0)==0){Ta=(c[f+1480+(Ha<<2)>>2]<<1|0)<=(-qa|0)|0}else{Ta=0}if((Oa|0)<0){Ua=(c[t>>2]|0)+Oa|0}else{Ua=Oa}S=c[t>>2]|0;if((Ua|0)<(S+1>>1|0)){Va=Ua;Wa=Ua<<1|Ta}else{ta=Ua-S|0;Va=ta;Wa=(((ta|0)>-1?ta:-ta|0)<<1)+~Ta|0}SJa(g,Wa,la,c[u>>2]|0,c[v>>2]|0);ta=(Va|0)>-1?Va:-Va|0;if((ta|0)>65535){Aa=F;break}S=(c[U>>2]|0)+ta|0;c[U>>2]=S;ta=ba(c[w>>2]|0,Va)|0;R=f+1480+(Ha<<2)|0;ua=(c[R>>2]|0)+ta|0;c[R>>2]=ua;ta=c[pa>>2]|0;if((ta|0)==(c[y>>2]|0)){c[U>>2]=S>>1;S=ua>>1;c[R>>2]=S;T=ta>>1;c[pa>>2]=T;Xa=T;Ya=S}else{Xa=ta;Ya=ua}ua=Xa+1|0;c[pa>>2]=ua;if((Ya|0)<=(~Xa|0)){ta=ua+Ya|0;S=-Xa|0;c[R>>2]=(ta|0)>(S|0)?ta:S;S=f+2948+(Ha<<2)|0;ta=c[S>>2]|0;if(!((ta|0)>-128)){Aa=F;break}c[S>>2]=ta-1;Aa=F;break}if((Ya|0)<=0){Aa=F;break}ta=Ya-ua|0;c[R>>2]=(ta|0)>0?0:ta;ta=f+2948+(Ha<<2)|0;R=c[ta>>2]|0;if((R|0)>=127){Aa=F;break}c[ta>>2]=R+1;Aa=F}}while(0);Q=Aa+l|0;if((Q|0)<(k|0)){F=Q}else{J=164;break}}if((J|0)==164){return}}function SJa(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=d>>e;i=h+1|0;if((i|0)>=(f|0)){j=b|0;k=c[j>>2]|0;l=b+4|0;m=c[l>>2]|0;if((f|0)>31){n=b+12|0;o=f-32|0;p=(o>>>0)%31|0;q=f;r=k;s=m;while(1){if((s|0)>31){t=s-31|0;u=r<<31}else{v=fe(r<<s|0)|0;w=c[n>>2]|0;x=v;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;t=s+1|0;u=0}c[j>>2]=u;c[l>>2]=t;w=q-31|0;if((w|0)>31){q=w;r=u;s=t}else{break}}y=f-31+(p-o)|0;z=u;A=t}else{y=f;z=k;A=m}if((A|0)>(y|0)){B=A-y|0;C=z<<y|1}else{m=fe(1>>>((y-A|0)>>>0)|z<<A|0)|0;z=b+12|0;k=c[z>>2]|0;x=m;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;B=32-y+A|0;C=1}c[j>>2]=C;c[l>>2]=B;A=d-1|0;if((B|0)>(g|0)){D=B-g|0;E=C<<g|A}else{y=fe(A>>>((g-B|0)>>>0)|C<<B|0)|0;C=b+12|0;z=c[C>>2]|0;x=y;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;D=32-g+B|0;E=A}c[j>>2]=E;c[l>>2]=D;return}D=b|0;l=c[D>>2]|0;E=b+4|0;j=c[E>>2]|0;if((i|0)>31){A=b+12|0;B=h-31|0;g=(B>>>0)%31|0;C=i;z=l;y=j;while(1){if((y|0)>31){F=y-31|0;G=z<<31}else{k=fe(z<<y|0)|0;m=c[A>>2]|0;x=k;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;F=y+1|0;G=0}c[D>>2]=G;c[E>>2]=F;m=C-31|0;if((m|0)>31){C=m;z=G;y=F}else{break}}H=h-30+(g-B)|0;I=G;J=F}else{H=i;I=l;J=j}if((J|0)>(H|0)){K=J-H|0;L=I<<H|1}else{j=fe(1>>>((H-J|0)>>>0)|I<<J|0)|0;I=b+12|0;l=c[I>>2]|0;x=j;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;K=32-H+J|0;L=1}c[D>>2]=L;c[E>>2]=K;if((e|0)==0){return}J=(1<<e)-1&d;if((K|0)>(e|0)){M=K-e|0;N=L<<e|J}else{d=fe(L<<K|J>>>((e-K|0)>>>0)|0)|0;L=b+12|0;b=c[L>>2]|0;x=d;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[L>>2]=(c[L>>2]|0)+4;M=32-e+K|0;N=J}c[D>>2]=N;c[E>>2]=M;return}function TJa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=a;e=7;while(1){f=d;g=b[d>>1]|0;h=g<<16>>16;i=d+2|0;j=b[i>>1]|0;k=j<<16>>16;l=d+4|0;m=b[l>>1]|0;n=m<<16>>16;o=d+6|0;p=b[o>>1]|0;q=p<<16>>16;r=d+8|0;s=b[r>>1]|0;t=s<<16>>16;u=d+10|0;v=b[u>>1]|0;w=v<<16>>16;x=d+12|0;y=b[x>>1]|0;z=y<<16>>16;A=d+14|0;B=b[A>>1]|0;C=B<<16>>16;do{if((m|j|p|s|v|y|B)<<16>>16==0){if(g<<16>>16==0){break}D=g<<2<<16>>16;E=D&65532|D<<16;c[f>>2]=E;c[l>>2]=E;c[r>>2]=E;c[x>>2]=E}else{E=j<<16>>16!=0;do{if(p<<16>>16==0){if(E){D=k*4433|0;F=k*10703|0;G=n+h<<13;H=h-n<<13;I=G-F|0;J=H-D|0;K=H+D|0;L=G+F|0;break}else{F=n+h<<13;G=h-n<<13;I=F;J=G;K=G;L=F;break}}else{if(E){F=(q+k|0)*4433|0;G=F+(q*-15137|0)|0;D=F+(k*6270|0)|0;F=n+h<<13;H=h-n<<13;I=F-D|0;J=H-G|0;K=G+H|0;L=D+F|0;break}else{F=q*-10703|0;D=q*4433|0;H=n+h<<13;G=h-n<<13;I=H-D|0;J=G-F|0;K=G+F|0;L=H+D|0;break}}}while(0);E=y<<16>>16!=0;D=v<<16>>16!=0;H=s<<16>>16!=0;do{if(B<<16>>16==0){if(!E){if(!D){if(!H){M=0;N=0;O=0;P=0;break}M=t*2260|0;N=t*6436|0;O=t*9633|0;P=t*11363|0;break}if(H){F=w+t|0;G=F*6436|0;Q=F*9633|0;M=(t*8697|0)-G|0;N=G+(w*-17799|0)|0;O=Q+(w*-11893|0)|0;P=Q+(t*1730|0)|0;break}else{M=w*-6436|0;N=w*-11363|0;O=w*-2260|0;P=w*9633|0;break}}if(D){Q=z+w|0;if(H){G=z+t|0;F=(G+w|0)*9633|0;R=Q*-20995|0;S=F+(w*-16069|0)|0;T=F+(G*-3196|0)|0;M=S+(t*-7373|0)|0;N=R+(z*16819|0)+T|0;O=R+(w*25172|0)+S|0;P=(t*4926|0)+T|0;break}else{T=Q*9633|0;S=Q*-11363|0;M=T+(w*-16069|0)|0;N=S+(z*13623|0)|0;O=S+(w*9102|0)|0;P=T+(z*-3196|0)|0;break}}else{if(H){T=z+t|0;S=T*9633|0;Q=T*6436|0;M=S+(t*-7373|0)|0;N=Q+(z*-4176|0)|0;O=S+(z*-20995|0)|0;P=Q+(t*4926|0)|0;break}else{M=z*9633|0;N=z*2260|0;O=z*-11363|0;P=z*6436|0;break}}}else{if(E){if(D){if(H){Q=C+w|0;S=z+t|0;T=(Q+S|0)*9633|0;R=(C+t|0)*-7373|0;G=(z+w|0)*-20995|0;F=T+(Q*-16069|0)|0;Q=T+(S*-3196|0)|0;M=R+(C*2446|0)+F|0;N=G+(z*16819|0)+Q|0;O=G+(w*25172|0)+F|0;P=R+(t*12299|0)+Q|0;break}else{Q=C+w|0;R=(Q+z|0)*9633|0;F=(z+w|0)*-20995|0;G=R+(Q*-16069|0)|0;Q=R+(z*-3196|0)|0;M=(C*-4927|0)+G|0;N=F+(z*16819|0)+Q|0;O=F+(w*25172|0)+G|0;P=Q+(C*-7373|0)|0;break}}else{if(H){Q=z+t|0;G=(C+Q|0)*9633|0;F=(C+t|0)*-7373|0;R=G+(C*-16069|0)|0;S=G+(Q*-3196|0)|0;M=F+(C*2446|0)+R|0;N=(z*-4176|0)+S|0;O=R+(z*-20995|0)|0;P=F+(t*12299|0)+S|0;break}else{S=(C+z|0)*9633|0;F=S+(C*-16069|0)|0;R=S+(z*-3196|0)|0;M=F+(C*-4926|0)|0;N=R+(z*-4176|0)|0;O=F+(z*-20995|0)|0;P=R+(C*-7373|0)|0;break}}}else{if(D){if(H){R=C+w|0;F=(R+t|0)*9633|0;S=(C+t|0)*-7373|0;Q=F+(R*-16069|0)|0;R=F+(t*-3196|0)|0;M=S+(C*2446|0)+Q|0;N=R+(w*-20995|0)|0;O=(w*4177|0)+Q|0;P=S+(t*12299|0)+R|0;break}else{R=C+w|0;S=R*9633|0;Q=R*-6436|0;M=Q+(C*-4926|0)|0;N=S+(w*-20995|0)|0;O=Q+(w*4176|0)|0;P=S+(C*-7373|0)|0;break}}else{if(H){S=C+t|0;Q=S*9633|0;R=S*2260|0;M=R+(C*-13623|0)|0;N=Q+(t*-3196|0)|0;O=Q+(C*-16069|0)|0;P=R+(t*9102|0)|0;break}else{M=C*-11363|0;N=C*9633|0;O=C*-6436|0;P=C*2260|0;break}}}}}while(0);H=L+1024|0;b[d>>1]=(H+P|0)>>>11;b[A>>1]=(H-P|0)>>>11;H=K+1024|0;b[i>>1]=(H+O|0)>>>11;b[x>>1]=(H-O|0)>>>11;H=J+1024|0;b[l>>1]=(H+N|0)>>>11;b[u>>1]=(H-N|0)>>>11;H=I+1024|0;b[o>>1]=(H+M|0)>>>11;b[r>>1]=(H-M|0)>>>11}}while(0);if((e|0)>0){d=d+16|0;e=e-1|0}else{U=a;V=7;break}}while(1){a=b[U>>1]|0;e=U+16|0;d=b[e>>1]|0;M=d<<16>>16;I=U+32|0;N=b[I>>1]|0;J=N<<16>>16;O=U+48|0;K=b[O>>1]|0;P=K<<16>>16;L=U+64|0;r=b[L>>1]|0;o=U+80|0;u=b[o>>1]|0;l=u<<16>>16;x=U+96|0;i=b[x>>1]|0;A=i<<16>>16;C=U+112|0;t=b[C>>1]|0;w=t<<16>>16;z=N<<16>>16!=0;do{if(i<<16>>16==0){if(z){N=J*4433|0;B=J*10703|0;s=r+a<<13;v=a-r<<13;W=s-B|0;X=v-N|0;Y=v+N|0;Z=s+B|0;break}else{B=r+a<<13;s=a-r<<13;W=B;X=s;Y=s;Z=B;break}}else{if(z){B=(A+J|0)*4433|0;s=B+(A*-15137|0)|0;N=B+(J*6270|0)|0;B=r+a<<13;v=a-r<<13;W=B-N|0;X=v-s|0;Y=s+v|0;Z=N+B|0;break}else{B=A*-10703|0;N=A*4433|0;v=r+a<<13;s=a-r<<13;W=v-N|0;X=s-B|0;Y=B+s|0;Z=N+v|0;break}}}while(0);r=u<<16>>16!=0;a=K<<16>>16!=0;A=d<<16>>16!=0;do{if(t<<16>>16==0){if(!r){if(!a){if(!A){_=0;$=0;aa=0;ba=0;break}_=M*2260|0;$=M*6436|0;aa=M*9633|0;ba=M*11363|0;break}if(A){J=P+M|0;z=J*6436|0;i=J*9633|0;_=(M*8697|0)-z|0;$=z+(P*-17799|0)|0;aa=i+(P*-11893|0)|0;ba=i+(M*1730|0)|0;break}else{_=P*-6436|0;$=P*-11363|0;aa=P*-2260|0;ba=P*9633|0;break}}if(a){i=l+P|0;if(A){z=l+M|0;J=(z+P|0)*9633|0;v=i*-20995|0;N=J+(P*-16069|0)|0;s=J+(z*-3196|0)|0;_=N+(M*-7373|0)|0;$=v+(l*16819|0)+s|0;aa=v+(P*25172|0)+N|0;ba=(M*4926|0)+s|0;break}else{s=i*9633|0;N=i*-11363|0;_=s+(P*-16069|0)|0;$=N+(l*13623|0)|0;aa=N+(P*9102|0)|0;ba=s+(l*-3196|0)|0;break}}else{if(A){s=l+M|0;N=s*9633|0;i=s*6436|0;_=N+(M*-7373|0)|0;$=i+(l*-4176|0)|0;aa=N+(l*-20995|0)|0;ba=i+(M*4926|0)|0;break}else{_=l*9633|0;$=l*2260|0;aa=l*-11363|0;ba=l*6436|0;break}}}else{if(r){if(a){if(A){i=w+P|0;N=l+M|0;s=(i+N|0)*9633|0;v=(w+M|0)*-7373|0;z=(l+P|0)*-20995|0;J=s+(i*-16069|0)|0;i=s+(N*-3196|0)|0;_=v+(w*2446|0)+J|0;$=z+(l*16819|0)+i|0;aa=z+(P*25172|0)+J|0;ba=v+(M*12299|0)+i|0;break}else{i=w+P|0;v=(i+l|0)*9633|0;J=(l+P|0)*-20995|0;z=v+(i*-16069|0)|0;i=v+(l*-3196|0)|0;_=(w*-4927|0)+z|0;$=J+(l*16819|0)+i|0;aa=J+(P*25172|0)+z|0;ba=i+(w*-7373|0)|0;break}}else{if(A){i=l+M|0;z=(w+i|0)*9633|0;J=(w+M|0)*-7373|0;v=z+(w*-16069|0)|0;N=z+(i*-3196|0)|0;_=J+(w*2446|0)+v|0;$=(l*-4176|0)+N|0;aa=v+(l*-20995|0)|0;ba=J+(M*12299|0)+N|0;break}else{N=(w+l|0)*9633|0;J=N+(w*-16069|0)|0;v=N+(l*-3196|0)|0;_=J+(w*-4926|0)|0;$=v+(l*-4176|0)|0;aa=J+(l*-20995|0)|0;ba=v+(w*-7373|0)|0;break}}}else{if(a){if(A){v=w+P|0;J=(v+M|0)*9633|0;N=(w+M|0)*-7373|0;i=J+(v*-16069|0)|0;v=J+(M*-3196|0)|0;_=N+(w*2446|0)+i|0;$=v+(P*-20995|0)|0;aa=(P*4177|0)+i|0;ba=N+(M*12299|0)+v|0;break}else{v=w+P|0;N=v*9633|0;i=v*-6436|0;_=i+(w*-4926|0)|0;$=N+(P*-20995|0)|0;aa=i+(P*4176|0)|0;ba=N+(w*-7373|0)|0;break}}else{if(A){N=w+M|0;i=N*9633|0;v=N*2260|0;_=v+(w*-13623|0)|0;$=i+(M*-3196|0)|0;aa=i+(w*-16069|0)|0;ba=v+(M*9102|0)|0;break}else{_=w*-11363|0;$=w*9633|0;aa=w*-6436|0;ba=w*2260|0;break}}}}}while(0);w=Z+131072|0;b[U>>1]=w+ba>>18;b[C>>1]=w-ba>>18;w=Y+131072|0;b[e>>1]=w+aa>>18;b[x>>1]=w-aa>>18;w=X+131072|0;b[I>>1]=w+$>>18;b[o>>1]=w-$>>18;w=W+131072|0;b[O>>1]=w+_>>18;b[L>>1]=w-_>>18;if((V|0)>0){U=U+2|0;V=V-1|0}else{break}}return}function UJa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=(b[a>>1]|0)+4&65535;b[a>>1]=d;e=a;f=3;g=d;while(1){d=e;h=g<<16>>16;i=e+2|0;j=b[i>>1]|0;k=j<<16>>16;l=e+4|0;m=b[l>>1]|0;n=m<<16>>16;o=e+6|0;p=b[o>>1]|0;q=p<<16>>16;do{if((m|j|p)<<16>>16==0){if(g<<16>>16==0){break}r=g<<2<<16>>16;s=r&65532|r<<16;c[d>>2]=s;c[l>>2]=s}else{s=j<<16>>16!=0;do{if(p<<16>>16==0){if(s){r=k*4433|0;t=k*10703|0;u=n+h<<13;v=h-n<<13;w=u-t|0;x=v-r|0;y=v+r|0;z=u+t|0;break}else{t=n+h<<13;u=h-n<<13;w=t;x=u;y=u;z=t;break}}else{if(s){t=(q+k|0)*4433|0;u=t+(q*-15137|0)|0;r=t+(k*6270|0)|0;t=n+h<<13;v=h-n<<13;w=t-r|0;x=v-u|0;y=u+v|0;z=r+t|0;break}else{t=q*-10703|0;r=q*4433|0;v=n+h<<13;u=h-n<<13;w=v-r|0;x=u-t|0;y=u+t|0;z=v+r|0;break}}}while(0);b[e>>1]=(z+1024|0)>>>11;b[i>>1]=(y+1024|0)>>>11;b[l>>1]=(x+1024|0)>>>11;b[o>>1]=(w+1024|0)>>>11}}while(0);o=e+16|0;if((f|0)<=0){A=a;B=3;break}e=o;f=f-1|0;g=b[o>>1]|0}while(1){g=b[A>>1]|0;f=A+16|0;e=b[f>>1]|0;a=e<<16>>16;w=A+32|0;x=b[w>>1]|0;y=A+48|0;z=b[y>>1]|0;o=z<<16>>16;l=e<<16>>16!=0;do{if(z<<16>>16==0){if(l){e=a*4433|0;i=a*10703|0;n=x+g<<13;h=g-x<<13;C=n-i|0;D=h-e|0;E=h+e|0;F=n+i|0;break}else{i=x+g<<13;n=g-x<<13;C=i;D=n;E=n;F=i;break}}else{if(l){i=(o+a|0)*4433|0;n=i+(o*-15137|0)|0;e=i+(a*6270|0)|0;i=x+g<<13;h=g-x<<13;C=i-e|0;D=h-n|0;E=n+h|0;F=e+i|0;break}else{i=o*-10703|0;e=o*4433|0;h=x+g<<13;n=g-x<<13;C=h-e|0;D=n-i|0;E=n+i|0;F=h+e|0;break}}}while(0);b[A>>1]=F>>18;b[f>>1]=E>>18;b[w>>1]=D>>18;b[y>>1]=C>>18;if((B|0)<=0){break}A=A+2|0;B=B-1|0}return}function VJa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=((b[a>>1]|0)+4&65535)<<16>>16;d=a+2|0;e=b[d>>1]|0;f=c+e|0;g=c-e|0;e=a+16|0;c=b[e>>1]|0;h=a+18|0;i=b[h>>1]|0;j=i+c|0;k=c-i|0;b[a>>1]=(j+f|0)>>>3;b[d>>1]=(k+g|0)>>>3;b[e>>1]=(f-j|0)>>>3;b[h>>1]=(g-k|0)>>>3;return}function WJa(a){a=a|0;b[a>>1]=((b[a>>1]|0)+4|0)>>>3;return}function XJa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=ICb()|0;c[b+1244>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+140>>2]=11;Z3(b,a);e=0;return e|0}function YJa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=c[b+60>>2]|0;n=c[g+24>>2]|0;o=g+28|0;g=c[o>>2]|0;p=n+g|0;if((g|0)<6){q=-1094995529;i=h;return q|0}r=n;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=a[n+4|0]|0;t=r&255;u=n+5|0;v=(s|0)!=0;a:do{if(v){do{if((s|0)>=0){if((s|0)>(g-5|0)){break}w=m+1244|0;x=$$a(b,c[w>>2]|0)|0;if((x|0)<0){q=x;i=h;return q|0}if(!((r&255)>>>0<2>>>0)){if(!(r<<24>>24==2)){yDb(b,24,2109240,(y=i,i=i+8|0,c[y>>2]=t,y)|0);i=y;q=-1094995529;i=h;return q|0}x=n+6|0;z=a[u]|0;A=b+124|0;if((c[A>>2]|0)<=0){B=x;break a}C=b+120|0;D=0;while(1){E=c[w>>2]|0;F=(c[E>>2]|0)+(ba(c[E+32>>2]|0,D)|0)|0;TGb(F|0,z|0,c[C>>2]|0)|0;F=D+1|0;if((F|0)<(c[A>>2]|0)){D=F}else{B=x;break a}}}x=s<<3;D=x>>>0>2147483639>>>0|(u|0)==0;A=D?0:u;C=D?8:x+8|0;x=b+124|0;D=c[x>>2]|0;if((D|0)>0){z=b+120|0;F=l|0;E=m+1240|0;G=l+4|0;H=k|0;I=k+4|0;J=j|0;K=j+4|0;L=0;M=0;N=c[z>>2]|0;O=D;while(1){if((N|0)>0){D=L;P=0;while(1){Q=c[w>>2]|0;R=c[Q>>2]|0;S=c[Q+32>>2]|0;Q=(ba(S,M)|0)+P|0;T=A+(D>>>3)|0;U=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(D&7)>>>30;T=D+2|0;V=C>>>0>T>>>0?T:C;if((U|0)==3){T=S+1|0;W=Q+S|0;X=Q+(S<<1)|0;Y=Q+(S*3|0)|0;Z=0;_=V;while(1){$=ba(Z,S)|0;aa=0;ca=_;while(1){da=aa+$|0;ea=A+(ca>>>3)|0;fa=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ca&7)>>>30;ea=ca+2|0;ga=C>>>0>ea>>>0?ea:C;if((fa|0)==2){ea=A+(ga>>>3)|0;ha=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ga&7)>>>24;ea=ga+8|0;ia=C>>>0>ea>>>0?ea:C;c[H>>2]=ha;ha=A+(ia>>>3)|0;ea=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ia&7)>>>24;ha=ia+8|0;c[I>>2]=ea;ea=da+Q|0;ia=(da|2)+Q|0;ja=(da|3)+Q|0;ka=(da|1)+Q|0;la=2;ma=C>>>0>ha>>>0?ha:C;while(1){ha=ba(la,S)|0;na=((ma|0)<(C|0))+ma|0;a[R+(ea+ha)|0]=c[k+(((d[A+(ma>>>3)|0]|0)<<(ma&7)>>>7&1)<<2)>>2];oa=((na|0)<(C|0))+na|0;a[R+(ea+(ha|1))|0]=c[k+(((d[A+(na>>>3)|0]|0)<<(na&7)>>>7&1)<<2)>>2];na=((oa|0)<(C|0))+oa|0;a[R+(ia+ha)|0]=c[k+(((d[A+(oa>>>3)|0]|0)<<(oa&7)>>>7&1)<<2)>>2];oa=((na|0)<(C|0))+na|0;a[R+(ja+ha)|0]=c[k+(((d[A+(na>>>3)|0]|0)<<(na&7)>>>7&1)<<2)>>2];na=ba(la|1,S)|0;ha=((oa|0)<(C|0))+oa|0;a[R+(ea+na)|0]=c[k+(((d[A+(oa>>>3)|0]|0)<<(oa&7)>>>7&1)<<2)>>2];oa=((ha|0)<(C|0))+ha|0;a[R+(ka+na)|0]=c[k+(((d[A+(ha>>>3)|0]|0)<<(ha&7)>>>7&1)<<2)>>2];ha=((oa|0)<(C|0))+oa|0;a[R+(ia+na)|0]=c[k+(((d[A+(oa>>>3)|0]|0)<<(oa&7)>>>7&1)<<2)>>2];oa=((ha|0)<(C|0))+ha|0;a[R+(ja+na)|0]=c[k+(((d[A+(ha>>>3)|0]|0)<<(ha&7)>>>7&1)<<2)>>2];ha=la-2|0;if((ha|0)>-1){la=ha;ma=oa}else{pa=oa;break}}}else if((fa|0)==3){ma=da+Q|0;la=da+S+Q|0;ja=T+da+Q|0;ia=0;ka=ga;while(1){ea=ba(ia,S)|0;oa=0;ha=ka;while(1){na=oa+ea|0;qa=R+(ma+na)|0;ra=A+(ha>>>3)|0;sa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ha&7)>>>30;ra=ha+2|0;ta=C>>>0>ra>>>0?ra:C;if((sa|0)==1){ra=A+(ta>>>3)|0;ua=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ta&7)>>>24;ra=ta+8|0;c[J>>2]=ua;va=ua&255;TGb(qa|0,va|0,2)|0;TGb(R+(la+na)|0,va|0,2)|0;wa=C>>>0>ra>>>0?ra:C}else if((sa|0)==3){ra=A+(ta>>>3)|0;va=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ta&7)>>>24;ra=ta+8|0;ua=C>>>0>ra>>>0?ra:C;a[qa]=va;va=A+(ua>>>3)|0;ra=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(ua&7)>>>24;va=ua+8|0;ua=C>>>0>va>>>0?va:C;a[R+(ma+(na|1))|0]=ra;ra=A+(ua>>>3)|0;va=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ua&7)>>>24;ra=ua+8|0;ua=C>>>0>ra>>>0?ra:C;a[R+(la+na)|0]=va;va=A+(ua>>>3)|0;ra=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(ua&7)>>>24;va=ua+8|0;a[R+(ja+na)|0]=ra;wa=C>>>0>va>>>0?va:C}else if((sa|0)==2){sa=A+(ta>>>3)|0;va=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ta&7)>>>24;sa=ta+8|0;ra=C>>>0>sa>>>0?sa:C;c[J>>2]=va;va=A+(ra>>>3)|0;sa=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(ra&7)>>>24;va=ra+8|0;ra=C>>>0>va>>>0?va:C;c[K>>2]=sa;sa=((ra|0)<(C|0))+ra|0;a[qa]=c[j+(((d[A+(ra>>>3)|0]|0)<<(ra&7)>>>7&1)<<2)>>2];ra=((sa|0)<(C|0))+sa|0;a[R+(ma+(na|1))|0]=c[j+(((d[A+(sa>>>3)|0]|0)<<(sa&7)>>>7&1)<<2)>>2];sa=((ra|0)<(C|0))+ra|0;a[R+(la+na)|0]=c[j+(((d[A+(ra>>>3)|0]|0)<<(ra&7)>>>7&1)<<2)>>2];a[R+(ja+na)|0]=c[j+(((d[A+(sa>>>3)|0]|0)<<(sa&7)>>>7&1)<<2)>>2];wa=((sa|0)<(C|0))+sa|0}else{wa=ta}ta=oa+2|0;if((ta|0)<4){oa=ta;ha=wa}else{break}}ha=ia+2|0;if((ha|0)<4){ia=ha;ka=wa}else{pa=wa;break}}}else if((fa|0)==1){ka=A+(ga>>>3)|0;ia=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ga&7)>>>24;ka=ga+8|0;c[H>>2]=ia;ja=ia&255;TGb(R+(da+Q)|0,ja|0,4)|0;TGb(R+(W+da)|0,ja|0,4)|0;TGb(R+(X+da)|0,ja|0,4)|0;TGb(R+(Y+da)|0,ja|0,4)|0;pa=C>>>0>ka>>>0?ka:C}else{pa=ga}ka=aa+4|0;if((ka|0)<8){aa=ka;ca=pa}else{break}}ca=Z+4|0;if((ca|0)<8){Z=ca;_=pa}else{xa=pa;break}}}else if((U|0)==2){_=A+(V>>>3)|0;Z=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(V&7)>>>24;_=V+8|0;Y=C>>>0>_>>>0?_:C;c[F>>2]=Z;Z=A+(Y>>>3)|0;_=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(Y&7)>>>24;Z=Y+8|0;c[G>>2]=_;_=7;Y=C>>>0>Z>>>0?Z:C;while(1){Z=(ba(_,S)|0)+Q|0;X=0;W=Y;while(1){ya=((W|0)<(C|0))+W|0;a[R+(Z+X)|0]=c[l+(((d[A+(W>>>3)|0]|0)<<(W&7)>>>7&1)<<2)>>2];T=X+1|0;if((T|0)<8){X=T;W=ya}else{break}}if((_|0)>0){_=_-1|0;Y=ya}else{xa=ya;break}}}else if((U|0)==1){Y=A+(V>>>3)|0;_=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(V&7)>>>24;Y=V+8|0;c[F>>2]=_;cf[c[E>>2]&1023](R+Q|0,_&255,S,8);xa=C>>>0>Y>>>0?Y:C}else{xa=V}Y=P+8|0;za=c[z>>2]|0;if((Y|0)<(za|0)){D=xa;P=Y}else{break}}Aa=xa;Ba=za;Ca=c[x>>2]|0}else{Aa=L;Ba=N;Ca=O}P=M+8|0;if((P|0)<(Ca|0)){L=Aa;M=P;N=Ba;O=Ca}else{break}}}B=n+(s+5)|0;break a}}while(0);yDb(b,16,2186264,(y=i,i=i+8|0,c[y>>2]=s,y)|0);i=y;q=-1094995529;i=h;return q|0}else{B=u}}while(0);if((p-B|0)>767){p=m+1248|0;u=0;y=B;while(1){B=(d[y+1|0]|0)<<8|(d[y]|0)<<16|(d[y+2|0]|0);c[p+(u<<2)>>2]=B<<2|B>>>4&197379|-16777216;B=u+1|0;if((B|0)<256){u=B;y=y+3|0}else{break}}c[m+2272>>2]=1}do{if(v){y=m+1244|0;u=c[y>>2]|0;c[u+84>>2]=1;c[u+88>>2]=1;p=m+2272|0;c[u+304>>2]=c[p>>2];c[p>>2]=0;UGb(c[u+4>>2]|0,m+1248|0,1024)|0;u=MCb(e,c[y>>2]|0)|0;if((u|0)<0){q=u;i=h;return q|0}else{c[f>>2]=1;break}}}while(0);q=c[o>>2]|0;i=h;return q|0}function ZJa(a){a=a|0;JCb((c[a+60>>2]|0)+1244|0);return 0}function _Ja(a){a=a|0;c[a+140>>2]=46;return 0}function $Ja(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+32|0;j=h|0;k=j;l=e;m=c[g+24>>2]|0;n=g+28|0;g=c[n>>2]|0;o=a+60|0;p=c[o>>2]|0;if((g|0)<2){q=-1094995529;i=h;return q|0}r=((d[m]|0)<<3)+8|0;s=((d[m+1|0]|0)<<3)+8|0;t=m+2|0;u=a+120|0;if((r|0)==(c[u>>2]|0)){if((s|0)!=(c[a+124>>2]|0)){v=4}}else{v=4}do{if((v|0)==4){$Db(p);$Db(p+4|0);w=V$a(a,r,s)|0;if((w|0)<0){q=w}else{break}i=h;return q|0}}while(0);w=p;do{if((c[w>>2]|0)==0){x=a+124|0;c[w>>2]=cEb(ba(c[u>>2]<<1,c[x>>2]|0)|0)|0;y=cEb(ba(c[u>>2]<<1,c[x>>2]|0)|0)|0;c[p+4>>2]=y;if(!((c[w>>2]|0)==0|(y|0)==0)){break}y=c[o>>2]|0;$Db(y);$Db(y+4|0);q=-12;i=h;return q|0}}while(0);o=ba(s,r)|0;r=_$a(a,l,0)|0;if((r|0)<0){q=r;i=h;return q|0}r=c[w>>2]|0;l=p+4|0;p=c[l>>2]|0;TGb(k|0,-1|0,32)|0;if((o|0)>0){k=m+(g-2)|0;s=m+(g-3)|0;y=m+(g-1)|0;a:do{if((p|0)==0){g=0;m=t;while(1){if(k>>>0<m>>>0){z=g;break a}x=m;A=(d[x]|d[x+1|0]<<8)<<16>>16;B=A&65535;C=m+2|0;if((B&32768|0)==0){b[r+(g<<1)>>1]=A;D=C;E=g+1|0}else{A=B&24576;if((A|0)==24576){break}x=(B&8191)+1|0;if((A|0)==8192){F=C;G=3}else if((A|0)==0){F=C;G=2}else{if(y>>>0<C>>>0){z=g;break a}F=m+3|0;G=(d[C]|0)+4|0}if((g|0)<(x|0)){z=g;break a}if((o-g|0)<(G|0)){z=g;break a}iEb(r+(g<<1)|0,x<<1,G<<1);D=F;E=G+g|0}if((E|0)<(o|0)){g=E;m=D}else{z=E;break a}}x=(B&1023)+3|0;A=j+((B>>>10&7)<<2)|0;H=c[A>>2]|0;if((H|0)<0){if(s>>>0<C>>>0){z=g;break}I=(d[m+3|0]|0)<<8|(d[m+4|0]|0)<<16|(d[C]|0);c[A>>2]=I;J=I}else{J=H}if((o-((J+g|0)%(o|0)|0)|0)<(x|0)){z=g;break}if((o-g|0)<(x|0)){z=g;break}yDb(a,16,2186232,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;z=g}else{x=0;H=t;while(1){if(k>>>0<H>>>0){z=x;break a}I=H;A=(d[I]|d[I+1|0]<<8)<<16>>16;I=A&65535;L=H+2|0;if((I&32768|0)==0){b[r+(x<<1)>>1]=A;M=L;N=x+1|0}else{A=I&24576;if((A|0)==24576){O=(I&1023)+3|0;P=j+((I>>>10&7)<<2)|0;Q=c[P>>2]|0;if((Q|0)<0){if(s>>>0<L>>>0){z=x;break a}R=(d[H+3|0]|0)<<8|(d[H+4|0]|0)<<16|(d[L]|0);c[P>>2]=R;S=H+5|0;T=R}else{S=L;T=Q}Q=(T+x|0)%(o|0)|0;if((o-Q|0)<(O|0)){z=x;break a}if((o-x|0)<(O|0)){z=x;break a}UGb(r+(x<<1)|0,p+(Q<<1)|0,O<<1)|0;U=S;V=O}else{O=(I&8191)+1|0;if((A|0)==8192){W=L;X=3}else if((A|0)==0){W=L;X=2}else{if(y>>>0<L>>>0){z=x;break a}W=H+3|0;X=(d[L]|0)+4|0}if((x|0)<(O|0)){z=x;break a}if((o-x|0)<(X|0)){z=x;break a}iEb(r+(x<<1)|0,O<<1,X<<1);U=W;V=X}M=U;N=V+x|0}if((N|0)<(o|0)){x=N;H=M}else{z=N;break}}}}while(0);if((z|0)!=(o|0)){Y=z;v=49}}else{Y=0;v=49}if((v|0)==49){yDb(a,48,2109208,(K=i,i=i+8|0,c[K>>2]=Y-o,K)|0);i=K}K=c[u>>2]<<1;iDb(c[e>>2]|0,c[e+32>>2]|0,c[w>>2]|0,K,K,c[a+124>>2]|0);a=c[l>>2]|0;c[l>>2]=c[w>>2];c[w>>2]=a;c[f>>2]=1;q=c[n>>2]|0;i=h;return q|0}function aKa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b);$Db(b+4|0);return 0}function bKa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b);$Db(b+4|0);return}function cKa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;do{if((c[a+120>>2]|0)<=320){if((c[a+124>>2]|0)>200){break}c[e+1036>>2]=e+1044;c[e+1040>>2]=e+65044;f=e+12|0;g=0;do{c[f+(g<<2)>>2]=g*65793|0|-16777216;g=g+1|0;}while((g|0)<256);g=a+100|0;do{if((c[g>>2]|0)<12){yDb(a,24,2351992,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;c[e+8>>2]=127}else{j=(c[a+96>>2]|0)+10|0;k=(d[j]|d[j+1|0]<<8)<<16>>16;j=e+8|0;c[j>>2]=k&65535;if(!((k&65535)>>>0>255>>>0)){break}c[j>>2]=127;yDb(a,16,2331896,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;l=-1094995529;i=b;return l|0}}while(0);if((c[g>>2]|0)==1036){j=0;k=(c[a+96>>2]|0)+12|0;while(1){m=k;c[f+(j<<2)>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=j+1|0;if((m|0)<256){j=m;k=k+4|0}else{break}}c[e+4>>2]=1}c[a+140>>2]=11;l=0;i=b;return l|0}}while(0);yDb(a,16,1894944,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;l=-22;i=b;return l|0}function dKa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0;h=i;j=c[b+60>>2]|0;k=HZ(g,0,0)|0;l=c[g+24>>2]|0;m=g+28|0;g=c[m>>2]|0;if(!((g|0)>-1)){yDb(0,0,1968104,(n=i,i=i+24|0,c[n>>2]=1939664,c[n+8>>2]=1915504,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}o=j+129044|0;c[o>>2]=l;p=j+129052|0;c[p>>2]=l;q=j+129048|0;c[q>>2]=l+g;g=_$a(b,e,0)|0;if((g|0)<0){r=g;i=h;return r|0}g=c[q>>2]|0;l=c[o>>2]|0;s=g;if((s-l|0)<1){t=0;u=l}else{v=l+1|0;c[o>>2]=v;t=d[l]|0;u=v}v=s-u|0;do{if((v|0)<1){w=g;x=u}else{if((a[u]|0)!=127){w=g;x=u;break}s=u+(v>>>0>3>>>0?3:v)|0;c[o>>2]=s;l=t&129;y=j+12|0;z=0;A=g;B=s;do{if((A-B|0)<3){C=-16777216}else{c[o>>2]=B+3;C=d[B]<<16|d[B+1|0]<<8|d[B+2|0]|-16777216}c[y+(z+l<<2)>>2]=C;A=c[q>>2]|0;D=c[o>>2]|0;E=A;s=E-D|0;F=s>>>0>1>>>0?1:s;B=D+F|0;c[o>>2]=B;z=z+1|0;}while((z|0)<127);z=B;l=(c[p>>2]|0)-z|0;y=E-z|0;if((l|0)>-511){G=l}else{G=(y|0)<-511?y:-511}y=D+(F+G)|0;c[o>>2]=y;w=A;x=y}}while(0);G=e+84|0;if((t&128|0)==0){c[G>>2]=0;c[e+88>>2]=2}else{c[G>>2]=1;c[e+88>>2]=1}a:do{if((t&64|0)!=0){c[e+304>>2]=1;G=j+8|0;if((c[G>>2]|0)<1){break}F=j+12|0;D=1;E=w;p=x;while(1){if((E-p|0)<3){H=-16777216}else{c[o>>2]=p+3;H=d[p]<<16|d[p+1|0]<<8|d[p+2|0]|-16777216}c[F+(D<<2)>>2]=H;C=D+1|0;if((C|0)>(c[G>>2]|0)){break a}D=C;E=c[q>>2]|0;p=c[o>>2]|0}}}while(0);if((k|0)!=0){c[e+304>>2]=1;UGb(j+12|0,k|0,1024)|0}k=j+4|0;if((c[k>>2]|0)!=0){c[k>>2]=0;c[e+304>>2]=1}UGb(c[e+4>>2]|0,j+12|0,1024)|0;k=c[o>>2]|0;do{if(((c[q>>2]|0)-k|0)<1){I=0}else{c[o>>2]=k+1;H=d[k]|0;if(!((H|0)==127|(H|0)==8)){I=H;break}H=j+1036|0;TGb(c[H>>2]|0,0,64e3)|0;x=t&15;b:do{if((x|0)==4){w=c[b+120>>2]|0;p=b+124|0;E=c[p>>2]|0;D=c[o>>2]|0;if(((c[q>>2]|0)-D|0)<1){J=0}else{c[o>>2]=D+1;J=d[D]|0}if((E|0)<=0){K=p;break}D=(w|0)>0;G=j+1040|0;F=0;A=7;B=J;c:while(1){if(D){C=0;g=A;v=B;while(1){u=(1<<g&v|0)==0;y=g-1|0;do{if((g|0)==0){l=c[o>>2]|0;if(((c[q>>2]|0)-l|0)<1){L=0;M=7;break}c[o>>2]=l+1;L=d[l]|0;M=7}else{L=v;M=y}}while(0);d:do{if(u){y=(L&1<<M|0)==0;l=M-1|0;do{if((M|0)==0){z=c[o>>2]|0;if(((c[q>>2]|0)-z|0)<1){N=0;O=7;break}c[o>>2]=z+1;N=d[z]|0;O=7}else{N=L;O=l}}while(0);if(!y){l=0;while(1){z=(((l>>3)+F|0)*320|0)+(l&7|C)|0;if((z|0)<0){P=0}else{P=(z|0)>63999?63999:z}a[(c[H>>2]|0)+P|0]=a[(c[G>>2]|0)+P|0]|0;z=l+1|0;if((z|0)<64){l=z}else{Q=N;R=O;break d}}}l=c[o>>2]|0;y=c[q>>2]|0;if((y|0)==(l|0)){S=145;break c}if((y-l|0)<1){T=0}else{c[o>>2]=l+1;T=a[l]|0}l=0;while(1){y=(((l>>3)+F|0)*320|0)+(l&7|C)|0;if((y|0)<0){U=0}else{U=(y|0)>63999?63999:y}a[(c[H>>2]|0)+U|0]=T;y=l+1|0;if((y|0)<64){l=y}else{Q=N;R=O;break}}}else{if((c[q>>2]|0)==(c[o>>2]|0)){S=156;break c}else{V=0;W=M;X=L}while(1){l=V<<2&4|C;y=V<<1&4|F;z=(1<<W&X|0)==0;s=W-1|0;do{if((W|0)==0){Y=c[o>>2]|0;if(((c[q>>2]|0)-Y|0)<1){Z=0;_=7;break}c[o>>2]=Y+1;Z=d[Y]|0;_=7}else{Z=X;_=s}}while(0);e:do{if(z){s=(Z&1<<_|0)==0;do{if((_|0)==0){Y=c[q>>2]|0;$=c[o>>2]|0;if((Y-$|0)<1){aa=0;ba=7;ca=Y;da=$;break}ea=$+1|0;c[o>>2]=ea;aa=d[$]|0;ba=7;ca=Y;da=ea}else{aa=Z;ba=_-1|0;ca=c[q>>2]|0;da=c[o>>2]|0}}while(0);if((ca-da|0)<1){fa=0}else{c[o>>2]=da+1;fa=d[da]|0}if(s){ea=fa&255;Y=0;while(1){$=(((Y>>2)+y|0)*320|0)+(Y&3|l)|0;if(($|0)<0){ga=0}else{ga=($|0)>63999?63999:$}a[(c[H>>2]|0)+ga|0]=ea;$=Y+1|0;if(($|0)<16){Y=$}else{ha=aa;ia=ba;break e}}}Y=(fa&15)-8|0;ea=(fa>>>4)-8|0;if((Y+l+((ea+y|0)*320|0)|0)>>>0>63036>>>0){S=173;break c}else{ja=0}while(1){s=ja&3|l;$=(ja>>2)+y|0;ka=s+Y+(($+ea|0)*320|0)|0;if((ka|0)<0){la=0}else{la=(ka|0)>63999?63999:ka}ka=($*320|0)+s|0;if((ka|0)<0){ma=0}else{ma=(ka|0)>63999?63999:ka}a[(c[H>>2]|0)+ma|0]=a[(c[G>>2]|0)+la|0]|0;ka=ja+1|0;if((ka|0)<16){ja=ka}else{ha=aa;ia=ba;break}}}else{ea=0;Y=_;ka=Z;while(1){s=ea<<1&2|l;$=ea&2|y;na=(1<<Y&ka|0)==0;oa=Y-1|0;do{if((Y|0)==0){pa=c[o>>2]|0;if(((c[q>>2]|0)-pa|0)<1){qa=0;ra=7;break}c[o>>2]=pa+1;qa=d[pa]|0;ra=7}else{qa=ka;ra=oa}}while(0);do{if(na){oa=(qa&1<<ra|0)==0;do{if((ra|0)==0){pa=c[q>>2]|0;sa=c[o>>2]|0;if((pa-sa|0)<1){ta=0;ua=7;va=pa;wa=sa;break}xa=sa+1|0;c[o>>2]=xa;ta=d[sa]|0;ua=7;va=pa;wa=xa}else{ta=qa;ua=ra-1|0;va=c[q>>2]|0;wa=c[o>>2]|0}}while(0);if((va-wa|0)<1){ya=0}else{c[o>>2]=wa+1;ya=d[wa]|0}if(oa){xa=ya&255;pa=$*320|0;sa=s+pa|0;if((sa|0)<0){za=0}else{za=(sa|0)>63999?63999:sa}a[(c[H>>2]|0)+za|0]=xa;sa=s|1;Aa=sa+pa|0;if((Aa|0)<0){Ba=0}else{Ba=(Aa|0)>63999?63999:Aa}a[(c[H>>2]|0)+Ba|0]=xa;Aa=($|1)*320|0;pa=Aa+s|0;if((pa|0)<0){Ca=0}else{Ca=(pa|0)>63999?63999:pa}a[(c[H>>2]|0)+Ca|0]=xa;pa=sa+Aa|0;if((pa|0)<0){Da=0}else{Da=(pa|0)>63999?63999:pa}a[(c[H>>2]|0)+Da|0]=xa;Ea=ta;Fa=ua;break}xa=(ya&15)-8|0;pa=(ya>>>4)-8|0;Aa=xa+s|0;sa=(pa+$|0)*320|0;Ga=sa+Aa|0;if(Ga>>>0>63678>>>0){S=200;break c}Ha=$*320|0;Ia=s+Ha|0;if((Ia|0)<0){Ja=0}else{Ja=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Ja|0]=a[(c[G>>2]|0)+Ga|0]|0;Ga=s|1;Ia=xa+Ga|0;xa=sa+Ia|0;if((xa|0)<0){Ka=0}else{Ka=(xa|0)>63999?63999:xa}xa=Ga+Ha|0;if((xa|0)<0){La=0}else{La=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+La|0]=a[(c[G>>2]|0)+Ka|0]|0;xa=$|1;Ha=(pa+xa|0)*320|0;pa=Ha+Aa|0;if((pa|0)<0){Ma=0}else{Ma=(pa|0)>63999?63999:pa}pa=xa*320|0;xa=pa+s|0;if((xa|0)<0){Na=0}else{Na=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+Na|0]=a[(c[G>>2]|0)+Ma|0]|0;xa=Ha+Ia|0;if((xa|0)<0){Oa=0}else{Oa=(xa|0)>63999?63999:xa}xa=Ga+pa|0;if((xa|0)<0){Pa=0}else{Pa=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+Pa|0]=a[(c[G>>2]|0)+Oa|0]|0;Ea=ta;Fa=ua}else{xa=c[o>>2]|0;if(((c[q>>2]|0)-xa|0)<1){Qa=0}else{c[o>>2]=xa+1;Qa=a[xa]|0}xa=$*320|0;pa=s+xa|0;if((pa|0)<0){Ra=0}else{Ra=(pa|0)>63999?63999:pa}a[(c[H>>2]|0)+Ra|0]=Qa;pa=c[o>>2]|0;if(((c[q>>2]|0)-pa|0)<1){Sa=0}else{c[o>>2]=pa+1;Sa=a[pa]|0}pa=s|1;Ga=pa+xa|0;if((Ga|0)<0){Ta=0}else{Ta=(Ga|0)>63999?63999:Ga}a[(c[H>>2]|0)+Ta|0]=Sa;Ga=c[o>>2]|0;if(((c[q>>2]|0)-Ga|0)<1){Ua=0}else{c[o>>2]=Ga+1;Ua=a[Ga]|0}Ga=($|1)*320|0;xa=Ga+s|0;if((xa|0)<0){Va=0}else{Va=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+Va|0]=Ua;xa=c[o>>2]|0;if(((c[q>>2]|0)-xa|0)<1){Wa=0}else{c[o>>2]=xa+1;Wa=a[xa]|0}xa=pa+Ga|0;if((xa|0)<0){Xa=0}else{Xa=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+Xa|0]=Wa;Ea=qa;Fa=ra}}while(0);s=ea+1|0;if((s|0)<4){ea=s;Y=Fa;ka=Ea}else{ha=Ea;ia=Fa;break}}}}while(0);y=V+1|0;if((y|0)<4){V=y;W=ia;X=ha}else{Q=ha;R=ia;break}}}}while(0);u=C+8|0;if((u|0)<(w|0)){C=u;g=R;v=Q}else{Ya=R;Za=Q;break}}}else{Ya=A;Za=B}v=F+8|0;if((v|0)<(E|0)){F=v;A=Ya;B=Za}else{K=p;break b}}if((S|0)==145){yDb(c[j>>2]|0,16,2051200,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=p;break}else if((S|0)==156){yDb(c[j>>2]|0,16,2051200,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=p;break}else if((S|0)==173){yDb(c[j>>2]|0,16,2005784,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=p;break}else if((S|0)==200){yDb(c[j>>2]|0,16,2005784,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=p;break}}else if((x|0)==0|(x|0)==1){UGb(c[H>>2]|0,c[j+1040>>2]|0,64e3)|0;K=b+124|0}else if((x|0)==3){B=c[b+120>>2]|0;A=b+124|0;F=c[A>>2]|0;E=c[o>>2]|0;if(((c[q>>2]|0)-E|0)<1){_a=0}else{c[o>>2]=E+1;_a=d[E]|0}if((F|0)<=0){K=A;break}E=(B|0)>0;w=0;G=7;D=_a;f:while(1){if(E){v=0;g=G;C=D;while(1){u=c[o>>2]|0;y=c[q>>2]|0;if((y|0)==(u|0)){S=40;break f}l=(1<<g&C|0)==0;z=g-1|0;do{if((g|0)==0){if((y-u|0)<1){$a=0;ab=7;bb=u;break}ka=u+1|0;c[o>>2]=ka;$a=d[u]|0;ab=7;bb=ka}else{$a=C;ab=z;bb=u}}while(0);if(l){if((y-bb|0)<1){cb=0}else{c[o>>2]=bb+1;cb=a[bb]|0}u=0;while(1){z=(((u>>3)+w|0)*320|0)+(u&7|v)|0;if((z|0)<0){db=0}else{db=(z|0)>63999?63999:z}a[(c[H>>2]|0)+db|0]=cb;z=u+1|0;if((z|0)<64){u=z}else{eb=$a;fb=ab;break}}}else{u=0;y=ab;l=$a;while(1){z=u<<2&4|v;ka=u<<1&4|w;Y=(1<<y&l|0)==0;ea=y-1|0;do{if((y|0)==0){s=c[o>>2]|0;if(((c[q>>2]|0)-s|0)<1){gb=0;hb=7;break}c[o>>2]=s+1;gb=d[s]|0;hb=7}else{gb=l;hb=ea}}while(0);g:do{if(Y){ea=(gb&1<<hb|0)==0;do{if((hb|0)==0){s=c[q>>2]|0;$=c[o>>2]|0;if((s-$|0)<1){ib=0;jb=7;kb=s;lb=$;break}na=$+1|0;c[o>>2]=na;ib=d[$]|0;jb=7;kb=s;lb=na}else{ib=gb;jb=hb-1|0;kb=c[q>>2]|0;lb=c[o>>2]|0}}while(0);if((kb-lb|0)<1){mb=0}else{c[o>>2]=lb+1;mb=d[lb]|0}if(ea){na=mb&255;s=0;while(1){$=(((s>>2)+ka|0)*320|0)+(s&3|z)|0;if(($|0)<0){nb=0}else{nb=($|0)>63999?63999:$}a[(c[H>>2]|0)+nb|0]=na;$=s+1|0;if(($|0)<16){s=$}else{ob=ib;pb=jb;break g}}}s=mb&15;na=mb>>>4;if((z-s+((ka-na|0)*320|0)|0)>>>0>63036>>>0){S=67;break f}else{qb=0}while(1){ea=qb&3|z;$=(qb>>2)+ka|0;xa=(($-na|0)*320|0)+(ea-s)|0;if((xa|0)<0){rb=0}else{rb=(xa|0)>63999?63999:xa}xa=c[H>>2]|0;Ga=($*320|0)+ea|0;if((Ga|0)<0){sb=0}else{sb=(Ga|0)>63999?63999:Ga}a[xa+sb|0]=a[xa+rb|0]|0;xa=qb+1|0;if((xa|0)<16){qb=xa}else{ob=ib;pb=jb;break}}}else{s=0;na=hb;xa=gb;while(1){Ga=s<<1&2|z;ea=s&2|ka;$=(1<<na&xa|0)==0;pa=na-1|0;do{if((na|0)==0){Ia=c[o>>2]|0;if(((c[q>>2]|0)-Ia|0)<1){tb=0;ub=7;break}c[o>>2]=Ia+1;tb=d[Ia]|0;ub=7}else{tb=xa;ub=pa}}while(0);do{if($){pa=(tb&1<<ub|0)==0;do{if((ub|0)==0){Ia=c[q>>2]|0;Ha=c[o>>2]|0;if((Ia-Ha|0)<1){vb=0;wb=7;xb=Ia;yb=Ha;break}Aa=Ha+1|0;c[o>>2]=Aa;vb=d[Ha]|0;wb=7;xb=Ia;yb=Aa}else{vb=tb;wb=ub-1|0;xb=c[q>>2]|0;yb=c[o>>2]|0}}while(0);if((xb-yb|0)<1){zb=0}else{c[o>>2]=yb+1;zb=d[yb]|0}if(pa){Aa=zb&255;Ia=ea*320|0;Ha=Ga+Ia|0;if((Ha|0)<0){Ab=0}else{Ab=(Ha|0)>63999?63999:Ha}a[(c[H>>2]|0)+Ab|0]=Aa;Ha=Ga|1;sa=Ha+Ia|0;if((sa|0)<0){Bb=0}else{Bb=(sa|0)>63999?63999:sa}a[(c[H>>2]|0)+Bb|0]=Aa;sa=(ea|1)*320|0;Ia=sa+Ga|0;if((Ia|0)<0){Cb=0}else{Cb=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Cb|0]=Aa;Ia=Ha+sa|0;if((Ia|0)<0){Db=0}else{Db=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Db|0]=Aa;Eb=vb;Fb=wb;break}Aa=zb&15;Ia=zb>>>4;sa=Ga-Aa|0;Ha=(ea-Ia|0)*320|0;Gb=Ha+sa|0;if(Gb>>>0>63678>>>0){S=94;break f}Hb=c[H>>2]|0;Ib=ea*320|0;Jb=Ga+Ib|0;if((Jb|0)<0){Kb=0}else{Kb=(Jb|0)>63999?63999:Jb}a[Hb+Kb|0]=a[Hb+Gb|0]|0;Gb=Ga|1;Hb=Gb-Aa|0;Aa=Ha+Hb|0;if((Aa|0)<0){Lb=0}else{Lb=(Aa|0)>63999?63999:Aa}Aa=c[H>>2]|0;Ha=Gb+Ib|0;if((Ha|0)<0){Mb=0}else{Mb=(Ha|0)>63999?63999:Ha}a[Aa+Mb|0]=a[Aa+Lb|0]|0;Aa=ea|1;Ha=(Aa-Ia|0)*320|0;Ia=Ha+sa|0;if((Ia|0)<0){Nb=0}else{Nb=(Ia|0)>63999?63999:Ia}Ia=c[H>>2]|0;sa=Aa*320|0;Aa=sa+Ga|0;if((Aa|0)<0){Ob=0}else{Ob=(Aa|0)>63999?63999:Aa}a[Ia+Ob|0]=a[Ia+Nb|0]|0;Ia=Ha+Hb|0;if((Ia|0)<0){Pb=0}else{Pb=(Ia|0)>63999?63999:Ia}Ia=c[H>>2]|0;Hb=Gb+sa|0;if((Hb|0)<0){Qb=0}else{Qb=(Hb|0)>63999?63999:Hb}a[Ia+Qb|0]=a[Ia+Pb|0]|0;Eb=vb;Fb=wb}else{Ia=c[o>>2]|0;if(((c[q>>2]|0)-Ia|0)<1){Rb=0}else{c[o>>2]=Ia+1;Rb=a[Ia]|0}Ia=ea*320|0;Hb=Ga+Ia|0;if((Hb|0)<0){Sb=0}else{Sb=(Hb|0)>63999?63999:Hb}a[(c[H>>2]|0)+Sb|0]=Rb;Hb=c[o>>2]|0;if(((c[q>>2]|0)-Hb|0)<1){Tb=0}else{c[o>>2]=Hb+1;Tb=a[Hb]|0}Hb=Ga|1;sa=Hb+Ia|0;if((sa|0)<0){Ub=0}else{Ub=(sa|0)>63999?63999:sa}a[(c[H>>2]|0)+Ub|0]=Tb;sa=c[o>>2]|0;if(((c[q>>2]|0)-sa|0)<1){Vb=0}else{c[o>>2]=sa+1;Vb=a[sa]|0}sa=(ea|1)*320|0;Ia=sa+Ga|0;if((Ia|0)<0){Wb=0}else{Wb=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Wb|0]=Vb;Ia=c[o>>2]|0;if(((c[q>>2]|0)-Ia|0)<1){Xb=0}else{c[o>>2]=Ia+1;Xb=a[Ia]|0}Ia=Hb+sa|0;if((Ia|0)<0){Yb=0}else{Yb=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Yb|0]=Xb;Eb=tb;Fb=ub}}while(0);Ga=s+1|0;if((Ga|0)<4){s=Ga;na=Fb;xa=Eb}else{ob=Eb;pb=Fb;break}}}}while(0);ka=u+1|0;if((ka|0)<4){u=ka;y=pb;l=ob}else{eb=ob;fb=pb;break}}}l=v+8|0;if((l|0)<(B|0)){v=l;g=fb;C=eb}else{Zb=fb;_b=eb;break}}}else{Zb=G;_b=D}C=w+8|0;if((C|0)<(F|0)){w=C;G=Zb;D=_b}else{K=A;break b}}if((S|0)==40){yDb(c[j>>2]|0,16,2051200,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=A;break}else if((S|0)==67){yDb(c[j>>2]|0,16,2005784,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=A;break}else if((S|0)==94){yDb(c[j>>2]|0,16,2005784,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=A;break}}else{yDb(b,16,2109176,(n=i,i=i+8|0,c[n>>2]=x,n)|0);i=n;r=-1094995529;i=h;return r|0}}while(0);h:do{if((c[K>>2]|0)>0){x=b+120|0;D=e+32|0;G=1;w=c[H>>2]|0;F=c[e>>2]|0;while(1){UGb(F|0,w|0,c[x>>2]|0)|0;if((G|0)>=(c[K>>2]|0)){break h}G=G+1|0;w=w+320|0;F=F+(c[D>>2]|0)|0}}}while(0);D=c[H>>2]|0;F=j+1044|0;if((D|0)==(F|0)){c[H>>2]=j+65044;c[j+1040>>2]=D}else{c[H>>2]=F;c[j+1040>>2]=j+65044}c[f>>2]=1;r=c[m>>2]|0;i=h;return r|0}}while(0);yDb(b,16,2186208,(n=i,i=i+8|0,c[n>>2]=I,n)|0);i=n;r=-1094995529;i=h;return r|0}function eKa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;Z3(b+4|0,a);return 0}function fKa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;h=i;i=i+48|0;j=h|0;k=h+16|0;l=h+32|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;o=g;c[j>>2]=e;c[j+4>>2]=0;c[j+8>>2]=0;c[e+84>>2]=1;p=a[m]|0;q=m+1|0;r=q;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=m+5|0;t=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=p&255;a:do{switch(r|0){case 5:{u=3;break};case 8:{c[b+140>>2]=30;v=m+9|0;c[k+12>>2]=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24;w=4;y=13;u=32;break};case 4:case 2:{w=3;y=9;u=32;break};case 3:{c[b+140>>2]=4;v=W0a(b,j,0)|0;if((v|0)<0){z=v;i=h;return z|0}if(n>>>0>9>>>0&s>>>0<n>>>0&t>>>0<n>>>0){v=b+120|0;A=b+124|0;hKa(o,c[e>>2]|0,c[v>>2]|0,c[A>>2]|0,c[e+32>>2]|0,m+9|0,n-9|0);hKa(o,c[e+4>>2]|0,(c[v>>2]|0)/2|0,c[A>>2]|0,c[e+36>>2]|0,m+s|0,n-s|0);hKa(o,c[e+8>>2]|0,(c[v>>2]|0)/2|0,c[A>>2]|0,c[e+40>>2]|0,m+t|0,n-t|0);break a}yDb(b,16,2109152,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;z=-1094995529;i=h;return z|0};case 10:{c[b+140>>2]=0;A=W0a(b,j,0)|0;if((A|0)<0){z=A;i=h;return z|0}if(n>>>0>9>>>0&n>>>0>s>>>0&n>>>0>t>>>0){A=b+120|0;v=b+124|0;hKa(o,c[e>>2]|0,c[A>>2]|0,c[v>>2]|0,c[e+32>>2]|0,m+9|0,n-9|0);hKa(o,c[e+8>>2]|0,(c[A>>2]|0)/2|0,(c[v>>2]|0)/2|0,c[e+40>>2]|0,m+s|0,n-s|0);hKa(o,c[e+4>>2]|0,(c[A>>2]|0)/2|0,(c[v>>2]|0)/2|0,c[e+36>>2]|0,m+t|0,n-t|0);break a}else{z=-1094995529;i=h;return z|0}break};case 9:{c[b+140>>2]=30;u=3;break};case 6:{v=b+792|0;A=b+140|0;if((c[v>>2]|0)==24){c[A>>2]=2;C=s}else{c[A>>2]=30;C=s|-16777216}A=W0a(b,j,0)|0;if((A|0)<0){z=A;i=h;return z|0}A=b+124|0;D=c[A>>2]|0;if((D|0)<=0){break a}E=b+120|0;F=e+32|0;G=C&255;H=C>>>8&255;I=C>>>16&255;J=c[e>>2]|0;K=0;L=c[E>>2]|0;M=D;while(1){if((L|0)>0){D=0;do{if((c[v>>2]|0)==24){N=D*3|0;a[J+(N+2)|0]=G;a[J+(N+1)|0]=H;a[J+N|0]=I}else{N=J+(D<<2)|0;x=C;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x}D=D+1|0;O=c[E>>2]|0;}while((D|0)<(O|0));P=O;Q=c[A>>2]|0}else{P=L;Q=M}D=K+1|0;if((D|0)<(Q|0)){J=J+(c[F>>2]|0)|0;K=D;L=P;M=Q}else{break}}break};default:{yDb(b,16,2051152,(B=i,i=i+8|0,c[B>>2]=r,B)|0);i=B;z=-1163346256;i=h;return z|0}}}while(0);b:do{if((u|0)==3){do{if(p<<24>>24==5){r=b+140|0;if((c[b+792>>2]|0)==24){c[r>>2]=2;R=3;break}else{c[r>>2]=298;R=4;break}}else{R=3}}while(0);r=W0a(b,j,0)|0;if((r|0)<0){z=r;i=h;return z|0}r=c[e>>2]|0;Q=b+124|0;P=c[Q>>2]|0;O=(P|0)>0;if(!(p<<24>>24==9)){if(!O){break}C=b+120|0;M=e+32|0;L=r;K=0;while(1){TGb(L|0,a[q]|0,ba(c[C>>2]|0,R)|0)|0;F=K+1|0;if((F|0)<(c[Q>>2]|0)){L=L+(c[M>>2]|0)|0;K=F}else{break b}}}if(!O){break}K=b+120|0;M=e+32|0;L=r;C=0;F=c[K>>2]|0;J=P;while(1){if((F|0)>0){A=0;do{E=L+(A<<2)|0;x=s;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;A=A+1|0;S=c[K>>2]|0;}while((A|0)<(S|0));T=S;U=c[Q>>2]|0}else{T=F;U=J}A=C+1|0;if((A|0)<(U|0)){L=L+(c[M>>2]|0)|0;C=A;F=T;J=U}else{break}}}else if((u|0)==32){if((p<<24>>24|0)==4|(p<<24>>24|0)==2){c[b+140>>2]=2}J=W0a(b,j,0)|0;if((J|0)<0){z=J;i=h;return z|0}c[k>>2]=t;c[k+4>>2]=s;c[k+8>>2]=y;J=b+120|0;F=(c[J>>2]|0)+15&-16;C=g+1264|0;c[C>>2]=F;M=g+1256|0;L=M;Q=b+124|0;kEb(M,g+1260|0,ba(ba(c[Q>>2]|0,w)|0,F)|0|1);F=c[L>>2]|0;if((F|0)==0){yDb(b,16,2186168,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;z=-12;i=h;return z|0}M=c[C>>2]|0;K=c[Q>>2]|0;P=0;while(1){r=P+1|0;c[l+(P<<2)>>2]=F+((ba(ba(M,r)|0,K)|0)-M);if((r|0)<(w|0)){P=r}else{V=0;break}}while(1){if((V|0)>=(w|0)){W=0;X=K;Y=M;Z=t;break}if(n>>>0>(c[k+(V<<2)>>2]|0)>>>0){V=V+1|0}else{u=41;break}}if((u|0)==41){yDb(b,16,2109152,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;z=-1094995529;i=h;return z|0}while(1){hKa(o,c[l+(W<<2)>>2]|0,c[J>>2]|0,X,-Y|0,m+Z|0,n-Z|0);M=W+1|0;if((M|0)>=(w|0)){break}W=M;X=c[Q>>2]|0;Y=c[C>>2]|0;Z=c[k+(M<<2)>>2]|0}M=c[e>>2]|0;K=c[L>>2]|0;P=c[C>>2]|0;F=c[Q>>2]|0;r=0;do{c[l+(r<<2)>>2]=K+(ba(ba(P,r)|0,F)|0);r=r+1|0;}while((r|0)<(w|0));if((F|0)<=0){break}r=l|0;K=l+4|0;L=l+8|0;O=p<<24>>24==8;A=l+12|0;E=e+32|0;I=M;H=0;G=c[J>>2]|0;v=P;while(1){if((G|0)>0){if(O){D=0;while(1){N=a[(c[K>>2]|0)+D|0]|0;_=I+(D<<2)|0;x=(N+(a[(c[r>>2]|0)+D|0]|0)&255)<<16|(N&255)<<8|(a[(c[L>>2]|0)+D|0]|0)+N&255|(d[(c[A>>2]|0)+D|0]|0)<<24;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;_=c[J>>2]|0;N=D+1|0;if((N|0)<(_|0)){D=N}else{$=_;break}}}else{D=0;while(1){_=a[(c[K>>2]|0)+D|0]|0;N=(a[(c[L>>2]|0)+D|0]|0)+_&255;aa=D*3|0;a[I+aa|0]=_+(a[(c[r>>2]|0)+D|0]|0);a[I+(aa+1)|0]=_;a[I+(aa+2)|0]=N;N=c[J>>2]|0;aa=D+1|0;if((aa|0)<(N|0)){D=aa}else{$=N;break}}}ca=$;da=c[C>>2]|0}else{ca=G;da=v}D=c[E>>2]|0;N=0;do{aa=l+(N<<2)|0;c[aa>>2]=(c[aa>>2]|0)+da;N=N+1|0;}while((N|0)<(w|0));N=H+1|0;if((N|0)<(c[Q>>2]|0)){I=I+D|0;H=N;G=ca;v=da}else{break}}}}while(0);c[f>>2]=1;z=n;i=h;return z|0}function gKa(a){a=a|0;$Db((c[a+60>>2]|0)+1256|0);return 0}function hKa(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;l=i;m=-h|0;n=i;i=i+4|0;i=i+7&-8;o=i;i=i+4|0;i=i+7&-8;p=i;i=i+4|0;i=i+7&-8;q=i;i=i+20|0;i=i+7&-8;r=i;i=i+1320|0;s=j+k|0;t=b|0;u=c[t>>2]|0;v=r|0;c[v>>2]=u;w=b+1248|0;c[w>>2]=0;if((k|0)<2){i=l;return}x=a[j]|0;y=x&255;a:do{if((x&255)>>>0<4>>>0){z=ba(g,f)|0;if((k|0)<5){i=l;return}A=x<<24>>24==0;if(A){B=1;C=z}else{D=j+1|0;E=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=E>>>0<z>>>0;B=D?5:1;C=D?E:z}z=j+B|0;E=k-B|0;D=E>>>0>268435455>>>0?-8:E<<3;E=D>>>0>2147483639>>>0|(z|0)==0;G=E?0:z;z=E?0:D;c[q>>2]=G;c[q+12>>2]=z;c[q+16>>2]=z+8;c[q+4>>2]=G+(z>>3);c[q+8>>2]=0;if(E){i=l;return}E=r+32|0;c[E>>2]=0;c[r+1060>>2]=-1;z=1;G=0;b:while(1){D=r+32+(z<<2)|0;if((jKa(q,D)|0)<0){H=9;break}I=c[D>>2]|0;D=YGb(I,0,G,0)|0;J=F;K=0;if(J>>>0>K>>>0|J>>>0==K>>>0&D>>>0>-1>>>0){H=11;break}L=I+G|0;do{if((I|0)==0){if((jKa(q,n)|0)!=0){H=14;break b}D=c[n>>2]|0;K=256-z|0;if(D>>>0>K>>>0){c[n>>2]=K;M=K}else{M=D}if((M|0)==0){N=z;break}D=M>>>0>1>>>0?M:1;TGb(r+32+(z+1<<2)|0,0,D<<2|0)|0;N=D+z|0}else{N=z}}while(0);I=N+1|0;if((I|0)<257){z=I;G=L}else{H=20;break}}if((H|0)==9){yDb(c[v>>2]|0,16,1894904,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else if((H|0)==11){yDb(c[v>>2]|0,16,2351920,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else if((H|0)==14){yDb(c[v>>2]|0,16,2331856,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else if((H|0)==20){if((L|0)==0){yDb(c[v>>2]|0,16,2307472,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}G=L>>>0>65535>>>0;z=G?L>>>16:L;I=G?16:0;if((z&65280|0)==0){P=I;Q=z}else{P=I|8;Q=z>>>8}z=(d[1191992+Q|0]|0)+P|0;I=L-1|0;do{if((I&L|0)==0){R=z}else{G=I>>>0>65535>>>0;D=G?I>>>16:I;K=G?16:0;if((D&65280|0)==0){S=K;T=D}else{S=K|8;T=D>>>8}D=S+1+(d[1191992+T|0]|0)|0;K=L;G=0;J=hHb(0,1048576,K,G)|0;U=F;V=gHb(J,U,K,G)|0;W=ZGb(0,1048576,V,F)|0;V=F;X=D;D=_Gb(J|0,U|0,X|0)|0;U=F;J=_Gb(W|0,V|0,X|0)|0;X=YGb(J,F,L>>>1,0)|0;J=hHb(X,F,K,G)|0;G=YGb(D,U,J,F)|0;J=F;U=G|0;G=J&0;D=J;J=0;K=1;X=0;do{V=r+32+(K<<2)|0;W=c[V>>2]|0;Y=0;Z=gHb(W,Y,U,G)|0;_=F;$=gHb(W,Y,D,J)|0;Y=YGb(_,0,$,F)|0;$=F;W=Y>>>21|$<<11;aa=W>>>0>65535>>>0;ca=aa?($>>>5|0<<27)&65535:W;W=aa?16:0;if((ca&65280|0)==0){da=W;ea=ca}else{da=W|8;ea=ca>>>8}ca=1<<(d[1191992+ea|0]|0)+da;YGb(ca,(ca|0)<0|0?-1:0,Z|0,_&0)|0;_=YGb(F,0,Y,$)|0;$=_>>>20|F<<12;c[V>>2]=$;X=$+X|0;K=K+1|0;}while((K|0)<129);if((X|0)==0){yDb(c[v>>2]|0,16,2289136,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else{fa=129;ga=X}do{K=r+32+(fa<<2)|0;$=c[K>>2]|0;V=0;_=gHb($,V,U,G)|0;Y=F;Z=gHb($,V,D,J)|0;V=YGb(Y,0,Z,F)|0;Z=F;$=V>>>21|Z<<11;ca=$>>>0>65535>>>0;W=ca?(Z>>>5|0<<27)&65535:$;$=ca?16:0;if((W&65280|0)==0){ha=$;ia=W}else{ha=$|8;ia=W>>>8}W=1<<(d[1191992+ia|0]|0)+ha;YGb(W,(W|0)<0|0?-1:0,_|0,Y&0)|0;Y=YGb(F,0,V,Z)|0;Z=Y>>>20|F<<12;c[K>>2]=Z;ga=Z+ga|0;fa=fa+1|0;}while((fa|0)<257);J=z+1|0;D=1<<J;if(ga>>>0>D>>>0){yDb(c[v>>2]|0,16,2273e3,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}if((D|0)==(ga|0)){R=J;break}G=1;U=D-ga|0;while(1){D=r+32+(G<<2)|0;X=c[D>>2]|0;if((X|0)==0){ja=U}else{c[D>>2]=X+1;ja=U-1|0}if((ja|0)==0){R=J;break}else{G=(G&127)+1|0;U=ja}}}}while(0);c[r+12>>2]=R;z=1;I=c[E>>2]|0;do{U=r+32+(z<<2)|0;I=(c[U>>2]|0)+I|0;c[U>>2]=I;z=z+1|0;}while((z|0)<257);kKa(r,q,C-h|0);if((g|0)<=0){break}z=A?-1:y;I=b+1252|0;E=0;U=0;do{G=ba(E,h)|0;J=0;X=0;D=c[I>>2]|0;c:while(1){if((D|0)==0){ka=J}else{Z=f-J|0;K=(D|0)>(Z|0)?Z:D;TGb(e+(J+G)|0,0,K|0)|0;c[I>>2]=(c[I>>2]|0)-K;ka=K+J|0}if((ka|0)<(f|0)){la=X;ma=ka}else{na=X;break}while(1){K=iKa(r)|0;a[e+(ma+G)|0]=K;Z=la+1|0;if(K<<24>>24==0){K=(c[w>>2]|0)+1|0;c[w>>2]=K;oa=ma+1|0;if((K|0)==(z|0)){break}else{pa=oa}}else{c[w>>2]=0;pa=ma+1|0}if((pa|0)<(f|0)){la=Z;ma=pa}else{na=Z;break c}}Z=iKa(r)|0;c[w>>2]=0;K=Z<<24>>24;Z=(K<<1^K>>>7)&255;c[I>>2]=Z;J=oa;X=la+2|0;D=Z}U=na+U|0;E=E+1|0;}while((E|0)<(g|0));if(!(U>>>0>C>>>0)){break}yDb(c[t>>2]|0,24,2005736,(O=i,i=i+16|0,c[O>>2]=U,c[O+8>>2]=C,O)|0);i=O;break}}else{if(!((x&255)>>>0<8>>>0)){if(!(x<<24>>24==-1)){yDb(u,16,1968064,(O=i,i=i+8|0,c[O>>2]=y,O)|0);i=O;i=l;return}if((g|0)<=0){i=l;return}E=j+1|0;I=0;do{z=e+(ba(I,h)|0)|0;TGb(z|0,a[E]|0,f|0)|0;I=I+1|0;}while((I|0)<(g|0));i=l;return}I=y-4|0;E=j+1|0;if((I|0)<=0){if((k-1|0)<(ba(g,f)|0)){i=l;return}if((g|0)>0){qa=0;ra=E}else{break}while(1){UGb(e+(ba(qa,h)|0)|0,ra|0,f)|0;U=qa+1|0;if((U|0)<(g|0)){qa=U;ra=ra+f|0}else{break a}}}if((g|0)<=0){break}U=-((I|0)<2|0)&255;z=-((I|0)<3|0)&255;A=f-2|0;D=b+1252|0;X=s;J=0;G=E;Z=u;d:while(1){K=ba(J,h)|0;Y=e+K|0;V=e+(A+K)|0;DDb(Z,1939648,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;TGb(Y|0,0,f|0)|0;K=V;_=Y;Y=G;W=0;$=c[D>>2]|0;e:while(1){if(($|0)==0){sa=_}else{ca=f-W|0;aa=($|0)>(ca|0)?ca:$;if((K-_|0)<(aa|0)){H=66;break d}TGb(_|0,0,aa|0)|0;c[D>>2]=(c[D>>2]|0)-aa;sa=_+aa|0}if(!(sa>>>0<V>>>0)){ta=Y;break}aa=X-Y|0;ua=0;while(1){if(!((sa+ua|0)>>>0<V>>>0)){H=74;break e}va=ua+1|0;ca=ua+3|0;if((ca|0)>=(aa|0)){H=124;break d}if((a[Y+(ua+2)|0]&U|a[Y+va|0]|a[Y+ca|0]&z)<<24>>24==0){break}else{ua=va}}aa=va+I|0;UGb(sa|0,Y|0,aa)|0;ca=a[Y+aa|0]|0;wa=(ca<<1^ca>>>7)&255;c[D>>2]=wa;_=sa+aa|0;Y=Y+(aa+1)|0;W=aa;$=wa}if((H|0)==74){H=0;UGb(sa|0,Y|0,ua)|0;ta=Y+ua|0}$=ta-G|0;if(($|0)<0){H=124;break}W=J+1|0;if((W|0)>=(g|0)){break a}J=W;G=G+$|0;Z=c[t>>2]|0}if((H|0)==66){yDb(c[t>>2]|0,16,1915472,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else if((H|0)==124){i=l;return}}}while(0);H=c[t>>2]|0;O=(g|0)>0;if((c[H+140>>2]|0)==4){if(!O){i=l;return}ta=f-1|0;ua=ta-(h<<1)|0;sa=ta-h|0;ta=b+1088|0;va=b+1092|0;u=~h;s=0;ra=e;qa=H;while(1){H=(c[qa+120>>2]|0)==(f|0);do{if((s|0)==1){k=H?4:2;j=d[ra+sa|0]|0;c[o>>2]=j;y=d[ra+(k+u)|0]|0;c[p>>2]=y;x=0;C=j;do{j=ra+x|0;C=(d[j]|0)+C|0;a[j]=C;x=x+1|0;}while((x|0)<(k|0));c[o>>2]=C;if((k|0)<(f|0)){xa=k;ya=C;za=y}else{break}while(1){x=ya&255;Aa=d[ra+(xa-h)|0]|0;Y=ya-za+Aa&255;do{if(x>>>0>Aa>>>0){if(!(Y>>>0>Aa>>>0)){Ba=Aa;break}Ba=Y>>>0>x>>>0?x:Y}else{if(!(Aa>>>0>Y>>>0)){Ba=Aa;break}Ba=Y>>>0>x>>>0?Y:x}}while(0);x=ra+xa|0;Ca=(d[x]|0)+Ba|0;a[x]=Ca;x=xa+1|0;if((x|0)<(f|0)){xa=x;ya=Ca;za=Aa}else{break}}c[o>>2]=Ca;c[p>>2]=Aa}else if((s|0)==0){c[o>>2]=d[ra]|0;if(H){a[ra]=0;_e[c[va>>2]&1023](ra,ra,f,0)|0;a[ra]=c[o>>2];break}else{_e[c[va>>2]&1023](ra,ra,f,0)|0;break}}else{c[p>>2]=d[ra+ua|0]|0;c[o>>2]=d[ra+sa|0]|0;Se[c[ta>>2]&511](ra,ra+m|0,ra,f,o,p)}}while(0);H=s+1|0;if((H|0)>=(g|0)){break}s=H;ra=ra+h|0;qa=c[t>>2]|0}i=l;return}else{if(!O){i=l;return}O=b+1092|0;b=f-1|0;qa=b-h|0;ra=b-(h<<1)|0;if((f|0)>0){Da=0;Ea=e}else{b=0;s=e;while(1){if((b|0)==0){_e[c[O>>2]&1023](s,s,f,0)|0}e=b+1|0;if((e|0)<(g|0)){b=e;s=s+h|0}else{break}}i=l;return}while(1){if((Da|0)==0){_e[c[O>>2]&1023](Ea,Ea,f,0)|0}else{s=a[Ea+qa|0]|0;b=s&255;do{if((Da|0)==1){if((c[(c[t>>2]|0)+140>>2]|0)!=0){Fa=0;Ga=s;Ha=s;Ia=b;break}Fa=0;Ga=s;Ha=a[Ea+m|0]|0;Ia=b}else{Fa=0;Ga=s;Ha=a[Ea+ra|0]|0;Ia=b}}while(0);while(1){b=a[Ea+(Fa-h)|0]|0;s=b&255;e=s+(Ia-(Ha&255))|0;do{if((Ga&255)>>>0>(b&255)>>>0){if((e|0)<=(s|0)){Ja=s;break}Ja=(e|0)>(Ia|0)?Ia:e}else{if((s|0)<=(e|0)){Ja=s;break}Ja=(e|0)>(Ia|0)?e:Ia}}while(0);e=Ea+Fa|0;s=(d[e]|0)+Ja|0;p=s&255;a[e]=p;e=Fa+1|0;if((e|0)<(f|0)){Fa=e;Ga=p;Ha=b;Ia=s&255}else{break}}}s=Da+1|0;if((s|0)<(g|0)){Da=s;Ea=Ea+h|0}else{break}}i=l;return}}function iKa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=a+8|0;e=c[b>>2]|0;f=a+4|0;if(e>>>0<8388609>>>0){g=a+24|0;h=c[a+28>>2]|0;i=c[f>>2]|0;j=e;k=c[g>>2]|0;while(1){l=i<<8;c[f>>2]=l;m=j<<8;c[b>>2]=m;n=k;o=((de((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)>>>1&255|l;c[f>>2]=o;if(k>>>0<h>>>0){l=k+1|0;c[g>>2]=l;p=l}else{p=k}if(m>>>0<8388609>>>0){i=o;j=m;k=p}else{q=m;r=o;break}}}else{q=e;r=c[f>>2]|0}f=q>>>((c[a+12>>2]|0)>>>0);e=a+4|0;p=ba(c[a+1052>>2]|0,f)|0;if(!(r>>>0<p>>>0)){s=255;t=q-p|0;u=(t|0)==0;v=u?128:t;c[b>>2]=v;w=a+32+(s<<2)|0;x=c[w>>2]|0;y=ba(x,f)|0;z=r-y|0;c[e>>2]=z;A=s&255;return A|0}p=c[a+36>>2]|0;if(r>>>0<(ba(p,f)|0)>>>0){B=0;C=p}else{p=f>>>0>65535>>>0;q=p?f>>>16:f;k=p?16:0;if((q&65280|0)==0){D=k;E=q}else{D=k|8;E=q>>>8}q=30-D-(d[1191992+E|0]|0)|0;E=ZGb(r,0,r>>>24,0)|0;gHb(c[1199552+(((f<<(q&255))+8388607|0)>>>23<<2)>>2]|0,0,E,F)|0;E=F;D=q-(c[a+16>>2]|0)&31;q=d[((E<<D|E>>>((32-D|0)>>>0))&255)+(a+1064)|0]|0;while(1){D=q+1|0;E=c[a+32+(D<<2)>>2]|0;if(r>>>0<(ba(E,f)|0)>>>0){B=q;C=E;break}else{q=D}}}s=B;t=ba(C-(c[a+32+(B<<2)>>2]|0)|0,f)|0;u=(t|0)==0;v=u?128:t;c[b>>2]=v;w=a+32+(s<<2)|0;x=c[w>>2]|0;y=ba(x,f)|0;z=r-y|0;c[e>>2]=z;A=s&255;return A|0}function jKa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=a+8|0;f=a|0;g=a+16|0;a=0;h=0;i=0;j=0;while(1){k=(h|0)==0;if(!((j|0)==0|k)){l=i;break}m=c[e>>2]|0;n=(d[(c[f>>2]|0)+(m>>>3)|0]|0)<<(m&7)>>>7;c[e>>2]=((m|0)<(c[g>>2]|0))+m;m=n&1;if((m|0)!=0&k){o=(d[862280+a|0]|0)+i|0}else{o=i}k=a+1|0;if((k|0)<7){a=k;j=h;h=m;i=o}else{l=o;break}}o=l-1|0;if(o>>>0>31>>>0){c[b>>2]=0;p=-1;return p|0}if((o|0)==0){c[b>>2]=0;p=0;return p|0}i=c[e>>2]|0;h=c[g>>2]|0;g=c[f>>2]|0;f=g+(i>>>3)|0;j=(fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(i&7);if((o|0)<26){f=i+o|0;c[e>>2]=h>>>0>f>>>0?f:h;q=j>>>((33-l|0)>>>0)}else{f=i+16|0;i=h>>>0>f>>>0?f:h;c[e>>2]=i;f=l-17|0;a=g+(i>>>3)|0;g=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>((49-l|0)>>>0);l=i+f|0;c[e>>2]=h>>>0>l>>>0?l:h;q=g|j>>>16<<f}c[b>>2]=(q|1<<o)-1;p=0;return p|0}function kKa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;f=e+8|0;g=c[f>>2]|0;h=-g&7;if((h|0)==0){i=g}else{j=c[e+16>>2]|0;k=h+g|0;g=j>>>0>k>>>0?k:j;c[f>>2]=g;i=g}g=(c[e+12>>2]|0)-i>>3;f=c[e>>2]|0;e=(i|0)/8|0;i=f+e|0;c[b+24>>2]=i;c[b+20>>2]=i;c[b+28>>2]=f+(e+g);c[b+8>>2]=128;c[b+4>>2]=(d[i]|0)>>>1;i=(c[b+12>>2]|0)-8|0;g=(i|0)>0?i:0;i=b+16|0;c[i>>2]=g;e=0;f=0;j=g;while(1){g=f<<j;k=e;while(1){h=k+1|0;if((c[b+32+(h<<2)>>2]|0)>>>0>g>>>0){break}else{k=h}}a[b+1064+f|0]=k;g=f+1|0;l=c[i>>2]|0;if((g|0)<256){e=k;f=g;j=l}else{break}}c[i>>2]=l+23;return}function lKa(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+16|0;j=b|0;k=b+8|0;c[j>>2]=g;c[k>>2]=h;do{if((c[a+176>>2]&1|0)==0){l=c[a>>2]|0;m=l;n=l+20|0;o=c[n>>2]|0;p=l+16|0;q=c[p>>2]|0;do{if((o|0)==0){r=q;s=0;while(1){if((s|0)>=(h|0)){t=6;break}u=r<<8;v=d[g+s|0]|0|u;if((u&16769024|0)==5693440){t=5;break}else{r=v;s=s+1|0}}if((t|0)==5){c[l+40>>2]=~s;w=1;x=v;t=7;break}else if((t|0)==6){y=0;z=r;A=c[l+40>>2]|0;t=10;break}}else{w=o;x=q;t=7}}while(0);do{if((t|0)==7){if((h|0)==0){B=0;break}q=c[l+40>>2]|0;o=(x&8191)-q|0;if(o>>>0>h>>>0){y=w;z=x;A=q;t=10;break}c[n>>2]=0;c[p>>2]=-1;B=o}}while(0);if((t|0)==10){c[l+40>>2]=A+h;c[n>>2]=y;c[p>>2]=z;B=-100}if((WRa(m,B,j,k)|0)>=0){C=B;D=c[j>>2]|0;E=c[k>>2]|0;break}c[e>>2]=0;c[f>>2]=0;F=c[k>>2]|0;i=b;return F|0}else{C=h;D=g;E=h}}while(0);c[e>>2]=D;c[f>>2]=E;F=C;i=b;return F|0}function mKa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=c[b+60>>2]|0;j=b+120|0;k=c[j>>2]|0;l=b+124|0;m=c[l>>2]|0;n=ba(m,k)|0;o=ba(m+3&-4,k+3&-4)|0;if((c[b+100>>2]|0)<8){yDb(b,16,2257456,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}k=b+48|0;m=c[k>>2]|0;if((m|0)==55){if((a[(c[b+96>>2]|0)+7|0]|0)!=3){r=6}}else if((m|0)==54){if((a[(c[b+96>>2]|0)+7|0]|0)!=1){r=6}}if((r|0)==6){yDb(b,16,2243176,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}r=b+96|0;m=d[(c[r>>2]|0)+4|0]|0;c[h>>2]=m;a:do{switch(m|0){case 1:{c[h+12>>2]=n<<1;c[b+140>>2]=4;s=b;yDb(s,48,2218648,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;if((c[j>>2]&3|0)==0){t=o<<1;break a}DDb(s,2209288,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0};case 0:{c[h+12>>2]=n*3|0;c[b+140>>2]=5;yDb(b,48,2230712,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=o*3|0;break};case 2:{c[h+12>>2]=n*3|0;c[b+140>>2]=3;yDb(b,48,2200688,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=o*3|0;break};case 5:{c[h+12>>2]=(n>>>1)*3|0;c[b+140>>2]=0;yDb(b,48,2165408,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=(o>>>1)*3|0;break};case 3:{c[h+12>>2]=(n>>>1)*3|0;c[b+140>>2]=7;yDb(b,48,2192160,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=(o>>>1)*3|0;break};case 4:{c[h+12>>2]=n<<1;c[b+140>>2]=4;yDb(b,48,2175832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=o<<1;break};default:{yDb(b,16,2158760,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;q=-1094995529;i=e;return q|0}}}while(0);eFb(c[b+140>>2]|0,f,g)|0;do{if(((c[j>>2]|0)%(1<<c[f>>2]|0)|0|0)==0){if(((c[l>>2]|0)%(1<<c[g>>2]|0)|0|0)!=0){break}m=a[(c[r>>2]|0)+5|0]|0;o=m<<24>>24;c[h+4>>2]=o;n=c[k>>2]|0;do{if((n|0)==55){if((o|0)==(-1|0)){yDb(b,48,2120536,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else if((o|0)==1){yDb(b,48,2132736,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else if((o|0)==9){yDb(b,48,2126352,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else{s=b;if(!((m&255)>>>0>9>>>0)){yDb(s,48,2100216,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;break}yDb(s,16,2114360,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=-1094995529;i=e;return q|0}}else if((n|0)==54){if((o|0)==0){yDb(b,48,2151648,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else if((o|0)==1){c[h+12>>2]=0;yDb(b,48,2144624,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else{yDb(b,16,2138992,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=-1094995529;i=e;return q|0}}else{yDb(b,16,2093576,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}}while(0);do{if((c[h+12>>2]|0)!=0){o=WDb(t)|0;c[h+16>>2]=o;if((o|0)!=0){break}yDb(b,16,2088392,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-12;i=e;return q|0}}while(0);o=d[(c[r>>2]|0)+6|0]|0;n=h+8|0;c[n>>2]=o;if((o&1|0)==0){u=o}else{yDb(b,48,2083624,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=c[n>>2]|0}if((u&2|0)!=0){yDb(b,48,2077984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}do{if((c[k>>2]|0)==55){if((c[n>>2]&4|0)==0){break}yDb(b,48,2073192,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);o=c[n>>2]|0;if((o&248|0)!=0){yDb(b,16,2068696,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p}if((c[k>>2]|0)!=55){q=0;i=e;return q|0}c[h+52>>2]=0;c[h+56>>2]=0;c[h+60>>2]=0;o=Qd(h+20|0,2064224,56)|0;if((o|0)==0){q=0;i=e;return q|0}yDb(b,16,2060288,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;$Db(h+16|0);q=-1313558101;i=e;return q|0}}while(0);DDb(b,2209288,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}function nKa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=c[b+120>>2]|0;m=c[b+124>>2]|0;n=_$a(b,e,0)|0;if((n|0)<0){o=n;i=h;return o|0}n=e;p=c[n>>2]|0;q=b+48|0;r=c[q>>2]|0;a:do{if((r|0)==54){s=c[g+4>>2]|0;if((s|0)==0){if((c[g>>2]|0)==2){if((k|0)==(ba(l*3|0,m)|0)){t=j;break}}if((c[g+8>>2]&1|0)==0){u=g+16|0;v=g+12|0;w=pKa(j,k,c[u>>2]|0,c[v>>2]|0)|0;y=c[v>>2]|0;if((y|0)==(w|0)){t=c[u>>2]|0;break}yDb(b,16,1939600,(z=i,i=i+16|0,c[z>>2]=y,c[z+8>>2]=w,z)|0);i=z;o=-1094995529;i=h;return o|0}w=j;y=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;if(k>>>0<8>>>0){yDb(b,16,2051128,(z=i,i=i+8|0,c[z>>2]=k,z)|0);i=z;o=-1094995529;i=h;return o|0}w=k-8|0;u=y>>>0>w>>>0?w:y;y=j+4|0;v=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=g+12|0;A=c[y>>2]|0;B=v>>>0>A>>>0?A:v;v=g+16|0;C=pKa(j+8|0,u,c[v>>2]|0,A)|0;if((B|0)!=(C|0)){yDb(b,16,2005640,(z=i,i=i+16|0,c[z>>2]=B,c[z+8>>2]=C,z)|0);i=z;o=-1094995529;i=h;return o|0}C=pKa(j+(u+8)|0,w-u|0,(c[v>>2]|0)+B|0,(c[y>>2]|0)-B|0)|0;if((B|0)==(C|0)){t=c[v>>2]|0;break}yDb(b,16,1968008,(z=i,i=i+16|0,c[z>>2]=B,c[z+8>>2]=C,z)|0);i=z;o=-1094995529;i=h;return o|0}else if((s|0)==1){switch(c[g>>2]|0){case 1:case 4:{D=4;break};case 3:case 5:{D=3;break};case 0:case 2:{D=6;break};default:{D=0}}if(k>>>0<(ba(ba(m,l)|0,D)|0)>>>1>>>0){o=-1094995529}else{t=j;break}i=h;return o|0}else{yDb(b,16,1915416,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=h;return o|0}}else if((r|0)==55){do{if((c[g+4>>2]|0)==-1){if((c[g>>2]|0)!=2){E=28;break}if((k|0)!=(ba(l*3|0,m)|0)){E=28;break}if((c[g+8>>2]&4|0)==0){t=j;break a}UGb(c[g+16>>2]|0,j|0,k)|0}else{E=28}}while(0);do{if((E|0)==28){if((c[g+8>>2]&1|0)==0){s=qKa(b,j,k,0,c[g+12>>2]|0)|0;if((s|0)<0){o=s}else{break}i=h;return o|0}s=j;C=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k-8|0;B=C>>>0>s>>>0?s:C;C=j+4|0;v=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;C=c[g+12>>2]|0;y=v>>>0>C>>>0?C:v;v=qKa(b,j+8|0,B,0,y)|0;if((v|0)<0){o=v;i=h;return o|0}v=qKa(b,j+(B+8)|0,s-B|0,y,y)|0;if((v|0)<0){o=v}else{break}i=h;return o|0}}while(0);t=c[g+16>>2]|0}else{yDb(b,16,1894840,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=h;return o|0}}while(0);b:do{if((c[q>>2]|0)==55){if((c[g+8>>2]&4|0)==0){break}switch(c[g>>2]|0){case 0:case 2:{if((m|0)==0){break b}j=l*3|0;E=l>>>0>1>>>0;r=0;do{D=ba(j,r)|0;if(E){v=t+(D+1)|0;y=1;B=a[t+D|0]|0;s=(d[v]|d[v+1|0]<<8)<<16>>16&65535;v=D;while(1){D=v+3|0;C=t+D|0;u=B-(a[C]|0)&255;a[C]=u;C=t+(v+4)|0;w=s-((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0;x=w&65535;a[C]=x;x=x>>8;a[C+1|0]=x;C=y+1|0;if(C>>>0<l>>>0){y=C;B=u;s=w;v=D}else{break}}}r=r+1|0;}while(r>>>0<m>>>0);break};case 5:{r=m>>>1;if((r|0)==0){break b}E=l*3|0;j=l>>>1;v=(j|0)==0;s=0;do{if(!v){B=0;y=ba(E,s)|0;D=0;w=0;u=0;C=0;while(1){A=t+y|0;F=D-(a[A]|0)&255;a[A]=F;A=t+(y+1)|0;G=F-(a[A]|0)&255;a[A]=G;A=t+(y+2)|0;F=w-(a[A]|0)&255;a[A]=F;A=t+(y+3)|0;H=F-(a[A]|0)&255;a[A]=H;A=t+(y+4)|0;F=u-(a[A]|0)&255;a[A]=F;A=t+(y+5)|0;I=C-(a[A]|0)&255;a[A]=I;A=B+1|0;if(A>>>0<j>>>0){B=A;y=y+6|0;D=G;w=H;u=F;C=I}else{break}}}s=s+1|0;}while(s>>>0<r>>>0);break};case 4:{if((m|0)==0){break b}r=l<<1;s=l>>>1;j=(s|0)==0;E=0;do{if(!j){v=0;C=ba(r,E)|0;u=0;w=0;D=0;while(1){y=t+C|0;B=u-(a[y]|0)&255;a[y]=B;y=t+(C|1)|0;I=B-(a[y]|0)&255;a[y]=I;y=t+(C+2)|0;B=w-(a[y]|0)&255;a[y]=B;y=t+(C+3)|0;F=D-(a[y]|0)&255;a[y]=F;y=v+1|0;if(y>>>0<s>>>0){v=y;C=C+4|0;u=I;w=B;D=F}else{break}}}E=E+1|0;}while(E>>>0<m>>>0);break};case 3:{if((m|0)==0){break b}E=l>>>2;s=(E|0)==0;r=0;do{if(!s){j=0;D=((ba(r,l)|0)>>>1)*3|0;w=0;u=0;C=0;while(1){v=t+D|0;F=w-(a[v]|0)&255;a[v]=F;v=t+(D+1)|0;B=F-(a[v]|0)&255;a[v]=B;v=t+(D+2)|0;F=B-(a[v]|0)&255;a[v]=F;v=t+(D+3)|0;B=F-(a[v]|0)&255;a[v]=B;v=t+(D+4)|0;F=u-(a[v]|0)&255;a[v]=F;v=t+(D+5)|0;I=C-(a[v]|0)&255;a[v]=I;v=j+1|0;if(v>>>0<E>>>0){j=v;D=D+6|0;w=B;u=F;C=I}else{break}}}r=r+1|0;}while(r>>>0<m>>>0);break};case 1:{if((m|0)==0){break b}r=l<<1;E=l>>>2;s=(E|0)==0;C=0;do{if(!s){u=0;w=ba(r,C)|0;D=0;j=0;I=0;while(1){F=t+w|0;B=D-(a[F]|0)&255;a[F]=B;F=t+(w|1)|0;v=B-(a[F]|0)&255;a[F]=v;F=t+(w+2)|0;B=v-(a[F]|0)&255;a[F]=B;F=t+(w+3)|0;v=B-(a[F]|0)&255;a[F]=v;F=t+(w+4)|0;B=j-(a[F]|0)&255;a[F]=B;F=t+(w+5)|0;y=B-(a[F]|0)&255;a[F]=y;F=t+(w+6)|0;B=I-(a[F]|0)&255;a[F]=B;F=t+(w+7)|0;H=B-(a[F]|0)&255;a[F]=H;F=u+1|0;if(F>>>0<E>>>0){u=F;w=w+8|0;D=v;j=y;I=H}else{break}}}C=C+1|0;}while(C>>>0<m>>>0);break};default:{yDb(b,16,2351872,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=h;return o|0}}}}while(0);q=m-1|0;C=e+32|0;E=c[C>>2]|0;r=(c[n>>2]|0)+(ba(E,q)|0)|0;n=c[e+4>>2]|0;s=e+36|0;I=c[s>>2]|0;j=n+(ba(I,q)|0)|0;D=c[e+8>>2]|0;w=e+40|0;e=c[w>>2]|0;u=D+(ba(e,q)|0)|0;c:do{switch(c[g>>2]|0){case 5:{H=(m>>>1)-1|0;if((q|0)==0){break c}y=l-1|0;v=(y|0)==0;F=0;B=r;G=n+(ba(I,H)|0)|0;A=D+(ba(e,H)|0)|0;H=t;J=E;K=I;L=e;while(1){if(v){M=H;N=J;O=K;P=L}else{Q=0;R=H;while(1){S=R;T=B+Q|0;x=(d[S]|d[S+1|0]<<8)<<16>>16;a[T]=x;x=x>>8;a[T+1|0]=x;T=R+2|0;S=B+(Q-(c[C>>2]|0))|0;x=(d[T]|d[T+1|0]<<8)<<16>>16;a[S]=x;x=x>>8;a[S+1|0]=x;S=Q>>1;a[G+S|0]=a[R+4|0]^-128;U=R+6|0;a[A+S|0]=a[R+5|0]^-128;S=Q+2|0;if(S>>>0<y>>>0){Q=S;R=U}else{break}}M=U;N=c[C>>2]|0;O=c[s>>2]|0;P=c[w>>2]|0}R=F+2|0;if(R>>>0<q>>>0){F=R;B=B+(-(N<<1)|0)|0;G=G+(-O|0)|0;A=A+(-P|0)|0;H=M;J=N;K=O;L=P}else{break}}break};case 0:{if((m|0)==0|(l|0)==0){break c}L=l*3|0;K=0;J=r;H=j;A=u;G=t;while(1){B=0;F=G;while(1){a[J+B|0]=a[F]|0;a[H+B|0]=a[F+1|0]^-128;a[A+B|0]=a[F+2|0]^-128;y=B+1|0;if(y>>>0<l>>>0){B=y;F=F+3|0}else{break}}F=K+1|0;if(F>>>0<m>>>0){K=F;J=J+(-(c[C>>2]|0)|0)|0;H=H+(-(c[s>>2]|0)|0)|0;A=A+(-(c[w>>2]|0)|0)|0;G=G+L|0}else{break}}break};case 2:{if(!((q|0)>-1)){break c}L=l*3|0;G=q;A=t;H=E;while(1){UGb(p+(ba(H,G)|0)|0,A|0,L)|0;if((G|0)<=0){break c}G=G-1|0;A=A+L|0;H=c[C>>2]|0}break};case 3:{if((m|0)==0){break c}H=l-3|0;if((H|0)==0){break c}else{V=0;W=r;X=j;Y=u;Z=t}while(1){L=0;A=Z;while(1){G=A;J=W+L|0;x=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;J=L>>2;a[X+J|0]=a[A+4|0]^-128;_=A+6|0;a[Y+J|0]=a[A+5|0]^-128;J=L+4|0;if(J>>>0<H>>>0){L=J;A=_}else{break}}A=V+1|0;if(A>>>0<m>>>0){V=A;W=W+(-(c[C>>2]|0)|0)|0;X=X+(-(c[s>>2]|0)|0)|0;Y=Y+(-(c[w>>2]|0)|0)|0;Z=_}else{break}}break};case 4:{if((m|0)==0){break c}H=l-1|0;A=(H|0)==0;L=0;J=r;G=j;K=u;F=t;B=E;y=I;v=e;while(1){if(A){$=F;aa=B;ca=y;da=v}else{R=0;Q=F;while(1){S=Q;T=J+R|0;x=(d[S]|d[S+1|0]<<8)<<16>>16;a[T]=x;x=x>>8;a[T+1|0]=x;T=R>>1;a[G+T|0]=a[Q+2|0]^-128;ea=Q+4|0;a[K+T|0]=a[Q+3|0]^-128;T=R+2|0;if(T>>>0<H>>>0){R=T;Q=ea}else{break}}$=ea;aa=c[C>>2]|0;ca=c[s>>2]|0;da=c[w>>2]|0}Q=L+1|0;if(Q>>>0<m>>>0){L=Q;J=J+(-aa|0)|0;G=G+(-ca|0)|0;K=K+(-da|0)|0;F=$;B=aa;y=ca;v=da}else{break}}break};case 1:{if((m|0)==0){break c}v=l-3|0;if((v|0)==0){break c}else{fa=0;ga=r;ha=j;ia=u;ja=t}while(1){y=0;B=ja;while(1){F=B;K=ga+y|0;x=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;K=y>>1;a[ha+K|0]=a[B+4|0]^-128;F=K|1;a[ha+F|0]=a[B+5|0]^-128;a[ia+K|0]=a[B+6|0]^-128;ka=B+8|0;a[ia+F|0]=a[B+7|0]^-128;F=y+4|0;if(F>>>0<v>>>0){y=F;B=ka}else{break}}B=fa+1|0;if(B>>>0<m>>>0){fa=B;ga=ga+(-(c[C>>2]|0)|0)|0;ha=ha+(-(c[s>>2]|0)|0)|0;ia=ia+(-(c[w>>2]|0)|0)|0;ja=ka}else{break}}break};default:{yDb(b,16,2331808,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=h;return o|0}}}while(0);c[f>>2]=1;o=k;i=h;return o|0}function oKa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+16|0);if((c[a+48>>2]|0)!=55){return 0}he(b+20|0)|0;return 0}function pKa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=e+f|0;f=b+c|0;c=e;h=g;i=f;j=d[b]|0;k=e;e=b+1|0;a:while(1){b=128;l=k;m=e;while(1){if(!(m>>>0<f>>>0&l>>>0<g>>>0)){break a}if((b&j|0)==0){n=m;o=l;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;p=l+4|0;q=m+4|0}else{o=m;n=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=n&2047;r=l;s=r-c|0;t=o>>>0>s>>>0?s:o;o=(n>>>11<<2)+4|0;n=h-r|0;r=o>>>0>n>>>0?n:o;if((t|0)==0){TGb(l|0,0,r|0)|0}else{iEb(l,t,r)}p=l+r|0;q=m+2|0}r=b>>>1;if((r|0)==0){break}else{b=r;l=p;m=q}}m=q+1|0;b=a[q]|0;r=b&255;if(b<<24>>24==0){u=m;v=p;w=r}else{j=r;k=p;e=m;continue}while(1){if((h-v|0)<32){j=w;k=v;e=u;continue a}if((i-u|0)<32){j=w;k=v;e=u;continue a}UGb(v|0,u|0,32)|0;m=v+32|0;r=u+33|0;b=a[u+32|0]|0;t=b&255;if(b<<24>>24==0){u=r;v=m;w=t}else{j=t;k=m;e=r;continue a}}}return l-c|0}function qKa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=c[a+60>>2]|0;j=h+20|0;k=j;l=bc(k|0)|0;if((l|0)!=0){yDb(a,16,2307440,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1313558101;i=g;return n|0}c[j>>2]=b;c[h+24>>2]=d;c[h+32>>2]=(c[h+16>>2]|0)+e;c[h+36>>2]=(c[h+12>>2]|0)-e;e=$c(k|0,4)|0;if(e>>>0>1>>>0){yDb(a,16,2289112,(m=i,i=i+8|0,c[m>>2]=e,m)|0);i=m;n=-1313558101;i=g;return n|0}e=c[h+40>>2]|0;if((e|0)==(f|0)){n=f;i=g;return n|0}yDb(a,16,2272960,(m=i,i=i+16|0,c[m>>2]=f,c[m+8>>2]=e,m)|0);i=m;n=-1313558101;i=g;return n|0}function rKa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=c[b+60>>2]|0;f=e;c[f>>2]=b;if((c[b+120>>2]|0)==0){yDb(0,0,2005608,(g=i,i=i+24|0,c[g>>2]=1967976,c[g+8>>2]=1939576,c[g+16>>2]=132,g)|0);i=g;Cd();return 0}if((c[b+124>>2]|0)==0){yDb(0,0,2005608,(g=i,i=i+24|0,c[g>>2]=1967976,c[g+8>>2]=1939576,c[g+16>>2]=132,g)|0);i=g;Cd();return 0}h=cEb(24)|0;j=b+96|0;c[j>>2]=h;if((h|0)==0){k=-12;i=d;return k|0}h=ICb()|0;c[b+804>>2]=h;if((h|0)==0){k=-12;i=d;return k|0}c[h+88>>2]=1;c[h+84>>2]=1;h=c[b+84>>2]|0;do{if((h|0)==-1){l=-1}else{if((h|0)<0){l=0;break}l=(h|0)>9?9:h}}while(0);h=e+8|0;c[h>>2]=l;l=e+12|0;c[l>>2]=0;m=e+4|0;c[m>>2]=2;c[b+792>>2]=24;a[c[j>>2]|0]=4;a[(c[j>>2]|0)+1|0]=0;a[(c[j>>2]|0)+2|0]=0;a[(c[j>>2]|0)+3|0]=0;a[(c[j>>2]|0)+4|0]=c[m>>2];a[(c[j>>2]|0)+5|0]=c[h>>2];a[(c[j>>2]|0)+6|0]=c[l>>2];a[(c[j>>2]|0)+7|0]=3;c[(c[f>>2]|0)+100>>2]=8;c[e+48>>2]=0;c[e+52>>2]=0;c[e+56>>2]=0;f=Sb(e+16|0,c[h>>2]|0,1915400,56)|0;if((f|0)==0){k=0;i=d;return k|0}yDb(b,16,1894776,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;k=1;i=d;return k|0}function sKa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=c[a+60>>2]|0;h=g+16|0;j=h;k=a+120|0;l=a+124|0;m=ob(j|0,ba((c[k>>2]|0)*3|0,c[l>>2]|0)|0)|0;n=r0a(a,b,m,(m|0)<0|0?-1:0)|0;if((n|0)<0){o=n;i=f;return o|0}if((c[a+140>>2]|0)!=3){yDb(a,16,2186128,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1;i=f;return o|0}n=bd(j|0)|0;if((n|0)!=0){yDb(a,16,2109072,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;o=-1;i=f;return o|0}c[g+28>>2]=c[b+24>>2];n=b+28|0;c[g+32>>2]=c[n>>2];m=d|0;q=d+32|0;d=h;h=g+20|0;r=c[l>>2]|0;while(1){l=r-1|0;if((r|0)<=0){break}c[d>>2]=(c[m>>2]|0)+(ba(c[q>>2]|0,l)|0);c[h>>2]=(c[k>>2]|0)*3|0;s=Yd(j|0,0)|0;if((s|0)==0){r=l}else{t=9;break}}if((t|0)==9){yDb(a,16,2051064,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;o=-1;i=f;return o|0}s=Yd(j|0,4)|0;if((s|0)==1){c[n>>2]=c[g+36>>2];g=b+36|0;c[g>>2]=c[g>>2]|1;c[e>>2]=1;o=0;i=f;return o|0}else{yDb(a,16,2051064,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;o=-1;i=f;return o|0}return 0}function tKa(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(a+96|0);Zc(b+16|0)|0;JCb(a+804|0);return 0}function uKa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;e=c[a+140>>2]|0;do{if((e|0)==0|(e|0)==4|(e|0)==5){if(!((c[a+680>>2]|0)>-1)){break}yDb(a,16,2108976,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}}while(0);e=ICb()|0;c[a+804>>2]=e;if((e|0)==0){g=-12;i=b;return g|0}c[e+88>>2]=1;c[e+84>>2]=1;e=(c[a+120>>2]|0)+1|0;if(e>>>0>268435454>>>0){h=0}else{h=WDb(e<<3)|0}c[d+1600>>2]=h;Z3(d,a);x2(d+1128|0,d+1244|0,1075976);ILa(a,d+1516|0,d+1504|0);sLa(d+1576|0,d+1528|0,1744176,1743824);sLa(d+1588|0,d+1552|0,1744200,1743824);g=0;i=b;return g|0}function vKa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;k=i;i=i+72|0;l=k|0;m=k+16|0;n=k+32|0;o=k+48|0;p=f+60|0;q=c[p>>2]|0;r=f+120|0;s=c[r>>2]|0;t=f+124|0;u=c[t>>2]|0;v=c[q+1516>>2]|0;w=c[q+1504>>2]|0;x=f+140|0;y=c[x>>2]|0;if((y|0)==298|(y|0)==30|(y|0)==3){z=ba(s*12|0,u)|0}else{z=ba(ba(ba(v*12|0,w)|0,(u-1+w|0)/(w|0)|0)|0,(s-1+v|0)/(v|0)|0)|0}v=z+16384|0;z=r0a(f,g,v,(v|0)<0|0?-1:0)|0;if((z|0)<0){A=z;i=k;return A|0}z=g+28|0;v=c[z>>2]|0;s=(v|0)<0;w=s?0:c[g+24>>2]|0;u=s?0:v;c[o+20>>2]=u<<3;v=o+8|0;c[v>>2]=w;s=o+16|0;c[s>>2]=w+u;u=o+12|0;c[u>>2]=w;w=o+4|0;c[w>>2]=32;y=o|0;c[y>>2]=0;B=q+1376|0;JLa(f,o,q+1244|0,B,B);B=c[w>>2]|0;q=c[v>>2]|0;C=c[u>>2]|0;D=(C-q<<3)+(32-B)|0;E=c[x>>2]|0;a:do{if((E|0)==298|(E|0)==30|(E|0)==3){F=c[p>>2]|0;G=c[h+68>>2]|0;H=c[h+72>>2]|0;I=c[h+32>>2]|0;J=c[F+1600>>2]|0;K=c[f+216>>2]|0;L=J|0;b[L>>1]=256;M=J+2|0;b[M>>1]=256;N=J+4|0;b[N>>1]=256;O=K+1|0;if((H|0)<=0){break}K=h|0;P=G*12|0;Q=(G|0)>0;R=F+1576|0;S=F+1528|0;T=F+1588|0;U=F+1552|0;F=n|0;V=l|0;W=m|0;X=n+4|0;Y=l+4|0;Z=m+4|0;_=n+8|0;$=l+8|0;aa=m+8|0;ca=0;da=q;ea=B;fa=C;while(1){ga=(ca|0)!=0?O:1;ha=c[K>>2]|0;ia=ba(ca,I)|0;ja=da;if(((c[s>>2]|0)-ja-(32-ea+(fa-ja<<3)>>3)|0)<(P|0)){break}ja=e[L>>1]|0;c[F>>2]=ja;c[V>>2]=ja;c[W>>2]=ja;ja=e[M>>1]|0;c[X>>2]=ja;c[Y>>2]=ja;c[Z>>2]=ja;ja=e[N>>1]|0;c[_>>2]=ja;c[$>>2]=ja;c[aa>>2]=ja;if(Q){ja=ia+1|0;ka=ia+2|0;la=(ga|0)==0;ma=0;while(1){if((c[x>>2]|0)==3){na=ma*3|0;oa=ha+(na+ia)|0;pa=ha+(ja+na)|0;b[J+(ma<<3)+2>>1]=(d[oa]|0|256)-(d[pa]|0);qa=ha+(ka+na)|0;b[J+(ma<<3)+4>>1]=(d[qa]|0|256)-(d[pa]|0);na=(((d[pa]|0)<<1)+(d[oa]|0)+(d[qa]|0)|0)>>>2&65535;b[J+(ma<<3)>>1]=na;ra=na}else{na=ma<<2;qa=ha+(na+ia)|0;oa=ha+((na|1)+ia)|0;b[J+(ma<<3)+2>>1]=(d[qa]|0|256)-(d[oa]|0);pa=ha+((na|2)+ia)|0;b[J+(ma<<3)+4>>1]=(d[pa]|0|256)-(d[oa]|0);na=(((d[oa]|0)<<1)+(d[qa]|0)+(d[pa]|0)|0)>>>2&65535;b[J+(ma<<3)>>1]=na;ra=na}na=ma+1|0;b:do{if(la){c[F>>2]=c[W>>2];c[W>>2]=e[J+(na<<3)>>1]|0;pa=ra&65535;c[V>>2]=pa;NLa(o,(pa+256&511)-256|0,R,S);c[X>>2]=c[Z>>2];c[Z>>2]=e[J+(na<<3)+2>>1]|0;pa=e[J+(ma<<3)+2>>1]|0;c[Y>>2]=pa;NLa(o,(pa+256&511)-256|0,T,U);c[_>>2]=c[aa>>2];c[aa>>2]=e[J+(na<<3)+4>>1]|0;pa=e[J+(ma<<3)+4>>1]|0;c[$>>2]=pa;NLa(o,(pa+256&511)-256|0,T,U)}else{pa=0;while(1){switch(ga|0){case 5:{sa=((c[m+(pa<<2)>>2]|0)-(c[n+(pa<<2)>>2]|0)>>1)+(c[l+(pa<<2)>>2]|0)|0;break};case 1:{sa=c[l+(pa<<2)>>2]|0;break};case 4:{sa=(c[m+(pa<<2)>>2]|0)+(c[l+(pa<<2)>>2]|0)-(c[n+(pa<<2)>>2]|0)|0;break};case 2:{sa=c[m+(pa<<2)>>2]|0;break};case 0:{sa=0;break};case 3:{sa=c[n+(pa<<2)>>2]|0;break};case 6:{sa=((c[l+(pa<<2)>>2]|0)-(c[n+(pa<<2)>>2]|0)>>1)+(c[m+(pa<<2)>>2]|0)|0;break};default:{sa=(c[m+(pa<<2)>>2]|0)+(c[l+(pa<<2)>>2]|0)>>1}}qa=m+(pa<<2)|0;c[n+(pa<<2)>>2]=c[qa>>2];c[qa>>2]=e[J+(na<<3)+(pa<<1)>>1]|0;qa=e[J+(ma<<3)+(pa<<1)>>1]|0;c[l+(pa<<2)>>2]=qa;oa=(256-sa+qa&511)-256|0;if((pa|0)==0){NLa(o,oa,R,S);pa=1;continue}else{NLa(o,oa,T,U);oa=pa+1|0;if((oa|0)<3){pa=oa;continue}else{break b}}}}}while(0);if((na|0)<(G|0)){ma=na}else{break}}}ma=ca+1|0;if((ma|0)>=(H|0)){break a}ca=ma;da=c[v>>2]|0;ea=c[w>>2]|0;fa=c[u>>2]|0}yDb(f,16,2186096,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;A=-1;i=k;return A|0}else{fa=c[f+216>>2]|0;ea=c[p>>2]|0;da=ea;ca=ea+1516|0;H=c[ca>>2]|0;G=((c[r>>2]|0)-1+H|0)/(H|0)|0;U=ea+1504|0;T=c[U>>2]|0;S=((c[t>>2]|0)-1+T|0)/(T|0)|0;if((S|0)<=0){break}R=G*12|0;J=(G|0)>0;$=ea+1576|0;aa=ea+1528|0;_=ea+1588|0;Y=ea+1552|0;ea=0;Z=H;H=T;T=q;X=B;V=C;while(1){W=T;if(((c[s>>2]|0)-W-(32-X+(V-W<<3)>>3)|0)<(ba(ba(R,H)|0,Z)|0)){break}if(J){W=(ea|0)==0;F=0;do{Q=(F|0)==0;if(Q|W){N=Q^1;Q=0;do{M=c[da+1516+(Q<<2)>>2]|0;L=c[da+1504+(Q<<2)>>2]|0;P=c[h+32+(Q<<2)>>2]|0;if((L|0)>0){I=(M|0)>0;K=h+(Q<<2)|0;O=ba(L,ea)|0;ma=ba(M,F)|0;ga=(Q|0)==0;la=~P;ia=0;do{if(I){ha=(ba(ia+O|0,P)|0)+ma|0;ka=(ia|ea|0)==0;ja=0;do{pa=c[K>>2]|0;oa=ha+ja|0;qa=pa+oa|0;ua=(ja|0)!=0|N;c:do{if(ka){if(!ua){va=128;break}va=d[pa+(oa-1)|0]|0}else{if(!ua){va=d[pa+(oa-P)|0]|0;break}switch(fa|0){case 5:{va=((d[pa+(oa-1)|0]|0)-(d[pa+(oa+la)|0]|0)>>1)+(d[pa+(oa-P)|0]|0)|0;break c;break};case 1:{va=d[pa+(oa-P)|0]|0;break c;break};case-1:{va=0;break c;break};case 4:{va=((d[pa+(oa-P)|0]|0)-(d[pa+(oa+la)|0]|0)>>1)+(d[pa+(oa-1)|0]|0)|0;break c;break};case 2:{va=d[pa+(oa+la)|0]|0;break c;break};case 0:{va=d[pa+(oa-1)|0]|0;break c;break};case 3:{va=(d[pa+(oa-P)|0]|0)+(d[pa+(oa-1)|0]|0)-(d[pa+(oa+la)|0]|0)|0;break c;break};default:{va=((d[pa+(oa-P)|0]|0)+(d[pa+(oa-1)|0]|0)|0)>>>1;break c}}}}while(0);oa=(d[qa]|0)-va|0;if(ga){NLa(o,oa,$,aa)}else{NLa(o,oa,_,Y)}ja=ja+1|0;}while((ja|0)<(M|0))}ia=ia+1|0;}while((ia|0)<(L|0))}Q=Q+1|0;}while((Q|0)<3)}else{Q=0;do{N=c[da+1516+(Q<<2)>>2]|0;na=c[da+1504+(Q<<2)>>2]|0;L=c[h+32+(Q<<2)>>2]|0;if((na|0)>0){ia=(N|0)>0;M=h+(Q<<2)|0;ga=ba(na,ea)|0;P=ba(N,F)|0;la=(Q|0)==0;K=~L;ma=0;do{d:do{if(ia){O=(ba(ma+ga|0,L)|0)+P|0;I=0;while(1){ja=c[M>>2]|0;ka=O+I|0;switch(fa|0){case 2:{wa=d[ja+(ka+K)|0]|0;break};case 3:{wa=(d[ja+(ka-L)|0]|0)+(d[ja+(ka-1)|0]|0)-(d[ja+(ka+K)|0]|0)|0;break};case 4:{wa=((d[ja+(ka-L)|0]|0)-(d[ja+(ka+K)|0]|0)>>1)+(d[ja+(ka-1)|0]|0)|0;break};case 5:{wa=((d[ja+(ka-1)|0]|0)-(d[ja+(ka+K)|0]|0)>>1)+(d[ja+(ka-L)|0]|0)|0;break};case 0:{wa=d[ja+(ka-1)|0]|0;break};case-1:{wa=0;break};case 1:{wa=d[ja+(ka-L)|0]|0;break};default:{wa=((d[ja+(ka-L)|0]|0)+(d[ja+(ka-1)|0]|0)|0)>>>1}}ha=(d[ja+ka|0]|0)-wa|0;if(la){NLa(o,ha,$,aa)}else{NLa(o,ha,_,Y)}I=I+1|0;if((I|0)>=(N|0)){break d}}}}while(0);ma=ma+1|0;}while((ma|0)<(na|0))}Q=Q+1|0;}while((Q|0)<3)}F=F+1|0;}while((F|0)<(G|0))}F=ea+1|0;if((F|0)>=(S|0)){break a}ea=F;Z=c[ca>>2]|0;H=c[U>>2]|0;T=c[v>>2]|0;X=c[w>>2]|0;V=c[u>>2]|0}yDb(f,16,2186096,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;A=-1;i=k;return A|0}}while(0);KLa(o,D>>3);MLa(o,D);D=c[w>>2]|0;if((D|0)<32){o=c[y>>2]<<D;c[y>>2]=o;D=o>>>24&255;while(1){o=c[u>>2]|0;c[u>>2]=o+1;a[o]=D;o=c[y>>2]|0;c[y>>2]=o<<8;ta=(c[w>>2]|0)+8|0;c[w>>2]=ta;if((ta|0)<32){D=o>>>16&255}else{break}}}c[w>>2]=32;c[y>>2]=0;c[z>>2]=(c[u>>2]|0)-(c[v>>2]|0);v=g+36|0;c[v>>2]=c[v>>2]|1;c[j>>2]=1;A=0;i=k;return A|0}function wKa(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(a+804|0);$Db(b+1600|0);return 0}function xKa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=c[a+100>>2]|0;if((f|0)<12){yDb(a,16,1967928,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-1094995529;i=b;return h|0}f=a+96|0;j=c[f>>2]|0;k=j;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;if((l|0)==1){c[e+4>>2]=0;m=j}else if((l|0)==2){k=j+8|0;c[e+4>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;m=j}else{k=j+8|0;c[e+4>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;DDb(a,1939552,(g=i,i=i+8|0,c[g>>2]=l,g)|0);i=g;m=c[f>>2]|0}f=m+4|0;m=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[e+8>>2]=m;switch(m|0){case-2:case 3:{c[a+140>>2]=3;break};case-4:case 5:{c[a+140>>2]=0;break};case-3:case 4:{c[a+140>>2]=30;break};case-1:case 1:case 2:{c[a+140>>2]=4;break};default:{yDb(a,32,1915368,(g=i,i=i+8|0,c[g>>2]=m,g)|0);i=g;h=-1094995529;i=b;return h|0}}if((c[a+688>>2]&1|0)==0){h=0;i=b;return h|0}yDb(a,32,1894736,(g=i,i=i+24|0,c[g>>2]=c[e+4>>2],c[g+8>>2]=l,c[g+16>>2]=m,g)|0);i=g;h=0;i=b;return h|0}function yKa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;g=c[a+60>>2]|0;h=g;j=c[e+24>>2]|0;k=e+28|0;e=c[k>>2]|0;l=_$a(a,b,0)|0;if((l|0)<0){m=l;i=f;return m|0}c[b+84>>2]=1;a:do{switch(c[g+8>>2]|0){case-1:case 1:case 2:{l=a+120|0;n=a+124|0;o=zKa(h,c[b>>2]|0,c[l>>2]|0,c[n>>2]|0,c[b+32>>2]|0,j,e,1)|0;if(!((o|0)>-1&(o|0)<(e|0))){break a}p=e-o|0;q=zKa(h,c[b+4>>2]|0,(c[l>>2]|0)/2|0,c[n>>2]|0,c[b+36>>2]|0,j+o|0,p,1)|0;if(!((q|0)>-1&(q|0)<(p|0))){break a}r=p-q|0;s=zKa(h,c[b+8>>2]|0,(c[l>>2]|0)/2|0,c[n>>2]|0,c[b+40>>2]|0,j+(q+o)|0,r,1)|0;t=r;u=17;break};case-3:case 4:{r=b;o=b+32|0;q=c[o>>2]|0;n=a+124|0;l=c[n>>2]|0;p=a+120|0;v=zKa(h,(c[r>>2]|0)+(ba(l-1|0,q)|0)|0,c[p>>2]|0,l,-q|0,j,e,4)|0;if(!((v|0)>-1&(v|0)<(e|0))){break a}q=e-v|0;l=c[o>>2]|0;w=c[n>>2]|0;x=zKa(h,(c[r>>2]|0)+((ba(w-1|0,l)|0)+1)|0,c[p>>2]|0,w,-l|0,j+v|0,q,4)|0;if(!((x|0)>-1&(x|0)<(q|0))){break a}l=x+v|0;v=q-x|0;x=c[o>>2]|0;q=c[n>>2]|0;w=zKa(h,(c[r>>2]|0)+((ba(q-1|0,x)|0)+2)|0,c[p>>2]|0,q,-x|0,j+l|0,v,4)|0;if(!((w|0)>-1&(w|0)<(v|0))){break a}x=v-w|0;v=c[o>>2]|0;o=c[n>>2]|0;s=zKa(h,(c[r>>2]|0)+((ba(o-1|0,v)|0)+3)|0,c[p>>2]|0,o,-v|0,j+(w+l)|0,x,4)|0;t=x;u=17;break};case-4:case 5:{x=a+120|0;l=a+124|0;w=zKa(h,c[b>>2]|0,c[x>>2]|0,c[l>>2]|0,c[b+32>>2]|0,j,e,1)|0;if(!((w|0)>-1&(w|0)<(e|0))){break a}v=e-w|0;o=zKa(h,c[b+8>>2]|0,(c[x>>2]|0)/2|0,(c[l>>2]|0)/2|0,c[b+40>>2]|0,j+w|0,v,1)|0;if(!((o|0)>-1&(o|0)<(v|0))){break a}p=v-o|0;s=zKa(h,c[b+4>>2]|0,(c[x>>2]|0)/2|0,(c[l>>2]|0)/2|0,c[b+36>>2]|0,j+(o+w)|0,p,1)|0;t=p;u=17;break};case-2:case 3:{p=b;w=b+32|0;o=c[w>>2]|0;l=a+124|0;x=c[l>>2]|0;v=a+120|0;r=zKa(h,(c[p>>2]|0)+(ba(x-1|0,o)|0)|0,c[v>>2]|0,x,-o|0,j,e,3)|0;if(!((r|0)>-1&(r|0)<(e|0))){break a}o=e-r|0;x=c[w>>2]|0;n=c[l>>2]|0;q=zKa(h,(c[p>>2]|0)+((ba(n-1|0,x)|0)+1)|0,c[v>>2]|0,n,-x|0,j+r|0,o,3)|0;if(!((q|0)>-1&(q|0)<(o|0))){break a}x=o-q|0;o=c[w>>2]|0;w=c[l>>2]|0;s=zKa(h,(c[p>>2]|0)+((ba(w-1|0,o)|0)+2)|0,c[v>>2]|0,w,-o|0,j+(q+r)|0,x,3)|0;t=x;u=17;break};default:{yDb(0,0,2186064,(y=i,i=i+24|0,c[y>>2]=2108968,c[y+8>>2]=2051040,c[y+16>>2]=235,y)|0);i=y;Cd();return 0}}}while(0);do{if((u|0)==17){if((s|0)<0|(s|0)>(t|0)){break}c[d>>2]=1;m=s-t+(c[k>>2]|0)|0;i=f;return m|0}}while(0);yDb(a,16,2005584,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;m=-22;i=f;return m|0}function zKa(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=i;i=i+48|0;n=m|0;if((k|0)<1){o=-1;i=m;return o|0}p=k>>>0>268435455>>>0?-8:k<<3;k=p>>>0>2147483639>>>0|(j|0)==0;q=k?0:j;j=k?0:p;c[n>>2]=q;c[n+12>>2]=j;c[n+16>>2]=j+8;c[n+4>>2]=q+(j>>3);j=n+8|0;c[j>>2]=0;c[n+20>>2]=0;c[n+24>>2]=0;c[n+28>>2]=0;c[n+40>>2]=c[b+4>>2];c[n+32>>2]=8;c[n+36>>2]=1;a[e]=(AKa(n)|0)+128;b=(f|0)>1;if(b){q=1;do{p=AKa(n)|0;k=ba(q,l)|0;a[e+k|0]=(d[e+(k-l)|0]|0)+p;q=q+1|0;}while((q|0)<(f|0))}q=e+h|0;a:do{if((g|0)>1){p=l+h|0;if(b){r=e;s=1;t=q}else{k=e;u=1;v=q;while(1){w=AKa(n)|0;a[v]=(d[k]|0)+w;w=u+1|0;if((w|0)<(g|0)){k=v;u=w;v=v+h|0}else{break a}}}while(1){v=AKa(n)|0;a[t]=(d[r]|0)+v;v=1;do{u=AKa(n)|0;k=ba(v,l)|0;w=k+h|0;x=r+w|0;y=d[r+k|0]|0;k=d[r+(w-l)|0]|0;z=k+y-(d[r+(w-p)|0]|0)|0;do{if((y|0)>(z|0)){if((k|0)<=(z|0)){A=z;break}A=k>>>0>y>>>0?y:k}else{if((z|0)<=(k|0)){A=z;break}A=k>>>0>y>>>0?k:y}}while(0);a[x]=A+u;v=v+1|0;}while((v|0)<(f|0));v=s+1|0;if((v|0)<(g|0)){r=t;s=v;t=t+h|0}else{break}}}}while(0);o=(c[j>>2]|0)+7>>3;i=m;return o|0}function AKa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a+24|0;d=c[b>>2]|0;if((d|0)>0){c[b>>2]=d-1;d=a+32|0;e=c[d>>2]|0;f=a+36|0;g=(c[f>>2]|0)+1|0;c[f>>2]=g;if((g|0)!=16){h=0;return h|0}c[d>>2]=e>>1;c[f>>2]=8;h=0;return h|0}f=a|0;e=a+36|0;d=c[e>>2]|0;g=a+32|0;i=c[g>>2]|0;if((i|0)>(d|0)){j=0;k=d;while(1){d=k<<1;l=j+1|0;if((i|0)>(d|0)&(l|0)<9){j=l;k=d}else{m=l;break}}}else{m=0}k=BKa(f,m)|0;m=(k+1>>1)+(c[g>>2]|0)|0;c[g>>2]=m;j=(c[e>>2]|0)+1|0;c[e>>2]=j;if((j|0)==16){c[g>>2]=m>>1;c[e>>2]=8}if((k|0)!=0){e=(c[a+40>>2]|0)+(k>>1)^-(k&1);k=a+28|0;m=c[k>>2]|0;if((m|0)<=0){h=e;return h|0}g=a+20|0;c[g>>2]=(c[g>>2]|0)+((m|0)>2?m:-3);c[k>>2]=0;h=e;return h|0}e=a+20|0;if(!((c[e>>2]|0)>-1)){k=a+28|0;c[k>>2]=(c[k>>2]|0)+1;h=0;return h|0}k=BKa(f,2)|0;c[b>>2]=k;if((k|0)>1){c[e>>2]=k+1+(c[e>>2]|0);h=0;return h|0}else{c[e>>2]=(c[e>>2]|0)-3;h=0;return h|0}return 0}function BKa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=c[a>>2]|0;i=h+(f>>>3)|0;j=(fe(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(f&7);i=j>>>0>65535>>>0;k=i?j>>>16:j;l=i?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=(d[1191992+n|0]|0)+m|0;m=k-b|0;if(!((m|0)<7|(k|0)==-2147483615)){n=b+32+f-k|0;c[e>>2]=g>>>0>n>>>0?n:g;o=(j>>>(m>>>0))+(30-k<<b)|0;return o|0}do{if((j|0)>-1){k=c[a+12>>2]|0;m=f;n=0;do{if(!(k>>>0>m>>>0)){o=-1;p=16;break}l=m+1|0;m=g>>>0>l>>>0?l:g;l=h+(m>>>3)|0;q=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7);n=n+1|0;}while((n|0)!=2147483647&(q|0)>-1);if((p|0)==16){return o|0}k=m+1|0;l=g>>>0>k>>>0?k:g;if((n|0)<2147483646){r=n;s=q;t=l;break}if((n|0)!=2147483646){o=-1;return o|0}c[e>>2]=l;o=0;return o|0}else{l=f+1|0;r=0;s=j;t=g>>>0>l>>>0?l:g}}while(0);if((b|0)==0){u=t;v=0}else{j=t+b|0;u=g>>>0>j>>>0?j:g;v=s<<1>>>((32-b|0)>>>0)}c[e>>2]=u;o=v+(r<<b)|0;return o|0}function CKa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0,s=0.0,t=0.0;f=i;i=i+776|0;g=f|0;j=f+256|0;k=f+512|0;l=a|0;m=a+16|0;Xe[c[a+20>>2]&4095](b,c[l>>2]|0,c[m>>2]|0);b=k|0;cf[c[a+24>>2]&1023](c[m>>2]|0,c[l>>2]|0,d,b);if((d|0)<=0){h[e>>3]=(-0.0-0.0)/+h[b>>3];i=f;return d|0}l=k+8|0;k=d<<3;UGb(j|0,l|0,k)|0;UGb(g|0,l|0,k)|0;k=j|0;n=+h[k>>3];o=+h[b>>3];p=(-0.0-n)/o;h[e>>3]=p;if((d|0)<=1){i=f;return d|0}b=1;q=o+n*p;o=n;n=p;while(1){l=d-b|0;if((l|0)>0){m=0;while(1){a=m+1|0;p=+h[j+(a<<3)>>3];r=g+(m<<3)|0;s=+h[r>>3];h[j+(m<<3)>>3]=p+n*s;h[r>>3]=n*p+s;if((a|0)<(l|0)){m=a}else{break}}t=+h[k>>3]}else{t=o}s=(-0.0-t)/q;h[e+(b<<3)>>3]=s;m=b+1|0;if((m|0)<(d|0)){b=m;q=q+t*s;o=t;n=s}else{break}}i=f;return d|0}function DKa(a,b,d,e,f,g,j,k,l,m,n,o,p){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0,P=0,S=0,T=0.0,U=0,V=0.0,W=0.0,X=0,Y=0.0,Z=0,_=0.0,$=0,aa=0,ba=0,ca=0,da=0;q=i;i=i+46728|0;r=q|0;s=q+264|0;t=q+520|0;u=q+8712|0;v=q+46408|0;w=(l|0)==3;x=(l|0)==2;if(!((l-2|0)>>>0<2>>>0)){yDb(0,0,2264824,(y=i,i=i+24|0,c[y>>2]=2321944,c[y+8>>2]=2186040,c[y+16>>2]=185,y)|0);i=y;Cd();return 0}y=a|0;z=a+4|0;do{if((c[y>>2]|0)==(d|0)){if((c[z>>2]|0)!=(f|0)){A=6;break}if((c[a+8>>2]|0)!=(l|0)){A=6}}else{A=6}}while(0);do{if((A|0)==6){B=a+12|0;$Db(B);c[y>>2]=d;c[z>>2]=f;c[a+8>>2]=l;C=f+3&-4;D=cEb(d+2+C<<3)|0;E=D;c[B>>2]=E;if((D|0)==0){break}c[a+16>>2]=E+(C<<3);c[a+20>>2]=286;c[a+24>>2]=262}}while(0);l=(m|0)<1?2:m;if(x){A=10}else{if(w&(l|0)>1){A=10}else{F=0}}do{if((A|0)==10){x=a+16|0;Xe[c[a+20>>2]&4095](b,d,c[x>>2]|0);m=r|0;cf[c[a+24>>2]&1023](c[x>>2]|0,d,f,m);x=t|0;z=(f|0)>0;if(!z){F=1;break}y=x;C=0;G=+h[m>>3];m=x;while(1){x=C+1|0;H=-0.0- +h[r+(x<<3)>>3];if((C|0)>0){E=0;I=H;while(1){J=I- +h[m+(E<<3)>>3]*+h[r+(C-E<<3)>>3];D=E+1|0;if((D|0)<(C|0)){E=D;I=J}else{K=J;break}}}else{K=H}I=K/G;J=G*(1.0-I*I);h[y+(C<<3)>>3]=I;E=x>>1;if((E|0)>0){D=C-1|0;B=0;do{L=+h[m+(B<<3)>>3];M=D-B|0;N=+h[m+(M<<3)>>3];h[y+(B<<3)>>3]=L+I*N;h[y+(M<<3)>>3]=N+I*L;B=B+1|0;}while((B|0)<(E|0))}if((x|0)<(f|0)){m=y;y=y+256|0;C=x;G=J}else{break}}if(z){O=0}else{F=1;break}while(1){h[s+(O<<3)>>3]=+Q(+(+h[t+(O<<8)+(O<<3)>>3]));C=O+1|0;if((C|0)<(f|0)){O=C}else{F=1;break}}}}while(0);do{if(w){O=v+31&-32;r=O;TGb(O|0,0,288)|0;O=(f|0)>0;if(O){a=f-1|0;A=0;do{h[u+10368+(a<<8)+(A<<3)>>3]=-0.0- +h[t+(a<<8)+(A<<3)>>3];A=A+1|0;}while((A|0)<(f|0))}if((F|0)<(l|0)){A=(f|0)<(d|0);a=(f|0)<0;z=r+8|0;C=f-1|0;y=F;while(1){m=y&1;E=u+(m*18848|0)|0;qDb(E,f);a:do{if(A){B=(y|0)==0;D=u+(m*18848|0)+18820|0;M=u+(m*18848|0)+18824|0;P=u+((m^1)*18848|0)|0;K=+(512>>>(y>>>0)|0);if(a){G=0.0;S=f;while(1){if(B){T=1.0}else{I=+Qe[c[M>>2]&3](P,z,C);T=1.0/(K+ +Q(+(I- +h[r>>3])))}I=G+T;ne[c[D>>2]&1023](E,r);U=S+1|0;if((U|0)<(d|0)){G=I;S=U}else{V=I;break a}}}else{W=0.0;X=f}while(1){S=0;do{h[r+(S<<3)>>3]=+(c[b+(X-S<<2)>>2]|0);S=S+1|0;}while((S|0)<=(f|0));b:do{if(B){Y=1.0}else{G=+Qe[c[M>>2]&3](P,z,C);I=+h[r>>3];H=1.0/(K+ +Q(+(G-I)));G=+R(H);S=0;L=I;while(1){h[r+(S<<3)>>3]=G*L;U=S+1|0;if((U|0)>(f|0)){Y=H;break b}S=U;L=+h[r+(U<<3)>>3]}}}while(0);L=W+Y;ne[c[D>>2]&1023](E,r);S=X+1|0;if((S|0)<(d|0)){W=L;X=S}else{V=L;break}}}else{V=0.0}}while(0);pDb(E,.001,0);m=y+1|0;if((m|0)<(l|0)){y=m}else{Z=l;_=V;break}}}else{Z=F;_=0.0}if(O){y=Z&1^1;J=+(d-f|0);r=0;do{C=0;do{h[t+(r<<8)+(C<<3)>>3]=-0.0- +h[u+(y*18848|0)+10368+(r<<8)+(C<<3)>>3];C=C+1|0;}while((C|0)<(f|0));h[s+(r<<3)>>3]=J*+R(+h[u+(y*18848|0)+18560+(r<<3)>>3]/_)/4.0e3;r=r+1|0;}while((r|0)<(f|0))}r=f-1|0;if((r|0)>0){$=f;aa=r}else{break}while(1){r=s+(aa<<3)|0;h[r>>3]=+h[s+($-2<<3)>>3]- +h[r>>3];r=aa-1|0;if((r|0)>0){$=aa;aa=r}else{break}}}}while(0);aa=e-1|0;if((n|0)==0){n=f;while(1){$=n-1|0;if(($|0)<(aa|0)){ba=e;break}if(+h[s+($<<3)>>3]>.1){ba=n;break}else{n=$}}n=ba-1|0;GKa(t+(n<<8)|0,ba,g,j+(n<<7)|0,k+(n<<2)|0,o,p);ca=ba;i=q;return ca|0}else{if((aa|0)<(f|0)){da=aa}else{ca=f;i=q;return ca|0}while(1){aa=da+1|0;GKa(t+(da<<8)|0,aa,g,j+(da<<7)|0,k+(da<<2)|0,o,p);if((aa|0)<(f|0)){da=aa}else{ca=f;break}}i=q;return ca|0}return 0}function EKa(a){a=a|0;$Db(a+12|0);return}function FKa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[a>>2]=b;c[a+4>>2]=d;c[a+8>>2]=e;e=d+3&-4;d=cEb(b+2+e<<3)|0;b=d;c[a+12>>2]=b;if((d|0)==0){f=-12;return f|0}c[a+16>>2]=b+(e<<3);c[a+20>>2]=286;c[a+24>>2]=262;f=0;return f|0}function GKa(a,b,d,e,f,g,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;var j=0,k=0,l=0.0,m=0,n=0.0,o=0.0,p=0,q=0.0,r=0.0,s=0,t=0,u=0;j=1<<d-1;d=j-1|0;k=(b|0)>0;if(k){l=0.0;m=0;while(1){n=+Q(+(+h[a+(m<<3)>>3]));o=l>n?l:n;p=m+1|0;if((p|0)<(b|0)){l=o;m=p}else{q=o;break}}}else{q=0.0}if(+(1<<g|0)*q<1.0){c[f>>2]=i;TGb(e|0,0,b<<2|0)|0;return}l=+(d|0);i=g;while(1){r=+(1<<i|0);if(q*r>l&(i|0)>0){i=i-1|0}else{break}}do{if((i|0)==0&q>l){o=l/q;if(k){s=0}else{break}while(1){g=a+(s<<3)|0;h[g>>3]=o*+h[g>>3];g=s+1|0;if((g|0)<(b|0)){s=g}else{t=8;break}}}else{t=8}}while(0);do{if((t|0)==8){if(!k){break}s=1-j|0;q=0.0;g=0;while(1){l=q-r*+h[a+(g<<3)>>3];m=Gc(+l)|0;if((m|0)<(s|0)){u=s}else{u=(m|0)>(d|0)?d:m}c[e+(g<<2)>>2]=u;m=g+1|0;if((m|0)<(b|0)){q=l- +(u|0);g=m}else{break}}}}while(0);c[f>>2]=i;return}function HKa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0.0,g=0.0,i=0.0,j=0;e=b>>1;if((e|0)<=0){return}f=2.0/(+(b|0)+-1.0)- +(e|0);b=0;do{g=f+ +(b|0);i=1.0-g*g;j=e+~b|0;h[d+(j<<3)>>3]=i*+(c[a+(j<<2)>>2]|0);j=b+e|0;h[d+(j<<3)>>3]=i*+(c[a+(j<<2)>>2]|0);b=b+1|0;}while((b|0)<(e|0));return}function IKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0.0;if((c|0)>0){e=0;while(1){if((e|0)<(b|0)){f=e;g=1.0;i=1.0;while(1){j=+h[a+(f<<3)>>3];k=f-e|0;l=g+j*+h[a+(k<<3)>>3];m=i+j*+h[a+(k-1<<3)>>3];k=f+1|0;if((k|0)<(b|0)){f=k;g=l;i=m}else{n=l;o=m;break}}}else{n=1.0;o=1.0}h[d+(e<<3)>>3]=n;h[d+((e|1)<<3)>>3]=o;f=e+2|0;if((f|0)<(c|0)){e=f}else{p=f;break}}}else{p=0}if((p|0)!=(c|0)){return}p=c-1|0;if((p|0)<(b|0)){e=p;o=1.0;while(1){p=e-c|0;n=o+(+h[a+(e<<3)>>3]*+h[a+(p<<3)>>3]+ +h[a+(e+1<<3)>>3]*+h[a+(p+1<<3)>>3]);p=e+2|0;if((p|0)<(b|0)){e=p;o=n}else{q=n;break}}}else{q=1.0}h[d+(c<<3)>>3]=q;return}function JKa(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f-1|0;if((g|0)>0){h=0;do{i=h;while(1){j=a+(i<<1)|0;k=b[j>>1]|0;l=a+(i+1<<1)|0;m=b[l>>1]|0;if(!(k<<16>>16>m<<16>>16)){break}b[l>>1]=k;b[j>>1]=m;if((i|0)>0){i=i-1|0}else{break}}h=h+1|0;}while((h|0)<(g|0))}if((f|0)>0){h=0;i=d;while(1){d=a+(h<<1)|0;m=b[d>>1]|0;j=(m<<16>>16|0)>(i|0)?m:i&65535;b[d>>1]=j;d=h+1|0;if((d|0)<(f|0)){h=d;i=(j<<16>>16)+c|0}else{break}}}c=a+(g<<1)|0;g=b[c>>1]|0;b[c>>1]=(g<<16>>16|0)>(e|0)?e&65535:g;return}function KKa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0.0,f=0,h=0.0,i=0.0;if((c|0)>0){d=0;e=0.0}else{return}do{f=a+(d<<2)|0;h=+g[f>>2];i=e+b;e=h>i?h:i;g[f>>2]=e;d=d+1|0;}while((d|0)<(c|0));return}function LKa(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)>0){e=0}else{return}do{f=(b[c+(e<<1)>>1]|0)*20861|0;g=f>>>23&255;h=b[213232+(g<<1)>>1]|0;b[a+(e<<1)>>1]=((ba((b[213232+(g+1<<1)>>1]|0)-h|0,f>>>15&255)|0)>>>8)+h;e=e+1|0;}while((e|0)<(d|0));return}function MKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((c|0)>0){d=0}else{return}do{h[a+(d<<3)>>3]=+T(+g[b+(d<<2)>>2]*6.283185307179586);d=d+1|0;}while((d|0)<(c|0));return}function NKa(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+96|0;g=f|0;h=f+48|0;c[g>>2]=4194304;j=-(b[d>>1]|0)<<8;k=g+4|0;c[k>>2]=j;l=(e|0)<2;if(l){m=j}else{j=2;while(1){n=c[g+(j-2<<2)>>2]|0;c[g+(j<<2)>>2]=n;o=b[d+((j<<1)-2<<1)>>1]|0;if((j|0)>1){p=o<<16>>16;q=o<<16>>16<0|0?-1:0;r=j;s=n;while(1){n=r-1|0;t=c[g+(n<<2)>>2]|0;u=gHb(t,(t|0)<0|0?-1:0,p,q)|0;v=F;w=YGb(c[g+(r-2<<2)>>2]|0,0,s,0)|0;x=ZGb(w,F,u>>>14|v<<18,v>>>14|0<<18)|0;c[g+(r<<2)>>2]=x;if((n|0)>1){r=n;s=t}else{break}}}s=(c[k>>2]|0)-(o<<16>>16<<8)|0;c[k>>2]=s;r=j+1|0;if((r|0)>(e|0)){m=s;break}else{j=r}}}j=h|0;c[j>>2]=4194304;k=-(b[d+2>>1]|0)<<8;r=h+4|0;c[r>>2]=k;if(l){y=k}else{k=2;while(1){l=c[h+(k-2<<2)>>2]|0;c[h+(k<<2)>>2]=l;s=b[d+((k<<1)-1<<1)>>1]|0;if((k|0)>1){q=s<<16>>16;p=s<<16>>16<0|0?-1:0;t=k;n=l;while(1){l=t-1|0;x=c[h+(l<<2)>>2]|0;v=gHb(x,(x|0)<0|0?-1:0,q,p)|0;u=F;w=YGb(c[h+(t-2<<2)>>2]|0,0,n,0)|0;z=ZGb(w,F,v>>>14|u<<18,u>>>14|0<<18)|0;c[h+(t<<2)>>2]=z;if((l|0)>1){t=l;n=x}else{break}}}n=(c[r>>2]|0)-(s<<16>>16<<8)|0;c[r>>2]=n;t=k+1|0;if((t|0)>(e|0)){y=n;break}else{k=t}}}b[a>>1]=4096;k=e+1|0;if((e|0)<=0){i=f;return}r=e<<1|1;e=1;d=c[j>>2]|0;j=m;m=y;while(1){y=m-d|0;t=j+1024+(c[g+(e-1<<2)>>2]|0)|0;b[a+(e<<1)>>1]=(y+t|0)>>>11;b[a+(r-e<<1)>>1]=(t-y|0)>>>11;y=e+1|0;if((y|0)>=(k|0)){break}e=y;d=m;j=c[g+(y<<2)>>2]|0;m=c[h+(y<<2)>>2]|0}i=f;return}function OKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,j=0,k=0,l=0.0,m=0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,F=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0,L=0.0,M=0;d=i;i=i+176|0;e=d|0;f=d+88|0;j=c>>1;k=e+8|0;h[e>>3]=0.0;h[f>>3]=1.0;l=+h[a>>3]*-2.0;m=f+8|0;h[m>>3]=l;a:do{if((j|0)<2){n=l}else{o=2;p=l;q=1.0;while(1){r=+h[a+((o<<1)-2<<3)>>3]*-2.0;s=o-1|0;t=f+(s<<3)|0;u=f+(o<<3)|0;h[u>>3]=q*2.0+p*r;do{if((s|0)>1){v=o-2|0;w=+h[f+(o-3<<3)>>3];h[t>>3]=p+(r*q+w);if((v|0)>1){x=v;y=w}else{break}while(1){v=f+(x<<3)|0;z=x-1|0;w=+h[f+(x-2<<3)>>3];h[v>>3]=+h[v>>3]+(r*y+w);if((z|0)>1){x=z;y=w}else{break}}}}while(0);w=r+ +h[m>>3];h[m>>3]=w;s=o+1|0;if((s|0)>(j|0)){n=w;break a}o=s;p=+h[u>>3];q=+h[t>>3]}}}while(0);m=j-1|0;h[k>>3]=1.0;y=+h[a+8>>3]*-2.0;k=e+16|0;h[k>>3]=y;b:do{if((m|0)>=2){x=2;l=y;q=1.0;while(1){p=+h[a+((x<<1)-1<<3)>>3]*-2.0;o=x-1|0;s=e+(x<<3)|0;z=x+1|0;v=e+(z<<3)|0;h[v>>3]=q*2.0+l*p;do{if((o|0)>1){A=x-2|0;w=+h[e+(A<<3)>>3];h[s>>3]=l+(p*q+w);if((A|0)>1){B=o;C=A;D=w}else{break}while(1){A=C-1|0;w=+h[e+(A<<3)>>3];h[e+(C+1<<3)>>3]=+h[e+(B<<3)>>3]+(p*D+w);if((A|0)>1){B=C;C=A;D=w}else{break}}}}while(0);h[k>>3]=p+ +h[k>>3];if((z|0)>(m|0)){break b}x=z;l=+h[v>>3];q=+h[s>>3]}}}while(0);k=c-1|0;D=+h[a+(k<<3)>>3];if((j|0)<=1){E=D+1.0;F=f+(j<<3)|0;G=+h[F>>3];H=E*G;I=H*.5;J=I;K=b+(m<<2)|0;g[K>>2]=J;L=D;M=b+(k<<2)|0;g[M>>2]=L;i=d;return}y=D+1.0;q=1.0-D;a=k;c=1;l=n;while(1){n=l*y;C=c+1|0;B=c-1|0;r=q*(+h[e+(C<<3)>>3]- +h[e+(B<<3)>>3]);g[b+(B<<2)>>2]=(n+r)*.5;B=a-1|0;g[b+(B<<2)>>2]=(n-r)*.5;if((C|0)>=(j|0)){break}a=B;c=C;l=+h[f+(C<<3)>>3]}E=D+1.0;F=f+(j<<3)|0;G=+h[F>>3];H=E*G;I=H*.5;J=I;K=b+(m<<2)|0;g[K>>2]=J;L=D;M=b+(k<<2)|0;g[M>>2]=L;i=d;return}function PKa(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+40|0;h=g|0;if((f|0)>0){j=0;do{b[h+(j<<1)>>1]=((b[e+(j<<1)>>1]|0)+(b[d+(j<<1)>>1]|0)|0)>>>1;j=j+1|0;}while((j|0)<(f|0))}j=f>>1;NKa(a,h|0,j);NKa(c,d,j);i=g;return}



function A5a(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Le=0,Me=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0,$i=0,aj=0,bj=0,cj=0,dj=0,ej=0,fj=0,gj=0,hj=0,ij=0,jj=0,kj=0,lj=0,mj=0,nj=0,oj=0,pj=0,qj=0,rj=0,sj=0,tj=0;g=i;i=i+96|0;j=g|0;k=g+8|0;l=g+16|0;m=g+56|0;n=g+72|0;o=g+80|0;p=f;q=c[f>>2]|0;r=c[q+(h*1536|0)+840>>2]>>16;s=f+48|0;t=e[s>>1]|0;u=ba(t,r)|0;v=c[f+5428>>2]|0;w=c[f+40>>2]|0;y=c[f+44>>2]|0;z=(c[f+4560>>2]|0)-1&r;A=f+4564|0;B=o|0;C=c[w>>2]|0;D=r<<4;E=f+52|0;F=(c[C>>2]|0)+(ba(D,c[E>>2]|0)|0)|0;c[B>>2]=F;G=o+4|0;H=r<<3;I=f+56|0;J=ba(c[I>>2]|0,H)|0;K=(c[C+4>>2]|0)+J|0;c[G>>2]=K;L=o+8|0;M=(c[C+8>>2]|0)+J|0;c[L>>2]=M;J=f+50|0;C=f+5432|0;if((c[C>>2]|0)==1){N=(c[f+4536>>2]|0)+(((ba(t+1|0,r+1|0)|0)+1|0)*96|0)|0}else{do{if((y|0)!=0){if((a[f+88|0]|0)==0){break}if((a[f+90|0]|0)!=0){break}Z0a(y|0,r,0)}}while(0);t=c[f+104>>2]|0;O=(e[J>>1]|0)-r<<1;TGb(t+((O-3|0)*96|0)|0,0,96)|0;c[f+112>>2]=33686018;N=t+((O-2|0)*96|0)|0}O=q+(h*1536|0)+824|0;TGb(O|0,0,9)|0;t=f+64|0;b[t>>1]=-64;P=b[s>>1]|0;Q=f+68|0;b[Q>>1]=P<<6;if(P<<16>>16==0){i=g;return}P=f+4728|0;R=w+12|0;w=(y|0)==0;S=f+188|0;T=S;U=f+90|0;V=f+88|0;W=f+62|0;X=f+60|0;Y=f+212|0;Z=S;S=f+192|0;_=f+204|0;$=f+196|0;aa=f+200|0;ca=f+213|0;da=n;ea=m;fa=n;ga=m|0;ha=m+4|0;ia=ha|0;ja=m+8|0;ka=ja|0;la=fa+3|0;ma=fa+2|0;na=fa+1|0;oa=ha;pa=ha+2|0;ha=f+66|0;qa=f+70|0;ra=ja;sa=ja+2|0;ja=f+2334|0;ta=f+2353|0;ua=m+12|0;m=f+214|0;va=f+108|0;wa=f+112|0;xa=f+211|0;ya=f+208|0;za=y+12|0;y=f+76|0;Aa=f+12|0;Ba=f+184|0;Ca=q+(h*1536|0)+832|0;Da=q+(h*1536|0)+768|0;Ea=A+(z*20|0)|0;Fa=A+(z*20|0)+4|0;Ga=A+(z*20|0)+16|0;Ha=A+(z*20|0)+8|0;Ia=A+(z*20|0)+12|0;z=f+4736|0;A=q+(h*1536|0)|0;Ja=f+4732|0;Ka=j;La=k;Ma=(r|0)!=0;Na=f+61|0;Oa=q+(h*1536|0)+836|0;Pa=f+180|0;Qa=f+99|0;Ra=Ma?5:6;Sa=Ma?0:4;Ta=Ma?2:7;Ua=Ma?2:8;Va=Ma?3:1;Wa=(r|0)==0;Xa=f+4740|0;Ya=f+4744|0;Za=l+12|0;_a=l+4|0;$a=l+3|0;ab=l+11|0;bb=l+19|0;cb=l+27|0;db=l+35|0;eb=Za;fb=l+20|0;gb=l+28|0;hb=l+36|0;l=q+(h*1536|0)+800|0;ib=f+80|0;jb=f+16|0;kb=f+4752|0;lb=f+4748|0;mb=(v|0)!=1;nb=(v-1|0)==(h|0);v=f+84|0;ob=f+20|0;pb=q+(h*1536|0)+1520|0;qb=f+100|0;rb=f+164|0;sb=f+101|0;tb=f+89|0;ub=O;O=(D|3)+16>>4;vb=f+5240|0;wb=f+63|0;xb=(H|3)+8>>3;yb=f+5276|0;zb=f+4724|0;Ab=q+(h*1536|0)+848|0;Bb=f+5312|0;f=D|8;Cb=(D|11)+8>>4;Db=H|4;Eb=(H|7)+4>>3;Fb=u;u=0;Gb=N;N=F;F=K;K=M;while(1){M=u<<2;Hb=M&12;Ib=c[E>>2]|0;Jb=N+((ba(Ib,Hb)|0)+64)|0;Xe[c[P>>2]&4095](Jb,Ib,4);Ib=u&7;Jb=F+((ba(c[I>>2]|0,Ib)|0)+64)|0;Xe[c[P>>2]&4095](Jb,K-F|0,2);do{if((c[C>>2]|0)==0){Jb=(c[(c[R>>2]|0)+4>>2]|0)+Fb|0;do{if(w){Kb=0}else{Lb=c[za>>2]|0;if((Lb|0)==0){Kb=0;break}Kb=(c[Lb+4>>2]|0)+Fb|0}}while(0);do{if((a[U]|0)==0){if((a[V]|0)==0){Mb=a[Jb]|0;break}else{Lb=a[(Kb|0)==0?Jb:Kb]|0;a[Jb]=Lb;Mb=Lb;break}}else{Lb=a[ya]|0;Nb=c[Z>>2]|0;Ob=d[1086680+Nb|0]|0;Pb=c[S>>2]|0;Qb=c[_>>2]|0;Rb=Nb<<Ob;c[Z>>2]=Rb;Nb=Qb<<Ob;Qb=Pb+Ob|0;do{if((Qb|0)>-1){Ob=c[$>>2]|0;if(!(Ob>>>0<(c[aa>>2]|0)>>>0)){Sb=Nb;Tb=Qb;break}c[$>>2]=Ob+2;Pb=Ob;Sb=((de((d[Pb]|d[Pb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Nb;Tb=Qb-16|0}else{Sb=Nb;Tb=Qb}}while(0);c[S>>2]=Tb;Qb=((ba(Rb-1|0,Lb&255)|0)>>8)+1|0;Nb=Qb<<16;Pb=Sb>>>0>=Nb>>>0;Ob=Pb&1;Ub=Pb?Rb-Qb|0:Qb;c[Z>>2]=Ub;Qb=Sb-(Pb?Nb:0)|0;c[_>>2]=Qb;Nb=a[(Pb?2:1)+(p+208)|0]|0;Pb=d[1086680+Ub|0]|0;Vb=Ub<<Pb;c[Z>>2]=Vb;Ub=Qb<<Pb;Qb=Pb+Tb|0;do{if((Qb|0)>-1){Pb=c[$>>2]|0;if(!(Pb>>>0<(c[aa>>2]|0)>>>0)){Wb=Ub;Xb=Qb;break}c[$>>2]=Pb+2;Yb=Pb;Wb=((de((d[Yb]|d[Yb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Ub;Xb=Qb-16|0}else{Wb=Ub;Xb=Qb}}while(0);c[S>>2]=Xb;Qb=((ba(Vb-1|0,Nb&255)|0)>>8)+1|0;Ub=Qb<<16;Rb=Wb>>>0>=Ub>>>0;c[Z>>2]=Rb?Vb-Qb|0:Qb;c[_>>2]=Wb-(Rb?Ub:0);Ub=Rb&1|Ob<<1;a[Jb]=Ub;Mb=Ub}}while(0);a[Gb+5|0]=Mb;if((a[W]|0)==0){Zb=0}else{Jb=a[xa]|0;Ub=c[Z>>2]|0;Rb=d[1086680+Ub|0]|0;Qb=c[S>>2]|0;Lb=c[_>>2]|0;Yb=Ub<<Rb;c[Z>>2]=Yb;Ub=Lb<<Rb;Lb=Qb+Rb|0;do{if((Lb|0)>-1){Rb=c[$>>2]|0;if(!(Rb>>>0<(c[aa>>2]|0)>>>0)){_b=Ub;$b=Lb;break}c[$>>2]=Rb+2;Qb=Rb;_b=((de((d[Qb]|d[Qb+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Ub;$b=Lb-16|0}else{_b=Ub;$b=Lb}}while(0);c[S>>2]=$b;Lb=((ba(Yb-1|0,Jb&255)|0)>>8)+1|0;Ub=Lb<<16;Qb=_b>>>0>=Ub>>>0;c[Z>>2]=Qb?Yb-Lb|0:Lb;c[_>>2]=_b-(Qb?Ub:0);Zb=Qb&1}a[Gb|0]=Zb;if((a[X]|0)!=0){Qb=0;Ub=c[Z>>2]|0;Lb=c[S>>2]|0;Rb=c[_>>2]|0;while(1){Pb=a[126080+Qb|0]|0;ac=d[1086680+Ub|0]|0;bc=Ub<<ac;c[Z>>2]=bc;cc=Rb<<ac;dc=ac+Lb|0;do{if((dc|0)>-1){ac=c[$>>2]|0;if(!(ac>>>0<(c[aa>>2]|0)>>>0)){ec=cc;fc=dc;break}c[$>>2]=ac+2;gc=ac;ec=((de((d[gc]|d[gc+1|0]<<8)<<16>>16|0)|0)&65535)<<dc|cc;fc=dc-16|0}else{ec=cc;fc=dc}}while(0);c[S>>2]=fc;dc=((ba(bc-1|0,Pb&255)|0)>>8)+1|0;cc=dc<<16;Ob=ec>>>0>=cc>>>0;Vb=Ob?bc-dc|0:dc;c[Z>>2]=Vb;dc=ec-(Ob?cc:0)|0;c[_>>2]=dc;cc=a[(Ob&1)+(126064+(Qb<<1))|0]|0;hc=cc<<24>>24;if(cc<<24>>24>0){Qb=hc;Ub=Vb;Lb=fc;Rb=dc}else{break}}Rb=-hc|0;a[Gb+1|0]=Rb;Lb=Rb&255;if((Lb|0)==4){Rb=c[va>>2]|0;Ub=0;Qb=Gb+6|0;while(1){Yb=p+112+Ub|0;Jb=0;dc=Qb;Vb=a[Yb]|0;while(1){cc=Vb&255;Ob=Rb+(Jb+M)|0;Nb=d[Ob]|0;gc=0;ac=c[Z>>2]|0;ic=c[S>>2]|0;jc=c[_>>2]|0;while(1){kc=a[125136+(Nb*90|0)+(cc*9|0)+gc|0]|0;lc=d[1086680+ac|0]|0;mc=ac<<lc;c[Z>>2]=mc;nc=jc<<lc;oc=lc+ic|0;do{if((oc|0)>-1){lc=c[$>>2]|0;if(!(lc>>>0<(c[aa>>2]|0)>>>0)){pc=nc;qc=oc;break}c[$>>2]=lc+2;rc=lc;pc=((de((d[rc]|d[rc+1|0]<<8)<<16>>16|0)|0)&65535)<<oc|nc;qc=oc-16|0}else{pc=nc;qc=oc}}while(0);c[S>>2]=qc;oc=((ba(mc-1|0,kc&255)|0)>>8)+1|0;nc=oc<<16;rc=pc>>>0>=nc>>>0;lc=rc?mc-oc|0:oc;c[Z>>2]=lc;oc=pc-(rc?nc:0)|0;c[_>>2]=oc;sc=a[(rc&1)+(125112+(gc<<1))|0]|0;if(sc<<24>>24>0){gc=sc<<24>>24;ac=lc;ic=qc;jc=oc}else{break}}jc=-sc&255;a[dc]=jc;a[Ob]=jc;a[Yb]=jc;ic=Jb+1|0;if((ic|0)<4){Jb=ic;dc=dc+1|0;Vb=jc}else{break}}Vb=Ub+1|0;if((Vb|0)<4){Ub=Vb;Qb=Qb+4|0}else{break}}}else{Qb=ba(d[126056+Lb|0]|0,16843009)|0;if((c[C>>2]|0)==0){c[(c[va>>2]|0)+M>>2]=Qb}else{c[Gb+22>>2]=Qb}c[wa>>2]=Qb}Qb=0;Ub=c[Z>>2]|0;Rb=c[S>>2]|0;Vb=c[_>>2]|0;while(1){dc=a[125096+Qb|0]|0;Jb=d[1086680+Ub|0]|0;Yb=Ub<<Jb;c[Z>>2]=Yb;bc=Vb<<Jb;Pb=Jb+Rb|0;do{if((Pb|0)>-1){Jb=c[$>>2]|0;if(!(Jb>>>0<(c[aa>>2]|0)>>>0)){tc=bc;uc=Pb;break}c[$>>2]=Jb+2;jc=Jb;tc=((de((d[jc]|d[jc+1|0]<<8)<<16>>16|0)|0)&65535)<<Pb|bc;uc=Pb-16|0}else{tc=bc;uc=Pb}}while(0);c[S>>2]=uc;Pb=((ba(Yb-1|0,dc&255)|0)>>8)+1|0;bc=Pb<<16;jc=tc>>>0>=bc>>>0;Jb=jc?Yb-Pb|0:Pb;c[Z>>2]=Jb;Pb=tc-(jc?bc:0)|0;c[_>>2]=Pb;vc=a[(jc&1)+(125088+(Qb<<1))|0]|0;if(vc<<24>>24>0){Qb=vc<<24>>24;Ub=Jb;Rb=uc;Vb=Pb}else{break}}a[Gb+4|0]=-vc;a[Gb+2|0]=0;break}Vb=d[Y]|0;Rb=c[Z>>2]|0;Ub=d[1086680+Rb|0]|0;Qb=c[S>>2]|0;Lb=c[_>>2]|0;Pb=Rb<<Ub;c[Z>>2]=Pb;Rb=Lb<<Ub;Lb=Qb+Ub|0;do{if((Lb|0)>-1){Ub=c[$>>2]|0;if(!(Ub>>>0<(c[aa>>2]|0)>>>0)){wc=Rb;xc=Lb;break}c[$>>2]=Ub+2;Qb=Ub;wc=((de((d[Qb]|d[Qb+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Rb;xc=Lb-16|0}else{wc=Rb;xc=Lb}}while(0);c[S>>2]=xc;Lb=((ba(Pb-1|0,Vb)|0)>>8)+1|0;Rb=Lb<<16;if(wc>>>0<Rb>>>0){c[Z>>2]=Lb;c[_>>2]=wc;Qb=0;Ub=Lb;Jb=xc;jc=wc;while(1){bc=a[p+215+Qb|0]|0;ic=d[1086680+Ub|0]|0;ac=Ub<<ic;c[Z>>2]=ac;gc=jc<<ic;cc=ic+Jb|0;do{if((cc|0)>-1){ic=c[$>>2]|0;if(!(ic>>>0<(c[aa>>2]|0)>>>0)){yc=gc;zc=cc;break}c[$>>2]=ic+2;Nb=ic;yc=((de((d[Nb]|d[Nb+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|gc;zc=cc-16|0}else{yc=gc;zc=cc}}while(0);c[S>>2]=zc;cc=((ba(ac-1|0,bc&255)|0)>>8)+1|0;gc=cc<<16;Yb=yc>>>0>=gc>>>0;dc=Yb?ac-cc|0:cc;c[Z>>2]=dc;cc=yc-(Yb?gc:0)|0;c[_>>2]=cc;gc=a[(Yb&1)+(126072+(Qb<<1))|0]|0;Ac=gc<<24>>24;if(gc<<24>>24>0){Qb=Ac;Ub=dc;Jb=zc;jc=cc}else{break}}jc=-Ac|0;a[Gb+1|0]=jc;if((jc&255|0)==4){jc=0;do{Jb=0;Ub=c[Z>>2]|0;Qb=c[S>>2]|0;Vb=c[_>>2]|0;while(1){cc=a[126040+Jb|0]|0;dc=d[1086680+Ub|0]|0;gc=Ub<<dc;c[Z>>2]=gc;Yb=Vb<<dc;Nb=dc+Qb|0;do{if((Nb|0)>-1){dc=c[$>>2]|0;if(!(dc>>>0<(c[aa>>2]|0)>>>0)){Bc=Yb;Cc=Nb;break}c[$>>2]=dc+2;ic=dc;Bc=((de((d[ic]|d[ic+1|0]<<8)<<16>>16|0)|0)&65535)<<Nb|Yb;Cc=Nb-16|0}else{Bc=Yb;Cc=Nb}}while(0);c[S>>2]=Cc;Nb=((ba(gc-1|0,cc&255)|0)>>8)+1|0;Yb=Nb<<16;Ob=Bc>>>0>=Yb>>>0;ic=Ob?gc-Nb|0:Nb;c[Z>>2]=ic;Nb=Bc-(Ob?Yb:0)|0;c[_>>2]=Nb;Dc=a[(Ob&1)+(125112+(Jb<<1))|0]|0;if(Dc<<24>>24>0){Jb=Dc<<24>>24;Ub=ic;Qb=Cc;Vb=Nb}else{break}}a[Gb+6+jc|0]=-Dc;jc=jc+1|0;}while((jc|0)<16)}jc=0;Vb=c[Z>>2]|0;Qb=c[S>>2]|0;Ub=c[_>>2]|0;while(1){Jb=a[p+219+jc|0]|0;ac=d[1086680+Vb|0]|0;bc=Vb<<ac;c[Z>>2]=bc;Nb=Ub<<ac;ic=ac+Qb|0;do{if((ic|0)>-1){ac=c[$>>2]|0;if(!(ac>>>0<(c[aa>>2]|0)>>>0)){Ec=Nb;Fc=ic;break}c[$>>2]=ac+2;Ob=ac;Ec=((de((d[Ob]|d[Ob+1|0]<<8)<<16>>16|0)|0)&65535)<<ic|Nb;Fc=ic-16|0}else{Ec=Nb;Fc=ic}}while(0);c[S>>2]=Fc;ic=((ba(bc-1|0,Jb&255)|0)>>8)+1|0;Nb=ic<<16;Ob=Ec>>>0>=Nb>>>0;ac=Ob?bc-ic|0:ic;c[Z>>2]=ac;ic=Ec-(Ob?Nb:0)|0;c[_>>2]=ic;Gc=a[(Ob&1)+(125088+(jc<<1))|0]|0;if(Gc<<24>>24>0){jc=Gc<<24>>24;Vb=ac;Qb=Fc;Ub=ic}else{break}}a[Gb+4|0]=-Gc;a[Gb+2|0]=0;a[Gb+3|0]=4;c[Gb+32>>2]=0;break}Ub=Pb-Lb|0;Qb=wc-Rb|0;c[_>>2]=Qb;Vb=d[ca]|0;jc=d[1086680+Ub|0]|0;ic=Ub<<jc;c[Z>>2]=ic;Ub=Qb<<jc;Qb=jc+xc|0;do{if((Qb|0)>-1){jc=c[$>>2]|0;if(!(jc>>>0<(c[aa>>2]|0)>>>0)){Hc=Ub;Ic=Qb;break}c[$>>2]=jc+2;ac=jc;Hc=((de((d[ac]|d[ac+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Ub;Ic=Qb-16|0}else{Hc=Ub;Ic=Qb}}while(0);c[S>>2]=Ic;Qb=((ba(ic-1|0,Vb)|0)>>8)+1|0;Ub=Qb<<16;if(Hc>>>0<Ub>>>0){c[Z>>2]=Qb;c[_>>2]=Hc;a[Gb+2|0]=1;Jc=0}else{Rb=ic-Qb|0;Qb=Hc-Ub|0;c[_>>2]=Qb;Ub=a[m]|0;Lb=d[1086680+Rb|0]|0;Pb=Rb<<Lb;c[Z>>2]=Pb;Rb=Qb<<Lb;Qb=Lb+Ic|0;do{if((Qb|0)>-1){Lb=c[$>>2]|0;if(!(Lb>>>0<(c[aa>>2]|0)>>>0)){Kc=Rb;Lc=Qb;break}c[$>>2]=Lb+2;ac=Lb;Kc=((de((d[ac]|d[ac+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Rb;Lc=Qb-16|0}else{Kc=Rb;Lc=Qb}}while(0);c[S>>2]=Lc;Qb=((ba(Pb-1|0,Ub&255)|0)>>8)+1|0;Rb=Qb<<16;ic=Kc>>>0>=Rb>>>0;c[Z>>2]=ic?Pb-Qb|0:Qb;c[_>>2]=Kc-(ic?Rb:0);Rb=ic?3:2;a[Gb+2|0]=Rb;Jc=(Rb&255)-1|0}Rb=p+76+(Jc<<2)|0;c[Rb>>2]=(c[Rb>>2]|0)+1;Rb=a[(d[Gb+2|0]|0)+(p+72)|0]|0;c[n>>2]=0;c[ga>>2]=0;c[ia>>2]=0;c[ka>>2]=0;ic=a[Gb+194|0]|0;Qb=ic&255;do{if(ic<<24>>24==0){Mc=0;Nc=2}else{Vb=c[Gb+220>>2]|0;if((Vb|0)==0){a[da]=2;Mc=0;Nc=4;break}if(Rb<<24>>24==(a[p+72+Qb|0]|0)){Oc=Vb}else{ac=~Vb;Oc=(ac&2147450879)+65537^ac&-2147450880}c[ia>>2]=Oc;a[na]=2;Mc=1;Nc=2}}while(0);Qb=a[Gb-96+2|0]|0;ic=Qb&255;do{if(Qb<<24>>24==0){Pc=Mc}else{Pb=c[Gb-96+28>>2]|0;if((Pb|0)==0){a[da]=Nc;Pc=Mc;break}if(Rb<<24>>24==(a[p+72+ic|0]|0)){Qc=Pb}else{Ub=~Pb;Qc=(Ub&2147450879)+65537^Ub&-2147450880}if((Qc|0)==(c[ea+(Mc<<2)>>2]|0)){Rc=Mc}else{Ub=Mc+1|0;c[ea+(Ub<<2)>>2]=Qc;Rc=Ub}Ub=fa+Rc|0;a[Ub]=(a[Ub]|0)+2;Pc=Rc}}while(0);ic=a[Gb+98|0]|0;Qb=ic&255;do{if(!(ic<<24>>24==0)){Ub=c[Gb+124>>2]|0;if((Ub|0)==0){a[da]=(a[da]|0)+1;break}if(Rb<<24>>24==(a[p+72+Qb|0]|0)){Sc=Ub}else{Pb=~Ub;Sc=(Pb&2147450879)+65537^Pb&-2147450880}if((Sc|0)==(c[ea+(Pc<<2)>>2]|0)){Tc=Pc}else{Pb=Pc+1|0;c[ea+(Pb<<2)>>2]=Sc;Tc=Pb}Pb=fa+Tc|0;a[Pb]=(a[Pb]|0)+1}}while(0);Qb=Gb+3|0;a[Qb]=4;Rb=a[da]|0;ic=c[126168+((Rb&255)<<4)>>2]|0;Pb=c[Z>>2]|0;Ub=d[1086680+Pb|0]|0;ac=c[S>>2]|0;Vb=c[_>>2]|0;Lb=Pb<<Ub;c[Z>>2]=Lb;Pb=Vb<<Ub;Vb=ac+Ub|0;do{if((Vb|0)>-1){Ub=c[$>>2]|0;if(!(Ub>>>0<(c[aa>>2]|0)>>>0)){Uc=Pb;Vc=Vb;break}c[$>>2]=Ub+2;ac=Ub;Uc=((de((d[ac]|d[ac+1|0]<<8)<<16>>16|0)|0)&65535)<<Vb|Pb;Vc=Vb-16|0}else{Uc=Pb;Vc=Vb}}while(0);c[S>>2]=Vc;Vb=((ba(Lb-1|0,ic)|0)>>8)+1|0;Pb=Vb<<16;if(Uc>>>0<Pb>>>0){c[Z>>2]=Vb;c[_>>2]=Uc;a[Gb+1|0]=5;c[Gb+28>>2]=0;c[Gb+32>>2]=0;break}c[Z>>2]=Lb-Vb;c[_>>2]=Uc-Pb;Pb=Gb+1|0;a[Pb]=6;do{if((a[la]|0)!=0){if((c[ia>>2]|0)!=(c[ua>>2]|0)){break}a[na]=(a[na]|0)+1}}while(0);Lb=a[ma]|0;ic=a[na]|0;if((Lb&255)>>>0>(ic&255)>>>0){a[ma]=ic;a[na]=Lb;Vb=c[ka>>2]|0;c[ka>>2]=c[ia>>2];c[ia>>2]=Vb;Wc=Lb;Xc=ic}else{Wc=ic;Xc=Lb}Lb=c[126172+((Wc&255)<<4)>>2]|0;ic=c[Z>>2]|0;Vb=d[1086680+ic|0]|0;ac=c[S>>2]|0;Ub=c[_>>2]|0;jc=ic<<Vb;c[Z>>2]=jc;ic=Ub<<Vb;Ub=ac+Vb|0;do{if((Ub|0)>-1){Vb=c[$>>2]|0;if(!(Vb>>>0<(c[aa>>2]|0)>>>0)){Yc=ic;Zc=Ub;break}c[$>>2]=Vb+2;ac=Vb;Yc=((de((d[ac]|d[ac+1|0]<<8)<<16>>16|0)|0)&65535)<<Ub|ic;Zc=Ub-16|0}else{Yc=ic;Zc=Ub}}while(0);c[S>>2]=Zc;Ub=((ba(jc-1|0,Lb)|0)>>8)+1|0;ic=Ub<<16;if(Yc>>>0<ic>>>0){c[Z>>2]=Ub;c[_>>2]=Yc;ac=Gb+28|0;Vb=b[oa>>1]|0;Ob=b[t>>1]|0;Nb=b[Q>>1]|0;if(Vb<<16>>16<Ob<<16>>16){_c=Ob}else{_c=Vb<<16>>16>Nb<<16>>16?Nb:Vb}b[ac>>1]=_c;Vb=b[pa>>1]|0;Nb=b[ha>>1]|0;Ob=b[qa>>1]|0;if(Vb<<16>>16<Nb<<16>>16){$c=Nb}else{$c=Vb<<16>>16>Ob<<16>>16?Ob:Vb}b[Gb+30>>1]=$c;c[Gb+32>>2]=c[ac>>2];break}ac=jc-Ub|0;Ub=Yc-ic|0;c[_>>2]=Ub;ic=c[126176+((Xc&255)<<4)>>2]|0;Vb=d[1086680+ac|0]|0;Ob=ac<<Vb;c[Z>>2]=Ob;ac=Ub<<Vb;Ub=Vb+Zc|0;do{if((Ub|0)>-1){Vb=c[$>>2]|0;if(!(Vb>>>0<(c[aa>>2]|0)>>>0)){ad=ac;bd=Ub;break}c[$>>2]=Vb+2;Nb=Vb;ad=((de((d[Nb]|d[Nb+1|0]<<8)<<16>>16|0)|0)&65535)<<Ub|ac;bd=Ub-16|0}else{ad=ac;bd=Ub}}while(0);c[S>>2]=bd;Ub=((ba(Ob-1|0,ic)|0)>>8)+1|0;ac=Ub<<16;if(ad>>>0<ac>>>0){c[Z>>2]=Ub;c[_>>2]=ad;jc=Gb+28|0;Lb=b[ra>>1]|0;Nb=b[t>>1]|0;Vb=b[Q>>1]|0;if(Lb<<16>>16<Nb<<16>>16){cd=Nb}else{cd=Lb<<16>>16>Vb<<16>>16?Vb:Lb}b[jc>>1]=cd;Lb=b[sa>>1]|0;Vb=b[ha>>1]|0;Nb=b[qa>>1]|0;if(Lb<<16>>16<Vb<<16>>16){dd=Vb}else{dd=Lb<<16>>16>Nb<<16>>16?Nb:Lb}b[Gb+30>>1]=dd;c[Gb+32>>2]=c[jc>>2];break}jc=Ob-Ub|0;c[Z>>2]=jc;Ub=ad-ac|0;c[_>>2]=Ub;ac=Gb+28|0;Lb=(Wc&255)>>>0>=(Rb&255)>>>0|0;Nb=b[ea+(Lb<<2)>>1]|0;Vb=b[t>>1]|0;Yb=b[Q>>1]|0;if(Nb<<16>>16<Vb<<16>>16){ed=Vb}else{ed=Nb<<16>>16>Yb<<16>>16?Yb:Nb}Nb=ac|0;b[Nb>>1]=ed;Yb=b[ea+(Lb<<2)+2>>1]|0;Lb=b[ha>>1]|0;Vb=b[qa>>1]|0;if(Yb<<16>>16<Lb<<16>>16){fd=Lb}else{fd=Yb<<16>>16>Vb<<16>>16?Vb:Yb}Yb=Gb+30|0;b[Yb>>1]=fd;Vb=(((a[Gb+193|0]|0)==7)+((a[Gb-96+1|0]|0)==7)&255)<<1|(a[Gb+97|0]|0)==7;a[la]=Vb;Lb=c[126180+((Vb&255)<<4)>>2]|0;Vb=d[1086680+jc|0]|0;dc=jc<<Vb;c[Z>>2]=dc;jc=Ub<<Vb;Ub=Vb+bd|0;do{if((Ub|0)>-1){Vb=c[$>>2]|0;if(!(Vb>>>0<(c[aa>>2]|0)>>>0)){gd=jc;hd=Ub;break}c[$>>2]=Vb+2;oc=Vb;gd=((de((d[oc]|d[oc+1|0]<<8)<<16>>16|0)|0)&65535)<<Ub|jc;hd=Ub-16|0}else{gd=jc;hd=Ub}}while(0);c[S>>2]=hd;Ub=((ba(dc-1|0,Lb)|0)>>8)+1|0;jc=Ub<<16;if(gd>>>0<jc>>>0){c[Z>>2]=Ub;c[_>>2]=gd;Rb=B5a(T,ja)|0;b[Yb>>1]=(e[Yb>>1]|0)+Rb;Rb=B5a(T,ta)|0;b[Nb>>1]=(e[Nb>>1]|0)+Rb;c[Gb+32>>2]=c[ac>>2];break}c[Z>>2]=dc-Ub;c[_>>2]=gd-jc;a[Pb]=7;jc=d[Gb-96+3|0]|0;Ub=d[Gb+195|0]|0;Rb=c[Z>>2]|0;Ob=d[1086680+Rb|0]|0;ic=c[S>>2]|0;oc=c[_>>2]|0;Vb=Rb<<Ob;c[Z>>2]=Vb;Rb=oc<<Ob;oc=ic+Ob|0;do{if((oc|0)>-1){Ob=c[$>>2]|0;if(!(Ob>>>0<(c[aa>>2]|0)>>>0)){id=Rb;jd=oc;break}c[$>>2]=Ob+2;ic=Ob;id=((de((d[ic]|d[ic+1|0]<<8)<<16>>16|0)|0)&65535)<<oc|Rb;jd=oc-16|0}else{id=Rb;jd=oc}}while(0);c[S>>2]=jd;oc=((Vb*110|0)-110>>8)+1|0;Rb=oc<<16;do{if(id>>>0<Rb>>>0){c[Z>>2]=oc;c[_>>2]=id;kd=3}else{Pb=Vb-oc|0;dc=id-Rb|0;c[_>>2]=dc;Nb=d[1086680+Pb|0]|0;Lb=Pb<<Nb;c[Z>>2]=Lb;Pb=dc<<Nb;dc=Nb+jd|0;do{if((dc|0)>-1){Nb=c[$>>2]|0;if(!(Nb>>>0<(c[aa>>2]|0)>>>0)){ld=Pb;md=dc;break}c[$>>2]=Nb+2;ic=Nb;ld=((de((d[ic]|d[ic+1|0]<<8)<<16>>16|0)|0)&65535)<<dc|Pb;md=dc-16|0}else{ld=Pb;md=dc}}while(0);c[S>>2]=md;dc=((Lb*111|0)-111>>8)+1|0;Pb=dc<<16;if(ld>>>0<Pb>>>0){c[Z>>2]=dc;c[_>>2]=ld;kd=2;break}bc=Lb-dc|0;dc=ld-Pb|0;c[_>>2]=dc;Pb=d[1086680+bc|0]|0;Jb=bc<<Pb;c[Z>>2]=Jb;bc=dc<<Pb;dc=Pb+md|0;do{if((dc|0)>-1){Pb=c[$>>2]|0;if(!(Pb>>>0<(c[aa>>2]|0)>>>0)){nd=bc;od=dc;break}c[$>>2]=Pb+2;ic=Pb;nd=((de((d[ic]|d[ic+1|0]<<8)<<16>>16|0)|0)&65535)<<dc|bc;od=dc-16|0}else{nd=bc;od=dc}}while(0);c[S>>2]=od;dc=((Jb*150|0)-150>>8)+1|0;bc=dc<<16;Lb=nd>>>0>=bc>>>0;c[Z>>2]=Lb?Jb-dc|0:dc;c[_>>2]=nd-(Lb?bc:0);kd=Lb&1}}while(0);Rb=d[126344+kd|0]|0;a[Qb]=kd;oc=Gb+28|0;Vb=0;do{Lb=a[126352+(kd<<4)+Vb|0]|0;bc=Lb&255;if((bc&3|0)==0){pd=Gb-96+32+(d[bc+3+(126264+(jc<<4))|0]<<2)|0}else{pd=Gb+32+(d[bc-1+(126264+(kd<<4))|0]<<2)|0}dc=c[pd>>2]|0;if((Lb&255)>>>0<4>>>0){qd=Gb+224+(d[bc+12+(126264+(Ub<<4))|0]<<2)|0}else{qd=Gb+32+(d[bc-4+(126264+(kd<<4))|0]<<2)|0}bc=c[qd>>2]|0;do{if((dc|0)==(bc|0)){rd=125072+((4-((dc|0)!=0)|0)*3|0)|0}else{if((bc|0)==0){rd=125078;break}rd=125072+(((dc|0)==0|0)*3|0)|0}}while(0);Jb=d[rd]|0;Lb=c[Z>>2]|0;ic=d[1086680+Lb|0]|0;Pb=c[S>>2]|0;Nb=c[_>>2]|0;Ob=Lb<<ic;c[Z>>2]=Ob;Lb=Nb<<ic;Nb=Pb+ic|0;do{if((Nb|0)>-1){ic=c[$>>2]|0;if(!(ic>>>0<(c[aa>>2]|0)>>>0)){sd=Lb;td=Nb;break}c[$>>2]=ic+2;Pb=ic;sd=((de((d[Pb]|d[Pb+1|0]<<8)<<16>>16|0)|0)&65535)<<Nb|Lb;td=Nb-16|0}else{sd=Lb;td=Nb}}while(0);c[S>>2]=td;Nb=((ba(Ob-1|0,Jb)|0)>>8)+1|0;Lb=Nb<<16;do{if(sd>>>0<Lb>>>0){c[Z>>2]=Nb;c[_>>2]=sd;c[Gb+32+(Vb<<2)>>2]=dc}else{Pb=Ob-Nb|0;c[Z>>2]=Pb;ic=sd-Lb|0;c[_>>2]=ic;lc=d[rd+1|0]|0;rc=d[1086680+Pb|0]|0;nc=Pb<<rc;c[Z>>2]=nc;Pb=ic<<rc;ic=rc+td|0;do{if((ic|0)>-1){rc=c[$>>2]|0;if(!(rc>>>0<(c[aa>>2]|0)>>>0)){ud=Pb;vd=ic;break}c[$>>2]=rc+2;wd=rc;ud=((de((d[wd]|d[wd+1|0]<<8)<<16>>16|0)|0)&65535)<<ic|Pb;vd=ic-16|0}else{ud=Pb;vd=ic}}while(0);c[S>>2]=vd;ic=((ba(nc-1|0,lc)|0)>>8)+1|0;Pb=ic<<16;if(ud>>>0<Pb>>>0){c[Z>>2]=ic;c[_>>2]=ud;c[Gb+32+(Vb<<2)>>2]=bc;break}gc=nc-ic|0;c[Z>>2]=gc;ic=ud-Pb|0;c[_>>2]=ic;Pb=d[rd+2|0]|0;cc=d[1086680+gc|0]|0;wd=gc<<cc;c[Z>>2]=wd;gc=ic<<cc;ic=cc+vd|0;do{if((ic|0)>-1){cc=c[$>>2]|0;if(!(cc>>>0<(c[aa>>2]|0)>>>0)){xd=gc;yd=ic;break}c[$>>2]=cc+2;rc=cc;xd=((de((d[rc]|d[rc+1|0]<<8)<<16>>16|0)|0)&65535)<<ic|gc;yd=ic-16|0}else{xd=gc;yd=ic}}while(0);c[S>>2]=yd;ic=((ba(wd-1|0,Pb)|0)>>8)+1|0;gc=ic<<16;if(xd>>>0<gc>>>0){c[Z>>2]=ic;c[_>>2]=xd;c[Gb+32+(Vb<<2)>>2]=0;break}else{c[Z>>2]=wd-ic;c[_>>2]=xd-gc;gc=e[Yb>>1]|0;b[Gb+32+(Vb<<2)+2>>1]=gc+(B5a(T,ja)|0);gc=e[oc>>1]|0;b[Gb+32+(Vb<<2)>>1]=gc+(B5a(T,ta)|0);break}}}while(0);Vb=Vb+1|0;}while((Vb|0)<(Rb|0));c[ac>>2]=c[Gb+32+(Rb-1<<2)>>2]}}while(0);M=Fb>>5;if((c[y>>2]|0)>(M|0)){Vb=(b[Gb+28>>1]>>2)+(u<<4|8)|0;oc=(b[Gb+30>>1]>>2)+D|0;Yb=c[c[Aa>>2]>>2]|0;Ub=c[E>>2]|0;jc=Vb+64+(ba(oc+Hb|0,Ub)|0)|0;Xe[c[P>>2]&4095]((c[Yb>>2]|0)+jc|0,Ub,4);Ub=(Vb>>1)+64+(ba(c[I>>2]|0,(oc>>1)+Ib|0)|0)|0;oc=c[Yb+4>>2]|0;Xe[c[P>>2]&4095](oc+Ub|0,(c[Yb+8>>2]|0)-oc|0,2)}oc=Gb|0;do{if((a[oc]|0)==0){Yb=c[Ba>>2]|0;Ub=d[Gb+5|0]|0;Vb=Gb+1|0;jc=a[Vb]|0;do{if((jc<<24>>24|0)==4|(jc<<24>>24|0)==7){zd=0;Ad=0;Bd=3;Cd=0}else{Qb=Yb+(u*9|0)+8|0;bc=p+750+(((d[Ca]|0)+(d[Qb]|0)|0)*11|0)|0;Lb=d[bc]|0;Nb=c[Ea>>2]|0;Ob=d[1086680+Nb|0]|0;dc=c[Fa>>2]|0;Jb=c[Ga>>2]|0;gc=Nb<<Ob;c[Ea>>2]=gc;Nb=Jb<<Ob;Jb=dc+Ob|0;do{if((Jb|0)>-1){Ob=c[Ha>>2]|0;if(!(Ob>>>0<(c[Ia>>2]|0)>>>0)){Dd=Nb;Ed=Jb;break}c[Ha>>2]=Ob+2;dc=Ob;Dd=((de((d[dc]|d[dc+1|0]<<8)<<16>>16|0)|0)&65535)<<Jb|Nb;Ed=Jb-16|0}else{Dd=Nb;Ed=Jb}}while(0);c[Fa>>2]=Ed;Jb=((ba(gc-1|0,Lb)|0)>>8)+1|0;Nb=Jb<<16;if(Dd>>>0<Nb>>>0){c[Ea>>2]=Jb;c[Ga>>2]=Dd;a[Qb]=0;a[Ca]=0;zd=0;Ad=0;Bd=0;Cd=1;break}dc=gc-Jb|0;c[Ea>>2]=dc;Jb=Dd-Nb|0;c[Ga>>2]=Jb;Nb=c[Ia>>2]|0;Ob=0;ic=bc;nc=dc;dc=Ed;lc=c[Ha>>2]|0;rc=Jb;while(1){Jb=d[ic+1|0]|0;cc=d[1086680+nc|0]|0;Fd=nc<<cc;Gd=rc<<cc;Hd=cc+dc|0;if((Hd|0)>-1&lc>>>0<Nb>>>0){cc=lc;Id=((de((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Gd;Jd=Hd-16|0;Kd=lc+2|0}else{Id=Gd;Jd=Hd;Kd=lc}Hd=((ba(Fd-1|0,Jb)|0)>>8)+1|0;Jb=Hd<<16;if(Id>>>0<Jb>>>0){Gd=Ob+1|0;if((Gd|0)==16){Ld=16;Md=Hd;Nd=Jd;Od=Kd;Pd=Id;break}Ob=Gd;ic=p+750+(Gd*33|0)|0;nc=Hd;dc=Jd;lc=Kd;rc=Id;continue}Gd=Fd-Hd|0;Hd=d[ic+2|0]|0;Fd=d[1086680+Gd|0]|0;cc=Gd<<Fd;Gd=Id-Jb<<Fd;Jb=Fd+Jd|0;if((Jb|0)>-1&Kd>>>0<Nb>>>0){Fd=Kd;Qd=((de((d[Fd]|d[Fd+1|0]<<8)<<16>>16|0)|0)&65535)<<Jb|Gd;Rd=Jb-16|0;Sd=Kd+2|0}else{Qd=Gd;Rd=Jb;Sd=Kd}Jb=((ba(cc-1|0,Hd)|0)>>8)+1|0;Hd=Jb<<16;if(Qd>>>0<Hd>>>0){Td=p+750+((Ob+1|0)*33|0)+11|0;Ud=1;Vd=Jb;Wd=Rd;Xd=Sd;Yd=Qd}else{Gd=cc-Jb|0;Jb=d[ic+3|0]|0;cc=d[1086680+Gd|0]|0;Fd=Gd<<cc;Gd=Qd-Hd<<cc;Hd=cc+Rd|0;if((Hd|0)>-1&Sd>>>0<Nb>>>0){cc=Sd;Zd=((de((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Gd;_d=Hd-16|0;$d=Sd+2|0}else{Zd=Gd;_d=Hd;$d=Sd}Hd=((ba(Fd-1|0,Jb)|0)>>8)+1|0;Jb=Hd<<16;do{if(Zd>>>0<Jb>>>0){Gd=d[ic+4|0]|0;cc=d[1086680+Hd|0]|0;ae=Hd<<cc;be=Zd<<cc;ce=cc+_d|0;if((ce|0)>-1&$d>>>0<Nb>>>0){cc=$d;ee=((de((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<ce|be;fe=ce-16|0;ge=$d+2|0}else{ee=be;fe=ce;ge=$d}ce=((ba(ae-1|0,Gd)|0)>>8)+1|0;Gd=ce<<16;if(ee>>>0<Gd>>>0){he=2;ie=ce;je=fe;ke=ge;le=ee;break}be=ae-ce|0;ce=a[ic+5|0]|0;ae=d[1086680+be|0]|0;cc=be<<ae;be=ee-Gd<<ae;Gd=ae+fe|0;if((Gd|0)>-1&ge>>>0<Nb>>>0){ae=ge;me=((de((d[ae]|d[ae+1|0]<<8)<<16>>16|0)|0)&65535)<<Gd|be;oe=Gd-16|0;pe=ge+2|0}else{me=be;oe=Gd;pe=ge}Gd=((ba(cc-1|0,ce&255)|0)>>8)+1|0;ce=Gd<<16;be=me>>>0>=ce>>>0;he=be?4:3;ie=be?cc-Gd|0:Gd;je=oe;ke=pe;le=me-(be?ce:0)|0}else{ce=Fd-Hd|0;be=d[ic+6|0]|0;Gd=d[1086680+ce|0]|0;cc=ce<<Gd;ce=Zd-Jb<<Gd;ae=Gd+_d|0;if((ae|0)>-1&$d>>>0<Nb>>>0){Gd=$d;qe=((de((d[Gd]|d[Gd+1|0]<<8)<<16>>16|0)|0)&65535)<<ae|ce;re=ae-16|0;se=$d+2|0}else{qe=ce;re=ae;se=$d}ae=((ba(cc-1|0,be)|0)>>8)+1|0;be=ae<<16;if(!(qe>>>0<be>>>0)){ce=cc-ae|0;cc=a[ic+8|0]|0;Gd=d[1086680+ce|0]|0;te=ce<<Gd;ce=qe-be<<Gd;be=Gd+re|0;if((be|0)>-1&se>>>0<Nb>>>0){Gd=se;ue=((de((d[Gd]|d[Gd+1|0]<<8)<<16>>16|0)|0)&65535)<<be|ce;ve=be-16|0;we=se+2|0}else{ue=ce;ve=be;we=se}be=((ba(te-1|0,cc&255)|0)>>8)+1|0;cc=be<<16;ce=ue>>>0>=cc>>>0;Gd=ce?te-be|0:be;be=a[ic+(ce?10:9)|0]|0;te=d[1086680+Gd|0]|0;xe=Gd<<te;Gd=ue-(ce?cc:0)<<te;cc=te+ve|0;if((cc|0)>-1&we>>>0<Nb>>>0){te=we;ye=((de((d[te]|d[te+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|Gd;ze=cc-16|0;Ae=we+2|0}else{ye=Gd;ze=cc;Ae=we}cc=((ba(xe-1|0,be&255)|0)>>8)+1|0;be=cc<<16;Gd=ye>>>0>=be>>>0;te=Gd&1|(ce&1)<<1;ce=c[1085080+(te<<2)>>2]|0;Be=0;Ce=ce;De=a[ce]|0;ce=Gd?xe-cc|0:cc;cc=ze;xe=ye-(Gd?be:0)|0;be=Ae;while(1){Gd=Ce+1|0;Ee=d[1086680+ce|0]|0;Fe=ce<<Ee;Ge=xe<<Ee;He=Ee+cc|0;if((He|0)>-1&be>>>0<Nb>>>0){Ee=be;Ie=((de((d[Ee]|d[Ee+1|0]<<8)<<16>>16|0)|0)&65535)<<He|Ge;Je=He-16|0;Le=be+2|0}else{Ie=Ge;Je=He;Le=be}He=((ba(Fe-1|0,De&255)|0)>>8)+1|0;Ge=He<<16;Ee=Ie>>>0>=Ge>>>0;Me=Ee?Fe-He|0:He;Oe=Ie-(Ee?Ge:0)|0;Pe=Ee&1|Be<<1;Ee=a[Gd]|0;if(Ee<<24>>24==0){break}else{Be=Pe;Ce=Gd;De=Ee;ce=Me;cc=Je;xe=Oe;be=Le}}he=(8<<te)+3+Pe|0;ie=Me;je=Je;ke=Le;le=Oe;break}be=d[ic+7|0]|0;xe=d[1086680+ae|0]|0;cc=ae<<xe;ce=qe<<xe;De=xe+re|0;if((De|0)>-1&se>>>0<Nb>>>0){xe=se;Qe=((de((d[xe]|d[xe+1|0]<<8)<<16>>16|0)|0)&65535)<<De|ce;Re=De-16|0;Se=se+2|0}else{Qe=ce;Re=De;Se=se}De=((ba(cc-1|0,be)|0)>>8)+1|0;be=De<<16;if(Qe>>>0<be>>>0){ce=d[1086680+De|0]|0;xe=De<<ce;Ce=Qe<<ce;Be=ce+Re|0;if((Be|0)>-1&Se>>>0<Nb>>>0){ce=Se;Te=((de((d[ce]|d[ce+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|Ce;Ue=Be-16|0;Ve=Se+2|0}else{Te=Ce;Ue=Be;Ve=Se}Be=((xe*159|0)-159>>8)+1|0;Ce=Be<<16;ce=Te>>>0>=Ce>>>0;he=ce?6:5;ie=ce?xe-Be|0:Be;je=Ue;ke=Ve;le=Te-(ce?Ce:0)|0;break}Ce=cc-De|0;De=d[1086680+Ce|0]|0;cc=Ce<<De;Ce=Qe-be<<De;be=De+Re|0;if((be|0)>-1&Se>>>0<Nb>>>0){De=Se;We=((de((d[De]|d[De+1|0]<<8)<<16>>16|0)|0)&65535)<<be|Ce;Ye=be-16|0;Ze=Se+2|0}else{We=Ce;Ye=be;Ze=Se}be=((cc*165|0)-165>>8)+1|0;Ce=be<<16;De=We>>>0>=Ce>>>0;ce=De?cc-be|0:be;be=d[1086680+ce|0]|0;cc=ce<<be;ce=We-(De?Ce:0)<<be;Ce=be+Ye|0;if((Ce|0)>-1&Ze>>>0<Nb>>>0){be=Ze;_e=((de((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Ce|ce;$e=Ce-16|0;af=Ze+2|0}else{_e=ce;$e=Ce;af=Ze}Ce=((cc*145|0)-145>>8)+1|0;ce=Ce<<16;be=_e>>>0>=ce>>>0;he=((De&1)<<1)+7+(be&1)|0;ie=be?cc-Ce|0:Ce;je=$e;ke=af;le=_e-(be?ce:0)|0}}while(0);Td=p+750+((Ob+1|0)*33|0)+22|0;Ud=he;Vd=ie;Wd=je;Xd=ke;Yd=le}Jb=d[1086680+Vd|0]|0;Hd=Vd<<Jb;Fd=Yd<<Jb;wd=Jb+Wd|0;if((wd|0)>-1&Xd>>>0<Nb>>>0){Jb=Xd;bf=((de((d[Jb]|d[Jb+1|0]<<8)<<16>>16|0)|0)&65535)<<wd|Fd;cf=wd-16|0;df=Xd+2|0}else{bf=Fd;cf=wd;df=Xd}wd=((Hd<<7)-128>>8)+1|0;Fd=wd<<16;Jb=bf>>>0>=Fd>>>0;Pb=Jb?Hd-wd|0:wd;wd=bf-(Jb?Fd:0)|0;Fd=(ba(Jb?-Ud|0:Ud,b[p+116+(Ub*12|0)+4+(((Ob|0)!=0)<<1)>>1]|0)|0)&65535;b[q+(h*1536|0)+768+(d[80+Ob|0]<<1)>>1]=Fd;Fd=Ob+1|0;if((Fd|0)>=16){Ld=Fd;Md=Pb;Nd=cf;Od=df;Pd=wd;break}Jb=d[Td]|0;Hd=d[1086680+Pb|0]|0;ce=Pb<<Hd;Pb=wd<<Hd;wd=Hd+cf|0;if((wd|0)>-1&df>>>0<Nb>>>0){Hd=df;ef=((de((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<wd|Pb;ff=wd-16|0;gf=df+2|0}else{ef=Pb;ff=wd;gf=df}wd=((ba(ce-1|0,Jb)|0)>>8)+1|0;Jb=wd<<16;if(ef>>>0<Jb>>>0){Ld=Fd;Md=wd;Nd=ff;Od=gf;Pd=ef;break}Ob=Fd;ic=Td;nc=ce-wd|0;dc=ff;lc=gf;rc=ef-Jb|0}c[Ea>>2]=Md;c[Fa>>2]=Nd;c[Ha>>2]=Od;c[Ia>>2]=Nb;c[Ga>>2]=Pd;rc=(Ld|0)!=0;lc=rc&1;a[Qb]=lc;a[Ca]=lc;if(!rc){zd=0;Ad=0;Bd=0;Cd=1;break}if((Ld|0)==1){ne[c[z>>2]&1023](A,Da);zd=1;Ad=1;Bd=0;Cd=1;break}else{ne[c[Ja>>2]&1023](A,Da);zd=1;Ad=Ld;Bd=0;Cd=1;break}}}while(0);jc=0;Rb=Ad;while(1){ac=q+(h*1536|0)+824+jc|0;rc=0;lc=Rb;do{dc=Yb+(u*9|0)+rc|0;nc=p+222+(Bd*528|0)+(Cd*33|0)+(((d[dc]|0)+(d[ac]|0)|0)*11|0)|0;ic=d[nc]|0;Ob=c[Ea>>2]|0;bc=d[1086680+Ob|0]|0;gc=c[Fa>>2]|0;Lb=c[Ga>>2]|0;Jb=Ob<<bc;c[Ea>>2]=Jb;Ob=Lb<<bc;Lb=gc+bc|0;do{if((Lb|0)>-1){bc=c[Ha>>2]|0;if(!(bc>>>0<(c[Ia>>2]|0)>>>0)){hf=Ob;jf=Lb;break}c[Ha>>2]=bc+2;gc=bc;hf=((de((d[gc]|d[gc+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Ob;jf=Lb-16|0}else{hf=Ob;jf=Lb}}while(0);c[Fa>>2]=jf;Lb=((ba(Jb-1|0,ic)|0)>>8)+1|0;Ob=Lb<<16;if(hf>>>0<Ob>>>0){c[Ea>>2]=Lb;kf=0;lf=hf}else{gc=Jb-Lb|0;c[Ea>>2]=gc;Lb=hf-Ob|0;c[Ga>>2]=Lb;Ob=c[Ia>>2]|0;bc=Cd;wd=nc;ce=gc;gc=jf;Fd=c[Ha>>2]|0;Pb=Lb;while(1){Lb=d[wd+1|0]|0;Hd=d[1086680+ce|0]|0;be=ce<<Hd;Ce=Pb<<Hd;cc=Hd+gc|0;if((cc|0)>-1&Fd>>>0<Ob>>>0){Hd=Fd;mf=((de((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|Ce;nf=cc-16|0;of=Fd+2|0}else{mf=Ce;nf=cc;of=Fd}cc=((ba(be-1|0,Lb)|0)>>8)+1|0;Lb=cc<<16;if(mf>>>0<Lb>>>0){Ce=bc+1|0;if((Ce|0)==16){pf=16;qf=cc;rf=nf;sf=of;tf=mf;break}bc=Ce;wd=p+222+(Bd*528|0)+(Ce*33|0)|0;ce=cc;gc=nf;Fd=of;Pb=mf;continue}Ce=be-cc|0;cc=d[wd+2|0]|0;be=d[1086680+Ce|0]|0;Hd=Ce<<be;Ce=mf-Lb<<be;Lb=be+nf|0;if((Lb|0)>-1&of>>>0<Ob>>>0){be=of;uf=((de((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Ce;vf=Lb-16|0;wf=of+2|0}else{uf=Ce;vf=Lb;wf=of}Lb=((ba(Hd-1|0,cc)|0)>>8)+1|0;cc=Lb<<16;if(uf>>>0<cc>>>0){xf=p+222+(Bd*528|0)+((bc+1|0)*33|0)+11|0;yf=1;zf=Lb;Af=vf;Bf=wf;Cf=uf}else{Ce=Hd-Lb|0;Lb=d[wd+3|0]|0;Hd=d[1086680+Ce|0]|0;be=Ce<<Hd;Ce=uf-cc<<Hd;cc=Hd+vf|0;if((cc|0)>-1&wf>>>0<Ob>>>0){Hd=wf;Df=((de((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|Ce;Ef=cc-16|0;Ff=wf+2|0}else{Df=Ce;Ef=cc;Ff=wf}cc=((ba(be-1|0,Lb)|0)>>8)+1|0;Lb=cc<<16;do{if(Df>>>0<Lb>>>0){Ce=d[wd+4|0]|0;Hd=d[1086680+cc|0]|0;De=cc<<Hd;Be=Df<<Hd;xe=Hd+Ef|0;if((xe|0)>-1&Ff>>>0<Ob>>>0){Hd=Ff;Gf=((de((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<xe|Be;Hf=xe-16|0;If=Ff+2|0}else{Gf=Be;Hf=xe;If=Ff}xe=((ba(De-1|0,Ce)|0)>>8)+1|0;Ce=xe<<16;if(Gf>>>0<Ce>>>0){Jf=2;Kf=xe;Lf=Hf;Mf=If;Nf=Gf;break}Be=De-xe|0;xe=a[wd+5|0]|0;De=d[1086680+Be|0]|0;Hd=Be<<De;Be=Gf-Ce<<De;Ce=De+Hf|0;if((Ce|0)>-1&If>>>0<Ob>>>0){De=If;Of=((de((d[De]|d[De+1|0]<<8)<<16>>16|0)|0)&65535)<<Ce|Be;Pf=Ce-16|0;Qf=If+2|0}else{Of=Be;Pf=Ce;Qf=If}Ce=((ba(Hd-1|0,xe&255)|0)>>8)+1|0;xe=Ce<<16;Be=Of>>>0>=xe>>>0;Jf=Be?4:3;Kf=Be?Hd-Ce|0:Ce;Lf=Pf;Mf=Qf;Nf=Of-(Be?xe:0)|0}else{xe=be-cc|0;Be=d[wd+6|0]|0;Ce=d[1086680+xe|0]|0;Hd=xe<<Ce;xe=Df-Lb<<Ce;De=Ce+Ef|0;if((De|0)>-1&Ff>>>0<Ob>>>0){Ce=Ff;Rf=((de((d[Ce]|d[Ce+1|0]<<8)<<16>>16|0)|0)&65535)<<De|xe;Sf=De-16|0;Tf=Ff+2|0}else{Rf=xe;Sf=De;Tf=Ff}De=((ba(Hd-1|0,Be)|0)>>8)+1|0;Be=De<<16;if(!(Rf>>>0<Be>>>0)){xe=Hd-De|0;Hd=a[wd+8|0]|0;Ce=d[1086680+xe|0]|0;mc=xe<<Ce;xe=Rf-Be<<Ce;Be=Ce+Sf|0;if((Be|0)>-1&Tf>>>0<Ob>>>0){Ce=Tf;Uf=((de((d[Ce]|d[Ce+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|xe;Vf=Be-16|0;Wf=Tf+2|0}else{Uf=xe;Vf=Be;Wf=Tf}Be=((ba(mc-1|0,Hd&255)|0)>>8)+1|0;Hd=Be<<16;xe=Uf>>>0>=Hd>>>0;Ce=xe?mc-Be|0:Be;Be=a[wd+(xe?10:9)|0]|0;mc=d[1086680+Ce|0]|0;kc=Ce<<mc;Ce=Uf-(xe?Hd:0)<<mc;Hd=mc+Vf|0;if((Hd|0)>-1&Wf>>>0<Ob>>>0){mc=Wf;Xf=((de((d[mc]|d[mc+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Ce;Yf=Hd-16|0;Zf=Wf+2|0}else{Xf=Ce;Yf=Hd;Zf=Wf}Hd=((ba(kc-1|0,Be&255)|0)>>8)+1|0;Be=Hd<<16;Ce=Xf>>>0>=Be>>>0;mc=Ce&1|(xe&1)<<1;xe=c[1085080+(mc<<2)>>2]|0;Ee=0;Gd=xe;Ge=a[xe]|0;xe=Ce?kc-Hd|0:Hd;Hd=Yf;kc=Xf-(Ce?Be:0)|0;Be=Zf;while(1){Ce=Gd+1|0;He=d[1086680+xe|0]|0;Fe=xe<<He;_f=kc<<He;$f=He+Hd|0;if(($f|0)>-1&Be>>>0<Ob>>>0){He=Be;ag=((de((d[He]|d[He+1|0]<<8)<<16>>16|0)|0)&65535)<<$f|_f;bg=$f-16|0;cg=Be+2|0}else{ag=_f;bg=$f;cg=Be}$f=((ba(Fe-1|0,Ge&255)|0)>>8)+1|0;_f=$f<<16;He=ag>>>0>=_f>>>0;dg=He?Fe-$f|0:$f;eg=ag-(He?_f:0)|0;fg=He&1|Ee<<1;He=a[Ce]|0;if(He<<24>>24==0){break}else{Ee=fg;Gd=Ce;Ge=He;xe=dg;Hd=bg;kc=eg;Be=cg}}Jf=(8<<mc)+3+fg|0;Kf=dg;Lf=bg;Mf=cg;Nf=eg;break}Be=d[wd+7|0]|0;kc=d[1086680+De|0]|0;Hd=De<<kc;xe=Rf<<kc;Ge=kc+Sf|0;if((Ge|0)>-1&Tf>>>0<Ob>>>0){kc=Tf;gg=((de((d[kc]|d[kc+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|xe;hg=Ge-16|0;ig=Tf+2|0}else{gg=xe;hg=Ge;ig=Tf}Ge=((ba(Hd-1|0,Be)|0)>>8)+1|0;Be=Ge<<16;if(gg>>>0<Be>>>0){xe=d[1086680+Ge|0]|0;kc=Ge<<xe;Gd=gg<<xe;Ee=xe+hg|0;if((Ee|0)>-1&ig>>>0<Ob>>>0){xe=ig;jg=((de((d[xe]|d[xe+1|0]<<8)<<16>>16|0)|0)&65535)<<Ee|Gd;kg=Ee-16|0;lg=ig+2|0}else{jg=Gd;kg=Ee;lg=ig}Ee=((kc*159|0)-159>>8)+1|0;Gd=Ee<<16;xe=jg>>>0>=Gd>>>0;Jf=xe?6:5;Kf=xe?kc-Ee|0:Ee;Lf=kg;Mf=lg;Nf=jg-(xe?Gd:0)|0;break}Gd=Hd-Ge|0;Ge=d[1086680+Gd|0]|0;Hd=Gd<<Ge;Gd=gg-Be<<Ge;Be=Ge+hg|0;if((Be|0)>-1&ig>>>0<Ob>>>0){Ge=ig;mg=((de((d[Ge]|d[Ge+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|Gd;ng=Be-16|0;og=ig+2|0}else{mg=Gd;ng=Be;og=ig}Be=((Hd*165|0)-165>>8)+1|0;Gd=Be<<16;Ge=mg>>>0>=Gd>>>0;xe=Ge?Hd-Be|0:Be;Be=d[1086680+xe|0]|0;Hd=xe<<Be;xe=mg-(Ge?Gd:0)<<Be;Gd=Be+ng|0;if((Gd|0)>-1&og>>>0<Ob>>>0){Be=og;pg=((de((d[Be]|d[Be+1|0]<<8)<<16>>16|0)|0)&65535)<<Gd|xe;qg=Gd-16|0;rg=og+2|0}else{pg=xe;qg=Gd;rg=og}Gd=((Hd*145|0)-145>>8)+1|0;xe=Gd<<16;Be=pg>>>0>=xe>>>0;Jf=((Ge&1)<<1)+7+(Be&1)|0;Kf=Be?Hd-Gd|0:Gd;Lf=qg;Mf=rg;Nf=pg-(Be?xe:0)|0}}while(0);xf=p+222+(Bd*528|0)+((bc+1|0)*33|0)+22|0;yf=Jf;zf=Kf;Af=Lf;Bf=Mf;Cf=Nf}Lb=d[1086680+zf|0]|0;cc=zf<<Lb;be=Cf<<Lb;ae=Lb+Af|0;if((ae|0)>-1&Bf>>>0<Ob>>>0){Lb=Bf;sg=((de((d[Lb]|d[Lb+1|0]<<8)<<16>>16|0)|0)&65535)<<ae|be;tg=ae-16|0;ug=Bf+2|0}else{sg=be;tg=ae;ug=Bf}ae=((cc<<7)-128>>8)+1|0;be=ae<<16;Lb=sg>>>0>=be>>>0;te=Lb?cc-ae|0:ae;ae=sg-(Lb?be:0)|0;be=(ba(Lb?-yf|0:yf,b[p+116+(Ub*12|0)+(((bc|0)!=0)<<1)>>1]|0)|0)&65535;b[q+(h*1536|0)+(jc<<7)+(rc<<5)+(d[80+bc|0]<<1)>>1]=be;be=bc+1|0;if((be|0)>=16){pf=be;qf=te;rf=tg;sf=ug;tf=ae;break}Lb=d[xf]|0;cc=d[1086680+te|0]|0;xe=te<<cc;te=ae<<cc;ae=cc+tg|0;if((ae|0)>-1&ug>>>0<Ob>>>0){cc=ug;vg=((de((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<ae|te;wg=ae-16|0;xg=ug+2|0}else{vg=te;wg=ae;xg=ug}ae=((ba(xe-1|0,Lb)|0)>>8)+1|0;Lb=ae<<16;if(vg>>>0<Lb>>>0){pf=be;qf=ae;rf=wg;sf=xg;tf=vg;break}bc=be;wd=xf;ce=xe-ae|0;gc=wg;Fd=xg;Pb=vg-Lb|0}c[Ea>>2]=qf;c[Fa>>2]=rf;c[Ha>>2]=sf;c[Ia>>2]=Ob;kf=pf;lf=tf}c[Ga>>2]=lf;a[q+(h*1536|0)+800+(jc<<2)+rc|0]=kf+zd;Pb=(kf|0)!=0|0;a[ac]=Pb;a[dc]=Pb;lc=kf+lc|0;rc=rc+1|0;}while((rc|0)<4);rc=jc+1|0;if((rc|0)<4){jc=rc;Rb=lc}else{yg=lc;zg=4;break}}while(1){Rb=0;jc=yg;while(1){rc=Rb<<1;ac=rc+zg+(q+(h*1536|0)+824)|0;Qb=0;Ag=jc;do{Nb=(Qb<<1)+zg+(Yb+(u*9|0))|0;Pb=Qb+rc|0;Fd=p+1278+(((d[Nb]|0)+(d[ac]|0)|0)*11|0)|0;gc=d[Fd]|0;ce=c[Ea>>2]|0;wd=d[1086680+ce|0]|0;bc=c[Fa>>2]|0;nc=c[Ga>>2]|0;Jb=ce<<wd;c[Ea>>2]=Jb;ce=nc<<wd;nc=bc+wd|0;do{if((nc|0)>-1){wd=c[Ha>>2]|0;if(!(wd>>>0<(c[Ia>>2]|0)>>>0)){Bg=ce;Cg=nc;break}c[Ha>>2]=wd+2;bc=wd;Bg=((de((d[bc]|d[bc+1|0]<<8)<<16>>16|0)|0)&65535)<<nc|ce;Cg=nc-16|0}else{Bg=ce;Cg=nc}}while(0);c[Fa>>2]=Cg;nc=((ba(Jb-1|0,gc)|0)>>8)+1|0;ce=nc<<16;if(Bg>>>0<ce>>>0){c[Ea>>2]=nc;Dg=0;Eg=Bg}else{bc=Jb-nc|0;c[Ea>>2]=bc;nc=Bg-ce|0;c[Ga>>2]=nc;ce=c[Ia>>2]|0;wd=0;ic=Fd;Lb=bc;bc=Cg;ae=c[Ha>>2]|0;xe=nc;while(1){nc=d[ic+1|0]|0;be=d[1086680+Lb|0]|0;te=Lb<<be;cc=xe<<be;Be=be+bc|0;if((Be|0)>-1&ae>>>0<ce>>>0){be=ae;Fg=((de((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|cc;Gg=Be-16|0;Hg=ae+2|0}else{Fg=cc;Gg=Be;Hg=ae}Be=((ba(te-1|0,nc)|0)>>8)+1|0;nc=Be<<16;if(Fg>>>0<nc>>>0){cc=wd+1|0;if((cc|0)==16){Ig=16;Jg=Be;Kg=Gg;Lg=Hg;Mg=Fg;break}wd=cc;ic=p+1278+(cc*33|0)|0;Lb=Be;bc=Gg;ae=Hg;xe=Fg;continue}cc=te-Be|0;Be=d[ic+2|0]|0;te=d[1086680+cc|0]|0;be=cc<<te;cc=Fg-nc<<te;nc=te+Gg|0;if((nc|0)>-1&Hg>>>0<ce>>>0){te=Hg;Ng=((de((d[te]|d[te+1|0]<<8)<<16>>16|0)|0)&65535)<<nc|cc;Og=nc-16|0;Pg=Hg+2|0}else{Ng=cc;Og=nc;Pg=Hg}nc=((ba(be-1|0,Be)|0)>>8)+1|0;Be=nc<<16;if(Ng>>>0<Be>>>0){Qg=p+1278+((wd+1|0)*33|0)+11|0;Rg=1;Sg=nc;Tg=Og;Ug=Pg;Vg=Ng}else{cc=be-nc|0;nc=d[ic+3|0]|0;be=d[1086680+cc|0]|0;te=cc<<be;cc=Ng-Be<<be;Be=be+Og|0;if((Be|0)>-1&Pg>>>0<ce>>>0){be=Pg;Wg=((de((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|cc;Xg=Be-16|0;Yg=Pg+2|0}else{Wg=cc;Xg=Be;Yg=Pg}Be=((ba(te-1|0,nc)|0)>>8)+1|0;nc=Be<<16;do{if(Wg>>>0<nc>>>0){cc=d[ic+4|0]|0;be=d[1086680+Be|0]|0;Gd=Be<<be;Hd=Wg<<be;Ge=be+Xg|0;if((Ge|0)>-1&Yg>>>0<ce>>>0){be=Yg;Zg=((de((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|Hd;_g=Ge-16|0;$g=Yg+2|0}else{Zg=Hd;_g=Ge;$g=Yg}Ge=((ba(Gd-1|0,cc)|0)>>8)+1|0;cc=Ge<<16;if(Zg>>>0<cc>>>0){ah=2;bh=Ge;ch=_g;dh=$g;eh=Zg;break}Hd=Gd-Ge|0;Ge=a[ic+5|0]|0;Gd=d[1086680+Hd|0]|0;be=Hd<<Gd;Hd=Zg-cc<<Gd;cc=Gd+_g|0;if((cc|0)>-1&$g>>>0<ce>>>0){Gd=$g;fh=((de((d[Gd]|d[Gd+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|Hd;gh=cc-16|0;hh=$g+2|0}else{fh=Hd;gh=cc;hh=$g}cc=((ba(be-1|0,Ge&255)|0)>>8)+1|0;Ge=cc<<16;Hd=fh>>>0>=Ge>>>0;ah=Hd?4:3;bh=Hd?be-cc|0:cc;ch=gh;dh=hh;eh=fh-(Hd?Ge:0)|0}else{Ge=te-Be|0;Hd=d[ic+6|0]|0;cc=d[1086680+Ge|0]|0;be=Ge<<cc;Ge=Wg-nc<<cc;Gd=cc+Xg|0;if((Gd|0)>-1&Yg>>>0<ce>>>0){cc=Yg;ih=((de((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<Gd|Ge;jh=Gd-16|0;kh=Yg+2|0}else{ih=Ge;jh=Gd;kh=Yg}Gd=((ba(be-1|0,Hd)|0)>>8)+1|0;Hd=Gd<<16;if(!(ih>>>0<Hd>>>0)){Ge=be-Gd|0;be=a[ic+8|0]|0;cc=d[1086680+Ge|0]|0;Ee=Ge<<cc;Ge=ih-Hd<<cc;Hd=cc+jh|0;if((Hd|0)>-1&kh>>>0<ce>>>0){cc=kh;lh=((de((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Ge;mh=Hd-16|0;nh=kh+2|0}else{lh=Ge;mh=Hd;nh=kh}Hd=((ba(Ee-1|0,be&255)|0)>>8)+1|0;be=Hd<<16;Ge=lh>>>0>=be>>>0;cc=Ge?Ee-Hd|0:Hd;Hd=a[ic+(Ge?10:9)|0]|0;Ee=d[1086680+cc|0]|0;kc=cc<<Ee;cc=lh-(Ge?be:0)<<Ee;be=Ee+mh|0;if((be|0)>-1&nh>>>0<ce>>>0){Ee=nh;oh=((de((d[Ee]|d[Ee+1|0]<<8)<<16>>16|0)|0)&65535)<<be|cc;ph=be-16|0;qh=nh+2|0}else{oh=cc;ph=be;qh=nh}be=((ba(kc-1|0,Hd&255)|0)>>8)+1|0;Hd=be<<16;cc=oh>>>0>=Hd>>>0;Ee=cc&1|(Ge&1)<<1;Ge=c[1085080+(Ee<<2)>>2]|0;He=0;Ce=Ge;_f=a[Ge]|0;Ge=cc?kc-be|0:be;be=ph;kc=oh-(cc?Hd:0)|0;Hd=qh;while(1){cc=Ce+1|0;$f=d[1086680+Ge|0]|0;Fe=Ge<<$f;rh=kc<<$f;sh=$f+be|0;if((sh|0)>-1&Hd>>>0<ce>>>0){$f=Hd;th=((de((d[$f]|d[$f+1|0]<<8)<<16>>16|0)|0)&65535)<<sh|rh;uh=sh-16|0;vh=Hd+2|0}else{th=rh;uh=sh;vh=Hd}sh=((ba(Fe-1|0,_f&255)|0)>>8)+1|0;rh=sh<<16;$f=th>>>0>=rh>>>0;wh=$f?Fe-sh|0:sh;xh=th-($f?rh:0)|0;yh=$f&1|He<<1;$f=a[cc]|0;if($f<<24>>24==0){break}else{He=yh;Ce=cc;_f=$f;Ge=wh;be=uh;kc=xh;Hd=vh}}ah=(8<<Ee)+3+yh|0;bh=wh;ch=uh;dh=vh;eh=xh;break}Hd=d[ic+7|0]|0;kc=d[1086680+Gd|0]|0;be=Gd<<kc;Ge=ih<<kc;_f=kc+jh|0;if((_f|0)>-1&kh>>>0<ce>>>0){kc=kh;zh=((de((d[kc]|d[kc+1|0]<<8)<<16>>16|0)|0)&65535)<<_f|Ge;Ah=_f-16|0;Bh=kh+2|0}else{zh=Ge;Ah=_f;Bh=kh}_f=((ba(be-1|0,Hd)|0)>>8)+1|0;Hd=_f<<16;if(zh>>>0<Hd>>>0){Ge=d[1086680+_f|0]|0;kc=_f<<Ge;Ce=zh<<Ge;He=Ge+Ah|0;if((He|0)>-1&Bh>>>0<ce>>>0){Ge=Bh;Ch=((de((d[Ge]|d[Ge+1|0]<<8)<<16>>16|0)|0)&65535)<<He|Ce;Dh=He-16|0;Eh=Bh+2|0}else{Ch=Ce;Dh=He;Eh=Bh}He=((kc*159|0)-159>>8)+1|0;Ce=He<<16;Ge=Ch>>>0>=Ce>>>0;ah=Ge?6:5;bh=Ge?kc-He|0:He;ch=Dh;dh=Eh;eh=Ch-(Ge?Ce:0)|0;break}Ce=be-_f|0;_f=d[1086680+Ce|0]|0;be=Ce<<_f;Ce=zh-Hd<<_f;Hd=_f+Ah|0;if((Hd|0)>-1&Bh>>>0<ce>>>0){_f=Bh;Fh=((de((d[_f]|d[_f+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Ce;Gh=Hd-16|0;Hh=Bh+2|0}else{Fh=Ce;Gh=Hd;Hh=Bh}Hd=((be*165|0)-165>>8)+1|0;Ce=Hd<<16;_f=Fh>>>0>=Ce>>>0;Ge=_f?be-Hd|0:Hd;Hd=d[1086680+Ge|0]|0;be=Ge<<Hd;Ge=Fh-(_f?Ce:0)<<Hd;Ce=Hd+Gh|0;if((Ce|0)>-1&Hh>>>0<ce>>>0){Hd=Hh;Ih=((de((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<Ce|Ge;Jh=Ce-16|0;Kh=Hh+2|0}else{Ih=Ge;Jh=Ce;Kh=Hh}Ce=((be*145|0)-145>>8)+1|0;Ge=Ce<<16;Hd=Ih>>>0>=Ge>>>0;ah=((_f&1)<<1)+7+(Hd&1)|0;bh=Hd?be-Ce|0:Ce;ch=Jh;dh=Kh;eh=Ih-(Hd?Ge:0)|0}}while(0);Qg=p+1278+((wd+1|0)*33|0)+22|0;Rg=ah;Sg=bh;Tg=ch;Ug=dh;Vg=eh}nc=d[1086680+Sg|0]|0;Be=Sg<<nc;te=Vg<<nc;De=nc+Tg|0;if((De|0)>-1&Ug>>>0<ce>>>0){nc=Ug;Lh=((de((d[nc]|d[nc+1|0]<<8)<<16>>16|0)|0)&65535)<<De|te;Mh=De-16|0;Nh=Ug+2|0}else{Lh=te;Mh=De;Nh=Ug}De=((Be<<7)-128>>8)+1|0;te=De<<16;nc=Lh>>>0>=te>>>0;mc=nc?Be-De|0:De;De=Lh-(nc?te:0)|0;te=(ba(nc?-Rg|0:Rg,b[p+116+(Ub*12|0)+8+(((wd|0)!=0)<<1)>>1]|0)|0)&65535;b[q+(h*1536|0)+(zg<<7)+(Pb<<5)+(d[80+wd|0]<<1)>>1]=te;te=wd+1|0;if((te|0)>=16){Ig=te;Jg=mc;Kg=Mh;Lg=Nh;Mg=De;break}nc=d[Qg]|0;Be=d[1086680+mc|0]|0;Ge=mc<<Be;mc=De<<Be;De=Be+Mh|0;if((De|0)>-1&Nh>>>0<ce>>>0){Be=Nh;Oh=((de((d[Be]|d[Be+1|0]<<8)<<16>>16|0)|0)&65535)<<De|mc;Ph=De-16|0;Qh=Nh+2|0}else{Oh=mc;Ph=De;Qh=Nh}De=((ba(Ge-1|0,nc)|0)>>8)+1|0;nc=De<<16;if(Oh>>>0<nc>>>0){Ig=te;Jg=De;Kg=Ph;Lg=Qh;Mg=Oh;break}wd=te;ic=Qg;Lb=Ge-De|0;bc=Ph;ae=Qh;xe=Oh-nc|0}c[Ea>>2]=Jg;c[Fa>>2]=Kg;c[Ha>>2]=Lg;c[Ia>>2]=ce;Dg=Ig;Eg=Mg}c[Ga>>2]=Eg;a[q+(h*1536|0)+800+(zg<<2)+Pb|0]=Dg;xe=(Dg|0)!=0|0;a[ac]=xe;a[Nb]=xe;Ag=Dg+Ag|0;Qb=Qb+1|0;}while((Qb|0)<2);Qb=Rb+1|0;if((Qb|0)<2){Rb=Qb;jc=Ag}else{break}}jc=zg+1|0;if((jc|0)<6){yg=Ag;zg=jc}else{break}}if((Ag|0)!=0){Rh=Vb;break}a[oc]=1;Rh=Vb}else{Rh=Gb+1|0}}while(0);a:do{if((d[Rh]|0)>>>0<5>>>0){do{if(Ma){if((a[Na]|0)==0){break}if((c[Oa>>2]|0)!=0){break}Ub=u+1|0;Yb=c[Pa>>2]|0;jc=c[B>>2]|0;Rb=c[G>>2]|0;lc=c[L>>2]|0;Qb=c[E>>2]|0;ac=c[I>>2]|0;rc=e[s>>1]|0;dc=a[Qa]|0;Ob=-ac|0;xe=Yb+(Ub<<5)-24|0;ae=c[xe>>2]|0;bc=c[xe+4>>2]|0;Lb=jc+(-8-Qb)|0;ic=c[Lb+4>>2]|0;c[xe>>2]=c[Lb>>2];c[xe+4>>2]=ic;c[Lb>>2]=ae;c[Lb+4>>2]=bc;bc=Yb+(Ub<<5)|0;Lb=c[bc>>2]|0;ae=c[bc+4>>2]|0;ic=jc+(-Qb|0)|0;xe=c[ic+4>>2]|0;c[bc>>2]=c[ic>>2];c[bc+4>>2]=xe;c[ic>>2]=Lb;c[ic+4>>2]=ae;ae=Yb+(Ub<<5)+8|0;ic=c[ae>>2]|0;Lb=c[ae+4>>2]|0;xe=jc+(8-Qb)|0;bc=c[xe+4>>2]|0;c[ae>>2]=c[xe>>2];c[ae+4>>2]=bc;c[xe>>2]=ic;c[xe+4>>2]=Lb;if((rc-1|0)>(u|0)){rc=Yb+(Ub<<5)+32|0;Lb=c[rc>>2]|0;xe=c[rc+4>>2]|0;ic=jc+(16-Qb)|0;Qb=c[ic+4>>2]|0;c[rc>>2]=c[ic>>2];c[rc+4>>2]=Qb;c[ic>>2]=Lb;c[ic+4>>2]=xe}if(!(dc<<24>>24==0)){break}dc=Yb+(Ub<<5)-16|0;xe=c[dc>>2]|0;ic=c[dc+4>>2]|0;Lb=-8-ac|0;ac=Rb+Lb|0;Qb=c[ac+4>>2]|0;c[dc>>2]=c[ac>>2];c[dc+4>>2]=Qb;c[ac>>2]=xe;c[ac+4>>2]=ic;ic=Yb+(Ub<<5)-8|0;ac=c[ic>>2]|0;xe=c[ic+4>>2]|0;Qb=lc+Lb|0;Lb=c[Qb+4>>2]|0;c[ic>>2]=c[Qb>>2];c[ic+4>>2]=Lb;c[Qb>>2]=ac;c[Qb+4>>2]=xe;xe=Yb+(Ub<<5)+16|0;Qb=c[xe>>2]|0;ac=c[xe+4>>2]|0;Lb=Rb+Ob|0;Rb=c[Lb+4>>2]|0;c[xe>>2]=c[Lb>>2];c[xe+4>>2]=Rb;c[Lb>>2]=Qb;c[Lb+4>>2]=ac;ac=Yb+(Ub<<5)+24|0;Ub=c[ac>>2]|0;Yb=c[ac+4>>2]|0;Lb=lc+Ob|0;Ob=c[Lb+4>>2]|0;c[ac>>2]=c[Lb>>2];c[ac+4>>2]=Ob;c[Lb>>2]=Ub;c[Lb+4>>2]=Yb}}while(0);Vb=a[Rh]|0;if((Vb&255)>>>0<4>>>0){Yb=Vb&255;if((Yb|0)==0){Sh=(u|0)==0?Ra:Sa}else if((Yb|0)==2){Sh=Ta}else if((Yb|0)==1){Sh=(u|0)!=0?1:8}else if((Yb|0)==3){Sh=(u|0)==0?Ua:Va}else{Sh=Yb}ne[c[p+5164+(Sh<<2)>>2]&1023](c[B>>2]|0,c[E>>2]|0)}else{Yb=c[B>>2]|0;Vb=Gb+6|0;c[k>>2]=2139062143;Lb=c[E>>2]|0;Ub=16-Lb|0;Ob=Yb+Ub|0;do{if(Ma){if(((e[s>>1]|0)-1|0)!=(u|0)){Th=Ob;break}c[j>>2]=ba(d[Yb+(Ub-1)|0]|0,16843009)|0;Th=Ka}else{Th=Ob}}while(0);if((a[oc]|0)==0){Uh=0;Vh=Yb;Wh=Vb;Xh=Lb}else{TGb(l|0,0,16)|0;Uh=0;Vh=Yb;Wh=Vb;Xh=c[E>>2]|0}while(1){Ob=(Uh|0)==0;Ub=Uh+r|0;ac=(Ub|0)==0;lc=(Ub|0)!=0;Ub=lc?10:13;Qb=lc?9:14;Rb=0;xe=Vh+(4-Xh)|0;ic=Xh;while(1){dc=Rb<<2;rc=Vh+dc|0;jc=(Rb|0)==3;if((Ob|jc)&Wa){Yh=La}else{Yh=jc?Th:xe}jc=d[Wh+Rb|0]|0;bc=Rb+u|0;switch(jc|0){case 0:{if((bc|0)!=0|ac){Zh=401}else{_h=0;Zh=406}break};case 3:case 7:{Zh=401;break};case 1:{if(ac){$h=1;Zh=407}else{Zh=403}break};case 8:{Zh=403;break};case 9:{ai=(bc|0)==0?Ub:Qb;Zh=414;break};case 2:case 4:case 5:case 6:{if(ac|(bc|0)==0){_h=jc;Zh=406}else{ai=jc;Zh=414}break};default:{ai=jc;Zh=414}}do{if((Zh|0)==401){Zh=0;ai=lc?jc:12;Zh=414}else if((Zh|0)==403){Zh=0;ai=(bc|0)!=0?jc:13;Zh=414}else if((Zh|0)==406){Zh=0;if(ac){$h=_h;Zh=407;break}c[_a>>2]=c[Vh+(dc-ic)>>2];if((bc|0)==0){a[$a]=-127;bi=_h;Zh=412;break}else{a[$a]=a[Vh+(dc+~ic)|0]|0;ci=_h;Zh=411;break}}}while(0);if((Zh|0)==407){Zh=0;a[$a]=127;c[_a>>2]=2139062143;ci=$h;Zh=411}else if((Zh|0)==414){Zh=0;Xe[c[p+5012+(ai<<2)>>2]&4095](rc,Yh,ic)}do{if((Zh|0)==411){Zh=0;if((bc|0)==0){bi=ci;Zh=412;break}jc=dc-1|0;a[ab]=a[Vh+jc|0]|0;a[bb]=a[Vh+(jc+ic)|0]|0;a[cb]=a[Vh+(jc+(ic<<1))|0]|0;a[db]=a[Vh+(jc+(ic*3|0))|0]|0;di=ci;Zh=415}}while(0);if((Zh|0)==412){Zh=0;a[db]=-127;a[cb]=-127;a[bb]=-127;a[ab]=-127;di=bi;Zh=415}if((Zh|0)==415){Zh=0;Xe[c[p+5012+(di<<2)>>2]&4095](Za,Yh,8);c[rc>>2]=c[eb>>2];c[Vh+((c[E>>2]|0)+dc)>>2]=c[fb>>2];c[Vh+((c[E>>2]<<1)+dc)>>2]=c[gb>>2];c[Vh+(((c[E>>2]|0)*3|0)+dc)>>2]=c[hb>>2]}bc=a[q+(h*1536|0)+800+(Uh<<2)+Rb|0]|0;if((bc<<24>>24|0)==1){Xe[c[Ya>>2]&4095](rc,q+(h*1536|0)+(Uh<<7)+(Rb<<5)|0,c[E>>2]|0)}else if((bc<<24>>24|0)!=0){Xe[c[Xa>>2]&4095](rc,q+(h*1536|0)+(Uh<<7)+(Rb<<5)|0,c[E>>2]|0)}bc=Rb+1|0;ei=c[E>>2]|0;if((bc|0)<4){Rb=bc;xe=Yh+4|0;ic=ei}else{break}}ic=Uh+1|0;if((ic|0)<4){Uh=ic;Vh=Vh+(ei<<2)|0;Wh=Wh+4|0;Xh=ei}else{break}}}Vb=d[Gb+4|0]|0;if((Vb|0)==0){fi=(u|0)==0?Ra:Sa}else if((Vb|0)==2){fi=Ta}else if((Vb|0)==1){fi=(u|0)!=0?1:8}else if((Vb|0)==3){fi=(u|0)==0?Ua:Va}else{fi=Vb}Vb=p+5120+(fi<<2)|0;Yb=c[G>>2]|0;ne[c[Vb>>2]&1023](Yb,c[I>>2]|0);Lb=c[L>>2]|0;ne[c[Vb>>2]&1023](Lb,c[I>>2]|0);if(!Ma){break}if((a[Na]|0)==0){break}if((c[Oa>>2]|0)!=0){break}Vb=u+1|0;ic=c[Pa>>2]|0;xe=c[B>>2]|0;Rb=c[E>>2]|0;ac=c[I>>2]|0;lc=e[s>>1]|0;Qb=a[Qa]|0;Ub=-ac|0;Ob=ic+(Vb<<5)-24|0;bc=c[Ob+4>>2]|0;jc=xe+(-8-Rb)|0;c[jc>>2]=c[Ob>>2];c[jc+4>>2]=bc;bc=ic+(Vb<<5)|0;jc=c[bc+4>>2]|0;Ob=xe+(-Rb|0)|0;c[Ob>>2]=c[bc>>2];c[Ob+4>>2]=jc;jc=ic+(Vb<<5)+8|0;Ob=c[jc>>2]|0;bc=c[jc+4>>2]|0;ae=xe+(8-Rb)|0;wd=c[ae+4>>2]|0;c[jc>>2]=c[ae>>2];c[jc+4>>2]=wd;c[ae>>2]=Ob;c[ae+4>>2]=bc;if((lc-1|0)>(u|0)){lc=ic+(Vb<<5)+32|0;bc=c[lc>>2]|0;ae=c[lc+4>>2]|0;Ob=xe+(16-Rb)|0;Rb=c[Ob+4>>2]|0;c[lc>>2]=c[Ob>>2];c[lc+4>>2]=Rb;c[Ob>>2]=bc;c[Ob+4>>2]=ae}if(!(Qb<<24>>24==0)){break}Qb=ic+(Vb<<5)-16|0;ae=c[Qb+4>>2]|0;Ob=-8-ac|0;ac=Yb+Ob|0;c[ac>>2]=c[Qb>>2];c[ac+4>>2]=ae;ae=ic+(Vb<<5)-8|0;ac=c[ae+4>>2]|0;Qb=Lb+Ob|0;c[Qb>>2]=c[ae>>2];c[Qb+4>>2]=ac;ac=ic+(Vb<<5)+16|0;Qb=c[ac>>2]|0;ae=c[ac+4>>2]|0;Ob=Yb+Ub|0;Yb=c[Ob+4>>2]|0;c[ac>>2]=c[Ob>>2];c[ac+4>>2]=Yb;c[Ob>>2]=Qb;c[Ob+4>>2]=ae;ae=ic+(Vb<<5)+24|0;Vb=c[ae>>2]|0;ic=c[ae+4>>2]|0;Ob=Lb+Ub|0;Ub=c[Ob+4>>2]|0;c[ae>>2]=c[Ob>>2];c[ae+4>>2]=Ub;c[Ob>>2]=Vb;c[Ob+4>>2]=ic}else{ic=u<<4;Ob=e[s>>1]|0;Vb=Ob<<4;Ub=e[J>>1]|0;ae=Ub<<4;Lb=c[p+8+(d[Gb+2|0]<<2)>>2]|0;Qb=Lb|0;Yb=Gb+32|0;switch(d[Gb+3|0]|0){case 2:{ac=c[Yb>>2]|0;bc=ac&65535;Rb=ac>>>16&65535;lc=c[B>>2]|0;xe=c[E>>2]|0;wd=Lb|0;jc=c[c[wd>>2]>>2]|0;if((ac|0)==0){Z0a(Qb,r,0);Fd=jc+((ba(xe,D)|0)+ic)|0;Ke[c[yb>>2]&1023](lc,xe,Fd,xe,8,0,0)}else{Fd=ac<<1&6;Jb=d[429480+Fd|0]|0;gc=b[Gb+34>>1]|0;nc=gc<<1&6;De=d[429480+nc|0]|0;Ge=(ac<<16>>18)+ic|0;ac=(gc>>2)+D|0;gc=d[429496+nc|0]|0;Z0a(Qb,ac+11+gc>>4,0);te=(ba(ac,xe)|0)+Ge|0;mc=jc+te|0;do{if((Ge|0)<(Jb|0)){Zh=542}else{if((Ge|0)>=(Vb-8-(d[429496+Fd|0]|0)|0)|(ac|0)<(De|0)){Zh=542;break}if((ac|0)<(ae-8-gc|0)){gi=mc;hi=xe}else{Zh=542}}}while(0);if((Zh|0)==542){Zh=0;mc=jc+(te-((ba(De,xe)|0)+Jb))|0;Ne[c[zb>>2]&127](Ab,mc,32,xe,(d[429488+Fd|0]|0)+8|0,(d[429488+nc|0]|0)+8|0,Ge-Jb|0,ac-De|0,Vb,ae);gi=(De<<5)+Jb+(q+(h*1536|0)+848)|0;hi=32}Ke[c[p+5276+(De*12|0)+(Jb<<2)>>2]&1023](lc,xe,gi,hi,8,Fd,nc)}if((a[wb]|0)==3){ii=bc&-8;ji=Rb&-8}else{ii=bc;ji=Rb}mc=ic>>1;gc=Ob<<3;Be=Ub<<3;Hd=c[G>>2]|0;Ce=c[I>>2]|0;be=c[L>>2]|0;_f=c[wd>>2]|0;He=c[_f+4>>2]|0;kc=c[_f+8>>2]|0;_f=ii&65535;b:do{if(((ji&65535)<<16|_f|0)==0){Z0a(Qb,r,0);$f=(ba(Ce,H)|0)+mc|0;Ke[c[Bb>>2]&1023](Hd,Ce,He+$f|0,Ce,4,0,0);Ke[c[Bb>>2]&1023](be,Ce,kc+$f|0,Ce,4,0,0)}else{$f=_f&7;cc=d[429480+$f|0]|0;rh=ji<<16>>16;sh=rh&7;Fe=d[429480+sh|0]|0;ki=(_f<<16>>19)+mc|0;li=(rh>>3)+H|0;rh=ki+(ba(li,Ce)|0)|0;mi=He+rh|0;ni=kc+rh|0;oi=d[429496+sh|0]|0;Z0a(Qb,li+7+oi>>3,0);do{if((ki|0)>=(cc|0)){if((ki|0)>=(gc-4-(d[429496+$f|0]|0)|0)|(li|0)<(Fe|0)){break}if((li|0)>=(Be-4-oi|0)){break}pi=p+5312+(Fe*12|0)+(cc<<2)|0;Ke[c[pi>>2]&1023](Hd,Ce,mi,Ce,4,$f,sh);Ke[c[pi>>2]&1023](be,Ce,ni,Ce,4,$f,sh);break b}}while(0);ni=rh-(ba(Fe,Ce)|0)-cc|0;mi=(d[429488+$f|0]|0)+4|0;oi=(d[429488+sh|0]|0)+4|0;pi=ki-cc|0;qi=li-Fe|0;Ne[c[zb>>2]&127](Ab,He+ni|0,32,Ce,mi,oi,pi,qi,gc,Be);ri=(Fe<<5)+cc+(q+(h*1536|0)+848)|0;si=p+5312+(Fe*12|0)+(cc<<2)|0;Ke[c[si>>2]&1023](Hd,Ce,ri,32,4,$f,sh);Ne[c[zb>>2]&127](Ab,kc+ni|0,32,Ce,mi,oi,pi,qi,gc,Be);Ke[c[si>>2]&1023](be,Ce,ri,32,4,$f,sh)}}while(0);Ce=c[Gb+36>>2]|0;kc=Ce&65535;He=Ce>>>16&65535;_f=c[E>>2]|0;Rb=lc+8|0;bc=ic|8;nc=c[c[wd>>2]>>2]|0;if((Ce|0)==0){Z0a(Qb,r,0);Fd=nc+((ba(_f,D)|0)+bc)|0;Ke[c[yb>>2]&1023](Rb,_f,Fd,_f,8,0,0)}else{Fd=Ce<<1&6;xe=d[429480+Fd|0]|0;Jb=b[Gb+38>>1]|0;De=Jb<<1&6;ac=d[429480+De|0]|0;Ge=(Ce<<16>>18)+bc|0;Ce=(Jb>>2)+D|0;Jb=d[429496+De|0]|0;Z0a(Qb,Ce+11+Jb>>4,0);te=(ba(Ce,_f)|0)+Ge|0;jc=nc+te|0;do{if((Ge|0)<(xe|0)){Zh=558}else{if((Ge|0)>=(Vb-8-(d[429496+Fd|0]|0)|0)|(Ce|0)<(ac|0)){Zh=558;break}if((Ce|0)<(ae-8-Jb|0)){ti=jc;ui=_f}else{Zh=558}}}while(0);if((Zh|0)==558){Zh=0;jc=nc+(te-((ba(ac,_f)|0)+xe))|0;Ne[c[zb>>2]&127](Ab,jc,32,_f,(d[429488+Fd|0]|0)+8|0,(d[429488+De|0]|0)+8|0,Ge-xe|0,Ce-ac|0,Vb,ae);ti=(ac<<5)+xe+(q+(h*1536|0)+848)|0;ui=32}Ke[c[p+5276+(ac*12|0)+(xe<<2)>>2]&1023](Rb,_f,ti,ui,8,Fd,De)}if((a[wb]|0)==3){vi=kc&-8;wi=He&-8}else{vi=kc;wi=He}jc=c[I>>2]|0;Jb=Hd+4|0;ri=be+4|0;si=mc|4;qi=c[wd>>2]|0;pi=c[qi+4>>2]|0;oi=c[qi+8>>2]|0;qi=vi&65535;c:do{if(((wi&65535)<<16|qi|0)==0){Z0a(Qb,r,0);mi=(ba(jc,H)|0)+si|0;Ke[c[Bb>>2]&1023](Jb,jc,pi+mi|0,jc,4,0,0);Ke[c[Bb>>2]&1023](ri,jc,oi+mi|0,jc,4,0,0)}else{mi=qi&7;ni=d[429480+mi|0]|0;xi=wi<<16>>16;yi=xi&7;zi=d[429480+yi|0]|0;Ai=(qi<<16>>19)+si|0;Bi=(xi>>3)+H|0;xi=Ai+(ba(Bi,jc)|0)|0;Ci=pi+xi|0;Di=oi+xi|0;Ei=d[429496+yi|0]|0;Z0a(Qb,Bi+7+Ei>>3,0);do{if((Ai|0)>=(ni|0)){if((Ai|0)>=(gc-4-(d[429496+mi|0]|0)|0)|(Bi|0)<(zi|0)){break}if((Bi|0)>=(Be-4-Ei|0)){break}Fi=p+5312+(zi*12|0)+(ni<<2)|0;Ke[c[Fi>>2]&1023](Jb,jc,Ci,jc,4,mi,yi);Ke[c[Fi>>2]&1023](ri,jc,Di,jc,4,mi,yi);break c}}while(0);Di=xi-(ba(zi,jc)|0)-ni|0;Ci=(d[429488+mi|0]|0)+4|0;Ei=(d[429488+yi|0]|0)+4|0;sh=Ai-ni|0;$f=Bi-zi|0;Ne[c[zb>>2]&127](Ab,pi+Di|0,32,jc,Ci,Ei,sh,$f,gc,Be);cc=(zi<<5)+ni+(q+(h*1536|0)+848)|0;Fe=p+5312+(zi*12|0)+(ni<<2)|0;Ke[c[Fe>>2]&1023](Jb,jc,cc,32,4,mi,yi);Ne[c[zb>>2]&127](Ab,oi+Di|0,32,jc,Ci,Ei,sh,$f,gc,Be);Ke[c[Fe>>2]&1023](ri,jc,cc,32,4,mi,yi)}}while(0);jc=c[Gb+40>>2]|0;ri=jc&65535;oi=jc>>>16&65535;Jb=c[E>>2]|0;pi=lc+(Jb<<3)|0;qi=c[c[wd>>2]>>2]|0;if((jc|0)==0){Z0a(Qb,Cb,0);He=qi+((ba(Jb,f)|0)+ic)|0;Ke[c[yb>>2]&1023](pi,Jb,He,Jb,8,0,0)}else{He=jc<<1&6;kc=d[429480+He|0]|0;De=b[Gb+42>>1]|0;Fd=De<<1&6;_f=d[429480+Fd|0]|0;Rb=(jc<<16>>18)+ic|0;jc=(De>>2)+f|0;De=d[429496+Fd|0]|0;Z0a(Qb,jc+11+De>>4,0);xe=(ba(jc,Jb)|0)+Rb|0;ac=qi+xe|0;do{if((Rb|0)<(kc|0)){Zh=574}else{if((Rb|0)>=(Vb-8-(d[429496+He|0]|0)|0)|(jc|0)<(_f|0)){Zh=574;break}if((jc|0)<(ae-8-De|0)){Gi=ac;Hi=Jb}else{Zh=574}}}while(0);if((Zh|0)==574){Zh=0;ac=qi+(xe-((ba(_f,Jb)|0)+kc))|0;Ne[c[zb>>2]&127](Ab,ac,32,Jb,(d[429488+He|0]|0)+8|0,(d[429488+Fd|0]|0)+8|0,Rb-kc|0,jc-_f|0,Vb,ae);Gi=(_f<<5)+kc+(q+(h*1536|0)+848)|0;Hi=32}Ke[c[p+5276+(_f*12|0)+(kc<<2)>>2]&1023](pi,Jb,Gi,Hi,8,He,Fd)}if((a[wb]|0)==3){Ii=ri&-8;Ji=oi&-8}else{Ii=ri;Ji=oi}ac=c[I>>2]|0;De=ac<<2;Ce=Hd+De|0;Ge=be+De|0;De=c[wd>>2]|0;te=c[De+4>>2]|0;nc=c[De+8>>2]|0;De=Ii&65535;d:do{if(((Ji&65535)<<16|De|0)==0){Z0a(Qb,Eb,0);cc=(ba(ac,Db)|0)+mc|0;Ke[c[Bb>>2]&1023](Ce,ac,te+cc|0,ac,4,0,0);Ke[c[Bb>>2]&1023](Ge,ac,nc+cc|0,ac,4,0,0)}else{cc=De&7;Fe=d[429480+cc|0]|0;$f=Ji<<16>>16;sh=$f&7;Ei=d[429480+sh|0]|0;Ci=(De<<16>>19)+mc|0;Di=($f>>3)+Db|0;$f=Ci+(ba(Di,ac)|0)|0;li=te+$f|0;ki=nc+$f|0;rh=d[429496+sh|0]|0;Z0a(Qb,Di+7+rh>>3,0);do{if((Ci|0)>=(Fe|0)){if((Ci|0)>=(gc-4-(d[429496+cc|0]|0)|0)|(Di|0)<(Ei|0)){break}if((Di|0)>=(Be-4-rh|0)){break}Fi=p+5312+(Ei*12|0)+(Fe<<2)|0;Ke[c[Fi>>2]&1023](Ce,ac,li,ac,4,cc,sh);Ke[c[Fi>>2]&1023](Ge,ac,ki,ac,4,cc,sh);break d}}while(0);ki=$f-(ba(Ei,ac)|0)-Fe|0;li=(d[429488+cc|0]|0)+4|0;rh=(d[429488+sh|0]|0)+4|0;yi=Ci-Fe|0;mi=Di-Ei|0;Ne[c[zb>>2]&127](Ab,te+ki|0,32,ac,li,rh,yi,mi,gc,Be);ni=(Ei<<5)+Fe+(q+(h*1536|0)+848)|0;zi=p+5312+(Ei*12|0)+(Fe<<2)|0;Ke[c[zi>>2]&1023](Ce,ac,ni,32,4,cc,sh);Ne[c[zb>>2]&127](Ab,nc+ki|0,32,ac,li,rh,yi,mi,gc,Be);Ke[c[zi>>2]&1023](Ge,ac,ni,32,4,cc,sh)}}while(0);ac=c[Gb+44>>2]|0;Ge=ac&65535;nc=ac>>>16&65535;Ce=c[E>>2]|0;te=lc+((Ce<<3)+8)|0;mc=c[c[wd>>2]>>2]|0;if((ac|0)==0){Z0a(Qb,Cb,0);De=mc+((ba(Ce,f)|0)+bc)|0;Ke[c[yb>>2]&1023](te,Ce,De,Ce,8,0,0)}else{De=ac<<1&6;oi=d[429480+De|0]|0;ri=b[Gb+46>>1]|0;Fd=ri<<1&6;He=d[429480+Fd|0]|0;Jb=(ac<<16>>18)+bc|0;ac=(ri>>2)+f|0;ri=d[429496+Fd|0]|0;Z0a(Qb,ac+11+ri>>4,0);pi=(ba(ac,Ce)|0)+Jb|0;kc=mc+pi|0;do{if((Jb|0)<(oi|0)){Zh=590}else{if((Jb|0)>=(Vb-8-(d[429496+De|0]|0)|0)|(ac|0)<(He|0)){Zh=590;break}if((ac|0)<(ae-8-ri|0)){Ki=kc;Li=Ce}else{Zh=590}}}while(0);if((Zh|0)==590){Zh=0;kc=mc+(pi-((ba(He,Ce)|0)+oi))|0;Ne[c[zb>>2]&127](Ab,kc,32,Ce,(d[429488+De|0]|0)+8|0,(d[429488+Fd|0]|0)+8|0,Jb-oi|0,ac-He|0,Vb,ae);Ki=(He<<5)+oi+(q+(h*1536|0)+848)|0;Li=32}Ke[c[p+5276+(He*12|0)+(oi<<2)>>2]&1023](te,Ce,Ki,Li,8,De,Fd)}if((a[wb]|0)==3){Mi=Ge&-8;Ni=nc&-8}else{Mi=Ge;Ni=nc}kc=c[I>>2]|0;ri=(kc<<2)+4|0;bc=Hd+ri|0;lc=be+ri|0;ri=c[wd>>2]|0;_f=c[ri+4>>2]|0;jc=c[ri+8>>2]|0;ri=Mi&65535;if(((Ni&65535)<<16|ri|0)==0){Z0a(Qb,Eb,0);Rb=(ba(kc,Db)|0)+si|0;Ke[c[Bb>>2]&1023](bc,kc,_f+Rb|0,kc,4,0,0);Ke[c[Bb>>2]&1023](lc,kc,jc+Rb|0,kc,4,0,0);break a}Rb=ri&7;xe=d[429480+Rb|0]|0;qi=Ni<<16>>16;ni=qi&7;zi=d[429480+ni|0]|0;mi=(ri<<16>>19)+si|0;ri=(qi>>3)+Db|0;qi=mi+(ba(ri,kc)|0)|0;yi=_f+qi|0;rh=jc+qi|0;li=d[429496+ni|0]|0;Z0a(Qb,ri+7+li>>3,0);do{if((mi|0)>=(xe|0)){if((mi|0)>=(gc-4-(d[429496+Rb|0]|0)|0)|(ri|0)<(zi|0)){break}if((ri|0)>=(Be-4-li|0)){break}ki=p+5312+(zi*12|0)+(xe<<2)|0;Ke[c[ki>>2]&1023](bc,kc,yi,kc,4,Rb,ni);Ke[c[ki>>2]&1023](lc,kc,rh,kc,4,Rb,ni);break a}}while(0);rh=qi-(ba(zi,kc)|0)-xe|0;yi=(d[429488+Rb|0]|0)+4|0;li=(d[429488+ni|0]|0)+4|0;si=mi-xe|0;wd=ri-zi|0;Ne[c[zb>>2]&127](Ab,_f+rh|0,32,kc,yi,li,si,wd,gc,Be);be=(zi<<5)+xe+(q+(h*1536|0)+848)|0;Hd=p+5312+(zi*12|0)+(xe<<2)|0;Ke[c[Hd>>2]&1023](bc,kc,be,32,4,Rb,ni);Ne[c[zb>>2]&127](Ab,jc+rh|0,32,kc,yi,li,si,wd,gc,Be);Ke[c[Hd>>2]&1023](lc,kc,be,32,4,Rb,ni);break a;break};case 1:{be=c[Yb>>2]|0;Hd=be&65535;wd=be>>>16&65535;si=c[B>>2]|0;li=c[E>>2]|0;yi=Lb|0;rh=c[c[yi>>2]>>2]|0;if((be|0)==0){Z0a(Qb,O,0);nc=rh+((ba(li,D)|0)+ic)|0;Ke[c[yb>>2]&1023](si,li,nc,li,16,0,0)}else{nc=be<<1&6;Ge=d[429480+nc|0]|0;Fd=b[Gb+34>>1]|0;De=Fd<<1&6;Ce=d[429480+De|0]|0;te=(be<<16>>18)+ic|0;be=(Fd>>2)+D|0;Fd=d[429496+De|0]|0;Z0a(Qb,be+19+Fd>>4,0);oi=(ba(be,li)|0)+te|0;He=rh+oi|0;do{if((te|0)<(Ge|0)){Zh=510}else{if((te|0)>=(Vb-8-(d[429496+nc|0]|0)|0)|(be|0)<(Ce|0)){Zh=510;break}if((be|0)<(ae-16-Fd|0)){Oi=He;Pi=li}else{Zh=510}}}while(0);if((Zh|0)==510){Zh=0;He=rh+(oi-((ba(Ce,li)|0)+Ge))|0;Ne[c[zb>>2]&127](Ab,He,32,li,(d[429488+nc|0]|0)+8|0,(d[429488+De|0]|0)+16|0,te-Ge|0,be-Ce|0,Vb,ae);Oi=(Ce<<5)+Ge+(q+(h*1536|0)+848)|0;Pi=32}Ke[c[p+5276+(Ce*12|0)+(Ge<<2)>>2]&1023](si,li,Oi,Pi,16,nc,De)}if((a[wb]|0)==3){Qi=Hd&-8;Ri=wd&-8}else{Qi=Hd;Ri=wd}He=ic>>1;Fd=Ob<<3;ni=Ub<<3;Rb=c[G>>2]|0;kc=c[I>>2]|0;lc=c[L>>2]|0;Be=c[yi>>2]|0;gc=c[Be+4>>2]|0;jc=c[Be+8>>2]|0;Be=Qi&65535;e:do{if(((Ri&65535)<<16|Be|0)==0){Z0a(Qb,xb,0);bc=(ba(kc,H)|0)+He|0;Ke[c[Bb>>2]&1023](Rb,kc,gc+bc|0,kc,8,0,0);Ke[c[Bb>>2]&1023](lc,kc,jc+bc|0,kc,8,0,0)}else{bc=Be&7;xe=d[429480+bc|0]|0;zi=Ri<<16>>16;_f=zi&7;ri=d[429480+_f|0]|0;mi=(Be<<16>>19)+He|0;qi=(zi>>3)+H|0;zi=mi+(ba(qi,kc)|0)|0;ac=gc+zi|0;Jb=jc+zi|0;pi=d[429496+_f|0]|0;Z0a(Qb,qi+11+pi>>3,0);do{if((mi|0)>=(xe|0)){if((mi|0)>=(Fd-4-(d[429496+bc|0]|0)|0)|(qi|0)<(ri|0)){break}if((qi|0)>=(ni-8-pi|0)){break}mc=p+5312+(ri*12|0)+(xe<<2)|0;Ke[c[mc>>2]&1023](Rb,kc,ac,kc,8,bc,_f);Ke[c[mc>>2]&1023](lc,kc,Jb,kc,8,bc,_f);break e}}while(0);Jb=zi-(ba(ri,kc)|0)-xe|0;ac=(d[429488+bc|0]|0)+4|0;pi=(d[429488+_f|0]|0)+8|0;sh=mi-xe|0;cc=qi-ri|0;Ne[c[zb>>2]&127](Ab,gc+Jb|0,32,kc,ac,pi,sh,cc,Fd,ni);Fe=(ri<<5)+xe+(q+(h*1536|0)+848)|0;Ei=p+5312+(ri*12|0)+(xe<<2)|0;Ke[c[Ei>>2]&1023](Rb,kc,Fe,32,8,bc,_f);Ne[c[zb>>2]&127](Ab,jc+Jb|0,32,kc,ac,pi,sh,cc,Fd,ni);Ke[c[Ei>>2]&1023](lc,kc,Fe,32,8,bc,_f)}}while(0);kc=c[Gb+36>>2]|0;jc=kc&65535;gc=kc>>>16&65535;Be=c[E>>2]|0;wd=si+8|0;Hd=ic|8;De=c[c[yi>>2]>>2]|0;if((kc|0)==0){Z0a(Qb,O,0);nc=De+((ba(Be,D)|0)+Hd)|0;Ke[c[yb>>2]&1023](wd,Be,nc,Be,16,0,0)}else{nc=kc<<1&6;li=d[429480+nc|0]|0;Ge=b[Gb+38>>1]|0;Ce=Ge<<1&6;be=d[429480+Ce|0]|0;te=(kc<<16>>18)+Hd|0;Hd=(Ge>>2)+D|0;Ge=d[429496+Ce|0]|0;Z0a(Qb,Hd+19+Ge>>4,0);kc=(ba(Hd,Be)|0)+te|0;oi=De+kc|0;do{if((te|0)<(li|0)){Zh=526}else{if((te|0)>=(Vb-8-(d[429496+nc|0]|0)|0)|(Hd|0)<(be|0)){Zh=526;break}if((Hd|0)<(ae-16-Ge|0)){Si=oi;Ti=Be}else{Zh=526}}}while(0);if((Zh|0)==526){Zh=0;oi=De+(kc-((ba(be,Be)|0)+li))|0;Ne[c[zb>>2]&127](Ab,oi,32,Be,(d[429488+nc|0]|0)+8|0,(d[429488+Ce|0]|0)+16|0,te-li|0,Hd-be|0,Vb,ae);Si=(be<<5)+li+(q+(h*1536|0)+848)|0;Ti=32}Ke[c[p+5276+(be*12|0)+(li<<2)>>2]&1023](wd,Be,Si,Ti,16,nc,Ce)}if((a[wb]|0)==3){Ui=jc&-8;Vi=gc&-8}else{Ui=jc;Vi=gc}oi=c[I>>2]|0;Ge=Rb+4|0;si=lc+4|0;rh=He|4;Fe=c[yi>>2]|0;Ei=c[Fe+4>>2]|0;cc=c[Fe+8>>2]|0;Fe=Ui&65535;if(((Vi&65535)<<16|Fe|0)==0){Z0a(Qb,xb,0);sh=(ba(oi,H)|0)+rh|0;Ke[c[Bb>>2]&1023](Ge,oi,Ei+sh|0,oi,8,0,0);Ke[c[Bb>>2]&1023](si,oi,cc+sh|0,oi,8,0,0);break a}sh=Fe&7;pi=d[429480+sh|0]|0;ac=Vi<<16>>16;Jb=ac&7;Di=d[429480+Jb|0]|0;Ci=(Fe<<16>>19)+rh|0;rh=(ac>>3)+H|0;ac=Ci+(ba(rh,oi)|0)|0;Fe=Ei+ac|0;$f=cc+ac|0;mc=d[429496+Jb|0]|0;Z0a(Qb,rh+11+mc>>3,0);do{if((Ci|0)>=(pi|0)){if((Ci|0)>=(Fd-4-(d[429496+sh|0]|0)|0)|(rh|0)<(Di|0)){break}if((rh|0)>=(ni-8-mc|0)){break}ki=p+5312+(Di*12|0)+(pi<<2)|0;Ke[c[ki>>2]&1023](Ge,oi,Fe,oi,8,sh,Jb);Ke[c[ki>>2]&1023](si,oi,$f,oi,8,sh,Jb);break a}}while(0);$f=ac-(ba(Di,oi)|0)-pi|0;Fe=(d[429488+sh|0]|0)+4|0;mc=(d[429488+Jb|0]|0)+8|0;yi=Ci-pi|0;He=rh-Di|0;Ne[c[zb>>2]&127](Ab,Ei+$f|0,32,oi,Fe,mc,yi,He,Fd,ni);lc=(Di<<5)+pi+(q+(h*1536|0)+848)|0;Rb=p+5312+(Di*12|0)+(pi<<2)|0;Ke[c[Rb>>2]&1023](Ge,oi,lc,32,8,sh,Jb);Ne[c[zb>>2]&127](Ab,cc+$f|0,32,oi,Fe,mc,yi,He,Fd,ni);Ke[c[Rb>>2]&1023](si,oi,lc,32,8,sh,Jb);break a;break};case 3:{lc=Lb|0;Rb=Vb-4|0;He=ae-4|0;yi=c[B>>2]|0;mc=0;do{Fe=mc<<2;$f=Fe+D|0;gc=($f|3)+4>>4;jc=0;do{Ce=c[E>>2]|0;nc=jc<<2;Be=yi+((ba(Ce,Fe)|0)+nc)|0;wd=jc+Fe|0;li=nc+ic|0;nc=c[c[lc>>2]>>2]|0;be=c[Gb+32+(wd<<2)>>2]|0;if((be|0)==0){Z0a(Qb,gc,0);Hd=nc+((ba(Ce,$f)|0)+li)|0;Ke[c[Bb>>2]&1023](Be,Ce,Hd,Ce,4,0,0)}else{Hd=be<<1&6;te=d[429480+Hd|0]|0;kc=b[Gb+32+(wd<<2)+2>>1]|0;wd=kc<<1&6;De=d[429480+wd|0]|0;ki=(be<<16>>18)+li|0;li=(kc>>2)+$f|0;kc=d[429496+wd|0]|0;Z0a(Qb,li+7+kc>>4,0);be=(ba(li,Ce)|0)+ki|0;Bi=nc+be|0;do{if((ki|0)<(te|0)){Zh=456}else{if((ki|0)>=(Rb-(d[429496+Hd|0]|0)|0)|(li|0)<(De|0)){Zh=456;break}if((li|0)<(He-kc|0)){Wi=Bi;Xi=Ce}else{Zh=456}}}while(0);if((Zh|0)==456){Zh=0;Bi=nc+(be-((ba(De,Ce)|0)+te))|0;Ne[c[zb>>2]&127](Ab,Bi,32,Ce,(d[429488+Hd|0]|0)+4|0,(d[429488+wd|0]|0)+4|0,ki-te|0,li-De|0,Vb,ae);Wi=(De<<5)+te+(q+(h*1536|0)+848)|0;Xi=32}Ke[c[p+5312+(De*12|0)+(te<<2)>>2]&1023](Be,Ce,Wi,Xi,4,Hd,wd)}jc=jc+1|0;}while((jc|0)<4);mc=mc+1|0;}while((mc|0)<4);mc=ic>>1;He=Ob<<3;Rb=Ub<<3;yi=He-4|0;Jb=Rb-4|0;sh=c[G>>2]|0;oi=c[L>>2]|0;si=0;do{ni=si<<3;Fd=ni|4;cc=si<<2;Ge=cc+H|0;pi=(Ge|3)+4>>3;Di=0;do{Ei=Di<<1;rh=Ei+ni|0;Ci=rh|1;ac=Ei+Fd|0;Ei=ac|1;jc=((((b[Gb+32+(Ci<<2)>>1]|0)+(b[Gb+32+(rh<<2)>>1]|0)&65535)+(b[Gb+32+(ac<<2)>>1]|0)&65535)+(b[Gb+32+(Ei<<2)>>1]|0)&65535)<<16>>16;$f=(jc+2+(jc>>31)|0)>>>2&65535;jc=((((b[Gb+32+(Ci<<2)+2>>1]|0)+(b[Gb+32+(rh<<2)+2>>1]|0)&65535)+(b[Gb+32+(ac<<2)+2>>1]|0)&65535)+(b[Gb+32+(Ei<<2)+2>>1]|0)&65535)<<16>>16;Ei=(jc+2+(jc>>31)|0)>>>2&65535;if((a[wb]|0)==3){Yi=$f&-8;Zi=Ei&-8}else{Yi=$f;Zi=Ei}Ei=c[I>>2]|0;$f=Di<<2;jc=(ba(Ei,cc)|0)+$f|0;ac=sh+jc|0;rh=oi+jc|0;jc=$f+mc|0;$f=c[lc>>2]|0;Ci=c[$f+4>>2]|0;gc=c[$f+8>>2]|0;$f=Yi&65535;f:do{if(((Zi&65535)<<16|$f|0)==0){Z0a(Qb,pi,0);Fe=(ba(Ei,Ge)|0)+jc|0;Ke[c[Bb>>2]&1023](ac,Ei,Ci+Fe|0,Ei,4,0,0);Ke[c[Bb>>2]&1023](rh,Ei,gc+Fe|0,Ei,4,0,0)}else{Fe=$f&7;_f=d[429480+Fe|0]|0;bc=Zi<<16>>16;xe=bc&7;ri=d[429480+xe|0]|0;qi=($f<<16>>19)+jc|0;mi=(bc>>3)+Ge|0;bc=qi+(ba(mi,Ei)|0)|0;zi=Ci+bc|0;Bi=gc+bc|0;kc=d[429496+xe|0]|0;Z0a(Qb,mi+7+kc>>3,0);do{if((qi|0)>=(_f|0)){if((qi|0)>=(yi-(d[429496+Fe|0]|0)|0)|(mi|0)<(ri|0)){break}if((mi|0)>=(Jb-kc|0)){break}rc=p+5312+(ri*12|0)+(_f<<2)|0;Ke[c[rc>>2]&1023](ac,Ei,zi,Ei,4,Fe,xe);Ke[c[rc>>2]&1023](rh,Ei,Bi,Ei,4,Fe,xe);break f}}while(0);Bi=bc-(ba(ri,Ei)|0)-_f|0;zi=(d[429488+Fe|0]|0)+4|0;kc=(d[429488+xe|0]|0)+4|0;Nb=qi-_f|0;Pb=mi-ri|0;Ne[c[zb>>2]&127](Ab,Ci+Bi|0,32,Ei,zi,kc,Nb,Pb,He,Rb);ce=(ri<<5)+_f+(q+(h*1536|0)+848)|0;rc=p+5312+(ri*12|0)+(_f<<2)|0;Ke[c[rc>>2]&1023](ac,Ei,ce,32,4,Fe,xe);Ne[c[zb>>2]&127](Ab,gc+Bi|0,32,Ei,zi,kc,Nb,Pb,He,Rb);Ke[c[rc>>2]&1023](rh,Ei,ce,32,4,Fe,xe)}}while(0);Di=Di+1|0;}while((Di|0)<2);si=si+1|0;}while((si|0)<2);break};case 4:{si=c[Gb+28>>2]|0;Rb=si&65535;He=si>>>16&65535;Jb=c[B>>2]|0;yi=c[E>>2]|0;lc=Lb|0;mc=c[c[lc>>2]>>2]|0;if((si|0)==0){Z0a(Qb,O,0);oi=mc+((ba(yi,D)|0)+ic)|0;Ke[c[vb>>2]&1023](Jb,yi,oi,yi,16,0,0)}else{oi=si<<1&6;sh=d[429480+oi|0]|0;Di=b[Gb+30>>1]|0;Ge=Di<<1&6;pi=d[429480+Ge|0]|0;cc=(si<<16>>18)+ic|0;si=(Di>>2)+D|0;Di=d[429496+Ge|0]|0;Z0a(Qb,si+19+Di>>4,0);Fd=(ba(si,yi)|0)+cc|0;ni=mc+Fd|0;do{if((cc|0)<(sh|0)){Zh=439}else{if((cc|0)>=(Vb-16-(d[429496+oi|0]|0)|0)|(si|0)<(pi|0)){Zh=439;break}if((si|0)<(ae-16-Di|0)){_i=ni;$i=yi}else{Zh=439}}}while(0);if((Zh|0)==439){Zh=0;ni=mc+(Fd-((ba(pi,yi)|0)+sh))|0;Ne[c[zb>>2]&127](Ab,ni,32,yi,(d[429488+oi|0]|0)+16|0,(d[429488+Ge|0]|0)+16|0,cc-sh|0,si-pi|0,Vb,ae);_i=(pi<<5)+sh+(q+(h*1536|0)+848)|0;$i=32}Ke[c[p+5240+(pi*12|0)+(sh<<2)>>2]&1023](Jb,yi,_i,$i,16,oi,Ge)}if((a[wb]|0)==3){aj=Rb&-8;bj=He&-8}else{aj=Rb;bj=He}ni=ic>>1;Di=Ob<<3;Ei=Ub<<3;rh=c[G>>2]|0;gc=c[I>>2]|0;ac=c[L>>2]|0;Ci=c[lc>>2]|0;jc=c[Ci+4>>2]|0;$f=c[Ci+8>>2]|0;Ci=aj&65535;if(((bj&65535)<<16|Ci|0)==0){Z0a(Qb,xb,0);wd=(ba(gc,H)|0)+ni|0;Ke[c[yb>>2]&1023](rh,gc,jc+wd|0,gc,8,0,0);Ke[c[yb>>2]&1023](ac,gc,$f+wd|0,gc,8,0,0);break a}wd=Ci&7;Hd=d[429480+wd|0]|0;Ce=bj<<16>>16;Be=Ce&7;te=d[429480+Be|0]|0;De=(Ci<<16>>19)+ni|0;ni=(Ce>>3)+H|0;Ce=De+(ba(ni,gc)|0)|0;Ci=jc+Ce|0;li=$f+Ce|0;ki=d[429496+Be|0]|0;Z0a(Qb,ni+11+ki>>3,0);do{if((De|0)>=(Hd|0)){if((De|0)>=(Di-8-(d[429496+wd|0]|0)|0)|(ni|0)<(te|0)){break}if((ni|0)>=(Ei-8-ki|0)){break}be=p+5276+(te*12|0)+(Hd<<2)|0;Ke[c[be>>2]&1023](rh,gc,Ci,gc,8,wd,Be);Ke[c[be>>2]&1023](ac,gc,li,gc,8,wd,Be);break a}}while(0);li=Ce-(ba(te,gc)|0)-Hd|0;Ci=(d[429488+wd|0]|0)+8|0;ki=(d[429488+Be|0]|0)+8|0;lc=De-Hd|0;He=ni-te|0;Ne[c[zb>>2]&127](Ab,jc+li|0,32,gc,Ci,ki,lc,He,Di,Ei);Rb=(te<<5)+Hd+(q+(h*1536|0)+848)|0;Ge=p+5276+(te*12|0)+(Hd<<2)|0;Ke[c[Ge>>2]&1023](rh,gc,Rb,32,8,wd,Be);Ne[c[zb>>2]&127](Ab,$f+li|0,32,gc,Ci,ki,lc,He,Di,Ei);Ke[c[Ge>>2]&1023](ac,gc,Rb,32,8,wd,Be);break a;break};case 0:{Rb=c[Yb>>2]|0;Ge=Rb&65535;He=Rb>>>16&65535;lc=c[B>>2]|0;ki=c[E>>2]|0;Ci=Lb|0;li=c[c[Ci>>2]>>2]|0;if((Rb|0)==0){Z0a(Qb,r,0);oi=li+((ba(ki,D)|0)+ic)|0;Ke[c[vb>>2]&1023](lc,ki,oi,ki,8,0,0)}else{oi=Rb<<1&6;yi=d[429480+oi|0]|0;Jb=b[Gb+34>>1]|0;sh=Jb<<1&6;pi=d[429480+sh|0]|0;si=(Rb<<16>>18)+ic|0;Rb=(Jb>>2)+D|0;Jb=d[429496+sh|0]|0;Z0a(Qb,Rb+11+Jb>>4,0);cc=(ba(Rb,ki)|0)+si|0;Fd=li+cc|0;do{if((si|0)<(yi|0)){Zh=478}else{if((si|0)>=(Vb-16-(d[429496+oi|0]|0)|0)|(Rb|0)<(pi|0)){Zh=478;break}if((Rb|0)<(ae-8-Jb|0)){cj=Fd;dj=ki}else{Zh=478}}}while(0);if((Zh|0)==478){Zh=0;Fd=li+(cc-((ba(pi,ki)|0)+yi))|0;Ne[c[zb>>2]&127](Ab,Fd,32,ki,(d[429488+oi|0]|0)+16|0,(d[429488+sh|0]|0)+8|0,si-yi|0,Rb-pi|0,Vb,ae);cj=(pi<<5)+yi+(q+(h*1536|0)+848)|0;dj=32}Ke[c[p+5240+(pi*12|0)+(yi<<2)>>2]&1023](lc,ki,cj,dj,8,oi,sh)}if((a[wb]|0)==3){ej=Ge&-8;fj=He&-8}else{ej=Ge;fj=He}Fd=ic>>1;Jb=Ob<<3;Lb=Ub<<3;Yb=c[G>>2]|0;Be=c[I>>2]|0;wd=c[L>>2]|0;gc=c[Ci>>2]|0;ac=c[gc+4>>2]|0;Ei=c[gc+8>>2]|0;gc=ej&65535;g:do{if(((fj&65535)<<16|gc|0)==0){Z0a(Qb,r,0);Di=(ba(Be,H)|0)+Fd|0;Ke[c[yb>>2]&1023](Yb,Be,ac+Di|0,Be,4,0,0);Ke[c[yb>>2]&1023](wd,Be,Ei+Di|0,Be,4,0,0)}else{Di=gc&7;$f=d[429480+Di|0]|0;rh=fj<<16>>16;Hd=rh&7;te=d[429480+Hd|0]|0;jc=(gc<<16>>19)+Fd|0;ni=(rh>>3)+H|0;rh=jc+(ba(ni,Be)|0)|0;De=ac+rh|0;Ce=Ei+rh|0;mc=d[429496+Hd|0]|0;Z0a(Qb,ni+7+mc>>3,0);do{if((jc|0)>=($f|0)){if((jc|0)>=(Jb-8-(d[429496+Di|0]|0)|0)|(ni|0)<(te|0)){break}if((ni|0)>=(Lb-4-mc|0)){break}be=p+5276+(te*12|0)+($f<<2)|0;Ke[c[be>>2]&1023](Yb,Be,De,Be,4,Di,Hd);Ke[c[be>>2]&1023](wd,Be,Ce,Be,4,Di,Hd);break g}}while(0);Ce=rh-(ba(te,Be)|0)-$f|0;De=(d[429488+Di|0]|0)+8|0;mc=(d[429488+Hd|0]|0)+4|0;be=jc-$f|0;nc=ni-te|0;Ne[c[zb>>2]&127](Ab,ac+Ce|0,32,Be,De,mc,be,nc,Jb,Lb);ce=(te<<5)+$f+(q+(h*1536|0)+848)|0;rc=p+5276+(te*12|0)+($f<<2)|0;Ke[c[rc>>2]&1023](Yb,Be,ce,32,4,Di,Hd);Ne[c[zb>>2]&127](Ab,Ei+Ce|0,32,Be,De,mc,be,nc,Jb,Lb);Ke[c[rc>>2]&1023](wd,Be,ce,32,4,Di,Hd)}}while(0);Be=c[Gb+36>>2]|0;Ei=Be&65535;ac=Be>>>16&65535;gc=c[E>>2]|0;Ub=lc+(gc<<3)|0;Ob=c[c[Ci>>2]>>2]|0;if((Be|0)==0){Z0a(Qb,Cb,0);He=Ob+((ba(gc,f)|0)+ic)|0;Ke[c[vb>>2]&1023](Ub,gc,He,gc,8,0,0)}else{He=Be<<1&6;Ge=d[429480+He|0]|0;sh=b[Gb+38>>1]|0;oi=sh<<1&6;ki=d[429480+oi|0]|0;yi=(Be<<16>>18)+ic|0;Be=(sh>>2)+f|0;sh=d[429496+oi|0]|0;Z0a(Qb,Be+11+sh>>4,0);pi=(ba(Be,gc)|0)+yi|0;Rb=Ob+pi|0;do{if((yi|0)<(Ge|0)){Zh=494}else{if((yi|0)>=(Vb-16-(d[429496+He|0]|0)|0)|(Be|0)<(ki|0)){Zh=494;break}if((Be|0)<(ae-8-sh|0)){gj=Rb;hj=gc}else{Zh=494}}}while(0);if((Zh|0)==494){Zh=0;Rb=Ob+(pi-((ba(ki,gc)|0)+Ge))|0;Ne[c[zb>>2]&127](Ab,Rb,32,gc,(d[429488+He|0]|0)+16|0,(d[429488+oi|0]|0)+8|0,yi-Ge|0,Be-ki|0,Vb,ae);gj=(ki<<5)+Ge+(q+(h*1536|0)+848)|0;hj=32}Ke[c[p+5240+(ki*12|0)+(Ge<<2)>>2]&1023](Ub,gc,gj,hj,8,He,oi)}if((a[wb]|0)==3){ij=Ei&-8;jj=ac&-8}else{ij=Ei;jj=ac}Rb=c[I>>2]|0;sh=Rb<<2;ic=Yb+sh|0;lc=wd+sh|0;sh=c[Ci>>2]|0;si=c[sh+4>>2]|0;cc=c[sh+8>>2]|0;sh=ij&65535;if(((jj&65535)<<16|sh|0)==0){Z0a(Qb,Eb,0);li=(ba(Rb,Db)|0)+Fd|0;Ke[c[yb>>2]&1023](ic,Rb,si+li|0,Rb,4,0,0);Ke[c[yb>>2]&1023](lc,Rb,cc+li|0,Rb,4,0,0);break a}li=sh&7;ce=d[429480+li|0]|0;rc=jj<<16>>16;nc=rc&7;be=d[429480+nc|0]|0;mc=(sh<<16>>19)+Fd|0;sh=(rc>>3)+Db|0;rc=mc+(ba(sh,Rb)|0)|0;De=si+rc|0;Ce=cc+rc|0;Pb=d[429496+nc|0]|0;Z0a(Qb,sh+7+Pb>>3,0);do{if((mc|0)>=(ce|0)){if((mc|0)>=(Jb-8-(d[429496+li|0]|0)|0)|(sh|0)<(be|0)){break}if((sh|0)>=(Lb-4-Pb|0)){break}Nb=p+5276+(be*12|0)+(ce<<2)|0;Ke[c[Nb>>2]&1023](ic,Rb,De,Rb,4,li,nc);Ke[c[Nb>>2]&1023](lc,Rb,Ce,Rb,4,li,nc);break a}}while(0);Ce=rc-(ba(be,Rb)|0)-ce|0;De=(d[429488+li|0]|0)+8|0;Pb=(d[429488+nc|0]|0)+4|0;Qb=mc-ce|0;Fd=sh-be|0;Ne[c[zb>>2]&127](Ab,si+Ce|0,32,Rb,De,Pb,Qb,Fd,Jb,Lb);Ci=(be<<5)+ce+(q+(h*1536|0)+848)|0;wd=p+5276+(be*12|0)+(ce<<2)|0;Ke[c[wd>>2]&1023](ic,Rb,Ci,32,4,li,nc);Ne[c[zb>>2]&127](Ab,cc+Ce|0,32,Rb,De,Pb,Qb,Fd,Jb,Lb);Ke[c[wd>>2]&1023](lc,Rb,Ci,32,4,li,nc);break a;break};default:{break a}}}}while(0);if((c[ib>>2]|0)>(M|0)){Ci=(b[Gb+28>>1]>>2)+(u<<4|8)|0;wd=(b[Gb+30>>1]>>2)+D|0;Fd=c[c[jb>>2]>>2]|0;Qb=c[E>>2]|0;Pb=Ci+64+(ba(wd+Hb|0,Qb)|0)|0;Xe[c[P>>2]&4095]((c[Fd>>2]|0)+Pb|0,Qb,4);Qb=(Ci>>1)+64+(ba(c[I>>2]|0,(wd>>1)+Ib|0)|0)|0;wd=c[Fd+4>>2]|0;Xe[c[P>>2]&4095](wd+Qb|0,(c[Fd+8>>2]|0)-wd|0,2)}do{if((a[oc]|0)==0){if((a[Rh]|0)==4){kj=0}else{wd=0;Fd=c[B>>2]|0;while(1){Qb=q+(h*1536|0)+800+(wd<<2)|0;Ci=d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0;h:do{if((Ci|0)!=0){if((Ci&-16843010|0)==0){Xe[c[lb>>2]&4095](Fd,q+(h*1536|0)+(wd<<7)|0,c[E>>2]|0);break}else{lj=Ci;mj=0}while(1){if((mj|0)>=4){break h}Qb=lj&255;do{if((Qb|0)==1){Xe[c[Ya>>2]&4095](Fd+(mj<<2)|0,q+(h*1536|0)+(wd<<7)+(mj<<5)|0,c[E>>2]|0)}else{if(!(Qb>>>0>1>>>0)){break}Xe[c[Xa>>2]&4095](Fd+(mj<<2)|0,q+(h*1536|0)+(wd<<7)+(mj<<5)|0,c[E>>2]|0)}}while(0);Qb=lj>>>8;if((Qb|0)==0){break}else{lj=Qb;mj=mj+1|0}}}}while(0);Ci=wd+1|0;if((Ci|0)<4){wd=Ci;Fd=Fd+(c[E>>2]<<2)|0}else{kj=0;break}}}do{Fd=kj+4|0;wd=q+(h*1536|0)+800+(Fd<<2)|0;nc=d[wd]|d[wd+1|0]<<8|d[wd+2|0]<<16|d[wd+3|0]<<24|0;kj=kj+1|0;i:do{if((nc|0)!=0){wd=c[o+(kj<<2)>>2]|0;if((nc&-16843010|0)==0){Xe[c[kb>>2]&4095](wd,q+(h*1536|0)+(Fd<<7)|0,c[I>>2]|0);break}else{nj=nc;oj=0}while(1){if((oj|0)>=2){break}li=nj&255;do{if((li|0)==1){Xe[c[Ya>>2]&4095](wd+(oj<<2)|0,q+(h*1536|0)+(Fd<<7)+(oj<<5)|0,c[I>>2]|0)}else{if(!(li>>>0>1>>>0)){break}Xe[c[Xa>>2]&4095](wd+(oj<<2)|0,q+(h*1536|0)+(Fd<<7)+(oj<<5)|0,c[I>>2]|0)}}while(0);li=nj>>>8;if((li|0)==0){break i}else{nj=li;oj=oj+1|0}}li=c[I>>2]<<2;Rb=nj;lc=0;while(1){if((lc|0)>=2){break i}Lb=Rb&255;do{if((Lb|0)==1){Xe[c[Ya>>2]&4095](wd+((lc<<2)+li)|0,q+(h*1536|0)+(Fd<<7)+(lc+2<<5)|0,c[I>>2]|0)}else{if(!(Lb>>>0>1>>>0)){break}Xe[c[Xa>>2]&4095](wd+((lc<<2)+li)|0,q+(h*1536|0)+(Fd<<7)+(lc+2<<5)|0,c[I>>2]|0)}}while(0);Lb=Rb>>>8;if((Lb|0)==0){break}else{Rb=Lb;lc=lc+1|0}}}}while(0);}while((kj|0)<2)}else{c[ub>>2]=0;c[ub+4>>2]=0;Fd=(c[Ba>>2]|0)+(u*9|0)|0;nc=Fd|0;x=0;a[nc]=x;x=x>>8;a[nc+1|0]=x;x=x>>8;a[nc+2|0]=x;x=x>>8;a[nc+3|0]=x;nc=Fd+4|0;x=0;a[nc]=x;x=x>>8;a[nc+1|0]=x;x=x>>8;a[nc+2|0]=x;x=x>>8;a[nc+3|0]=x;nc=a[Rh]|0;if((nc<<24>>24|0)==4|(nc<<24>>24|0)==7){break}a[Ca]=0;a[(c[Ba>>2]|0)+(u*9|0)+8|0]=0}}while(0);do{if((a[Na]|0)!=0){nc=c[pb>>2]|0;do{if((a[V]|0)==0){pj=d[qb]|0}else{Fd=a[(d[Gb+5|0]|0)+(p+95)|0]|0;if((a[tb]|0)!=0){pj=Fd;break}pj=(d[qb]|0)+Fd|0}}while(0);if((a[rb]|0)==0){qj=pj}else{qj=(a[(d[Gb+2|0]|0)+(p+173)|0]|0)+pj+(a[(d[Rh]|0)+(p+165)|0]|0)|0}if(qj>>>0<64>>>0){rj=qj}else{rj=-qj>>31&63}Fd=a[sb]|0;if(Fd<<24>>24==0){sj=rj}else{lc=Fd&255;Fd=rj>>((lc+3|0)>>>2);Rb=9-lc|0;sj=(Fd|0)>(Rb|0)?Rb:Fd}a[nc+(u*3|0)|0]=rj;a[nc+(u*3|0)+1|0]=(sj|0)>1?sj&255:1;do{if((a[oc]|0)==0){tj=1}else{Fd=a[Rh]|0;if(Fd<<24>>24==4){tj=1;break}tj=Fd<<24>>24==7|0}}while(0);a[nc+(u*3|0)+2|0]=tj;if(!(mb&(a[Na]|0)!=0&nb)){break}Fd=u+1|0;Rb=c[Pa>>2]|0;lc=Rb+(Fd<<5)|0;li=c[B>>2]|0;if((a[Qa]|0)==0){wd=c[G>>2]|0;Lb=c[L>>2]|0;Jb=c[I>>2]|0;cc=(c[E>>2]|0)*15|0;ic=li+cc|0;ce=c[ic+4>>2]|0;be=lc;c[be>>2]=c[ic>>2];c[be+4>>2]=ce;ce=li+(cc+8)|0;cc=c[ce+4>>2]|0;be=Rb+(Fd<<5)+8|0;c[be>>2]=c[ce>>2];c[be+4>>2]=cc;cc=Jb*7|0;Jb=wd+cc|0;wd=c[Jb+4>>2]|0;be=Rb+(Fd<<5)+16|0;c[be>>2]=c[Jb>>2];c[be+4>>2]=wd;wd=Lb+cc|0;cc=c[wd+4>>2]|0;Lb=Rb+(Fd<<5)+24|0;c[Lb>>2]=c[wd>>2];c[Lb+4>>2]=cc;break}else{cc=(c[E>>2]|0)*15|0;Lb=li+cc|0;wd=c[Lb+4>>2]|0;be=lc;c[be>>2]=c[Lb>>2];c[be+4>>2]=wd;wd=li+(cc+8)|0;cc=c[wd+4>>2]|0;li=Rb+(Fd<<5)+8|0;c[li>>2]=c[wd>>2];c[li+4>>2]=cc;break}}}while(0);if((c[v>>2]|0)>(M|0)){oc=(b[Gb+28>>1]>>2)+(u<<4|8)|0;cc=(b[Gb+30>>1]>>2)+D|0;li=c[c[ob>>2]>>2]|0;wd=c[E>>2]|0;Fd=oc+64+(ba(cc+Hb|0,wd)|0)|0;Xe[c[P>>2]&4095]((c[li>>2]|0)+Fd|0,wd,4);wd=(oc>>1)+64+(ba(c[I>>2]|0,(cc>>1)+Ib|0)|0)|0;cc=c[li+4>>2]|0;Xe[c[P>>2]&4095](cc+wd|0,(c[li+8>>2]|0)-cc|0,2)}cc=(c[B>>2]|0)+16|0;c[B>>2]=cc;li=(c[G>>2]|0)+8|0;c[G>>2]=li;wd=(c[L>>2]|0)+8|0;c[L>>2]=wd;b[t>>1]=(b[t>>1]|0)-64;b[Q>>1]=(b[Q>>1]|0)-64;oc=u+1|0;if((oc|0)>=(e[s>>1]|0)){break}Fb=Fb+1|0;u=oc;Gb=Gb+96|0;N=cc;F=li;K=wd}i=g;return}function B5a(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;f=d[e]|0;g=b|0;h=c[g>>2]|0;i=d[1086680+h|0]|0;j=b+4|0;k=c[j>>2]|0;l=b+16|0;m=c[l>>2]|0;n=h<<i;c[g>>2]=n;h=m<<i;m=k+i|0;do{if((m|0)>-1){i=b+8|0;k=c[i>>2]|0;if(!(k>>>0<(c[b+12>>2]|0)>>>0)){o=h;p=m;break}c[i>>2]=k+2;i=k;o=((de((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535)<<m|h;p=m-16|0}else{o=h;p=m}}while(0);c[j>>2]=p;m=((ba(n-1|0,f)|0)>>8)+1|0;f=m<<16;do{if(o>>>0<f>>>0){c[g>>2]=m;c[l>>2]=o;h=a[e+2|0]|0;i=d[1086680+m|0]|0;k=m<<i;c[g>>2]=k;q=o<<i;r=p+i|0;do{if((r|0)>-1){i=b+8|0;s=c[i>>2]|0;if(!(s>>>0<(c[b+12>>2]|0)>>>0)){t=q;u=r;break}c[i>>2]=s+2;i=s;t=((de((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535)<<r|q;u=r-16|0}else{t=q;u=r}}while(0);c[j>>2]=u;r=((ba(k-1|0,h&255)|0)>>8)+1|0;q=r<<16;i=t>>>0>=q>>>0;s=i&1;v=i?k-r|0:r;c[g>>2]=v;r=t-(i?q:0)|0;c[l>>2]=r;q=(-s&3)+3|0;i=s<<2;s=a[e+q|0]|0;w=d[1086680+v|0]|0;x=v<<w;c[g>>2]=x;v=r<<w;r=u+w|0;do{if((r|0)>-1){w=b+8|0;y=c[w>>2]|0;if(!(y>>>0<(c[b+12>>2]|0)>>>0)){z=v;A=r;break}c[w>>2]=y+2;w=y;z=((de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<r|v;A=r-16|0}else{z=v;A=r}}while(0);c[j>>2]=A;r=((ba(x-1|0,s&255)|0)>>8)+1|0;v=r<<16;k=z>>>0>=v>>>0;h=k?x-r|0:r;c[g>>2]=h;r=z-(k?v:0)|0;c[l>>2]=r;v=(k&1)<<1|i;w=a[e+((k?2:1)+q)|0]|0;k=d[1086680+h|0]|0;y=h<<k;c[g>>2]=y;h=r<<k;r=A+k|0;do{if((r|0)>-1){k=b+8|0;B=c[k>>2]|0;if(!(B>>>0<(c[b+12>>2]|0)>>>0)){C=h;D=r;break}c[k>>2]=B+2;k=B;C=((de((d[k]|d[k+1|0]<<8)<<16>>16|0)|0)&65535)<<r|h;D=r-16|0}else{C=h;D=r}}while(0);c[j>>2]=D;r=((ba(y-1|0,w&255)|0)>>8)+1|0;h=r<<16;q=C>>>0>=h>>>0;i=q?y-r|0:r;c[g>>2]=i;r=C-(q?h:0)|0;c[l>>2]=r;E=v|q&1;F=i;G=D;H=r}else{r=n-m|0;c[g>>2]=r;i=o-f|0;c[l>>2]=i;q=b+8|0;h=b+12|0;x=a[e+9|0]|0;s=d[1086680+r|0]|0;k=r<<s;c[g>>2]=k;r=i<<s;i=p+s|0;do{if((i|0)>-1){s=c[q>>2]|0;if(!(s>>>0<(c[h>>2]|0)>>>0)){I=r;J=i;break}c[q>>2]=s+2;B=s;I=((de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)<<i|r;J=i-16|0}else{I=r;J=i}}while(0);c[j>>2]=J;i=((ba(k-1|0,x&255)|0)>>8)+1|0;r=i<<16;v=I>>>0>=r>>>0;y=v&1;w=v?k-i|0:i;c[g>>2]=w;i=I-(v?r:0)|0;c[l>>2]=i;r=a[e+10|0]|0;v=d[1086680+w|0]|0;B=w<<v;c[g>>2]=B;w=i<<v;i=J+v|0;do{if((i|0)>-1){v=c[q>>2]|0;if(!(v>>>0<(c[h>>2]|0)>>>0)){K=w;L=i;break}c[q>>2]=v+2;s=v;K=((de((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<i|w;L=i-16|0}else{K=w;L=i}}while(0);c[j>>2]=L;i=((ba(B-1|0,r&255)|0)>>8)+1|0;w=i<<16;k=K>>>0>=w>>>0;x=k?B-i|0:i;c[g>>2]=x;i=K-(k?w:0)|0;c[l>>2]=i;w=(k&1)<<1|y;k=a[e+11|0]|0;s=d[1086680+x|0]|0;v=x<<s;c[g>>2]=v;x=i<<s;i=L+s|0;do{if((i|0)>-1){s=c[q>>2]|0;if(!(s>>>0<(c[h>>2]|0)>>>0)){M=x;N=i;break}c[q>>2]=s+2;O=s;M=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<i|x;N=i-16|0}else{M=x;N=i}}while(0);c[j>>2]=N;i=((ba(v-1|0,k&255)|0)>>8)+1|0;x=i<<16;y=M>>>0>=x>>>0;B=y?v-i|0:i;c[g>>2]=B;i=M-(y?x:0)|0;c[l>>2]=i;x=9;r=(y&1)<<2|w;y=B;B=N;O=i;while(1){i=a[e+(x+9)|0]|0;s=d[1086680+y|0]|0;P=y<<s;c[g>>2]=P;Q=O<<s;R=B+s|0;do{if((R|0)>-1){s=c[q>>2]|0;if(!(s>>>0<(c[h>>2]|0)>>>0)){S=Q;T=R;break}c[q>>2]=s+2;U=s;S=((de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)<<R|Q;T=R-16|0}else{S=Q;T=R}}while(0);c[j>>2]=T;R=((ba(P-1|0,i&255)|0)>>8)+1|0;Q=R<<16;U=S>>>0>=Q>>>0;V=U?P-R|0:R;c[g>>2]=V;W=S-(U?Q:0)|0;c[l>>2]=W;X=((U&1)<<x)+r|0;U=x-1|0;if((U|0)>3){x=U;r=X;y=V;B=T;O=W}else{break}}if((X&65520|0)==0){Y=V;Z=T;_=W}else{O=a[e+12|0]|0;B=d[1086680+V|0]|0;y=V<<B;c[g>>2]=y;r=W<<B;x=T+B|0;do{if((x|0)>-1){B=c[q>>2]|0;if(!(B>>>0<(c[h>>2]|0)>>>0)){$=r;aa=x;break}c[q>>2]=B+2;w=B;$=((de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<x|r;aa=x-16|0}else{$=r;aa=x}}while(0);c[j>>2]=aa;x=((ba(y-1|0,O&255)|0)>>8)+1|0;r=x<<16;q=$>>>0>=r>>>0;h=q?y-x|0:x;c[g>>2]=h;x=$-(q?r:0)|0;c[l>>2]=x;if(q){Y=h;Z=aa;_=x}else{E=X;F=h;G=aa;H=x;break}}E=X+8|0;F=Y;G=Z;H=_}}while(0);if((E|0)==0){return 0}_=a[e+1|0]|0;e=d[1086680+F|0]|0;Z=F<<e;c[g>>2]=Z;F=H<<e;H=G+e|0;if(!((H|0)>-1)){ca=F;da=H;c[j>>2]=da;ea=Z-1|0;fa=_&255;ga=ba(ea,fa)|0;ha=ga>>8;ia=ha+1|0;ja=ia<<16;ka=ca>>>0>=ja>>>0;la=Z-ia|0;ma=ka?la:ia;c[g>>2]=ma;na=ka?ja:0;oa=ca-na|0;c[l>>2]=oa;pa=-E|0;qa=ka?pa:E;return qa|0}e=b+8|0;G=c[e>>2]|0;if(!(G>>>0<(c[b+12>>2]|0)>>>0)){ca=F;da=H;c[j>>2]=da;ea=Z-1|0;fa=_&255;ga=ba(ea,fa)|0;ha=ga>>8;ia=ha+1|0;ja=ia<<16;ka=ca>>>0>=ja>>>0;la=Z-ia|0;ma=ka?la:ia;c[g>>2]=ma;na=ka?ja:0;oa=ca-na|0;c[l>>2]=oa;pa=-E|0;qa=ka?pa:E;return qa|0}c[e>>2]=G+2;e=G;ca=((de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535)<<H|F;da=H-16|0;c[j>>2]=da;ea=Z-1|0;fa=_&255;ga=ba(ea,fa)|0;ha=ga>>8;ia=ha+1|0;ja=ia<<16;ka=ca>>>0>=ja>>>0;la=Z-ia|0;ma=ka?la:ia;c[g>>2]=ma;na=ka?ja:0;oa=ca-na|0;c[l>>2]=oa;pa=-E|0;qa=ka?pa:E;return qa|0}function C5a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((b|0)!=0){f=0;return f|0}b=a+188|0;g=a+192|0;h=a+204|0;i=a+196|0;j=a+200|0;a=c[b>>2]|0;k=c[g>>2]|0;l=c[h>>2]|0;m=d[1086680+a|0]|0;n=a<<m;c[b>>2]=n;a=l<<m;l=m+k|0;do{if((l|0)>-1){k=c[i>>2]|0;if(!(k>>>0<(c[j>>2]|0)>>>0)){o=a;p=l;break}c[i>>2]=k+2;m=k;o=((de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535)<<l|a;p=l-16|0}else{o=a;p=l}}while(0);c[g>>2]=p;l=((n<<7)-128>>8)+1|0;a=l<<16;m=o>>>0>=a>>>0;k=m?n-l|0:l;l=o-(m?a:0)|0;c[h>>2]=l;a=(m&1)<<1;m=d[1086680+k|0]|0;o=k<<m;c[b>>2]=o;k=l<<m;l=m+p|0;do{if((l|0)>-1){p=c[i>>2]|0;if(!(p>>>0<(c[j>>2]|0)>>>0)){q=k;r=l;break}c[i>>2]=p+2;m=p;q=((de((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535)<<l|k;r=l-16|0}else{q=k;r=l}}while(0);c[g>>2]=r;r=((o<<7)-128>>8)+1|0;g=r<<16;l=q>>>0>=g>>>0;c[b>>2]=l?o-r|0:r;c[h>>2]=q-(l?g:0);g=l&1|a;if((g|0)==1){f=1;return f|0}else if((g|0)==2){f=(e|0)==2?3:2;return f|0}else{f=-1;return f|0}return 0}function D5a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=a|0;f=c[e>>2]|0;g=d[1086680+f|0]|0;h=a+4|0;i=c[h>>2]|0;j=a+16|0;k=c[j>>2]|0;l=f<<g;c[e>>2]=l;f=k<<g;k=i+g|0;do{if((k|0)>-1){g=a+8|0;i=c[g>>2]|0;if(!(i>>>0<(c[a+12>>2]|0)>>>0)){m=f;n=k;break}c[g>>2]=i+2;g=i;m=((de((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535)<<k|f;n=k-16|0}else{m=f;n=k}}while(0);c[h>>2]=n;k=((l<<7)-128>>8)+1|0;f=k<<16;g=m>>>0>=f>>>0;i=g?l-k|0:k;c[e>>2]=i;k=m-(g?f:0)|0;c[j>>2]=k;if(!g){o=0;return o|0}if((b|0)==0){p=0;q=i;r=n;s=k}else{g=a+8|0;f=a+12|0;m=b;b=0;l=i;i=n;n=k;while(1){k=m-1|0;t=b<<1;u=d[1086680+l|0]|0;v=l<<u;c[e>>2]=v;w=n<<u;x=u+i|0;do{if((x|0)>-1){u=c[g>>2]|0;if(!(u>>>0<(c[f>>2]|0)>>>0)){y=w;z=x;break}c[g>>2]=u+2;A=u;y=((de((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535)<<x|w;z=x-16|0}else{y=w;z=x}}while(0);c[h>>2]=z;x=((v<<7)-128>>8)+1|0;w=x<<16;A=y>>>0>=w>>>0;u=A?v-x|0:x;c[e>>2]=u;x=y-(A?w:0)|0;c[j>>2]=x;w=A&1|t;if((k|0)==0){p=w;q=u;r=z;s=x;break}else{m=k;b=w;l=u;i=z;n=x}}}n=d[1086680+q|0]|0;z=q<<n;c[e>>2]=z;q=s<<n;s=r+n|0;do{if((s|0)>-1){n=a+8|0;r=c[n>>2]|0;if(!(r>>>0<(c[a+12>>2]|0)>>>0)){B=q;C=s;break}c[n>>2]=r+2;n=r;B=((de((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<s|q;C=s-16|0}else{B=q;C=s}}while(0);c[h>>2]=C;C=((z<<7)-128>>8)+1|0;h=C<<16;s=B>>>0>=h>>>0;c[e>>2]=s?z-C|0:C;c[j>>2]=B-(s?h:0);o=s?-p|0:p;return o|0}function E5a(a,b){a=a|0;b=b|0;c[a>>2]=212;c[a+4>>2]=376;c[a+8>>2]=32;c[a+12>>2]=1698;c[a+16>>2]=1076;c[a+20>>2]=864;c[a+24>>2]=102;c[a+28>>2]=170;c[a+32>>2]=280;c[a+36>>2]=204;c[a+40>>2]=6;c[a+44>>2]=326;c[a+48>>2]=238;c[a+52>>2]=248;c[a+56>>2]=260;c[a+60>>2]=1184;c[a+64>>2]=582;c[a+68>>2]=616;c[a+72>>2]=158;c[a+76>>2]=466;c[a+80>>2]=280;c[a+84>>2]=536;c[a+88>>2]=298;c[a+92>>2]=134;c[a+96>>2]=56;c[a+100>>2]=528;c[a+104>>2]=468;c[a+108>>2]=300;c[a+112>>2]=132;c[a+116>>2]=584;c[a+120>>2]=88;c[a+124>>2]=278;c[a+128>>2]=112;c[a+132>>2]=500;c[a+136>>2]=140;c[a+140>>2]=352;c[a+144>>2]=322;c[a+148>>2]=316;c[a+152>>2]=192;c[a+156>>2]=558;c[a+160>>2]=484;c[a+164>>2]=358;c[a+168>>2]=414;c[a+172>>2]=582;c[a+176>>2]=114;c[a+180>>2]=114;c[a+184>>2]=588;c[a+188>>2]=198;c[a+192>>2]=198;c[a+196>>2]=588;c[a+200>>2]=198;c[a+204>>2]=198;c[a+208>>2]=528;c[a+212>>2]=312;c[a+216>>2]=312;c[a+220>>2]=170;c[a+224>>2]=258;c[a+228>>2]=258;c[a+232>>2]=170;c[a+236>>2]=258;c[a+240>>2]=258;c[a+244>>2]=140;c[a+248>>2]=412;c[a+252>>2]=412;c[a+256>>2]=562;c[a+260>>2]=580;c[a+264>>2]=580;c[a+268>>2]=562;c[a+272>>2]=580;c[a+276>>2]=580;return}function F5a(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b[d>>1]|0;f=d+24|0;g=b[f>>1]|0;h=g+e|0;i=d+8|0;j=b[i>>1]|0;k=d+16|0;l=b[k>>1]|0;m=l+j|0;n=j-l|0;l=e-g|0;b[d>>1]=m+h;b[i>>1]=n+l;b[k>>1]=h-m;b[f>>1]=l-n;n=d+2|0;l=b[n>>1]|0;f=d+26|0;m=b[f>>1]|0;h=m+l|0;k=d+10|0;i=b[k>>1]|0;g=d+18|0;e=b[g>>1]|0;j=e+i|0;o=i-e|0;e=l-m|0;b[n>>1]=j+h;b[k>>1]=o+e;b[g>>1]=h-j;b[f>>1]=e-o;o=d+4|0;e=b[o>>1]|0;f=d+28|0;j=b[f>>1]|0;h=j+e|0;g=d+12|0;k=b[g>>1]|0;n=d+20|0;m=b[n>>1]|0;l=m+k|0;i=k-m|0;m=e-j|0;b[o>>1]=l+h;b[g>>1]=i+m;b[n>>1]=h-l;b[f>>1]=m-i;i=d+6|0;m=b[i>>1]|0;f=d+30|0;l=b[f>>1]|0;h=l+m|0;n=d+14|0;g=b[n>>1]|0;o=d+22|0;j=b[o>>1]|0;e=j+g|0;k=g-j|0;j=m-l|0;b[i>>1]=e+h;b[n>>1]=k+j;b[o>>1]=h-e;b[f>>1]=j-k;k=0;do{j=k<<2;f=d+(j<<1)|0;e=b[f>>1]|0;h=b[d+((j|3)<<1)>>1]|0;o=e+3+h|0;n=b[d+((j|1)<<1)>>1]|0;i=b[d+((j|2)<<1)>>1]|0;j=i+n|0;l=n-i|0;i=e-h+3|0;h=f;c[h>>2]=0;c[h+4>>2]=0;b[a+(k<<7)>>1]=(j+o|0)>>>3;b[a+(k<<7)+32>>1]=(l+i|0)>>>3;b[a+(k<<7)+64>>1]=(o-j|0)>>>3;b[a+(k<<7)+96>>1]=(i-l|0)>>>3;k=k+1|0;}while((k|0)<4);return}function G5a(a,c){a=a|0;c=c|0;var d=0;d=((b[c>>1]|0)+3|0)>>>3;b[c>>1]=0;c=d&65535;b[a>>1]=c;b[a+32>>1]=c;b[a+64>>1]=c;b[a+96>>1]=c;b[a+128>>1]=c;b[a+160>>1]=c;b[a+192>>1]=c;b[a+224>>1]=c;b[a+256>>1]=c;b[a+288>>1]=c;b[a+320>>1]=c;b[a+352>>1]=c;b[a+384>>1]=c;b[a+416>>1]=c;b[a+448>>1]=c;b[a+480>>1]=c;return}function H5a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+32|0;h=g|0;j=0;while(1){k=e+(j<<1)|0;l=b[k>>1]|0;m=e+(j+8<<1)|0;n=b[m>>1]|0;o=n+l|0;p=l-n|0;n=e+(j+4<<1)|0;l=b[n>>1]|0;q=e+(j+12<<1)|0;r=b[q>>1]|0;s=((l*35468|0)>>16)-r-((r*20091|0)>>16)|0;t=((l*20091|0)>>16)+l+((r*35468|0)>>16)|0;b[k>>1]=0;b[n>>1]=0;b[m>>1]=0;b[q>>1]=0;q=j<<2;b[h+(q<<1)>>1]=t+o;b[h+((q|1)<<1)>>1]=s+p;b[h+((q|2)<<1)>>1]=p-s;b[h+((q|3)<<1)>>1]=o-t;t=j+1|0;if((t|0)<4){j=t}else{u=c;v=0;break}}while(1){c=b[h+(v<<1)>>1]|0;j=b[h+(v+8<<1)>>1]|0;e=b[h+(v+4<<1)>>1]|0;t=b[h+(v+12<<1)>>1]|0;o=((e*35468|0)>>16)-t-((t*20091|0)>>16)|0;q=((e*20091|0)>>16)+e+((t*35468|0)>>16)|0;t=j+c+4|0;e=(t+q>>3)+(d[u]|0)|0;if(e>>>0>255>>>0){w=-e>>31&255}else{w=e&255}a[u]=w;e=u+1|0;s=c-j+4|0;j=(d[e]|0)+(s+o>>3)|0;if(j>>>0>255>>>0){x=-j>>31&255}else{x=j&255}a[e]=x;e=u+2|0;j=(d[e]|0)+(s-o>>3)|0;if(j>>>0>255>>>0){y=-j>>31&255}else{y=j&255}a[e]=y;e=u+3|0;j=(d[e]|0)+(t-q>>3)|0;if(j>>>0>255>>>0){z=-j>>31&255}else{z=j&255}a[e]=z;e=v+1|0;if((e|0)<4){u=u+f|0;v=e}else{break}}i=g;return}function I5a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=(b[e>>1]|0)+4>>3;b[e>>1]=0;e=0;h=c;while(1){c=(d[h]|0)+g|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=e+1|0;if((c|0)<4){e=c;h=h+f|0}else{break}}return}function J5a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=e|0;h=(b[g>>1]|0)+4>>3;b[g>>1]=0;g=0;i=c;while(1){j=(d[i]|0)+h|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i]=k;j=i+1|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[j]=m;j=i+2|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){n=-l>>31&255}else{n=l&255}a[j]=n;j=i+3|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){o=-l>>31&255}else{o=l&255}a[j]=o;j=g+1|0;if((j|0)<4){g=j;i=i+f|0}else{break}}i=e+32|0;g=(b[i>>1]|0)+4>>3;b[i>>1]=0;i=0;o=c+4|0;while(1){h=(d[o]|0)+g|0;if(h>>>0>255>>>0){p=-h>>31&255}else{p=h&255}a[o]=p;h=o+1|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){q=-n>>31&255}else{q=n&255}a[h]=q;h=o+2|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){r=-n>>31&255}else{r=n&255}a[h]=r;h=o+3|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){s=-n>>31&255}else{s=n&255}a[h]=s;h=i+1|0;if((h|0)<4){i=h;o=o+f|0}else{break}}o=e+64|0;i=(b[o>>1]|0)+4>>3;b[o>>1]=0;o=0;s=c+8|0;while(1){g=(d[s]|0)+i|0;if(g>>>0>255>>>0){t=-g>>31&255}else{t=g&255}a[s]=t;g=s+1|0;r=(d[g]|0)+i|0;if(r>>>0>255>>>0){u=-r>>31&255}else{u=r&255}a[g]=u;g=s+2|0;r=(d[g]|0)+i|0;if(r>>>0>255>>>0){v=-r>>31&255}else{v=r&255}a[g]=v;g=s+3|0;r=(d[g]|0)+i|0;if(r>>>0>255>>>0){w=-r>>31&255}else{w=r&255}a[g]=w;g=o+1|0;if((g|0)<4){o=g;s=s+f|0}else{break}}s=e+96|0;e=(b[s>>1]|0)+4>>3;b[s>>1]=0;s=0;o=c+12|0;while(1){c=(d[o]|0)+e|0;if(c>>>0>255>>>0){x=-c>>31&255}else{x=c&255}a[o]=x;c=o+1|0;w=(d[c]|0)+e|0;if(w>>>0>255>>>0){y=-w>>31&255}else{y=w&255}a[c]=y;c=o+2|0;w=(d[c]|0)+e|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[c]=z;c=o+3|0;w=(d[c]|0)+e|0;if(w>>>0>255>>>0){A=-w>>31&255}else{A=w&255}a[c]=A;c=s+1|0;if((c|0)<4){s=c;o=o+f|0}else{break}}return}function K5a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=e|0;h=(b[g>>1]|0)+4>>3;b[g>>1]=0;g=0;i=c;while(1){j=(d[i]|0)+h|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i]=k;j=i+1|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[j]=m;j=i+2|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){n=-l>>31&255}else{n=l&255}a[j]=n;j=i+3|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){o=-l>>31&255}else{o=l&255}a[j]=o;j=g+1|0;if((j|0)<4){g=j;i=i+f|0}else{break}}i=e+32|0;g=(b[i>>1]|0)+4>>3;b[i>>1]=0;i=0;o=c+4|0;while(1){h=(d[o]|0)+g|0;if(h>>>0>255>>>0){p=-h>>31&255}else{p=h&255}a[o]=p;h=o+1|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){q=-n>>31&255}else{q=n&255}a[h]=q;h=o+2|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){r=-n>>31&255}else{r=n&255}a[h]=r;h=o+3|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){s=-n>>31&255}else{s=n&255}a[h]=s;h=i+1|0;if((h|0)<4){i=h;o=o+f|0}else{break}}o=f<<2;i=e+64|0;s=(b[i>>1]|0)+4>>3;b[i>>1]=0;i=0;g=c+o|0;while(1){r=(d[g]|0)+s|0;if(r>>>0>255>>>0){t=-r>>31&255}else{t=r&255}a[g]=t;r=g+1|0;q=(d[r]|0)+s|0;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[r]=u;r=g+2|0;q=(d[r]|0)+s|0;if(q>>>0>255>>>0){v=-q>>31&255}else{v=q&255}a[r]=v;r=g+3|0;q=(d[r]|0)+s|0;if(q>>>0>255>>>0){w=-q>>31&255}else{w=q&255}a[r]=w;r=i+1|0;if((r|0)<4){i=r;g=g+f|0}else{break}}g=e+96|0;e=(b[g>>1]|0)+4>>3;b[g>>1]=0;g=0;i=c+(o+4)|0;while(1){o=(d[i]|0)+e|0;if(o>>>0>255>>>0){x=-o>>31&255}else{x=o&255}a[i]=x;o=i+1|0;c=(d[o]|0)+e|0;if(c>>>0>255>>>0){y=-c>>31&255}else{y=c&255}a[o]=y;o=i+2|0;c=(d[o]|0)+e|0;if(c>>>0>255>>>0){z=-c>>31&255}else{z=c&255}a[o]=z;o=i+3|0;c=(d[o]|0)+e|0;if(c>>>0>255>>>0){A=-c>>31&255}else{A=c&255}a[o]=A;o=g+1|0;if((o|0)<4){g=o;i=i+f|0}else{break}}return}function L5a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=c*-3|0;i=c*-2|0;j=c<<1;k=c*3|0;l=c*-4|0;m=0;do{n=b+m|0;o=b+(m+h)|0;p=d[o]|0;q=b+(m+i)|0;r=d[q]|0;s=b+(m-c)|0;t=d[s]|0;u=d[n]|0;v=b+(m+c)|0;w=d[v]|0;x=b+(m+j)|0;y=d[x]|0;z=d[b+(m+k)|0]|0;A=t-u|0;B=r-w|0;do{if(((((B|0)>-1?B:-B|0)>>1)+(((A|0)>-1?A:-A|0)<<1)|0)<=(e|0)){C=(d[b+(m+l)|0]|0)-p|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=p-r|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=r-t|0;D=(C|0)>-1?C:-C|0;if((D|0)>(f|0)){break}C=z-y|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=y-w|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=w-u|0;E=(C|0)>-1?C:-C|0;if((E|0)>(f|0)){break}if((D|0)>(g|0)|(E|0)>(g|0)){E=d[1235032+(((u-t|0)*3|0)+1024+(d[1235032+(r+1152-w)|0]|0))|0]|0;D=E-124|0;C=E-125|0;a[s]=a[1235032+(((C|0)>127?15:C>>3)+(t|1024))|0]|0;a[n]=a[1235032+((u|1024)-((D|0)>127?15:D>>3))|0]|0;break}else{D=(d[1235032+(((u-t|0)*3|0)+1024+(d[1235032+(r+1152-w)|0]|0))|0]|0)-128|0;C=(D*27|0)+63>>7;E=(D*18|0)+63>>7;F=(D*9|0)+63>>7;a[o]=a[1235032+(F+(p|1024))|0]|0;a[q]=a[1235032+(E+(r|1024))|0]|0;a[s]=a[1235032+(C+(t|1024))|0]|0;a[n]=a[1235032+((u|1024)-C)|0]|0;a[v]=a[1235032+((w|1024)-E)|0]|0;a[x]=a[1235032+((y|1024)-F)|0]|0;break}}}while(0);m=m+1|0;}while((m|0)<16);return}function M5a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=0;do{i=ba(h,c)|0;j=b+i|0;k=b+(i-3)|0;l=d[k]|0;m=b+(i-2)|0;n=d[m]|0;o=b+(i-1)|0;p=d[o]|0;q=d[j]|0;r=b+(i+1)|0;s=d[r]|0;t=b+(i+2)|0;u=d[t]|0;v=d[b+(i+3)|0]|0;w=p-q|0;x=n-s|0;do{if(((((x|0)>-1?x:-x|0)>>1)+(((w|0)>-1?w:-w|0)<<1)|0)<=(e|0)){y=(d[b+(i-4)|0]|0)-l|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=l-n|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=n-p|0;z=(y|0)>-1?y:-y|0;if((z|0)>(f|0)){break}y=v-u|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=u-s|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=s-q|0;A=(y|0)>-1?y:-y|0;if((A|0)>(f|0)){break}if((z|0)>(g|0)|(A|0)>(g|0)){A=d[1235032+(((q-p|0)*3|0)+1024+(d[1235032+(n+1152-s)|0]|0))|0]|0;z=A-124|0;y=A-125|0;a[o]=a[1235032+(((y|0)>127?15:y>>3)+(p|1024))|0]|0;a[j]=a[1235032+((q|1024)-((z|0)>127?15:z>>3))|0]|0;break}else{z=(d[1235032+(((q-p|0)*3|0)+1024+(d[1235032+(n+1152-s)|0]|0))|0]|0)-128|0;y=(z*27|0)+63>>7;A=(z*18|0)+63>>7;B=(z*9|0)+63>>7;a[k]=a[1235032+(B+(l|1024))|0]|0;a[m]=a[1235032+(A+(n|1024))|0]|0;a[o]=a[1235032+(y+(p|1024))|0]|0;a[j]=a[1235032+((q|1024)-y)|0]|0;a[r]=a[1235032+((s|1024)-A)|0]|0;a[t]=a[1235032+((u|1024)-B)|0]|0;break}}}while(0);h=h+1|0;}while((h|0)<16);return}function N5a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;i=e*-3|0;j=e*-2|0;k=e<<1;l=e*3|0;m=e*-4|0;n=0;while(1){o=b+n|0;p=b+(n+i)|0;q=d[p]|0;r=b+(n+j)|0;s=d[r]|0;t=b+(n-e)|0;u=d[t]|0;v=d[o]|0;w=b+(n+e)|0;x=d[w]|0;y=b+(n+k)|0;z=d[y]|0;A=d[b+(n+l)|0]|0;B=u-v|0;C=s-x|0;do{if(((((C|0)>-1?C:-C|0)>>1)+(((B|0)>-1?B:-B|0)<<1)|0)<=(f|0)){D=(d[b+(n+m)|0]|0)-q|0;if((((D|0)>-1?D:-D|0)|0)>(g|0)){break}D=q-s|0;if((((D|0)>-1?D:-D|0)|0)>(g|0)){break}D=s-u|0;E=(D|0)>-1?D:-D|0;if((E|0)>(g|0)){break}D=A-z|0;if((((D|0)>-1?D:-D|0)|0)>(g|0)){break}D=z-x|0;if((((D|0)>-1?D:-D|0)|0)>(g|0)){break}D=x-v|0;F=(D|0)>-1?D:-D|0;if((F|0)>(g|0)){break}if((E|0)>(h|0)|(F|0)>(h|0)){F=d[1235032+(((v-u|0)*3|0)+1024+(d[1235032+(s+1152-x)|0]|0))|0]|0;E=F-124|0;D=F-125|0;a[t]=a[1235032+(((D|0)>127?15:D>>3)+(u|1024))|0]|0;a[o]=a[1235032+((v|1024)-((E|0)>127?15:E>>3))|0]|0;break}else{E=(d[1235032+(((v-u|0)*3|0)+1024+(d[1235032+(s+1152-x)|0]|0))|0]|0)-128|0;D=(E*27|0)+63>>7;F=(E*18|0)+63>>7;G=(E*9|0)+63>>7;a[p]=a[1235032+(G+(q|1024))|0]|0;a[r]=a[1235032+(F+(s|1024))|0]|0;a[t]=a[1235032+(D+(u|1024))|0]|0;a[o]=a[1235032+((v|1024)-D)|0]|0;a[w]=a[1235032+((x|1024)-F)|0]|0;a[y]=a[1235032+((z|1024)-G)|0]|0;break}}}while(0);z=n+1|0;if((z|0)<8){n=z}else{H=0;break}}do{n=c+H|0;b=c+(H+i)|0;z=d[b]|0;y=c+(H+j)|0;x=d[y]|0;w=c+(H-e)|0;v=d[w]|0;o=d[n]|0;u=c+(H+e)|0;t=d[u]|0;s=c+(H+k)|0;r=d[s]|0;q=d[c+(H+l)|0]|0;p=v-o|0;A=x-t|0;do{if(((((A|0)>-1?A:-A|0)>>1)+(((p|0)>-1?p:-p|0)<<1)|0)<=(f|0)){B=(d[c+(H+m)|0]|0)-z|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=z-x|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=x-v|0;C=(B|0)>-1?B:-B|0;if((C|0)>(g|0)){break}B=q-r|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=r-t|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=t-o|0;G=(B|0)>-1?B:-B|0;if((G|0)>(g|0)){break}if((C|0)>(h|0)|(G|0)>(h|0)){G=d[1235032+(((o-v|0)*3|0)+1024+(d[1235032+(x+1152-t)|0]|0))|0]|0;C=G-124|0;B=G-125|0;a[w]=a[1235032+(((B|0)>127?15:B>>3)+(v|1024))|0]|0;a[n]=a[1235032+((o|1024)-((C|0)>127?15:C>>3))|0]|0;break}else{C=(d[1235032+(((o-v|0)*3|0)+1024+(d[1235032+(x+1152-t)|0]|0))|0]|0)-128|0;B=(C*27|0)+63>>7;G=(C*18|0)+63>>7;F=(C*9|0)+63>>7;a[b]=a[1235032+(F+(z|1024))|0]|0;a[y]=a[1235032+(G+(x|1024))|0]|0;a[w]=a[1235032+(B+(v|1024))|0]|0;a[n]=a[1235032+((o|1024)-B)|0]|0;a[u]=a[1235032+((t|1024)-G)|0]|0;a[s]=a[1235032+((r|1024)-F)|0]|0;break}}}while(0);H=H+1|0;}while((H|0)<8);return}function O5a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=0;while(1){j=ba(i,e)|0;k=b+j|0;l=b+(j-3)|0;m=d[l]|0;n=b+(j-2)|0;o=d[n]|0;p=b+(j-1)|0;q=d[p]|0;r=d[k]|0;s=b+(j+1)|0;t=d[s]|0;u=b+(j+2)|0;v=d[u]|0;w=d[b+(j+3)|0]|0;x=q-r|0;y=o-t|0;do{if(((((y|0)>-1?y:-y|0)>>1)+(((x|0)>-1?x:-x|0)<<1)|0)<=(f|0)){z=(d[b+(j-4)|0]|0)-m|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=m-o|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=o-q|0;A=(z|0)>-1?z:-z|0;if((A|0)>(g|0)){break}z=w-v|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=v-t|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=t-r|0;B=(z|0)>-1?z:-z|0;if((B|0)>(g|0)){break}if((A|0)>(h|0)|(B|0)>(h|0)){B=d[1235032+(((r-q|0)*3|0)+1024+(d[1235032+(o+1152-t)|0]|0))|0]|0;A=B-124|0;z=B-125|0;a[p]=a[1235032+(((z|0)>127?15:z>>3)+(q|1024))|0]|0;a[k]=a[1235032+((r|1024)-((A|0)>127?15:A>>3))|0]|0;break}else{A=(d[1235032+(((r-q|0)*3|0)+1024+(d[1235032+(o+1152-t)|0]|0))|0]|0)-128|0;z=(A*27|0)+63>>7;B=(A*18|0)+63>>7;C=(A*9|0)+63>>7;a[l]=a[1235032+(C+(m|1024))|0]|0;a[n]=a[1235032+(B+(o|1024))|0]|0;a[p]=a[1235032+(z+(q|1024))|0]|0;a[k]=a[1235032+((r|1024)-z)|0]|0;a[s]=a[1235032+((t|1024)-B)|0]|0;a[u]=a[1235032+((v|1024)-C)|0]|0;break}}}while(0);v=i+1|0;if((v|0)<8){i=v}else{D=0;break}}do{i=ba(D,e)|0;b=c+i|0;v=c+(i-3)|0;u=d[v]|0;t=c+(i-2)|0;s=d[t]|0;r=c+(i-1)|0;k=d[r]|0;q=d[b]|0;p=c+(i+1)|0;o=d[p]|0;n=c+(i+2)|0;m=d[n]|0;l=d[c+(i+3)|0]|0;w=k-q|0;j=s-o|0;do{if(((((j|0)>-1?j:-j|0)>>1)+(((w|0)>-1?w:-w|0)<<1)|0)<=(f|0)){x=(d[c+(i-4)|0]|0)-u|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=u-s|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=s-k|0;y=(x|0)>-1?x:-x|0;if((y|0)>(g|0)){break}x=l-m|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=m-o|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=o-q|0;C=(x|0)>-1?x:-x|0;if((C|0)>(g|0)){break}if((y|0)>(h|0)|(C|0)>(h|0)){C=d[1235032+(((q-k|0)*3|0)+1024+(d[1235032+(s+1152-o)|0]|0))|0]|0;y=C-124|0;x=C-125|0;a[r]=a[1235032+(((x|0)>127?15:x>>3)+(k|1024))|0]|0;a[b]=a[1235032+((q|1024)-((y|0)>127?15:y>>3))|0]|0;break}else{y=(d[1235032+(((q-k|0)*3|0)+1024+(d[1235032+(s+1152-o)|0]|0))|0]|0)-128|0;x=(y*27|0)+63>>7;C=(y*18|0)+63>>7;B=(y*9|0)+63>>7;a[v]=a[1235032+(B+(u|1024))|0]|0;a[t]=a[1235032+(C+(s|1024))|0]|0;a[r]=a[1235032+(x+(k|1024))|0]|0;a[b]=a[1235032+((q|1024)-x)|0]|0;a[p]=a[1235032+((o|1024)-C)|0]|0;a[n]=a[1235032+((m|1024)-B)|0]|0;break}}}while(0);D=D+1|0;}while((D|0)<8);return}function P5a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=c*-3|0;i=c*-2|0;j=c<<1;k=c*3|0;l=c*-4|0;m=0;do{n=b+m|0;o=d[b+(m+h)|0]|0;p=b+(m+i)|0;q=d[p]|0;r=b+(m-c)|0;s=d[r]|0;t=d[n]|0;u=b+(m+c)|0;v=d[u]|0;w=d[b+(m+j)|0]|0;x=d[b+(m+k)|0]|0;y=s-t|0;z=q-v|0;do{if(((((z|0)>-1?z:-z|0)>>1)+(((y|0)>-1?y:-y|0)<<1)|0)<=(e|0)){A=(d[b+(m+l)|0]|0)-o|0;if((((A|0)>-1?A:-A|0)|0)>(f|0)){break}A=o-q|0;if((((A|0)>-1?A:-A|0)|0)>(f|0)){break}A=q-s|0;B=(A|0)>-1?A:-A|0;if((B|0)>(f|0)){break}A=x-w|0;if((((A|0)>-1?A:-A|0)|0)>(f|0)){break}A=w-v|0;if((((A|0)>-1?A:-A|0)|0)>(f|0)){break}A=v-t|0;C=(A|0)>-1?A:-A|0;if((C|0)>(f|0)){break}A=(t-s|0)*3|0;if((B|0)>(g|0)|(C|0)>(g|0)){C=d[1235032+(A+1024+(d[1235032+(q+1152-v)|0]|0))|0]|0;B=C-124|0;D=C-125|0;a[r]=a[1235032+(((D|0)>127?15:D>>3)+(s|1024))|0]|0;a[n]=a[1235032+((t|1024)-((B|0)>127?15:B>>3))|0]|0;break}else{B=d[A+1236184|0]|0;A=B-124|0;D=(A|0)>127?15:A>>3;A=B-125|0;a[r]=a[1235032+(((A|0)>127?15:A>>3)+(s|1024))|0]|0;a[n]=a[1235032+((t|1024)-D)|0]|0;A=D+1>>1;a[p]=a[1235032+(A+(q|1024))|0]|0;a[u]=a[1235032+((v|1024)-A)|0]|0;break}}}while(0);m=m+1|0;}while((m|0)<16);return}function Q5a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=0;do{i=ba(h,c)|0;j=b+i|0;k=d[b+(i-3)|0]|0;l=b+(i-2)|0;m=d[l]|0;n=b+(i-1)|0;o=d[n]|0;p=d[j]|0;q=b+(i+1)|0;r=d[q]|0;s=d[b+(i+2)|0]|0;t=d[b+(i+3)|0]|0;u=o-p|0;v=m-r|0;do{if(((((v|0)>-1?v:-v|0)>>1)+(((u|0)>-1?u:-u|0)<<1)|0)<=(e|0)){w=(d[b+(i-4)|0]|0)-k|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=k-m|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=m-o|0;x=(w|0)>-1?w:-w|0;if((x|0)>(f|0)){break}w=t-s|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=s-r|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=r-p|0;y=(w|0)>-1?w:-w|0;if((y|0)>(f|0)){break}w=(p-o|0)*3|0;if((x|0)>(g|0)|(y|0)>(g|0)){y=d[1235032+(w+1024+(d[1235032+(m+1152-r)|0]|0))|0]|0;x=y-124|0;z=y-125|0;a[n]=a[1235032+(((z|0)>127?15:z>>3)+(o|1024))|0]|0;a[j]=a[1235032+((p|1024)-((x|0)>127?15:x>>3))|0]|0;break}else{x=d[w+1236184|0]|0;w=x-124|0;z=(w|0)>127?15:w>>3;w=x-125|0;a[n]=a[1235032+(((w|0)>127?15:w>>3)+(o|1024))|0]|0;a[j]=a[1235032+((p|1024)-z)|0]|0;w=z+1>>1;a[l]=a[1235032+(w+(m|1024))|0]|0;a[q]=a[1235032+((r|1024)-w)|0]|0;break}}}while(0);h=h+1|0;}while((h|0)<16);return}function R5a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;i=e*-3|0;j=e*-2|0;k=e<<1;l=e*3|0;m=e*-4|0;n=0;while(1){o=b+n|0;p=d[b+(n+i)|0]|0;q=b+(n+j)|0;r=d[q]|0;s=b+(n-e)|0;t=d[s]|0;u=d[o]|0;v=b+(n+e)|0;w=d[v]|0;x=d[b+(n+k)|0]|0;y=d[b+(n+l)|0]|0;z=t-u|0;A=r-w|0;do{if(((((A|0)>-1?A:-A|0)>>1)+(((z|0)>-1?z:-z|0)<<1)|0)<=(f|0)){B=(d[b+(n+m)|0]|0)-p|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=p-r|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=r-t|0;C=(B|0)>-1?B:-B|0;if((C|0)>(g|0)){break}B=y-x|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=x-w|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=w-u|0;D=(B|0)>-1?B:-B|0;if((D|0)>(g|0)){break}B=(u-t|0)*3|0;if((C|0)>(h|0)|(D|0)>(h|0)){D=d[1235032+(B+1024+(d[1235032+(r+1152-w)|0]|0))|0]|0;C=D-124|0;E=D-125|0;a[s]=a[1235032+(((E|0)>127?15:E>>3)+(t|1024))|0]|0;a[o]=a[1235032+((u|1024)-((C|0)>127?15:C>>3))|0]|0;break}else{C=d[B+1236184|0]|0;B=C-124|0;E=(B|0)>127?15:B>>3;B=C-125|0;a[s]=a[1235032+(((B|0)>127?15:B>>3)+(t|1024))|0]|0;a[o]=a[1235032+((u|1024)-E)|0]|0;B=E+1>>1;a[q]=a[1235032+(B+(r|1024))|0]|0;a[v]=a[1235032+((w|1024)-B)|0]|0;break}}}while(0);w=n+1|0;if((w|0)<8){n=w}else{F=0;break}}do{n=c+F|0;b=d[c+(F+i)|0]|0;w=c+(F+j)|0;v=d[w]|0;r=c+(F-e)|0;q=d[r]|0;u=d[n]|0;o=c+(F+e)|0;t=d[o]|0;s=d[c+(F+k)|0]|0;x=d[c+(F+l)|0]|0;y=q-u|0;p=v-t|0;do{if(((((p|0)>-1?p:-p|0)>>1)+(((y|0)>-1?y:-y|0)<<1)|0)<=(f|0)){z=(d[c+(F+m)|0]|0)-b|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=b-v|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=v-q|0;A=(z|0)>-1?z:-z|0;if((A|0)>(g|0)){break}z=x-s|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=s-t|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=t-u|0;B=(z|0)>-1?z:-z|0;if((B|0)>(g|0)){break}z=(u-q|0)*3|0;if((A|0)>(h|0)|(B|0)>(h|0)){B=d[1235032+(z+1024+(d[1235032+(v+1152-t)|0]|0))|0]|0;A=B-124|0;E=B-125|0;a[r]=a[1235032+(((E|0)>127?15:E>>3)+(q|1024))|0]|0;a[n]=a[1235032+((u|1024)-((A|0)>127?15:A>>3))|0]|0;break}else{A=d[z+1236184|0]|0;z=A-124|0;E=(z|0)>127?15:z>>3;z=A-125|0;a[r]=a[1235032+(((z|0)>127?15:z>>3)+(q|1024))|0]|0;a[n]=a[1235032+((u|1024)-E)|0]|0;z=E+1>>1;a[w]=a[1235032+(z+(v|1024))|0]|0;a[o]=a[1235032+((t|1024)-z)|0]|0;break}}}while(0);F=F+1|0;}while((F|0)<8);return}function S5a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=0;while(1){j=ba(i,e)|0;k=b+j|0;l=d[b+(j-3)|0]|0;m=b+(j-2)|0;n=d[m]|0;o=b+(j-1)|0;p=d[o]|0;q=d[k]|0;r=b+(j+1)|0;s=d[r]|0;t=d[b+(j+2)|0]|0;u=d[b+(j+3)|0]|0;v=p-q|0;w=n-s|0;do{if(((((w|0)>-1?w:-w|0)>>1)+(((v|0)>-1?v:-v|0)<<1)|0)<=(f|0)){x=(d[b+(j-4)|0]|0)-l|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=l-n|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=n-p|0;y=(x|0)>-1?x:-x|0;if((y|0)>(g|0)){break}x=u-t|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=t-s|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=s-q|0;z=(x|0)>-1?x:-x|0;if((z|0)>(g|0)){break}x=(q-p|0)*3|0;if((y|0)>(h|0)|(z|0)>(h|0)){z=d[1235032+(x+1024+(d[1235032+(n+1152-s)|0]|0))|0]|0;y=z-124|0;A=z-125|0;a[o]=a[1235032+(((A|0)>127?15:A>>3)+(p|1024))|0]|0;a[k]=a[1235032+((q|1024)-((y|0)>127?15:y>>3))|0]|0;break}else{y=d[x+1236184|0]|0;x=y-124|0;A=(x|0)>127?15:x>>3;x=y-125|0;a[o]=a[1235032+(((x|0)>127?15:x>>3)+(p|1024))|0]|0;a[k]=a[1235032+((q|1024)-A)|0]|0;x=A+1>>1;a[m]=a[1235032+(x+(n|1024))|0]|0;a[r]=a[1235032+((s|1024)-x)|0]|0;break}}}while(0);s=i+1|0;if((s|0)<8){i=s}else{B=0;break}}do{i=ba(B,e)|0;b=c+i|0;s=d[c+(i-3)|0]|0;r=c+(i-2)|0;n=d[r]|0;m=c+(i-1)|0;q=d[m]|0;k=d[b]|0;p=c+(i+1)|0;o=d[p]|0;t=d[c+(i+2)|0]|0;u=d[c+(i+3)|0]|0;l=q-k|0;j=n-o|0;do{if(((((j|0)>-1?j:-j|0)>>1)+(((l|0)>-1?l:-l|0)<<1)|0)<=(f|0)){v=(d[c+(i-4)|0]|0)-s|0;if((((v|0)>-1?v:-v|0)|0)>(g|0)){break}v=s-n|0;if((((v|0)>-1?v:-v|0)|0)>(g|0)){break}v=n-q|0;w=(v|0)>-1?v:-v|0;if((w|0)>(g|0)){break}v=u-t|0;if((((v|0)>-1?v:-v|0)|0)>(g|0)){break}v=t-o|0;if((((v|0)>-1?v:-v|0)|0)>(g|0)){break}v=o-k|0;x=(v|0)>-1?v:-v|0;if((x|0)>(g|0)){break}v=(k-q|0)*3|0;if((w|0)>(h|0)|(x|0)>(h|0)){x=d[1235032+(v+1024+(d[1235032+(n+1152-o)|0]|0))|0]|0;w=x-124|0;A=x-125|0;a[m]=a[1235032+(((A|0)>127?15:A>>3)+(q|1024))|0]|0;a[b]=a[1235032+((k|1024)-((w|0)>127?15:w>>3))|0]|0;break}else{w=d[v+1236184|0]|0;v=w-124|0;A=(v|0)>127?15:v>>3;v=w-125|0;a[m]=a[1235032+(((v|0)>127?15:v>>3)+(q|1024))|0]|0;a[b]=a[1235032+((k|1024)-A)|0]|0;v=A+1>>1;a[r]=a[1235032+(v+(n|1024))|0]|0;a[p]=a[1235032+((o|1024)-v)|0]|0;break}}}while(0);B=B+1|0;}while((B|0)<8);return}function T5a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c*-2|0;g=0;do{h=b+g|0;i=d[b+(g+f)|0]|0;j=b+(g-c)|0;k=d[j]|0;l=d[h]|0;m=d[b+(g+c)|0]|0;n=k-l|0;o=i-m|0;if(((((o|0)>-1?o:-o|0)>>1)+(((n|0)>-1?n:-n|0)<<1)|0)<=(e|0)){n=d[1235032+(((l-k|0)*3|0)+1024+(d[1235032+(i+1152-m)|0]|0))|0]|0;m=n-124|0;i=n-125|0;a[j]=a[1235032+(((i|0)>127?15:i>>3)+(k|1024))|0]|0;a[h]=a[1235032+((l|1024)-((m|0)>127?15:m>>3))|0]|0}g=g+1|0;}while((g|0)<16);return}function U5a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=0;do{g=ba(f,c)|0;h=b+g|0;i=d[b+(g-2)|0]|0;j=b+(g-1)|0;k=d[j]|0;l=d[h]|0;m=d[b+(g+1)|0]|0;g=k-l|0;n=i-m|0;if(((((n|0)>-1?n:-n|0)>>1)+(((g|0)>-1?g:-g|0)<<1)|0)<=(e|0)){g=d[1235032+(((l-k|0)*3|0)+1024+(d[1235032+(i+1152-m)|0]|0))|0]|0;m=g-124|0;i=g-125|0;a[j]=a[1235032+(((i|0)>127?15:i>>3)+(k|1024))|0]|0;a[h]=a[1235032+((l|1024)-((m|0)>127?15:m>>3))|0]|0}f=f+1|0;}while((f|0)<16);return}function V5a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)>0){h=c;i=a;j=0}else{return}while(1){UGb(i|0,h|0,16)|0;a=j+1|0;if((a|0)<(e|0)){h=h+d|0;i=i+b|0;j=a}else{break}}return}function W5a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=h-1|0;if((g|0)<=0){return}h=d[429506+(i*6|0)|0]|0;j=d[429505+(i*6|0)|0]|0;k=d[429507+(i*6|0)|0]|0;l=d[429508+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){m=0;while(1){n=ba(d[i+m|0]|0,h)|0;o=ba(d[i+(m-1)|0]|0,j)|0;p=m+1|0;q=ba(d[i+p|0]|0,k)|0;a[e+m|0]=a[(n+64-o+q-(ba(d[i+(m+2)|0]|0,l)|0)>>7)+1236056|0]|0;if((p|0)<16){m=p}else{break}}m=b+1|0;if((m|0)<(g|0)){i=i+f|0;e=e+c|0;b=m}else{break}}return}function X5a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=h-1|0;if((g|0)<=0){return}h=d[429506+(i*6|0)|0]|0;j=d[429505+(i*6|0)|0]|0;k=d[429504+(i*6|0)|0]|0;l=d[429507+(i*6|0)|0]|0;m=d[429508+(i*6|0)|0]|0;n=d[429509+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){o=0;while(1){p=ba(d[i+o|0]|0,h)|0;q=ba(d[i+(o-1)|0]|0,j)|0;r=ba(d[i+(o-2)|0]|0,k)|0;s=o+1|0;t=ba(d[i+s|0]|0,l)|0;u=ba(d[i+(o+2)|0]|0,m)|0;a[e+o|0]=a[(p+64-q+r+t-u+(ba(d[i+(o+3)|0]|0,n)|0)>>7)+1236056|0]|0;if((s|0)<16){o=s}else{break}}o=b+1|0;if((o|0)<(g|0)){i=i+f|0;e=e+c|0;b=o}else{break}}return}function Y5a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i-1|0;if((g|0)<=0){return}i=d[429506+(h*6|0)|0]|0;j=d[429505+(h*6|0)|0]|0;k=d[429507+(h*6|0)|0]|0;l=d[429508+(h*6|0)|0]|0;h=f<<1;m=e;e=b;b=0;while(1){n=0;do{o=ba(d[m+n|0]|0,i)|0;p=ba(d[m+(n-f)|0]|0,j)|0;q=ba(d[m+(n+f)|0]|0,k)|0;a[e+n|0]=a[(o+64-p+q-(ba(d[m+(n+h)|0]|0,l)|0)>>7)+1236056|0]|0;n=n+1|0;}while((n|0)<16);n=b+1|0;if((n|0)<(g|0)){m=m+f|0;e=e+c|0;b=n}else{break}}return}function Z5a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+560|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429507+(m*6|0)|0]|0;q=d[429508+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;r=l|0;while(1){s=0;t=a[m]|0;u=a[m+1|0]|0;while(1){v=ba(t&255,n)|0;w=ba(d[m+(s-1)|0]|0,o)|0;x=s+1|0;y=ba(u&255,p)|0;z=a[m+(s+2)|0]|0;a[r+s|0]=a[(v+64-w+y-(ba(z&255,q)|0)>>7)+1236056|0]|0;if((x|0)<16){s=x;t=u;u=z}else{break}}u=e+1|0;if((u|0)<(h|0)){m=m+f|0;e=u;r=r+16|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(r*6|0)|0]|0;e=d[429505+(r*6|0)|0]|0;f=d[429507+(r*6|0)|0]|0;m=d[429508+(r*6|0)|0]|0;r=b;b=0;h=l+16|0;while(1){l=0;do{q=ba(d[h+l|0]|0,j)|0;p=ba(d[h+(l-16)|0]|0,e)|0;o=ba(d[h+(l+16)|0]|0,f)|0;a[r+l|0]=a[(q+64-p+o-(ba(d[h+(l+32)|0]|0,m)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<16);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;h=h+16|0}else{break}}i=k;return}function _5a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+560|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429504+(m*6|0)|0]|0;q=d[429507+(m*6|0)|0]|0;r=d[429508+(m*6|0)|0]|0;s=d[429509+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ba(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ba(A&255,o)|0;C=ba(w&255,p)|0;D=u+1|0;E=ba(x&255,q)|0;F=ba(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ba(G&255,s)|0)>>7)+1236056|0]|0;if((D|0)<16){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+16|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(t*6|0)|0]|0;e=d[429505+(t*6|0)|0]|0;f=d[429507+(t*6|0)|0]|0;m=d[429508+(t*6|0)|0]|0;t=b;b=0;h=l+16|0;while(1){l=0;do{s=ba(d[h+l|0]|0,j)|0;r=ba(d[h+(l-16)|0]|0,e)|0;q=ba(d[h+(l+16)|0]|0,f)|0;a[t+l|0]=a[(s+64-r+q-(ba(d[h+(l+32)|0]|0,m)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<16);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;h=h+16|0}else{break}}i=k;return}function $5a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i-1|0;if((g|0)<=0){return}i=d[429506+(h*6|0)|0]|0;j=d[429505+(h*6|0)|0]|0;k=d[429504+(h*6|0)|0]|0;l=f<<1;m=d[429507+(h*6|0)|0]|0;n=d[429508+(h*6|0)|0]|0;o=d[429509+(h*6|0)|0]|0;h=f*3|0;p=e;e=b;b=0;while(1){q=0;do{r=ba(d[p+q|0]|0,i)|0;s=ba(d[p+(q-f)|0]|0,j)|0;t=ba(d[p+(q-l)|0]|0,k)|0;u=ba(d[p+(q+f)|0]|0,m)|0;v=ba(d[p+(q+l)|0]|0,n)|0;a[e+q|0]=a[(r+64-s+t+u-v+(ba(d[p+(q+h)|0]|0,o)|0)>>7)+1236056|0]|0;q=q+1|0;}while((q|0)<16);q=b+1|0;if((q|0)<(g|0)){p=p+f|0;e=e+c|0;b=q}else{break}}return}function a6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+592|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429507+(m*6|0)|0]|0;q=d[429508+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;r=l|0;while(1){s=0;t=a[m]|0;u=a[m+1|0]|0;while(1){v=ba(t&255,n)|0;w=ba(d[m+(s-1)|0]|0,o)|0;x=s+1|0;y=ba(u&255,p)|0;z=a[m+(s+2)|0]|0;a[r+s|0]=a[(v+64-w+y-(ba(z&255,q)|0)>>7)+1236056|0]|0;if((x|0)<16){s=x;t=u;u=z}else{break}}u=e+1|0;if((u|0)<(h|0)){m=m+f|0;e=u;r=r+16|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(r*6|0)|0]|0;e=d[429505+(r*6|0)|0]|0;f=d[429504+(r*6|0)|0]|0;m=d[429507+(r*6|0)|0]|0;h=d[429508+(r*6|0)|0]|0;q=d[429509+(r*6|0)|0]|0;r=b;b=0;p=l+32|0;while(1){l=0;do{o=ba(d[p+l|0]|0,j)|0;n=ba(d[p+(l-16)|0]|0,e)|0;u=ba(d[p+(l-32)|0]|0,f)|0;t=ba(d[p+(l+16)|0]|0,m)|0;s=ba(d[p+(l+32)|0]|0,h)|0;a[r+l|0]=a[(o+64-n+u+t-s+(ba(d[p+(l+48)|0]|0,q)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<16);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;p=p+16|0}else{break}}i=k;return}function b6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+592|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429504+(m*6|0)|0]|0;q=d[429507+(m*6|0)|0]|0;r=d[429508+(m*6|0)|0]|0;s=d[429509+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ba(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ba(A&255,o)|0;C=ba(w&255,p)|0;D=u+1|0;E=ba(x&255,q)|0;F=ba(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ba(G&255,s)|0)>>7)+1236056|0]|0;if((D|0)<16){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+16|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(t*6|0)|0]|0;e=d[429505+(t*6|0)|0]|0;f=d[429504+(t*6|0)|0]|0;m=d[429507+(t*6|0)|0]|0;h=d[429508+(t*6|0)|0]|0;s=d[429509+(t*6|0)|0]|0;t=b;b=0;r=l+32|0;while(1){l=0;do{q=ba(d[r+l|0]|0,j)|0;p=ba(d[r+(l-16)|0]|0,e)|0;o=ba(d[r+(l-32)|0]|0,f)|0;n=ba(d[r+(l+16)|0]|0,m)|0;y=ba(d[r+(l+32)|0]|0,h)|0;a[t+l|0]=a[(q+64-p+o+n-y+(ba(d[r+(l+48)|0]|0,s)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<16);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;r=r+16|0}else{break}}i=k;return}function c6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=j;e=k;i=b|0;h=b+4|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=e|0;x=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=e+4|0;x=b;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=l+1|0;if((h|0)<(g|0)){j=j+f|0;k=k+c|0;l=h}else{break}}return}function d6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=h-1|0;if((g|0)<=0){return}h=d[429506+(i*6|0)|0]|0;j=d[429505+(i*6|0)|0]|0;k=d[429507+(i*6|0)|0]|0;l=d[429508+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){m=0;while(1){n=ba(d[i+m|0]|0,h)|0;o=ba(d[i+(m-1)|0]|0,j)|0;p=m+1|0;q=ba(d[i+p|0]|0,k)|0;a[e+m|0]=a[(n+64-o+q-(ba(d[i+(m+2)|0]|0,l)|0)>>7)+1236056|0]|0;if((p|0)<8){m=p}else{break}}m=b+1|0;if((m|0)<(g|0)){i=i+f|0;e=e+c|0;b=m}else{break}}return}function e6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=h-1|0;if((g|0)<=0){return}h=d[429506+(i*6|0)|0]|0;j=d[429505+(i*6|0)|0]|0;k=d[429504+(i*6|0)|0]|0;l=d[429507+(i*6|0)|0]|0;m=d[429508+(i*6|0)|0]|0;n=d[429509+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){o=0;while(1){p=ba(d[i+o|0]|0,h)|0;q=ba(d[i+(o-1)|0]|0,j)|0;r=ba(d[i+(o-2)|0]|0,k)|0;s=o+1|0;t=ba(d[i+s|0]|0,l)|0;u=ba(d[i+(o+2)|0]|0,m)|0;a[e+o|0]=a[(p+64-q+r+t-u+(ba(d[i+(o+3)|0]|0,n)|0)>>7)+1236056|0]|0;if((s|0)<8){o=s}else{break}}o=b+1|0;if((o|0)<(g|0)){i=i+f|0;e=e+c|0;b=o}else{break}}return}function f6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i-1|0;if((g|0)<=0){return}i=d[429506+(h*6|0)|0]|0;j=d[429505+(h*6|0)|0]|0;k=d[429507+(h*6|0)|0]|0;l=d[429508+(h*6|0)|0]|0;h=f<<1;m=e;e=b;b=0;while(1){n=0;do{o=ba(d[m+n|0]|0,i)|0;p=ba(d[m+(n-f)|0]|0,j)|0;q=ba(d[m+(n+f)|0]|0,k)|0;a[e+n|0]=a[(o+64-p+q-(ba(d[m+(n+h)|0]|0,l)|0)>>7)+1236056|0]|0;n=n+1|0;}while((n|0)<8);n=b+1|0;if((n|0)<(g|0)){m=m+f|0;e=e+c|0;b=n}else{break}}return}function g6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+152|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429507+(m*6|0)|0]|0;q=d[429508+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;r=l|0;while(1){s=0;t=a[m]|0;u=a[m+1|0]|0;while(1){v=ba(t&255,n)|0;w=ba(d[m+(s-1)|0]|0,o)|0;x=s+1|0;y=ba(u&255,p)|0;z=a[m+(s+2)|0]|0;a[r+s|0]=a[(v+64-w+y-(ba(z&255,q)|0)>>7)+1236056|0]|0;if((x|0)<8){s=x;t=u;u=z}else{break}}u=e+1|0;if((u|0)<(h|0)){m=m+f|0;e=u;r=r+8|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(r*6|0)|0]|0;e=d[429505+(r*6|0)|0]|0;f=d[429507+(r*6|0)|0]|0;m=d[429508+(r*6|0)|0]|0;r=b;b=0;h=l+8|0;while(1){l=0;do{q=ba(d[h+l|0]|0,j)|0;p=ba(d[h+(l-8)|0]|0,e)|0;o=ba(d[h+(l+8)|0]|0,f)|0;a[r+l|0]=a[(q+64-p+o-(ba(d[h+(l+16)|0]|0,m)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<8);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;h=h+8|0}else{break}}i=k;return}function h6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+152|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429504+(m*6|0)|0]|0;q=d[429507+(m*6|0)|0]|0;r=d[429508+(m*6|0)|0]|0;s=d[429509+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ba(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ba(A&255,o)|0;C=ba(w&255,p)|0;D=u+1|0;E=ba(x&255,q)|0;F=ba(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ba(G&255,s)|0)>>7)+1236056|0]|0;if((D|0)<8){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+8|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(t*6|0)|0]|0;e=d[429505+(t*6|0)|0]|0;f=d[429507+(t*6|0)|0]|0;m=d[429508+(t*6|0)|0]|0;t=b;b=0;h=l+8|0;while(1){l=0;do{s=ba(d[h+l|0]|0,j)|0;r=ba(d[h+(l-8)|0]|0,e)|0;q=ba(d[h+(l+8)|0]|0,f)|0;a[t+l|0]=a[(s+64-r+q-(ba(d[h+(l+16)|0]|0,m)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<8);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;h=h+8|0}else{break}}i=k;return}function i6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i-1|0;if((g|0)<=0){return}i=d[429506+(h*6|0)|0]|0;j=d[429505+(h*6|0)|0]|0;k=d[429504+(h*6|0)|0]|0;l=f<<1;m=d[429507+(h*6|0)|0]|0;n=d[429508+(h*6|0)|0]|0;o=d[429509+(h*6|0)|0]|0;h=f*3|0;p=e;e=b;b=0;while(1){q=0;do{r=ba(d[p+q|0]|0,i)|0;s=ba(d[p+(q-f)|0]|0,j)|0;t=ba(d[p+(q-l)|0]|0,k)|0;u=ba(d[p+(q+f)|0]|0,m)|0;v=ba(d[p+(q+l)|0]|0,n)|0;a[e+q|0]=a[(r+64-s+t+u-v+(ba(d[p+(q+h)|0]|0,o)|0)>>7)+1236056|0]|0;q=q+1|0;}while((q|0)<8);q=b+1|0;if((q|0)<(g|0)){p=p+f|0;e=e+c|0;b=q}else{break}}return}function j6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+168|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429507+(m*6|0)|0]|0;q=d[429508+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;r=l|0;while(1){s=0;t=a[m]|0;u=a[m+1|0]|0;while(1){v=ba(t&255,n)|0;w=ba(d[m+(s-1)|0]|0,o)|0;x=s+1|0;y=ba(u&255,p)|0;z=a[m+(s+2)|0]|0;a[r+s|0]=a[(v+64-w+y-(ba(z&255,q)|0)>>7)+1236056|0]|0;if((x|0)<8){s=x;t=u;u=z}else{break}}u=e+1|0;if((u|0)<(h|0)){m=m+f|0;e=u;r=r+8|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(r*6|0)|0]|0;e=d[429505+(r*6|0)|0]|0;f=d[429504+(r*6|0)|0]|0;m=d[429507+(r*6|0)|0]|0;h=d[429508+(r*6|0)|0]|0;q=d[429509+(r*6|0)|0]|0;r=b;b=0;p=l+16|0;while(1){l=0;do{o=ba(d[p+l|0]|0,j)|0;n=ba(d[p+(l-8)|0]|0,e)|0;u=ba(d[p+(l-16)|0]|0,f)|0;t=ba(d[p+(l+8)|0]|0,m)|0;s=ba(d[p+(l+16)|0]|0,h)|0;a[r+l|0]=a[(o+64-n+u+t-s+(ba(d[p+(l+24)|0]|0,q)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<8);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;p=p+8|0}else{break}}i=k;return}function k6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+168|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429504+(m*6|0)|0]|0;q=d[429507+(m*6|0)|0]|0;r=d[429508+(m*6|0)|0]|0;s=d[429509+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ba(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ba(A&255,o)|0;C=ba(w&255,p)|0;D=u+1|0;E=ba(x&255,q)|0;F=ba(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ba(G&255,s)|0)>>7)+1236056|0]|0;if((D|0)<8){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+8|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(t*6|0)|0]|0;e=d[429505+(t*6|0)|0]|0;f=d[429504+(t*6|0)|0]|0;m=d[429507+(t*6|0)|0]|0;h=d[429508+(t*6|0)|0]|0;s=d[429509+(t*6|0)|0]|0;t=b;b=0;r=l+16|0;while(1){l=0;do{q=ba(d[r+l|0]|0,j)|0;p=ba(d[r+(l-8)|0]|0,e)|0;o=ba(d[r+(l-16)|0]|0,f)|0;n=ba(d[r+(l+8)|0]|0,m)|0;y=ba(d[r+(l+16)|0]|0,h)|0;a[t+l|0]=a[(q+64-p+o+n-y+(ba(d[r+(l+24)|0]|0,s)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<8);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;r=r+8|0}else{break}}i=k;return}function l6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=j;e=k;x=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=l+1|0;if((e|0)<(g|0)){j=j+f|0;k=k+c|0;l=e}else{break}}return}function m6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=h-1|0;if((g|0)<=0){return}h=d[429506+(i*6|0)|0]|0;j=d[429505+(i*6|0)|0]|0;k=d[429507+(i*6|0)|0]|0;l=d[429508+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){m=ba(d[i]|0,h)|0;n=ba(d[i-1|0]|0,j)|0;o=i+1|0;p=ba(d[o]|0,k)|0;q=i+2|0;a[e]=a[(m+64-n+p-(ba(d[q]|0,l)|0)>>7)+1236056|0]|0;p=ba(d[o]|0,h)|0;n=ba(d[i]|0,j)|0;m=ba(d[q]|0,k)|0;r=i+3|0;a[e+1|0]=a[(p+64-n+m-(ba(d[r]|0,l)|0)>>7)+1236056|0]|0;m=ba(d[q]|0,h)|0;n=ba(d[o]|0,j)|0;o=ba(d[r]|0,k)|0;p=i+4|0;a[e+2|0]=a[(m+64-n+o-(ba(d[p]|0,l)|0)>>7)+1236056|0]|0;o=ba(d[r]|0,h)|0;r=ba(d[q]|0,j)|0;q=ba(d[p]|0,k)|0;a[e+3|0]=a[(o+64-r+q-(ba(d[i+5|0]|0,l)|0)>>7)+1236056|0]|0;q=b+1|0;if((q|0)<(g|0)){i=i+f|0;e=e+c|0;b=q}else{break}}return}function n6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=h-1|0;if((g|0)<=0){return}h=d[429506+(i*6|0)|0]|0;j=d[429505+(i*6|0)|0]|0;k=d[429504+(i*6|0)|0]|0;l=d[429507+(i*6|0)|0]|0;m=d[429508+(i*6|0)|0]|0;n=d[429509+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){o=0;while(1){p=ba(d[i+o|0]|0,h)|0;q=ba(d[i+(o-1)|0]|0,j)|0;r=ba(d[i+(o-2)|0]|0,k)|0;s=o+1|0;t=ba(d[i+s|0]|0,l)|0;u=ba(d[i+(o+2)|0]|0,m)|0;a[e+o|0]=a[(p+64-q+r+t-u+(ba(d[i+(o+3)|0]|0,n)|0)>>7)+1236056|0]|0;if((s|0)<4){o=s}else{break}}o=b+1|0;if((o|0)<(g|0)){i=i+f|0;e=e+c|0;b=o}else{break}}return}function o6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i-1|0;if((g|0)<=0){return}i=d[429506+(h*6|0)|0]|0;j=d[429505+(h*6|0)|0]|0;k=d[429507+(h*6|0)|0]|0;l=d[429508+(h*6|0)|0]|0;h=f<<1;m=e;e=b;b=0;while(1){n=ba(d[m]|0,i)|0;o=ba(d[m+(-f|0)|0]|0,j)|0;p=m+f|0;q=ba(d[p]|0,k)|0;a[e]=a[(n+64-o+q-(ba(d[m+h|0]|0,l)|0)>>7)+1236056|0]|0;q=ba(d[m+1|0]|0,i)|0;o=ba(d[m+(1-f)|0]|0,j)|0;n=ba(d[m+(f+1)|0]|0,k)|0;a[e+1|0]=a[(q+64-o+n-(ba(d[m+(h|1)|0]|0,l)|0)>>7)+1236056|0]|0;n=ba(d[m+2|0]|0,i)|0;o=ba(d[m+(2-f)|0]|0,j)|0;q=ba(d[m+(f+2)|0]|0,k)|0;a[e+2|0]=a[(n+64-o+q-(ba(d[m+(h+2)|0]|0,l)|0)>>7)+1236056|0]|0;q=ba(d[m+3|0]|0,i)|0;o=ba(d[m+(3-f)|0]|0,j)|0;n=ba(d[m+(f+3)|0]|0,k)|0;a[e+3|0]=a[(q+64-o+n-(ba(d[m+(h+3)|0]|0,l)|0)>>7)+1236056|0]|0;n=b+1|0;if((n|0)<(g|0)){m=p;e=e+c|0;b=n}else{break}}return}function p6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;k=i;i=i+48|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429507+(m*6|0)|0]|0;q=d[429508+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;r=l|0;while(1){s=d[m]|0;t=ba(s,n)|0;u=ba(d[m-1|0]|0,o)|0;v=d[m+1|0]|0;w=ba(v,p)|0;x=d[m+2|0]|0;a[r]=a[(t+64-u+w-(ba(x,q)|0)>>7)+1236056|0]|0;w=ba(v,n)|0;u=ba(s,o)|0;s=ba(x,p)|0;t=d[m+3|0]|0;a[r+1|0]=a[(w+64-u+s-(ba(t,q)|0)>>7)+1236056|0]|0;s=ba(x,n)|0;u=ba(v,o)|0;v=ba(t,p)|0;w=d[m+4|0]|0;a[r+2|0]=a[(s+64-u+v-(ba(w,q)|0)>>7)+1236056|0]|0;v=ba(t,n)|0;t=ba(x,o)|0;x=ba(w,p)|0;a[r+3|0]=a[(v+64-t+x-(ba(d[m+5|0]|0,q)|0)>>7)+1236056|0]|0;x=e+1|0;if((x|0)<(h|0)){m=m+f|0;e=x;r=r+4|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=l+4|0;l=d[429506+(r*6|0)|0]|0;e=d[429505+(r*6|0)|0]|0;f=d[429507+(r*6|0)|0]|0;m=d[429508+(r*6|0)|0]|0;r=b;b=0;h=j;q=a[j]|0;while(1){j=ba(q&255,l)|0;p=ba(d[h-4|0]|0,e)|0;o=h+4|0;n=a[o]|0;x=ba(n&255,f)|0;a[r]=a[(j+64-p+x-(ba(d[h+8|0]|0,m)|0)>>7)+1236056|0]|0;x=ba(d[h+1|0]|0,l)|0;p=ba(d[h-3|0]|0,e)|0;j=ba(d[h+5|0]|0,f)|0;a[r+1|0]=a[(x+64-p+j-(ba(d[h+9|0]|0,m)|0)>>7)+1236056|0]|0;j=ba(d[h+2|0]|0,l)|0;p=ba(d[h-2|0]|0,e)|0;x=ba(d[h+6|0]|0,f)|0;a[r+2|0]=a[(j+64-p+x-(ba(d[h+10|0]|0,m)|0)>>7)+1236056|0]|0;x=ba(d[h+3|0]|0,l)|0;p=ba(d[h-1|0]|0,e)|0;j=ba(d[h+7|0]|0,f)|0;a[r+3|0]=a[(x+64-p+j-(ba(d[h+11|0]|0,m)|0)>>7)+1236056|0]|0;j=b+1|0;if((j|0)<(g|0)){r=r+c|0;b=j;h=o;q=n}else{break}}i=k;return}function q6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+48|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429504+(m*6|0)|0]|0;q=d[429507+(m*6|0)|0]|0;r=d[429508+(m*6|0)|0]|0;s=d[429509+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ba(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ba(A&255,o)|0;C=ba(w&255,p)|0;D=u+1|0;E=ba(x&255,q)|0;F=ba(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ba(G&255,s)|0)>>7)+1236056|0]|0;if((D|0)<4){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+4|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=l+4|0;l=d[429506+(t*6|0)|0]|0;e=d[429505+(t*6|0)|0]|0;f=d[429507+(t*6|0)|0]|0;m=d[429508+(t*6|0)|0]|0;t=b;b=0;h=j;s=a[j]|0;while(1){j=ba(s&255,l)|0;r=ba(d[h-4|0]|0,e)|0;q=h+4|0;p=a[q]|0;o=ba(p&255,f)|0;a[t]=a[(j+64-r+o-(ba(d[h+8|0]|0,m)|0)>>7)+1236056|0]|0;o=ba(d[h+1|0]|0,l)|0;r=ba(d[h-3|0]|0,e)|0;j=ba(d[h+5|0]|0,f)|0;a[t+1|0]=a[(o+64-r+j-(ba(d[h+9|0]|0,m)|0)>>7)+1236056|0]|0;j=ba(d[h+2|0]|0,l)|0;r=ba(d[h-2|0]|0,e)|0;o=ba(d[h+6|0]|0,f)|0;a[t+2|0]=a[(j+64-r+o-(ba(d[h+10|0]|0,m)|0)>>7)+1236056|0]|0;o=ba(d[h+3|0]|0,l)|0;r=ba(d[h-1|0]|0,e)|0;j=ba(d[h+7|0]|0,f)|0;a[t+3|0]=a[(o+64-r+j-(ba(d[h+11|0]|0,m)|0)>>7)+1236056|0]|0;j=b+1|0;if((j|0)<(g|0)){t=t+c|0;b=j;h=q;s=p}else{break}}i=k;return}function r6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i-1|0;if((g|0)<=0){return}i=d[429506+(h*6|0)|0]|0;j=d[429505+(h*6|0)|0]|0;k=d[429504+(h*6|0)|0]|0;l=f<<1;m=d[429507+(h*6|0)|0]|0;n=d[429508+(h*6|0)|0]|0;o=d[429509+(h*6|0)|0]|0;h=f*3|0;p=e;e=b;b=0;while(1){q=0;do{r=ba(d[p+q|0]|0,i)|0;s=ba(d[p+(q-f)|0]|0,j)|0;t=ba(d[p+(q-l)|0]|0,k)|0;u=ba(d[p+(q+f)|0]|0,m)|0;v=ba(d[p+(q+l)|0]|0,n)|0;a[e+q|0]=a[(r+64-s+t+u-v+(ba(d[p+(q+h)|0]|0,o)|0)>>7)+1236056|0]|0;q=q+1|0;}while((q|0)<4);q=b+1|0;if((q|0)<(g|0)){p=p+f|0;e=e+c|0;b=q}else{break}}return}function s6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;k=i;i=i+56|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429507+(m*6|0)|0]|0;q=d[429508+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;r=l|0;while(1){s=d[m]|0;t=ba(s,n)|0;u=ba(d[m-1|0]|0,o)|0;v=d[m+1|0]|0;w=ba(v,p)|0;x=d[m+2|0]|0;a[r]=a[(t+64-u+w-(ba(x,q)|0)>>7)+1236056|0]|0;w=ba(v,n)|0;u=ba(s,o)|0;s=ba(x,p)|0;t=d[m+3|0]|0;a[r+1|0]=a[(w+64-u+s-(ba(t,q)|0)>>7)+1236056|0]|0;s=ba(x,n)|0;u=ba(v,o)|0;v=ba(t,p)|0;w=d[m+4|0]|0;a[r+2|0]=a[(s+64-u+v-(ba(w,q)|0)>>7)+1236056|0]|0;v=ba(t,n)|0;t=ba(x,o)|0;x=ba(w,p)|0;a[r+3|0]=a[(v+64-t+x-(ba(d[m+5|0]|0,q)|0)>>7)+1236056|0]|0;x=e+1|0;if((x|0)<(h|0)){m=m+f|0;e=x;r=r+4|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(r*6|0)|0]|0;e=d[429505+(r*6|0)|0]|0;f=d[429504+(r*6|0)|0]|0;m=d[429507+(r*6|0)|0]|0;h=d[429508+(r*6|0)|0]|0;q=d[429509+(r*6|0)|0]|0;r=b;b=0;p=l+8|0;while(1){l=0;do{o=ba(d[p+l|0]|0,j)|0;n=ba(d[p+(l-4)|0]|0,e)|0;x=ba(d[p+(l-8)|0]|0,f)|0;t=ba(d[p+(l+4)|0]|0,m)|0;v=ba(d[p+(l+8)|0]|0,h)|0;a[r+l|0]=a[(o+64-n+x+t-v+(ba(d[p+(l+12)|0]|0,q)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<4);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;p=p+4|0}else{break}}i=k;return}function t6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+56|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[429506+(m*6|0)|0]|0;o=d[429505+(m*6|0)|0]|0;p=d[429504+(m*6|0)|0]|0;q=d[429507+(m*6|0)|0]|0;r=d[429508+(m*6|0)|0]|0;s=d[429509+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ba(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ba(A&255,o)|0;C=ba(w&255,p)|0;D=u+1|0;E=ba(x&255,q)|0;F=ba(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ba(G&255,s)|0)>>7)+1236056|0]|0;if((D|0)<4){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+4|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[429506+(t*6|0)|0]|0;e=d[429505+(t*6|0)|0]|0;f=d[429504+(t*6|0)|0]|0;m=d[429507+(t*6|0)|0]|0;h=d[429508+(t*6|0)|0]|0;s=d[429509+(t*6|0)|0]|0;t=b;b=0;r=l+8|0;while(1){l=0;do{q=ba(d[r+l|0]|0,j)|0;p=ba(d[r+(l-4)|0]|0,e)|0;o=ba(d[r+(l-8)|0]|0,f)|0;n=ba(d[r+(l+4)|0]|0,m)|0;y=ba(d[r+(l+8)|0]|0,h)|0;a[t+l|0]=a[(q+64-p+o+n-y+(ba(d[r+(l+12)|0]|0,s)|0)>>7)+1236056|0]|0;l=l+1|0;}while((l|0)<4);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;r=r+4|0}else{break}}i=k;return}function u6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;i=8-h|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=0;while(1){e=ba(d[j+b|0]|0,i)|0;m=b+1|0;a[k+b|0]=(e+4+(ba(d[j+m|0]|0,h)|0)|0)>>>3;if((m|0)<16){b=m}else{break}}b=l+1|0;if((b|0)<(g|0)){j=j+f|0;k=k+c|0;l=b}else{break}}return}function v6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;h=8-i|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=0;do{e=ba(d[j+b|0]|0,h)|0;a[k+b|0]=(e+4+(ba(d[j+(b+f)|0]|0,i)|0)|0)>>>3;b=b+1|0;}while((b|0)<16);b=l+1|0;if((b|0)<(g|0)){j=j+f|0;k=k+c|0;l=b}else{break}}return}function w6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+528|0;l=8-h|0;m=8-j|0;n=k|0;o=g+1|0;if((o|0)>0){p=e;e=0;q=n;while(1){r=0;s=a[p]|0;while(1){t=ba(s&255,l)|0;u=r+1|0;v=a[p+u|0]|0;a[q+r|0]=(t+4+(ba(v&255,h)|0)|0)>>>3;if((u|0)<16){r=u;s=v}else{break}}s=e+1|0;if((s|0)<(o|0)){p=p+f|0;e=s;q=q+16|0}else{break}}}if((g|0)>0){w=b;x=0;y=n}else{i=k;return}while(1){n=0;do{b=ba(d[y+n|0]|0,m)|0;a[w+n|0]=(b+4+(ba(d[y+(n+16)|0]|0,j)|0)|0)>>>3;n=n+1|0;}while((n|0)<16);n=x+1|0;if((n|0)<(g|0)){w=w+c|0;x=n;y=y+16|0}else{break}}i=k;return}function x6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=8-h|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=ba(d[j]|0,i)|0;e=j+1|0;a[k]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;e=j+2|0;a[k+1|0]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;e=j+3|0;a[k+2|0]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;e=j+4|0;a[k+3|0]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;e=j+5|0;a[k+4|0]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;e=j+6|0;a[k+5|0]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;e=j+7|0;a[k+6|0]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;a[k+7|0]=(b+4+(ba(d[j+8|0]|0,h)|0)|0)>>>3;b=l+1|0;if((b|0)<(g|0)){j=j+f|0;k=k+c|0;l=b}else{break}}return}function y6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;h=8-i|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=ba(d[j]|0,h)|0;e=j+f|0;a[k]=(b+4+(ba(d[e]|0,i)|0)|0)>>>3;b=ba(d[j+1|0]|0,h)|0;a[k+1|0]=(b+4+(ba(d[j+(f+1)|0]|0,i)|0)|0)>>>3;b=ba(d[j+2|0]|0,h)|0;a[k+2|0]=(b+4+(ba(d[j+(f+2)|0]|0,i)|0)|0)>>>3;b=ba(d[j+3|0]|0,h)|0;a[k+3|0]=(b+4+(ba(d[j+(f+3)|0]|0,i)|0)|0)>>>3;b=ba(d[j+4|0]|0,h)|0;a[k+4|0]=(b+4+(ba(d[j+(f+4)|0]|0,i)|0)|0)>>>3;b=ba(d[j+5|0]|0,h)|0;a[k+5|0]=(b+4+(ba(d[j+(f+5)|0]|0,i)|0)|0)>>>3;b=ba(d[j+6|0]|0,h)|0;a[k+6|0]=(b+4+(ba(d[j+(f+6)|0]|0,i)|0)|0)>>>3;b=ba(d[j+7|0]|0,h)|0;a[k+7|0]=(b+4+(ba(d[j+(f+7)|0]|0,i)|0)|0)>>>3;b=l+1|0;if((b|0)<(g|0)){j=e;k=k+c|0;l=b}else{break}}return}function z6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;i=i+136|0;l=8-h|0;m=8-j|0;n=k|0;o=g+1|0;if((o|0)>0){p=e;e=0;q=n;while(1){r=ba(d[p]|0,l)|0;s=d[p+1|0]|0;a[q]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;s=d[p+2|0]|0;a[q+1|0]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;s=d[p+3|0]|0;a[q+2|0]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;s=d[p+4|0]|0;a[q+3|0]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;s=d[p+5|0]|0;a[q+4|0]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;s=d[p+6|0]|0;a[q+5|0]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;s=d[p+7|0]|0;a[q+6|0]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;a[q+7|0]=(r+4+(ba(d[p+8|0]|0,h)|0)|0)>>>3;r=e+1|0;if((r|0)<(o|0)){p=p+f|0;e=r;q=q+8|0}else{break}}}if((g|0)<=0){i=k;return}q=b;b=0;e=n;f=a[n]|0;while(1){n=ba(f&255,m)|0;p=e+8|0;o=a[p]|0;a[q]=(n+4+(ba(o&255,j)|0)|0)>>>3;n=ba(d[e+1|0]|0,m)|0;a[q+1|0]=(n+4+(ba(d[e+9|0]|0,j)|0)|0)>>>3;n=ba(d[e+2|0]|0,m)|0;a[q+2|0]=(n+4+(ba(d[e+10|0]|0,j)|0)|0)>>>3;n=ba(d[e+3|0]|0,m)|0;a[q+3|0]=(n+4+(ba(d[e+11|0]|0,j)|0)|0)>>>3;n=ba(d[e+4|0]|0,m)|0;a[q+4|0]=(n+4+(ba(d[e+12|0]|0,j)|0)|0)>>>3;n=ba(d[e+5|0]|0,m)|0;a[q+5|0]=(n+4+(ba(d[e+13|0]|0,j)|0)|0)>>>3;n=ba(d[e+6|0]|0,m)|0;a[q+6|0]=(n+4+(ba(d[e+14|0]|0,j)|0)|0)>>>3;n=ba(d[e+7|0]|0,m)|0;a[q+7|0]=(n+4+(ba(d[e+15|0]|0,j)|0)|0)>>>3;n=b+1|0;if((n|0)<(g|0)){q=q+c|0;b=n;e=p;f=o}else{break}}i=k;return}function A6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=8-h|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=ba(d[j]|0,i)|0;e=j+1|0;a[k]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;e=j+2|0;a[k+1|0]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;e=j+3|0;a[k+2|0]=(b+4+(ba(d[e]|0,h)|0)|0)>>>3;b=ba(d[e]|0,i)|0;a[k+3|0]=(b+4+(ba(d[j+4|0]|0,h)|0)|0)>>>3;b=l+1|0;if((b|0)<(g|0)){j=j+f|0;k=k+c|0;l=b}else{break}}return}function B6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;h=8-i|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=ba(d[j]|0,h)|0;e=j+f|0;a[k]=(b+4+(ba(d[e]|0,i)|0)|0)>>>3;b=ba(d[j+1|0]|0,h)|0;a[k+1|0]=(b+4+(ba(d[j+(f+1)|0]|0,i)|0)|0)>>>3;b=ba(d[j+2|0]|0,h)|0;a[k+2|0]=(b+4+(ba(d[j+(f+2)|0]|0,i)|0)|0)>>>3;b=ba(d[j+3|0]|0,h)|0;a[k+3|0]=(b+4+(ba(d[j+(f+3)|0]|0,i)|0)|0)>>>3;b=l+1|0;if((b|0)<(g|0)){j=e;k=k+c|0;l=b}else{break}}return}function C6a(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;i=i+40|0;l=8-h|0;m=8-j|0;n=k|0;o=g+1|0;if((o|0)>0){p=e;e=0;q=n;while(1){r=ba(d[p]|0,l)|0;s=d[p+1|0]|0;a[q]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;s=d[p+2|0]|0;a[q+1|0]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;s=d[p+3|0]|0;a[q+2|0]=(r+4+(ba(s,h)|0)|0)>>>3;r=ba(s,l)|0;a[q+3|0]=(r+4+(ba(d[p+4|0]|0,h)|0)|0)>>>3;r=e+1|0;if((r|0)<(o|0)){p=p+f|0;e=r;q=q+4|0}else{break}}}if((g|0)<=0){i=k;return}q=b;b=0;e=n;f=a[n]|0;while(1){n=ba(f&255,m)|0;p=e+4|0;o=a[p]|0;a[q]=(n+4+(ba(o&255,j)|0)|0)>>>3;n=ba(d[e+1|0]|0,m)|0;a[q+1|0]=(n+4+(ba(d[e+5|0]|0,j)|0)|0)>>>3;n=ba(d[e+2|0]|0,m)|0;a[q+2|0]=(n+4+(ba(d[e+6|0]|0,j)|0)|0)>>>3;n=ba(d[e+3|0]|0,m)|0;a[q+3|0]=(n+4+(ba(d[e+7|0]|0,j)|0)|0)>>>3;n=b+1|0;if((n|0)<(g|0)){q=q+c|0;b=n;e=p;f=o}else{break}}i=k;return}function D6a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=b+60|0;f=c[e>>2]|0;c[(c[b+64>>2]|0)+4>>2]=1;c[b+140>>2]=0;R6a(f);T3a(f+1024|0,8);a[f+1409|0]=-1;f=c[e>>2]|0;e=f+1360|0;g=0;while(1){if((g|0)>=2){break}h=ICb()|0;c[e+(g*24|0)>>2]=h;if((h|0)==0){j=5;break}else{g=g+1|0}}if((j|0)==5){F6a(b)|0;yDb(b,16,2207736,(k=i,i=i+8|0,c[k>>2]=g,k)|0);i=k;l=-12;i=d;return l|0}g=f+1168|0;e=f+1264|0;f=0;while(1){if((f|0)>=8){l=0;j=9;break}h=g+(f*12|0)|0;c[h>>2]=ICb()|0;m=ICb()|0;c[e+(f*12|0)>>2]=m;if((c[h>>2]|0)==0|(m|0)==0){break}else{f=f+1|0}}if((j|0)==9){i=d;return l|0}F6a(b)|0;yDb(b,16,2207736,(k=i,i=i+8|0,c[k>>2]=f,k)|0);i=k;l=-12;i=d;return l|0}function E6a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,ee=0,ge=0,he=0,ie=0,je=0,ke=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0;h=i;i=i+8|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=b+60|0;m=c[g>>2]|0;n=m;o=H6a(b,k,l,j)|0;if((o|0)<0){p=o;i=h;return p|0}if((o|0)==0){q=c[j>>2]|0;j=c[m+1168+(q*12|0)>>2]|0;if((c[j>>2]|0)==0){yDb(b,16,2178544,(r=i,i=i+8|0,c[r>>2]=q,r)|0);i=r;p=-1094995529;i=h;return p|0}q=MCb(e,j)|0;if((q|0)<0){p=q;i=h;return p|0}c[f>>2]=1;p=0;i=h;return p|0}q=k+o|0;k=l-o|0;o=m+1360|0;l=m+1384|0;if((c[c[l>>2]>>2]|0)!=0){U0a(b,l);XAb(m+1396|0)}j=m+1137|0;s=o;do{if((a[j]|0)==0){if((c[c[s>>2]>>2]|0)==0){break}t=l;u=T0a(t,o)|0;if((u|0)<0){p=u;i=h;return p|0}u=WAb(c[m+1372>>2]|0)|0;v=m+1396|0;c[v>>2]=u;if((u|0)!=0){c[m+1400>>2]=c[m+1376>>2];c[m+1404>>2]=c[m+1380>>2];break}U0a(b,t);XAb(v);p=-12;i=h;return p|0}}while(0);l=o;if((c[c[s>>2]>>2]|0)!=0){U0a(b,l);XAb(m+1372|0)}o=c[g>>2]|0;v=W0a(b,l,1)|0;if((v|0)<0){p=v;i=h;return p|0}v=ba(c[o+1796>>2]<<6,c[o+1800>>2]|0)|0;t=VAb(v*13|0)|0;c[m+1372>>2]=t;if((t|0)==0){U0a(b,l);p=-12;i=h;return p|0}u=t+4|0;t=c[u>>2]|0;c[m+1376>>2]=t;c[m+1380>>2]=(c[u>>2]|0)+v;do{if((a[o+1550|0]|0)!=0){if((a[o+1553|0]|0)!=0){break}if((a[o+1144|0]|0)!=0){break}if((a[o+1137|0]|0)!=0){break}UGb(t|0,c[o+1400>>2]|0,v)|0}}while(0);v=c[s>>2]|0;c[v+84>>2]=d[j]|0;c[v+88>>2]=(a[j]|0)!=0?1:2;o=c[v+32>>2]|0;t=c[v+36>>2]|0;u=m+1264|0;w=u;y=m+1146|0;z=m+1168|0;A=z;B=0;while(1){if((B|0)>=8){break}C=w+(B*12|0)|0;if((c[c[C>>2]>>2]|0)!=0){U0a(b,C)}if((d[y]&1<<B|0)==0){D=T0a(C,A+(B*12|0)|0)|0}else{D=T0a(C,l)|0}if((D|0)<0){p=D;E=507;break}else{B=B+1|0}}if((E|0)==507){i=h;return p|0}B=m+1808|0;TGb(c[m+30096>>2]|0,0,c[B>>2]|0)|0;TGb(c[m+30116>>2]|0,0,c[B>>2]|0)|0;do{if((a[j]|0)==0){if((a[m+1144|0]|0)!=0){E=35;break}TGb(c[m+30100>>2]|0,10,c[B>>2]|0)|0}else{E=35}}while(0);if((E|0)==35){TGb(c[m+30100>>2]|0,2,c[B>>2]<<1|0)|0}D=m+1796|0;TGb(c[m+30104>>2]|0,0,c[D>>2]<<4|0)|0;TGb(c[m+30108>>2]|0,0,c[D>>2]<<3|0)|0;TGb(c[m+30112>>2]|0,0,c[D>>2]<<3|0)|0;TGb(c[m+30124>>2]|0,0,c[B>>2]|0)|0;do{if((c[b+816>>2]|0)==1){if((a[m+1154|0]|0)==0){G=0;break}G=(a[m+1155|0]|0)==0|0}else{G=0}}while(0);c[m+1092>>2]=G;A=m+1088|0;c[A>>2]=G;G=c[g>>2]|0;y=G+1080|0;w=c[y>>2]|0;C=G+35860|0;do{if((w|0)==0){E=43}else{if((c[C>>2]|0)==0){E=43;break}if((c[G+35856>>2]|0)!=(c[G+1092>>2]|0)){E=43}}}while(0);do{if((E|0)==43){ZDb(w|0);ZDb(c[C>>2]|0);H=G+1092|0;do{if((c[H>>2]|0)==0){c[y>>2]=WDb(68)|0;I=cEb(12672)|0;c[C>>2]=I;if((c[y>>2]|0)==0|(I|0)==0){break}c[G+35868>>2]=I+8192;c[G+35872>>2]=I+10240;c[G+35884>>2]=I+12288;c[G+35888>>2]=I+12544;c[G+35892>>2]=I+12608;E=48}else{I=ba(c[G+1800>>2]|0,c[G+1796>>2]|0)|0;c[y>>2]=WDb(ba((c[G+1808>>2]|0)*68|0,c[G+1804>>2]|0)|0)|0;J=cEb(I*12672|0)|0;K=J;c[C>>2]=K;if((c[y>>2]|0)==0|(J|0)==0){break}J=I<<12;c[G+35868>>2]=K+(J<<1);L=I<<10;M=J+L|0;c[G+35872>>2]=K+(M<<1);J=M+L|0;c[G+35884>>2]=K+(J<<1);L=J+(I<<7)|0;c[G+35888>>2]=K+(L<<1);c[G+35892>>2]=K+(L+(I<<5)<<1);E=48}}while(0);if((E|0)==48){c[G+35856>>2]=c[H>>2];break}yDb(b,16,2102280,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=-12;i=h;return p|0}}while(0);r=m+1154|0;G=m+1155|0;do{if((a[r]|0)!=0){if((a[G]|0)==0){break}y=m+29836|0;C=m+1156|0;w=m+1812|0;I=m+10279|0;L=0;while(1){if((L|0)<4){N=0}else{break}while(1){K=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)|0;J=I+(L*1584|0)+(N*66|0)|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+3|0;K=I+(L*1584|0)+(N*66|0)+11|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+6|0;J=I+(L*1584|0)+(N*66|0)+22|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+9|0;K=I+(L*1584|0)+(N*66|0)+33|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+12|0;J=I+(L*1584|0)+(N*66|0)+44|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+15|0;K=I+(L*1584|0)+(N*66|0)+55|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=N+1|0;if((K|0)<6){N=K}else{O=0;break}}while(1){K=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)|0;J=I+(L*1584|0)+396+(O*66|0)|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+3|0;K=I+(L*1584|0)+396+(O*66|0)+11|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+6|0;J=I+(L*1584|0)+396+(O*66|0)+22|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+9|0;K=I+(L*1584|0)+396+(O*66|0)+33|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+12|0;J=I+(L*1584|0)+396+(O*66|0)+44|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+15|0;K=I+(L*1584|0)+396+(O*66|0)+55|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=O+1|0;if((K|0)<6){O=K}else{P=0;break}}while(1){K=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)|0;J=I+(L*1584|0)+792+(P*66|0)|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+3|0;K=I+(L*1584|0)+792+(P*66|0)+11|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+6|0;J=I+(L*1584|0)+792+(P*66|0)+22|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+9|0;K=I+(L*1584|0)+792+(P*66|0)+33|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+12|0;J=I+(L*1584|0)+792+(P*66|0)+44|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+15|0;K=I+(L*1584|0)+792+(P*66|0)+55|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=P+1|0;if((K|0)<6){P=K}else{Q=0;break}}do{K=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)|0;J=I+(L*1584|0)+1188+(Q*66|0)|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+3|0;K=I+(L*1584|0)+1188+(Q*66|0)+11|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+6|0;J=I+(L*1584|0)+1188+(Q*66|0)+22|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+9|0;K=I+(L*1584|0)+1188+(Q*66|0)+33|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+12|0;J=I+(L*1584|0)+1188+(Q*66|0)+44|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+15|0;K=I+(L*1584|0)+1188+(Q*66|0)+55|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;Q=Q+1|0;}while((Q|0)<6);if((c[y>>2]|0)==(L|0)){break}else{L=L+1|0}}UGb(w+((d[C]|0)*2039|0)|0,m+9968|0,311)|0;X0a(b)}}while(0);Q=m+1080|0;P=m+1084|0;O=m+35860|0;N=m+35864|0;L=m+35868|0;y=m+35876|0;I=m+35872|0;H=m+35880|0;K=m+35884|0;J=m+35896|0;M=m+35888|0;R=m+35900|0;S=m+35892|0;T=m+35904|0;U=m+1776|0;V=m+1156|0;W=m+1144|0;X=m+1138|0;Y=c[299912]|0;Z=0;_=c[299908]|0;$=0;aa=m+17612|0;ca=m+17616|0;da=m+17620|0;ea=m+17624|0;fa=m+17628|0;ga=m+17632|0;ha=m+17348|0;ia=m+17352|0;ja=m+17356|0;ka=m+17360|0;la=m+17364|0;ma=m+17368|0;na=m+17372|0;oa=m+17376|0;pa=m+29840|0;qa=m+29836|0;ra=m+1148|0;sa=m+17636|0;ta=m+17640|0;ua=m+17644|0;va=m+17648|0;wa=m+1147|0;xa=m+10159|0;ya=m+10147|0;za=m+10153|0;Aa=m+10157|0;Ba=m+1780|0;Ca=m+1784|0;Da=m+1768|0;Ea=m+1800|0;Fa=m+30160|0;Ga=m+1772|0;Ha=o<<6;Ia=t<<5;Ja=m+1804|0;Ka=m+30148|0;La=v|0;Ma=o*63|0;o=m+30152|0;Na=v+4|0;Oa=t*31|0;t=m+30156|0;Pa=v+8|0;v=m+1408|0;Qa=m+1788|0;Ra=m+1792|0;Sa=m+1764|0;Ta=m+1072|0;Ua=m+1052|0;Va=m+30032|0;Wa=m+29872|0;Xa=Wa;Ya=m+29856|0;Za=m+30016|0;_a=m+30056|0;$a=q;q=k;a:while(1){c[P>>2]=c[Q>>2];c[N>>2]=c[O>>2];c[y>>2]=c[L>>2];c[H>>2]=c[I>>2];c[J>>2]=c[K>>2];c[R>>2]=c[M>>2];c[T>>2]=c[S>>2];if((c[U>>2]|0)==0){ab=q;bb=$a}else{k=0;cb=0;db=0;eb=q;fb=$a;while(1){gb=c[Da>>2]|0;hb=c[Ea>>2]|0;ib=(ba(hb,k)|0)>>gb;jb=k+1|0;kb=(ba(hb,jb)|0)>>gb;gb=((ib|0)>(hb|0)?hb:ib)<<3;c[Ba>>2]=gb;ib=((kb|0)>(hb|0)?hb:kb)<<3;c[Ca>>2]=ib;do{if((c[A>>2]|0)==2){lb=fb;mb=eb;nb=gb;ob=ib}else{kb=c[Ga>>2]|0;if((kb|0)==0){lb=fb;mb=eb;nb=gb;ob=ib;break}else{pb=0;qb=eb;rb=fb;sb=kb}do{if((pb|0)==(sb-1|0)){if((k|0)==((c[U>>2]|0)-1|0)){tb=qb;ub=rb;vb=qb}else{E=63}}else{E=63}if((E|0)==63){E=0;kb=rb;hb=fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0;kb=qb-4|0;if(hb>>>0>kb>>>0){E=65;break a}tb=kb;ub=rb+4|0;vb=hb}g5a((c[Ta>>2]|0)+(pb*20|0)|0,ub,vb);hb=c[Ta>>2]|0;wb=hb+(pb*20|0)|0;kb=c[wb>>2]|0;xb=d[1086680+kb|0]|0;yb=hb+(pb*20|0)+4|0;zb=c[yb>>2]|0;Ab=hb+(pb*20|0)+16|0;Bb=c[Ab>>2]|0;Cb=kb<<xb;c[wb>>2]=Cb;kb=Bb<<xb;Bb=zb+xb|0;do{if((Bb|0)>-1){xb=hb+(pb*20|0)+8|0;zb=c[xb>>2]|0;if(!(zb>>>0<(c[hb+(pb*20|0)+12>>2]|0)>>>0)){Db=kb;Eb=Bb;break}c[xb>>2]=zb+2;xb=zb;Db=((de((d[xb]|d[xb+1|0]<<8)<<16>>16|0)|0)&65535)<<Bb|kb;Eb=Bb-16|0}else{Db=kb;Eb=Bb}}while(0);c[yb>>2]=Eb;Fb=((Cb<<7)-128>>8)+1|0;Gb=Fb<<16;if(!(Db>>>0<Gb>>>0)){E=70;break a}c[wb>>2]=Fb;c[Ab>>2]=Db;rb=ub+vb|0;qb=tb-vb|0;pb=pb+1|0;sb=c[Ga>>2]|0;}while(pb>>>0<sb>>>0);lb=rb;mb=qb;nb=c[Ba>>2]|0;ob=c[Ca>>2]|0}}while(0);if(nb>>>0<ob>>>0){ib=nb;gb=cb;Bb=db;while(1){if((c[Ga>>2]|0)!=0){kb=0;hb=c[Fa>>2]|0;xb=gb;zb=Bb;while(1){Hb=c[Sa>>2]|0;Ib=c[D>>2]|0;Jb=(ba(Ib,kb)|0)>>Hb;Kb=kb+1|0;Lb=(ba(Ib,Kb)|0)>>Hb;Hb=((Jb|0)>(Ib|0)?Ib:Jb)<<3;c[Qa>>2]=Hb;Jb=((Lb|0)>(Ib|0)?Ib:Lb)<<3;c[Ra>>2]=Jb;Lb=c[A>>2]|0;if((Lb|0)!=2){TGb(Va|0,0,16)|0;do{if((a[j]|0)==0){if((a[W]|0)!=0){E=79;break}c[Xa>>2]=168430090;c[Xa+4>>2]=168430090}else{E=79}}while(0);if((E|0)==79){E=0;TGb(Wa|0,2,16)|0}TGb(Ya|0,0,16)|0;TGb(Za|0,0,16)|0;c[_a>>2]=0;c[_a+4>>2]=0;yb=(c[Ta>>2]|0)+(kb*20|0)|0;c[Ua>>2]=c[yb>>2];c[Ua+4>>2]=c[yb+4>>2];c[Ua+8>>2]=c[yb+8>>2];c[Ua+12>>2]=c[yb+12>>2];c[Ua+16>>2]=c[yb+16>>2]}if(Hb>>>0<Jb>>>0){yb=Hb;Ib=hb;Mb=xb;Nb=zb;Ob=Lb;while(1){do{if((Ob|0)==1){E=86}else{TGb(Ib+64|0,0,128)|0;if((c[A>>2]|0)!=2){E=86;break}I6a(b,ib,yb,Ib,Mb,Nb,0)}}while(0);if((E|0)==86){E=0;J6a(b,ib,yb,Ib,Mb,Nb,0)}Pb=yb+8|0;Qb=Mb+64|0;Rb=Nb+32|0;Sb=Ib+192|0;Tb=c[A>>2]|0;if(Pb>>>0<(c[Ra>>2]|0)>>>0){yb=Pb;Ib=Sb;Mb=Qb;Nb=Rb;Ob=Tb}else{Ub=Sb;Vb=Qb;Wb=Rb;Xb=Tb;break}}}else{Ub=hb;Vb=xb;Wb=zb;Xb=Lb}if((Xb|0)!=2){Ob=(c[Ta>>2]|0)+(kb*20|0)|0;c[Ob>>2]=c[Ua>>2];c[Ob+4>>2]=c[Ua+4>>2];c[Ob+8>>2]=c[Ua+8>>2];c[Ob+12>>2]=c[Ua+12>>2];c[Ob+16>>2]=c[Ua+16>>2]}if(Kb>>>0<(c[Ga>>2]|0)>>>0){kb=Kb;hb=Ub;xb=Vb;zb=Wb}else{break}}}zb=ib+8|0;if((c[A>>2]|0)!=1){if(zb>>>0<(c[Ja>>2]|0)>>>0){UGb(c[Ka>>2]|0,(c[La>>2]|0)+(gb+Ma)|0,c[B>>2]<<3)|0;xb=Bb+Oa|0;UGb(c[o>>2]|0,(c[Na>>2]|0)+xb|0,c[B>>2]<<2)|0;UGb(c[t>>2]|0,(c[Pa>>2]|0)+xb|0,c[B>>2]<<2)|0}b:do{if((a[v]|0)!=0){if((c[B>>2]|0)==0){break}xb=0;hb=c[Fa>>2]|0;kb=gb;Ob=Bb;while(1){Nb=c[g>>2]|0;Mb=c[Nb+1360>>2]|0;Ib=Mb|0;yb=hb|0;Hb=c[Mb+32>>2]|0;Jb=c[Mb+36>>2]|0;Tb=Hb<<4;Rb=(xb|0)!=0;Qb=Nb+320|0;Sb=Qb;Pb=Hb<<3;Yb=Qb;Qb=Pb|4;Zb=Nb+352|0;_b=Zb;$b=Zb;Zb=Nb+336|0;ac=Nb+344|0;bc=0;cc=yb;dc=(c[Ib>>2]|0)+kb|0;while(1){ec=hb+64+(bc<<2)|0;fc=bc|1;gc=hb+64+(fc<<2)|0;hc=hb+64+(bc<<2)+1|0;ic=a[hc]|a[ec]|a[hb+64+(bc<<2)+2|0];jc=ic&255;kc=a[hb+64+(bc<<2)+3|0]|0;lc=kc&255;mc=hb+64+(fc<<2)+1|0;nc=a[hb+64+(fc<<2)+2|0]|a[mc];oc=nc&255;pc=a[hb+64+(fc<<2)+3|0]|0;fc=pc&255;qc=kc|ic|nc|pc;pc=qc&255;if(!(qc<<24>>24==0)){qc=cc;nc=dc;ic=1;while(1){do{if((ic&jc|0)==0){if((ic&oc|0)==0){break}kc=d[qc+8|0]|0;if(!(Rb|(ic|0)>1)){break}le[c[Sb+(((a[mc]&255&ic|0)!=0)<<3)>>2]&1023](nc+Pb|0,Hb,d[Nb+(kc+1474)|0]|0,d[Nb+(kc+1410)|0]|0,kc>>>4)}else{kc=d[qc]|0;rc=kc>>>4;sc=d[Nb+(kc+1474)|0]|0;tc=d[Nb+(kc+1410)|0]|0;if(!(Rb|(ic|0)>1)){break}if((d[ec]&ic|0)==0){if((ic&oc|0)==0){le[c[Sb+(((a[hc]&255&ic|0)!=0)<<3)>>2]&1023](nc,Hb,sc,tc,rc);break}else{kc=d[qc+8|0]|0;le[c[$b+(((a[hc]&255&ic|0)!=0)<<4)+(((a[mc]&255&ic|0)!=0)<<3)>>2]&1023](nc,Hb,d[Nb+(kc+1474)|0]<<8|sc,d[Nb+(kc+1410)|0]<<8|tc,kc>>>4<<8|rc);break}}else{if((d[gc]&ic|0)==0){le[c[Zb>>2]&1023](nc,Hb,sc,tc,rc);break}else{le[c[ac>>2]&1023](nc,Hb,sc,tc,rc);break}}}}while(0);do{if((ic&lc|0)==0){if((ic&fc|0)==0){break}rc=d[qc+8|0]|0;le[c[Yb>>2]&1023](nc+Qb|0,Hb,d[Nb+(rc+1474)|0]|0,d[Nb+(rc+1410)|0]|0,rc>>>4)}else{rc=d[qc]|0;tc=rc>>>4;sc=d[Nb+(rc+1474)|0]|0;kc=d[Nb+(rc+1410)|0]|0;if((ic&fc|0)==0){le[c[Yb>>2]&1023](nc+4|0,Hb,sc,kc,tc);break}else{rc=d[qc+8|0]|0;le[c[_b>>2]&1023](nc+4|0,Hb,d[Nb+(rc+1474)|0]<<8|sc,d[Nb+(rc+1410)|0]<<8|kc,rc>>>4<<8|tc);break}}}while(0);tc=ic<<1;if((pc&-tc|0)==0){break}else{qc=qc+1|0;nc=nc+8|0;ic=tc}}}ic=bc+2|0;if((ic|0)<8){bc=ic;cc=cc+16|0;dc=dc+Tb|0}else{break}}Tb=Nb+324|0;dc=Hb<<2;cc=dc+8|0;bc=Nb+356|0;_b=Nb+340|0;Yb=Nb+348|0;Qb=0;ic=yb;nc=(c[Ib>>2]|0)+kb|0;while(1){qc=hb+96+(Qb<<2)|0;pc=hb+96+(Qb<<2)+1|0;fc=a[pc]|a[qc]|a[hb+96+(Qb<<2)+2|0];lc=fc&255;gc=d[hb+96+(Qb<<2)+3|0]|0;if(!(fc<<24>>24==0)){fc=(Qb|ib|0)==0;mc=ic;hc=nc;oc=1;while(1){do{if(!fc){if((oc&lc|0)==0){ec=oc<<1;if((ec&lc|0)==0){break}jc=d[mc+1|0]|0;le[c[Sb+(((a[pc]&255&ec|0)!=0)<<3)+4>>2]&1023](hc+8|0,Hb,d[Nb+(jc+1474)|0]|0,d[Nb+(jc+1410)|0]|0,jc>>>4);break}jc=d[mc]|0;ec=jc>>>4;tc=d[Nb+(jc+1474)|0]|0;rc=d[Nb+(jc+1410)|0]|0;jc=d[qc]|0;kc=oc<<1;if((jc&oc|0)==0){if((kc&lc|0)==0){le[c[Sb+(((a[pc]&255&oc|0)!=0)<<3)+4>>2]&1023](hc,Hb,tc,rc,ec);break}else{sc=d[mc+1|0]|0;uc=d[pc]|0;le[c[$b+(((uc&oc|0)!=0)<<4)+(((uc&kc|0)!=0)<<3)+4>>2]&1023](hc,Hb,d[Nb+(sc+1474)|0]<<8|tc,d[Nb+(sc+1410)|0]<<8|rc,sc>>>4<<8|ec);break}}else{if((jc&kc|0)==0){le[c[_b>>2]&1023](hc,Hb,tc,rc,ec);break}else{le[c[Yb>>2]&1023](hc,Hb,tc,rc,ec);break}}}}while(0);do{if((oc&gc|0)==0){if((oc<<1&gc|0)==0){break}ec=d[mc+1|0]|0;le[c[Tb>>2]&1023](hc+cc|0,Hb,d[Nb+(ec+1474)|0]|0,d[Nb+(ec+1410)|0]|0,ec>>>4)}else{ec=d[mc]|0;rc=ec>>>4;tc=d[Nb+(ec+1474)|0]|0;kc=d[Nb+(ec+1410)|0]|0;if((oc<<1&gc|0)==0){le[c[Tb>>2]&1023](hc+dc|0,Hb,tc,kc,rc);break}else{ec=d[mc+1|0]|0;le[c[bc>>2]&1023](hc+dc|0,Hb,d[Nb+(ec+1474)|0]<<8|tc,d[Nb+(ec+1410)|0]<<8|kc,ec>>>4<<8|rc);break}}}while(0);rc=oc<<2;if((lc&-rc|0)==0){break}else{mc=mc+2|0;hc=hc+16|0;oc=rc}}}oc=Qb+1|0;if((oc|0)<8){Qb=oc;ic=ic+8|0;nc=nc+Pb|0}else{break}}Pb=Jb<<4;nc=Jb<<3;ic=Jb<<2;Qb=0;do{Qb=Qb+1|0;Hb=Mb+(Qb<<2)|0;dc=0;bc=yb;Tb=(c[Hb>>2]|0)+Ob|0;while(1){cc=hb+128+(dc<<2)|0;Ib=dc|2;oc=hb+128+(Ib<<2)|0;hc=hb+128+(dc<<2)+1|0;mc=a[hc]|a[cc]|a[hb+128+(dc<<2)+2|0];lc=mc&255;gc=hb+128+(Ib<<2)+1|0;pc=a[hb+128+(Ib<<2)+2|0]|a[gc];Ib=pc&255;qc=pc|mc;mc=qc&255;if(!(qc<<24>>24==0)){qc=Tb;pc=bc;fc=1;while(1){do{if(Rb|(fc|0)>1){if((fc&lc|0)==0){if((fc&Ib|0)==0){break}rc=d[pc+16|0]|0;le[c[Sb+(((a[gc]&255&fc|0)!=0)<<3)>>2]&1023](qc+nc|0,Jb,d[Nb+(rc+1474)|0]|0,d[Nb+(rc+1410)|0]|0,rc>>>4);break}rc=d[pc]|0;ec=rc>>>4;kc=d[Nb+(rc+1474)|0]|0;tc=d[Nb+(rc+1410)|0]|0;if((d[cc]&fc|0)==0){if((fc&Ib|0)==0){le[c[Sb+(((a[hc]&255&fc|0)!=0)<<3)>>2]&1023](qc,Jb,kc,tc,ec);break}else{rc=d[pc+16|0]|0;le[c[$b+(((a[hc]&255&fc|0)!=0)<<4)+(((a[gc]&255&fc|0)!=0)<<3)>>2]&1023](qc,Jb,d[Nb+(rc+1474)|0]<<8|kc,d[Nb+(rc+1410)|0]<<8|tc,rc>>>4<<8|ec);break}}else{if((d[oc]&fc|0)==0){le[c[Zb>>2]&1023](qc,Jb,kc,tc,ec);break}else{le[c[ac>>2]&1023](qc,Jb,kc,tc,ec);break}}}}while(0);ec=fc<<1;if((mc&-ec|0)==0){break}else{qc=qc+4|0;pc=(fc&170|0)==0?pc:pc+2|0;fc=ec}}}fc=dc+4|0;if((fc|0)<8){dc=fc;bc=bc+32|0;Tb=Tb+Pb|0}else{break}}Tb=0;bc=yb;dc=(c[Hb>>2]|0)+Ob|0;while(1){fc=hb+160+(Tb<<2)|0;pc=hb+160+(Tb<<2)+1|0;qc=a[pc]|a[fc]|a[hb+160+(Tb<<2)+2|0];mc=qc&255;if(!(qc<<24>>24==0)){qc=(Tb|ib|0)==0;oc=dc;gc=bc;hc=1;while(1){do{if(!qc){if((hc&mc|0)==0){Ib=hc<<2;if((Ib&mc|0)==0){break}cc=d[gc+2|0]|0;le[c[Sb+(((a[pc]&255&Ib|0)!=0)<<3)+4>>2]&1023](oc+8|0,Jb,d[Nb+(cc+1474)|0]|0,d[Nb+(cc+1410)|0]|0,cc>>>4);break}cc=d[gc]|0;Ib=cc>>>4;lc=d[Nb+(cc+1474)|0]|0;ec=d[Nb+(cc+1410)|0]|0;cc=d[fc]|0;tc=hc<<2;if((cc&hc|0)==0){if((tc&mc|0)==0){le[c[Sb+(((a[pc]&255&hc|0)!=0)<<3)+4>>2]&1023](oc,Jb,lc,ec,Ib);break}else{kc=d[gc+2|0]|0;rc=d[pc]|0;le[c[$b+(((rc&hc|0)!=0)<<4)+(((rc&tc|0)!=0)<<3)+4>>2]&1023](oc,Jb,d[Nb+(kc+1474)|0]<<8|lc,d[Nb+(kc+1410)|0]<<8|ec,kc>>>4<<8|Ib);break}}else{if((cc&tc|0)==0){le[c[_b>>2]&1023](oc,Jb,lc,ec,Ib);break}else{le[c[Yb>>2]&1023](oc,Jb,lc,ec,Ib);break}}}}while(0);Ib=hc<<4;if((mc&-Ib|0)==0){break}else{oc=oc+16|0;gc=gc+4|0;hc=Ib}}}hc=(Tb&1|0)==0?bc:bc+16|0;gc=Tb+1|0;if((gc|0)<8){Tb=gc;bc=hc;dc=dc+ic|0}else{break}}}while((Qb|0)<2);Qb=xb+8|0;if(!(Qb>>>0<(c[B>>2]|0)>>>0)){break b}xb=Qb;hb=hb+192|0;kb=kb+64|0;Ob=Ob+32|0}}}while(0);Y0a(l,ib>>3,0)}Ob=gb+Ha|0;kb=Bb+Ia|0;if(zb>>>0<(c[Ca>>2]|0)>>>0){ib=zb;gb=Ob;Bb=kb}else{vc=Ob;wc=kb;break}}}else{vc=cb;wc=db}if(jb>>>0<(c[U>>2]|0)>>>0){k=jb;cb=vc;db=wc;eb=mb;fb=lb}else{ab=mb;bb=lb;break}}}xc=c[A>>2]|0;if((xc|0)>=2){E=179;break}do{if((a[r]|0)==0){yc=xc}else{if((a[G]|0)!=0){yc=xc;break}fb=d[V]|0;do{if((a[j]|0)==0){if((a[W]|0)!=0){zc=0;Ac=112;break}eb=(a[X]|0)==0;zc=eb?0:0;Ac=eb?112:128}else{zc=0;Ac=112}}while(0);jb=gHb(Y,Z,Ac,zc)|0;eb=F;db=0;do{cb=0;do{k=0;do{C=0;do{w=(C|0)==0;Bb=0;do{gb=d[V]|0;ib=n+1812+(gb*2039|0)+311+(db*432|0)+(cb*216|0)+(k*108|0)+(C*18|0)+(Bb*3|0)|0;kb=n+18316+(db*1728|0)+(cb*864|0)+(k*432|0)+(C*72|0)+(Bb*12|0)|0;if(w&(Bb|0)>2){break}Ob=c[n+25228+(db*1152|0)+(cb*576|0)+(k*288|0)+(C*48|0)+(Bb<<3)>>2]|0;hb=(c[n+25228+(db*1152|0)+(cb*576|0)+(k*288|0)+(C*48|0)+(Bb<<3)+4>>2]|0)+Ob|0;if((hb|0)!=0){xb=d[ib]|0;Kb=(((hb>>>1)+(Ob<<8)|0)>>>0)/(hb>>>0)|0;if((Kb|0)<1){Bc=1}else{Bc=(Kb|0)>255?255:Kb}Kb=hb>>>0>24>>>0;gHb(jb,eb,Kb?24:hb,Kb?0:0)|0;a[ib]=(((ba(Bc-xb|0,F)|0)+128|0)>>>8)+xb}xb=n+1812+(gb*2039|0)+311+(db*432|0)+(cb*216|0)+(k*108|0)+(C*18|0)+(Bb*3|0)+1|0;ib=c[kb>>2]|0;kb=n+18316+(db*1728|0)+(cb*864|0)+(k*432|0)+(C*72|0)+(Bb*12|0)+4|0;Kb=c[kb>>2]|0;hb=n+18316+(db*1728|0)+(cb*864|0)+(k*432|0)+(C*72|0)+(Bb*12|0)+8|0;Ob=c[hb>>2]|0;Lb=Kb+ib+Ob|0;if((Lb|0)==0){Cc=Kb;Dc=Ob}else{Ob=d[xb]|0;Kb=(((Lb>>>1)+(ib<<8)|0)>>>0)/(Lb>>>0)|0;if((Kb|0)<1){Ec=1}else{Ec=(Kb|0)>255?255:Kb}Kb=Lb>>>0>24>>>0;gHb(jb,eb,Kb?24:Lb,Kb?0:0)|0;a[xb]=(((ba(Ec-Ob|0,F)|0)+128|0)>>>8)+Ob;Cc=c[kb>>2]|0;Dc=c[hb>>2]|0}hb=n+1812+(gb*2039|0)+311+(db*432|0)+(cb*216|0)+(k*108|0)+(C*18|0)+(Bb*3|0)+2|0;gb=Cc+Dc|0;if((gb|0)!=0){kb=d[hb]|0;Ob=(((gb>>>1)+(Cc<<8)|0)>>>0)/(gb>>>0)|0;if((Ob|0)<1){Fc=1}else{Fc=(Ob|0)>255?255:Ob}Ob=gb>>>0>24>>>0;gHb(jb,eb,Ob?24:gb,Ob?0:0)|0;a[hb]=(((ba(Fc-kb|0,F)|0)+128|0)>>>8)+kb}Bb=Bb+1|0;}while((Bb|0)<6);C=C+1|0;}while((C|0)<6);k=k+1|0;}while((k|0)<2);cb=cb+1|0;}while((cb|0)<2);db=db+1|0;}while((db|0)<4);do{if((a[j]|0)==0){if((a[W]|0)!=0){E=211;break}db=n+1812+(fb*2039|0)+191|0;eb=c[aa>>2]|0;jb=(c[ca>>2]|0)+eb|0;if((jb|0)!=0){cb=d[db]|0;zb=(((jb>>>1)+(eb<<8)|0)>>>0)/(jb>>>0)|0;if((zb|0)<1){Gc=1}else{Gc=(zb|0)>255?255:zb}zb=jb>>>0>20>>>0;eb=jb;gHb(zb?2560:eb<<7|0>>>25,zb?0:0<<7|eb>>>25,_,$)|0;a[db]=(((ba(Gc-cb|0,F)|0)+128|0)>>>8)+cb}cb=n+1812+(fb*2039|0)+192|0;db=c[da>>2]|0;eb=(c[ea>>2]|0)+db|0;if((eb|0)!=0){zb=d[cb]|0;jb=(((eb>>>1)+(db<<8)|0)>>>0)/(eb>>>0)|0;if((jb|0)<1){Hc=1}else{Hc=(jb|0)>255?255:jb}jb=eb>>>0>20>>>0;db=eb;gHb(jb?2560:db<<7|0>>>25,jb?0:0<<7|db>>>25,_,$)|0;a[cb]=(((ba(Hc-zb|0,F)|0)+128|0)>>>8)+zb}zb=n+1812+(fb*2039|0)+193|0;cb=c[fa>>2]|0;db=(c[ga>>2]|0)+cb|0;if((db|0)!=0){jb=d[zb]|0;eb=(((db>>>1)+(cb<<8)|0)>>>0)/(db>>>0)|0;if((eb|0)<1){Ic=1}else{Ic=(eb|0)>255?255:eb}eb=db>>>0>20>>>0;cb=db;gHb(eb?2560:cb<<7|0>>>25,eb?0:0<<7|cb>>>25,_,$)|0;a[zb]=(((ba(Ic-jb|0,F)|0)+128|0)>>>8)+jb}jb=n+1812+(fb*2039|0)+155|0;zb=c[ha>>2]|0;cb=(c[ia>>2]|0)+zb|0;if((cb|0)!=0){eb=d[jb]|0;db=(((cb>>>1)+(zb<<8)|0)>>>0)/(cb>>>0)|0;if((db|0)<1){Jc=1}else{Jc=(db|0)>255?255:db}db=cb>>>0>20>>>0;zb=cb;gHb(db?2560:zb<<7|0>>>25,db?0:0<<7|zb>>>25,_,$)|0;a[jb]=(((ba(Jc-eb|0,F)|0)+128|0)>>>8)+eb}eb=n+1812+(fb*2039|0)+156|0;jb=c[ja>>2]|0;zb=(c[ka>>2]|0)+jb|0;if((zb|0)!=0){db=d[eb]|0;cb=(((zb>>>1)+(jb<<8)|0)>>>0)/(zb>>>0)|0;if((cb|0)<1){Kc=1}else{Kc=(cb|0)>255?255:cb}cb=zb>>>0>20>>>0;jb=zb;gHb(cb?2560:jb<<7|0>>>25,cb?0:0<<7|jb>>>25,_,$)|0;a[eb]=(((ba(Kc-db|0,F)|0)+128|0)>>>8)+db}db=n+1812+(fb*2039|0)+157|0;eb=c[la>>2]|0;jb=(c[ma>>2]|0)+eb|0;if((jb|0)!=0){cb=d[db]|0;zb=(((jb>>>1)+(eb<<8)|0)>>>0)/(jb>>>0)|0;if((zb|0)<1){Lc=1}else{Lc=(zb|0)>255?255:zb}zb=jb>>>0>20>>>0;eb=jb;gHb(zb?2560:eb<<7|0>>>25,zb?0:0<<7|eb>>>25,_,$)|0;a[db]=(((ba(Lc-cb|0,F)|0)+128|0)>>>8)+cb}cb=n+1812+(fb*2039|0)+158|0;db=c[na>>2]|0;eb=(c[oa>>2]|0)+db|0;if((eb|0)!=0){zb=d[cb]|0;jb=(((eb>>>1)+(db<<8)|0)>>>0)/(eb>>>0)|0;if((jb|0)<1){Mc=1}else{Mc=(jb|0)>255?255:jb}jb=eb>>>0>20>>>0;db=eb;gHb(jb?2560:db<<7|0>>>25,jb?0:0<<7|db>>>25,_,$)|0;a[cb]=(((ba(Mc-zb|0,F)|0)+128|0)>>>8)+zb}zb=c[pa>>2]|0;if((zb|0)==2){cb=0;do{db=n+1812+(fb*2039|0)+159+cb|0;jb=c[n+17380+(cb<<3)>>2]|0;eb=(c[n+17380+(cb<<3)+4>>2]|0)+jb|0;if((eb|0)!=0){k=d[db]|0;C=(((eb>>>1)+(jb<<8)|0)>>>0)/(eb>>>0)|0;if((C|0)<1){Nc=1}else{Nc=(C|0)>255?255:C}C=eb>>>0>20>>>0;jb=eb;gHb(C?2560:jb<<7|0>>>25,C?0:0<<7|jb>>>25,_,$)|0;a[db]=(((ba(Nc-k|0,F)|0)+128|0)>>>8)+k}cb=cb+1|0;}while((cb|0)<5);Oc=c[pa>>2]|0}else{Oc=zb}if((Oc|0)==0){Pc=0;E=233}else{cb=0;do{k=n+1812+(fb*2039|0)+174+cb|0;db=c[n+17500+(cb<<3)>>2]|0;jb=(c[n+17500+(cb<<3)+4>>2]|0)+db|0;if((jb|0)!=0){C=d[k]|0;eb=(((jb>>>1)+(db<<8)|0)>>>0)/(jb>>>0)|0;if((eb|0)<1){Qc=1}else{Qc=(eb|0)>255?255:eb}eb=jb>>>0>20>>>0;db=jb;gHb(eb?2560:db<<7|0>>>25,eb?0:0<<7|db>>>25,_,$)|0;a[k]=(((ba(Qc-C|0,F)|0)+128|0)>>>8)+C}cb=cb+1|0;}while((cb|0)<5);if((c[pa>>2]|0)==1){Rc=0}else{Pc=0;E=233}}if((E|0)==233){while(1){E=0;cb=n+1812+(fb*2039|0)+164+(Pc<<1)|0;zb=c[n+17420+(Pc<<4)>>2]|0;C=(c[n+17420+(Pc<<4)+4>>2]|0)+zb|0;if((C|0)!=0){k=d[cb]|0;db=(((C>>>1)+(zb<<8)|0)>>>0)/(C>>>0)|0;if((db|0)<1){Sc=1}else{Sc=(db|0)>255?255:db}db=C>>>0>20>>>0;zb=C;gHb(db?2560:zb<<7|0>>>25,db?0:0<<7|zb>>>25,_,$)|0;a[cb]=(((ba(Sc-k|0,F)|0)+128|0)>>>8)+k}k=n+1812+(fb*2039|0)+164+(Pc<<1)+1|0;cb=c[n+17420+(Pc<<4)+8>>2]|0;zb=(c[n+17420+(Pc<<4)+12>>2]|0)+cb|0;if((zb|0)!=0){db=d[k]|0;C=(((zb>>>1)+(cb<<8)|0)>>>0)/(zb>>>0)|0;if((C|0)<1){Tc=1}else{Tc=(C|0)>255?255:C}C=zb>>>0>20>>>0;cb=zb;gHb(C?2560:cb<<7|0>>>25,C?0:0<<7|cb>>>25,_,$)|0;a[k]=(((ba(Tc-db|0,F)|0)+128|0)>>>8)+db}db=Pc+1|0;if((db|0)<5){Pc=db;E=233}else{Rc=0;break}}}do{db=0;do{k=n+1812+(fb*2039|0)+263+(Rc*12|0)+(db*3|0)|0;cb=c[n+18060+(Rc<<6)+(db<<4)>>2]|0;C=n+18060+(Rc<<6)+(db<<4)+4|0;zb=c[C>>2]|0;eb=n+18060+(Rc<<6)+(db<<4)+8|0;jb=c[eb>>2]|0;Bb=n+18060+(Rc<<6)+(db<<4)+12|0;w=c[Bb>>2]|0;kb=zb+cb+jb+w|0;if((kb|0)==0){Uc=zb;Vc=jb;Wc=w}else{w=d[k]|0;jb=(((kb>>>1)+(cb<<8)|0)>>>0)/(kb>>>0)|0;if((jb|0)<1){Xc=1}else{Xc=(jb|0)>255?255:jb}jb=kb>>>0>20>>>0;cb=kb;gHb(jb?2560:cb<<7|0>>>25,jb?0:0<<7|cb>>>25,_,$)|0;a[k]=(((ba(Xc-w|0,F)|0)+128|0)>>>8)+w;Uc=c[C>>2]|0;Vc=c[eb>>2]|0;Wc=c[Bb>>2]|0}C=n+1812+(fb*2039|0)+263+(Rc*12|0)+(db*3|0)+1|0;w=Vc+Wc+Uc|0;if((w|0)==0){Yc=Vc;Zc=Wc}else{k=d[C]|0;cb=(((w>>>1)+(Uc<<8)|0)>>>0)/(w>>>0)|0;if((cb|0)<1){_c=1}else{_c=(cb|0)>255?255:cb}cb=w>>>0>20>>>0;jb=w;gHb(cb?2560:jb<<7|0>>>25,cb?0:0<<7|jb>>>25,_,$)|0;a[C]=(((ba(_c-k|0,F)|0)+128|0)>>>8)+k;Yc=c[eb>>2]|0;Zc=c[Bb>>2]|0}Bb=n+1812+(fb*2039|0)+263+(Rc*12|0)+(db*3|0)+2|0;eb=Yc+Zc|0;if((eb|0)!=0){k=d[Bb]|0;C=(((eb>>>1)+(Yc<<8)|0)>>>0)/(eb>>>0)|0;if((C|0)<1){$c=1}else{$c=(C|0)>255?255:C}C=eb>>>0>20>>>0;jb=eb;gHb(C?2560:jb<<7|0>>>25,C?0:0<<7|jb>>>25,_,$)|0;a[Bb]=(((ba($c-k|0,F)|0)+128|0)>>>8)+k}db=db+1|0;}while((db|0)<4);Rc=Rc+1|0;}while((Rc|0)<4);if((c[qa>>2]|0)==4){db=0;do{k=n+17572+(db*12|0)|0;Bb=n+17540+(db<<4)|0;jb=n+1812+(fb*2039|0)+189+db|0;C=c[n+17596+(db<<3)>>2]|0;eb=(c[n+17596+(db<<3)+4>>2]|0)+C|0;if((eb|0)!=0){cb=d[jb]|0;w=(((eb>>>1)+(C<<8)|0)>>>0)/(eb>>>0)|0;if((w|0)<1){ad=1}else{ad=(w|0)>255?255:w}w=eb>>>0>20>>>0;C=eb;gHb(w?2560:C<<7|0>>>25,w?0:0<<7|C>>>25,_,$)|0;a[jb]=(((ba(ad-cb|0,F)|0)+128|0)>>>8)+cb}cb=n+1812+(fb*2039|0)+185+(db<<1)|0;jb=c[k>>2]|0;k=n+17572+(db*12|0)+4|0;C=c[k>>2]|0;w=n+17572+(db*12|0)+8|0;eb=c[w>>2]|0;kb=C+jb+eb|0;if((kb|0)==0){bd=C;cd=eb}else{eb=d[cb]|0;C=(((kb>>>1)+(jb<<8)|0)>>>0)/(kb>>>0)|0;if((C|0)<1){dd=1}else{dd=(C|0)>255?255:C}C=kb>>>0>20>>>0;jb=kb;gHb(C?2560:jb<<7|0>>>25,C?0:0<<7|jb>>>25,_,$)|0;a[cb]=(((ba(dd-eb|0,F)|0)+128|0)>>>8)+eb;bd=c[k>>2]|0;cd=c[w>>2]|0}w=n+1812+(fb*2039|0)+185+(db<<1)+1|0;k=bd+cd|0;if((k|0)!=0){eb=d[w]|0;cb=(((k>>>1)+(bd<<8)|0)>>>0)/(k>>>0)|0;if((cb|0)<1){ed=1}else{ed=(cb|0)>255?255:cb}cb=k>>>0>20>>>0;jb=k;gHb(cb?2560:jb<<7|0>>>25,cb?0:0<<7|jb>>>25,_,$)|0;a[w]=(((ba(ed-eb|0,F)|0)+128|0)>>>8)+eb}eb=n+1812+(fb*2039|0)+179+(db*3|0)|0;w=c[Bb>>2]|0;Bb=n+17540+(db<<4)+4|0;jb=c[Bb>>2]|0;cb=n+17540+(db<<4)+8|0;k=c[cb>>2]|0;C=n+17540+(db<<4)+12|0;kb=c[C>>2]|0;zb=jb+w+k+kb|0;if((zb|0)==0){fd=jb;gd=k;hd=kb}else{kb=d[eb]|0;k=(((zb>>>1)+(w<<8)|0)>>>0)/(zb>>>0)|0;if((k|0)<1){id=1}else{id=(k|0)>255?255:k}k=zb>>>0>20>>>0;w=zb;gHb(k?2560:w<<7|0>>>25,k?0:0<<7|w>>>25,_,$)|0;a[eb]=(((ba(id-kb|0,F)|0)+128|0)>>>8)+kb;fd=c[Bb>>2]|0;gd=c[cb>>2]|0;hd=c[C>>2]|0}Bb=n+1812+(fb*2039|0)+179+(db*3|0)+1|0;kb=gd+hd+fd|0;if((kb|0)==0){jd=gd;kd=hd}else{eb=d[Bb]|0;w=(((kb>>>1)+(fd<<8)|0)>>>0)/(kb>>>0)|0;if((w|0)<1){ld=1}else{ld=(w|0)>255?255:w}w=kb>>>0>20>>>0;k=kb;gHb(w?2560:k<<7|0>>>25,w?0:0<<7|k>>>25,_,$)|0;a[Bb]=(((ba(ld-eb|0,F)|0)+128|0)>>>8)+eb;jd=c[cb>>2]|0;kd=c[C>>2]|0}C=n+1812+(fb*2039|0)+179+(db*3|0)+2|0;cb=jd+kd|0;if((cb|0)!=0){eb=d[C]|0;Bb=(((cb>>>1)+(jd<<8)|0)>>>0)/(cb>>>0)|0;if((Bb|0)<1){md=1}else{md=(Bb|0)>255?255:Bb}Bb=cb>>>0>20>>>0;k=cb;gHb(Bb?2560:k<<7|0>>>25,Bb?0:0<<7|k>>>25,_,$)|0;a[C]=(((ba(md-eb|0,F)|0)+128|0)>>>8)+eb}db=db+1|0;}while((db|0)<2)}if((c[ra>>2]|0)==4){db=0;while(1){eb=n+1812+(fb*2039|0)+126+(db<<1)|0;C=c[n+17188+(db*12|0)>>2]|0;k=n+17188+(db*12|0)+4|0;Bb=c[k>>2]|0;cb=n+17188+(db*12|0)+8|0;w=c[cb>>2]|0;kb=Bb+C+w|0;if((kb|0)==0){nd=Bb;od=w}else{w=d[eb]|0;Bb=(((kb>>>1)+(C<<8)|0)>>>0)/(kb>>>0)|0;if((Bb|0)<1){pd=1}else{pd=(Bb|0)>255?255:Bb}Bb=kb>>>0>20>>>0;C=kb;gHb(Bb?2560:C<<7|0>>>25,Bb?0:0<<7|C>>>25,_,$)|0;a[eb]=(((ba(pd-w|0,F)|0)+128|0)>>>8)+w;nd=c[k>>2]|0;od=c[cb>>2]|0}cb=n+1812+(fb*2039|0)+126+(db<<1)+1|0;k=nd+od|0;if((k|0)!=0){w=d[cb]|0;eb=(((k>>>1)+(nd<<8)|0)>>>0)/(k>>>0)|0;if((eb|0)<1){qd=1}else{qd=(eb|0)>255?255:eb}eb=k>>>0>20>>>0;C=k;gHb(eb?2560:C<<7|0>>>25,eb?0:0<<7|C>>>25,_,$)|0;a[cb]=(((ba(qd-w|0,F)|0)+128|0)>>>8)+w}w=db+1|0;if((w|0)<4){db=w}else{rd=0;break}}}else{rd=0}do{db=n+1812+(fb*2039|0)+134+(rd*3|0)|0;w=n+17236+(rd<<4)|0;cb=c[n+17236+(rd<<4)+8>>2]|0;C=n+17236+(rd<<4)+4|0;eb=c[C>>2]|0;k=c[w>>2]|0;Bb=n+17236+(rd<<4)+12|0;kb=c[Bb>>2]|0;zb=eb+cb+k+kb|0;if((zb|0)==0){sd=k;td=eb;ud=kb}else{kb=d[db]|0;eb=(((zb>>>1)+(cb<<8)|0)>>>0)/(zb>>>0)|0;if((eb|0)<1){vd=1}else{vd=(eb|0)>255?255:eb}eb=zb>>>0>20>>>0;cb=zb;gHb(eb?2560:cb<<7|0>>>25,eb?0:0<<7|cb>>>25,_,$)|0;a[db]=(((ba(vd-kb|0,F)|0)+128|0)>>>8)+kb;sd=c[w>>2]|0;td=c[C>>2]|0;ud=c[Bb>>2]|0}w=n+1812+(fb*2039|0)+134+(rd*3|0)+1|0;kb=td+ud+sd|0;if((kb|0)==0){wd=td;xd=ud}else{db=d[w]|0;cb=(((kb>>>1)+(sd<<8)|0)>>>0)/(kb>>>0)|0;if((cb|0)<1){yd=1}else{yd=(cb|0)>255?255:cb}cb=kb>>>0>20>>>0;eb=kb;gHb(cb?2560:eb<<7|0>>>25,cb?0:0<<7|eb>>>25,_,$)|0;a[w]=(((ba(yd-db|0,F)|0)+128|0)>>>8)+db;wd=c[C>>2]|0;xd=c[Bb>>2]|0}Bb=n+1812+(fb*2039|0)+134+(rd*3|0)+2|0;C=wd+xd|0;if((C|0)!=0){db=d[Bb]|0;w=(((C>>>1)+(wd<<8)|0)>>>0)/(C>>>0)|0;if((w|0)<1){zd=1}else{zd=(w|0)>255?255:w}w=C>>>0>20>>>0;eb=C;gHb(w?2560:eb<<7|0>>>25,w?0:0<<7|eb>>>25,_,$)|0;a[Bb]=(((ba(zd-db|0,F)|0)+128|0)>>>8)+db}rd=rd+1|0;}while((rd|0)<7);db=n+1812+(fb*2039|0)+194|0;Bb=c[sa>>2]|0;eb=c[ta>>2]|0;w=c[ua>>2]|0;C=c[va>>2]|0;cb=eb+Bb+w+C|0;if((cb|0)==0){Ad=eb;Bd=w;Cd=C}else{C=d[db]|0;w=(((cb>>>1)+(Bb<<8)|0)>>>0)/(cb>>>0)|0;if((w|0)<1){Dd=1}else{Dd=(w|0)>255?255:w}w=cb>>>0>20>>>0;Bb=cb;gHb(w?2560:Bb<<7|0>>>25,w?0:0<<7|Bb>>>25,_,$)|0;a[db]=(((ba(Dd-C|0,F)|0)+128|0)>>>8)+C;Ad=c[ta>>2]|0;Bd=c[ua>>2]|0;Cd=c[va>>2]|0}C=n+1812+(fb*2039|0)+195|0;db=Bd+Cd+Ad|0;if((db|0)==0){Ed=Bd;Fd=Cd}else{Bb=d[C]|0;w=(((db>>>1)+(Ad<<8)|0)>>>0)/(db>>>0)|0;if((w|0)<1){Gd=1}else{Gd=(w|0)>255?255:w}w=db>>>0>20>>>0;cb=db;gHb(w?2560:cb<<7|0>>>25,w?0:0<<7|cb>>>25,_,$)|0;a[C]=(((ba(Gd-Bb|0,F)|0)+128|0)>>>8)+Bb;Ed=c[ua>>2]|0;Fd=c[va>>2]|0}Bb=n+1812+(fb*2039|0)+196|0;C=Ed+Fd|0;if((C|0)==0){Hd=0}else{cb=d[Bb]|0;w=(((C>>>1)+(Ed<<8)|0)>>>0)/(C>>>0)|0;if((w|0)<1){Id=1}else{Id=(w|0)>255?255:w}w=C>>>0>20>>>0;db=C;gHb(w?2560:db<<7|0>>>25,w?0:0<<7|db>>>25,_,$)|0;a[Bb]=(((ba(Id-cb|0,F)|0)+128|0)>>>8)+cb;Hd=0}while(1){cb=n+1812+(fb*2039|0)+197+(Hd*33|0)|0;Bb=c[n+17652+(Hd*204|0)>>2]|0;db=(c[n+17652+(Hd*204|0)+4>>2]|0)+Bb|0;if((db|0)!=0){w=d[cb]|0;C=(((db>>>1)+(Bb<<8)|0)>>>0)/(db>>>0)|0;if((C|0)<1){Jd=1}else{Jd=(C|0)>255?255:C}C=db>>>0>20>>>0;Bb=db;gHb(C?2560:Bb<<7|0>>>25,C?0:0<<7|Bb>>>25,_,$)|0;a[cb]=(((ba(Jd-w|0,F)|0)+128|0)>>>8)+w}w=n+1812+(fb*2039|0)+197+(Hd*33|0)+1|0;cb=n+17652+(Hd*204|0)+12|0;Bb=c[cb>>2]|0;C=n+17652+(Hd*204|0)+16|0;db=n+17652+(Hd*204|0)+20|0;eb=n+17652+(Hd*204|0)+24|0;kb=n+17652+(Hd*204|0)+28|0;zb=n+17652+(Hd*204|0)+32|0;k=n+17652+(Hd*204|0)+36|0;jb=n+17652+(Hd*204|0)+40|0;hb=n+17652+(Hd*204|0)+44|0;Ob=n+17652+(Hd*204|0)+48|0;gb=(c[C>>2]|0)+Bb+(c[db>>2]|0)+(c[eb>>2]|0)+(c[kb>>2]|0)+(c[zb>>2]|0)+(c[k>>2]|0)+(c[jb>>2]|0)+(c[hb>>2]|0)+(c[Ob>>2]|0)|0;xb=c[n+17652+(Hd*204|0)+8>>2]|0;Kb=gb+xb|0;if((Kb|0)==0){Kd=Bb}else{Bb=d[w]|0;Lb=(((Kb>>>1)+(xb<<8)|0)>>>0)/(Kb>>>0)|0;if((Lb|0)<1){Ld=1}else{Ld=(Lb|0)>255?255:Lb}Lb=Kb>>>0>20>>>0;xb=Kb;gHb(Lb?2560:xb<<7|0>>>25,Lb?0:0<<7|xb>>>25,_,$)|0;a[w]=(((ba(Ld-Bb|0,F)|0)+128|0)>>>8)+Bb;Kd=c[cb>>2]|0}cb=gb-Kd|0;Bb=n+1812+(fb*2039|0)+197+(Hd*33|0)+2|0;if((gb|0)!=0){w=d[Bb]|0;xb=(((Kd<<8)+(gb>>>1)|0)>>>0)/(gb>>>0)|0;if((xb|0)<1){Md=1}else{Md=(xb|0)>255?255:xb}xb=gb>>>0>20>>>0;Lb=gb;gHb(xb?2560:Lb<<7|0>>>25,xb?0:0<<7|Lb>>>25,_,$)|0;a[Bb]=(((ba(Md-w|0,F)|0)+128|0)>>>8)+w}w=c[C>>2]|0;Bb=c[db>>2]|0;Lb=Bb+w|0;xb=cb-Lb|0;Kb=n+1812+(fb*2039|0)+197+(Hd*33|0)+3|0;if((gb|0)==(Kd|0)){Nd=w;Od=Bb}else{Bb=d[Kb]|0;w=(((Lb<<8)+(cb>>>1)|0)>>>0)/(cb>>>0)|0;if((w|0)<1){Pd=1}else{Pd=(w|0)>255?255:w}w=cb>>>0>20>>>0;gb=cb;gHb(w?2560:gb<<7|0>>>25,w?0:0<<7|gb>>>25,_,$)|0;a[Kb]=(((ba(Pd-Bb|0,F)|0)+128|0)>>>8)+Bb;Nd=c[C>>2]|0;Od=c[db>>2]|0}db=n+1812+(fb*2039|0)+197+(Hd*33|0)+4|0;C=Nd+Od|0;if((C|0)!=0){Bb=d[db]|0;Kb=(((C>>>1)+(Nd<<8)|0)>>>0)/(C>>>0)|0;if((Kb|0)<1){Qd=1}else{Qd=(Kb|0)>255?255:Kb}Kb=C>>>0>20>>>0;gb=C;gHb(Kb?2560:gb<<7|0>>>25,Kb?0:0<<7|gb>>>25,_,$)|0;a[db]=(((ba(Qd-Bb|0,F)|0)+128|0)>>>8)+Bb}Bb=c[eb>>2]|0;db=c[kb>>2]|0;gb=db+Bb|0;Kb=xb-gb|0;C=n+1812+(fb*2039|0)+197+(Hd*33|0)+5|0;if((cb|0)==(Lb|0)){Rd=Bb;Sd=db}else{db=d[C]|0;Bb=(((gb<<8)+(xb>>>1)|0)>>>0)/(xb>>>0)|0;if((Bb|0)<1){Td=1}else{Td=(Bb|0)>255?255:Bb}Bb=xb>>>0>20>>>0;Lb=xb;gHb(Bb?2560:Lb<<7|0>>>25,Bb?0:0<<7|Lb>>>25,_,$)|0;a[C]=(((ba(Td-db|0,F)|0)+128|0)>>>8)+db;Rd=c[eb>>2]|0;Sd=c[kb>>2]|0}kb=n+1812+(fb*2039|0)+197+(Hd*33|0)+6|0;eb=Rd+Sd|0;if((eb|0)!=0){db=d[kb]|0;C=(((eb>>>1)+(Rd<<8)|0)>>>0)/(eb>>>0)|0;if((C|0)<1){Ud=1}else{Ud=(C|0)>255?255:C}C=eb>>>0>20>>>0;Lb=eb;gHb(C?2560:Lb<<7|0>>>25,C?0:0<<7|Lb>>>25,_,$)|0;a[kb]=(((ba(Ud-db|0,F)|0)+128|0)>>>8)+db}db=n+1812+(fb*2039|0)+197+(Hd*33|0)+7|0;if((xb|0)!=(gb|0)){gb=d[db]|0;xb=(((c[zb>>2]<<8)+(Kb>>>1)|0)>>>0)/(Kb>>>0)|0;if((xb|0)<1){Vd=1}else{Vd=(xb|0)>255?255:xb}xb=Kb>>>0>20>>>0;zb=Kb;gHb(xb?2560:zb<<7|0>>>25,xb?0:0<<7|zb>>>25,_,$)|0;a[db]=(((ba(Vd-gb|0,F)|0)+128|0)>>>8)+gb}gb=n+1812+(fb*2039|0)+197+(Hd*33|0)+8|0;db=c[k>>2]|0;zb=c[jb>>2]|0;xb=zb+db|0;Kb=xb+(c[hb>>2]|0)+(c[Ob>>2]|0)|0;if((Kb|0)==0){Wd=db;Xd=zb}else{zb=d[gb]|0;db=(((Kb>>>1)+(xb<<8)|0)>>>0)/(Kb>>>0)|0;if((db|0)<1){Yd=1}else{Yd=(db|0)>255?255:db}db=Kb>>>0>20>>>0;xb=Kb;gHb(db?2560:xb<<7|0>>>25,db?0:0<<7|xb>>>25,_,$)|0;a[gb]=(((ba(Yd-zb|0,F)|0)+128|0)>>>8)+zb;Wd=c[k>>2]|0;Xd=c[jb>>2]|0}jb=n+1812+(fb*2039|0)+197+(Hd*33|0)+9|0;k=Wd+Xd|0;if((k|0)!=0){zb=d[jb]|0;gb=(((k>>>1)+(Wd<<8)|0)>>>0)/(k>>>0)|0;if((gb|0)<1){Zd=1}else{Zd=(gb|0)>255?255:gb}gb=k>>>0>20>>>0;xb=k;gHb(gb?2560:xb<<7|0>>>25,gb?0:0<<7|xb>>>25,_,$)|0;a[jb]=(((ba(Zd-zb|0,F)|0)+128|0)>>>8)+zb}zb=n+1812+(fb*2039|0)+197+(Hd*33|0)+10|0;jb=c[hb>>2]|0;hb=(c[Ob>>2]|0)+jb|0;if((hb|0)!=0){Ob=d[zb]|0;xb=(((hb>>>1)+(jb<<8)|0)>>>0)/(hb>>>0)|0;if((xb|0)<1){_d=1}else{_d=(xb|0)>255?255:xb}xb=hb>>>0>20>>>0;jb=hb;gHb(xb?2560:jb<<7|0>>>25,xb?0:0<<7|jb>>>25,_,$)|0;a[zb]=(((ba(_d-Ob|0,F)|0)+128|0)>>>8)+Ob}Ob=n+1812+(fb*2039|0)+197+(Hd*33|0)+11|0;zb=c[n+17652+(Hd*204|0)+52>>2]|0;jb=(c[n+17652+(Hd*204|0)+56>>2]|0)+zb|0;if((jb|0)==0){$d=0}else{xb=d[Ob]|0;hb=(((jb>>>1)+(zb<<8)|0)>>>0)/(jb>>>0)|0;if((hb|0)<1){ae=1}else{ae=(hb|0)>255?255:hb}hb=jb>>>0>20>>>0;zb=jb;gHb(hb?2560:zb<<7|0>>>25,hb?0:0<<7|zb>>>25,_,$)|0;a[Ob]=(((ba(ae-xb|0,F)|0)+128|0)>>>8)+xb;$d=0}while(1){xb=n+1812+(fb*2039|0)+197+(Hd*33|0)+12+$d|0;Ob=c[n+17652+(Hd*204|0)+60+($d<<3)>>2]|0;zb=(c[n+17652+(Hd*204|0)+60+($d<<3)+4>>2]|0)+Ob|0;if((zb|0)!=0){hb=d[xb]|0;jb=(((zb>>>1)+(Ob<<8)|0)>>>0)/(zb>>>0)|0;if((jb|0)<1){be=1}else{be=(jb|0)>255?255:jb}jb=zb>>>0>20>>>0;Ob=zb;gHb(jb?2560:Ob<<7|0>>>25,jb?0:0<<7|Ob>>>25,_,$)|0;a[xb]=(((ba(be-hb|0,F)|0)+128|0)>>>8)+hb}hb=$d+1|0;if((hb|0)<10){$d=hb}else{ce=0;break}}do{hb=n+1812+(fb*2039|0)+197+(Hd*33|0)+22+(ce*3|0)|0;xb=c[n+17652+(Hd*204|0)+140+(ce<<4)>>2]|0;Ob=n+17652+(Hd*204|0)+140+(ce<<4)+4|0;jb=c[Ob>>2]|0;zb=n+17652+(Hd*204|0)+140+(ce<<4)+8|0;gb=c[zb>>2]|0;k=n+17652+(Hd*204|0)+140+(ce<<4)+12|0;db=c[k>>2]|0;Kb=jb+xb+gb+db|0;if((Kb|0)==0){ee=jb;ge=gb;he=db}else{db=d[hb]|0;gb=(((Kb>>>1)+(xb<<8)|0)>>>0)/(Kb>>>0)|0;if((gb|0)<1){ie=1}else{ie=(gb|0)>255?255:gb}gb=Kb>>>0>20>>>0;xb=Kb;gHb(gb?2560:xb<<7|0>>>25,gb?0:0<<7|xb>>>25,_,$)|0;a[hb]=(((ba(ie-db|0,F)|0)+128|0)>>>8)+db;ee=c[Ob>>2]|0;ge=c[zb>>2]|0;he=c[k>>2]|0}Ob=n+1812+(fb*2039|0)+197+(Hd*33|0)+22+(ce*3|0)+1|0;db=ge+he+ee|0;if((db|0)==0){je=ge;ke=he}else{hb=d[Ob]|0;xb=(((db>>>1)+(ee<<8)|0)>>>0)/(db>>>0)|0;if((xb|0)<1){me=1}else{me=(xb|0)>255?255:xb}xb=db>>>0>20>>>0;gb=db;gHb(xb?2560:gb<<7|0>>>25,xb?0:0<<7|gb>>>25,_,$)|0;a[Ob]=(((ba(me-hb|0,F)|0)+128|0)>>>8)+hb;je=c[zb>>2]|0;ke=c[k>>2]|0}k=n+1812+(fb*2039|0)+197+(Hd*33|0)+22+(ce*3|0)+2|0;zb=je+ke|0;if((zb|0)!=0){hb=d[k]|0;Ob=(((zb>>>1)+(je<<8)|0)>>>0)/(zb>>>0)|0;if((Ob|0)<1){ne=1}else{ne=(Ob|0)>255?255:Ob}Ob=zb>>>0>20>>>0;gb=zb;gHb(Ob?2560:gb<<7|0>>>25,Ob?0:0<<7|gb>>>25,_,$)|0;a[k]=(((ba(ne-hb|0,F)|0)+128|0)>>>8)+hb}ce=ce+1|0;}while((ce|0)<2);hb=n+1812+(fb*2039|0)+197+(Hd*33|0)+28|0;k=c[n+17652+(Hd*204|0)+172>>2]|0;gb=n+17652+(Hd*204|0)+176|0;Ob=c[gb>>2]|0;zb=n+17652+(Hd*204|0)+180|0;xb=c[zb>>2]|0;db=n+17652+(Hd*204|0)+184|0;Kb=c[db>>2]|0;jb=Ob+k+xb+Kb|0;if((jb|0)==0){oe=Ob;pe=xb;qe=Kb}else{Kb=d[hb]|0;xb=(((jb>>>1)+(k<<8)|0)>>>0)/(jb>>>0)|0;if((xb|0)<1){re=1}else{re=(xb|0)>255?255:xb}xb=jb>>>0>20>>>0;k=jb;gHb(xb?2560:k<<7|0>>>25,xb?0:0<<7|k>>>25,_,$)|0;a[hb]=(((ba(re-Kb|0,F)|0)+128|0)>>>8)+Kb;oe=c[gb>>2]|0;pe=c[zb>>2]|0;qe=c[db>>2]|0}gb=n+1812+(fb*2039|0)+197+(Hd*33|0)+29|0;Kb=pe+qe+oe|0;if((Kb|0)==0){se=pe;te=qe}else{hb=d[gb]|0;k=(((Kb>>>1)+(oe<<8)|0)>>>0)/(Kb>>>0)|0;if((k|0)<1){ue=1}else{ue=(k|0)>255?255:k}k=Kb>>>0>20>>>0;xb=Kb;gHb(k?2560:xb<<7|0>>>25,k?0:0<<7|xb>>>25,_,$)|0;a[gb]=(((ba(ue-hb|0,F)|0)+128|0)>>>8)+hb;se=c[zb>>2]|0;te=c[db>>2]|0}db=n+1812+(fb*2039|0)+197+(Hd*33|0)+30|0;zb=se+te|0;if((zb|0)!=0){hb=d[db]|0;gb=(((zb>>>1)+(se<<8)|0)>>>0)/(zb>>>0)|0;if((gb|0)<1){ve=1}else{ve=(gb|0)>255?255:gb}gb=zb>>>0>20>>>0;xb=zb;gHb(gb?2560:xb<<7|0>>>25,gb?0:0<<7|xb>>>25,_,$)|0;a[db]=(((ba(ve-hb|0,F)|0)+128|0)>>>8)+hb}do{if((a[wa]|0)!=0){hb=n+1812+(fb*2039|0)+197+(Hd*33|0)+31|0;db=c[n+17652+(Hd*204|0)+188>>2]|0;xb=(c[n+17652+(Hd*204|0)+192>>2]|0)+db|0;if((xb|0)!=0){gb=d[hb]|0;zb=(((xb>>>1)+(db<<8)|0)>>>0)/(xb>>>0)|0;if((zb|0)<1){we=1}else{we=(zb|0)>255?255:zb}zb=xb>>>0>20>>>0;db=xb;gHb(zb?2560:db<<7|0>>>25,zb?0:0<<7|db>>>25,_,$)|0;a[hb]=(((ba(we-gb|0,F)|0)+128|0)>>>8)+gb}gb=n+1812+(fb*2039|0)+197+(Hd*33|0)+32|0;hb=c[n+17652+(Hd*204|0)+196>>2]|0;db=(c[n+17652+(Hd*204|0)+200>>2]|0)+hb|0;if((db|0)==0){break}zb=d[gb]|0;xb=(((db>>>1)+(hb<<8)|0)>>>0)/(db>>>0)|0;if((xb|0)<1){xe=1}else{xe=(xb|0)>255?255:xb}xb=db>>>0>20>>>0;hb=db;gHb(xb?2560:hb<<7|0>>>25,xb?0:0<<7|hb>>>25,_,$)|0;a[gb]=(((ba(xe-zb|0,F)|0)+128|0)>>>8)+zb}}while(0);zb=Hd+1|0;if((zb|0)<2){Hd=zb}else{ye=0;break}}while(1){zb=n+1812+(fb*2039|0)+(ye*9|0)|0;gb=n+16628+(ye*40|0)|0;hb=n+16628+(ye*40|0)+4|0;xb=n+16628+(ye*40|0)+12|0;db=n+16628+(ye*40|0)+16|0;k=n+16628+(ye*40|0)+20|0;Kb=n+16628+(ye*40|0)+24|0;jb=n+16628+(ye*40|0)+28|0;Ob=n+16628+(ye*40|0)+32|0;kb=n+16628+(ye*40|0)+36|0;Lb=c[kb>>2]|0;C=(c[hb>>2]|0)+(c[gb>>2]|0)+(c[xb>>2]|0)+(c[db>>2]|0)+(c[k>>2]|0)+(c[Kb>>2]|0)+(c[jb>>2]|0)+(c[Ob>>2]|0)+Lb|0;eb=c[n+16628+(ye*40|0)+8>>2]|0;Bb=C+eb|0;if((Bb|0)==0){ze=Lb}else{Lb=d[zb]|0;cb=(((Bb>>>1)+(eb<<8)|0)>>>0)/(Bb>>>0)|0;if((cb|0)<1){Ae=1}else{Ae=(cb|0)>255?255:cb}cb=Bb>>>0>20>>>0;eb=Bb;gHb(cb?2560:eb<<7|0>>>25,cb?0:0<<7|eb>>>25,_,$)|0;a[zb]=(((ba(Ae-Lb|0,F)|0)+128|0)>>>8)+Lb;ze=c[kb>>2]|0}kb=C-ze|0;Lb=n+1812+(fb*2039|0)+(ye*9|0)+1|0;if((C|0)!=0){zb=d[Lb]|0;eb=(((ze<<8)+(C>>>1)|0)>>>0)/(C>>>0)|0;if((eb|0)<1){Be=1}else{Be=(eb|0)>255?255:eb}eb=C>>>0>20>>>0;cb=C;gHb(eb?2560:cb<<7|0>>>25,eb?0:0<<7|cb>>>25,_,$)|0;a[Lb]=(((ba(Be-zb|0,F)|0)+128|0)>>>8)+zb}zb=c[gb>>2]|0;gb=kb-zb|0;Lb=n+1812+(fb*2039|0)+(ye*9|0)+2|0;if((C|0)!=(ze|0)){C=d[Lb]|0;cb=(((zb<<8)+(kb>>>1)|0)>>>0)/(kb>>>0)|0;if((cb|0)<1){Ce=1}else{Ce=(cb|0)>255?255:cb}cb=kb>>>0>20>>>0;eb=kb;gHb(cb?2560:eb<<7|0>>>25,cb?0:0<<7|eb>>>25,_,$)|0;a[Lb]=(((ba(Ce-C|0,F)|0)+128|0)>>>8)+C}C=(c[db>>2]|0)+(c[hb>>2]|0)+(c[k>>2]|0)|0;Lb=gb-C|0;eb=n+1812+(fb*2039|0)+(ye*9|0)+3|0;if((kb|0)!=(zb|0)){zb=d[eb]|0;kb=(((C<<8)+(gb>>>1)|0)>>>0)/(gb>>>0)|0;if((kb|0)<1){De=1}else{De=(kb|0)>255?255:kb}kb=gb>>>0>20>>>0;cb=gb;gHb(kb?2560:cb<<7|0>>>25,kb?0:0<<7|cb>>>25,_,$)|0;a[eb]=(((ba(De-zb|0,F)|0)+128|0)>>>8)+zb}zb=n+1812+(fb*2039|0)+(ye*9|0)+4|0;if((C|0)!=0){eb=d[zb]|0;cb=(((c[hb>>2]<<8)+(C>>>1)|0)>>>0)/(C>>>0)|0;if((cb|0)<1){Ee=1}else{Ee=(cb|0)>255?255:cb}cb=C>>>0>20>>>0;hb=C;gHb(cb?2560:hb<<7|0>>>25,cb?0:0<<7|hb>>>25,_,$)|0;a[zb]=(((ba(Ee-eb|0,F)|0)+128|0)>>>8)+eb}eb=n+1812+(fb*2039|0)+(ye*9|0)+5|0;zb=c[db>>2]|0;db=(c[k>>2]|0)+zb|0;if((db|0)!=0){k=d[eb]|0;hb=(((db>>>1)+(zb<<8)|0)>>>0)/(db>>>0)|0;if((hb|0)<1){Fe=1}else{Fe=(hb|0)>255?255:hb}hb=db>>>0>20>>>0;zb=db;gHb(hb?2560:zb<<7|0>>>25,hb?0:0<<7|zb>>>25,_,$)|0;a[eb]=(((ba(Fe-k|0,F)|0)+128|0)>>>8)+k}k=c[xb>>2]|0;xb=Lb-k|0;eb=n+1812+(fb*2039|0)+(ye*9|0)+6|0;if((gb|0)!=(C|0)){C=d[eb]|0;gb=(((k<<8)+(Lb>>>1)|0)>>>0)/(Lb>>>0)|0;if((gb|0)<1){Ge=1}else{Ge=(gb|0)>255?255:gb}gb=Lb>>>0>20>>>0;zb=Lb;gHb(gb?2560:zb<<7|0>>>25,gb?0:0<<7|zb>>>25,_,$)|0;a[eb]=(((ba(Ge-C|0,F)|0)+128|0)>>>8)+C}C=n+1812+(fb*2039|0)+(ye*9|0)+7|0;if((Lb|0)!=(k|0)){k=d[C]|0;Lb=(((c[jb>>2]<<8)+(xb>>>1)|0)>>>0)/(xb>>>0)|0;if((Lb|0)<1){He=1}else{He=(Lb|0)>255?255:Lb}Lb=xb>>>0>20>>>0;jb=xb;gHb(Lb?2560:jb<<7|0>>>25,Lb?0:0<<7|jb>>>25,_,$)|0;a[C]=(((ba(He-k|0,F)|0)+128|0)>>>8)+k}k=n+1812+(fb*2039|0)+(ye*9|0)+8|0;C=c[Kb>>2]|0;Kb=(c[Ob>>2]|0)+C|0;if((Kb|0)!=0){Ob=d[k]|0;jb=(((Kb>>>1)+(C<<8)|0)>>>0)/(Kb>>>0)|0;if((jb|0)<1){Ie=1}else{Ie=(jb|0)>255?255:jb}jb=Kb>>>0>20>>>0;C=Kb;gHb(jb?2560:C<<7|0>>>25,jb?0:0<<7|C>>>25,_,$)|0;a[k]=(((ba(Ie-Ob|0,F)|0)+128|0)>>>8)+Ob}Ob=ye+1|0;if((Ob|0)<4){ye=Ob}else{Je=0;break}}do{Ob=n+1812+(fb*2039|0)+36+(Je*9|0)|0;k=n+16788+(Je*40|0)|0;C=n+16788+(Je*40|0)+4|0;jb=n+16788+(Je*40|0)+12|0;Kb=n+16788+(Je*40|0)+16|0;Lb=n+16788+(Je*40|0)+20|0;xb=n+16788+(Je*40|0)+24|0;eb=n+16788+(Je*40|0)+28|0;zb=n+16788+(Je*40|0)+32|0;gb=n+16788+(Je*40|0)+36|0;hb=c[gb>>2]|0;db=(c[C>>2]|0)+(c[k>>2]|0)+(c[jb>>2]|0)+(c[Kb>>2]|0)+(c[Lb>>2]|0)+(c[xb>>2]|0)+(c[eb>>2]|0)+(c[zb>>2]|0)+hb|0;cb=c[n+16788+(Je*40|0)+8>>2]|0;kb=db+cb|0;if((kb|0)==0){Ke=hb}else{hb=d[Ob]|0;Bb=(((kb>>>1)+(cb<<8)|0)>>>0)/(kb>>>0)|0;if((Bb|0)<1){Le=1}else{Le=(Bb|0)>255?255:Bb}Bb=kb>>>0>20>>>0;cb=kb;gHb(Bb?2560:cb<<7|0>>>25,Bb?0:0<<7|cb>>>25,_,$)|0;a[Ob]=(((ba(Le-hb|0,F)|0)+128|0)>>>8)+hb;Ke=c[gb>>2]|0}gb=db-Ke|0;hb=n+1812+(fb*2039|0)+36+(Je*9|0)+1|0;if((db|0)!=0){Ob=d[hb]|0;cb=(((Ke<<8)+(db>>>1)|0)>>>0)/(db>>>0)|0;if((cb|0)<1){Me=1}else{Me=(cb|0)>255?255:cb}cb=db>>>0>20>>>0;Bb=db;gHb(cb?2560:Bb<<7|0>>>25,cb?0:0<<7|Bb>>>25,_,$)|0;a[hb]=(((ba(Me-Ob|0,F)|0)+128|0)>>>8)+Ob}Ob=c[k>>2]|0;k=gb-Ob|0;hb=n+1812+(fb*2039|0)+36+(Je*9|0)+2|0;if((db|0)!=(Ke|0)){db=d[hb]|0;Bb=(((Ob<<8)+(gb>>>1)|0)>>>0)/(gb>>>0)|0;if((Bb|0)<1){Ne=1}else{Ne=(Bb|0)>255?255:Bb}Bb=gb>>>0>20>>>0;cb=gb;gHb(Bb?2560:cb<<7|0>>>25,Bb?0:0<<7|cb>>>25,_,$)|0;a[hb]=(((ba(Ne-db|0,F)|0)+128|0)>>>8)+db}db=(c[Kb>>2]|0)+(c[C>>2]|0)+(c[Lb>>2]|0)|0;hb=k-db|0;cb=n+1812+(fb*2039|0)+36+(Je*9|0)+3|0;if((gb|0)!=(Ob|0)){Ob=d[cb]|0;gb=(((db<<8)+(k>>>1)|0)>>>0)/(k>>>0)|0;if((gb|0)<1){Oe=1}else{Oe=(gb|0)>255?255:gb}gb=k>>>0>20>>>0;Bb=k;gHb(gb?2560:Bb<<7|0>>>25,gb?0:0<<7|Bb>>>25,_,$)|0;a[cb]=(((ba(Oe-Ob|0,F)|0)+128|0)>>>8)+Ob}Ob=n+1812+(fb*2039|0)+36+(Je*9|0)+4|0;if((db|0)!=0){cb=d[Ob]|0;Bb=(((c[C>>2]<<8)+(db>>>1)|0)>>>0)/(db>>>0)|0;if((Bb|0)<1){Pe=1}else{Pe=(Bb|0)>255?255:Bb}Bb=db>>>0>20>>>0;C=db;gHb(Bb?2560:C<<7|0>>>25,Bb?0:0<<7|C>>>25,_,$)|0;a[Ob]=(((ba(Pe-cb|0,F)|0)+128|0)>>>8)+cb}cb=n+1812+(fb*2039|0)+36+(Je*9|0)+5|0;Ob=c[Kb>>2]|0;Kb=(c[Lb>>2]|0)+Ob|0;if((Kb|0)!=0){Lb=d[cb]|0;C=(((Kb>>>1)+(Ob<<8)|0)>>>0)/(Kb>>>0)|0;if((C|0)<1){Qe=1}else{Qe=(C|0)>255?255:C}C=Kb>>>0>20>>>0;Ob=Kb;gHb(C?2560:Ob<<7|0>>>25,C?0:0<<7|Ob>>>25,_,$)|0;a[cb]=(((ba(Qe-Lb|0,F)|0)+128|0)>>>8)+Lb}Lb=c[jb>>2]|0;jb=hb-Lb|0;cb=n+1812+(fb*2039|0)+36+(Je*9|0)+6|0;if((k|0)!=(db|0)){db=d[cb]|0;k=(((Lb<<8)+(hb>>>1)|0)>>>0)/(hb>>>0)|0;if((k|0)<1){Re=1}else{Re=(k|0)>255?255:k}k=hb>>>0>20>>>0;Ob=hb;gHb(k?2560:Ob<<7|0>>>25,k?0:0<<7|Ob>>>25,_,$)|0;a[cb]=(((ba(Re-db|0,F)|0)+128|0)>>>8)+db}db=n+1812+(fb*2039|0)+36+(Je*9|0)+7|0;if((hb|0)!=(Lb|0)){Lb=d[db]|0;hb=(((c[eb>>2]<<8)+(jb>>>1)|0)>>>0)/(jb>>>0)|0;if((hb|0)<1){Se=1}else{Se=(hb|0)>255?255:hb}hb=jb>>>0>20>>>0;eb=jb;gHb(hb?2560:eb<<7|0>>>25,hb?0:0<<7|eb>>>25,_,$)|0;a[db]=(((ba(Se-Lb|0,F)|0)+128|0)>>>8)+Lb}Lb=n+1812+(fb*2039|0)+36+(Je*9|0)+8|0;db=c[xb>>2]|0;xb=(c[zb>>2]|0)+db|0;if((xb|0)!=0){zb=d[Lb]|0;eb=(((xb>>>1)+(db<<8)|0)>>>0)/(xb>>>0)|0;if((eb|0)<1){Te=1}else{Te=(eb|0)>255?255:eb}eb=xb>>>0>20>>>0;db=xb;gHb(eb?2560:db<<7|0>>>25,eb?0:0<<7|db>>>25,_,$)|0;a[Lb]=(((ba(Te-zb|0,F)|0)+128|0)>>>8)+zb}Je=Je+1|0;}while((Je|0)<10)}else{E=211}}while(0);if((E|0)==211){E=0;zb=n+1812+(fb*2039|0)+191|0;a[zb]=a[xa]|0;a[zb+1|0]=a[xa+1|0]|0;a[zb+2|0]=a[xa+2|0]|0;zb=n+1812+(fb*2039|0)+179|0;a[zb]=a[ya]|0;a[zb+1|0]=a[ya+1|0]|0;a[zb+2|0]=a[ya+2|0]|0;a[zb+3|0]=a[ya+3|0]|0;a[zb+4|0]=a[ya+4|0]|0;a[zb+5|0]=a[ya+5|0]|0;zb=n+1812+(fb*2039|0)+185|0;x=d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0;a[zb]=x;x=x>>8;a[zb+1|0]=x;x=x>>8;a[zb+2|0]=x;x=x>>8;a[zb+3|0]=x;zb=n+1812+(fb*2039|0)+189|0;x=(d[Aa]|d[Aa+1|0]<<8)<<16>>16;a[zb]=x;x=x>>8;a[zb+1|0]=x}X0a(b);yc=c[A>>2]|0}}while(0);c[A>>2]=yc+1;if((yc|0)==1){$a=bb;q=ab}else{break}}if((E|0)==65){Y0a(l,2147483647,0);p=-1094995529;i=h;return p|0}else if((E|0)==70){c[wb>>2]=Cb-Fb;c[Ab>>2]=Db-Gb;Y0a(l,2147483647,0);p=-1094995529;i=h;return p|0}else if((E|0)==179){c[A>>2]=xc+1}Y0a(l,2147483647,0);l=z;if((c[c[z>>2]>>2]|0)!=0){U0a(b,l)}T0a(l,u)|0;u=m+1180|0;l=u;if((c[c[u>>2]>>2]|0)!=0){U0a(b,l)}T0a(l,m+1276|0)|0;l=m+1192|0;u=l;if((c[c[l>>2]>>2]|0)!=0){U0a(b,u)}T0a(u,m+1288|0)|0;u=m+1204|0;l=u;if((c[c[u>>2]>>2]|0)!=0){U0a(b,l)}T0a(l,m+1300|0)|0;l=m+1216|0;u=l;if((c[c[l>>2]>>2]|0)!=0){U0a(b,u)}T0a(u,m+1312|0)|0;u=m+1228|0;l=u;if((c[c[u>>2]>>2]|0)!=0){U0a(b,l)}T0a(l,m+1324|0)|0;l=m+1240|0;u=l;if((c[c[l>>2]>>2]|0)!=0){U0a(b,u)}T0a(u,m+1336|0)|0;u=m+1252|0;l=u;if((c[c[u>>2]>>2]|0)!=0){U0a(b,l)}T0a(l,m+1348|0)|0;if((a[m+1139|0]|0)!=0){p=0;i=h;return p|0}m=MCb(e,c[s>>2]|0)|0;if((m|0)<0){p=m;i=h;return p|0}c[f>>2]=1;p=0;i=h;return p|0}function F6a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;d=b+1360|0;e=d;if((c[c[e>>2]>>2]|0)!=0){U0a(a,d);XAb(b+1372|0)}JCb(e);e=b+1384|0;d=e;if((c[c[d>>2]>>2]|0)!=0){U0a(a,e);XAb(b+1396|0)}JCb(d);d=b+1168|0;e=b+1264|0;f=0;do{g=d+(f*12|0)|0;h=g|0;if((c[c[h>>2]>>2]|0)!=0){U0a(a,g)}JCb(h);h=e+(f*12|0)|0;g=h|0;if((c[c[g>>2]>>2]|0)!=0){U0a(a,h)}JCb(g);f=f+1|0;}while((f|0)<8);$Db(b+30148|0);$Db(b+1080|0);$Db(b+35860|0);$Db(b+1072|0);c[b+1076>>2]=0;return 0}function G6a(a){a=a|0;var b=0;b=c[a+60>>2]|0;U0a(a,b+1360|0);XAb(b+1372|0);U0a(a,b+1384|0);XAb(b+1396|0);U0a(a,b+1168|0);U0a(a,b+1180|0);U0a(a,b+1192|0);U0a(a,b+1204|0);U0a(a,b+1216|0);U0a(a,b+1228|0);U0a(a,b+1240|0);U0a(a,b+1252|0);return}function H6a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0;j=i;k=e+60|0;l=c[k>>2]|0;m=g>>>0>268435455>>>0?-8:g<<3;n=m>>>0>2147483639>>>0|(f|0)==0;o=n?0:f;p=n?0:m;m=l+1032|0;c[m>>2]=o;c[l+1044>>2]=p;q=p+8|0;r=l+1048|0;c[r>>2]=q;c[l+1036>>2]=o+(p>>3);p=l+1040|0;c[p>>2]=0;if(n){yDb(e,16,1935408,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}n=o;u=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24)&192;n=q>>>0>2>>>0?2:q;c[p>>2]=n;if((u|0)!=128){yDb(e,16,1912152,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}u=d[o+(n>>>3)|0]<<(n&2)>>>7;v=(n|0)<(q|0)|n;c[p>>2]=v;a[l+1136|0]=u&1;u=d[o+(n>>>3)|0]|0;n=((v|0)<(q|0))+v|0;c[p>>2]=n;if((u&128>>>((v&7)>>>0)|0)!=0){yDb(e,16,1891624,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}v=d[o+(n>>>3)|0]|0;u=((n|0)<(q|0))+n|0;c[p>>2]=u;if((v&128>>>((n&7)>>>0)|0)!=0){n=o+(u>>>3)|0;v=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(u&7)>>>29;n=u+3|0;c[p>>2]=q>>>0>n>>>0?n:q;c[h>>2]=v;t=0;i=j;return t|0}c[l+1096>>2]=c[l+1092>>2];v=l+1137|0;a[l+1138|0]=a[v]|0;h=d[o+(u>>>3)|0]<<(u&7);n=((u|0)<(q|0))+u|0;c[p>>2]=n;u=(h>>>7&1^1)&255;a[v]=u;h=l+1139|0;w=a[h]|0;y=d[o+(n>>>3)|0]<<(n&7);z=((n|0)<(q|0))+n|0;c[p>>2]=z;n=(y>>>7&1^1)&255;a[h]=n;h=d[o+(z>>>3)|0]<<(z&7)>>>7;y=((z|0)<(q|0))+z|0;c[p>>2]=y;z=h&1;h=l+1141|0;a[h]=z;A=z<<24>>24==0;if(A){B=w<<24>>24==0|0}else{B=0}w=l+1140|0;a[w]=B;a:do{if(u<<24>>24==0){if(n<<24>>24==0){C=0;D=y}else{z=d[o+(y>>>3)|0]<<(y&7)>>>7;E=((y|0)<(q|0))+y|0;c[p>>2]=E;C=z&1;D=E}a[l+1144|0]=C;if(A){E=o+(D>>>3)|0;z=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>30;E=D+2|0;F=q>>>0>E>>>0?E:q;c[p>>2]=F;G=z&255;H=F}else{G=0;H=D}a[l+1145|0]=G;F=o+(H>>>3)|0;z=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(H&7);if(!(C<<24>>24==0)){F=H+24|0;E=q>>>0>F>>>0?F:q;c[p>>2]=E;if((z&-256|0)==1233338880){F=o+(E>>>3)|0;I=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>24;F=E+8|0;E=q>>>0>F>>>0?F:q;c[p>>2]=E;a[l+1146|0]=I;I=o+(E>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(E&7)>>>16;I=E+16|0;E=q>>>0>I>>>0?I:q;c[p>>2]=E;I=F+1|0;F=o+(E>>>3)|0;J=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>16;F=E+16|0;E=q>>>0>F>>>0?F:q;c[p>>2]=E;F=J+1|0;J=d[o+(E>>>3)|0]|0;K=((E|0)<(q|0))+E|0;c[p>>2]=K;if((J&128>>>((E&7)>>>0)|0)==0){L=I;M=F;N=K;break}E=K+32|0;K=q>>>0>E>>>0?E:q;c[p>>2]=K;L=I;M=F;N=K;break}else{yDb(e,16,2349160,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}}K=H+8|0;F=q>>>0>K>>>0?K:q;c[p>>2]=F;a[l+1146|0]=z>>>24;z=o+(F>>>3)|0;K=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(F&7)>>>29;z=F+3|0;F=q>>>0>z>>>0?z:q;c[p>>2]=F;a[l+1157|0]=K;z=d[o+(F>>>3)|0]<<(F&7)>>>7;I=((F|0)<(q|0))+F|0;c[p>>2]=I;F=z&1;a[l+1160|0]=F;z=o+(I>>>3)|0;E=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(I&7)>>>29;z=I+3|0;I=q>>>0>z>>>0?z:q;c[p>>2]=I;a[l+1158|0]=E;z=d[o+(I>>>3)|0]<<(I&7)>>>7;J=((I|0)<(q|0))+I|0;c[p>>2]=J;I=z&1;a[l+1161|0]=I;z=o+(J>>>3)|0;O=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(J&7)>>>29;z=J+3|0;J=q>>>0>z>>>0?z:q;c[p>>2]=J;a[l+1159|0]=O;z=d[o+(J>>>3)|0]<<(J&7)>>>7;P=((J|0)<(q|0))+J|0;c[p>>2]=P;J=z&1;a[l+1162|0]=J;z=l+1168|0;Q=z+(K*12|0)|0;do{if((c[c[Q>>2]>>2]|0)!=0){K=z+(E*12|0)|0;if((c[c[K>>2]>>2]|0)==0){break}R=z+(O*12|0)|0;if((c[c[R>>2]>>2]|0)==0){break}S=d[o+(P>>>3)|0]|0;T=((P|0)<(q|0))+P|0;c[p>>2]=T;do{if((S&128>>>((P&7)>>>0)|0)==0){U=d[o+(T>>>3)|0]|0;V=((T|0)<(q|0))+T|0;c[p>>2]=V;if((U&128>>>((T&7)>>>0)|0)!=0){U=c[K>>2]|0;W=c[U+68>>2]|0;X=c[U+72>>2]|0;Y=V;break}U=d[o+(V>>>3)|0]|0;Z=((V|0)<(q|0))+V|0;c[p>>2]=Z;if((U&128>>>((V&7)>>>0)|0)==0){V=o+(Z>>>3)|0;U=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Z&7)>>>16;V=Z+16|0;_=q>>>0>V>>>0?V:q;c[p>>2]=_;V=o+(_>>>3)|0;$=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(_&7)>>>16;V=_+16|0;_=q>>>0>V>>>0?V:q;c[p>>2]=_;W=U+1|0;X=$+1|0;Y=_;break}else{_=c[R>>2]|0;W=c[_+68>>2]|0;X=c[_+72>>2]|0;Y=Z;break}}else{Z=c[Q>>2]|0;W=c[Z+68>>2]|0;X=c[Z+72>>2]|0;Y=T}}while(0);T=c[l+1360>>2]|0;if((c[T+68>>2]|0)==(W|0)){aa=(c[T+72>>2]|0)==(X|0)|0}else{aa=0}a[w]=B&aa;T=((Y|0)<(q|0))+Y|0;if((d[o+(Y>>>3)|0]&128>>>((Y&7)>>>0)|0)==0){ba=T}else{R=T+32|0;ba=q>>>0>R>>>0?R:q}c[p>>2]=ba;R=d[o+(ba>>>3)|0]<<(ba&7)>>>7;T=((ba|0)<(q|0))+ba|0;c[p>>2]=T;a[l+1147|0]=R&1;R=d[o+(T>>>3)|0]|0;K=((T|0)<(q|0))+T|0;c[p>>2]=K;if((R&128>>>((T&7)>>>0)|0)==0){T=o+(K>>>3)|0;R=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(K&7)>>>30;T=K+2|0;S=q>>>0>T>>>0?T:q;c[p>>2]=S;ca=R;da=S}else{ca=4;da=K}c[l+1148>>2]=ca;if(F<<24>>24==I<<24>>24){a[l+1152|0]=F^J;if(F<<24>>24==J<<24>>24){L=W;M=X;N=da;break a}a[l+1153|0]=2;a[l+1163|0]=0;a[l+1164|0]=1;L=W;M=X;N=da;break a}a[l+1152|0]=1;K=l+1153|0;if(F<<24>>24==J<<24>>24){a[K]=1;a[l+1163|0]=0;a[l+1164|0]=2;L=W;M=X;N=da;break a}else{a[K]=0;a[l+1163|0]=1;a[l+1164|0]=2;L=W;M=X;N=da;break a}}}while(0);yDb(e,16,2304584,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}else{J=o+(y>>>3)|0;F=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(y&7);J=y+24|0;I=q>>>0>J>>>0?J:q;c[p>>2]=I;if((F&-256|0)!=1233338880){yDb(e,16,2349160,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}F=o+(I>>>3)|0;J=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>29;F=I+3|0;I=q>>>0>F>>>0?F:q;c[p>>2]=I;a[l+1142|0]=J;if((J|0)==7){yDb(e,16,2329e3,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}else{J=d[o+(I>>>3)|0]<<(I&7)>>>7;F=((I|0)<(q|0))+I|0;c[p>>2]=F;a[l+1143|0]=J&1;a[l+1146|0]=-1;J=o+(F>>>3)|0;I=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(F&7)>>>16;J=F+16|0;F=q>>>0>J>>>0?J:q;c[p>>2]=F;J=I+1|0;I=o+(F>>>3)|0;Q=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(F&7)>>>16;I=F+16|0;F=q>>>0>I>>>0?I:q;c[p>>2]=F;I=Q+1|0;Q=d[o+(F>>>3)|0]|0;P=((F|0)<(q|0))+F|0;c[p>>2]=P;if((Q&128>>>((F&7)>>>0)|0)==0){L=J;M=I;N=P;break}F=P+32|0;P=q>>>0>F>>>0?F:q;c[p>>2]=P;L=J;M=I;N=P;break}}}while(0);if(A){A=d[o+(N>>>3)|0]<<(N&7)>>>7;y=((N|0)<(q|0))+N|0;c[p>>2]=y;a[l+1154|0]=A&1;A=d[o+(y>>>3)|0]<<(y&7)>>>7;da=((y|0)<(q|0))+y|0;c[p>>2]=da;ea=A&1;fa=da}else{a[l+1154|0]=0;ea=1;fa=N}a[l+1155|0]=ea;ea=o+(fa>>>3)|0;N=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(fa&7)>>>30;ea=fa+2|0;fa=q>>>0>ea>>>0?ea:q;c[p>>2]=fa;a[l+1156|0]=N;ea=o+(fa>>>3)|0;da=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(fa&7)>>>26;ea=fa+6|0;fa=q>>>0>ea>>>0?ea:q;c[p>>2]=fa;ea=l+1408|0;a[ea]=da;da=o+(fa>>>3)|0;A=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(fa&7)>>>29;da=fa+3|0;fa=q>>>0>da>>>0?da:q;c[p>>2]=fa;da=l+1409|0;if((a[da]|0)!=(A|0)){TGb(l+1410|0,0,64)|0}a[da]=A;A=d[o+(fa>>>3)|0]<<(fa&7)>>>7;da=((fa|0)<(q|0))+fa|0;c[p>>2]=da;fa=A&1;A=l+1538|0;a[A]=fa;do{if(fa<<24>>24==0){TGb(A|0,0,7)|0;ga=da;ha=o;ia=q}else{y=d[o+(da>>>3)|0]|0;X=((da|0)<(q|0))+da|0;c[p>>2]=X;if((y&128>>>((da&7)>>>0)|0)==0){ga=X;ha=o;ia=q;break}else{ja=0;ka=X;la=o;ma=q}while(1){X=d[la+(ka>>>3)|0]|0;y=((ka|0)<(ma|0))+ka|0;c[p>>2]=y;if((X&128>>>((ka&7)>>>0)|0)!=0){X=la+(y>>>3)|0;W=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(y&7)>>>26;X=y+6|0;y=ma>>>0>X>>>0?X:ma;c[p>>2]=y;X=d[la+(y>>>3)|0]|0;c[p>>2]=((y|0)<(ma|0))+y;a[l+(ja+1541)|0]=(X&128>>>((y&7)>>>0)|0)!=0?-W|0:W}W=ja+1|0;na=c[p>>2]|0;if((W|0)>=4){break}ja=W;ka=na;la=c[m>>2]|0;ma=c[r>>2]|0}W=c[m>>2]|0;y=d[W+(na>>>3)|0]|0;X=c[r>>2]|0;ca=((na|0)<(X|0))+na|0;c[p>>2]=ca;if((y&128>>>((na&7)>>>0)|0)==0){oa=ca}else{y=W+(ca>>>3)|0;ba=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(ca&7)>>>26;y=ca+6|0;ca=X>>>0>y>>>0?y:X;c[p>>2]=ca;y=d[W+(ca>>>3)|0]|0;Y=((ca|0)<(X|0))+ca|0;c[p>>2]=Y;a[l+1539|0]=(y&128>>>((ca&7)>>>0)|0)!=0?-ba|0:ba;oa=Y}Y=d[W+(oa>>>3)|0]|0;ba=((oa|0)<(X|0))+oa|0;c[p>>2]=ba;if((Y&128>>>((oa&7)>>>0)|0)==0){ga=ba;ha=W;ia=X;break}Y=W+(ba>>>3)|0;ca=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(ba&7)>>>26;Y=ba+6|0;ba=X>>>0>Y>>>0?Y:X;c[p>>2]=ba;Y=d[W+(ba>>>3)|0]|0;y=((ba|0)<(X|0))+ba|0;c[p>>2]=y;a[l+1540|0]=(Y&128>>>((ba&7)>>>0)|0)!=0?-ca|0:ca;ga=y;ha=W;ia=X}}while(0);oa=ha+(ga>>>3)|0;na=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ga&7)>>>24;oa=ga+8|0;ga=ia>>>0>oa>>>0?oa:ia;c[p>>2]=ga;oa=na&255;na=l+1545|0;a[na]=oa;ma=d[ha+(ga>>>3)|0]|0;la=((ga|0)<(ia|0))+ga|0;c[p>>2]=la;if((ma&128>>>((ga&7)>>>0)|0)==0){pa=0;qa=la}else{ga=ha+(la>>>3)|0;ma=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(la&7)>>>28;ga=la+4|0;la=ia>>>0>ga>>>0?ga:ia;c[p>>2]=la;ga=d[ha+(la>>>3)|0]|0;ka=((la|0)<(ia|0))+la|0;c[p>>2]=ka;pa=((ga&128>>>((la&7)>>>0)|0)!=0?-ma|0:ma)&255;qa=ka}ka=l+1546|0;a[ka]=pa;ma=d[ha+(qa>>>3)|0]|0;la=((qa|0)<(ia|0))+qa|0;c[p>>2]=la;if((ma&128>>>((qa&7)>>>0)|0)==0){ra=0;sa=la}else{qa=ha+(la>>>3)|0;ma=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(la&7)>>>28;qa=la+4|0;la=ia>>>0>qa>>>0?qa:ia;c[p>>2]=la;qa=d[ha+(la>>>3)|0]|0;ga=((la|0)<(ia|0))+la|0;c[p>>2]=ga;ra=((qa&128>>>((la&7)>>>0)|0)!=0?-ma|0:ma)&255;sa=ga}ga=l+1547|0;a[ga]=ra;ma=d[ha+(sa>>>3)|0]|0;la=((sa|0)<(ia|0))+sa|0;c[p>>2]=la;if((ma&128>>>((sa&7)>>>0)|0)==0){ta=0;ua=la}else{sa=ha+(la>>>3)|0;ma=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(la&7)>>>28;sa=la+4|0;la=ia>>>0>sa>>>0?sa:ia;c[p>>2]=la;sa=d[ha+(la>>>3)|0]|0;qa=((la|0)<(ia|0))+la|0;c[p>>2]=qa;ta=((sa&128>>>((la&7)>>>0)|0)!=0?-ma|0:ma)&255;ua=qa}qa=l+1548|0;a[qa]=ta;if((oa|pa|ra)<<24>>24==0){va=ta<<24>>24==0|0}else{va=0}ta=l+1549|0;a[ta]=va;va=d[ha+(ua>>>3)|0]<<(ua&7)>>>7;ra=((ua|0)<(ia|0))+ua|0;c[p>>2]=ra;ua=va&1;va=l+1550|0;a[va]=ua;b:do{if(ua<<24>>24==0){pa=l+1554|0;oa=pa;x=0;a[oa]=x;x=x>>8;a[oa+1|0]=x;x=x>>8;a[oa+2|0]=x;x=x>>8;a[oa+3|0]=x;wa=pa}else{pa=d[ha+(ra>>>3)|0]<<(ra&7)>>>7;oa=((ra|0)<(ia|0))+ra|0;c[p>>2]=oa;ma=pa&1;pa=l+1553|0;a[pa]=ma;do{if(ma<<24>>24==0){xa=0;ya=oa;za=ha;Aa=ia;Ba=86}else{la=d[ha+(oa>>>3)|0]<<(oa&7)>>>7;sa=((oa|0)<(ia|0))+oa|0;c[p>>2]=sa;ja=0;q=sa;sa=la&1;la=ia;o=ha;do{if((sa|0)==0){Ca=-1}else{da=o+(q>>>3)|0;A=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(q&7)>>>24;da=q+8|0;c[p>>2]=la>>>0>da>>>0?da:la;Ca=A&255}a[l+(ja+16615)|0]=Ca;ja=ja+1|0;A=c[p>>2]|0;o=c[m>>2]|0;da=d[o+(A>>>3)|0]<<(A&7)>>>7;la=c[r>>2]|0;q=((A|0)<(la|0))+A|0;c[p>>2]=q;sa=da&1}while((ja|0)<7);ja=sa&255;a[l+1551|0]=ja;da=ja<<24>>24==0;if(da){Da=q}else{ja=d[o+(q>>>3)|0]|0;A=((q|0)<(la|0))+q|0;c[p>>2]=A;if((ja&128>>>((q&7)>>>0)|0)==0){Ea=-1;Fa=A}else{ja=o+(A>>>3)|0;fa=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(A&7)>>>24;ja=A+8|0;A=la>>>0>ja>>>0?ja:la;c[p>>2]=A;Ea=fa&255;Fa=A}a[l+16622|0]=Ea;A=d[o+(Fa>>>3)|0]|0;fa=((Fa|0)<(la|0))+Fa|0;c[p>>2]=fa;if((A&128>>>((Fa&7)>>>0)|0)==0){Ga=-1;Ha=fa}else{A=o+(fa>>>3)|0;ja=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(fa&7)>>>24;A=fa+8|0;fa=la>>>0>A>>>0?A:la;c[p>>2]=fa;Ga=ja&255;Ha=fa}a[l+16623|0]=Ga;fa=d[o+(Ha>>>3)|0]|0;ja=((Ha|0)<(la|0))+Ha|0;c[p>>2]=ja;if((fa&128>>>((Ha&7)>>>0)|0)==0){Ia=-1;Ja=ja}else{fa=o+(ja>>>3)|0;A=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ja&7)>>>24;fa=ja+8|0;ja=la>>>0>fa>>>0?fa:la;c[p>>2]=ja;Ia=A&255;Ja=ja}a[l+16624|0]=Ia;Da=Ja}ja=a[pa]|0;if(ja<<24>>24==0){xa=0;ya=Da;za=o;Aa=la;Ba=86;break}if(da){Ka=Da;La=o;Ma=la;break}xa=ja&255;ya=Da;za=o;Aa=la;Ba=86}}while(0);do{if((Ba|0)==86){pa=c[l+1360>>2]|0;if((L|0)==(c[pa+68>>2]|0)){if((M|0)==(c[pa+72>>2]|0)){Ka=ya;La=za;Ma=Aa;break}}yDb(e,16,2286688,(s=i,i=i+16|0,c[s>>2]=d[l+1551|0]|0,c[s+8>>2]=xa,s)|0);i=s;t=-1094995529;i=j;return t|0}}while(0);pa=d[La+(Ka>>>3)|0]|0;oa=((Ka|0)<(Ma|0))+Ka|0;c[p>>2]=oa;if((pa&128>>>((Ka&7)>>>0)|0)==0){wa=l+1554|0;break}pa=d[La+(oa>>>3)|0]<<(oa&7)>>>7;ma=((oa|0)<(Ma|0))+oa|0;c[p>>2]=ma;a[l+1552|0]=pa&1;pa=l+1554|0;oa=pa;ja=0;da=ma;ma=La;A=Ma;while(1){fa=d[ma+(da>>>3)|0]<<(da&7)>>>7;c[p>>2]=((da|0)<(A|0))+da;X=fa&1;a[oa+(ja*26|0)|0]=X;if(!(X<<24>>24==0)){X=c[p>>2]|0;fa=c[r>>2]|0;W=c[m>>2]|0;y=W+(X>>>3)|0;ca=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(X&7)>>>24;y=X+8|0;X=fa>>>0>y>>>0?y:fa;c[p>>2]=X;y=d[W+(X>>>3)|0]|0;c[p>>2]=((X|0)<(fa|0))+X;b[oa+(ja*26|0)+6>>1]=(y&128>>>((X&7)>>>0)|0)!=0?-ca|0:ca}ca=c[p>>2]|0;X=d[(c[m>>2]|0)+(ca>>>3)|0]<<(ca&7)>>>7;c[p>>2]=((ca|0)<(c[r>>2]|0))+ca;ca=X&1;a[oa+(ja*26|0)+1|0]=ca;if(!(ca<<24>>24==0)){ca=c[p>>2]|0;X=c[r>>2]|0;y=c[m>>2]|0;fa=y+(ca>>>3)|0;W=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ca&7)>>>26;fa=ca+6|0;ca=X>>>0>fa>>>0?fa:X;c[p>>2]=ca;fa=d[y+(ca>>>3)|0]|0;c[p>>2]=((ca|0)<(X|0))+ca;a[oa+(ja*26|0)+8|0]=(fa&128>>>((ca&7)>>>0)|0)!=0?-W|0:W}W=c[p>>2]|0;ca=d[(c[m>>2]|0)+(W>>>3)|0]<<(W&7)>>>7;c[p>>2]=((W|0)<(c[r>>2]|0))+W;W=ca&1;a[oa+(ja*26|0)+2|0]=W;if(!(W<<24>>24==0)){W=c[p>>2]|0;ca=c[r>>2]|0;fa=(c[m>>2]|0)+(W>>>3)|0;X=(fe(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(W&7)>>>30;fa=W+2|0;c[p>>2]=ca>>>0>fa>>>0?fa:ca;a[oa+(ja*26|0)+4|0]=X}X=c[p>>2]|0;ca=d[(c[m>>2]|0)+(X>>>3)|0]<<(X&7)>>>7;c[p>>2]=((X|0)<(c[r>>2]|0))+X;a[oa+(ja*26|0)+3|0]=ca&1;ca=ja+1|0;if((ca|0)>=8){wa=pa;break b}ja=ca;da=c[p>>2]|0;ma=c[m>>2]|0;A=c[r>>2]|0}}}while(0);Ma=wa;wa=l+1541|0;La=l+1539|0;Ka=l+1540|0;xa=l+1552|0;Aa=0;do{do{if((a[Ma+(Aa*26|0)|0]|0)==0){Na=d[na]|0}else{if((a[xa]|0)==0){Na=(b[Ma+(Aa*26|0)+6>>1]|0)+(d[na]|0)|0;break}else{Na=b[Ma+(Aa*26|0)+6>>1]|0;break}}}while(0);za=(a[ka]|0)+Na|0;if(za>>>0<256>>>0){Oa=za}else{Oa=-za>>31&255}za=(a[ga]|0)+Na|0;if(za>>>0<256>>>0){Pa=za}else{Pa=-za>>31&255}za=(a[qa]|0)+Na|0;if(za>>>0<256>>>0){Qa=za}else{Qa=-za>>31&255}if(Na>>>0<256>>>0){Ra=Na}else{Ra=-Na>>31&255}b[Ma+(Aa*26|0)+10>>1]=b[119920+(Oa<<1)>>1]|0;b[Ma+(Aa*26|0)+12>>1]=b[122448+(Ra<<1)>>1]|0;b[Ma+(Aa*26|0)+14>>1]=b[119920+(Pa<<1)>>1]|0;b[Ma+(Aa*26|0)+16>>1]=b[122448+(Qa<<1)>>1]|0;za=a[ea]|0;ya=za&255;Da=(za&255)>>>0>31>>>0|0;do{if((a[Ma+(Aa*26|0)+1|0]|0)==0){Sa=ya}else{za=a[Ma+(Aa*26|0)+8|0]|0;if((a[xa]|0)!=0){Sa=za;break}Sa=za+ya|0}}while(0);ya=(a[wa]<<Da)+Sa|0;if(ya>>>0<64>>>0){Ta=ya&255}else{Ta=-ya>>31&63}a[Ma+(Aa*26|0)+19|0]=Ta;a[Ma+(Aa*26|0)+18|0]=Ta;ya=l+1542|0;za=((a[La]|0)+(a[ya]|0)<<Da)+Sa|0;if(za>>>0<64>>>0){Ua=za&255}else{Ua=-za>>31&63}a[Ma+(Aa*26|0)+20|0]=Ua;za=((a[Ka]|0)+(a[ya]|0)<<Da)+Sa|0;if(za>>>0<64>>>0){Va=za&255}else{Va=-za>>31&63}a[Ma+(Aa*26|0)+21|0]=Va;za=a[l+1543|0]|0;ya=((a[La]|0)+za<<Da)+Sa|0;if(ya>>>0<64>>>0){Wa=ya&255}else{Wa=-ya>>31&63}a[Ma+(Aa*26|0)+22|0]=Wa;ya=((a[Ka]|0)+za<<Da)+Sa|0;if(ya>>>0<64>>>0){Xa=ya&255}else{Xa=-ya>>31&63}a[Ma+(Aa*26|0)+23|0]=Xa;ya=l+1544|0;za=((a[La]|0)+(a[ya]|0)<<Da)+Sa|0;if(za>>>0<64>>>0){Ya=za&255}else{Ya=-za>>31&63}a[Ma+(Aa*26|0)+24|0]=Ya;za=((a[Ka]|0)+(a[ya]|0)<<Da)+Sa|0;if(za>>>0<64>>>0){Za=za&255}else{Za=-za>>31&63}a[Ma+(Aa*26|0)+25|0]=Za;Aa=Aa+1|0;}while((Aa|0)<(((a[va]|0)!=0?8:1)|0));va=c[k>>2]|0;if(!((L|0)>0&(M|0)>0)){yDb(0,0,2046192,(s=i,i=i+24|0,c[s>>2]=2217064,c[s+8>>2]=1963512,c[s+16>>2]=316,s)|0);i=s;Cd();return 0}k=va+30148|0;Aa=k;Za=e+120|0;do{if((c[Aa>>2]|0)==0){Ba=130}else{if((c[Za>>2]|0)!=(L|0)){Ba=130;break}if((c[e+124>>2]|0)!=(M|0)){Ba=130}}}while(0);do{if((Ba|0)==130){c[Za>>2]=L;c[e+124>>2]=M;Ma=va+1796|0;c[Ma>>2]=L+63>>6;c[va+1800>>2]=M+63>>6;c[va+1808>>2]=L+7>>3;c[va+1804>>2]=M+7>>3;$Db(k);Sa=WDb((c[Ma>>2]|0)*560|0)|0;if((Sa|0)!=0){c[Aa>>2]=Sa;Ka=c[Ma>>2]|0;Ma=Ka<<6;c[va+30152>>2]=Sa+Ma;Ya=Ka<<5;La=Ya+Ma|0;c[va+30156>>2]=Sa+La;Ma=La+Ya|0;c[va+30104>>2]=Sa+Ma;Ya=Ka<<4;La=Ma+Ya|0;c[va+30100>>2]=Sa+La;Ma=La+Ya|0;c[va+30144>>2]=Sa+Ma;Ya=Ma+(Ka<<7)|0;c[va+30096>>2]=Sa+Ya;Ma=Ka<<3;Ka=Ya+Ma|0;c[va+30116>>2]=Sa+Ka;Ya=Ka+Ma|0;c[va+30120>>2]=Sa+Ya;Ka=Ya+Ma|0;c[va+30108>>2]=Sa+Ka;Ya=Ka+Ma|0;c[va+30112>>2]=Sa+Ya;Ka=Ya+Ma|0;c[va+30124>>2]=Sa+Ka;Ya=Ka+Ma|0;c[va+30128>>2]=Sa+Ya;Ka=Ya+Ma|0;c[va+30132>>2]=Sa+Ka;Ya=Ka+Ma|0;c[va+30136>>2]=Sa+Ya;Ka=Ya+Ma|0;c[va+30140>>2]=Sa+Ka;c[va+30160>>2]=Sa+(Ka+Ma);$Db(va+1080|0);$Db(va+35860|0);break}yDb(e,16,2270680,(s=i,i=i+16|0,c[s>>2]=L,c[s+8>>2]=M,s)|0);i=s;t=-12;i=j;return t|0}}while(0);M=l+1764|0;L=c[l+1796>>2]|0;va=0;while(1){if(L>>>(va>>>0)>>>0>64>>>0){va=va+1|0}else{break}}Aa=M;c[Aa>>2]=va;M=0;while(1){if(L>>>(M>>>0)>>>0>3>>>0){M=M+1|0}else{break}}L=M-1|0;M=(L|0)<0?0:L;L=c[p>>2]|0;c:do{if(M>>>0>va>>>0){k=c[m>>2]|0;Za=c[r>>2]|0;Ma=va;Ka=L;while(1){Sa=d[k+(Ka>>>3)|0]|0;Ya=((Ka|0)<(Za|0))+Ka|0;c[p>>2]=Ya;if((Sa&128>>>((Ka&7)>>>0)|0)==0){_a=Ma;$a=Ya;break c}Sa=Ma+1|0;c[Aa>>2]=Sa;if(M>>>0>Sa>>>0){Ma=Sa;Ka=Ya}else{_a=Sa;$a=Ya;break}}}else{_a=va;$a=L}}while(0);L=c[m>>2]|0;va=d[L+($a>>>3)|0]|0;M=c[r>>2]|0;Aa=(($a|0)<(M|0))+$a|0;c[p>>2]=Aa;if((va&128>>>(($a&7)>>>0)|0)==0){ab=0}else{$a=d[L+(Aa>>>3)|0]<<(Aa&7)>>>7;c[p>>2]=((Aa|0)<(M|0))+Aa;ab=($a&1)+1|0}c[l+1768>>2]=ab;c[l+1776>>2]=1<<ab;ab=l+1772|0;$a=1<<_a;do{if((c[ab>>2]|0)!=($a|0)){c[ab>>2]=$a;Aa=l+1072|0;M=jEb(c[Aa>>2]|0,l+1076|0,20<<_a)|0;c[Aa>>2]=M;if((M|0)!=0){break}yDb(e,16,2255360,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-12;i=j;return t|0}}while(0);do{if((a[v]|0)==0){if((a[h]|0)!=0){Ba=149;break}if((a[l+1144|0]|0)!=0){Ba=149}}else{Ba=149}}while(0);if((Ba|0)==149){h=l+5890|0;UGb(l+7929|0,116832,311)|0;UGb(h|0,116832,311)|0;UGb(l+3851|0,h|0,311)|0;UGb(l+1812|0,h|0,311)|0;UGb(l+2123|0,118192,1728)|0;UGb(l+4162|0,118192,1728)|0;UGb(l+6201|0,118192,1728)|0;UGb(l+8240|0,118192,1728)|0}h=c[p>>2]|0;_a=c[r>>2]|0;r=c[m>>2]|0;m=r+(h>>>3)|0;$a=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(h&7)>>>16;m=h+16|0;h=_a>>>0>m>>>0?m:_a;m=-h&7;if((m|0)==0){bb=h}else{ab=m+h|0;bb=_a>>>0>ab>>>0?ab:_a}c[p>>2]=bb;p=r+(bb>>3)|0;bb=p-f|0;if(($a|0)>(g-bb|0)){yDb(e,16,2240960,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}g=l+1052|0;f=g;g5a(f,p,$a);p=g;g=c[p>>2]|0;r=d[1086680+g|0]|0;_a=l+1056|0;ab=c[_a>>2]|0;h=l+1068|0;m=c[h>>2]|0;M=g<<r;c[p>>2]=M;g=m<<r;m=ab+r|0;do{if((m|0)>-1){r=l+1060|0;ab=c[r>>2]|0;if(!(ab>>>0<(c[l+1064>>2]|0)>>>0)){cb=g;db=m;break}c[r>>2]=ab+2;r=ab;cb=((de((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535)<<m|g;db=m-16|0}else{cb=g;db=m}}while(0);c[_a>>2]=db;m=((M<<7)-128>>8)+1|0;g=m<<16;if(!(cb>>>0<g>>>0)){c[p>>2]=M-m;c[h>>2]=cb-g;yDb(e,16,2228840,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}c[p>>2]=m;c[h>>2]=cb;do{if((a[v]|0)==0){if((a[l+1144|0]|0)!=0){Ba=161;break}TGb(l+16628|0,0,13208)|0}else{Ba=161}}while(0);if((Ba|0)==161){TGb(l+18316|0,0,11520)|0}s=l+9968|0;e=l+1812|0;UGb(s|0,e+(N*2039|0)|0,311)|0;do{if((a[ta]|0)==0){g=l+1060|0;M=l+1064|0;r=d[1086680+m|0]|0;ab=m<<r;c[p>>2]=ab;Aa=cb<<r;L=r+db|0;do{if((L|0)>-1){r=c[g>>2]|0;if(!(r>>>0<(c[M>>2]|0)>>>0)){eb=Aa;fb=L;break}c[g>>2]=r+2;va=r;eb=((de((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)&65535)<<L|Aa;fb=L-16|0}else{eb=Aa;fb=L}}while(0);c[_a>>2]=fb;L=((ab<<7)-128>>8)+1|0;Aa=L<<16;va=eb>>>0>=Aa>>>0;r=va?ab-L|0:L;L=eb-(va?Aa:0)|0;c[h>>2]=L;Aa=(va&1)<<1;va=d[1086680+r|0]|0;Ka=r<<va;c[p>>2]=Ka;r=L<<va;L=va+fb|0;do{if((L|0)>-1){va=c[g>>2]|0;if(!(va>>>0<(c[M>>2]|0)>>>0)){gb=r;hb=L;break}c[g>>2]=va+2;Ma=va;gb=((de((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<L|r;hb=L-16|0}else{gb=r;hb=L}}while(0);c[_a>>2]=hb;L=((Ka<<7)-128>>8)+1|0;r=L<<16;ab=gb>>>0>=r>>>0;Ma=ab?Ka-L|0:L;c[p>>2]=Ma;L=gb-(ab?r:0)|0;c[h>>2]=L;r=ab&1|Aa;ab=l+29836|0;c[ab>>2]=r;if((r|0)==3){va=d[1086680+Ma|0]|0;Za=Ma<<va;c[p>>2]=Za;k=L<<va;Da=hb+va|0;do{if((Da|0)>-1){va=c[g>>2]|0;if(!(va>>>0<(c[M>>2]|0)>>>0)){ib=k;jb=Da;break}c[g>>2]=va+2;Ya=va;ib=((de((d[Ya]|d[Ya+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|k;jb=Da-16|0}else{ib=k;jb=Da}}while(0);c[_a>>2]=jb;Da=((Za<<7)-128>>8)+1|0;k=Da<<16;Aa=ib>>>0>=k>>>0;Ka=Aa?Za-Da|0:Da;c[p>>2]=Ka;Da=ib-(Aa?k:0)|0;c[h>>2]=Da;k=Aa?4:3;c[ab>>2]=k;kb=k;lb=Ka;mb=jb;nb=Da}else{kb=r;lb=Ma;mb=hb;nb=L}if((kb|0)!=4){ob=g;pb=M;break}Da=d[1086680+lb|0]|0;Ka=lb<<Da;c[p>>2]=Ka;k=nb<<Da;Aa=mb+Da|0;do{if((Aa|0)>-1){Da=c[g>>2]|0;if(!(Da>>>0<(c[M>>2]|0)>>>0)){qb=k;rb=Aa;break}c[g>>2]=Da+2;Ya=Da;qb=((de((d[Ya]|d[Ya+1|0]<<8)<<16>>16|0)|0)&65535)<<Aa|k;rb=Aa-16|0}else{qb=k;rb=Aa}}while(0);c[_a>>2]=rb;Aa=((Ka*252|0)-252>>8)+1|0;k=Aa<<16;if(qb>>>0<k>>>0){c[p>>2]=Aa;c[h>>2]=qb;sb=Aa;tb=rb;ub=qb}else{c[p>>2]=Ka-Aa;c[h>>2]=qb-k;k=l+10157|0;a[k]=Q6a(f,d[k]|0)|0;sb=c[p>>2]|0;tb=c[_a>>2]|0;ub=c[h>>2]|0}k=d[1086680+sb|0]|0;Aa=sb<<k;c[p>>2]=Aa;L=ub<<k;Ma=tb+k|0;do{if((Ma|0)>-1){k=c[g>>2]|0;if(!(k>>>0<(c[M>>2]|0)>>>0)){vb=L;wb=Ma;break}c[g>>2]=k+2;r=k;vb=((de((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|L;wb=Ma-16|0}else{vb=L;wb=Ma}}while(0);c[_a>>2]=wb;Ma=((Aa*252|0)-252>>8)+1|0;L=Ma<<16;if(vb>>>0<L>>>0){c[p>>2]=Ma;c[h>>2]=vb}else{c[p>>2]=Aa-Ma;c[h>>2]=vb-L;L=l+10158|0;a[L]=Q6a(f,d[L]|0)|0}L=l+10153|0;Ma=0;do{Ka=c[p>>2]|0;r=d[1086680+Ka|0]|0;k=c[_a>>2]|0;ab=c[h>>2]|0;Za=Ka<<r;c[p>>2]=Za;Ka=ab<<r;ab=k+r|0;do{if((ab|0)>-1){r=c[g>>2]|0;if(!(r>>>0<(c[M>>2]|0)>>>0)){xb=Ka;yb=ab;break}c[g>>2]=r+2;k=r;xb=((de((d[k]|d[k+1|0]<<8)<<16>>16|0)|0)&65535)<<ab|Ka;yb=ab-16|0}else{xb=Ka;yb=ab}}while(0);c[_a>>2]=yb;ab=((Za*252|0)-252>>8)+1|0;Ka=ab<<16;if(xb>>>0<Ka>>>0){c[p>>2]=ab;c[h>>2]=xb;zb=ab;Ab=yb;Bb=xb}else{c[p>>2]=Za-ab;c[h>>2]=xb-Ka;Ka=L+(Ma<<1)|0;a[Ka]=Q6a(f,d[Ka]|0)|0;zb=c[p>>2]|0;Ab=c[_a>>2]|0;Bb=c[h>>2]|0}Ka=d[1086680+zb|0]|0;ab=zb<<Ka;c[p>>2]=ab;la=Bb<<Ka;o=Ab+Ka|0;do{if((o|0)>-1){Ka=c[g>>2]|0;if(!(Ka>>>0<(c[M>>2]|0)>>>0)){Cb=la;Db=o;break}c[g>>2]=Ka+2;q=Ka;Cb=((de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<o|la;Db=o-16|0}else{Cb=la;Db=o}}while(0);c[_a>>2]=Db;o=((ab*252|0)-252>>8)+1|0;la=o<<16;if(Cb>>>0<la>>>0){c[p>>2]=o;c[h>>2]=Cb}else{c[p>>2]=ab-o;c[h>>2]=Cb-la;la=L+(Ma<<1)+1|0;a[la]=Q6a(f,d[la]|0)|0}Ma=Ma+1|0;}while((Ma|0)<2);Ma=l+10147|0;L=0;while(1){Aa=c[p>>2]|0;la=d[1086680+Aa|0]|0;o=c[_a>>2]|0;Za=c[h>>2]|0;q=Aa<<la;c[p>>2]=q;Aa=Za<<la;Za=o+la|0;do{if((Za|0)>-1){la=c[g>>2]|0;if(!(la>>>0<(c[M>>2]|0)>>>0)){Eb=Aa;Fb=Za;break}c[g>>2]=la+2;o=la;Eb=((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<Za|Aa;Fb=Za-16|0}else{Eb=Aa;Fb=Za}}while(0);c[_a>>2]=Fb;Za=((q*252|0)-252>>8)+1|0;Aa=Za<<16;if(Eb>>>0<Aa>>>0){c[p>>2]=Za;c[h>>2]=Eb}else{c[p>>2]=q-Za;c[h>>2]=Eb-Aa;Aa=Ma+L|0;a[Aa]=Q6a(f,d[Aa]|0)|0}Aa=L+1|0;if((Aa|0)<3){L=Aa}else{Gb=0;break}}while(1){L=c[p>>2]|0;Aa=d[1086680+L|0]|0;Za=c[_a>>2]|0;ab=c[h>>2]|0;o=L<<Aa;c[p>>2]=o;L=ab<<Aa;ab=Za+Aa|0;do{if((ab|0)>-1){Aa=c[g>>2]|0;if(!(Aa>>>0<(c[M>>2]|0)>>>0)){Hb=L;Ib=ab;break}c[g>>2]=Aa+2;Za=Aa;Hb=((de((d[Za]|d[Za+1|0]<<8)<<16>>16|0)|0)&65535)<<ab|L;Ib=ab-16|0}else{Hb=L;Ib=ab}}while(0);c[_a>>2]=Ib;ab=((o*252|0)-252>>8)+1|0;L=ab<<16;if(Hb>>>0<L>>>0){c[p>>2]=ab;c[h>>2]=Hb}else{c[p>>2]=o-ab;c[h>>2]=Hb-L;L=Ma+3+Gb|0;a[L]=Q6a(f,d[L]|0)|0}L=Gb+1|0;if((L|0)<3){Gb=L}else{ob=g;pb=M;break}}}else{c[l+29836>>2]=0;ob=l+1060|0;pb=l+1064|0}}while(0);Gb=l+29836|0;Hb=l+10279|0;Ib=0;while(1){if((Ib|0)>=4){Jb=0;break}Eb=c[p>>2]|0;Fb=d[1086680+Eb|0]|0;Cb=c[_a>>2]|0;Db=c[h>>2]|0;Ab=Eb<<Fb;c[p>>2]=Ab;Eb=Db<<Fb;Db=Cb+Fb|0;do{if((Db|0)>-1){Fb=c[ob>>2]|0;if(!(Fb>>>0<(c[pb>>2]|0)>>>0)){Kb=Eb;Lb=Db;break}c[ob>>2]=Fb+2;Cb=Fb;Kb=((de((d[Cb]|d[Cb+1|0]<<8)<<16>>16|0)|0)&65535)<<Db|Eb;Lb=Db-16|0}else{Kb=Eb;Lb=Db}}while(0);c[_a>>2]=Lb;Db=((Ab<<7)-128>>8)+1|0;Eb=Db<<16;Cb=Kb>>>0>=Eb>>>0;c[p>>2]=Cb?Ab-Db|0:Db;c[h>>2]=Kb-(Cb?Eb:0);if(Cb){Cb=0;do{Eb=0;do{Db=0;do{d:do{if((Db|0)==0){Fb=0;do{if((Fb|0)>2){break d}else{Mb=0}do{Bb=c[p>>2]|0;zb=d[1086680+Bb|0]|0;xb=c[_a>>2]|0;yb=c[h>>2]|0;vb=Bb<<zb;c[p>>2]=vb;Bb=yb<<zb;yb=xb+zb|0;do{if((yb|0)>-1){zb=c[ob>>2]|0;if(!(zb>>>0<(c[pb>>2]|0)>>>0)){Nb=Bb;Ob=yb;break}c[ob>>2]=zb+2;xb=zb;Nb=((de((d[xb]|d[xb+1|0]<<8)<<16>>16|0)|0)&65535)<<yb|Bb;Ob=yb-16|0}else{Nb=Bb;Ob=yb}}while(0);c[_a>>2]=Ob;yb=((vb*252|0)-252>>8)+1|0;Bb=yb<<16;if(Nb>>>0<Bb>>>0){c[p>>2]=yb;c[h>>2]=Nb;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Fb*11|0)+Mb|0]=a[e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Eb*108|0)+(Fb*3|0)+Mb|0]|0}else{c[p>>2]=vb-yb;c[h>>2]=Nb-Bb;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Fb*11|0)+Mb|0]=Q6a(f,d[e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Eb*108|0)+(Fb*3|0)+Mb|0]|0)|0}Mb=Mb+1|0;}while((Mb|0)<3);a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Fb*11|0)+3|0]=0;Fb=Fb+1|0;}while((Fb|0)<6)}else{Fb=0;do{Bb=0;do{yb=c[p>>2]|0;xb=d[1086680+yb|0]|0;zb=c[_a>>2]|0;wb=c[h>>2]|0;tb=yb<<xb;c[p>>2]=tb;yb=wb<<xb;wb=zb+xb|0;do{if((wb|0)>-1){xb=c[ob>>2]|0;if(!(xb>>>0<(c[pb>>2]|0)>>>0)){Pb=yb;Qb=wb;break}c[ob>>2]=xb+2;zb=xb;Pb=((de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)&65535)<<wb|yb;Qb=wb-16|0}else{Pb=yb;Qb=wb}}while(0);c[_a>>2]=Qb;wb=((tb*252|0)-252>>8)+1|0;yb=wb<<16;if(Pb>>>0<yb>>>0){c[p>>2]=wb;c[h>>2]=Pb;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Db*66|0)+(Fb*11|0)+Bb|0]=a[e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Eb*108|0)+(Db*18|0)+(Fb*3|0)+Bb|0]|0}else{c[p>>2]=tb-wb;c[h>>2]=Pb-yb;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Db*66|0)+(Fb*11|0)+Bb|0]=Q6a(f,d[e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Eb*108|0)+(Db*18|0)+(Fb*3|0)+Bb|0]|0)|0}Bb=Bb+1|0;}while((Bb|0)<3);a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Db*66|0)+(Fb*11|0)+3|0]=0;Fb=Fb+1|0;}while((Fb|0)<6)}}while(0);Db=Db+1|0;}while((Db|0)<6);Eb=Eb+1|0;}while((Eb|0)<2);Cb=Cb+1|0;}while((Cb|0)<2)}else{Cb=0;do{Ab=0;do{Eb=0;do{if((Eb|0)==0){o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+3|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+3|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+11|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+14|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+6|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+22|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+25|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+9|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+33|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+36|0]=0}else{o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+3|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+3|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+11|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+14|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+6|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+22|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+25|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+9|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+33|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+36|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+12|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+44|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+47|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+15|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+55|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+58|0]=0}Eb=Eb+1|0;}while((Eb|0)<6);Ab=Ab+1|0;}while((Ab|0)<2);Cb=Cb+1|0;}while((Cb|0)<2)}if((c[Gb>>2]|0)==(Ib|0)){Jb=0;break}else{Ib=Ib+1|0}}do{Ib=c[p>>2]|0;Gb=d[1086680+Ib|0]|0;Hb=c[_a>>2]|0;N=c[h>>2]|0;e=Ib<<Gb;c[p>>2]=e;Ib=N<<Gb;N=Hb+Gb|0;do{if((N|0)>-1){Gb=c[ob>>2]|0;if(!(Gb>>>0<(c[pb>>2]|0)>>>0)){Rb=Ib;Sb=N;break}c[ob>>2]=Gb+2;Hb=Gb;Rb=((de((d[Hb]|d[Hb+1|0]<<8)<<16>>16|0)|0)&65535)<<N|Ib;Sb=N-16|0}else{Rb=Ib;Sb=N}}while(0);c[_a>>2]=Sb;N=((e*252|0)-252>>8)+1|0;Ib=N<<16;if(Rb>>>0<Ib>>>0){c[p>>2]=N;c[h>>2]=Rb}else{c[p>>2]=e-N;c[h>>2]=Rb-Ib;Ib=l+(Jb+10159)|0;a[Ib]=Q6a(f,d[Ib]|0)|0}Jb=Jb+1|0;}while((Jb|0)<3);do{if((a[v]|0)==0){if((a[l+1144|0]|0)!=0){break}Jb=l+10102|0;Rb=0;do{Sb=0;do{Ib=c[p>>2]|0;N=d[1086680+Ib|0]|0;Hb=c[_a>>2]|0;Gb=c[h>>2]|0;Pb=Ib<<N;c[p>>2]=Pb;Ib=Gb<<N;Gb=Hb+N|0;do{if((Gb|0)>-1){N=c[ob>>2]|0;if(!(N>>>0<(c[pb>>2]|0)>>>0)){Tb=Ib;Ub=Gb;break}c[ob>>2]=N+2;Hb=N;Tb=((de((d[Hb]|d[Hb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Ib;Ub=Gb-16|0}else{Tb=Ib;Ub=Gb}}while(0);c[_a>>2]=Ub;Gb=((Pb*252|0)-252>>8)+1|0;Ib=Gb<<16;if(Tb>>>0<Ib>>>0){c[p>>2]=Gb;c[h>>2]=Tb}else{c[p>>2]=Pb-Gb;c[h>>2]=Tb-Ib;Ib=Jb+(Rb*3|0)+Sb|0;a[Ib]=Q6a(f,d[Ib]|0)|0}Sb=Sb+1|0;}while((Sb|0)<3);Rb=Rb+1|0;}while((Rb|0)<7);if((c[l+1148>>2]|0)==4){Rb=l+10094|0;Jb=0;while(1){e=c[p>>2]|0;Sb=d[1086680+e|0]|0;Ib=c[_a>>2]|0;Gb=c[h>>2]|0;Hb=e<<Sb;c[p>>2]=Hb;e=Gb<<Sb;Gb=Ib+Sb|0;do{if((Gb|0)>-1){Sb=c[ob>>2]|0;if(!(Sb>>>0<(c[pb>>2]|0)>>>0)){Vb=e;Wb=Gb;break}c[ob>>2]=Sb+2;Ib=Sb;Vb=((de((d[Ib]|d[Ib+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|e;Wb=Gb-16|0}else{Vb=e;Wb=Gb}}while(0);c[_a>>2]=Wb;Gb=((Hb*252|0)-252>>8)+1|0;e=Gb<<16;if(Vb>>>0<e>>>0){c[p>>2]=Gb;c[h>>2]=Vb;Xb=Gb;Yb=Wb;Zb=Vb}else{c[p>>2]=Hb-Gb;c[h>>2]=Vb-e;e=Rb+(Jb<<1)|0;a[e]=Q6a(f,d[e]|0)|0;Xb=c[p>>2]|0;Yb=c[_a>>2]|0;Zb=c[h>>2]|0}e=d[1086680+Xb|0]|0;Gb=Xb<<e;c[p>>2]=Gb;Ib=Zb<<e;Sb=Yb+e|0;do{if((Sb|0)>-1){e=c[ob>>2]|0;if(!(e>>>0<(c[pb>>2]|0)>>>0)){_b=Ib;$b=Sb;break}c[ob>>2]=e+2;N=e;_b=((de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<Sb|Ib;$b=Sb-16|0}else{_b=Ib;$b=Sb}}while(0);c[_a>>2]=$b;Sb=((Gb*252|0)-252>>8)+1|0;Ib=Sb<<16;if(_b>>>0<Ib>>>0){c[p>>2]=Sb;c[h>>2]=_b}else{c[p>>2]=Gb-Sb;c[h>>2]=_b-Ib;Ib=Rb+(Jb<<1)+1|0;a[Ib]=Q6a(f,d[Ib]|0)|0}Ib=Jb+1|0;if((Ib|0)<4){Jb=Ib}else{ac=0;break}}}else{ac=0}do{Jb=c[p>>2]|0;Rb=d[1086680+Jb|0]|0;Ib=c[_a>>2]|0;Sb=c[h>>2]|0;Hb=Jb<<Rb;c[p>>2]=Hb;Jb=Sb<<Rb;Sb=Ib+Rb|0;do{if((Sb|0)>-1){Rb=c[ob>>2]|0;if(!(Rb>>>0<(c[pb>>2]|0)>>>0)){bc=Jb;cc=Sb;break}c[ob>>2]=Rb+2;Ib=Rb;bc=((de((d[Ib]|d[Ib+1|0]<<8)<<16>>16|0)|0)&65535)<<Sb|Jb;cc=Sb-16|0}else{bc=Jb;cc=Sb}}while(0);c[_a>>2]=cc;Sb=((Hb*252|0)-252>>8)+1|0;Jb=Sb<<16;if(bc>>>0<Jb>>>0){c[p>>2]=Sb;c[h>>2]=bc}else{c[p>>2]=Hb-Sb;c[h>>2]=bc-Jb;Jb=l+(ac+10123)|0;a[Jb]=Q6a(f,d[Jb]|0)|0}ac=ac+1|0;}while((ac|0)<4);if((a[l+1152|0]|0)==0){c[l+29840>>2]=0;Ba=288}else{Jb=c[p>>2]|0;Sb=d[1086680+Jb|0]|0;Gb=c[_a>>2]|0;Ib=c[h>>2]|0;Rb=Jb<<Sb;c[p>>2]=Rb;Jb=Ib<<Sb;Ib=Gb+Sb|0;do{if((Ib|0)>-1){Sb=c[ob>>2]|0;if(!(Sb>>>0<(c[pb>>2]|0)>>>0)){dc=Jb;ec=Ib;break}c[ob>>2]=Sb+2;Gb=Sb;dc=((de((d[Gb]|d[Gb+1|0]<<8)<<16>>16|0)|0)&65535)<<Ib|Jb;ec=Ib-16|0}else{dc=Jb;ec=Ib}}while(0);c[_a>>2]=ec;Ib=((Rb<<7)-128>>8)+1|0;Jb=Ib<<16;Gb=dc>>>0>=Jb>>>0;Sb=Gb&1;N=Gb?Rb-Ib|0:Ib;c[p>>2]=N;Ib=dc-(Gb?Jb:0)|0;c[h>>2]=Ib;Jb=l+29840|0;c[Jb>>2]=Sb;do{if(Gb){e=d[1086680+N|0]|0;Qb=N<<e;c[p>>2]=Qb;Mb=Ib<<e;Nb=ec+e|0;do{if((Nb|0)>-1){e=c[ob>>2]|0;if(!(e>>>0<(c[pb>>2]|0)>>>0)){fc=Mb;gc=Nb;break}c[ob>>2]=e+2;Ob=e;fc=((de((d[Ob]|d[Ob+1|0]<<8)<<16>>16|0)|0)&65535)<<Nb|Mb;gc=Nb-16|0}else{fc=Mb;gc=Nb}}while(0);c[_a>>2]=gc;Nb=((Qb<<7)-128>>8)+1|0;Mb=Nb<<16;Hb=fc>>>0>=Mb>>>0;Ob=Hb?Qb-Nb|0:Nb;c[p>>2]=Ob;Nb=fc-(Hb?Mb:0)|0;c[h>>2]=Nb;Mb=(Hb&1)+Sb|0;c[Jb>>2]=Mb;if((Mb|0)==2){hc=0;ic=Ob;jc=gc;kc=Nb}else{lc=Mb;break}while(1){Mb=d[1086680+ic|0]|0;Nb=ic<<Mb;c[p>>2]=Nb;Ob=kc<<Mb;Hb=jc+Mb|0;do{if((Hb|0)>-1){Mb=c[ob>>2]|0;if(!(Mb>>>0<(c[pb>>2]|0)>>>0)){mc=Ob;nc=Hb;break}c[ob>>2]=Mb+2;e=Mb;mc=((de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535)<<Hb|Ob;nc=Hb-16|0}else{mc=Ob;nc=Hb}}while(0);c[_a>>2]=nc;Hb=((Nb*252|0)-252>>8)+1|0;Ob=Hb<<16;if(mc>>>0<Ob>>>0){c[p>>2]=Hb;c[h>>2]=mc}else{c[p>>2]=Nb-Hb;c[h>>2]=mc-Ob;Ob=l+(hc+10127)|0;a[Ob]=Q6a(f,d[Ob]|0)|0}Ob=hc+1|0;if((Ob|0)>=5){break}hc=Ob;ic=c[p>>2]|0;jc=c[_a>>2]|0;kc=c[h>>2]|0}lc=c[Jb>>2]|0}else{lc=Sb}}while(0);if((lc|0)==1){oc=0;Ba=304}else{Ba=288}}if((Ba|0)==288){Sb=l+29840|0;Jb=l+10132|0;Ib=0;do{N=c[p>>2]|0;Gb=d[1086680+N|0]|0;Rb=c[_a>>2]|0;Qb=c[h>>2]|0;Ob=N<<Gb;c[p>>2]=Ob;N=Qb<<Gb;Qb=Rb+Gb|0;do{if((Qb|0)>-1){Gb=c[ob>>2]|0;if(!(Gb>>>0<(c[pb>>2]|0)>>>0)){pc=N;qc=Qb;break}c[ob>>2]=Gb+2;Rb=Gb;pc=((de((d[Rb]|d[Rb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|N;qc=Qb-16|0}else{pc=N;qc=Qb}}while(0);c[_a>>2]=qc;Qb=((Ob*252|0)-252>>8)+1|0;N=Qb<<16;if(pc>>>0<N>>>0){c[p>>2]=Qb;c[h>>2]=pc;rc=Qb;sc=qc;tc=pc}else{c[p>>2]=Ob-Qb;c[h>>2]=pc-N;N=Jb+(Ib<<1)|0;a[N]=Q6a(f,d[N]|0)|0;rc=c[p>>2]|0;sc=c[_a>>2]|0;tc=c[h>>2]|0}N=d[1086680+rc|0]|0;Qb=rc<<N;c[p>>2]=Qb;Rb=tc<<N;Gb=sc+N|0;do{if((Gb|0)>-1){N=c[ob>>2]|0;if(!(N>>>0<(c[pb>>2]|0)>>>0)){uc=Rb;vc=Gb;break}c[ob>>2]=N+2;Hb=N;uc=((de((d[Hb]|d[Hb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Rb;vc=Gb-16|0}else{uc=Rb;vc=Gb}}while(0);c[_a>>2]=vc;Gb=((Qb*252|0)-252>>8)+1|0;Rb=Gb<<16;if(uc>>>0<Rb>>>0){c[p>>2]=Gb;c[h>>2]=uc}else{c[p>>2]=Qb-Gb;c[h>>2]=uc-Rb;Rb=Jb+(Ib<<1)+1|0;a[Rb]=Q6a(f,d[Rb]|0)|0}Ib=Ib+1|0;}while((Ib|0)<5);if((c[Sb>>2]|0)!=0){oc=0;Ba=304}}if((Ba|0)==304){while(1){Ba=0;Ib=c[p>>2]|0;Jb=d[1086680+Ib|0]|0;Rb=c[_a>>2]|0;Gb=c[h>>2]|0;Ob=Ib<<Jb;c[p>>2]=Ob;Ib=Gb<<Jb;Gb=Rb+Jb|0;do{if((Gb|0)>-1){Jb=c[ob>>2]|0;if(!(Jb>>>0<(c[pb>>2]|0)>>>0)){wc=Ib;xc=Gb;break}c[ob>>2]=Jb+2;Rb=Jb;wc=((de((d[Rb]|d[Rb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Ib;xc=Gb-16|0}else{wc=Ib;xc=Gb}}while(0);c[_a>>2]=xc;Gb=((Ob*252|0)-252>>8)+1|0;Ib=Gb<<16;if(wc>>>0<Ib>>>0){c[p>>2]=Gb;c[h>>2]=wc}else{c[p>>2]=Ob-Gb;c[h>>2]=wc-Ib;Ib=l+(oc+10142)|0;a[Ib]=Q6a(f,d[Ib]|0)|0}Ib=oc+1|0;if((Ib|0)<5){oc=Ib;Ba=304}else{break}}}Sb=s;Ib=0;do{Gb=0;do{Qb=c[p>>2]|0;Rb=d[1086680+Qb|0]|0;Jb=c[_a>>2]|0;Hb=c[h>>2]|0;N=Qb<<Rb;c[p>>2]=N;Qb=Hb<<Rb;Hb=Jb+Rb|0;do{if((Hb|0)>-1){Rb=c[ob>>2]|0;if(!(Rb>>>0<(c[pb>>2]|0)>>>0)){yc=Qb;zc=Hb;break}c[ob>>2]=Rb+2;Jb=Rb;yc=((de((d[Jb]|d[Jb+1|0]<<8)<<16>>16|0)|0)&65535)<<Hb|Qb;zc=Hb-16|0}else{yc=Qb;zc=Hb}}while(0);c[_a>>2]=zc;Hb=((N*252|0)-252>>8)+1|0;Qb=Hb<<16;if(yc>>>0<Qb>>>0){c[p>>2]=Hb;c[h>>2]=yc}else{c[p>>2]=N-Hb;c[h>>2]=yc-Qb;Qb=Sb+(Ib*9|0)+Gb|0;a[Qb]=Q6a(f,d[Qb]|0)|0}Gb=Gb+1|0;}while((Gb|0)<9);Ib=Ib+1|0;}while((Ib|0)<4);Ib=l+10231|0;Sb=0;while(1){Gb=3-Sb|0;Ob=0;do{Qb=0;do{Hb=c[p>>2]|0;Nb=d[1086680+Hb|0]|0;Jb=c[_a>>2]|0;Rb=c[h>>2]|0;Pb=Hb<<Nb;c[p>>2]=Pb;Hb=Rb<<Nb;Rb=Jb+Nb|0;do{if((Rb|0)>-1){Nb=c[ob>>2]|0;if(!(Nb>>>0<(c[pb>>2]|0)>>>0)){Ac=Hb;Bc=Rb;break}c[ob>>2]=Nb+2;Jb=Nb;Ac=((de((d[Jb]|d[Jb+1|0]<<8)<<16>>16|0)|0)&65535)<<Rb|Hb;Bc=Rb-16|0}else{Ac=Hb;Bc=Rb}}while(0);c[_a>>2]=Bc;Rb=((Pb*252|0)-252>>8)+1|0;Hb=Rb<<16;if(Ac>>>0<Hb>>>0){c[p>>2]=Rb;c[h>>2]=Ac}else{c[p>>2]=Pb-Rb;c[h>>2]=Ac-Hb;Hb=Ib+(Gb*12|0)+(Ob*3|0)+Qb|0;a[Hb]=Q6a(f,d[Hb]|0)|0}Qb=Qb+1|0;}while((Qb|0)<3);Ob=Ob+1|0;}while((Ob|0)<4);Ob=Sb+1|0;if((Ob|0)<4){Sb=Ob}else{Cc=0;break}}do{Sb=c[p>>2]|0;Ib=d[1086680+Sb|0]|0;Ob=c[_a>>2]|0;Gb=c[h>>2]|0;Qb=Sb<<Ib;c[p>>2]=Qb;Sb=Gb<<Ib;Gb=Ob+Ib|0;do{if((Gb|0)>-1){Ib=c[ob>>2]|0;if(!(Ib>>>0<(c[pb>>2]|0)>>>0)){Dc=Sb;Ec=Gb;break}c[ob>>2]=Ib+2;Ob=Ib;Dc=((de((d[Ob]|d[Ob+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Sb;Ec=Gb-16|0}else{Dc=Sb;Ec=Gb}}while(0);c[_a>>2]=Ec;Gb=((Qb*252|0)-252>>8)+1|0;Sb=Gb<<16;if(Dc>>>0<Sb>>>0){c[p>>2]=Gb;c[h>>2]=Dc}else{Ob=Qb-Gb|0;c[p>>2]=Ob;Gb=Dc-Sb|0;c[h>>2]=Gb;Sb=7;Ib=0;N=Ob;Ob=Ec;Hb=Gb;while(1){Gb=Sb-1|0;Rb=Ib<<1;Jb=d[1086680+N|0]|0;Nb=N<<Jb;c[p>>2]=Nb;e=Hb<<Jb;Mb=Jb+Ob|0;do{if((Mb|0)>-1){Jb=c[ob>>2]|0;if(!(Jb>>>0<(c[pb>>2]|0)>>>0)){Fc=e;Gc=Mb;break}c[ob>>2]=Jb+2;Kb=Jb;Fc=((de((d[Kb]|d[Kb+1|0]<<8)<<16>>16|0)|0)&65535)<<Mb|e;Gc=Mb-16|0}else{Fc=e;Gc=Mb}}while(0);c[_a>>2]=Gc;Mb=((Nb<<7)-128>>8)+1|0;e=Mb<<16;Kb=Fc>>>0>=e>>>0;Jb=Kb?Nb-Mb|0:Mb;c[p>>2]=Jb;Mb=Fc-(Kb?e:0)|0;c[h>>2]=Mb;Hc=Kb&1|Rb;if((Gb|0)==0){break}else{Sb=Gb;Ib=Hc;N=Jb;Ob=Gc;Hb=Mb}}a[l+(Cc+10162)|0]=Hc<<1|1}Cc=Cc+1|0;}while((Cc|0)<3);Hb=l+10165|0;Ob=0;while(1){N=c[p>>2]|0;Ib=d[1086680+N|0]|0;Sb=c[_a>>2]|0;Qb=c[h>>2]|0;Mb=N<<Ib;c[p>>2]=Mb;N=Qb<<Ib;Qb=Sb+Ib|0;do{if((Qb|0)>-1){Ib=c[ob>>2]|0;if(!(Ib>>>0<(c[pb>>2]|0)>>>0)){Ic=N;Jc=Qb;break}c[ob>>2]=Ib+2;Sb=Ib;Ic=((de((d[Sb]|d[Sb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|N;Jc=Qb-16|0}else{Ic=N;Jc=Qb}}while(0);c[_a>>2]=Jc;Qb=((Mb*252|0)-252>>8)+1|0;N=Qb<<16;if(Ic>>>0<N>>>0){c[p>>2]=Qb;c[h>>2]=Ic;Kc=0}else{Sb=Mb-Qb|0;c[p>>2]=Sb;Qb=Ic-N|0;c[h>>2]=Qb;N=7;Ib=0;Jb=Sb;Sb=Jc;Kb=Qb;while(1){Qb=N-1|0;e=Ib<<1;Lb=d[1086680+Jb|0]|0;Cb=Jb<<Lb;c[p>>2]=Cb;Ab=Kb<<Lb;Eb=Lb+Sb|0;do{if((Eb|0)>-1){Lb=c[ob>>2]|0;if(!(Lb>>>0<(c[pb>>2]|0)>>>0)){Lc=Ab;Mc=Eb;break}c[ob>>2]=Lb+2;o=Lb;Lc=((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<Eb|Ab;Mc=Eb-16|0}else{Lc=Ab;Mc=Eb}}while(0);c[_a>>2]=Mc;Eb=((Cb<<7)-128>>8)+1|0;Ab=Eb<<16;Gb=Lc>>>0>=Ab>>>0;Rb=Gb?Cb-Eb|0:Eb;c[p>>2]=Rb;Eb=Lc-(Gb?Ab:0)|0;c[h>>2]=Eb;Nc=Gb&1|e;if((Qb|0)==0){break}else{N=Qb;Ib=Nc;Jb=Rb;Sb=Mc;Kb=Eb}}a[Hb+(Ob*33|0)|0]=Nc<<1|1;Kc=0}while(1){Kb=(Kc|0)<10;Sb=c[p>>2]|0;Jb=d[1086680+Sb|0]|0;Ib=c[_a>>2]|0;N=c[h>>2]|0;Mb=Sb<<Jb;c[p>>2]=Mb;Sb=N<<Jb;N=Ib+Jb|0;do{if((N|0)>-1){Jb=c[ob>>2]|0;if(!(Jb>>>0<(c[pb>>2]|0)>>>0)){Oc=Sb;Pc=N;break}c[ob>>2]=Jb+2;Ib=Jb;Oc=((de((d[Ib]|d[Ib+1|0]<<8)<<16>>16|0)|0)&65535)<<N|Sb;Pc=N-16|0}else{Oc=Sb;Pc=N}}while(0);c[_a>>2]=Pc;N=((Mb*252|0)-252>>8)+1|0;Sb=N<<16;if(Oc>>>0<Sb>>>0){c[p>>2]=N;Qc=0;Rc=Oc;Sc=N}else{Qb=Mb-N|0;c[p>>2]=Qb;Qc=1;Rc=Oc-Sb|0;Sc=Qb}c[h>>2]=Rc;if(!Kb){break}if(Qc){Qb=7;Sb=0;N=Sc;e=Pc;Cb=Rc;while(1){Ib=Qb-1|0;Jb=Sb<<1;Eb=d[1086680+N|0]|0;Rb=N<<Eb;c[p>>2]=Rb;Gb=Cb<<Eb;Ab=Eb+e|0;do{if((Ab|0)>-1){Eb=c[ob>>2]|0;if(!(Eb>>>0<(c[pb>>2]|0)>>>0)){Tc=Gb;Uc=Ab;break}c[ob>>2]=Eb+2;Nb=Eb;Tc=((de((d[Nb]|d[Nb+1|0]<<8)<<16>>16|0)|0)&65535)<<Ab|Gb;Uc=Ab-16|0}else{Tc=Gb;Uc=Ab}}while(0);c[_a>>2]=Uc;Ab=((Rb<<7)-128>>8)+1|0;Gb=Ab<<16;Pb=Tc>>>0>=Gb>>>0;Nb=Pb?Rb-Ab|0:Ab;c[p>>2]=Nb;Ab=Tc-(Pb?Gb:0)|0;c[h>>2]=Ab;Vc=Pb&1|Jb;if((Ib|0)==0){break}else{Qb=Ib;Sb=Vc;N=Nb;e=Uc;Cb=Ab}}a[Hb+(Ob*33|0)+1+Kc|0]=Vc<<1|1}Kc=Kc+1|0}if(Qc){Cb=7;e=0;N=Sc;Sb=Pc;Qb=Rc;while(1){Kb=Cb-1|0;Mb=e<<1;Ab=d[1086680+N|0]|0;Nb=N<<Ab;c[p>>2]=Nb;Pb=Qb<<Ab;Gb=Ab+Sb|0;do{if((Gb|0)>-1){Ab=c[ob>>2]|0;if(!(Ab>>>0<(c[pb>>2]|0)>>>0)){Wc=Pb;Xc=Gb;break}c[ob>>2]=Ab+2;Eb=Ab;Wc=((de((d[Eb]|d[Eb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Pb;Xc=Gb-16|0}else{Wc=Pb;Xc=Gb}}while(0);c[_a>>2]=Xc;Gb=((Nb<<7)-128>>8)+1|0;Pb=Gb<<16;Eb=Wc>>>0>=Pb>>>0;Ab=Eb?Nb-Gb|0:Gb;c[p>>2]=Ab;Gb=Wc-(Eb?Pb:0)|0;c[h>>2]=Gb;Yc=Eb&1|Mb;if((Kb|0)==0){break}else{Cb=Kb;e=Yc;N=Ab;Sb=Xc;Qb=Gb}}a[Hb+(Ob*33|0)+11|0]=Yc<<1|1;Zc=0}else{Zc=0}do{Qb=c[p>>2]|0;Sb=d[1086680+Qb|0]|0;N=c[_a>>2]|0;e=c[h>>2]|0;Cb=Qb<<Sb;c[p>>2]=Cb;Qb=e<<Sb;e=N+Sb|0;do{if((e|0)>-1){Sb=c[ob>>2]|0;if(!(Sb>>>0<(c[pb>>2]|0)>>>0)){_c=Qb;$c=e;break}c[ob>>2]=Sb+2;N=Sb;_c=((de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<e|Qb;$c=e-16|0}else{_c=Qb;$c=e}}while(0);c[_a>>2]=$c;e=((Cb*252|0)-252>>8)+1|0;Qb=e<<16;if(_c>>>0<Qb>>>0){c[p>>2]=e;c[h>>2]=_c}else{Kb=Cb-e|0;c[p>>2]=Kb;e=_c-Qb|0;c[h>>2]=e;Qb=7;Mb=0;Nb=Kb;Kb=$c;N=e;while(1){e=Qb-1|0;Sb=Mb<<1;Gb=d[1086680+Nb|0]|0;Ab=Nb<<Gb;c[p>>2]=Ab;Eb=N<<Gb;Pb=Gb+Kb|0;do{if((Pb|0)>-1){Gb=c[ob>>2]|0;if(!(Gb>>>0<(c[pb>>2]|0)>>>0)){ad=Eb;bd=Pb;break}c[ob>>2]=Gb+2;o=Gb;ad=((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<Pb|Eb;bd=Pb-16|0}else{ad=Eb;bd=Pb}}while(0);c[_a>>2]=bd;Pb=((Ab<<7)-128>>8)+1|0;Eb=Pb<<16;Ib=ad>>>0>=Eb>>>0;Jb=Ib?Ab-Pb|0:Pb;c[p>>2]=Jb;Pb=ad-(Ib?Eb:0)|0;c[h>>2]=Pb;cd=Ib&1|Sb;if((e|0)==0){break}else{Qb=e;Mb=cd;Nb=Jb;Kb=bd;N=Pb}}a[Hb+(Ob*33|0)+12+Zc|0]=cd<<1|1}Zc=Zc+1|0;}while((Zc|0)<10);N=Ob+1|0;if((N|0)<2){Ob=N}else{dd=0;break}}do{Ob=0;while(1){N=0;do{Kb=c[p>>2]|0;Nb=d[1086680+Kb|0]|0;Mb=c[_a>>2]|0;Qb=c[h>>2]|0;Cb=Kb<<Nb;c[p>>2]=Cb;Kb=Qb<<Nb;Qb=Mb+Nb|0;do{if((Qb|0)>-1){Nb=c[ob>>2]|0;if(!(Nb>>>0<(c[pb>>2]|0)>>>0)){ed=Kb;fd=Qb;break}c[ob>>2]=Nb+2;Mb=Nb;ed=((de((d[Mb]|d[Mb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Kb;fd=Qb-16|0}else{ed=Kb;fd=Qb}}while(0);c[_a>>2]=fd;Qb=((Cb*252|0)-252>>8)+1|0;Kb=Qb<<16;if(ed>>>0<Kb>>>0){c[p>>2]=Qb;c[h>>2]=ed}else{e=Cb-Qb|0;c[p>>2]=e;Qb=ed-Kb|0;c[h>>2]=Qb;Kb=7;Sb=0;Ab=e;e=fd;Mb=Qb;while(1){Qb=Kb-1|0;Nb=Sb<<1;Pb=d[1086680+Ab|0]|0;Jb=Ab<<Pb;c[p>>2]=Jb;Ib=Mb<<Pb;Eb=Pb+e|0;do{if((Eb|0)>-1){Pb=c[ob>>2]|0;if(!(Pb>>>0<(c[pb>>2]|0)>>>0)){gd=Ib;hd=Eb;break}c[ob>>2]=Pb+2;Rb=Pb;gd=((de((d[Rb]|d[Rb+1|0]<<8)<<16>>16|0)|0)&65535)<<Eb|Ib;hd=Eb-16|0}else{gd=Ib;hd=Eb}}while(0);c[_a>>2]=hd;Eb=((Jb<<7)-128>>8)+1|0;Ib=Eb<<16;Rb=gd>>>0>=Ib>>>0;Pb=Rb?Jb-Eb|0:Eb;c[p>>2]=Pb;Eb=gd-(Rb?Ib:0)|0;c[h>>2]=Eb;id=Rb&1|Nb;if((Qb|0)==0){break}else{Kb=Qb;Sb=id;Ab=Pb;e=hd;Mb=Eb}}a[Hb+(dd*33|0)+22+(Ob*3|0)+N|0]=id<<1|1}N=N+1|0;}while((N|0)<3);N=Ob+1|0;if((N|0)<2){Ob=N}else{jd=0;break}}do{Ob=c[p>>2]|0;N=d[1086680+Ob|0]|0;Mb=c[_a>>2]|0;e=c[h>>2]|0;Ab=Ob<<N;c[p>>2]=Ab;Ob=e<<N;e=Mb+N|0;do{if((e|0)>-1){N=c[ob>>2]|0;if(!(N>>>0<(c[pb>>2]|0)>>>0)){kd=Ob;ld=e;break}c[ob>>2]=N+2;Mb=N;kd=((de((d[Mb]|d[Mb+1|0]<<8)<<16>>16|0)|0)&65535)<<e|Ob;ld=e-16|0}else{kd=Ob;ld=e}}while(0);c[_a>>2]=ld;e=((Ab*252|0)-252>>8)+1|0;Ob=e<<16;if(kd>>>0<Ob>>>0){c[p>>2]=e;c[h>>2]=kd}else{Mb=Ab-e|0;c[p>>2]=Mb;e=kd-Ob|0;c[h>>2]=e;Ob=7;N=0;Sb=Mb;Mb=ld;Kb=e;while(1){e=Ob-1|0;Cb=N<<1;Eb=d[1086680+Sb|0]|0;Pb=Sb<<Eb;c[p>>2]=Pb;Rb=Kb<<Eb;Ib=Eb+Mb|0;do{if((Ib|0)>-1){Eb=c[ob>>2]|0;if(!(Eb>>>0<(c[pb>>2]|0)>>>0)){md=Rb;nd=Ib;break}c[ob>>2]=Eb+2;o=Eb;md=((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<Ib|Rb;nd=Ib-16|0}else{md=Rb;nd=Ib}}while(0);c[_a>>2]=nd;Ib=((Pb<<7)-128>>8)+1|0;Rb=Ib<<16;o=md>>>0>=Rb>>>0;Eb=o?Pb-Ib|0:Ib;c[p>>2]=Eb;Ib=md-(o?Rb:0)|0;c[h>>2]=Ib;od=o&1|Cb;if((e|0)==0){break}else{Ob=e;N=od;Sb=Eb;Mb=nd;Kb=Ib}}a[Hb+(dd*33|0)+28+jd|0]=od<<1|1}jd=jd+1|0;}while((jd|0)<3);dd=dd+1|0;}while((dd|0)<2);if((a[l+1147|0]|0)==0){break}else{pd=0}do{Kb=c[p>>2]|0;Mb=d[1086680+Kb|0]|0;Sb=c[_a>>2]|0;N=c[h>>2]|0;Ob=Kb<<Mb;c[p>>2]=Ob;Kb=N<<Mb;N=Sb+Mb|0;do{if((N|0)>-1){Mb=c[ob>>2]|0;if(!(Mb>>>0<(c[pb>>2]|0)>>>0)){qd=Kb;rd=N;break}c[ob>>2]=Mb+2;Sb=Mb;qd=((de((d[Sb]|d[Sb+1|0]<<8)<<16>>16|0)|0)&65535)<<N|Kb;rd=N-16|0}else{qd=Kb;rd=N}}while(0);c[_a>>2]=rd;N=((Ob*252|0)-252>>8)+1|0;Kb=N<<16;if(qd>>>0<Kb>>>0){c[p>>2]=N;c[h>>2]=qd;sd=N;td=rd;ud=qd}else{Sb=Ob-N|0;c[p>>2]=Sb;N=qd-Kb|0;c[h>>2]=N;Kb=7;Mb=0;Ab=Sb;Sb=rd;Ib=N;while(1){N=Kb-1|0;Eb=Mb<<1;o=d[1086680+Ab|0]|0;Rb=Ab<<o;c[p>>2]=Rb;Gb=Ib<<o;Lb=o+Sb|0;do{if((Lb|0)>-1){o=c[ob>>2]|0;if(!(o>>>0<(c[pb>>2]|0)>>>0)){vd=Gb;wd=Lb;break}c[ob>>2]=o+2;Db=o;vd=((de((d[Db]|d[Db+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Gb;wd=Lb-16|0}else{vd=Gb;wd=Lb}}while(0);c[_a>>2]=wd;Lb=((Rb<<7)-128>>8)+1|0;Gb=Lb<<16;Db=vd>>>0>=Gb>>>0;o=Db?Rb-Lb|0:Lb;c[p>>2]=o;Lb=vd-(Db?Gb:0)|0;c[h>>2]=Lb;xd=Db&1|Eb;if((N|0)==0){break}else{Kb=N;Mb=xd;Ab=o;Sb=wd;Ib=Lb}}a[Hb+(pd*33|0)+31|0]=xd<<1|1;sd=c[p>>2]|0;td=c[_a>>2]|0;ud=c[h>>2]|0}Ib=d[1086680+sd|0]|0;Sb=sd<<Ib;c[p>>2]=Sb;Ab=ud<<Ib;Mb=td+Ib|0;do{if((Mb|0)>-1){Ib=c[ob>>2]|0;if(!(Ib>>>0<(c[pb>>2]|0)>>>0)){yd=Ab;zd=Mb;break}c[ob>>2]=Ib+2;Kb=Ib;yd=((de((d[Kb]|d[Kb+1|0]<<8)<<16>>16|0)|0)&65535)<<Mb|Ab;zd=Mb-16|0}else{yd=Ab;zd=Mb}}while(0);c[_a>>2]=zd;Mb=((Sb*252|0)-252>>8)+1|0;Ab=Mb<<16;if(yd>>>0<Ab>>>0){c[p>>2]=Mb;c[h>>2]=yd}else{Kb=Sb-Mb|0;c[p>>2]=Kb;Mb=yd-Ab|0;c[h>>2]=Mb;Ab=7;Ib=0;Ob=Kb;Kb=zd;Lb=Mb;while(1){Mb=Ab-1|0;o=Ib<<1;Db=d[1086680+Ob|0]|0;Gb=Ob<<Db;c[p>>2]=Gb;Fb=Lb<<Db;Bb=Db+Kb|0;do{if((Bb|0)>-1){Db=c[ob>>2]|0;if(!(Db>>>0<(c[pb>>2]|0)>>>0)){Ad=Fb;Bd=Bb;break}c[ob>>2]=Db+2;yb=Db;Ad=((de((d[yb]|d[yb+1|0]<<8)<<16>>16|0)|0)&65535)<<Bb|Fb;Bd=Bb-16|0}else{Ad=Fb;Bd=Bb}}while(0);c[_a>>2]=Bd;Bb=((Gb<<7)-128>>8)+1|0;Fb=Bb<<16;N=Ad>>>0>=Fb>>>0;Eb=N?Gb-Bb|0:Bb;c[p>>2]=Eb;Bb=Ad-(N?Fb:0)|0;c[h>>2]=Bb;Dd=N&1|o;if((Mb|0)==0){break}else{Ab=Mb;Ib=Dd;Ob=Eb;Kb=Bd;Lb=Bb}}a[Hb+(pd*33|0)+32|0]=Dd<<1|1}pd=pd+1|0;}while((pd|0)<2)}}while(0);t=bb+$a|0;i=j;return t|0}function I6a(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;i=a+60|0;j=c[i>>2]|0;k=c[j+1084>>2]|0;l=k+60|0;m=c[l>>2]|0;a:do{if((h|0)==3){n=b;o=f;p=g;q=k;r=m;s=d}else{t=b;u=d;v=f;w=g;x=j;y=k;z=h;A=j;B=l;C=m;b:while(1){D=t;E=v;F=w;G=x;H=y;I=z;J=A;K=B;L=C;while(1){M=c[J+1360>>2]|0;N=4>>>(I>>>0);O=c[M+32>>2]|0;P=c[M+36>>2]|0;if((L|0)==(I|0)){Q=5;break b}R=I+1|0;I6a(a,D,u,e,E,F,R);S=N+u|0;T=N+D|0;U=T>>>0<(c[G+1804>>2]|0)>>>0;if(S>>>0<(c[G+1808>>2]|0)>>>0){break}if(!U){Q=15;break b}M=(ba(N<<3,O)|0)+E|0;V=(ba(N<<2,P)|0)+F|0;W=c[i>>2]|0;X=c[W+1084>>2]|0;Y=X+60|0;Z=c[Y>>2]|0;if((R|0)==3){n=T;o=M;p=V;q=X;r=Z;s=u;break a}else{D=T;E=M;F=V;G=W;H=X;I=R;J=W;K=Y;L=Z}}J=N<<3;I=N<<2;I6a(a,D,S,e,J+E|0,I+F|0,R);if(!U){Q=15;break}Z=(ba(O,J)|0)+E|0;Y=(ba(P,I)|0)+F|0;I6a(a,T,u,e,Z,Y,R);W=Z+J|0;J=Y+I|0;I=c[i>>2]|0;Y=c[I+1084>>2]|0;Z=Y+60|0;X=c[Z>>2]|0;if((R|0)==3){n=T;o=W;p=J;q=Y;r=X;s=S;break a}else{t=T;u=S;v=W;w=J;x=I;y=Y;z=R;A=I;B=Z;C=X}}if((Q|0)==5){C=H+64|0;K6a(a,D,u,e,E,F,L,c[C>>2]|0);B=c[C>>2]|0;if((B|0)==2){C=N+u|0;if(!(C>>>0<(c[G+1808>>2]|0)>>>0)){return}K6a(a,D,C,e,(N<<3)+E|0,(N<<2)+F|0,c[K>>2]|0,2);return}else if((B|0)==1){B=N+D|0;if(!(B>>>0<(c[G+1804>>2]|0)>>>0)){return}C=(ba(N<<3,O)|0)+E|0;A=(ba(N<<2,P)|0)+F|0;K6a(a,B,u,e,C,A,c[K>>2]|0,1);return}else{return}}else if((Q|0)==15){return}}}while(0);K6a(a,n,s,e,o,p,r,c[q+64>>2]|0);return}function J6a(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;l=i;m=c[b+60>>2]|0;n=3-k|0;o=(d[m+(e&7|30032)|0]|0)>>>(n>>>0)<<1&2|(d[(c[m+30096>>2]|0)+f|0]|0)>>>(n>>>0)&1;if((a[m+1137|0]|0)==0){p=m+10231|0}else{p=118144}n=4>>>(k>>>0);q=c[m+1360>>2]|0;r=c[q+32>>2]|0;s=c[q+36>>2]|0;if((k|0)==3){q=m+1052|0;t=m+1056|0;u=m+1068|0;v=m+1060|0;w=m+1064|0;x=0;y=c[q>>2]|0;z=c[t>>2]|0;A=c[u>>2]|0;while(1){B=a[p+36+(o*3|0)+x|0]|0;C=d[1086680+y|0]|0;D=y<<C;c[q>>2]=D;E=A<<C;F=C+z|0;do{if((F|0)>-1){C=c[v>>2]|0;if(!(C>>>0<(c[w>>2]|0)>>>0)){G=E;H=F;break}c[v>>2]=C+2;I=C;G=((de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)<<F|E;H=F-16|0}else{G=E;H=F}}while(0);c[t>>2]=H;F=((ba(D-1|0,B&255)|0)>>8)+1|0;E=F<<16;I=G>>>0>=E>>>0;C=I?D-F|0:F;c[q>>2]=C;F=G-(I?E:0)|0;c[u>>2]=F;E=a[(I&1)+(106464+(x<<1))|0]|0;J=E<<24>>24;if(E<<24>>24>0){x=J;y=C;z=H;A=F}else{break}}A=-J|0;K6a(b,e,f,g,h,j,3,A);K=A;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}A=n+f|0;J=n+e|0;H=J>>>0<(c[m+1804>>2]|0)>>>0;if(!(A>>>0<(c[m+1808>>2]|0)>>>0)){if(!H){J6a(b,e,f,g,h,j,k+1|0);K=3;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}z=d[p+(k*12|0)+(o*3|0)+2|0]|0;y=m+1052|0;x=c[y>>2]|0;u=d[1086680+x|0]|0;G=m+1056|0;q=c[G>>2]|0;t=m+1068|0;v=c[t>>2]|0;w=x<<u;c[y>>2]=w;x=v<<u;v=q+u|0;do{if((v|0)>-1){u=m+1060|0;q=c[u>>2]|0;if(!(q>>>0<(c[m+1064>>2]|0)>>>0)){Q=x;R=v;break}c[u>>2]=q+2;u=q;Q=((de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)<<v|x;R=v-16|0}else{Q=x;R=v}}while(0);c[G>>2]=R;R=((ba(w-1|0,z)|0)>>8)+1|0;z=R<<16;if(Q>>>0<z>>>0){c[y>>2]=R;c[t>>2]=Q;K6a(b,e,f,g,h,j,k,2);K=2;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else{c[y>>2]=w-R;c[t>>2]=Q-z;z=k+1|0;J6a(b,e,f,g,h,j,z);J6a(b,J,f,g,(ba(n<<3,r)|0)+h|0,(ba(n<<2,s)|0)+j|0,z);K=3;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}}z=m+1052|0;if(!H){H=d[p+(k*12|0)+(o*3|0)+1|0]|0;Q=z;t=c[Q>>2]|0;R=d[1086680+t|0]|0;w=m+1056|0;y=c[w>>2]|0;G=m+1068|0;v=c[G>>2]|0;x=t<<R;c[Q>>2]=x;t=v<<R;v=y+R|0;do{if((v|0)>-1){R=m+1060|0;y=c[R>>2]|0;if(!(y>>>0<(c[m+1064>>2]|0)>>>0)){S=t;T=v;break}c[R>>2]=y+2;R=y;S=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<v|t;T=v-16|0}else{S=t;T=v}}while(0);c[w>>2]=T;T=((ba(x-1|0,H)|0)>>8)+1|0;H=T<<16;if(S>>>0<H>>>0){c[Q>>2]=T;c[G>>2]=S;K6a(b,e,f,g,h,j,k,1);K=1;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else{c[Q>>2]=x-T;c[G>>2]=S-H;H=k+1|0;J6a(b,e,f,g,h,j,H);J6a(b,e,A,g,(n<<3)+h|0,(n<<2)+j|0,H);K=3;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}}H=z;z=m+1056|0;S=m+1068|0;G=m+1060|0;T=m+1064|0;x=0;Q=c[H>>2]|0;w=c[z>>2]|0;v=c[S>>2]|0;while(1){t=a[p+(k*12|0)+(o*3|0)+x|0]|0;R=d[1086680+Q|0]|0;y=Q<<R;c[H>>2]=y;u=v<<R;q=R+w|0;do{if((q|0)>-1){R=c[G>>2]|0;if(!(R>>>0<(c[T>>2]|0)>>>0)){U=u;V=q;break}c[G>>2]=R+2;F=R;U=((de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<q|u;V=q-16|0}else{U=u;V=q}}while(0);c[z>>2]=V;q=((ba(y-1|0,t&255)|0)>>8)+1|0;u=q<<16;D=U>>>0>=u>>>0;B=D?y-q|0:q;c[H>>2]=B;q=U-(D?u:0)|0;c[S>>2]=q;u=a[(D&1)+(106464+(x<<1))|0]|0;W=u<<24>>24;if(u<<24>>24>0){x=W;Q=B;w=V;v=q}else{break}}v=-W|0;if((v|0)==1){K6a(b,e,f,g,h,j,k,1);K6a(b,J,f,g,(ba(n<<3,r)|0)+h|0,(ba(n<<2,s)|0)+j|0,k,1);K=1;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else if((v|0)==0){K6a(b,e,f,g,h,j,k,0);K=0;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else if((v|0)==3){W=k+1|0;J6a(b,e,f,g,h,j,W);V=n<<3;w=n<<2;J6a(b,e,A,g,V+h|0,w+j|0,W);Q=(ba(r,V)|0)+h|0;r=(ba(s,w)|0)+j|0;J6a(b,J,f,g,Q,r,W);J6a(b,J,A,g,Q+V|0,r+w|0,W);K=3;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else if((v|0)==2){K6a(b,e,f,g,h,j,k,2);K6a(b,e,A,g,(n<<3)+h|0,(n<<2)+j|0,k,2);K=2;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else{yDb(0,0,2046192,(l=i,i=i+24|0,c[l>>2]=2000488,c[l+8>>2]=1963512,c[l+16>>2]=3131,l)|0);i=l;Cd()}}function K6a(f,g,h,j,k,l,m,n){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0;o=i;i=i+80|0;p=o|0;q=o+48|0;r=f+60|0;f=c[r>>2]|0;s=f+1084|0;t=c[s>>2]|0;u=(m*3|0)+n|0;v=d[1678874+(u<<1)|0]|0;w=d[1678875+(u<<1)|0]|0;x=c[f+1360>>2]|0;c[f+1100>>2]=g;y=f+1104|0;c[y>>2]=g&7;c[f+1108>>2]=h;z=f+1112|0;c[z>>2]=h&7;c[f+35908>>2]=-128-(h<<6);c[f+35912>>2]=-128-(g<<6);A=f+1808|0;B=v+h|0;c[f+35916>>2]=((c[A>>2]|0)-B<<6)+128;C=f+1804|0;D=w+g|0;c[f+35920>>2]=((c[C>>2]|0)-D<<6)+128;E=f+1088|0;do{if((c[E>>2]|0)<2){c[t+48>>2]=u;c[t+60>>2]=m;c[t+64>>2]=n;L6a(f);F=c[t+52>>2]|0;G=1<<F;if((v<<1|0)==(G|0)){H=1}else{H=(w<<1|0)==(G|0)|0}c[t+56>>2]=F-H;a:do{if((a[t+10|0]|0)==0){F=c[r>>2]|0;G=c[F+1084>>2]|0;I=c[F+1100>>2]|0;J=c[F+1108>>2]|0;K=G+1|0;L=(a[K]|0)==0|0;M=c[G+52>>2]|0;N=F+10279|0;O=N+(M*1584|0)+(L*396|0)|0;P=F+18316|0;Q=P+(M*1728|0)+(L*432|0)|0;R=F+25228|0;S=R+(M*1152|0)+(L*288|0)|0;L=G+48|0;T=c[L>>2]|0;U=a[1678874+(T<<1)|0]|0;V=U&255;W=V<<1;X=a[1678875+(T<<1)|0]|0;T=X&255;Y=T<<1;Z=(c[F+1808>>2]|0)-J<<1;_=Z>>>0>W>>>0?W:Z;$=(c[F+1804>>2]|0)-I<<1;aa=$>>>0>Y>>>0?Y:$;$=d[G|0]|0;ca=F+1554|0;da=ca+($*26|0)+10|0;ea=(d[F+1549|0]<<2)+M|0;fa=G+56|0;ga=c[fa>>2]|0;ha=c[104368+(ga<<4)>>2]|0;ia=c[104288+(ga<<4)>>2]|0;ja=J<<1;ka=c[F+30104>>2]|0;la=I&7;I=la<<1|29856;ma=1403368+(M<<4)|0;na=1403368+(ga<<4)|0;do{if((M|0)==0){if((aa|0)<=0){break}ga=(_|0)>0;oa=F+1052|0;pa=F+35864|0;qa=da|0;ra=F+35896|0;sa=~Z;ta=~W;ua=~(sa>>>0>ta>>>0?sa:ta);ta=0;sa=0;while(1){if(ga){va=F+(ta+I)|0;wa=0;xa=sa;while(1){ya=c[108584+(d[((c[L>>2]|0)>>>0>9>>>0?xa:0)+(G+5)|0]<<2)>>2]|0;za=ka+(wa+ja)|0;Aa=M6a(oa,(c[pa>>2]|0)+(xa<<4<<1)|0,16,Q,S,O,(d[va]|0)+(d[za]|0)|0,c[104368+(ea<<4)+(ya<<2)>>2]|0,c[104288+(ea<<4)+(ya<<2)>>2]|0,ma,qa)|0;ya=(Aa|0)!=0|0;a[va]=ya;a[za]=ya;a[(c[ra>>2]|0)+xa|0]=Aa;Aa=wa+1|0;if((Aa|0)>=(_|0)){break}wa=Aa;xa=xa+1|0}Ba=sa+ua|0}else{Ba=sa}xa=ta+1|0;if((xa|0)<(aa|0)){ta=xa;sa=Ba}else{break}}}else if((M|0)==2){sa=(aa|0)>0;if(sa){ta=0;do{ua=F+(ta+I)|0;a[ua]=(c[ua>>2]|0)!=0|0;ta=ta+4|0;}while((ta|0)<(aa|0))}ta=(_|0)>0;if(ta){ua=0;do{ra=ka+(ua+ja)|0;a[ra]=(c[ra>>2]|0)!=0|0;ua=ua+4|0;}while((ua|0)<(_|0))}if(sa){ua=G+5|0;ra=F+1052|0;qa=F+35864|0;pa=da|0;oa=F+35896|0;ga=0;xa=0;while(1){if(ta){wa=F+(ga+I)|0;va=0;Aa=xa;while(1){ya=c[108584+(d[ua]<<2)>>2]|0;za=ka+(va+ja)|0;Ca=M6a(ra,(c[qa>>2]|0)+(Aa<<4<<1)|0,256,Q,S,O,(d[wa]|0)+(d[za]|0)|0,c[104368+(ea<<4)+(ya<<2)>>2]|0,c[104288+(ea<<4)+(ya<<2)>>2]|0,ma,pa)|0;ya=(Ca|0)!=0|0;a[wa]=ya;a[za]=ya;b[(c[oa>>2]|0)+Aa>>1]=Ca;Ca=va+4|0;ya=Aa+16|0;if((Ca|0)<(_|0)){va=Ca;Aa=ya}else{Da=ya;break}}}else{Da=xa}Aa=ga+4|0;if((Aa|0)<(aa|0)){ga=Aa;xa=Da}else{break}}}do{if((_|0)==(W|0)){if(U<<24>>24==0){break}else{Ea=0}do{xa=ka+(Ea+ja)|0;c[xa>>2]=ba(d[xa]|0,16843009)|0;Ea=Ea+4|0;}while((Ea|0)<(W|0))}else{if(ta){Fa=0}else{break}do{xa=_-Fa-1|0;TGb(ka+((Fa|1)+ja)|0,a[ka+(Fa+ja)|0]|0,((xa|0)>3?3:xa)|0)|0;Fa=Fa+4|0;}while((Fa|0)<(_|0))}}while(0);if((aa|0)==(Y|0)){if(X<<24>>24==0){break}else{Ga=0}do{ta=F+(Ga+I)|0;c[ta>>2]=ba(d[ta]|0,16843009)|0;Ga=Ga+4|0;}while((Ga|0)<(Y|0))}else{if(sa){Ha=0}else{break}do{ta=aa-Ha-1|0;TGb(F+((Ha|1)+I)|0,a[F+(Ha+I)|0]|0,((ta|0)>3?3:ta)|0)|0;Ha=Ha+4|0;}while((Ha|0)<(aa|0))}}else if((M|0)==3){sa=(aa|0)>0;if(sa){ta=0;do{xa=F+(ta+I)|0;ga=xa;a[xa]=((c[ga>>2]|0)!=0|(c[ga+4>>2]|0)!=0)&1;ta=ta+8|0;}while((ta|0)<(aa|0))}ta=(_|0)>0;if(ta){ga=0;do{xa=ka+(ga+ja)|0;oa=xa;a[xa]=((c[oa>>2]|0)!=0|(c[oa+4>>2]|0)!=0)&1;ga=ga+8|0;}while((ga|0)<(_|0))}if(sa){ga=G+5|0;oa=F+1052|0;xa=F+35864|0;pa=da|0;qa=F+35896|0;ra=0;ua=0;while(1){if(ta){Aa=F+(ra+I)|0;va=0;wa=ua;while(1){ya=c[108584+(d[ga]<<2)>>2]|0;Ca=ka+(va+ja)|0;za=N6a(oa,(c[xa>>2]|0)+(wa<<4<<1)|0,Q,S,O,(d[Aa]|0)+(d[Ca]|0)|0,c[104368+(ea<<4)+(ya<<2)>>2]|0,c[104288+(ea<<4)+(ya<<2)>>2]|0,ma,pa)|0;ya=(za|0)!=0|0;a[Aa]=ya;a[Ca]=ya;b[(c[qa>>2]|0)+wa>>1]=za;za=va+8|0;ya=wa+64|0;if((za|0)<(_|0)){va=za;wa=ya}else{Ia=ya;break}}}else{Ia=ua}wa=ra+8|0;if((wa|0)<(aa|0)){ra=wa;ua=Ia}else{break}}}do{if((_|0)==(W|0)){if(U<<24>>24==0){break}else{Ja=0}do{ua=ka+(Ja+ja)|0;ra=ba(d[ua]|0,16843009)|0;c[ua>>2]=ra;c[ka+((Ja|4)+ja)>>2]=ra;Ja=Ja+8|0;}while((Ja|0)<(W|0))}else{if(ta){Ka=0}else{break}do{ra=_-Ka-1|0;TGb(ka+((Ka|1)+ja)|0,a[ka+(Ka+ja)|0]|0,((ra|0)>7?7:ra)|0)|0;Ka=Ka+8|0;}while((Ka|0)<(_|0))}}while(0);if((aa|0)==(Y|0)){if(X<<24>>24==0){break}else{La=0}do{ta=F+(La+I)|0;ra=ba(d[ta]|0,16843009)|0;c[ta>>2]=ra;c[F+((La|4)+I)>>2]=ra;La=La+8|0;}while((La|0)<(Y|0))}else{if(sa){Ma=0}else{break}do{ra=aa-Ma-1|0;TGb(F+((Ma|1)+I)|0,a[F+(Ma+I)|0]|0,((ra|0)>7?7:ra)|0)|0;Ma=Ma+8|0;}while((Ma|0)<(aa|0))}}else if((M|0)==1){sa=(aa|0)>0;if(sa){ra=0;do{ta=F+(ra+I)|0;a[ta]=(b[ta>>1]|0)!=0|0;ra=ra+2|0;}while((ra|0)<(aa|0))}ra=(_|0)>0;if(ra){ta=0;do{ua=ka+(ta+ja)|0;a[ua]=(b[ua>>1]|0)!=0|0;ta=ta+2|0;}while((ta|0)<(_|0))}if(sa){ta=G+5|0;ua=F+1052|0;qa=F+35864|0;pa=da|0;xa=F+35896|0;oa=0;ga=0;while(1){if(ra){wa=F+(oa+I)|0;va=0;Aa=ga;while(1){ya=c[108584+(d[ta]<<2)>>2]|0;za=ka+(va+ja)|0;Ca=M6a(ua,(c[qa>>2]|0)+(Aa<<4<<1)|0,64,Q,S,O,(d[wa]|0)+(d[za]|0)|0,c[104368+(ea<<4)+(ya<<2)>>2]|0,c[104288+(ea<<4)+(ya<<2)>>2]|0,ma,pa)|0;ya=(Ca|0)!=0|0;a[wa]=ya;a[za]=ya;a[(c[xa>>2]|0)+Aa|0]=Ca;Ca=va+2|0;ya=Aa+4|0;if((Ca|0)<(_|0)){va=Ca;Aa=ya}else{Na=ya;break}}}else{Na=ga}Aa=oa+2|0;if((Aa|0)<(aa|0)){oa=Aa;ga=Na}else{break}}}if((_|0)>1){ga=ja-1|0;oa=1;do{a[ka+(oa+ja)|0]=a[ka+(ga+oa)|0]|0;oa=oa+2|0;}while((oa|0)<(_|0))}if((aa|0)<=1){break}oa=I-1|0;ga=1;do{a[F+(ga+I)|0]=a[F+(oa+ga)|0]|0;ga=ga+2|0;}while((ga|0)<(aa|0))}}while(0);I=(a[K]|0)==0|0;ka=c[fa>>2]|0;ja=N+(ka*1584|0)+792+(I*396|0)|0;ma=P+(ka*1728|0)+864+(I*432|0)|0;ea=R+(ka*1152|0)+576+(I*288|0)|0;I=_>>1;O=aa>>1;S=F+30108|0;Q=F+30016|0;da=(aa|0)>0;G=(_|0)>0;M=F+1052|0;Y=F+35876|0;X=ca+($*26|0)+14|0;W=F+35900|0;U=(I|0)==(V|0);L=(O|0)==(T|0);Z=(_|0)>2;ga=(aa|0)>2;oa=la-1|0;xa=J-1|0;pa=(_|0)>8?((I+1073741823|0)>>>2<<4)+16|0:16;qa=(_|0)>4?((I+2147483647|0)>>>1<<2)+4|0:4;ua=(I|0)>1?I:1;ta=0;ra=ka;while(1){ka=c[S+(ta<<2)>>2]|0;sa=ka+J|0;Aa=Q+(ta<<3)+la|0;do{if((ra|0)==2){if(da){va=0;do{wa=va+la+(Q+(ta<<3))|0;a[wa]=(c[wa>>2]|0)!=0|0;va=va+4|0;}while((va|0)<(O|0))}if(G){va=0;do{wa=ka+(va+J)|0;a[wa]=(c[wa>>2]|0)!=0|0;va=va+4|0;}while((va|0)<(I|0))}if(da){va=Y+(ta<<2)|0;wa=W+(ta<<2)|0;ya=0;Ca=0;while(1){if(G){za=ya+la+(Q+(ta<<3))|0;Oa=0;Pa=Ca;while(1){Qa=ka+(Oa+J)|0;Ra=M6a(M,(c[va>>2]|0)+(Pa<<4<<1)|0,256,ma,ea,ja,(d[za]|0)+(d[Qa]|0)|0,ha,ia,na,X)|0;Sa=(Ra|0)!=0|0;a[za]=Sa;a[Qa]=Sa;a[(c[wa>>2]|0)+Pa|0]=Ra;Ra=Oa+4|0;if((Ra|0)<(I|0)){Oa=Ra;Pa=Pa+16|0}else{break}}Ta=Ca+pa|0}else{Ta=Ca}Pa=ya+4|0;if((Pa|0)<(O|0)){ya=Pa;Ca=Ta}else{break}}}do{if(U){if(G){Ua=0}else{break}do{Ca=ka+(Ua+J)|0;c[Ca>>2]=ba(d[Ca]|0,16843009)|0;Ua=Ua+4|0;}while((Ua|0)<(V|0))}else{if(G){Va=0}else{break}do{Ca=I-Va-1|0;TGb(ka+((Va|1)+J)|0,a[ka+(Va+J)|0]|0,((Ca|0)>3?3:Ca)|0)|0;Va=Va+4|0;}while((Va|0)<(I|0))}}while(0);if(L){if(da){Wa=0}else{break}do{Ca=Wa+la+(Q+(ta<<3))|0;c[Ca>>2]=ba(d[Ca]|0,16843009)|0;Wa=Wa+4|0;}while((Wa|0)<(T|0))}else{if(da){Xa=0}else{break}do{Ca=O-Xa-1|0;TGb((Xa|1)+la+(Q+(ta<<3))|0,a[Xa+la+(Q+(ta<<3))|0]|0,((Ca|0)>3?3:Ca)|0)|0;Xa=Xa+4|0;}while((Xa|0)<(O|0))}}else if((ra|0)==0){if(!da){break}Ca=Y+(ta<<2)|0;ya=W+(ta<<2)|0;wa=0;va=0;while(1){if(G){Pa=wa+la+(Q+(ta<<3))|0;Oa=0;za=va;while(1){Ra=ka+(Oa+J)|0;Sa=M6a(M,(c[Ca>>2]|0)+(za<<4<<1)|0,16,ma,ea,ja,(d[Pa]|0)+(d[Ra]|0)|0,ha,ia,na,X)|0;Qa=(Sa|0)!=0|0;a[Pa]=Qa;a[Ra]=Qa;a[(c[ya>>2]|0)+za|0]=Sa;Sa=Oa+1|0;if((Sa|0)<(I|0)){Oa=Sa;za=za+1|0}else{break}}Ya=va+ua|0}else{Ya=va}za=wa+1|0;if((za|0)<(O|0)){wa=za;va=Ya}else{break}}}else if((ra|0)==1){if(da){va=0;do{wa=va+la+(Q+(ta<<3))|0;a[wa]=(b[wa>>1]|0)!=0|0;va=va+2|0;}while((va|0)<(O|0))}if(G){va=0;do{wa=ka+(va+J)|0;a[wa]=(b[wa>>1]|0)!=0|0;va=va+2|0;}while((va|0)<(I|0))}if(da){va=Y+(ta<<2)|0;wa=W+(ta<<2)|0;ya=0;Ca=0;while(1){if(G){za=ya+la+(Q+(ta<<3))|0;Oa=0;Pa=Ca;while(1){Sa=ka+(Oa+J)|0;Qa=M6a(M,(c[va>>2]|0)+(Pa<<4<<1)|0,64,ma,ea,ja,(d[za]|0)+(d[Sa]|0)|0,ha,ia,na,X)|0;Ra=(Qa|0)!=0|0;a[za]=Ra;a[Sa]=Ra;a[(c[wa>>2]|0)+Pa|0]=Qa;Qa=Oa+2|0;if((Qa|0)<(I|0)){Oa=Qa;Pa=Pa+4|0}else{break}}Za=Ca+qa|0}else{Za=Ca}Pa=ya+2|0;if((Pa|0)<(O|0)){ya=Pa;Ca=Za}else{break}}}if(Z){Ca=1;do{a[ka+(Ca+J)|0]=a[ka+(xa+Ca)|0]|0;Ca=Ca+2|0;}while((Ca|0)<(I|0))}if(ga){_a=1}else{break}do{a[_a+la+(Q+(ta<<3))|0]=a[oa+_a+(Q+(ta<<3))|0]|0;_a=_a+2|0;}while((_a|0)<(O|0))}else if((ra|0)==3){if(da){Ca=0;do{ya=(Ca|la)+(Q+(ta<<3))|0;wa=ya;a[ya]=((c[wa>>2]|0)!=0|(c[wa+4>>2]|0)!=0)&1;Ca=Ca+8|0;}while((Ca|0)<(O|0))}if(G){Ca=0;do{wa=ka+(Ca+J)|0;ya=wa;a[wa]=((c[ya>>2]|0)!=0|(c[ya+4>>2]|0)!=0)&1;Ca=Ca+8|0;}while((Ca|0)<(I|0))}Ca=N6a(M,c[Y+(ta<<2)>>2]|0,ma,ea,ja,(d[Aa]|0)+(d[sa]|0)|0,ha,ia,na,X)|0;ya=(Ca|0)!=0|0;a[Aa]=ya;a[sa]=ya;b[c[W+(ta<<2)>>2]>>1]=Ca;do{if(U){if(G){$a=0}else{break}do{Ca=ka+($a+J)|0;ya=ba(d[Ca]|0,16843009)|0;c[Ca>>2]=ya;c[ka+(($a|4)+J)>>2]=ya;$a=$a+8|0;}while(($a|0)<(V|0))}else{if(G){ab=0}else{break}do{ya=I-ab-1|0;TGb(ka+((ab|1)+J)|0,a[ka+(ab+J)|0]|0,((ya|0)>7?7:ya)|0)|0;ab=ab+8|0;}while((ab|0)<(I|0))}}while(0);if(L){if(da){bb=0}else{break}do{ya=(bb|la)+(Q+(ta<<3))|0;Ca=ba(d[ya]|0,16843009)|0;c[ya>>2]=Ca;c[(bb|4)+la+(Q+(ta<<3))>>2]=Ca;bb=bb+8|0;}while((bb|0)<(T|0))}else{if(da){cb=0}else{break}do{Ca=O-cb-1|0;TGb((cb|1)+la+(Q+(ta<<3))|0,a[(cb|la)+(Q+(ta<<3))|0]|0,((Ca|0)>7?7:Ca)|0)|0;cb=cb+8|0;}while((cb|0)<(O|0))}}}while(0);ka=ta+1|0;if((ka|0)>=2){break a}ta=ka;ra=c[fa>>2]|0}}else{fa=c[y>>2]|0;if((v|0)==4){ra=(c[f+30104>>2]|0)+(h<<1)|0;c[ra>>2]=0;c[ra+4>>2]=0;c[(c[f+30108>>2]|0)+h>>2]=0;c[(c[f+30112>>2]|0)+h>>2]=0}else if((v|0)==8){ra=h<<1;ta=f+30104|0;O=(c[ta>>2]|0)+ra|0;c[O>>2]=0;c[O+4>>2]=0;O=(c[ta>>2]|0)+(ra+8)|0;c[O>>2]=0;c[O+4>>2]=0;O=(c[f+30108>>2]|0)+h|0;c[O>>2]=0;c[O+4>>2]=0;O=(c[f+30112>>2]|0)+h|0;c[O>>2]=0;c[O+4>>2]=0}else if((v|0)==1){b[(c[f+30104>>2]|0)+(h<<1)>>1]=0;a[(c[f+30108>>2]|0)+h|0]=0;a[(c[f+30112>>2]|0)+h|0]=0}else if((v|0)==2){c[(c[f+30104>>2]|0)+(h<<1)>>2]=0;b[(c[f+30108>>2]|0)+h>>1]=0;b[(c[f+30112>>2]|0)+h>>1]=0}if((w|0)==8){O=fa<<1;ra=f+(O+29856)|0;c[ra>>2]=0;c[ra+4>>2]=0;ra=f+(O+29864)|0;c[ra>>2]=0;c[ra+4>>2]=0;ra=f+(fa+30016)|0;c[ra>>2]=0;c[ra+4>>2]=0;ra=f+(fa+30024)|0;c[ra>>2]=0;c[ra+4>>2]=0;break}else if((w|0)==1){b[f+((fa<<1)+29856)>>1]=0;a[f+(fa+30016)|0]=0;a[f+(fa+30024)|0]=0;break}else if((w|0)==2){c[f+((fa<<1)+29856)>>2]=0;b[f+(fa+30016)>>1]=0;b[f+(fa+30024)>>1]=0;break}else if((w|0)==4){ra=f+((fa<<1)+29856)|0;c[ra>>2]=0;c[ra+4>>2]=0;c[f+(fa+30016)>>2]=0;c[f+(fa+30024)>>2]=0;break}else{break}}}while(0);if((c[E>>2]|0)!=1){break}c[s>>2]=(c[s>>2]|0)+68;fa=ba(w,v)|0;ra=f+35864|0;c[ra>>2]=(c[ra>>2]|0)+(fa<<6<<1);ra=fa<<4;O=f+35876|0;c[O>>2]=(c[O>>2]|0)+(ra<<1);O=f+35880|0;c[O>>2]=(c[O>>2]|0)+(ra<<1);ra=ba(v<<2,w)|0;O=f+35896|0;c[O>>2]=(c[O>>2]|0)+ra;ra=f+35900|0;c[ra>>2]=(c[ra>>2]|0)+fa;ra=f+35904|0;c[ra>>2]=(c[ra>>2]|0)+fa;i=o;return}}while(0);cb=x+32|0;bb=c[cb>>2]|0;if((B<<3|0)>(bb|0)){db=1}else{db=D>>>0>(c[C>>2]|0)>>>0}ab=x+36|0;if((B<<2|0)>(c[ab>>2]|0)){eb=1}else{eb=D>>>0>(c[C>>2]|0)>>>0}if(db){c[f+1116>>2]=f+35936;c[f+1128>>2]=64}else{c[f+1116>>2]=(c[x>>2]|0)+k;c[f+1128>>2]=bb}if(eb){c[f+1120>>2]=f+40032;c[f+1124>>2]=f+41056;c[f+1132>>2]=32}else{c[f+1120>>2]=(c[x+4>>2]|0)+l;c[f+1124>>2]=(c[x+8>>2]|0)+l;c[f+1132>>2]=c[ab>>2]}bb=t+1|0;$a=c[r>>2]|0;do{if((a[bb]|0)==0){r=$a;_a=c[$a+1084>>2]|0;Za=c[$a+1100>>2]|0;Ya=c[$a+1108>>2]|0;Xa=$a+1168|0;Wa=Xa+((d[$a+((d[_a+3|0]|0)+1157)|0]|0)*12|0)|0;Va=c[Wa>>2]|0;Ua=c[Va+68>>2]|0;Ta=c[Va+72>>2]|0;Na=$a+1128|0;Ma=c[Na>>2]|0;La=$a+1132|0;Ka=c[La>>2]|0;Ja=_a+2|0;if((a[Ja]|0)==0){fb=0;gb=0;hb=0;ib=0}else{Ia=Xa+((d[$a+((d[_a+4|0]|0)+1157)|0]|0)*12|0)|0;Xa=c[Ia>>2]|0;fb=Ia;gb=Xa;hb=c[Xa+68>>2]|0;ib=c[Xa+72>>2]|0}Xa=_a+48|0;Ia=c[Xa>>2]|0;do{if(Ia>>>0>9>>>0){if((Ia|0)==10){Ha=_a+12|0;Ga=c[Ha>>2]|0;Fa=$a+768|0;Ea=$a+1116|0;Da=c[Ea>>2]|0;Ba=Va|0;H=c[Ba>>2]|0;n=Va+32|0;m=c[n>>2]|0;u=Za<<3;fa=Ya<<3;ra=b[_a+16>>1]|0;O=b[_a+18>>1]|0;ta=(O>>3)+u|0;Q=(ra>>3)+fa|0;la=(ba(ta,m)|0)+Q|0;da=H+la|0;T=ra&7;ra=O&7;O=(ra|0)!=0|0;L=O<<2;I=ta+11+L>>6;Z0a(Wa,(I|0)>0?I:0,0);I=(T|0)!=0|0;J=-I|0;G=J&3;V=-O|0;U=V&3;do{if((Q|0)<(G|0)|(ta|0)<(U|0)){jb=288}else{if(((I<<2)+Q|0)>(Ua-8|0)){jb=288;break}if((L+ta|0)>(Ta-4|0)){jb=288}else{kb=da;lb=m}}}while(0);if((jb|0)==288){da=H+(la-G-(ba(U,m)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,da,80,m,J&7|8,(V&7)+4|0,Q-G|0,ta-U|0,Ua,Ta);kb=(U*80|0|G)+(r+30176)|0;lb=80}Ke[c[Fa+(Ga<<5)+(I<<3)+(O<<2)>>2]&1023](Da,Ma,kb,lb,4,T<<1,ra<<1);da=c[Ha>>2]|0;L=Ma<<2;W=(c[Ea>>2]|0)+L|0;X=c[Ba>>2]|0;na=c[n>>2]|0;ia=u|4;ha=b[_a+32>>1]|0;ja=b[_a+34>>1]|0;ea=(ja>>3)+ia|0;ma=(ha>>3)+fa|0;Y=(ba(ea,na)|0)+ma|0;M=X+Y|0;oa=ha&7;ha=ja&7;ja=(ha|0)!=0|0;ga=ja<<2;xa=ea+11+ga>>6;Z0a(Wa,(xa|0)>0?xa:0,0);xa=(oa|0)!=0|0;Z=-xa|0;qa=Z&3;ua=-ja|0;pa=ua&3;do{if((ma|0)<(qa|0)|(ea|0)<(pa|0)){jb=292}else{if(((xa<<2)+ma|0)>(Ua-8|0)){jb=292;break}if((ga+ea|0)>(Ta-4|0)){jb=292}else{mb=M;nb=na}}}while(0);if((jb|0)==292){M=X+(Y-qa-(ba(pa,na)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,M,80,na,Z&7|8,(ua&7)+4|0,ma-qa|0,ea-pa|0,Ua,Ta);mb=(pa*80|0|qa)+(r+30176)|0;nb=80}Ke[c[Fa+(da<<5)+(xa<<3)+(ja<<2)>>2]&1023](W,Ma,mb,nb,4,oa<<1,ha<<1);if((a[Ja]|0)==0){break}M=c[Ha>>2]|0;ga=c[Ea>>2]|0;n=gb|0;Ba=c[n>>2]|0;ra=gb+32|0;T=c[ra>>2]|0;Da=b[_a+20>>1]|0;O=b[_a+22>>1]|0;I=(O>>3)+u|0;Ga=(Da>>3)+fa|0;G=(ba(I,T)|0)+Ga|0;U=Ba+G|0;ta=Da&7;Da=O&7;O=(Da|0)!=0|0;Q=O<<2;V=I+11+Q>>6;Z0a(fb,(V|0)>0?V:0,0);V=(ta|0)!=0|0;J=-V|0;m=J&3;la=-O|0;H=la&3;do{if((Ga|0)<(m|0)|(I|0)<(H|0)){jb=297}else{if(((V<<2)+Ga|0)>(hb-8|0)){jb=297;break}if((Q+I|0)>(ib-4|0)){jb=297}else{ob=U;pb=T}}}while(0);if((jb|0)==297){U=Ba+(G-m-(ba(H,T)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,U,80,T,J&7|8,(la&7)+4|0,Ga-m|0,I-H|0,hb,ib);ob=(H*80|0|m)+(r+30176)|0;pb=80}Ke[c[Fa+(M<<5)+16+(V<<3)+(O<<2)>>2]&1023](ga,Ma,ob,pb,4,ta<<1,Da<<1);U=c[Ha>>2]|0;Q=(c[Ea>>2]|0)+L|0;u=c[n>>2]|0;ha=c[ra>>2]|0;oa=b[_a+36>>1]|0;W=b[_a+38>>1]|0;ja=(W>>3)+ia|0;xa=(oa>>3)+fa|0;da=(ba(ja,ha)|0)+xa|0;qa=u+da|0;pa=oa&7;oa=W&7;W=(oa|0)!=0|0;ea=W<<2;ma=ja+11+ea>>6;Z0a(fb,(ma|0)>0?ma:0,0);ma=(pa|0)!=0|0;ua=-ma|0;Z=ua&3;na=-W|0;Y=na&3;do{if((xa|0)<(Z|0)|(ja|0)<(Y|0)){jb=301}else{if(((ma<<2)+xa|0)>(hb-8|0)){jb=301;break}if((ea+ja|0)>(ib-4|0)){jb=301}else{qb=qa;rb=ha}}}while(0);if((jb|0)==301){qa=u+(da-Z-(ba(Y,ha)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,qa,80,ha,ua&7|8,(na&7)+4|0,xa-Z|0,ja-Y|0,hb,ib);qb=(Y*80|0|Z)+(r+30176)|0;rb=80}Ke[c[Fa+(U<<5)+16+(ma<<3)+(W<<2)>>2]&1023](Q,Ma,qb,rb,4,pa<<1,oa<<1);break}qa=_a+12|0;ea=c[qa>>2]|0;fa=$a+896|0;ia=$a+1116|0;ra=c[ia>>2]|0;n=Va|0;L=c[n>>2]|0;Ea=Va+32|0;Ha=c[Ea>>2]|0;Da=Za<<3;ta=Ya<<3;ga=b[_a+16>>1]|0;O=b[_a+18>>1]|0;V=(O>>3)+Da|0;M=(ga>>3)+ta|0;m=(ba(V,Ha)|0)+M|0;H=L+m|0;I=ga&7;ga=O&7;O=(ga|0)!=0|0;Ga=O<<2;if((Ia|0)==11){la=V+15+Ga>>6;Z0a(Wa,(la|0)>0?la:0,0);la=(I|0)!=0|0;J=-la|0;T=J&3;G=-O|0;Ba=G&3;do{if((M|0)<(T|0)|(V|0)<(Ba|0)){jb=307}else{if(((la<<2)+M|0)>(Ua-4|0)){jb=307;break}if((Ga+V|0)>(Ta-8|0)){jb=307}else{sb=H;tb=Ha}}}while(0);if((jb|0)==307){oa=L+(m-T-(ba(Ba,Ha)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,oa,80,Ha,(J&7)+4|0,G&7|8,M-T|0,V-Ba|0,Ua,Ta);sb=(Ba*80|0|T)+(r+30176)|0;tb=80}Ke[c[fa+(ea<<5)+(la<<3)+(O<<2)>>2]&1023](ra,Ma,sb,tb,8,I<<1,ga<<1);oa=c[qa>>2]|0;pa=(c[ia>>2]|0)+4|0;Q=c[n>>2]|0;W=c[Ea>>2]|0;ma=ta|4;U=b[_a+24>>1]|0;Fa=b[_a+26>>1]|0;Z=(Fa>>3)+Da|0;Y=(U>>3)+ma|0;ja=(ba(Z,W)|0)+Y|0;xa=Q+ja|0;na=U&7;U=Fa&7;Fa=(U|0)!=0|0;ua=Fa<<2;ha=Z+15+ua>>6;Z0a(Wa,(ha|0)>0?ha:0,0);ha=(na|0)!=0|0;da=-ha|0;u=da&3;X=-Fa|0;S=X&3;do{if((Y|0)<(u|0)|(Z|0)<(S|0)){jb=311}else{if(((ha<<2)+Y|0)>(Ua-4|0)){jb=311;break}if((ua+Z|0)>(Ta-8|0)){jb=311}else{ub=xa;vb=W}}}while(0);if((jb|0)==311){xa=Q+(ja-u-(ba(S,W)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,xa,80,W,(da&7)+4|0,X&7|8,Y-u|0,Z-S|0,Ua,Ta);ub=(S*80|0|u)+(r+30176)|0;vb=80}Ke[c[fa+(oa<<5)+(ha<<3)+(Fa<<2)>>2]&1023](pa,Ma,ub,vb,8,na<<1,U<<1);if((a[Ja]|0)==0){break}xa=c[qa>>2]|0;ua=c[ia>>2]|0;la=gb|0;T=c[la>>2]|0;Ba=gb+32|0;G=c[Ba>>2]|0;J=b[_a+20>>1]|0;_=b[_a+22>>1]|0;aa=(_>>3)+Da|0;F=(J>>3)+ta|0;$=(ba(aa,G)|0)+F|0;ca=T+$|0;R=J&7;J=_&7;_=(J|0)!=0|0;P=_<<2;N=aa+15+P>>6;Z0a(fb,(N|0)>0?N:0,0);N=(R|0)!=0|0;K=-N|0;ka=K&3;sa=-_|0;Aa=sa&3;do{if((F|0)<(ka|0)|(aa|0)<(Aa|0)){jb=316}else{if(((N<<2)+F|0)>(hb-4|0)){jb=316;break}if((P+aa|0)>(ib-8|0)){jb=316}else{wb=ca;xb=G}}}while(0);if((jb|0)==316){ca=T+($-ka-(ba(Aa,G)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,ca,80,G,(K&7)+4|0,sa&7|8,F-ka|0,aa-Aa|0,hb,ib);wb=(Aa*80|0|ka)+(r+30176)|0;xb=80}Ke[c[fa+(xa<<5)+16+(N<<3)+(_<<2)>>2]&1023](ua,Ma,wb,xb,8,R<<1,J<<1);ca=c[qa>>2]|0;P=(c[ia>>2]|0)+4|0;U=c[la>>2]|0;na=c[Ba>>2]|0;pa=b[_a+28>>1]|0;Fa=b[_a+30>>1]|0;ha=(Fa>>3)+Da|0;oa=(pa>>3)+ma|0;u=(ba(ha,na)|0)+oa|0;S=U+u|0;Z=pa&7;pa=Fa&7;Fa=(pa|0)!=0|0;Y=Fa<<2;X=ha+15+Y>>6;Z0a(fb,(X|0)>0?X:0,0);X=(Z|0)!=0|0;da=-X|0;W=da&3;ja=-Fa|0;Q=ja&3;do{if((oa|0)<(W|0)|(ha|0)<(Q|0)){jb=320}else{if(((X<<2)+oa|0)>(hb-4|0)){jb=320;break}if((Y+ha|0)>(ib-8|0)){jb=320}else{yb=S;zb=na}}}while(0);if((jb|0)==320){S=U+(u-W-(ba(Q,na)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,S,80,na,(da&7)+4|0,ja&7|8,oa-W|0,ha-Q|0,hb,ib);yb=(Q*80|0|W)+(r+30176)|0;zb=80}Ke[c[fa+(ca<<5)+16+(X<<3)+(Fa<<2)>>2]&1023](P,Ma,yb,zb,8,Z<<1,pa<<1);break}S=V+11+Ga>>6;Z0a(Wa,(S|0)>0?S:0,0);S=(I|0)!=0|0;Y=-S|0;ma=Y&3;Ba=-O|0;la=Ba&3;do{if((M|0)<(ma|0)|(V|0)<(la|0)){jb=325}else{if(((S<<2)+M|0)>(Ua-4|0)){jb=325;break}if((Ga+V|0)>(Ta-4|0)){jb=325}else{Ab=H;Bb=Ha}}}while(0);if((jb|0)==325){H=L+(m-ma-(ba(la,Ha)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,H,80,Ha,(Y&7)+4|0,(Ba&7)+4|0,M-ma|0,V-la|0,Ua,Ta);Ab=(la*80|0|ma)+(r+30176)|0;Bb=80}Ke[c[fa+(ea<<5)+(S<<3)+(O<<2)>>2]&1023](ra,Ma,Ab,Bb,4,I<<1,ga<<1);H=c[qa>>2]|0;Ga=(c[ia>>2]|0)+4|0;pa=c[n>>2]|0;Z=c[Ea>>2]|0;P=ta|4;Fa=b[_a+24>>1]|0;X=b[_a+26>>1]|0;ca=(X>>3)+Da|0;W=(Fa>>3)+P|0;Q=(ba(ca,Z)|0)+W|0;ha=pa+Q|0;oa=Fa&7;Fa=X&7;X=(Fa|0)!=0|0;ja=X<<2;da=ca+11+ja>>6;Z0a(Wa,(da|0)>0?da:0,0);da=(oa|0)!=0|0;na=-da|0;u=na&3;U=-X|0;J=U&3;do{if((W|0)<(u|0)|(ca|0)<(J|0)){jb=329}else{if(((da<<2)+W|0)>(Ua-4|0)){jb=329;break}if((ja+ca|0)>(Ta-4|0)){jb=329}else{Cb=ha;Db=Z}}}while(0);if((jb|0)==329){ha=pa+(Q-u-(ba(J,Z)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,ha,80,Z,(na&7)+4|0,(U&7)+4|0,W-u|0,ca-J|0,Ua,Ta);Cb=(J*80|0|u)+(r+30176)|0;Db=80}Ke[c[fa+(H<<5)+(da<<3)+(X<<2)>>2]&1023](Ga,Ma,Cb,Db,4,oa<<1,Fa<<1);ha=c[qa>>2]|0;ja=Ma<<2;ga=(c[ia>>2]|0)+ja|0;I=c[n>>2]|0;ra=c[Ea>>2]|0;O=Da|4;S=b[_a+32>>1]|0;ea=b[_a+34>>1]|0;ma=(ea>>3)+O|0;la=(S>>3)+ta|0;V=(ba(ma,ra)|0)+la|0;M=I+V|0;Ba=S&7;S=ea&7;ea=(S|0)!=0|0;Y=ea<<2;Ha=ma+11+Y>>6;Z0a(Wa,(Ha|0)>0?Ha:0,0);Ha=(Ba|0)!=0|0;m=-Ha|0;L=m&3;R=-ea|0;ua=R&3;do{if((la|0)<(L|0)|(ma|0)<(ua|0)){jb=333}else{if(((Ha<<2)+la|0)>(Ua-4|0)){jb=333;break}if((Y+ma|0)>(Ta-4|0)){jb=333}else{Eb=M;Fb=ra}}}while(0);if((jb|0)==333){M=I+(V-L-(ba(ua,ra)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,M,80,ra,(m&7)+4|0,(R&7)+4|0,la-L|0,ma-ua|0,Ua,Ta);Eb=(ua*80|0|L)+(r+30176)|0;Fb=80}Ke[c[fa+(ha<<5)+(Ha<<3)+(ea<<2)>>2]&1023](ga,Ma,Eb,Fb,4,Ba<<1,S<<1);M=c[qa>>2]|0;Y=ja+4|0;Fa=(c[ia>>2]|0)+Y|0;oa=c[n>>2]|0;Ga=c[Ea>>2]|0;X=b[_a+40>>1]|0;da=b[_a+42>>1]|0;H=(da>>3)+O|0;u=(X>>3)+P|0;J=(ba(H,Ga)|0)+u|0;ca=oa+J|0;W=X&7;X=da&7;da=(X|0)!=0|0;U=da<<2;na=H+11+U>>6;Z0a(Wa,(na|0)>0?na:0,0);na=(W|0)!=0|0;Z=-na|0;Q=Z&3;pa=-da|0;_=pa&3;do{if((u|0)<(Q|0)|(H|0)<(_|0)){jb=337}else{if(((na<<2)+u|0)>(Ua-4|0)){jb=337;break}if((U+H|0)>(Ta-4|0)){jb=337}else{Gb=ca;Hb=Ga}}}while(0);if((jb|0)==337){ca=oa+(J-Q-(ba(_,Ga)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,ca,80,Ga,(Z&7)+4|0,(pa&7)+4|0,u-Q|0,H-_|0,Ua,Ta);Gb=(_*80|0|Q)+(r+30176)|0;Hb=80}Ke[c[fa+(M<<5)+(na<<3)+(da<<2)>>2]&1023](Fa,Ma,Gb,Hb,4,W<<1,X<<1);if((a[Ja]|0)==0){break}ca=c[qa>>2]|0;U=c[ia>>2]|0;Ea=gb|0;n=c[Ea>>2]|0;S=gb+32|0;Ba=c[S>>2]|0;ga=b[_a+20>>1]|0;ea=b[_a+22>>1]|0;Ha=(ea>>3)+Da|0;ha=(ga>>3)+ta|0;L=(ba(Ha,Ba)|0)+ha|0;ua=n+L|0;ma=ga&7;ga=ea&7;ea=(ga|0)!=0|0;la=ea<<2;R=Ha+11+la>>6;Z0a(fb,(R|0)>0?R:0,0);R=(ma|0)!=0|0;m=-R|0;ra=m&3;V=-ea|0;I=V&3;do{if((ha|0)<(ra|0)|(Ha|0)<(I|0)){jb=342}else{if(((R<<2)+ha|0)>(hb-4|0)){jb=342;break}if((la+Ha|0)>(ib-4|0)){jb=342}else{Ib=ua;Jb=Ba}}}while(0);if((jb|0)==342){ua=n+(L-ra-(ba(I,Ba)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,ua,80,Ba,(m&7)+4|0,(V&7)+4|0,ha-ra|0,Ha-I|0,hb,ib);Ib=(I*80|0|ra)+(r+30176)|0;Jb=80}Ke[c[fa+(ca<<5)+16+(R<<3)+(ea<<2)>>2]&1023](U,Ma,Ib,Jb,4,ma<<1,ga<<1);ua=c[qa>>2]|0;la=(c[ia>>2]|0)+4|0;X=c[Ea>>2]|0;W=c[S>>2]|0;Fa=b[_a+28>>1]|0;da=b[_a+30>>1]|0;na=(da>>3)+Da|0;M=(Fa>>3)+P|0;Q=(ba(na,W)|0)+M|0;_=X+Q|0;H=Fa&7;Fa=da&7;da=(Fa|0)!=0|0;u=da<<2;pa=na+11+u>>6;Z0a(fb,(pa|0)>0?pa:0,0);pa=(H|0)!=0|0;Z=-pa|0;Ga=Z&3;J=-da|0;oa=J&3;do{if((M|0)<(Ga|0)|(na|0)<(oa|0)){jb=346}else{if(((pa<<2)+M|0)>(hb-4|0)){jb=346;break}if((u+na|0)>(ib-4|0)){jb=346}else{Kb=_;Lb=W}}}while(0);if((jb|0)==346){_=X+(Q-Ga-(ba(oa,W)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,_,80,W,(Z&7)+4|0,(J&7)+4|0,M-Ga|0,na-oa|0,hb,ib);Kb=(oa*80|0|Ga)+(r+30176)|0;Lb=80}Ke[c[fa+(ua<<5)+16+(pa<<3)+(da<<2)>>2]&1023](la,Ma,Kb,Lb,4,H<<1,Fa<<1);_=c[qa>>2]|0;u=(c[ia>>2]|0)+ja|0;Da=c[Ea>>2]|0;ga=c[S>>2]|0;ma=b[_a+36>>1]|0;U=b[_a+38>>1]|0;ea=(U>>3)+O|0;R=(ma>>3)+ta|0;ca=(ba(ea,ga)|0)+R|0;ra=Da+ca|0;I=ma&7;ma=U&7;U=(ma|0)!=0|0;Ha=U<<2;ha=ea+11+Ha>>6;Z0a(fb,(ha|0)>0?ha:0,0);ha=(I|0)!=0|0;V=-ha|0;m=V&3;Ba=-U|0;L=Ba&3;do{if((R|0)<(m|0)|(ea|0)<(L|0)){jb=350}else{if(((ha<<2)+R|0)>(hb-4|0)){jb=350;break}if((Ha+ea|0)>(ib-4|0)){jb=350}else{Mb=ra;Nb=ga}}}while(0);if((jb|0)==350){ra=Da+(ca-m-(ba(L,ga)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,ra,80,ga,(V&7)+4|0,(Ba&7)+4|0,R-m|0,ea-L|0,hb,ib);Mb=(L*80|0|m)+(r+30176)|0;Nb=80}Ke[c[fa+(_<<5)+16+(ha<<3)+(U<<2)>>2]&1023](u,Ma,Mb,Nb,4,I<<1,ma<<1);ra=c[qa>>2]|0;Ha=(c[ia>>2]|0)+Y|0;ta=c[Ea>>2]|0;ja=c[S>>2]|0;Fa=b[_a+44>>1]|0;H=b[_a+46>>1]|0;la=(H>>3)+O|0;da=(Fa>>3)+P|0;pa=(ba(la,ja)|0)+da|0;ua=ta+pa|0;Ga=Fa&7;Fa=H&7;H=(Fa|0)!=0|0;oa=H<<2;na=la+11+oa>>6;Z0a(fb,(na|0)>0?na:0,0);na=(Ga|0)!=0|0;M=-na|0;J=M&3;Z=-H|0;W=Z&3;do{if((da|0)<(J|0)|(la|0)<(W|0)){jb=354}else{if(((na<<2)+da|0)>(hb-4|0)){jb=354;break}if((oa+la|0)>(ib-4|0)){jb=354}else{Ob=ua;Pb=ja}}}while(0);if((jb|0)==354){ua=ta+(pa-J-(ba(W,ja)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,ua,80,ja,(M&7)+4|0,(Z&7)+4|0,da-J|0,la-W|0,hb,ib);Ob=(W*80|0|J)+(r+30176)|0;Pb=80}Ke[c[fa+(ra<<5)+16+(na<<3)+(H<<2)>>2]&1023](Ha,Ma,Ob,Pb,4,Ga<<1,Fa<<1)}else{ua=d[910440+Ia|0]|0;oa=d[1678848+(Ia<<1)|0]<<2;P=d[1678849+(Ia<<1)|0]<<2;O=_a+12|0;S=c[O>>2]|0;Ea=$a+384|0;Y=$a+1116|0;ia=c[Y>>2]|0;qa=c[Va>>2]|0;ma=c[Va+32>>2]|0;I=Za<<3;u=Ya<<3;U=b[_a+16>>1]|0;ha=b[_a+18>>1]|0;_=(ha>>3)+I|0;m=(U>>3)+u|0;L=(ba(_,ma)|0)+m|0;ea=qa+L|0;R=U&7;U=ha&7;ha=(U|0)!=0|0;Ba=ha<<2;V=P+7|0;ga=_+V+Ba>>6;Z0a(Wa,(ga|0)>0?ga:0,0);ga=(R|0)!=0|0;ca=-ga|0;Da=ca&3;Q=-ha|0;X=Q&3;do{if((m|0)<(Da|0)|(_|0)<(X|0)){jb=359}else{if(((ga<<2)+m|0)>(Ua-oa|0)){jb=359;break}if((Ba+_|0)>(Ta-P|0)){jb=359}else{Qb=ea;Rb=ma}}}while(0);if((jb|0)==359){ea=qa+(L-Da-(ba(X,ma)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,ea,80,ma,(ca&7)+oa|0,(Q&7)+P|0,m-Da|0,_-X|0,Ua,Ta);Qb=(X*80|0|Da)+(r+30176)|0;Rb=80}Ke[c[Ea+(ua<<7)+(S<<5)+(ga<<3)+(ha<<2)>>2]&1023](ia,Ma,Qb,Rb,P,R<<1,U<<1);if((a[Ja]|0)==0){break}ea=c[O>>2]|0;Ba=c[Y>>2]|0;Fa=c[gb>>2]|0;Ga=c[gb+32>>2]|0;Ha=b[_a+20>>1]|0;H=b[_a+22>>1]|0;na=(H>>3)+I|0;ra=(Ha>>3)+u|0;fa=(ba(na,Ga)|0)+ra|0;J=Fa+fa|0;W=Ha&7;Ha=H&7;H=(Ha|0)!=0|0;la=H<<2;da=na+V+la>>6;Z0a(fb,(da|0)>0?da:0,0);da=(W|0)!=0|0;Z=-da|0;M=Z&3;ja=-H|0;pa=ja&3;do{if((ra|0)<(M|0)|(na|0)<(pa|0)){jb=364}else{if(((da<<2)+ra|0)>(hb-oa|0)){jb=364;break}if((la+na|0)>(ib-P|0)){jb=364}else{Sb=J;Tb=Ga}}}while(0);if((jb|0)==364){J=Fa+(fa-M-(ba(pa,Ga)|0))|0;Ne[c[$a+1024>>2]&127]($a+30176|0,J,80,Ga,(Z&7)+oa|0,(ja&7)+P|0,ra-M|0,na-pa|0,hb,ib);Sb=(pa*80|0|M)+(r+30176)|0;Tb=80}Ke[c[Ea+(ua<<7)+(ea<<5)+16+(da<<3)+(H<<2)>>2]&1023](Ba,Ma,Sb,Tb,P,W<<1,Ha<<1)}}while(0);Ma=c[Xa>>2]|0;Ia=d[910453+Ma|0]|0;J=d[1678874+(Ma<<1)|0]<<2;la=d[1678875+(Ma<<1)|0]<<2;V=Ua+1>>1;u=Ta+1>>1;if((a[Ja]|0)==0){Ub=hb;Vb=ib}else{Ub=hb+1>>1;Vb=ib+1>>1}I=_a+16|0;if(Ma>>>0>9>>>0){Ma=(b[_a+24>>1]|0)+(b[I>>1]|0)+(b[_a+32>>1]|0)+(b[_a+40>>1]|0)|0;Y=(b[_a+26>>1]|0)+(b[_a+18>>1]|0)+(b[_a+34>>1]|0)+(b[_a+42>>1]|0)|0;Wb=((((Ma|0)>0?2:-2)+Ma|0)/4|0)&65535;Xb=((((Y|0)>0?2:-2)+Y|0)/4|0)&65535}else{Y=c[I>>2]|0;Wb=Y&65535;Xb=Y>>>16&65535}Y=_a+12|0;I=c[Y>>2]|0;Ma=$a+384|0;O=$a+1116|0;U=$a+1120|0;R=c[U>>2]|0;ia=$a+1124|0;ha=c[ia>>2]|0;ga=c[Va+4>>2]|0;S=c[Va+36>>2]|0;Da=c[Va+8>>2]|0;X=c[Va+40>>2]|0;_=Za<<2;m=Ya<<2;Q=Wb<<16>>16;ca=Xb<<16>>16;ma=(ca>>4)+_|0;L=(Q>>4)+m|0;qa=(ba(S,ma)|0)+L|0;ta=ga+qa|0;n=(ba(X,ma)|0)+L|0;N=Da+n|0;xa=Q&15;Q=ca&15;ca=(Q|0)!=0|0;ka=ca<<2;Aa=la+7|0;aa=ma+Aa+ka>>5;Z0a(Wa,(aa|0)>0?aa:0,0);aa=(xa|0)!=0|0;F=-aa|0;sa=F&3;K=-ca|0;G=K&3;do{if((L|0)<(sa|0)|(ma|0)<(G|0)){jb=374}else{if(((aa<<2)+L|0)>(V-J|0)){jb=374;break}if((ka+ma|0)>(u-la|0)){jb=374;break}$=Ma+(Ia<<7)+(I<<5)+(aa<<3)+(ca<<2)|0;Ke[c[$>>2]&1023](R,Ka,ta,S,la,xa,Q);Ke[c[$>>2]&1023](ha,Ka,N,X,la,xa,Q)}}while(0);if((jb|0)==374){N=$a+1024|0;ta=$a+30176|0;ka=ga+(qa-((ba(G,S)|0)+sa))|0;Wa=(F&7)+J|0;Va=(K&7)+la|0;Ta=L-sa|0;Ua=ma-G|0;Ne[c[N>>2]&127](ta,ka,80,S,Wa,Va,Ta,Ua,V,u);ka=(G*80|0|sa)+(r+30176)|0;$=Ma+(Ia<<7)+(I<<5)+(aa<<3)+(ca<<2)|0;Ke[c[$>>2]&1023](R,Ka,ka,80,la,xa,Q);T=Da+(n-((ba(X,G)|0)+sa))|0;Ne[c[N>>2]&127](ta,T,80,X,Wa,Va,Ta,Ua,V,u);Ke[c[$>>2]&1023](ha,Ka,ka,80,la,xa,Q)}b:do{if((a[Ja]|0)!=0){ka=_a+20|0;if((c[Xa>>2]|0)>>>0>9>>>0){$=(b[_a+28>>1]|0)+(b[ka>>1]|0)+(b[_a+36>>1]|0)+(b[_a+44>>1]|0)|0;Ua=(b[_a+30>>1]|0)+(b[_a+22>>1]|0)+(b[_a+38>>1]|0)+(b[_a+46>>1]|0)|0;Yb=(((($|0)>0?2:-2)+$|0)/4|0)&65535;Zb=((((Ua|0)>0?2:-2)+Ua|0)/4|0)&65535}else{Ua=c[ka>>2]|0;Yb=Ua&65535;Zb=Ua>>>16&65535}Ua=c[Y>>2]|0;ka=c[U>>2]|0;$=c[ia>>2]|0;Ta=c[gb+4>>2]|0;Va=c[gb+36>>2]|0;Wa=c[gb+8>>2]|0;T=c[gb+40>>2]|0;ta=Yb<<16>>16;N=Zb<<16>>16;Ca=(N>>4)+_|0;ya=(ta>>4)+m|0;wa=(ba(Va,Ca)|0)+ya|0;va=Ta+wa|0;Pa=(ba(T,Ca)|0)+ya|0;Oa=Wa+Pa|0;za=ta&15;ta=N&15;N=(ta|0)!=0|0;Qa=N<<2;Ra=Ca+Aa+Qa>>5;Z0a(fb,(Ra|0)>0?Ra:0,0);Ra=(za|0)!=0|0;Sa=-Ra|0;_b=Sa&3;$b=-N|0;ac=$b&3;do{if(!((ya|0)<(_b|0)|(Ca|0)<(ac|0))){if(((Ra<<2)+ya|0)>(Ub-J|0)){break}if((Qa+Ca|0)>(Vb-la|0)){break}bc=Ma+(Ia<<7)+(Ua<<5)+16+(Ra<<3)+(N<<2)|0;Ke[c[bc>>2]&1023](ka,Ka,va,Va,la,za,ta);Ke[c[bc>>2]&1023]($,Ka,Oa,T,la,za,ta);break b}}while(0);Oa=$a+1024|0;va=$a+30176|0;Qa=Ta+(wa-((ba(ac,Va)|0)+_b))|0;Ha=(Sa&7)+J|0;W=($b&7)+la|0;P=ya-_b|0;Ba=Ca-ac|0;Ne[c[Oa>>2]&127](va,Qa,80,Va,Ha,W,P,Ba,Ub,Vb);Qa=(ac*80|0|_b)+(r+30176)|0;H=Ma+(Ia<<7)+(Ua<<5)+16+(Ra<<3)+(N<<2)|0;Ke[c[H>>2]&1023](ka,Ka,Qa,80,la,za,ta);da=Wa+(Pa-((ba(T,ac)|0)+_b))|0;Ne[c[Oa>>2]&127](va,da,80,T,Ha,W,P,Ba,Ub,Vb);Ke[c[H>>2]&1023]($,Ka,Qa,80,la,za,ta)}}while(0);if((a[_a+10|0]|0)!=0){break}la=c[Xa>>2]|0;Ka=d[1678874+(la<<1)|0]<<1;Ia=_a+52|0;Ma=c[Ia>>2]|0;r=1<<Ma;J=d[1678875+(la<<1)|0]<<1;la=1<<(Ma<<1);Aa=(c[$a+1808>>2]|0)-Ya<<1;m=Aa>>>0>Ka>>>0?Ka:Aa;Aa=(c[$a+1804>>2]|0)-Za<<1;Ka=Aa>>>0>J>>>0?J:Aa;Aa=d[$a+1549|0]<<2;J=_a+56|0;_=c[J>>2]|0;Y=Aa+_|0;Ja=1<<_;Q=(Ka|0)>0;if(Q){xa=(m|0)>0;ha=$a+35896|0;u=r<<2;V=$a+240|0;X=V+(Aa+Ma<<4)|0;Aa=$a+35864|0;sa=0;G=0;n=c[O>>2]|0;while(1){c:do{if(xa){Da=sa;R=0;ca=n;while(1){aa=(c[ha>>2]|0)+Da|0;if((c[Ia>>2]|0)>>>0>1>>>0){cc=e[aa>>1]|0}else{cc=d[aa]|0}if((cc|0)!=0){cf[c[X>>2]&1023](ca,c[Na>>2]|0,(c[Aa>>2]|0)+(Da<<4<<1)|0,cc)}aa=R+r|0;I=Da+la|0;if((aa|0)>=(m|0)){dc=I;break c}Da=I;R=aa;ca=ca+u|0}}else{dc=sa}}while(0);ta=G+r|0;if((ta|0)<(Ka|0)){sa=dc;G=ta;n=n+(c[Na>>2]<<2<<Ma)|0}else{break}}ec=c[J>>2]|0;fc=V}else{ec=_;fc=$a+240|0}Ma=m>>1;Na=Ka>>1;n=1<<(ec<<1);G=(m|0)>0;sa=Ja<<2;r=fc+(Y<<4)|0;if(!Q){break}u=$a+35900|0;la=$a+35876|0;Aa=0;X=0;Ia=c[U>>2]|0;while(1){d:do{if(G){ha=Aa;xa=0;O=Ia;while(1){_a=(c[u>>2]|0)+ha|0;if((c[J>>2]|0)>>>0>1>>>0){gc=e[_a>>1]|0}else{gc=d[_a]|0}if((gc|0)!=0){cf[c[r>>2]&1023](O,c[La>>2]|0,(c[la>>2]|0)+(ha<<4<<1)|0,gc)}_a=xa+Ja|0;Za=ha+n|0;if((_a|0)>=(Ma|0)){hc=Za;break d}ha=Za;xa=_a;O=O+sa|0}}else{hc=Aa}}while(0);ic=c[La>>2]|0;O=Ia+(ba(ic,sa)|0)|0;xa=X+Ja|0;if((xa|0)<(Na|0)){Aa=hc;X=xa;Ia=O}else{break}}Ia=$a+35904|0;X=$a+35880|0;Aa=0;la=0;u=c[ia>>2]|0;U=ic;while(1){if(G){Q=Aa;Y=0;m=u;while(1){Ka=(c[Ia>>2]|0)+Q|0;if((c[J>>2]|0)>>>0>1>>>0){jc=e[Ka>>1]|0}else{jc=d[Ka]|0}if((jc|0)!=0){cf[c[r>>2]&1023](m,c[La>>2]|0,(c[X>>2]|0)+(Q<<4<<1)|0,jc)}Ka=Y+Ja|0;kc=Q+n|0;if((Ka|0)>=(Ma|0)){break}Q=kc;Y=Ka;m=m+sa|0}lc=kc;mc=c[La>>2]|0}else{lc=Aa;mc=U}m=u+(ba(mc,sa)|0)|0;Y=la+Ja|0;if((Y|0)<(Na|0)){Aa=lc;la=Y;u=m;U=mc}else{break}}}else{U=q|0;u=$a;la=c[$a+1084>>2]|0;Aa=c[$a+1100>>2]|0;Na=c[$a+1108>>2]|0;Ja=la+48|0;sa=c[Ja>>2]|0;La=d[1678874+(sa<<1)|0]|0;Ma=La<<1;n=la+52|0;X=c[n>>2]|0;r=1<<X;J=d[1678875+(sa<<1)|0]<<1;sa=1<<(X<<1);Ia=$a+1808|0;G=(c[Ia>>2]|0)-Na<<1;ia=G>>>0>Ma>>>0?Ma:G;G=$a+1804|0;m=(c[G>>2]|0)-Aa<<1;Y=m>>>0>J>>>0?J:m;m=d[$a+1549|0]<<2;J=m+X|0;X=la+56|0;Q=c[X>>2]|0;Ka=m+Q|0;m=1<<Q;_=$a+1116|0;V=_;O=$a+1360|0;xa=(Y|0)>0;if(xa){ha=c[O>>2]|0;_a=(ia|0)>0;Za=r<<2;Ya=$a+1128|0;Xa=p+16|0;ta=la+10|0;za=$a+35896|0;$=(Aa|0)>0;T=$a+1788|0;_b=Ma-1|0;Ma=$a;ac=$a+240|0;Pa=$a+35864|0;Wa=Aa&7;ka=$a+30148|0;N=Na<<3;Ra=p+20|0;Ua=Ra;Va=p+19|0;Ca=p+15|0;ya=c[_>>2]|0;_=(c[ha>>2]|0)+k|0;$b=0;Sa=0;wa=ha;while(1){if(_a){ha=$b<<1;Ta=$|($b|0)>0;ca=Ta&1;R=($b|0)==0;Da=($b|Wa|0)==0;aa=Ta?-127:127;I=0;S=ya;ma=_;L=Sa;while(1){K=c[n>>2]|0;if((c[Ja>>2]|0)>>>0>9>>>0){nc=(K|0)==0?I+ha|0:0}else{nc=0}F=d[la+5+nc|0]|0;qa=c[108584+(F<<2)>>2]|0;do{if((a[ta]|0)==0){ga=(c[za>>2]|0)+L|0;if(K>>>0>1>>>0){oc=e[ga>>1]|0;break}else{oc=d[ga]|0;break}}else{oc=0}}while(0);ga=c[(c[O>>2]|0)+32>>2]|0;Qa=c[Ya>>2]|0;H=(c[T>>2]|0)>>>0<Na>>>0|(I|0)>0;Ba=(_b|0)>(I|0);P=a[1488128+(F<<2)+((H&1)<<1)+ca|0]|0;W=P&255;e:do{if((2813>>>(W>>>0)&1|0)==0){pc=Xa}else{Ha=4<<K;da=((c[Ia>>2]|0)-Na<<1)-I<<2;va=(K|0)==0;do{if(va){if(!((P<<24>>24|0)==7|(P<<24>>24|0)==3)){qc=0;break}qc=Ba?4:0}else{qc=0}}while(0);do{if(Ta){do{if(Da){rc=(c[ka>>2]|0)+((I<<2)+N)|0}else{if(R){rc=ma+(-ga|0)|0;break}else{rc=S+(-Qa|0)|0;break}}}while(0);do{if(H){if(Da){sc=(c[ka>>2]|0)+((I<<2)+N)|0;break}if(R|(I|0)==0){sc=ma+(-ga|0)|0;break}else{sc=S+(-Qa|0)|0;break}}else{sc=0}}while(0);Oa=624>>>(W>>>0)&1;if((Oa|0)==0){jb=183}else{if(H&(rc|0)==(sc|0)){jb=183}}f:do{if((jb|0)==183){jb=0;do{if(va){if(!((P<<24>>24|0)==7|(P<<24>>24|0)==3)){break}if(!Ba){break f}}}while(0);if((qc+Ha|0)<=(da|0)){pc=rc;break e}}}while(0);if((Ha|0)>(da|0)){UGb(Xa|0,rc|0,da)|0;TGb(p+(da+16)|0,a[p+(da+15)|0]|0,Ha-da|0)|0;tc=sc;uc=rc;vc=Oa;break}else{UGb(Xa|0,rc|0,Ha)|0;tc=sc;uc=rc;vc=Oa;break}}else{TGb(Xa|0,127,Ha|0)|0;tc=0;uc=0;vc=624>>>(W>>>0)&1}}while(0);do{if((vc|0)!=0){if(H&Ta){a[Ca]=a[tc-1|0]|0;break}else{a[Ca]=aa;break}}}while(0);if(!va){pc=Xa;break}if(!((P<<24>>24|0)==7|(P<<24>>24|0)==3)){pc=Xa;break}do{if(Ta&Ba){if((qc+Ha|0)>(da|0)){break}ea=uc+4|0;c[Ua>>2]=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24;pc=Xa;break e}}while(0);TGb(Ra|0,a[Va]|0,4)|0;pc=Xa}}while(0);g:do{if((1910>>>(W>>>0)&1|0)!=0){Ba=4<<K;if(!H){TGb(U|0,-127|0,Ba|0)|0;break}P=((c[G>>2]|0)-Aa<<1)-$b<<2;F=(I|0)==0;da=F?ma:S;Ha=F?ga:Qa;if((Ba|0)<=(P|0)){if((Ba|0)<=0){break}F=Ba-1|0;va=0;while(1){a[q+(F-va)|0]=a[da+((ba(va,Ha)|0)-1)|0]|0;va=va+1|0;if((va|0)>=(Ba|0)){break g}}}if((P|0)>0){va=Ba-1|0;F=0;do{a[q+(va-F)|0]=a[da+((ba(F,Ha)|0)-1)|0]|0;F=F+1|0;}while((F|0)<(P|0))}F=Ba-P|0;TGb(U|0,a[q+F|0]|0,F|0)|0}}while(0);cf[c[Ma+((c[n>>2]|0)*60|0)+(W<<2)>>2]&1023](S,Qa,U,pc);if((oc|0)!=0){cf[c[ac+(J<<4)+(qa<<2)>>2]&1023](S,c[Ya>>2]|0,(c[Pa>>2]|0)+(L<<4<<1)|0,oc)}ga=I+r|0;wc=L+sa|0;if((ga|0)>=(ia|0)){break}I=ga;S=S+Za|0;ma=ma+Za|0;L=wc}xc=wc;yc=c[O>>2]|0}else{xc=Sa;yc=wa}L=_+(ba(c[yc+32>>2]|0,Za)|0)|0;ma=ya+(ba(c[Ya>>2]|0,Za)|0)|0;S=$b+r|0;if((S|0)<(Y|0)){ya=ma;_=L;$b=S;Sa=xc;wa=yc}else{break}}zc=c[X>>2]|0;Ac=Xa;Bc=ta;Cc=T;Dc=Ma;Ec=ac;Fc=Wa;Gc=Ra;Hc=Ua;Ic=Va;Jc=Ca}else{wa=p+20|0;zc=Q;Ac=p+16|0;Bc=la+10|0;Cc=$a+1788|0;Dc=$a;Ec=$a+240|0;Fc=Aa&7;Gc=wa;Hc=wa;Ic=p+19|0;Jc=p+15|0}wa=ia>>1;Sa=Y>>1;$b=1<<(zc<<1);_=(ia|0)>0;ya=m<<2;r=$a+1132|0;Za=la+9|0;Ya=$a+35900|0;sa=(Aa|0)>0;Pa=La-1|0;J=Ec+(Ka<<4)|0;n=$a+35876|0;N=Na<<2;ka=0;while(1){_b=ka+1|0;if(xa){za=c[O>>2]|0;Ja=Ya+(ka<<2)|0;$=n+(ka<<2)|0;_a=u+30148+(_b<<2)|0;S=c[V+(_b<<2)>>2]|0;L=(c[za+(_b<<2)>>2]|0)+l|0;ma=0;I=0;Ta=za;while(1){if(_){za=sa|(ma|0)>0;aa=za&1;R=(ma|0)==0;Da=(ma|Fc|0)==0;ca=za?-127:127;ha=ma+Aa|0;ga=0;H=I;K=S;F=L;while(1){Ha=d[Za]|0;da=c[X>>2]|0;do{if((a[Bc]|0)==0){va=(c[Ja>>2]|0)+H|0;if(da>>>0>1>>>0){Kc=e[va>>1]|0;break}else{Kc=d[va]|0;break}}else{Kc=0}}while(0);P=c[(c[O>>2]|0)+36>>2]|0;Ba=c[r>>2]|0;va=(c[Cc>>2]|0)>>>0<Na>>>0|(ga|0)>0;ea=(Pa|0)>(ga|0);ua=a[1488128+(Ha<<2)+((va&1)<<1)+aa|0]|0;Ea=ua&255;h:do{if((2813>>>(Ea>>>0)&1|0)==0){Lc=Ac}else{M=4<<da;pa=(c[Ia>>2]|0)-(ga+Na)<<2;na=(da|0)==0;do{if(na){if(!((ua<<24>>24|0)==7|(ua<<24>>24|0)==3)){Mc=0;break}Mc=ea?4:0}else{Mc=0}}while(0);do{if(za){do{if(Da){Nc=(c[_a>>2]|0)+((ga<<2)+N)|0}else{if(R){Nc=F+(-P|0)|0;break}else{Nc=K+(-Ba|0)|0;break}}}while(0);do{if(va){if(Da){Oc=(c[_a>>2]|0)+((ga<<2)+N)|0;break}if(R|(ga|0)==0){Oc=F+(-P|0)|0;break}else{Oc=K+(-Ba|0)|0;break}}else{Oc=0}}while(0);Oa=624>>>(Ea>>>0)&1;if((Oa|0)==0){jb=247}else{if(va&(Nc|0)==(Oc|0)){jb=247}}i:do{if((jb|0)==247){jb=0;do{if(na){if(!((ua<<24>>24|0)==7|(ua<<24>>24|0)==3)){break}if(!ea){break i}}}while(0);if((Mc+M|0)<=(pa|0)){Lc=Nc;break h}}}while(0);if((M|0)>(pa|0)){UGb(Ac|0,Nc|0,pa)|0;TGb(p+(pa+16)|0,a[p+(pa+15)|0]|0,M-pa|0)|0;Pc=Oc;Qc=Nc;Rc=Oa;break}else{UGb(Ac|0,Nc|0,M)|0;Pc=Oc;Qc=Nc;Rc=Oa;break}}else{TGb(Ac|0,127,M|0)|0;Pc=0;Qc=0;Rc=624>>>(Ea>>>0)&1}}while(0);do{if((Rc|0)!=0){if(va&za){a[Jc]=a[Pc-1|0]|0;break}else{a[Jc]=ca;break}}}while(0);if(!na){Lc=Ac;break}if(!((ua<<24>>24|0)==7|(ua<<24>>24|0)==3)){Lc=Ac;break}do{if(za&ea){if((Mc+M|0)>(pa|0)){break}ra=Qc+4|0;c[Hc>>2]=d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24;Lc=Ac;break h}}while(0);TGb(Gc|0,a[Ic]|0,4)|0;Lc=Ac}}while(0);j:do{if((1910>>>(Ea>>>0)&1|0)!=0){ea=4<<da;if(!va){TGb(U|0,-127|0,ea|0)|0;break}ua=(c[G>>2]|0)-ha<<2;Ha=(ga|0)==0;pa=Ha?F:K;M=Ha?P:Ba;if((ea|0)<=(ua|0)){if((ea|0)<=0){break}Ha=ea-1|0;na=0;while(1){a[q+(Ha-na)|0]=a[pa+((ba(na,M)|0)-1)|0]|0;na=na+1|0;if((na|0)>=(ea|0)){break j}}}if((ua|0)>0){na=ea-1|0;Ha=0;do{a[q+(na-Ha)|0]=a[pa+((ba(Ha,M)|0)-1)|0]|0;Ha=Ha+1|0;}while((Ha|0)<(ua|0))}Ha=ea-ua|0;TGb(U|0,a[q+Ha|0]|0,Ha|0)|0}}while(0);cf[c[Dc+((c[X>>2]|0)*60|0)+(Ea<<2)>>2]&1023](K,Ba,U,Lc);if((Kc|0)!=0){cf[c[J>>2]&1023](K,c[r>>2]|0,(c[$>>2]|0)+(H<<4<<1)|0,Kc)}P=ga+m|0;Sc=H+$b|0;if((P|0)<(wa|0)){ga=P;H=Sc;K=K+ya|0;F=F+ya|0}else{break}}Tc=Sc;Uc=c[O>>2]|0}else{Tc=I;Uc=Ta}F=L+(ba(c[Uc+36>>2]|0,ya)|0)|0;K=S+(ba(c[r>>2]|0,ya)|0)|0;H=ma+m|0;if((H|0)<(Sa|0)){S=K;L=F;ma=H;I=Tc;Ta=Uc}else{break}}}if((_b|0)<2){ka=_b}else{break}}}}while(0);do{if(db){Uc=(c[A>>2]|0)-h|0;Tc=(Uc>>>0>v>>>0?v:Uc)<<3;Uc=(c[C>>2]|0)-g|0;Sc=(Uc>>>0>w>>>0?w:Uc)<<3;if((Tc|0)<=0){break}Uc=f+384|0;Kc=x|0;Lc=0;Dc=0;while(1){q=64>>>(Dc>>>0);if((q&Tc|0)==0){Vc=Lc}else{Ke[c[Uc+(Dc<<7)>>2]&1023]((c[Kc>>2]|0)+(Lc+k)|0,c[cb>>2]|0,f+(Lc+35936)|0,64,Sc,0,0);Vc=q+Lc|0}if((Vc|0)<(Tc|0)){Lc=Vc;Dc=Dc+1|0}else{break}}}}while(0);do{if(eb){Vc=(c[A>>2]|0)-h|0;cb=(Vc>>>0>v>>>0?v:Vc)<<2;Vc=(c[C>>2]|0)-g|0;k=(Vc>>>0>w>>>0?w:Vc)<<2;if((cb|0)<=0){break}Vc=f+384|0;db=x+4|0;Dc=x+8|0;Lc=x+40|0;Tc=0;Sc=1;while(1){Kc=64>>>(Sc>>>0);if((Kc&cb|0)==0){Wc=Tc}else{Uc=Vc+(Sc<<7)|0;q=Tc+l|0;Ke[c[Uc>>2]&1023]((c[db>>2]|0)+q|0,c[ab>>2]|0,f+(Tc+40032)|0,32,k,0,0);Ke[c[Uc>>2]&1023]((c[Dc>>2]|0)+q|0,c[Lc>>2]|0,f+(Tc+41056)|0,32,k,0,0);Wc=Kc+Tc|0}if((Wc|0)<(cb|0)){Tc=Wc;Sc=Sc+1|0}else{break}}}}while(0);do{if((a[f+1408|0]|0)!=0){Wc=(a[bb]|0)==0;if(Wc){Xc=(d[t+3|0]|0)+1|0}else{Xc=0}ab=a[((a[t+8|0]|0)!=12)+(f+1554+((d[t|0]|0)*26|0)+18+(Xc<<1))|0]|0;l=ab&255;if(ab<<24>>24==0){break}x=(c[A>>2]|0)-h|0;eb=x>>>0>v>>>0?v:x;x=(c[C>>2]|0)-g|0;Sc=x>>>0>w>>>0?w:x;if(Wc){Yc=(a[t+10|0]|0)!=0|0}else{Yc=0}Wc=c[z>>2]|0;x=c[y>>2]|0;Tc=j+((x<<3)+Wc)|0;if((v|0)==1){cb=Tc;k=w;while(1){a[cb]=ab;Lc=k-1|0;if((Lc|0)==0){break}else{cb=cb+8|0;k=Lc}}}else if((v|0)==2){k=(l*257|0)&65535;cb=Tc;ab=w;while(1){b[cb>>1]=k;Lc=ab-1|0;if((Lc|0)==0){break}else{cb=cb+8|0;ab=Lc}}}else if((v|0)==4){ab=ba(l,16843009)|0;cb=Tc;k=w;while(1){c[cb>>2]=ab;Lc=k-1|0;if((Lc|0)==0){break}else{cb=cb+8|0;k=Lc}}}else if((v|0)==8){k=ba(l,16843009)|0;cb=Tc;ab=w;while(1){c[cb>>2]=k;c[cb+4>>2]=k;Lc=ab-1|0;if((Lc|0)==0){break}else{cb=cb+8|0;ab=Lc}}}ab=c[t+52>>2]|0;cb=1<<Wc;k=(cb<<eb)-cb|0;k:do{if((ab|Yc|0)==0){Tc=k&17;Lc=k-Tc|0;Dc=x+Sc|0;if((Sc|0)>0){Zc=x}else{break}do{db=j+64+(Zc<<2)+1|0;a[db]=d[db]|Tc;db=j+64+(Zc<<2)+2|0;a[db]=d[db]|Lc;db=2-((Zc&3|0)==0)+(j+96+(Zc<<2))|0;a[db]=d[db]|k;db=j+64+(Zc<<2)+3|0;a[db]=d[db]|k;db=j+96+(Zc<<2)+3|0;a[db]=d[db]|k;Zc=Zc+1|0;}while((Zc|0)<(Dc|0))}else{if((Yc|0)==0){Dc=(ab|0)==1|0;Lc=ab-1|0;Tc=1<<Lc;_b=c[684744+(Lc<<2)>>2]&k;Lc=x+Sc|0;if((Sc|0)>0){_c=x}else{break}while(1){db=j+64+(_c<<2)+Dc|0;a[db]=d[db]|_b;db=_c+1|0;if((db|0)<(Lc|0)){_c=db}else{$c=x;break}}while(1){_b=j+96+($c<<2)+Dc|0;a[_b]=d[_b]|k;$c=$c+Tc|0;if(($c|0)>=(Lc|0)){break k}}}if((ab|0)==1){Lc=j+96+(x<<2)+1|0;a[Lc]=d[Lc]|k;ad=1}else if((ab|0)==0){Lc=cb&17;Tc=cb-Lc|0;Dc=x+Sc|0;if((Sc|0)>0){_b=x;do{db=j+64+(_b<<2)+2|0;a[db]=d[db]|Tc;db=j+64+(_b<<2)+1|0;a[db]=d[db]|Lc;_b=_b+1|0;}while((_b|0)<(Dc|0))}Dc=2-((x&3|0)==0)+(j+96+(x<<2))|0;a[Dc]=d[Dc]|k;break}else{Dc=j+96+(x<<2)|0;a[Dc]=d[Dc]|k;ad=0}Dc=x+Sc|0;if((Sc|0)>0){bd=x}else{break}do{_b=j+64+(bd<<2)+ad|0;a[_b]=d[_b]|cb;bd=bd+1|0;}while((bd|0)<(Dc|0))}}while(0);k=c[A>>2]|0;ab=(k&1|0)==0|B>>>0<k>>>0?0:k&7;k=c[C>>2]|0;if((k&1|0)==0){cd=0}else{cd=D>>>0<k>>>0?0:k&7}k=c[t+56>>2]|0;Dc=(k|0)==0;do{if(Dc){if((Sc|0)==1){if((x&1|0)!=0){break}dd=(cd|0)==0?2:1}else{dd=Sc}if((eb|0)!=1){ed=eb;fd=dd;jb=471;break}if((Wc&1|0)!=0){break}ed=(ab|0)==0?2:1;fd=dd;jb=471}else{ed=eb;fd=Sc;jb=471}}while(0);l:do{if((jb|0)==471){Sc=(cb<<ed)-cb|0;if((k|Yc|0)==0){eb=(cb<<ed-1)-cb|0;_b=Sc&1;Lc=Sc-_b|0;Tc=fd+x|0;if((fd|0)<=0){break}db=(ab&1|0)==0;Vc=x;while(1){Kc=2-((Vc&7|0)==0)|0;q=j+128+(Vc<<2)+1|0;a[q]=d[q]|_b;q=j+128+(Vc<<2)+2|0;a[q]=d[q]|Lc;do{if(db){jb=477}else{if((Vc&1|0)==0){jb=477;break}q=j+160+(Vc<<2)+Kc|0;a[q]=d[q]|eb}}while(0);if((jb|0)==477){jb=0;q=j+160+(Vc<<2)+Kc|0;a[q]=d[q]|Sc}Vc=Vc+1|0;if((Vc|0)>=(Tc|0)){break l}}}if((Yc|0)!=0){if(Dc){Tc=(Wc|0)==0|0;Vc=cb-Tc|0;eb=fd+x|0;if((fd|0)>0){db=x;do{Lc=j+128+(db<<2)+2|0;a[Lc]=d[Lc]|Vc;Lc=j+128+(db<<2)+1|0;a[Lc]=d[Lc]|Tc;db=db+1|0;}while((db|0)<(eb|0))}eb=2-((x&7|0)==0)+(j+160+(x<<2))|0;a[eb]=d[eb]|Sc;break}if((k|0)==1){eb=j+160+(x<<2)+1|0;a[eb]=d[eb]|Sc;gd=1}else{eb=((fd|0)==1)+(j+160+(x<<2))|0;a[eb]=d[eb]|Sc;gd=(ed|0)==1|0}eb=fd+x|0;if((fd|0)>0){hd=x}else{break}while(1){db=j+128+(hd<<2)+gd|0;a[db]=d[db]|cb;hd=hd+1|0;if((hd|0)>=(eb|0)){break l}}}eb=(k|0)==1|0;db=1<<k;Tc=c[684744+(k<<2)>>2]|0;Vc=Tc&Sc;Lc=k>>>0>1>>>0;do{if(Lc){_b=ed-1|0;if((_b^ed|0)!=1){jb=481;break}q=Tc&(cb<<_b)-cb;_b=Vc-q|0;Uc=fd+x|0;if((fd|0)>0){id=x}else{jb=488;break}while(1){Ac=j+128+(id<<2)|0;a[Ac]=d[Ac]|q;Ac=j+128+(id<<2)+1|0;a[Ac]=d[Ac]|_b;Ac=id+1|0;if((Ac|0)<(Uc|0)){id=Ac}else{jb=486;break}}}else{jb=481}}while(0);do{if((jb|0)==481){Tc=fd+x|0;if((fd|0)>0){jd=x}else{jb=486;break}while(1){Uc=j+128+(jd<<2)+eb|0;a[Uc]=d[Uc]|Vc;Uc=jd+1|0;if((Uc|0)<(Tc|0)){jd=Uc}else{jb=486;break}}}}while(0);if((jb|0)==486){if(Lc){jb=488}}do{if((jb|0)==488){Vc=fd-1|0;if((Vc^fd|0)!=1){break}Tc=x-1+fd|0;if((Tc|0)>(x|0)){Uc=x;while(1){_b=j+160+(Uc<<2)|0;a[_b]=d[_b]|Sc;_b=Uc+db|0;if((_b|0)<(Tc|0)){Uc=_b}else{kd=_b;break}}}else{kd=x}if((kd-x|0)!=(Vc|0)){break l}Uc=j+160+(kd<<2)+1|0;a[Uc]=d[Uc]|Sc;break l}}while(0);Lc=fd+x|0;if((fd|0)>0){ld=x}else{break}do{Uc=j+160+(ld<<2)+eb|0;a[Uc]=d[Uc]|Sc;ld=ld+db|0;}while((ld|0)<(Lc|0))}}while(0);x=f+(l+1410)|0;if((a[x]|0)!=0){break}cb=a[f+1409|0]|0;k=cb<<24>>24;if(cb<<24>>24>0){cb=l>>>(k+3>>2>>>0);Wc=9-k|0;md=(cb|0)>(Wc|0)?Wc:cb}else{md=l}cb=(md|0)>1?md:1;a[x]=cb;a[f+(l+1474)|0]=(l<<1)+4+cb}}while(0);if((c[E>>2]|0)!=2){i=o;return}c[s>>2]=(c[s>>2]|0)+68;s=ba(w,v)|0;E=f+35864|0;c[E>>2]=(c[E>>2]|0)+(s<<6<<1);E=s<<4;md=f+35876|0;c[md>>2]=(c[md>>2]|0)+(E<<1);md=f+35880|0;c[md>>2]=(c[md>>2]|0)+(E<<1);E=ba(v<<2,w)|0;w=f+35896|0;c[w>>2]=(c[w>>2]|0)+E;E=f+35900|0;c[E>>2]=(c[E>>2]|0)+s;E=f+35904|0;c[E>>2]=(c[E>>2]|0)+s;i=o;return}function L6a(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0;f=e;g=c[e+1084>>2]|0;h=c[e+1100>>2]|0;i=c[e+1108>>2]|0;j=c[e+1104>>2]|0;k=g+48|0;l=c[k>>2]|0;m=d[1403e3+l|0]|0;n=(c[e+1808>>2]|0)-i|0;o=d[1678874+(l<<1)|0]|0;p=n>>>0>o>>>0?o:n;n=(c[e+1804>>2]|0)-h|0;o=d[1678875+(l<<1)|0]|0;l=n>>>0>o>>>0?o:n;n=(h|0)>0;o=i>>>0>(c[e+1788>>2]|0)>>>0;q=e+1550|0;a:do{if((a[q]|0)==0){a[g|0]=0}else{do{if((a[e+1137|0]|0)==0){if((a[e+1144|0]|0)!=0){break}b:do{if((a[e+1553|0]|0)!=0){r=e+1052|0;do{if((a[e+1551|0]|0)==0){s=c[r>>2]|0;t=c[e+1056>>2]|0;u=c[e+1068>>2]|0}else{v=d[e+((d[(c[e+30124>>2]|0)+i|0]|0)+16622+(d[e+(j+30056)|0]|0))|0]|0;w=r;y=c[w>>2]|0;z=d[1086680+y|0]|0;A=e+1056|0;B=c[A>>2]|0;C=e+1068|0;D=c[C>>2]|0;E=y<<z;c[w>>2]=E;y=D<<z;D=B+z|0;do{if((D|0)>-1){z=e+1060|0;B=c[z>>2]|0;if(!(B>>>0<(c[e+1064>>2]|0)>>>0)){F=y;G=D;break}c[z>>2]=B+2;z=B;F=((de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<D|y;G=D-16|0}else{F=y;G=D}}while(0);c[A>>2]=G;D=((ba(E-1|0,v)|0)>>8)+1|0;y=D<<16;if(F>>>0<y>>>0){c[w>>2]=D;c[C>>2]=F;s=D;t=G;u=F;break}else{c[w>>2]=E-D;c[C>>2]=F-y;break b}}}while(0);r=e+1052|0;y=e+1056|0;D=e+1068|0;z=e+1060|0;B=e+1064|0;H=0;I=s;J=t;K=u;while(1){L=a[e+(H+16615)|0]|0;M=d[1086680+I|0]|0;N=I<<M;c[r>>2]=N;O=K<<M;P=M+J|0;do{if((P|0)>-1){M=c[z>>2]|0;if(!(M>>>0<(c[B>>2]|0)>>>0)){Q=O;R=P;break}c[z>>2]=M+2;S=M;Q=((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)<<P|O;R=P-16|0}else{Q=O;R=P}}while(0);c[y>>2]=R;P=((ba(N-1|0,L&255)|0)>>8)+1|0;O=P<<16;C=Q>>>0>=O>>>0;E=C?N-P|0:P;c[r>>2]=E;P=Q-(C?O:0)|0;c[D>>2]=P;T=a[(C&1)+(104272+(H<<1))|0]|0;if(T<<24>>24>0){H=T<<24>>24;I=E;J=R;K=P}else{break}}a[g|0]=-T;TGb((c[e+30124>>2]|0)+i|0,0,p|0)|0;TGb(e+(j+30056)|0,0,l|0)|0;break a}}while(0);K=c[e+1400>>2]|0;if((c[e+1096>>2]|0)==0){Z0a(e+1384|0,h>>3,0)}do{if((l|0)>0){J=e+1796|0;if((p|0)>0){U=8;V=0}else{W=8;break}while(1){I=ba(V+h<<3,c[J>>2]|0)|0;H=0;X=U;do{D=d[K+(H+i+I)|0]|0;X=(X|0)>(D|0)?D:X;H=H+1|0;}while((H|0)<(p|0));H=V+1|0;if((H|0)<(l|0)){U=X;V=H}else{break}}W=X&255}else{W=8}}while(0);a[g|0]=W;TGb((c[e+30124>>2]|0)+i|0,1,p|0)|0;TGb(e+(j+30056)|0,1,l|0)|0;break a}}while(0);K=e+1052|0;J=e+1056|0;H=e+1068|0;I=e+1060|0;N=e+1064|0;L=0;D=c[K>>2]|0;r=c[J>>2]|0;y=c[H>>2]|0;while(1){z=a[e+(L+16615)|0]|0;B=d[1086680+D|0]|0;P=D<<B;c[K>>2]=P;E=y<<B;C=B+r|0;do{if((C|0)>-1){B=c[I>>2]|0;if(!(B>>>0<(c[N>>2]|0)>>>0)){Y=E;Z=C;break}c[I>>2]=B+2;O=B;Y=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<C|E;Z=C-16|0}else{Y=E;Z=C}}while(0);c[J>>2]=Z;C=((ba(P-1|0,z&255)|0)>>8)+1|0;E=C<<16;O=Y>>>0>=E>>>0;B=O?P-C|0:C;c[K>>2]=B;C=Y-(O?E:0)|0;c[H>>2]=C;_=a[(O&1)+(104272+(L<<1))|0]|0;if(_<<24>>24>0){L=_<<24>>24;D=B;r=Z;y=C}else{break}}a[g|0]=-_}}while(0);do{if((a[q]|0)==0){$=48}else{do{if((a[e+1553|0]|0)==0){if((a[e+1137|0]|0)!=0){$=39;break}if((a[e+1144|0]|0)!=0){$=39}}else{$=39}}while(0);do{if(($|0)==39){_=c[e+1796>>2]|0;Z=(ba(h<<3,_)|0)+i|0;Y=(c[e+1376>>2]|0)+Z|0;Z=_<<3;_=a[g|0]|0;W=_&255;if((p|0)==1){X=Y;V=l;while(1){a[X]=_;U=V-1|0;if((U|0)==0){break}else{X=X+Z|0;V=U}}}else if((p|0)==2){V=(W*257|0)&65535;X=Y;_=l;while(1){b[X>>1]=V;P=_-1|0;if((P|0)==0){break}else{X=X+Z|0;_=P}}}else if((p|0)==4){_=ba(W,16843009)|0;X=Y;V=l;while(1){c[X>>2]=_;P=V-1|0;if((P|0)==0){break}else{X=X+Z|0;V=P}}}else if((p|0)==8){V=ba(W,16843009)|0;X=Y;_=l;while(1){c[X>>2]=V;c[X+4>>2]=V;P=_-1|0;if((P|0)==0){break}else{X=X+Z|0;_=P}}}else{break}}}while(0);if((a[q]|0)==0){$=48;break}_=(a[e+1554+((d[g|0]|0)*26|0)+3|0]|0)!=0;Z=g+10|0;a[Z]=_&1;if(_){aa=Z}else{ca=Z;$=50}}}while(0);if(($|0)==48){q=g+10|0;a[q]=0;ca=q;$=50}if(($|0)==50){q=(d[(c[e+30116>>2]|0)+i|0]|0)+(d[e+(j+30040)|0]|0)|0;Z=a[e+(q+10159)|0]|0;_=e+1052|0;X=c[_>>2]|0;V=d[1086680+X|0]|0;Y=e+1056|0;W=c[Y>>2]|0;P=e+1068|0;z=c[P>>2]|0;U=X<<V;c[_>>2]=U;X=z<<V;z=W+V|0;do{if((z|0)>-1){V=e+1060|0;W=c[V>>2]|0;if(!(W>>>0<(c[e+1064>>2]|0)>>>0)){da=X;ea=z;break}c[V>>2]=W+2;V=W;da=((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<z|X;ea=z-16|0}else{da=X;ea=z}}while(0);c[Y>>2]=ea;ea=((ba(U-1|0,Z&255)|0)>>8)+1|0;Z=ea<<16;Y=da>>>0>=Z>>>0;c[_>>2]=Y?U-ea|0:ea;c[P>>2]=da-(Y?Z:0);a[ca]=Y&1;Z=e+17612+(q<<3)+((Y&1)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;aa=ca}ca=e+1137|0;do{if((a[ca]|0)==0){if((a[e+1144|0]|0)!=0){$=56;break}Z=d[g|0]|0;Y=e+1554|0;if((a[Y+(Z*26|0)+2|0]|0)==0){do{if(n&o){q=(d[e+(j+30064)|0]|0)+(d[(c[e+30128>>2]|0)+i|0]|0)|0;fa=((q|0)==2)+q|0}else{if(n){fa=d[(c[e+30128>>2]|0)+i|0]<<1;break}if(!o){fa=0;break}fa=d[e+(j+30064)|0]<<1}}while(0);q=a[e+(fa+10123)|0]|0;da=e+1052|0;P=c[da>>2]|0;ea=d[1086680+P|0]|0;U=e+1056|0;_=c[U>>2]|0;z=e+1068|0;X=c[z>>2]|0;V=P<<ea;c[da>>2]=V;P=X<<ea;X=_+ea|0;do{if((X|0)>-1){ea=e+1060|0;_=c[ea>>2]|0;if(!(_>>>0<(c[e+1064>>2]|0)>>>0)){ga=P;ha=X;break}c[ea>>2]=_+2;ea=_;ga=((de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<X|P;ha=X-16|0}else{ga=P;ha=X}}while(0);c[U>>2]=ha;X=((ba(V-1|0,q&255)|0)>>8)+1|0;P=X<<16;ea=ga>>>0>=P>>>0;c[da>>2]=ea?V-X|0:X;c[z>>2]=ga-(ea?P:0);P=e+17348+(fa<<3)+((ea&1)<<2)|0;c[P>>2]=(c[P>>2]|0)+1;P=ea&1^1;a[g+1|0]=P;ia=P}else{P=(a[Y+(Z*26|0)+4|0]|0)==0|0;a[g+1|0]=P;ia=P}P=g+1|0;if(!(ia<<24>>24==0)){ja=P;$=72;break}if((a[aa]|0)==0){ja=P;$=72;break}ka=c[e+29836>>2]|0;la=P;$=113}else{$=56}}while(0);if(($|0)==56){a[g+1|0]=1;ja=g+1|0;$=72}do{if(($|0)==72){ia=c[e+29836>>2]|0;if((ia|0)!=4){ka=ia;la=ja;$=113;break}do{if(n){ia=(a[(c[e+30116>>2]|0)+i|0]|0)!=0;if(!o){if(ia){ma=1;break}ma=d[(c[e+30120>>2]|0)+i|0]<<1>>>0>m>>>0|0;break}if(ia){na=m}else{na=d[(c[e+30120>>2]|0)+i|0]|0}if((a[e+(j+30040)|0]|0)==0){oa=d[e+(j+30048)|0]|0}else{oa=m}ma=(oa+na|0)>>>0>m>>>0|0}else{if(!o){ma=1;break}if((a[e+(j+30040)|0]|0)!=0){ma=1;break}ma=d[e+(j+30048)|0]<<1>>>0>m>>>0|0}}while(0);if((m|0)==3){Z=e+10147|0;Y=a[Z+(ma*3|0)|0]|0;z=e+1052|0;V=c[z>>2]|0;da=d[1086680+V|0]|0;q=e+1056|0;U=c[q>>2]|0;ia=e+1068|0;fa=c[ia>>2]|0;ga=V<<da;c[z>>2]=ga;V=fa<<da;fa=U+da|0;do{if((fa|0)>-1){da=e+1060|0;U=c[da>>2]|0;if(!(U>>>0<(c[e+1064>>2]|0)>>>0)){pa=V;qa=fa;break}c[da>>2]=U+2;da=U;pa=((de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|V;qa=fa-16|0}else{pa=V;qa=fa}}while(0);c[q>>2]=qa;fa=((ba(ga-1|0,Y&255)|0)>>8)+1|0;V=fa<<16;da=pa>>>0>=V>>>0;U=da&1;ha=da?ga-fa|0:fa;c[z>>2]=ha;fa=pa-(da?V:0)|0;c[ia>>2]=fa;V=g+52|0;c[V>>2]=U;do{if(da){P=a[Z+(ma*3|0)+1|0]|0;ea=d[1086680+ha|0]|0;X=ha<<ea;c[z>>2]=X;_=fa<<ea;W=qa+ea|0;do{if((W|0)>-1){ea=e+1060|0;T=c[ea>>2]|0;if(!(T>>>0<(c[e+1064>>2]|0)>>>0)){ra=_;sa=W;break}c[ea>>2]=T+2;ea=T;ra=((de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<W|_;sa=W-16|0}else{ra=_;sa=W}}while(0);c[q>>2]=sa;W=((ba(X-1|0,P&255)|0)>>8)+1|0;_=W<<16;ea=ra>>>0>=_>>>0;T=ea?X-W|0:W;c[z>>2]=T;W=ra-(ea?_:0)|0;c[ia>>2]=W;_=(ea&1)+U|0;c[V>>2]=_;if((_|0)!=2){ta=_;break}_=a[Z+(ma*3|0)+2|0]|0;ea=d[1086680+T|0]|0;R=T<<ea;c[z>>2]=R;T=W<<ea;W=sa+ea|0;do{if((W|0)>-1){ea=e+1060|0;Q=c[ea>>2]|0;if(!(Q>>>0<(c[e+1064>>2]|0)>>>0)){ua=T;va=W;break}c[ea>>2]=Q+2;ea=Q;ua=((de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<W|T;va=W-16|0}else{ua=T;va=W}}while(0);c[q>>2]=va;W=((ba(R-1|0,_&255)|0)>>8)+1|0;T=W<<16;X=ua>>>0>=T>>>0;c[z>>2]=X?R-W|0:W;c[ia>>2]=ua-(X?T:0);T=X&1|2;c[V>>2]=T;ta=T}else{ta=U}}while(0);U=e+17540+(ma<<4)+(ta<<2)|0;c[U>>2]=(c[U>>2]|0)+1;wa=ja;break}else if((m|0)==2){U=e+10153|0;V=a[U+(ma<<1)|0]|0;ia=e+1052|0;z=c[ia>>2]|0;q=d[1086680+z|0]|0;Z=e+1056|0;fa=c[Z>>2]|0;ha=e+1068|0;da=c[ha>>2]|0;ga=z<<q;c[ia>>2]=ga;z=da<<q;da=fa+q|0;do{if((da|0)>-1){q=e+1060|0;fa=c[q>>2]|0;if(!(fa>>>0<(c[e+1064>>2]|0)>>>0)){xa=z;ya=da;break}c[q>>2]=fa+2;q=fa;xa=((de((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<da|z;ya=da-16|0}else{xa=z;ya=da}}while(0);c[Z>>2]=ya;da=((ba(ga-1|0,V&255)|0)>>8)+1|0;z=da<<16;q=xa>>>0>=z>>>0;fa=q&1;Y=q?ga-da|0:da;c[ia>>2]=Y;da=xa-(q?z:0)|0;c[ha>>2]=da;z=g+52|0;c[z>>2]=fa;if(q){q=a[U+(ma<<1)+1|0]|0;T=d[1086680+Y|0]|0;X=Y<<T;c[ia>>2]=X;Y=da<<T;da=ya+T|0;do{if((da|0)>-1){T=e+1060|0;W=c[T>>2]|0;if(!(W>>>0<(c[e+1064>>2]|0)>>>0)){za=Y;Aa=da;break}c[T>>2]=W+2;T=W;za=((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<da|Y;Aa=da-16|0}else{za=Y;Aa=da}}while(0);c[Z>>2]=Aa;da=((ba(X-1|0,q&255)|0)>>8)+1|0;Y=da<<16;U=za>>>0>=Y>>>0;c[ia>>2]=U?X-da|0:da;c[ha>>2]=za-(U?Y:0);Y=(U&1)+fa|0;c[z>>2]=Y;Ba=Y}else{Ba=fa}Y=e+17572+(ma*12|0)+(Ba<<2)|0;c[Y>>2]=(c[Y>>2]|0)+1;wa=ja;break}else if((m|0)==1){Y=a[e+(ma+10157)|0]|0;U=e+1052|0;da=c[U>>2]|0;ga=d[1086680+da|0]|0;V=e+1056|0;T=c[V>>2]|0;W=e+1068|0;P=c[W>>2]|0;ea=da<<ga;c[U>>2]=ea;da=P<<ga;P=T+ga|0;do{if((P|0)>-1){ga=e+1060|0;T=c[ga>>2]|0;if(!(T>>>0<(c[e+1064>>2]|0)>>>0)){Ca=da;Da=P;break}c[ga>>2]=T+2;ga=T;Ca=((de((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)<<P|da;Da=P-16|0}else{Ca=da;Da=P}}while(0);c[V>>2]=Da;P=((ba(ea-1|0,Y&255)|0)>>8)+1|0;da=P<<16;fa=Ca>>>0>=da>>>0;z=fa&1;c[U>>2]=fa?ea-P|0:P;c[W>>2]=Ca-(fa?da:0);c[g+52>>2]=z;da=e+17596+(ma<<3)+(z<<2)|0;c[da>>2]=(c[da>>2]|0)+1;wa=ja;break}else if((m|0)==0){c[g+52>>2]=0;wa=ja;break}else{wa=ja;break}}}while(0);if(($|0)==113){c[g+52>>2]=m>>>0>ka>>>0?ka:m;wa=la}do{if((a[ca]|0)==0){if((a[e+1144|0]|0)!=0){$=116;break}if((a[wa]|0)!=0){a[g+2|0]=0;la=c[k>>2]|0;c:do{if(la>>>0>9>>>0){m=e+1052|0;ka=e+1056|0;ja=e+1068|0;ma=e+1060|0;Ca=e+1064|0;Da=0;Ba=c[m>>2]|0;za=c[ka>>2]|0;Aa=c[ja>>2]|0;while(1){ya=a[e+(Da+9968)|0]|0;xa=d[1086680+Ba|0]|0;ta=Ba<<xa;c[m>>2]=ta;ua=Aa<<xa;va=xa+za|0;do{if((va|0)>-1){xa=c[ma>>2]|0;if(!(xa>>>0<(c[Ca>>2]|0)>>>0)){Ea=ua;Fa=va;break}c[ma>>2]=xa+2;sa=xa;Ea=((de((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<va|ua;Fa=va-16|0}else{Ea=ua;Fa=va}}while(0);c[ka>>2]=Fa;va=((ba(ta-1|0,ya&255)|0)>>8)+1|0;ua=va<<16;sa=Ea>>>0>=ua>>>0;xa=sa?ta-va|0:va;c[m>>2]=xa;va=Ea-(sa?ua:0)|0;c[ja>>2]=va;ua=a[(sa&1)+(108560+(Da<<1))|0]|0;Ga=ua<<24>>24;if(ua<<24>>24>0){Da=Ga;Ba=xa;za=Fa;Aa=va}else{break}}Aa=-Ga|0;za=g+5|0;a[za]=Aa;Ba=e+16628|0;Da=Ba+((Aa&255)<<2)|0;c[Da>>2]=(c[Da>>2]|0)+1;Da=(la|0)==10;do{if(Da){a[g+6|0]=a[za]|0}else{Aa=0;R=c[m>>2]|0;_=c[ka>>2]|0;va=c[ja>>2]|0;while(1){xa=a[e+(Aa+9968)|0]|0;ua=d[1086680+R|0]|0;sa=R<<ua;c[m>>2]=sa;ra=va<<ua;qa=ua+_|0;do{if((qa|0)>-1){ua=c[ma>>2]|0;if(!(ua>>>0<(c[Ca>>2]|0)>>>0)){Ha=ra;Ia=qa;break}c[ma>>2]=ua+2;pa=ua;Ha=((de((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<qa|ra;Ia=qa-16|0}else{Ha=ra;Ia=qa}}while(0);c[ka>>2]=Ia;qa=((ba(sa-1|0,xa&255)|0)>>8)+1|0;ra=qa<<16;pa=Ha>>>0>=ra>>>0;ua=pa?sa-qa|0:qa;c[m>>2]=ua;qa=Ha-(pa?ra:0)|0;c[ja>>2]=qa;ra=a[(pa&1)+(108560+(Aa<<1))|0]|0;Ja=ra<<24>>24;if(ra<<24>>24>0){Aa=Ja;R=ua;_=Ia;va=qa}else{break}}va=-Ja|0;a[g+6|0]=va;_=Ba+((va&255)<<2)|0;c[_>>2]=(c[_>>2]|0)+1;if((la|0)!=11){break}a[g+7|0]=a[za]|0;a[g+8|0]=a[g+6|0]|0;break c}}while(0);za=0;_=c[m>>2]|0;va=c[ka>>2]|0;R=c[ja>>2]|0;while(1){Aa=a[e+(za+9968)|0]|0;ta=d[1086680+_|0]|0;ya=_<<ta;c[m>>2]=ya;qa=R<<ta;ua=ta+va|0;do{if((ua|0)>-1){ta=c[ma>>2]|0;if(!(ta>>>0<(c[Ca>>2]|0)>>>0)){Ka=qa;La=ua;break}c[ma>>2]=ta+2;ra=ta;Ka=((de((d[ra]|d[ra+1|0]<<8)<<16>>16|0)|0)&65535)<<ua|qa;La=ua-16|0}else{Ka=qa;La=ua}}while(0);c[ka>>2]=La;ua=((ba(ya-1|0,Aa&255)|0)>>8)+1|0;qa=ua<<16;ra=Ka>>>0>=qa>>>0;ta=ra?ya-ua|0:ua;c[m>>2]=ta;ua=Ka-(ra?qa:0)|0;c[ja>>2]=ua;qa=a[(ra&1)+(108560+(za<<1))|0]|0;Ma=qa<<24>>24;if(qa<<24>>24>0){za=Ma;_=ta;va=La;R=ua}else{break}}R=-Ma|0;va=g+7|0;a[va]=R;_=Ba+((R&255)<<2)|0;c[_>>2]=(c[_>>2]|0)+1;if(Da){a[g+8|0]=a[va]|0;break}va=0;_=c[m>>2]|0;R=c[ka>>2]|0;za=c[ja>>2]|0;while(1){ua=a[e+(va+9968)|0]|0;ta=d[1086680+_|0]|0;qa=_<<ta;c[m>>2]=qa;ra=za<<ta;pa=ta+R|0;do{if((pa|0)>-1){ta=c[ma>>2]|0;if(!(ta>>>0<(c[Ca>>2]|0)>>>0)){Na=ra;Oa=pa;break}c[ma>>2]=ta+2;na=ta;Na=((de((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|ra;Oa=pa-16|0}else{Na=ra;Oa=pa}}while(0);c[ka>>2]=Oa;pa=((ba(qa-1|0,ua&255)|0)>>8)+1|0;ra=pa<<16;ya=Na>>>0>=ra>>>0;Aa=ya?qa-pa|0:pa;c[m>>2]=Aa;pa=Na-(ya?ra:0)|0;c[ja>>2]=pa;ra=a[(ya&1)+(108560+(va<<1))|0]|0;Pa=ra<<24>>24;if(ra<<24>>24>0){va=Pa;_=Aa;R=Oa;za=pa}else{break}}za=-Pa|0;a[g+8|0]=za;R=Ba+((za&255)<<2)|0;c[R>>2]=(c[R>>2]|0)+1}else{R=d[1402968+la|0]|0;za=e+9968|0;_=e+1052|0;va=e+1056|0;ja=e+1068|0;m=e+1060|0;ka=e+1064|0;ma=0;Ca=c[_>>2]|0;Da=c[va>>2]|0;pa=c[ja>>2]|0;while(1){Aa=a[za+(R*9|0)+ma|0]|0;ra=d[1086680+Ca|0]|0;ya=Ca<<ra;c[_>>2]=ya;na=pa<<ra;ta=ra+Da|0;do{if((ta|0)>-1){ra=c[m>>2]|0;if(!(ra>>>0<(c[ka>>2]|0)>>>0)){Qa=na;Ra=ta;break}c[m>>2]=ra+2;oa=ra;Qa=((de((d[oa]|d[oa+1|0]<<8)<<16>>16|0)|0)&65535)<<ta|na;Ra=ta-16|0}else{Qa=na;Ra=ta}}while(0);c[va>>2]=Ra;ta=((ba(ya-1|0,Aa&255)|0)>>8)+1|0;na=ta<<16;qa=Qa>>>0>=na>>>0;ua=qa?ya-ta|0:ta;c[_>>2]=ua;ta=Qa-(qa?na:0)|0;c[ja>>2]=ta;Sa=a[(qa&1)+(108560+(ma<<1))|0]|0;if(Sa<<24>>24>0){ma=Sa<<24>>24;Ca=ua;Da=Ra;pa=ta}else{break}}pa=-Sa&255;Da=e+16628+(R*40|0)+((pa&255)<<2)|0;TGb(g+5|0,pa|0,4)|0;c[Da>>2]=(c[Da>>2]|0)+1}}while(0);la=g+8|0;W=d[la]|0;ea=e+10004|0;U=e+1052|0;Y=e+1056|0;V=e+1068|0;Da=e+1060|0;pa=e+1064|0;Ca=0;ma=c[U>>2]|0;ja=c[Y>>2]|0;_=c[V>>2]|0;while(1){va=a[ea+(W*9|0)+Ca|0]|0;m=d[1086680+ma|0]|0;ka=ma<<m;c[U>>2]=ka;za=_<<m;Ba=m+ja|0;do{if((Ba|0)>-1){m=c[Da>>2]|0;if(!(m>>>0<(c[pa>>2]|0)>>>0)){Ta=za;Ua=Ba;break}c[Da>>2]=m+2;ta=m;Ta=((de((d[ta]|d[ta+1|0]<<8)<<16>>16|0)|0)&65535)<<Ba|za;Ua=Ba-16|0}else{Ta=za;Ua=Ba}}while(0);c[Y>>2]=Ua;Ba=((ba(ka-1|0,va&255)|0)>>8)+1|0;za=Ba<<16;R=Ta>>>0>=za>>>0;ta=R?ka-Ba|0:Ba;c[U>>2]=ta;Ba=Ta-(R?za:0)|0;c[V>>2]=Ba;za=a[(R&1)+(108560+(Ca<<1))|0]|0;Va=za<<24>>24;if(za<<24>>24>0){Ca=Va;ma=ta;ja=Ua;_=Ba}else{break}}_=-Va|0;a[g+9|0]=_;ja=e+16788+((d[la]|0)*40|0)+((_&255)<<2)|0;c[ja>>2]=(c[ja>>2]|0)+1;Wa=0;Xa=0;break}ja=g|0;_=d[ja]|0;ma=e+1554|0;do{if((a[ma+(_*26|0)+2|0]|0)==0){Ca=c[e+29840>>2]|0;if((Ca|0)==2){d:do{if(n){V=a[(c[e+30132>>2]|0)+i|0]|0;U=V<<24>>24!=0;if(!o){if(U){Ya=3;break}if((a[(c[e+30128>>2]|0)+i|0]|0)!=0){Ya=0;break}Ya=(a[(c[e+30136>>2]|0)+i|0]|0)==(a[e+1153|0]|0)|0;break}do{if(U){if((a[e+(j+30072)|0]|0)!=0){Ya=4;break d}if(V<<24>>24==0){break}if((a[e+(j+30064)|0]|0)!=0){Ya=3;break d}Ya=(a[e+(j+30080)|0]|0)==(a[e+1153|0]|0)|2;break d}}while(0);V=(a[(c[e+30128>>2]|0)+i|0]|0)==0;if((a[e+(j+30072)|0]|0)!=0){if(!V){Ya=3;break}Ya=(a[(c[e+30136>>2]|0)+i|0]|0)==(a[e+1153|0]|0)|2;break}if(V){Za=(a[(c[e+30136>>2]|0)+i|0]|0)==(a[e+1153|0]|0)|0}else{Za=0}if((a[e+(j+30064)|0]|0)==0){_a=(a[e+(h&7|30080)|0]|0)==(a[e+1153|0]|0)|0}else{_a=0}Ya=_a^Za}else{if(!o){Ya=1;break}if((a[e+(j+30072)|0]|0)!=0){Ya=3;break}if((a[e+(j+30064)|0]|0)!=0){Ya=0;break}Ya=(a[e+(j+30080)|0]|0)==(a[e+1153|0]|0)|0}}while(0);ka=a[e+(Ya+10127)|0]|0;va=e+1052|0;V=c[va>>2]|0;U=d[1086680+V|0]|0;ya=e+1056|0;Aa=c[ya>>2]|0;Y=e+1068|0;Da=c[Y>>2]|0;pa=V<<U;c[va>>2]=pa;V=Da<<U;Da=Aa+U|0;do{if((Da|0)>-1){U=e+1060|0;Aa=c[U>>2]|0;if(!(Aa>>>0<(c[e+1064>>2]|0)>>>0)){$a=V;ab=Da;break}c[U>>2]=Aa+2;U=Aa;$a=((de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|V;ab=Da-16|0}else{$a=V;ab=Da}}while(0);c[ya>>2]=ab;Da=((ba(pa-1|0,ka&255)|0)>>8)+1|0;V=Da<<16;U=$a>>>0>=V>>>0;c[va>>2]=U?pa-Da|0:Da;c[Y>>2]=$a-(U?V:0);V=g+2|0;a[V]=U&1;Da=e+17380+(Ya<<3)+((U&1)<<2)|0;c[Da>>2]=(c[Da>>2]|0)+1;bb=a[V]|0}else{V=(Ca|0)==1|0;a[g+2|0]=V;bb=V}if(!(bb<<24>>24==0)){V=e+1153|0;Da=a[V]|0;U=a[e+((Da&255)+1160)|0]|0;Aa=U<<24>>24==0|0;a[(U&255)+(g+3)|0]=Da;do{if(n){Da=(a[(c[e+30128>>2]|0)+i|0]|0)!=0;if(!o){if(Da){cb=2;break}U=(a[(c[e+30136>>2]|0)+i|0]|0)!=(a[e+1164|0]|0)|0;if((a[(c[e+30132>>2]|0)+i|0]|0)==0){cb=-U&3;break}else{cb=U<<2;break}}U=(a[e+(j+30064)|0]|0)!=0;if(Da){if(U){cb=2;break}cb=((a[e+(j+30080)|0]|0)!=(a[e+1164|0]|0))<<1|1;break}if(U){cb=((a[(c[e+30136>>2]|0)+i|0]|0)!=(a[e+1164|0]|0))<<1|1;break}U=a[e+(j+30080)|0]|0;Da=a[(c[e+30136>>2]|0)+i|0]|0;W=U<<24>>24==Da<<24>>24;if(W){if(U<<24>>24==(a[e+1164|0]|0)){cb=0;break}}ea=(a[(c[e+30132>>2]|0)+i|0]|0)==0;if((a[e+(j+30072)|0]|0)!=0){if(!ea){cb=W?4:2;break}Ba=a[e+1164|0]|0;ta=U<<24>>24!=Ba<<24>>24;za=Da<<24>>24==Ba<<24>>24;if(!za){cb=ta|za?4:1;break}cb=ta?2:4;break}if(!ea){ea=a[e+1164|0]|0;ta=Da<<24>>24!=ea<<24>>24;za=U<<24>>24==ea<<24>>24;if(!za){cb=ta|za?4:1;break}cb=ta?2:4;break}ta=a[V]|0;if(Da<<24>>24==ta<<24>>24){if(U<<24>>24==(a[e+1163|0]|0)){cb=4;break}}if(U<<24>>24==ta<<24>>24){if(Da<<24>>24==(a[e+1163|0]|0)){cb=4;break}}cb=W?3:1}else{if(!o){cb=2;break}if((a[e+(j+30064)|0]|0)!=0){cb=2;break}W=(a[e+(j+30080)|0]|0)!=(a[e+1164|0]|0)|0;if((a[e+(j+30072)|0]|0)==0){cb=-W&3;break}else{cb=W<<2;break}}}while(0);V=a[e+(cb+10142)|0]|0;Ca=e+1052|0;Y=c[Ca>>2]|0;pa=d[1086680+Y|0]|0;va=e+1056|0;ka=c[va>>2]|0;ya=e+1068|0;W=c[ya>>2]|0;Da=Y<<pa;c[Ca>>2]=Da;Y=W<<pa;W=ka+pa|0;do{if((W|0)>-1){pa=e+1060|0;ka=c[pa>>2]|0;if(!(ka>>>0<(c[e+1064>>2]|0)>>>0)){db=Y;eb=W;break}c[pa>>2]=ka+2;pa=ka;db=((de((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<W|Y;eb=W-16|0}else{db=Y;eb=W}}while(0);c[va>>2]=eb;W=((ba(Da-1|0,V&255)|0)>>8)+1|0;Y=W<<16;pa=db>>>0>=Y>>>0;c[Ca>>2]=pa?Da-W|0:W;c[ya>>2]=db-(pa?Y:0);a[g+3+Aa|0]=a[e+(pa?1164:1163)|0]|0;Y=e+17500+(cb<<3)+((pa&1)<<2)|0;c[Y>>2]=(c[Y>>2]|0)+1;break}e:do{if(n){if((a[(c[e+30128>>2]|0)+i|0]|0)!=0){$=280;break}do{if(o){if((a[e+(j+30064)|0]|0)!=0){break}Y=(a[(c[e+30132>>2]|0)+i|0]|0)!=0;if((a[e+(j+30072)|0]|0)==0){pa=(a[e+(j+30080)|0]|0)==0|0;if(!Y){fb=((a[(c[e+30136>>2]|0)+i|0]|0)==0)+pa<<1;break e}if((a[e+1153|0]|0)==0){gb=1}else{gb=(a[(c[e+30136>>2]|0)+i|0]|0)==0|0}fb=gb+(-pa&3)|0;break e}if(Y){if((a[e+1153|0]|0)==0){fb=2;break e}if((a[e+(j+30080)|0]|0)==0){fb=2;break e}fb=(a[(c[e+30136>>2]|0)+i|0]|0)!=0?1:2;break e}else{if((a[e+1153|0]|0)==0){hb=1}else{hb=(a[e+(j+30080)|0]|0)==0|0}fb=hb+(-((a[(c[e+30136>>2]|0)+i|0]|0)==0|0)&3)|0;break e}}}while(0);if((a[(c[e+30132>>2]|0)+i|0]|0)==0){fb=((a[(c[e+30136>>2]|0)+i|0]|0)==0)<<2;break}if((a[e+1153|0]|0)==0){fb=2;break}fb=(a[(c[e+30136>>2]|0)+i|0]|0)!=0?1:2}else{$=280}}while(0);do{if(($|0)==280){if(!o){fb=2;break}if((a[e+(j+30064)|0]|0)!=0){fb=2;break}if((a[e+(j+30072)|0]|0)==0){fb=((a[e+(j+30080)|0]|0)==0)<<2;break}if((a[e+1153|0]|0)==0){fb=2;break}fb=(a[e+(j+30080)|0]|0)!=0?1:2}}while(0);Aa=e+10132|0;ya=a[Aa+(fb<<1)|0]|0;Da=e+1052|0;Ca=c[Da>>2]|0;V=d[1086680+Ca|0]|0;va=e+1056|0;Y=c[va>>2]|0;pa=e+1068|0;W=c[pa>>2]|0;ka=Ca<<V;c[Da>>2]=ka;Ca=W<<V;W=Y+V|0;do{if((W|0)>-1){V=e+1060|0;Y=c[V>>2]|0;if(!(Y>>>0<(c[e+1064>>2]|0)>>>0)){ib=Ca;jb=W;break}c[V>>2]=Y+2;V=Y;ib=((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<W|Ca;jb=W-16|0}else{ib=Ca;jb=W}}while(0);c[va>>2]=jb;W=((ba(ka-1|0,ya&255)|0)>>8)+1|0;Ca=W<<16;V=ib>>>0>=Ca>>>0;c[Da>>2]=V?ka-W|0:W;c[pa>>2]=ib-(V?Ca:0);Ca=e+17420|0;W=Ca+(fb<<4)+((V&1)<<2)|0;c[W>>2]=(c[W>>2]|0)+1;if(!V){a[g+3|0]=0;break}do{if(n){if(!o){if((a[(c[e+30128>>2]|0)+i|0]|0)!=0){kb=2;break}if((a[(c[e+30132>>2]|0)+i|0]|0)==0){if((a[(c[e+30136>>2]|0)+i|0]|0)==0){kb=2;break}kb=((a[(c[e+30136>>2]|0)+i|0]|0)==1)<<2;break}else{if((a[e+1153|0]|0)==1){kb=3;break}kb=-((a[(c[e+30136>>2]|0)+i|0]|0)==1|0)&3;break}}V=(a[(c[e+30128>>2]|0)+i|0]|0)!=0;if((a[e+(j+30064)|0]|0)!=0){if(V){kb=2;break}if((a[(c[e+30132>>2]|0)+i|0]|0)==0){W=a[(c[e+30136>>2]|0)+i|0]|0;if(W<<24>>24==0){kb=3;break}kb=(W<<24>>24==1)<<2;break}else{if((a[e+1153|0]|0)==1){kb=3;break}kb=((a[(c[e+30136>>2]|0)+i|0]|0)==1)<<1|1;break}}if(V){if((a[e+(j+30072)|0]|0)==0){V=a[e+(j+30080)|0]|0;if(V<<24>>24==0){kb=3;break}kb=(V<<24>>24==1)<<2;break}else{if((a[e+1153|0]|0)==1){kb=3;break}kb=((a[e+(j+30080)|0]|0)==1)<<1|1;break}}V=(a[e+(j+30072)|0]|0)!=0;if((a[(c[e+30132>>2]|0)+i|0]|0)!=0){W=a[e+(j+30080)|0]|0;if(V){if(!(W<<24>>24==(a[(c[e+30136>>2]|0)+i|0]|0))){kb=2;break}if((a[e+1153|0]|0)==1){kb=3;break}kb=-(W<<24>>24==1|0)&3;break}if(W<<24>>24==0){if((a[e+1153|0]|0)==1){kb=3;break}kb=((a[(c[e+30136>>2]|0)+i|0]|0)==1)<<1|1;break}if((a[e+1153|0]|0)==1){lb=1}else{lb=(a[(c[e+30136>>2]|0)+i|0]|0)==1|0}kb=lb+(-(W<<24>>24==1|0)&3)|0;break}W=a[(c[e+30136>>2]|0)+i|0]|0;Y=W<<24>>24!=0;if(V){if(!Y){if((a[e+1153|0]|0)==1){kb=3;break}kb=((a[e+(j+30080)|0]|0)==1)<<1|1;break}if((a[e+1153|0]|0)==1){mb=1}else{mb=(a[e+(j+30080)|0]|0)==1|0}kb=mb+(-(W<<24>>24==1|0)&3)|0;break}else{V=a[e+(j+30080)|0]|0;ta=V<<24>>24!=0;if(!Y){if(!ta){kb=3;break}kb=(V<<24>>24==1)<<2;break}if(ta){kb=(V<<24>>24==1)+(W<<24>>24==1)<<1;break}else{kb=(W<<24>>24==1)<<2;break}}}else{if(!o){kb=2;break}if((a[e+(j+30064)|0]|0)!=0){kb=2;break}if((a[e+(j+30072)|0]|0)==0){W=a[e+(j+30080)|0]|0;if(W<<24>>24==0){kb=2;break}kb=(W<<24>>24==1)<<2;break}else{if((a[e+1153|0]|0)==1){kb=3;break}kb=-((a[e+(j+30080)|0]|0)==1|0)&3;break}}}while(0);ka=a[Aa+(kb<<1)+1|0]|0;ya=c[Da>>2]|0;W=d[1086680+ya|0]|0;V=c[va>>2]|0;ta=c[pa>>2]|0;Y=ya<<W;c[Da>>2]=Y;ya=ta<<W;ta=V+W|0;do{if((ta|0)>-1){W=e+1060|0;V=c[W>>2]|0;if(!(V>>>0<(c[e+1064>>2]|0)>>>0)){nb=ya;ob=ta;break}c[W>>2]=V+2;W=V;nb=((de((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<ta|ya;ob=ta-16|0}else{nb=ya;ob=ta}}while(0);c[va>>2]=ob;ta=((ba(Y-1|0,ka&255)|0)>>8)+1|0;ya=ta<<16;Aa=nb>>>0>=ya>>>0;c[Da>>2]=Aa?Y-ta|0:ta;c[pa>>2]=nb-(Aa?ya:0);ya=Ca+(kb<<4)+8+((Aa&1)<<2)|0;c[ya>>2]=(c[ya>>2]|0)+1;a[g+3|0]=Aa?2:1}else{a[g+2|0]=0;a[g+3|0]=(a[ma+(_*26|0)+4|0]|0)-1}}while(0);_=c[k>>2]|0;do{if(_>>>0<10>>>0){if((a[ma+((d[ja]|0)*26|0)+3|0]|0)!=0){la=g+5|0;x=202116108;a[la]=x;x=x>>8;a[la+1|0]=x;x=x>>8;a[la+2|0]=x;x=x>>8;a[la+3|0]=x;break}la=d[1402984+_|0]|0;Aa=d[(d[e+(j+29872+la)|0]|0)+(1403032+((d[(c[e+30100>>2]|0)+(la+i)|0]|0)*14|0))|0]|0;la=e+10102|0;ya=e+1052|0;ta=e+1056|0;W=e+1068|0;V=e+1060|0;U=e+1064|0;za=0;ea=c[ya>>2]|0;Ba=c[ta>>2]|0;R=c[W>>2]|0;while(1){m=a[la+(Aa*3|0)+za|0]|0;ua=d[1086680+ea|0]|0;qa=ea<<ua;c[ya>>2]=qa;na=R<<ua;oa=ua+Ba|0;do{if((oa|0)>-1){ua=c[V>>2]|0;if(!(ua>>>0<(c[U>>2]|0)>>>0)){pb=na;qb=oa;break}c[V>>2]=ua+2;ra=ua;pb=((de((d[ra]|d[ra+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|na;qb=oa-16|0}else{pb=na;qb=oa}}while(0);c[ta>>2]=qb;oa=((ba(qa-1|0,m&255)|0)>>8)+1|0;na=oa<<16;ra=pb>>>0>=na>>>0;ua=ra?qa-oa|0:oa;c[ya>>2]=ua;oa=pb-(ra?na:0)|0;c[W>>2]=oa;rb=a[(ra&1)+(108640+(za<<1))|0]|0;if(rb<<24>>24>0){za=rb<<24>>24;ea=ua;Ba=qb;R=oa}else{break}}R=-rb&255;Ba=e+17236+(Aa<<4)+((R&255)-10<<2)|0;TGb(g+5|0,R|0,4)|0;c[Ba>>2]=(c[Ba>>2]|0)+1}}while(0);ja=c[e+1148>>2]|0;if((ja|0)==4){f:do{if(n){if(!((d[(c[e+30100>>2]|0)+i|0]|0)>>>0>9>>>0)){$=363;break}do{if(o){if(!((d[e+(j+29872)|0]|0)>>>0>9>>>0)){break}ma=a[e+(j+30088)|0]|0;sb=(a[(c[e+30140>>2]|0)+i|0]|0)==ma<<24>>24?ma&255:3;break f}}while(0);sb=d[(c[e+30140>>2]|0)+i|0]|0}else{$=363}}while(0);do{if(($|0)==363){if(!o){sb=3;break}if(!((d[e+(j+29872)|0]|0)>>>0>9>>>0)){sb=3;break}sb=d[e+(j+30088)|0]|0}}while(0);Aa=e+10094|0;ma=e+1052|0;Ba=e+1056|0;R=e+1068|0;ea=e+1060|0;za=e+1064|0;W=0;ya=c[ma>>2]|0;ta=c[Ba>>2]|0;V=c[R>>2]|0;while(1){U=a[Aa+(sb<<1)+W|0]|0;la=d[1086680+ya|0]|0;Ca=ya<<la;c[ma>>2]=Ca;pa=V<<la;Y=la+ta|0;do{if((Y|0)>-1){la=c[ea>>2]|0;if(!(la>>>0<(c[za>>2]|0)>>>0)){tb=pa;ub=Y;break}c[ea>>2]=la+2;Da=la;tb=((de((d[Da]|d[Da+1|0]<<8)<<16>>16|0)|0)&65535)<<Y|pa;ub=Y-16|0}else{tb=pa;ub=Y}}while(0);c[Ba>>2]=ub;Y=((ba(Ca-1|0,U&255)|0)>>8)+1|0;pa=Y<<16;Da=tb>>>0>=pa>>>0;la=Da?Ca-Y|0:Y;c[ma>>2]=la;Y=tb-(Da?pa:0)|0;c[R>>2]=Y;pa=a[(Da&1)+(108648+(W<<1))|0]|0;vb=pa<<24>>24;if(pa<<24>>24>0){W=vb;ya=la;ta=ub;V=Y}else{break}}V=-vb|0;ta=e+17188+(sb*12|0)+(V<<2)|0;c[ta>>2]=(c[ta>>2]|0)+1;c[g+12>>2]=c[108656+(V<<2)>>2];wb=V}else{c[g+12>>2]=ja;wb=0}g:do{if(_>>>0>9>>>0){V=d[(d[e+(j+29872)|0]|0)+(1403032+((d[(c[e+30100>>2]|0)+i|0]|0)*14|0))|0]|0;ta=e+10102|0;ya=e+1052|0;W=e+1056|0;R=e+1068|0;ma=e+1060|0;Ba=e+1064|0;ea=0;za=c[ya>>2]|0;Aa=c[W>>2]|0;Y=c[R>>2]|0;while(1){la=a[ta+(V*3|0)+ea|0]|0;pa=d[1086680+za|0]|0;Da=za<<pa;c[ya>>2]=Da;ka=Y<<pa;va=pa+Aa|0;do{if((va|0)>-1){pa=c[ma>>2]|0;if(!(pa>>>0<(c[Ba>>2]|0)>>>0)){xb=ka;yb=va;break}c[ma>>2]=pa+2;oa=pa;xb=((de((d[oa]|d[oa+1|0]<<8)<<16>>16|0)|0)&65535)<<va|ka;yb=va-16|0}else{xb=ka;yb=va}}while(0);c[W>>2]=yb;va=((ba(Da-1|0,la&255)|0)>>8)+1|0;ka=va<<16;qa=xb>>>0>=ka>>>0;m=qa?Da-va|0:va;c[ya>>2]=m;va=xb-(qa?ka:0)|0;c[R>>2]=va;ka=a[(qa&1)+(108640+(ea<<1))|0]|0;zb=ka<<24>>24;if(ka<<24>>24>0){ea=zb;za=m;Aa=yb;Y=va}else{break}}Y=-zb|0;Aa=g+5|0;a[Aa]=Y;za=e+17236|0;ea=za+(V<<4)+((Y&255)-10<<2)|0;c[ea>>2]=(c[ea>>2]|0)+1;ea=g+16|0;O6a(f,ea|0,d[Aa]|0,0);do{if((c[k>>2]|0)==10){a[g+6|0]=a[Aa]|0;c[g+24>>2]=c[ea>>2];c[g+28>>2]=c[g+20>>2]}else{Y=0;Ca=c[ya>>2]|0;U=c[W>>2]|0;va=c[R>>2]|0;while(1){m=a[ta+(V*3|0)+Y|0]|0;ka=d[1086680+Ca|0]|0;qa=Ca<<ka;c[ya>>2]=qa;oa=va<<ka;pa=ka+U|0;do{if((pa|0)>-1){ka=c[ma>>2]|0;if(!(ka>>>0<(c[Ba>>2]|0)>>>0)){Ab=oa;Bb=pa;break}c[ma>>2]=ka+2;ua=ka;Ab=((de((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|oa;Bb=pa-16|0}else{Ab=oa;Bb=pa}}while(0);c[W>>2]=Bb;pa=((ba(qa-1|0,m&255)|0)>>8)+1|0;oa=pa<<16;sa=Ab>>>0>=oa>>>0;xa=sa?qa-pa|0:pa;c[ya>>2]=xa;pa=Ab-(sa?oa:0)|0;c[R>>2]=pa;oa=a[(sa&1)+(108640+(Y<<1))|0]|0;Cb=oa<<24>>24;if(oa<<24>>24>0){Y=Cb;Ca=xa;U=Bb;va=pa}else{break}}va=-Cb|0;U=g+6|0;a[U]=va;Ca=za+(V<<4)+((va&255)-10<<2)|0;c[Ca>>2]=(c[Ca>>2]|0)+1;O6a(f,g+24|0,d[U]|0,1);if((c[k>>2]|0)!=11){break}a[g+7|0]=a[Aa]|0;c[g+32>>2]=c[ea>>2];c[g+36>>2]=c[g+20>>2];a[g+8|0]=a[g+6|0]|0;c[g+40>>2]=c[g+24>>2];c[g+44>>2]=c[g+28>>2];break g}}while(0);ea=0;Aa=c[ya>>2]|0;U=c[W>>2]|0;Ca=c[R>>2]|0;while(1){va=a[ta+(V*3|0)+ea|0]|0;Y=d[1086680+Aa|0]|0;Da=Aa<<Y;c[ya>>2]=Da;la=Ca<<Y;pa=Y+U|0;do{if((pa|0)>-1){Y=c[ma>>2]|0;if(!(Y>>>0<(c[Ba>>2]|0)>>>0)){Db=la;Eb=pa;break}c[ma>>2]=Y+2;xa=Y;Db=((de((d[xa]|d[xa+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|la;Eb=pa-16|0}else{Db=la;Eb=pa}}while(0);c[W>>2]=Eb;pa=((ba(Da-1|0,va&255)|0)>>8)+1|0;la=pa<<16;xa=Db>>>0>=la>>>0;Y=xa?Da-pa|0:pa;c[ya>>2]=Y;pa=Db-(xa?la:0)|0;c[R>>2]=pa;la=a[(xa&1)+(108640+(ea<<1))|0]|0;Fb=la<<24>>24;if(la<<24>>24>0){ea=Fb;Aa=Y;U=Eb;Ca=pa}else{break}}Ca=-Fb|0;U=g+7|0;a[U]=Ca;Aa=za+(V<<4)+((Ca&255)-10<<2)|0;c[Aa>>2]=(c[Aa>>2]|0)+1;Aa=g+32|0;O6a(f,Aa|0,d[U]|0,2);if((c[k>>2]|0)==10){a[g+8|0]=a[U]|0;c[g+40>>2]=c[Aa>>2];c[g+44>>2]=c[g+36>>2];break}Aa=0;U=c[ya>>2]|0;Ca=c[W>>2]|0;ea=c[R>>2]|0;while(1){pa=a[ta+(V*3|0)+Aa|0]|0;Y=d[1086680+U|0]|0;la=U<<Y;c[ya>>2]=la;xa=ea<<Y;oa=Y+Ca|0;do{if((oa|0)>-1){Y=c[ma>>2]|0;if(!(Y>>>0<(c[Ba>>2]|0)>>>0)){Gb=xa;Hb=oa;break}c[ma>>2]=Y+2;sa=Y;Gb=((de((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|xa;Hb=oa-16|0}else{Gb=xa;Hb=oa}}while(0);c[W>>2]=Hb;oa=((ba(la-1|0,pa&255)|0)>>8)+1|0;xa=oa<<16;Da=Gb>>>0>=xa>>>0;va=Da?la-oa|0:oa;c[ya>>2]=va;oa=Gb-(Da?xa:0)|0;c[R>>2]=oa;xa=a[(Da&1)+(108640+(Aa<<1))|0]|0;Ib=xa<<24>>24;if(xa<<24>>24>0){Aa=Ib;U=va;Ca=Hb;ea=oa}else{break}}ea=-Ib|0;Ca=g+8|0;a[Ca]=ea;U=za+(V<<4)+((ea&255)-10<<2)|0;c[U>>2]=(c[U>>2]|0)+1;O6a(f,g+40|0,d[Ca]|0,3)}else{Ca=g+16|0;O6a(f,Ca|0,d[g+5|0]|0,-1);U=c[Ca>>2]|0;c[g+24>>2]=U;c[g+32>>2]=U;c[g+40>>2]=U;U=c[g+20>>2]|0;c[g+28>>2]=U;c[g+36>>2]=U;c[g+44>>2]=U}}while(0);if((a[g+2|0]|0)==0){Jb=0}else{Jb=d[e+((d[e+1163|0]|0)+1160)|0]|0}Wa=d[g+3+Jb|0]|0;Xa=wb}else{$=116}}while(0);if(($|0)==116){wb=i<<1;Jb=c[e+30100>>2]|0;f=Jb+wb|0;Ib=j<<1;Hb=e+(Ib+29872)|0;a[g+2|0]=0;Gb=c[k>>2]|0;Fb=d[Hb]|0;Eb=d[f]|0;Db=e+1052|0;Cb=e+1056|0;Bb=e+1068|0;Ab=e+1060|0;zb=e+1064|0;yb=0;xb=c[Db>>2]|0;sb=c[Cb>>2]|0;vb=c[Bb>>2]|0;while(1){ub=a[117144+(Eb*90|0)+(Fb*9|0)+yb|0]|0;tb=d[1086680+xb|0]|0;o=xb<<tb;c[Db>>2]=o;n=vb<<tb;rb=tb+sb|0;do{if((rb|0)>-1){tb=c[Ab>>2]|0;if(!(tb>>>0<(c[zb>>2]|0)>>>0)){Kb=n;Lb=rb;break}c[Ab>>2]=tb+2;qb=tb;Kb=((de((d[qb]|d[qb+1|0]<<8)<<16>>16|0)|0)&65535)<<rb|n;Lb=rb-16|0}else{Kb=n;Lb=rb}}while(0);c[Cb>>2]=Lb;rb=((ba(o-1|0,ub&255)|0)>>8)+1|0;n=rb<<16;qb=Kb>>>0>=n>>>0;tb=qb?o-rb|0:rb;c[Db>>2]=tb;rb=Kb-(qb?n:0)|0;c[Bb>>2]=rb;n=a[(qb&1)+(108560+(yb<<1))|0]|0;Mb=n<<24>>24;if(n<<24>>24>0){yb=Mb;xb=tb;sb=Lb;vb=rb}else{break}}vb=-Mb|0;Mb=vb&255;do{if(Gb>>>0>9>>>0){a[f]=Mb;Lb=g+5|0;a[Lb]=Mb;if((c[k>>2]|0)==10){a[g+6|0]=Mb;a[Jb+(wb|1)|0]=Mb;Nb=Mb}else{sb=vb&255;xb=Jb+(wb|1)|0;yb=d[xb]|0;Kb=0;Fb=c[Db>>2]|0;Eb=c[Cb>>2]|0;rb=c[Bb>>2]|0;while(1){tb=a[117144+(yb*90|0)+(sb*9|0)+Kb|0]|0;n=d[1086680+Fb|0]|0;qb=Fb<<n;c[Db>>2]=qb;pb=rb<<n;kb=n+Eb|0;do{if((kb|0)>-1){n=c[Ab>>2]|0;if(!(n>>>0<(c[zb>>2]|0)>>>0)){Ob=pb;Pb=kb;break}c[Ab>>2]=n+2;nb=n;Ob=((de((d[nb]|d[nb+1|0]<<8)<<16>>16|0)|0)&65535)<<kb|pb;Pb=kb-16|0}else{Ob=pb;Pb=kb}}while(0);c[Cb>>2]=Pb;kb=((ba(qb-1|0,tb&255)|0)>>8)+1|0;pb=kb<<16;V=Ob>>>0>=pb>>>0;za=V?qb-kb|0:kb;c[Db>>2]=za;kb=Ob-(V?pb:0)|0;c[Bb>>2]=kb;Qb=a[(V&1)+(108560+(Kb<<1))|0]|0;if(Qb<<24>>24>0){Kb=Qb<<24>>24;Fb=za;Eb=Pb;rb=kb}else{break}}rb=-Qb&255;a[g+6|0]=rb;a[xb]=rb;Nb=rb}a[Hb]=Nb;if((c[k>>2]|0)==11){a[g+7|0]=a[Lb]|0;rb=a[g+6|0]|0;a[g+8|0]=rb;a[Jb+(wb|1)|0]=rb;a[e+(Ib+29873)|0]=rb;break}rb=e+(Ib+29873)|0;Eb=d[rb]|0;Fb=d[f]|0;Kb=0;sb=c[Db>>2]|0;yb=c[Cb>>2]|0;o=c[Bb>>2]|0;while(1){ub=a[117144+(Fb*90|0)+(Eb*9|0)+Kb|0]|0;kb=d[1086680+sb|0]|0;za=sb<<kb;c[Db>>2]=za;V=o<<kb;pb=kb+yb|0;do{if((pb|0)>-1){kb=c[Ab>>2]|0;if(!(kb>>>0<(c[zb>>2]|0)>>>0)){Rb=V;Sb=pb;break}c[Ab>>2]=kb+2;nb=kb;Rb=((de((d[nb]|d[nb+1|0]<<8)<<16>>16|0)|0)&65535)<<pb|V;Sb=pb-16|0}else{Rb=V;Sb=pb}}while(0);c[Cb>>2]=Sb;pb=((ba(za-1|0,ub&255)|0)>>8)+1|0;V=pb<<16;qb=Rb>>>0>=V>>>0;tb=qb?za-pb|0:pb;c[Db>>2]=tb;pb=Rb-(qb?V:0)|0;c[Bb>>2]=pb;V=a[(qb&1)+(108560+(Kb<<1))|0]|0;Tb=V<<24>>24;if(V<<24>>24>0){Kb=Tb;sb=tb;yb=Sb;o=pb}else{break}}o=-Tb|0;yb=o&255;a[f]=yb;a[g+7|0]=yb;if((c[k>>2]|0)==10){a[g+8|0]=yb;a[Jb+(wb|1)|0]=yb;a[rb]=yb;break}yb=o&255;o=Jb+(wb|1)|0;sb=d[o]|0;Kb=0;Eb=c[Db>>2]|0;Fb=c[Cb>>2]|0;Lb=c[Bb>>2]|0;while(1){xb=a[117144+(sb*90|0)+(yb*9|0)+Kb|0]|0;pb=d[1086680+Eb|0]|0;tb=Eb<<pb;c[Db>>2]=tb;V=Lb<<pb;qb=pb+Fb|0;do{if((qb|0)>-1){pb=c[Ab>>2]|0;if(!(pb>>>0<(c[zb>>2]|0)>>>0)){Ub=V;Vb=qb;break}c[Ab>>2]=pb+2;nb=pb;Ub=((de((d[nb]|d[nb+1|0]<<8)<<16>>16|0)|0)&65535)<<qb|V;Vb=qb-16|0}else{Ub=V;Vb=qb}}while(0);c[Cb>>2]=Vb;qb=((ba(tb-1|0,xb&255)|0)>>8)+1|0;V=qb<<16;za=Ub>>>0>=V>>>0;ub=za?tb-qb|0:qb;c[Db>>2]=ub;qb=Ub-(za?V:0)|0;c[Bb>>2]=qb;Wb=a[(za&1)+(108560+(Kb<<1))|0]|0;if(Wb<<24>>24>0){Kb=Wb<<24>>24;Eb=ub;Fb=Vb;Lb=qb}else{break}}Lb=-Wb&255;a[g+8|0]=Lb;a[o]=Lb;a[rb]=Lb}else{Lb=g+5|0;TGb(Lb|0,Mb|0,4)|0;TGb(f|0,Mb|0,d[1678848+(Gb<<1)|0]|0)|0;TGb(Hb|0,a[Lb]|0,d[1678849+(c[k>>2]<<1)|0]|0)|0}}while(0);Hb=d[g+8|0]|0;Gb=0;Mb=c[Db>>2]|0;f=c[Cb>>2]|0;Wb=c[Bb>>2]|0;while(1){Vb=a[118048+(Hb*9|0)+Gb|0]|0;Ub=d[1086680+Mb|0]|0;wb=Mb<<Ub;c[Db>>2]=wb;Jb=Wb<<Ub;Tb=Ub+f|0;do{if((Tb|0)>-1){Ub=c[Ab>>2]|0;if(!(Ub>>>0<(c[zb>>2]|0)>>>0)){Xb=Jb;Yb=Tb;break}c[Ab>>2]=Ub+2;Sb=Ub;Xb=((de((d[Sb]|d[Sb+1|0]<<8)<<16>>16|0)|0)&65535)<<Tb|Jb;Yb=Tb-16|0}else{Xb=Jb;Yb=Tb}}while(0);c[Cb>>2]=Yb;Tb=((ba(wb-1|0,Vb&255)|0)>>8)+1|0;Jb=Tb<<16;rb=Xb>>>0>=Jb>>>0;o=rb?wb-Tb|0:Tb;c[Db>>2]=o;Tb=Xb-(rb?Jb:0)|0;c[Bb>>2]=Tb;Zb=a[(rb&1)+(108560+(Gb<<1))|0]|0;if(Zb<<24>>24>0){Gb=Zb<<24>>24;Mb=o;f=Yb;Wb=Tb}else{break}}a[g+9|0]=-Zb;Wa=0;Xa=0}Zb=d[1678874+(c[k>>2]<<1)|0]|0;do{if((Zb|0)==1){a[(c[e+30116>>2]|0)+i|0]=a[aa]|0;a[(c[e+30120>>2]|0)+i|0]=c[g+52>>2];a[(c[e+30096>>2]|0)+i|0]=a[1403232+(c[k>>2]|0)|0]|0;if((a[ca]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}a[(c[e+30128>>2]|0)+i|0]=a[wa]|0;a[(c[e+30132>>2]|0)+i|0]=a[g+2|0]|0;a[(c[e+30100>>2]|0)+i|0]=a[g+8|0]|0;if((a[wa]|0)!=0){break}a[(c[e+30136>>2]|0)+i|0]=Wa;if((c[e+1148>>2]|0)!=4){break}a[(c[e+30140>>2]|0)+i|0]=Xa}else if((Zb|0)==4){Wb=ba(d[aa]|0,16843009)|0;c[(c[e+30116>>2]|0)+i>>2]=Wb;Wb=ba(c[g+52>>2]|0,16843009)|0;c[(c[e+30120>>2]|0)+i>>2]=Wb;Wb=ba(d[1403232+(c[k>>2]|0)|0]|0,16843009)|0;c[(c[e+30096>>2]|0)+i>>2]=Wb;if((a[ca]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}Wb=ba(d[wa]|0,16843009)|0;c[(c[e+30128>>2]|0)+i>>2]=Wb;Wb=ba(d[g+2|0]|0,16843009)|0;c[(c[e+30132>>2]|0)+i>>2]=Wb;Wb=ba(d[g+8|0]|0,16843009)|0;c[(c[e+30100>>2]|0)+i>>2]=Wb;if((a[wa]|0)!=0){break}Wb=ba(Wa,16843009)|0;c[(c[e+30136>>2]|0)+i>>2]=Wb;if((c[e+1148>>2]|0)!=4){break}Wb=ba(Xa,16843009)|0;c[(c[e+30140>>2]|0)+i>>2]=Wb}else if((Zb|0)==8){Wb=ba(d[aa]|0,16843009)|0;Yb=e+30116|0;c[(c[Yb>>2]|0)+i>>2]=Wb;f=i+4|0;c[(c[Yb>>2]|0)+f>>2]=Wb;Wb=ba(c[g+52>>2]|0,16843009)|0;Yb=e+30120|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;Wb=ba(d[1403232+(c[k>>2]|0)|0]|0,16843009)|0;Yb=e+30096|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;if((a[ca]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}Wb=ba(d[wa]|0,16843009)|0;Yb=e+30128|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;Wb=ba(d[g+2|0]|0,16843009)|0;Yb=e+30132|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;Wb=ba(d[g+8|0]|0,16843009)|0;Yb=e+30100|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;if((a[wa]|0)!=0){break}Wb=ba(Wa,16843009)|0;Yb=e+30136|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;if((c[e+1148>>2]|0)!=4){break}Wb=ba(Xa,16843009)|0;Yb=e+30140|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb}else if((Zb|0)==2){b[(c[e+30116>>2]|0)+i>>1]=(d[aa]|0)*257;b[(c[e+30120>>2]|0)+i>>1]=(c[g+52>>2]|0)*257|0;b[(c[e+30096>>2]|0)+i>>1]=(d[1403232+(c[k>>2]|0)|0]|0)*257;if((a[ca]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}b[(c[e+30128>>2]|0)+i>>1]=(d[wa]|0)*257;b[(c[e+30132>>2]|0)+i>>1]=(d[g+2|0]|0)*257;b[(c[e+30100>>2]|0)+i>>1]=(d[g+8|0]|0)*257;if((a[wa]|0)!=0){break}b[(c[e+30136>>2]|0)+i>>1]=Wa*257|0;if((c[e+1148>>2]|0)!=4){break}b[(c[e+30140>>2]|0)+i>>1]=Xa*257|0}}while(0);Zb=d[1678875+(c[k>>2]<<1)|0]|0;do{if((Zb|0)==4){c[e+(j+30040)>>2]=ba(d[aa]|0,16843009)|0;c[e+(j+30048)>>2]=ba(c[g+52>>2]|0,16843009)|0;c[e+(j+30032)>>2]=ba(d[1403016+(c[k>>2]|0)|0]|0,16843009)|0;if((a[ca]|0)!=0){break}if((a[e+1144|0]|0)!=0){$=449;break}c[e+(j+30064)>>2]=ba(d[wa]|0,16843009)|0;c[e+(j+30072)>>2]=ba(d[g+2|0]|0,16843009)|0;c[e+(j+29872)>>2]=ba(d[g+8|0]|0,16843009)|0;if((a[wa]|0)!=0){$=449;break}c[e+(j+30080)>>2]=ba(Wa,16843009)|0;if((c[e+1148>>2]|0)!=4){$=449;break}c[e+(j+30088)>>2]=ba(Xa,16843009)|0;$=449}else if((Zb|0)==2){b[e+(j+30040)>>1]=(d[aa]|0)*257;b[e+(j+30048)>>1]=(c[g+52>>2]|0)*257|0;b[e+(j+30032)>>1]=(d[1403016+(c[k>>2]|0)|0]|0)*257;if((a[ca]|0)!=0){break}if((a[e+1144|0]|0)!=0){$=449;break}b[e+(j+30064)>>1]=(d[wa]|0)*257;b[e+(j+30072)>>1]=(d[g+2|0]|0)*257;b[e+(j+29872)>>1]=(d[g+8|0]|0)*257;if((a[wa]|0)!=0){$=449;break}b[e+(j+30080)>>1]=Wa*257|0;if((c[e+1148>>2]|0)!=4){$=449;break}b[e+(j+30088)>>1]=Xa*257|0;$=449}else if((Zb|0)==1){a[e+(j+30040)|0]=a[aa]|0;a[e+(j+30048)|0]=c[g+52>>2];a[e+(j+30032)|0]=a[1403016+(c[k>>2]|0)|0]|0;if((a[ca]|0)!=0){break}if((a[e+1144|0]|0)!=0){$=449;break}a[e+(j+30064)|0]=a[wa]|0;a[e+(j+30072)|0]=a[g+2|0]|0;a[e+(j+29872)|0]=a[g+8|0]|0;if((a[wa]|0)!=0){$=449;break}a[e+(j+30080)|0]=Wa;if((c[e+1148>>2]|0)!=4){$=449;break}a[e+(j+30088)|0]=Xa;$=449}else if((Zb|0)==8){Wb=ba(d[aa]|0,16843009)|0;c[e+(j+30040)>>2]=Wb;c[e+(j+30044)>>2]=Wb;Wb=ba(c[g+52>>2]|0,16843009)|0;c[e+(j+30048)>>2]=Wb;c[e+(j+30052)>>2]=Wb;Wb=ba(d[1403016+(c[k>>2]|0)|0]|0,16843009)|0;c[e+(j+30032)>>2]=Wb;c[e+(j+30036)>>2]=Wb;if((a[ca]|0)!=0){break}if((a[e+1144|0]|0)!=0){$=449;break}Wb=ba(d[wa]|0,16843009)|0;c[e+(j+30064)>>2]=Wb;c[e+(j+30068)>>2]=Wb;Wb=ba(d[g+2|0]|0,16843009)|0;c[e+(j+30072)>>2]=Wb;c[e+(j+30076)>>2]=Wb;Wb=ba(d[g+8|0]|0,16843009)|0;c[e+(j+29872)>>2]=Wb;c[e+(j+29876)>>2]=Wb;if((a[wa]|0)!=0){$=449;break}Wb=ba(Wa,16843009)|0;c[e+(j+30080)>>2]=Wb;c[e+(j+30084)>>2]=Wb;if((c[e+1148>>2]|0)!=4){$=449;break}Wb=ba(Xa,16843009)|0;c[e+(j+30088)>>2]=Wb;c[e+(j+30092)>>2]=Wb;$=449}else{$=449}}while(0);do{if(($|0)==449){if((a[ca]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}Xa=c[g+40>>2]|0;Wa=c[g+44>>2]|0;if((c[k>>2]|0)>>>0>9>>>0){aa=j<<1;Zb=e+29888|0;c[Zb+(aa<<3)>>2]=c[g+24>>2];c[Zb+(aa<<3)+4>>2]=c[g+28>>2];Wb=aa|1;c[Zb+(Wb<<3)>>2]=Xa;c[Zb+(Wb<<3)+4>>2]=Wa;Wb=i<<1;Zb=e+30144|0;c[(c[Zb>>2]|0)+(Wb<<3)>>2]=c[g+32>>2];c[(c[Zb>>2]|0)+(Wb<<3)+4>>2]=c[g+36>>2];aa=Wb|1;c[(c[Zb>>2]|0)+(aa<<3)>>2]=Xa;c[(c[Zb>>2]|0)+(aa<<3)+4>>2]=Wa;break}aa=p<<1;if((aa|0)>0){Zb=i<<1;Wb=e+30144|0;f=0;do{Yb=f+Zb|0;c[(c[Wb>>2]|0)+(Yb<<3)>>2]=Xa;c[(c[Wb>>2]|0)+(Yb<<3)+4>>2]=Wa;f=f+1|0;}while((f|0)<(aa|0))}aa=l<<1;if((aa|0)<=0){break}f=j<<1;Wb=e+29888|0;Zb=0;do{wb=Zb+f|0;c[Wb+(wb<<3)>>2]=Xa;c[Wb+(wb<<3)+4>>2]=Wa;Zb=Zb+1|0;}while((Zb|0)<(aa|0))}}while(0);if((l|0)<=0){return}j=e+1796|0;k=e+1380|0;e=g+2|0;ca=(p|0)>0;$=g+3|0;aa=g+4|0;Zb=g+40|0;Wa=g+44|0;Wb=g+40|0;g=0;do{Xa=(ba(g+h<<3,c[j>>2]|0)|0)+i|0;f=c[k>>2]|0;do{if((a[wa]|0)==0){if((a[e]|0)==0){if(ca){_b=0}else{break}do{wb=_b+Xa|0;a[f+(wb*12|0)+8|0]=a[$]|0;a[f+(wb*12|0)+9|0]=-1;c[f+(wb*12|0)>>2]=c[Wb>>2];_b=_b+1|0;}while((_b|0)<(p|0))}else{if(ca){$b=0}else{break}do{tb=$b+Xa|0;a[f+(tb*12|0)+8|0]=a[$]|0;a[f+(tb*12|0)+9|0]=a[aa]|0;c[f+(tb*12|0)>>2]=c[Zb>>2];c[f+(tb*12|0)+4>>2]=c[Wa>>2];$b=$b+1|0;}while(($b|0)<(p|0))}}else{if(ca){ac=0}else{break}do{tb=ac+Xa|0;a[f+(tb*12|0)+9|0]=-1;a[f+(tb*12|0)+8|0]=-1;ac=ac+1|0;}while((ac|0)<(p|0))}}while(0);g=g+1|0;}while((g|0)<(l|0));return}function M6a(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0;q=i;i=i+1024|0;r=q|0;s=e|0;t=e+4|0;u=e+16|0;v=e+8|0;w=e+12|0;e=l;y=k+(l*11|0)|0;l=b[o>>1]|0;z=0;A=0;B=c[s>>2]|0;C=c[t>>2]|0;D=c[u>>2]|0;a:while(1){E=d[y]|0;F=d[1086680+B|0]|0;G=B<<F;c[s>>2]=G;H=D<<F;I=F+C|0;do{if((I|0)>-1){F=c[v>>2]|0;if(!(F>>>0<(c[w>>2]|0)>>>0)){J=H;K=I;break}c[v>>2]=F+2;L=F;J=((de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<I|H;K=I-16|0}else{J=H;K=I}}while(0);c[t>>2]=K;M=((ba(G-1|0,E)|0)>>8)+1|0;I=M<<16;if(J>>>0<I>>>0){N=6;break}c[s>>2]=G-M;c[u>>2]=J-I;I=j+(z*48|0)+(e<<3)+4|0;c[I>>2]=(c[I>>2]|0)+1;I=e;H=y;L=l;F=z;O=A;while(1){P=d[H+1|0]|0;Q=c[s>>2]|0;R=d[1086680+Q|0]|0;S=c[t>>2]|0;T=c[u>>2]|0;U=Q<<R;c[s>>2]=U;Q=T<<R;T=S+R|0;do{if((T|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){V=Q;W=T;break}c[v>>2]=R+2;S=R;V=((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)<<T|Q;W=T-16|0}else{V=Q;W=T}}while(0);c[t>>2]=W;X=((ba(U-1|0,P)|0)>>8)+1|0;Y=X<<16;if(!(V>>>0<Y>>>0)){break}c[s>>2]=X;c[u>>2]=V;T=h+(F*72|0)+(I*12|0)|0;c[T>>2]=(c[T>>2]|0)+1;T=L-1|0;if((T|0)==0){Q=F+1|0;Z=b[o+(Q<<1)>>1]|0;_=Q}else{Z=T;_=F}a[r+(b[m+(O<<1)>>1]|0)|0]=0;T=((d[r+(b[n+(O<<2)>>1]|0)|0]|0)+1+(d[r+(b[n+(O<<2)+2>>1]|0)|0]|0)|0)>>>1;Q=O+1|0;if((Q|0)==(g|0)){$=g;N=154;break a}else{I=T;H=k+(_*66|0)+(T*11|0)|0;L=Z;F=_;O=Q}}G=U-X|0;c[s>>2]=G;E=V-Y|0;c[u>>2]=E;Q=b[m+(O<<1)>>1]|0;T=H+2|0;S=d[T]|0;R=d[1086680+G|0]|0;aa=G<<R;c[s>>2]=aa;G=E<<R;E=R+W|0;do{if((E|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){ca=G;da=E;break}c[v>>2]=R+2;ea=R;ca=((de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<E|G;da=E-16|0}else{ca=G;da=E}}while(0);c[t>>2]=da;E=((ba(aa-1|0,S)|0)>>8)+1|0;G=E<<16;do{if(ca>>>0<G>>>0){c[s>>2]=E;c[u>>2]=ca;ea=h+(F*72|0)+(I*12|0)+4|0;c[ea>>2]=(c[ea>>2]|0)+1;a[r+Q|0]=1;fa=1}else{c[s>>2]=aa-E;c[u>>2]=ca-G;ea=H+3|0;if((a[ea]|0)==0){R=106512+(d[T]<<3)|0;ga=ea;ha=R|0;ia=R+4|0;R=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;ia=ga|0;x=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x;ia=ga+4|0;x=R;a[ia]=x;x=x>>8;a[ia+1|0]=x;x=x>>8;a[ia+2|0]=x;x=x>>8;a[ia+3|0]=x}ia=h+(F*72|0)+(I*12|0)+8|0;c[ia>>2]=(c[ia>>2]|0)+1;ia=d[ea]|0;ea=c[s>>2]|0;R=d[1086680+ea|0]|0;ga=c[t>>2]|0;ha=c[u>>2]|0;ja=ea<<R;c[s>>2]=ja;ea=ha<<R;ha=ga+R|0;do{if((ha|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){ka=ea;la=ha;break}c[v>>2]=R+2;ga=R;ka=((de((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)<<ha|ea;la=ha-16|0}else{ka=ea;la=ha}}while(0);c[t>>2]=la;ha=((ba(ja-1|0,ia)|0)>>8)+1|0;ea=ha<<16;if(ka>>>0<ea>>>0){c[s>>2]=ha;c[u>>2]=ka;P=d[H+4|0]|0;ga=d[1086680+ha|0]|0;R=ha<<ga;c[s>>2]=R;ma=ka<<ga;na=ga+la|0;do{if((na|0)>-1){ga=c[v>>2]|0;if(!(ga>>>0<(c[w>>2]|0)>>>0)){oa=ma;pa=na;break}c[v>>2]=ga+2;qa=ga;oa=((de((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<na|ma;pa=na-16|0}else{oa=ma;pa=na}}while(0);c[t>>2]=pa;na=((ba(R-1|0,P)|0)>>8)+1|0;ma=na<<16;if(oa>>>0<ma>>>0){c[s>>2]=na;c[u>>2]=oa;a[r+Q|0]=2;fa=2;break}ia=R-na|0;c[s>>2]=ia;na=oa-ma|0;c[u>>2]=na;ma=a[H+5|0]|0;qa=d[1086680+ia|0]|0;ga=ia<<qa;c[s>>2]=ga;ia=na<<qa;na=qa+pa|0;do{if((na|0)>-1){qa=c[v>>2]|0;if(!(qa>>>0<(c[w>>2]|0)>>>0)){ra=ia;sa=na;break}c[v>>2]=qa+2;ta=qa;ra=((de((d[ta]|d[ta+1|0]<<8)<<16>>16|0)|0)&65535)<<na|ia;sa=na-16|0}else{ra=ia;sa=na}}while(0);c[t>>2]=sa;na=((ba(ga-1|0,ma&255)|0)>>8)+1|0;ia=na<<16;R=ra>>>0>=ia>>>0;c[s>>2]=R?ga-na|0:na;c[u>>2]=ra-(R?ia:0);a[r+Q|0]=3;fa=R?4:3;break}R=ja-ha|0;c[s>>2]=R;ia=ka-ea|0;c[u>>2]=ia;na=d[H+6|0]|0;P=d[1086680+R|0]|0;ta=R<<P;c[s>>2]=ta;R=ia<<P;ia=P+la|0;do{if((ia|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){ua=R;va=ia;break}c[v>>2]=P+2;qa=P;ua=((de((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ia|R;va=ia-16|0}else{ua=R;va=ia}}while(0);c[t>>2]=va;ia=((ba(ta-1|0,na)|0)>>8)+1|0;R=ia<<16;if(ua>>>0<R>>>0){c[s>>2]=ia;c[u>>2]=ua;a[r+Q|0]=4;ea=d[H+7|0]|0;ha=d[1086680+ia|0]|0;ja=ia<<ha;c[s>>2]=ja;ga=ua<<ha;ma=ha+va|0;do{if((ma|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){wa=ga;xa=ma;break}c[v>>2]=ha+2;qa=ha;wa=((de((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|ga;xa=ma-16|0}else{wa=ga;xa=ma}}while(0);c[t>>2]=xa;ma=((ba(ja-1|0,ea)|0)>>8)+1|0;ga=ma<<16;if(wa>>>0<ga>>>0){c[u>>2]=wa;na=d[1086680+ma|0]|0;qa=ma<<na;c[s>>2]=qa;ha=wa<<na;P=na+xa|0;do{if((P|0)>-1){na=c[v>>2]|0;if(!(na>>>0<(c[w>>2]|0)>>>0)){ya=ha;za=P;break}c[v>>2]=na+2;Aa=na;ya=((de((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ha;za=P-16|0}else{ya=ha;za=P}}while(0);c[t>>2]=za;P=((qa*159|0)-159>>8)+1|0;ha=P<<16;ea=ya>>>0>=ha>>>0;c[s>>2]=ea?qa-P|0:P;c[u>>2]=ya-(ea?ha:0);fa=ea?6:5;break}ea=ja-ma|0;ha=wa-ga|0;c[u>>2]=ha;P=d[1086680+ea|0]|0;Aa=ea<<P;c[s>>2]=Aa;ea=ha<<P;ha=P+xa|0;do{if((ha|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){Ba=ea;Ca=ha;break}c[v>>2]=P+2;na=P;Ba=((de((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ha|ea;Ca=ha-16|0}else{Ba=ea;Ca=ha}}while(0);c[t>>2]=Ca;ha=((Aa*165|0)-165>>8)+1|0;ea=ha<<16;ga=Ba>>>0>=ea>>>0;ma=ga?Aa-ha|0:ha;ha=Ba-(ga?ea:0)|0;c[u>>2]=ha;ea=((ga&1)<<1)+7|0;ga=d[1086680+ma|0]|0;ja=ma<<ga;c[s>>2]=ja;ma=ha<<ga;ha=ga+Ca|0;do{if((ha|0)>-1){ga=c[v>>2]|0;if(!(ga>>>0<(c[w>>2]|0)>>>0)){Da=ma;Ea=ha;break}c[v>>2]=ga+2;qa=ga;Da=((de((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ha|ma;Ea=ha-16|0}else{Da=ma;Ea=ha}}while(0);c[t>>2]=Ea;ha=((ja*145|0)-145>>8)+1|0;ma=ha<<16;Aa=Da>>>0>=ma>>>0;c[s>>2]=Aa?ja-ha|0:ha;c[u>>2]=Da-(Aa?ma:0);fa=ea+(Aa&1)|0;break}Aa=ta-ia|0;c[s>>2]=Aa;ma=ua-R|0;c[u>>2]=ma;a[r+Q|0]=5;ha=d[H+8|0]|0;qa=d[1086680+Aa|0]|0;ga=Aa<<qa;c[s>>2]=ga;Aa=ma<<qa;ma=qa+va|0;do{if((ma|0)>-1){qa=c[v>>2]|0;if(!(qa>>>0<(c[w>>2]|0)>>>0)){Fa=Aa;Ga=ma;break}c[v>>2]=qa+2;na=qa;Fa=((de((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|Aa;Ga=ma-16|0}else{Fa=Aa;Ga=ma}}while(0);c[t>>2]=Ga;ma=((ba(ga-1|0,ha)|0)>>8)+1|0;Aa=ma<<16;if(Fa>>>0<Aa>>>0){c[s>>2]=ma;c[u>>2]=Fa;R=d[H+9|0]|0;ia=d[1086680+ma|0]|0;ta=ma<<ia;c[s>>2]=ta;ea=Fa<<ia;ja=ia+Ga|0;do{if((ja|0)>-1){ia=c[v>>2]|0;if(!(ia>>>0<(c[w>>2]|0)>>>0)){Ha=ea;Ia=ja;break}c[v>>2]=ia+2;na=ia;Ha=((de((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ja|ea;Ia=ja-16|0}else{Ha=ea;Ia=ja}}while(0);c[t>>2]=Ia;ja=((ba(ta-1|0,R)|0)>>8)+1|0;ea=ja<<16;if(Ha>>>0<ea>>>0){c[u>>2]=Ha;ha=d[1086680+ja|0]|0;na=ja<<ha;c[s>>2]=na;ia=Ha<<ha;qa=ha+Ia|0;do{if((qa|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){Ja=ia;Ka=qa;break}c[v>>2]=ha+2;P=ha;Ja=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<qa|ia;Ka=qa-16|0}else{Ja=ia;Ka=qa}}while(0);c[t>>2]=Ka;qa=((na*173|0)-173>>8)+1|0;ia=qa<<16;R=Ja>>>0>=ia>>>0;P=R?na-qa|0:qa;qa=Ja-(R?ia:0)|0;c[u>>2]=qa;ia=(R&1)<<2|11;R=d[1086680+P|0]|0;ha=P<<R;c[s>>2]=ha;P=qa<<R;qa=R+Ka|0;do{if((qa|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){La=P;Ma=qa;break}c[v>>2]=R+2;Na=R;La=((de((d[Na]|d[Na+1|0]<<8)<<16>>16|0)|0)&65535)<<qa|P;Ma=qa-16|0}else{La=P;Ma=qa}}while(0);c[t>>2]=Ma;qa=((ha*148|0)-148>>8)+1|0;P=qa<<16;na=La>>>0>=P>>>0;Na=na?ha-qa|0:qa;qa=La-(na?P:0)|0;c[u>>2]=qa;P=((na&1)<<1)+ia|0;na=d[1086680+Na|0]|0;R=Na<<na;c[s>>2]=R;Na=qa<<na;qa=na+Ma|0;do{if((qa|0)>-1){na=c[v>>2]|0;if(!(na>>>0<(c[w>>2]|0)>>>0)){Oa=Na;Pa=qa;break}c[v>>2]=na+2;Qa=na;Oa=((de((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<qa|Na;Pa=qa-16|0}else{Oa=Na;Pa=qa}}while(0);c[t>>2]=Pa;qa=((R*140|0)-140>>8)+1|0;Na=qa<<16;ia=Oa>>>0>=Na>>>0;c[s>>2]=ia?R-qa|0:qa;c[u>>2]=Oa-(ia?Na:0);fa=P+(ia&1)|0;break}ia=ta-ja|0;Na=Ha-ea|0;c[u>>2]=Na;qa=d[1086680+ia|0]|0;ha=ia<<qa;c[s>>2]=ha;ia=Na<<qa;Na=qa+Ia|0;do{if((Na|0)>-1){qa=c[v>>2]|0;if(!(qa>>>0<(c[w>>2]|0)>>>0)){Ra=ia;Sa=Na;break}c[v>>2]=qa+2;Qa=qa;Ra=((de((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<Na|ia;Sa=Na-16|0}else{Ra=ia;Sa=Na}}while(0);c[t>>2]=Sa;Na=((ha*176|0)-176>>8)+1|0;ia=Na<<16;ea=Ra>>>0>=ia>>>0;ja=ea?ha-Na|0:Na;Na=Ra-(ea?ia:0)|0;c[u>>2]=Na;ia=(ea&1)<<3;ea=d[1086680+ja|0]|0;ta=ja<<ea;c[s>>2]=ta;ja=Na<<ea;Na=ea+Sa|0;do{if((Na|0)>-1){ea=c[v>>2]|0;if(!(ea>>>0<(c[w>>2]|0)>>>0)){Ta=ja;Ua=Na;break}c[v>>2]=ea+2;P=ea;Ta=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<Na|ja;Ua=Na-16|0}else{Ta=ja;Ua=Na}}while(0);c[t>>2]=Ua;Na=((ta*155|0)-155>>8)+1|0;ja=Na<<16;ha=Ta>>>0>=ja>>>0;P=ha?ta-Na|0:Na;Na=Ta-(ha?ja:0)|0;c[u>>2]=Na;ja=ia|(ha&1)<<2|19;ha=d[1086680+P|0]|0;ea=P<<ha;c[s>>2]=ea;P=Na<<ha;Na=ha+Ua|0;do{if((Na|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){Va=P;Wa=Na;break}c[v>>2]=ha+2;R=ha;Va=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<Na|P;Wa=Na-16|0}else{Va=P;Wa=Na}}while(0);c[t>>2]=Wa;Na=((ea*140|0)-140>>8)+1|0;P=Na<<16;ia=Va>>>0>=P>>>0;ta=ia?ea-Na|0:Na;Na=Va-(ia?P:0)|0;c[u>>2]=Na;P=((ia&1)<<1)+ja|0;ia=d[1086680+ta|0]|0;R=ta<<ia;c[s>>2]=R;ta=Na<<ia;Na=ia+Wa|0;do{if((Na|0)>-1){ia=c[v>>2]|0;if(!(ia>>>0<(c[w>>2]|0)>>>0)){Xa=ta;Ya=Na;break}c[v>>2]=ia+2;ha=ia;Xa=((de((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535)<<Na|ta;Ya=Na-16|0}else{Xa=ta;Ya=Na}}while(0);c[t>>2]=Ya;Na=((R*135|0)-135>>8)+1|0;ta=Na<<16;ja=Xa>>>0>=ta>>>0;c[s>>2]=ja?R-Na|0:Na;c[u>>2]=Xa-(ja?ta:0);fa=P+(ja&1)|0;break}ja=ga-ma|0;c[s>>2]=ja;ta=Fa-Aa|0;c[u>>2]=ta;Na=d[H+10|0]|0;ea=d[1086680+ja|0]|0;ha=ja<<ea;c[s>>2]=ha;ja=ta<<ea;ta=ea+Ga|0;do{if((ta|0)>-1){ea=c[v>>2]|0;if(!(ea>>>0<(c[w>>2]|0)>>>0)){Za=ja;_a=ta;break}c[v>>2]=ea+2;ia=ea;Za=((de((d[ia]|d[ia+1|0]<<8)<<16>>16|0)|0)&65535)<<ta|ja;_a=ta-16|0}else{Za=ja;_a=ta}}while(0);c[t>>2]=_a;ta=((ba(ha-1|0,Na)|0)>>8)+1|0;ja=ta<<16;if(Za>>>0<ja>>>0){c[u>>2]=Za;Aa=d[1086680+ta|0]|0;ma=ta<<Aa;c[s>>2]=ma;ga=Za<<Aa;P=Aa+_a|0;do{if((P|0)>-1){Aa=c[v>>2]|0;if(!(Aa>>>0<(c[w>>2]|0)>>>0)){$a=ga;ab=P;break}c[v>>2]=Aa+2;R=Aa;$a=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ga;ab=P-16|0}else{$a=ga;ab=P}}while(0);c[t>>2]=ab;P=((ma*180|0)-180>>8)+1|0;ga=P<<16;Na=$a>>>0>=ga>>>0;R=Na?ma-P|0:P;P=$a-(Na?ga:0)|0;c[u>>2]=P;ga=(Na&1)<<4;Na=d[1086680+R|0]|0;Aa=R<<Na;c[s>>2]=Aa;R=P<<Na;P=Na+ab|0;do{if((P|0)>-1){Na=c[v>>2]|0;if(!(Na>>>0<(c[w>>2]|0)>>>0)){bb=R;cb=P;break}c[v>>2]=Na+2;ia=Na;bb=((de((d[ia]|d[ia+1|0]<<8)<<16>>16|0)|0)&65535)<<P|R;cb=P-16|0}else{bb=R;cb=P}}while(0);c[t>>2]=cb;P=((Aa*157|0)-157>>8)+1|0;R=P<<16;ma=bb>>>0>=R>>>0;ia=ma?Aa-P|0:P;P=bb-(ma?R:0)|0;c[u>>2]=P;R=(ma&1)<<3;ma=d[1086680+ia|0]|0;Na=ia<<ma;c[s>>2]=Na;ia=P<<ma;P=ma+cb|0;do{if((P|0)>-1){ma=c[v>>2]|0;if(!(ma>>>0<(c[w>>2]|0)>>>0)){db=ia;eb=P;break}c[v>>2]=ma+2;ea=ma;db=((de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ia;eb=P-16|0}else{db=ia;eb=P}}while(0);c[t>>2]=eb;P=((Na*141|0)-141>>8)+1|0;ia=P<<16;Aa=db>>>0>=ia>>>0;ea=Aa?Na-P|0:P;P=db-(Aa?ia:0)|0;c[u>>2]=P;ia=ga|R|(Aa&1)<<2|35;Aa=d[1086680+ea|0]|0;ma=ea<<Aa;c[s>>2]=ma;ea=P<<Aa;P=Aa+eb|0;do{if((P|0)>-1){Aa=c[v>>2]|0;if(!(Aa>>>0<(c[w>>2]|0)>>>0)){fb=ea;gb=P;break}c[v>>2]=Aa+2;Qa=Aa;fb=((de((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ea;gb=P-16|0}else{fb=ea;gb=P}}while(0);c[t>>2]=gb;P=((ma*134|0)-134>>8)+1|0;ea=P<<16;R=fb>>>0>=ea>>>0;ga=R?ma-P|0:P;P=fb-(R?ea:0)|0;c[u>>2]=P;ea=((R&1)<<1)+ia|0;R=d[1086680+ga|0]|0;Na=ga<<R;c[s>>2]=Na;ga=P<<R;P=R+gb|0;do{if((P|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){hb=ga;ib=P;break}c[v>>2]=R+2;Qa=R;hb=((de((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ga;ib=P-16|0}else{hb=ga;ib=P}}while(0);c[t>>2]=ib;P=((Na*130|0)-130>>8)+1|0;ga=P<<16;ia=hb>>>0>=ga>>>0;c[s>>2]=ia?Na-P|0:P;c[u>>2]=hb-(ia?ga:0);fa=ea+(ia&1)|0;break}ia=ha-ta|0;ga=Za-ja|0;c[u>>2]=ga;P=d[1086680+ia|0]|0;ma=ia<<P;c[s>>2]=ma;ia=ga<<P;ga=P+_a|0;do{if((ga|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){jb=ia;kb=ga;break}c[v>>2]=P+2;Qa=P;jb=((de((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ia;kb=ga-16|0}else{jb=ia;kb=ga}}while(0);c[t>>2]=kb;ga=((ma*254|0)-254>>8)+1|0;ia=ga<<16;ja=jb>>>0>=ia>>>0;ta=ja?ma-ga|0:ga;ga=jb-(ja?ia:0)|0;c[u>>2]=ga;ia=(ja&1)<<13;ja=d[1086680+ta|0]|0;ha=ta<<ja;c[s>>2]=ha;ta=ga<<ja;ga=ja+kb|0;do{if((ga|0)>-1){ja=c[v>>2]|0;if(!(ja>>>0<(c[w>>2]|0)>>>0)){lb=ta;mb=ga;break}c[v>>2]=ja+2;ea=ja;lb=((de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ta;mb=ga-16|0}else{lb=ta;mb=ga}}while(0);c[t>>2]=mb;ga=((ha*254|0)-254>>8)+1|0;ta=ga<<16;ma=lb>>>0>=ta>>>0;ea=ma?ha-ga|0:ga;ga=lb-(ma?ta:0)|0;c[u>>2]=ga;ta=(ma&1)<<12;ma=d[1086680+ea|0]|0;ja=ea<<ma;c[s>>2]=ja;ea=ga<<ma;ga=ma+mb|0;do{if((ga|0)>-1){ma=c[v>>2]|0;if(!(ma>>>0<(c[w>>2]|0)>>>0)){nb=ea;ob=ga;break}c[v>>2]=ma+2;Na=ma;nb=((de((d[Na]|d[Na+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ea;ob=ga-16|0}else{nb=ea;ob=ga}}while(0);c[t>>2]=ob;ga=((ja*254|0)-254>>8)+1|0;ea=ga<<16;ha=nb>>>0>=ea>>>0;Na=ha?ja-ga|0:ga;ga=nb-(ha?ea:0)|0;c[u>>2]=ga;ea=(ha&1)<<11;ha=d[1086680+Na|0]|0;ma=Na<<ha;c[s>>2]=ma;Na=ga<<ha;ga=ha+ob|0;do{if((ga|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){pb=Na;qb=ga;break}c[v>>2]=ha+2;Qa=ha;pb=((de((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|Na;qb=ga-16|0}else{pb=Na;qb=ga}}while(0);c[t>>2]=qb;ga=((ma*252|0)-252>>8)+1|0;Na=ga<<16;ja=pb>>>0>=Na>>>0;Qa=ja?ma-ga|0:ga;ga=pb-(ja?Na:0)|0;c[u>>2]=ga;Na=(ja&1)<<10;ja=d[1086680+Qa|0]|0;ha=Qa<<ja;c[s>>2]=ha;Qa=ga<<ja;ga=ja+qb|0;do{if((ga|0)>-1){ja=c[v>>2]|0;if(!(ja>>>0<(c[w>>2]|0)>>>0)){rb=Qa;sb=ga;break}c[v>>2]=ja+2;P=ja;rb=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|Qa;sb=ga-16|0}else{rb=Qa;sb=ga}}while(0);c[t>>2]=sb;ga=((ha*249|0)-249>>8)+1|0;Qa=ga<<16;ma=rb>>>0>=Qa>>>0;P=ma?ha-ga|0:ga;ga=rb-(ma?Qa:0)|0;c[u>>2]=ga;Qa=(ma&1)<<9;ma=d[1086680+P|0]|0;ja=P<<ma;c[s>>2]=ja;P=ga<<ma;ga=ma+sb|0;do{if((ga|0)>-1){ma=c[v>>2]|0;if(!(ma>>>0<(c[w>>2]|0)>>>0)){tb=P;ub=ga;break}c[v>>2]=ma+2;R=ma;tb=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|P;ub=ga-16|0}else{tb=P;ub=ga}}while(0);c[t>>2]=ub;ga=((ja*243|0)-243>>8)+1|0;P=ga<<16;ha=tb>>>0>=P>>>0;R=ha?ja-ga|0:ga;ga=tb-(ha?P:0)|0;c[u>>2]=ga;P=ia|ta|ea|Na|Qa|(ha&1)<<8|67;ha=d[1086680+R|0]|0;ma=R<<ha;c[s>>2]=ma;R=ga<<ha;ga=ha+ub|0;do{if((ga|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){vb=R;wb=ga;break}c[v>>2]=ha+2;Aa=ha;vb=((de((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|R;wb=ga-16|0}else{vb=R;wb=ga}}while(0);c[t>>2]=wb;ga=((ma*230|0)-230>>8)+1|0;R=ga<<16;Qa=vb>>>0>=R>>>0;Na=Qa?ma-ga|0:ga;ga=vb-(Qa?R:0)|0;c[u>>2]=ga;R=((Qa&1)<<7)+P|0;Qa=d[1086680+Na|0]|0;ea=Na<<Qa;c[s>>2]=ea;Na=ga<<Qa;ga=Qa+wb|0;do{if((ga|0)>-1){Qa=c[v>>2]|0;if(!(Qa>>>0<(c[w>>2]|0)>>>0)){xb=Na;yb=ga;break}c[v>>2]=Qa+2;ta=Qa;xb=((de((d[ta]|d[ta+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|Na;yb=ga-16|0}else{xb=Na;yb=ga}}while(0);c[t>>2]=yb;ga=((ea*196|0)-196>>8)+1|0;Na=ga<<16;P=xb>>>0>=Na>>>0;ma=P?ea-ga|0:ga;ga=xb-(P?Na:0)|0;c[u>>2]=ga;Na=R+((P&1)<<6)|0;P=d[1086680+ma|0]|0;ta=ma<<P;c[s>>2]=ta;ma=ga<<P;ga=P+yb|0;do{if((ga|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){zb=ma;Ab=ga;break}c[v>>2]=P+2;Qa=P;zb=((de((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ma;Ab=ga-16|0}else{zb=ma;Ab=ga}}while(0);c[t>>2]=Ab;ga=((ta*177|0)-177>>8)+1|0;ma=ga<<16;R=zb>>>0>=ma>>>0;ea=R?ta-ga|0:ga;ga=zb-(R?ma:0)|0;c[u>>2]=ga;ma=Na+((R&1)<<5)|0;R=d[1086680+ea|0]|0;Qa=ea<<R;c[s>>2]=Qa;ea=ga<<R;ga=R+Ab|0;do{if((ga|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){Bb=ea;Cb=ga;break}c[v>>2]=R+2;P=R;Bb=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ea;Cb=ga-16|0}else{Bb=ea;Cb=ga}}while(0);c[t>>2]=Cb;ga=((Qa*153|0)-153>>8)+1|0;ea=ga<<16;Na=Bb>>>0>=ea>>>0;ta=Na?Qa-ga|0:ga;ga=Bb-(Na?ea:0)|0;c[u>>2]=ga;ea=ma+((Na&1)<<4)|0;Na=d[1086680+ta|0]|0;P=ta<<Na;c[s>>2]=P;ta=ga<<Na;ga=Na+Cb|0;do{if((ga|0)>-1){Na=c[v>>2]|0;if(!(Na>>>0<(c[w>>2]|0)>>>0)){Db=ta;Eb=ga;break}c[v>>2]=Na+2;R=Na;Db=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ta;Eb=ga-16|0}else{Db=ta;Eb=ga}}while(0);c[t>>2]=Eb;ga=((P*140|0)-140>>8)+1|0;ta=ga<<16;ma=Db>>>0>=ta>>>0;Qa=ma?P-ga|0:ga;ga=Db-(ma?ta:0)|0;c[u>>2]=ga;ta=ea+((ma&1)<<3)|0;ma=d[1086680+Qa|0]|0;R=Qa<<ma;c[s>>2]=R;Qa=ga<<ma;ga=ma+Eb|0;do{if((ga|0)>-1){ma=c[v>>2]|0;if(!(ma>>>0<(c[w>>2]|0)>>>0)){Fb=Qa;Gb=ga;break}c[v>>2]=ma+2;Na=ma;Fb=((de((d[Na]|d[Na+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|Qa;Gb=ga-16|0}else{Fb=Qa;Gb=ga}}while(0);c[t>>2]=Gb;ga=((R*133|0)-133>>8)+1|0;Qa=ga<<16;ea=Fb>>>0>=Qa>>>0;P=ea?R-ga|0:ga;ga=Fb-(ea?Qa:0)|0;c[u>>2]=ga;Qa=ta+((ea&1)<<2)|0;ea=d[1086680+P|0]|0;Na=P<<ea;c[s>>2]=Na;P=ga<<ea;ga=ea+Gb|0;do{if((ga|0)>-1){ea=c[v>>2]|0;if(!(ea>>>0<(c[w>>2]|0)>>>0)){Hb=P;Ib=ga;break}c[v>>2]=ea+2;ma=ea;Hb=((de((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|P;Ib=ga-16|0}else{Hb=P;Ib=ga}}while(0);c[t>>2]=Ib;ga=((Na*130|0)-130>>8)+1|0;P=ga<<16;ta=Hb>>>0>=P>>>0;R=ta?Na-ga|0:ga;ga=Hb-(ta?P:0)|0;c[u>>2]=ga;P=Qa+((ta&1)<<1)|0;ta=d[1086680+R|0]|0;ma=R<<ta;c[s>>2]=ma;R=ga<<ta;ga=ta+Ib|0;do{if((ga|0)>-1){ta=c[v>>2]|0;if(!(ta>>>0<(c[w>>2]|0)>>>0)){Jb=R;Kb=ga;break}c[v>>2]=ta+2;ea=ta;Jb=((de((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|R;Kb=ga-16|0}else{Jb=R;Kb=ga}}while(0);c[t>>2]=Kb;ga=((ma*129|0)-129>>8)+1|0;R=ga<<16;Qa=Jb>>>0>=R>>>0;c[s>>2]=Qa?ma-ga|0:ga;c[u>>2]=Jb-(Qa?R:0);fa=P+(Qa&1)|0}}while(0);H=L-1|0;if((H|0)==0){I=F+1|0;Lb=b[o+(I<<1)>>1]|0;Mb=I}else{Lb=H;Mb=F}H=c[s>>2]|0;I=d[1086680+H|0]|0;T=c[t>>2]|0;G=c[u>>2]|0;E=H<<I;c[s>>2]=E;H=G<<I;G=T+I|0;do{if((G|0)>-1){I=c[v>>2]|0;if(!(I>>>0<(c[w>>2]|0)>>>0)){Nb=H;Ob=G;break}c[v>>2]=I+2;T=I;Nb=((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<G|H;Ob=G-16|0}else{Nb=H;Ob=G}}while(0);c[t>>2]=Ob;G=((E<<7)-128>>8)+1|0;H=G<<16;F=Nb>>>0>=H>>>0;L=F?E-G|0:G;c[s>>2]=L;G=Nb-(F?H:0)|0;c[u>>2]=G;b[f+(Q<<1)>>1]=ba(F?-fa|0:fa,b[p+(((O|0)!=0)<<1)>>1]|0)|0;F=((d[r+(b[n+(O<<2)>>1]|0)|0]|0)+1+(d[r+(b[n+(O<<2)+2>>1]|0)|0]|0)|0)>>>1;H=O+1|0;if((H|0)<(g|0)){e=F;y=k+(Mb*66|0)+(F*11|0)|0;l=Lb;z=Mb;A=H;B=L;C=Ob;D=G}else{$=H;N=154;break}}if((N|0)==6){c[s>>2]=M;c[u>>2]=J;J=j+(z*48|0)+(e<<3)|0;c[J>>2]=(c[J>>2]|0)+1;$=A;i=q;return $|0}else if((N|0)==154){i=q;return $|0}return 0}function N6a(e,f,g,h,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0;p=i;i=i+1024|0;q=p|0;r=e|0;s=e+4|0;t=e+16|0;u=e+8|0;v=e+12|0;e=k;w=j+(k*11|0)|0;k=b[n>>1]|0;y=0;z=0;A=c[r>>2]|0;B=c[s>>2]|0;C=c[t>>2]|0;a:while(1){D=d[w]|0;E=d[1086680+A|0]|0;F=A<<E;c[r>>2]=F;G=C<<E;H=E+B|0;do{if((H|0)>-1){E=c[u>>2]|0;if(!(E>>>0<(c[v>>2]|0)>>>0)){I=G;J=H;break}c[u>>2]=E+2;K=E;I=((de((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535)<<H|G;J=H-16|0}else{I=G;J=H}}while(0);c[s>>2]=J;L=((ba(F-1|0,D)|0)>>8)+1|0;H=L<<16;if(I>>>0<H>>>0){M=6;break}c[r>>2]=F-L;c[t>>2]=I-H;H=h+(y*48|0)+(e<<3)+4|0;c[H>>2]=(c[H>>2]|0)+1;H=e;G=w;K=k;E=y;N=z;while(1){O=d[G+1|0]|0;P=c[r>>2]|0;Q=d[1086680+P|0]|0;R=c[s>>2]|0;S=c[t>>2]|0;T=P<<Q;c[r>>2]=T;P=S<<Q;S=R+Q|0;do{if((S|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){U=P;V=S;break}c[u>>2]=Q+2;R=Q;U=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<S|P;V=S-16|0}else{U=P;V=S}}while(0);c[s>>2]=V;W=((ba(T-1|0,O)|0)>>8)+1|0;X=W<<16;if(!(U>>>0<X>>>0)){break}c[r>>2]=W;c[t>>2]=U;S=g+(E*72|0)+(H*12|0)|0;c[S>>2]=(c[S>>2]|0)+1;S=K-1|0;if((S|0)==0){P=E+1|0;Y=b[n+(P<<1)>>1]|0;Z=P}else{Y=S;Z=E}a[q+(b[l+(N<<1)>>1]|0)|0]=0;S=((d[q+(b[m+(N<<2)>>1]|0)|0]|0)+1+(d[q+(b[m+(N<<2)+2>>1]|0)|0]|0)|0)>>>1;P=N+1|0;if((P|0)==1024){_=1024;M=154;break a}else{H=S;G=j+(Z*66|0)+(S*11|0)|0;K=Y;E=Z;N=P}}F=T-W|0;c[r>>2]=F;D=U-X|0;c[t>>2]=D;P=b[l+(N<<1)>>1]|0;S=G+2|0;R=d[S]|0;Q=d[1086680+F|0]|0;$=F<<Q;c[r>>2]=$;F=D<<Q;D=Q+V|0;do{if((D|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){aa=F;ca=D;break}c[u>>2]=Q+2;da=Q;aa=((de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<D|F;ca=D-16|0}else{aa=F;ca=D}}while(0);c[s>>2]=ca;D=((ba($-1|0,R)|0)>>8)+1|0;F=D<<16;do{if(aa>>>0<F>>>0){c[r>>2]=D;c[t>>2]=aa;da=g+(E*72|0)+(H*12|0)+4|0;c[da>>2]=(c[da>>2]|0)+1;a[q+P|0]=1;ea=1}else{c[r>>2]=$-D;c[t>>2]=aa-F;da=G+3|0;if((a[da]|0)==0){Q=106512+(d[S]<<3)|0;fa=da;ga=Q|0;ha=Q+4|0;Q=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;ha=fa|0;x=d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x;ha=fa+4|0;x=Q;a[ha]=x;x=x>>8;a[ha+1|0]=x;x=x>>8;a[ha+2|0]=x;x=x>>8;a[ha+3|0]=x}ha=g+(E*72|0)+(H*12|0)+8|0;c[ha>>2]=(c[ha>>2]|0)+1;ha=d[da]|0;da=c[r>>2]|0;Q=d[1086680+da|0]|0;fa=c[s>>2]|0;ga=c[t>>2]|0;ia=da<<Q;c[r>>2]=ia;da=ga<<Q;ga=fa+Q|0;do{if((ga|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){ja=da;ka=ga;break}c[u>>2]=Q+2;fa=Q;ja=((de((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|da;ka=ga-16|0}else{ja=da;ka=ga}}while(0);c[s>>2]=ka;ga=((ba(ia-1|0,ha)|0)>>8)+1|0;da=ga<<16;if(ja>>>0<da>>>0){c[r>>2]=ga;c[t>>2]=ja;O=d[G+4|0]|0;fa=d[1086680+ga|0]|0;Q=ga<<fa;c[r>>2]=Q;la=ja<<fa;ma=fa+ka|0;do{if((ma|0)>-1){fa=c[u>>2]|0;if(!(fa>>>0<(c[v>>2]|0)>>>0)){na=la;oa=ma;break}c[u>>2]=fa+2;pa=fa;na=((de((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|la;oa=ma-16|0}else{na=la;oa=ma}}while(0);c[s>>2]=oa;ma=((ba(Q-1|0,O)|0)>>8)+1|0;la=ma<<16;if(na>>>0<la>>>0){c[r>>2]=ma;c[t>>2]=na;a[q+P|0]=2;ea=2;break}ha=Q-ma|0;c[r>>2]=ha;ma=na-la|0;c[t>>2]=ma;la=a[G+5|0]|0;pa=d[1086680+ha|0]|0;fa=ha<<pa;c[r>>2]=fa;ha=ma<<pa;ma=pa+oa|0;do{if((ma|0)>-1){pa=c[u>>2]|0;if(!(pa>>>0<(c[v>>2]|0)>>>0)){qa=ha;ra=ma;break}c[u>>2]=pa+2;sa=pa;qa=((de((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|ha;ra=ma-16|0}else{qa=ha;ra=ma}}while(0);c[s>>2]=ra;ma=((ba(fa-1|0,la&255)|0)>>8)+1|0;ha=ma<<16;Q=qa>>>0>=ha>>>0;c[r>>2]=Q?fa-ma|0:ma;c[t>>2]=qa-(Q?ha:0);a[q+P|0]=3;ea=Q?4:3;break}Q=ia-ga|0;c[r>>2]=Q;ha=ja-da|0;c[t>>2]=ha;ma=d[G+6|0]|0;O=d[1086680+Q|0]|0;sa=Q<<O;c[r>>2]=sa;Q=ha<<O;ha=O+ka|0;do{if((ha|0)>-1){O=c[u>>2]|0;if(!(O>>>0<(c[v>>2]|0)>>>0)){ta=Q;ua=ha;break}c[u>>2]=O+2;pa=O;ta=((de((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<ha|Q;ua=ha-16|0}else{ta=Q;ua=ha}}while(0);c[s>>2]=ua;ha=((ba(sa-1|0,ma)|0)>>8)+1|0;Q=ha<<16;if(ta>>>0<Q>>>0){c[r>>2]=ha;c[t>>2]=ta;a[q+P|0]=4;da=d[G+7|0]|0;ga=d[1086680+ha|0]|0;ia=ha<<ga;c[r>>2]=ia;fa=ta<<ga;la=ga+ua|0;do{if((la|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){va=fa;wa=la;break}c[u>>2]=ga+2;pa=ga;va=((de((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<la|fa;wa=la-16|0}else{va=fa;wa=la}}while(0);c[s>>2]=wa;la=((ba(ia-1|0,da)|0)>>8)+1|0;fa=la<<16;if(va>>>0<fa>>>0){c[t>>2]=va;ma=d[1086680+la|0]|0;pa=la<<ma;c[r>>2]=pa;ga=va<<ma;O=ma+wa|0;do{if((O|0)>-1){ma=c[u>>2]|0;if(!(ma>>>0<(c[v>>2]|0)>>>0)){xa=ga;ya=O;break}c[u>>2]=ma+2;za=ma;xa=((de((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<O|ga;ya=O-16|0}else{xa=ga;ya=O}}while(0);c[s>>2]=ya;O=((pa*159|0)-159>>8)+1|0;ga=O<<16;da=xa>>>0>=ga>>>0;c[r>>2]=da?pa-O|0:O;c[t>>2]=xa-(da?ga:0);ea=da?6:5;break}da=ia-la|0;ga=va-fa|0;c[t>>2]=ga;O=d[1086680+da|0]|0;za=da<<O;c[r>>2]=za;da=ga<<O;ga=O+wa|0;do{if((ga|0)>-1){O=c[u>>2]|0;if(!(O>>>0<(c[v>>2]|0)>>>0)){Aa=da;Ba=ga;break}c[u>>2]=O+2;ma=O;Aa=((de((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|da;Ba=ga-16|0}else{Aa=da;Ba=ga}}while(0);c[s>>2]=Ba;ga=((za*165|0)-165>>8)+1|0;da=ga<<16;fa=Aa>>>0>=da>>>0;la=fa?za-ga|0:ga;ga=Aa-(fa?da:0)|0;c[t>>2]=ga;da=((fa&1)<<1)+7|0;fa=d[1086680+la|0]|0;ia=la<<fa;c[r>>2]=ia;la=ga<<fa;ga=fa+Ba|0;do{if((ga|0)>-1){fa=c[u>>2]|0;if(!(fa>>>0<(c[v>>2]|0)>>>0)){Ca=la;Da=ga;break}c[u>>2]=fa+2;pa=fa;Ca=((de((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|la;Da=ga-16|0}else{Ca=la;Da=ga}}while(0);c[s>>2]=Da;ga=((ia*145|0)-145>>8)+1|0;la=ga<<16;za=Ca>>>0>=la>>>0;c[r>>2]=za?ia-ga|0:ga;c[t>>2]=Ca-(za?la:0);ea=da+(za&1)|0;break}za=sa-ha|0;c[r>>2]=za;la=ta-Q|0;c[t>>2]=la;a[q+P|0]=5;ga=d[G+8|0]|0;pa=d[1086680+za|0]|0;fa=za<<pa;c[r>>2]=fa;za=la<<pa;la=pa+ua|0;do{if((la|0)>-1){pa=c[u>>2]|0;if(!(pa>>>0<(c[v>>2]|0)>>>0)){Ea=za;Fa=la;break}c[u>>2]=pa+2;ma=pa;Ea=((de((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<la|za;Fa=la-16|0}else{Ea=za;Fa=la}}while(0);c[s>>2]=Fa;la=((ba(fa-1|0,ga)|0)>>8)+1|0;za=la<<16;if(Ea>>>0<za>>>0){c[r>>2]=la;c[t>>2]=Ea;Q=d[G+9|0]|0;ha=d[1086680+la|0]|0;sa=la<<ha;c[r>>2]=sa;da=Ea<<ha;ia=ha+Fa|0;do{if((ia|0)>-1){ha=c[u>>2]|0;if(!(ha>>>0<(c[v>>2]|0)>>>0)){Ga=da;Ha=ia;break}c[u>>2]=ha+2;ma=ha;Ga=((de((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<ia|da;Ha=ia-16|0}else{Ga=da;Ha=ia}}while(0);c[s>>2]=Ha;ia=((ba(sa-1|0,Q)|0)>>8)+1|0;da=ia<<16;if(Ga>>>0<da>>>0){c[t>>2]=Ga;ga=d[1086680+ia|0]|0;ma=ia<<ga;c[r>>2]=ma;ha=Ga<<ga;pa=ga+Ha|0;do{if((pa|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){Ia=ha;Ja=pa;break}c[u>>2]=ga+2;O=ga;Ia=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|ha;Ja=pa-16|0}else{Ia=ha;Ja=pa}}while(0);c[s>>2]=Ja;pa=((ma*173|0)-173>>8)+1|0;ha=pa<<16;Q=Ia>>>0>=ha>>>0;O=Q?ma-pa|0:pa;pa=Ia-(Q?ha:0)|0;c[t>>2]=pa;ha=(Q&1)<<2|11;Q=d[1086680+O|0]|0;ga=O<<Q;c[r>>2]=ga;O=pa<<Q;pa=Q+Ja|0;do{if((pa|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){Ka=O;La=pa;break}c[u>>2]=Q+2;Ma=Q;Ka=((de((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|O;La=pa-16|0}else{Ka=O;La=pa}}while(0);c[s>>2]=La;pa=((ga*148|0)-148>>8)+1|0;O=pa<<16;ma=Ka>>>0>=O>>>0;Ma=ma?ga-pa|0:pa;pa=Ka-(ma?O:0)|0;c[t>>2]=pa;O=((ma&1)<<1)+ha|0;ma=d[1086680+Ma|0]|0;Q=Ma<<ma;c[r>>2]=Q;Ma=pa<<ma;pa=ma+La|0;do{if((pa|0)>-1){ma=c[u>>2]|0;if(!(ma>>>0<(c[v>>2]|0)>>>0)){Na=Ma;Oa=pa;break}c[u>>2]=ma+2;Pa=ma;Na=((de((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|Ma;Oa=pa-16|0}else{Na=Ma;Oa=pa}}while(0);c[s>>2]=Oa;pa=((Q*140|0)-140>>8)+1|0;Ma=pa<<16;ha=Na>>>0>=Ma>>>0;c[r>>2]=ha?Q-pa|0:pa;c[t>>2]=Na-(ha?Ma:0);ea=O+(ha&1)|0;break}ha=sa-ia|0;Ma=Ga-da|0;c[t>>2]=Ma;pa=d[1086680+ha|0]|0;ga=ha<<pa;c[r>>2]=ga;ha=Ma<<pa;Ma=pa+Ha|0;do{if((Ma|0)>-1){pa=c[u>>2]|0;if(!(pa>>>0<(c[v>>2]|0)>>>0)){Qa=ha;Ra=Ma;break}c[u>>2]=pa+2;Pa=pa;Qa=((de((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|ha;Ra=Ma-16|0}else{Qa=ha;Ra=Ma}}while(0);c[s>>2]=Ra;Ma=((ga*176|0)-176>>8)+1|0;ha=Ma<<16;da=Qa>>>0>=ha>>>0;ia=da?ga-Ma|0:Ma;Ma=Qa-(da?ha:0)|0;c[t>>2]=Ma;ha=(da&1)<<3;da=d[1086680+ia|0]|0;sa=ia<<da;c[r>>2]=sa;ia=Ma<<da;Ma=da+Ra|0;do{if((Ma|0)>-1){da=c[u>>2]|0;if(!(da>>>0<(c[v>>2]|0)>>>0)){Sa=ia;Ta=Ma;break}c[u>>2]=da+2;O=da;Sa=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|ia;Ta=Ma-16|0}else{Sa=ia;Ta=Ma}}while(0);c[s>>2]=Ta;Ma=((sa*155|0)-155>>8)+1|0;ia=Ma<<16;ga=Sa>>>0>=ia>>>0;O=ga?sa-Ma|0:Ma;Ma=Sa-(ga?ia:0)|0;c[t>>2]=Ma;ia=ha|(ga&1)<<2|19;ga=d[1086680+O|0]|0;da=O<<ga;c[r>>2]=da;O=Ma<<ga;Ma=ga+Ta|0;do{if((Ma|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){Ua=O;Va=Ma;break}c[u>>2]=ga+2;Q=ga;Ua=((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|O;Va=Ma-16|0}else{Ua=O;Va=Ma}}while(0);c[s>>2]=Va;Ma=((da*140|0)-140>>8)+1|0;O=Ma<<16;ha=Ua>>>0>=O>>>0;sa=ha?da-Ma|0:Ma;Ma=Ua-(ha?O:0)|0;c[t>>2]=Ma;O=((ha&1)<<1)+ia|0;ha=d[1086680+sa|0]|0;Q=sa<<ha;c[r>>2]=Q;sa=Ma<<ha;Ma=ha+Va|0;do{if((Ma|0)>-1){ha=c[u>>2]|0;if(!(ha>>>0<(c[v>>2]|0)>>>0)){Wa=sa;Xa=Ma;break}c[u>>2]=ha+2;ga=ha;Wa=((de((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|sa;Xa=Ma-16|0}else{Wa=sa;Xa=Ma}}while(0);c[s>>2]=Xa;Ma=((Q*135|0)-135>>8)+1|0;sa=Ma<<16;ia=Wa>>>0>=sa>>>0;c[r>>2]=ia?Q-Ma|0:Ma;c[t>>2]=Wa-(ia?sa:0);ea=O+(ia&1)|0;break}ia=fa-la|0;c[r>>2]=ia;sa=Ea-za|0;c[t>>2]=sa;Ma=d[G+10|0]|0;da=d[1086680+ia|0]|0;ga=ia<<da;c[r>>2]=ga;ia=sa<<da;sa=da+Fa|0;do{if((sa|0)>-1){da=c[u>>2]|0;if(!(da>>>0<(c[v>>2]|0)>>>0)){Ya=ia;Za=sa;break}c[u>>2]=da+2;ha=da;Ya=((de((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535)<<sa|ia;Za=sa-16|0}else{Ya=ia;Za=sa}}while(0);c[s>>2]=Za;sa=((ba(ga-1|0,Ma)|0)>>8)+1|0;ia=sa<<16;if(Ya>>>0<ia>>>0){c[t>>2]=Ya;za=d[1086680+sa|0]|0;la=sa<<za;c[r>>2]=la;fa=Ya<<za;O=za+Za|0;do{if((O|0)>-1){za=c[u>>2]|0;if(!(za>>>0<(c[v>>2]|0)>>>0)){_a=fa;$a=O;break}c[u>>2]=za+2;Q=za;_a=((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<O|fa;$a=O-16|0}else{_a=fa;$a=O}}while(0);c[s>>2]=$a;O=((la*180|0)-180>>8)+1|0;fa=O<<16;Ma=_a>>>0>=fa>>>0;Q=Ma?la-O|0:O;O=_a-(Ma?fa:0)|0;c[t>>2]=O;fa=(Ma&1)<<4;Ma=d[1086680+Q|0]|0;za=Q<<Ma;c[r>>2]=za;Q=O<<Ma;O=Ma+$a|0;do{if((O|0)>-1){Ma=c[u>>2]|0;if(!(Ma>>>0<(c[v>>2]|0)>>>0)){ab=Q;bb=O;break}c[u>>2]=Ma+2;ha=Ma;ab=((de((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535)<<O|Q;bb=O-16|0}else{ab=Q;bb=O}}while(0);c[s>>2]=bb;O=((za*157|0)-157>>8)+1|0;Q=O<<16;la=ab>>>0>=Q>>>0;ha=la?za-O|0:O;O=ab-(la?Q:0)|0;c[t>>2]=O;Q=(la&1)<<3;la=d[1086680+ha|0]|0;Ma=ha<<la;c[r>>2]=Ma;ha=O<<la;O=la+bb|0;do{if((O|0)>-1){la=c[u>>2]|0;if(!(la>>>0<(c[v>>2]|0)>>>0)){cb=ha;db=O;break}c[u>>2]=la+2;da=la;cb=((de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<O|ha;db=O-16|0}else{cb=ha;db=O}}while(0);c[s>>2]=db;O=((Ma*141|0)-141>>8)+1|0;ha=O<<16;za=cb>>>0>=ha>>>0;da=za?Ma-O|0:O;O=cb-(za?ha:0)|0;c[t>>2]=O;ha=fa|Q|(za&1)<<2|35;za=d[1086680+da|0]|0;la=da<<za;c[r>>2]=la;da=O<<za;O=za+db|0;do{if((O|0)>-1){za=c[u>>2]|0;if(!(za>>>0<(c[v>>2]|0)>>>0)){eb=da;fb=O;break}c[u>>2]=za+2;Pa=za;eb=((de((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<O|da;fb=O-16|0}else{eb=da;fb=O}}while(0);c[s>>2]=fb;O=((la*134|0)-134>>8)+1|0;da=O<<16;Q=eb>>>0>=da>>>0;fa=Q?la-O|0:O;O=eb-(Q?da:0)|0;c[t>>2]=O;da=((Q&1)<<1)+ha|0;Q=d[1086680+fa|0]|0;Ma=fa<<Q;c[r>>2]=Ma;fa=O<<Q;O=Q+fb|0;do{if((O|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){gb=fa;hb=O;break}c[u>>2]=Q+2;Pa=Q;gb=((de((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<O|fa;hb=O-16|0}else{gb=fa;hb=O}}while(0);c[s>>2]=hb;O=((Ma*130|0)-130>>8)+1|0;fa=O<<16;ha=gb>>>0>=fa>>>0;c[r>>2]=ha?Ma-O|0:O;c[t>>2]=gb-(ha?fa:0);ea=da+(ha&1)|0;break}ha=ga-sa|0;fa=Ya-ia|0;c[t>>2]=fa;O=d[1086680+ha|0]|0;la=ha<<O;c[r>>2]=la;ha=fa<<O;fa=O+Za|0;do{if((fa|0)>-1){O=c[u>>2]|0;if(!(O>>>0<(c[v>>2]|0)>>>0)){ib=ha;jb=fa;break}c[u>>2]=O+2;Pa=O;ib=((de((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|ha;jb=fa-16|0}else{ib=ha;jb=fa}}while(0);c[s>>2]=jb;fa=((la*254|0)-254>>8)+1|0;ha=fa<<16;ia=ib>>>0>=ha>>>0;sa=ia?la-fa|0:fa;fa=ib-(ia?ha:0)|0;c[t>>2]=fa;ha=(ia&1)<<13;ia=d[1086680+sa|0]|0;ga=sa<<ia;c[r>>2]=ga;sa=fa<<ia;fa=ia+jb|0;do{if((fa|0)>-1){ia=c[u>>2]|0;if(!(ia>>>0<(c[v>>2]|0)>>>0)){kb=sa;lb=fa;break}c[u>>2]=ia+2;da=ia;kb=((de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|sa;lb=fa-16|0}else{kb=sa;lb=fa}}while(0);c[s>>2]=lb;fa=((ga*254|0)-254>>8)+1|0;sa=fa<<16;la=kb>>>0>=sa>>>0;da=la?ga-fa|0:fa;fa=kb-(la?sa:0)|0;c[t>>2]=fa;sa=(la&1)<<12;la=d[1086680+da|0]|0;ia=da<<la;c[r>>2]=ia;da=fa<<la;fa=la+lb|0;do{if((fa|0)>-1){la=c[u>>2]|0;if(!(la>>>0<(c[v>>2]|0)>>>0)){mb=da;nb=fa;break}c[u>>2]=la+2;Ma=la;mb=((de((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|da;nb=fa-16|0}else{mb=da;nb=fa}}while(0);c[s>>2]=nb;fa=((ia*254|0)-254>>8)+1|0;da=fa<<16;ga=mb>>>0>=da>>>0;Ma=ga?ia-fa|0:fa;fa=mb-(ga?da:0)|0;c[t>>2]=fa;da=(ga&1)<<11;ga=d[1086680+Ma|0]|0;la=Ma<<ga;c[r>>2]=la;Ma=fa<<ga;fa=ga+nb|0;do{if((fa|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){ob=Ma;pb=fa;break}c[u>>2]=ga+2;Pa=ga;ob=((de((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Ma;pb=fa-16|0}else{ob=Ma;pb=fa}}while(0);c[s>>2]=pb;fa=((la*252|0)-252>>8)+1|0;Ma=fa<<16;ia=ob>>>0>=Ma>>>0;Pa=ia?la-fa|0:fa;fa=ob-(ia?Ma:0)|0;c[t>>2]=fa;Ma=(ia&1)<<10;ia=d[1086680+Pa|0]|0;ga=Pa<<ia;c[r>>2]=ga;Pa=fa<<ia;fa=ia+pb|0;do{if((fa|0)>-1){ia=c[u>>2]|0;if(!(ia>>>0<(c[v>>2]|0)>>>0)){qb=Pa;rb=fa;break}c[u>>2]=ia+2;O=ia;qb=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Pa;rb=fa-16|0}else{qb=Pa;rb=fa}}while(0);c[s>>2]=rb;fa=((ga*249|0)-249>>8)+1|0;Pa=fa<<16;la=qb>>>0>=Pa>>>0;O=la?ga-fa|0:fa;fa=qb-(la?Pa:0)|0;c[t>>2]=fa;Pa=(la&1)<<9;la=d[1086680+O|0]|0;ia=O<<la;c[r>>2]=ia;O=fa<<la;fa=la+rb|0;do{if((fa|0)>-1){la=c[u>>2]|0;if(!(la>>>0<(c[v>>2]|0)>>>0)){sb=O;tb=fa;break}c[u>>2]=la+2;Q=la;sb=((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|O;tb=fa-16|0}else{sb=O;tb=fa}}while(0);c[s>>2]=tb;fa=((ia*243|0)-243>>8)+1|0;O=fa<<16;ga=sb>>>0>=O>>>0;Q=ga?ia-fa|0:fa;fa=sb-(ga?O:0)|0;c[t>>2]=fa;O=ha|sa|da|Ma|Pa|(ga&1)<<8|67;ga=d[1086680+Q|0]|0;la=Q<<ga;c[r>>2]=la;Q=fa<<ga;fa=ga+tb|0;do{if((fa|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){ub=Q;vb=fa;break}c[u>>2]=ga+2;za=ga;ub=((de((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Q;vb=fa-16|0}else{ub=Q;vb=fa}}while(0);c[s>>2]=vb;fa=((la*230|0)-230>>8)+1|0;Q=fa<<16;Pa=ub>>>0>=Q>>>0;Ma=Pa?la-fa|0:fa;fa=ub-(Pa?Q:0)|0;c[t>>2]=fa;Q=((Pa&1)<<7)+O|0;Pa=d[1086680+Ma|0]|0;da=Ma<<Pa;c[r>>2]=da;Ma=fa<<Pa;fa=Pa+vb|0;do{if((fa|0)>-1){Pa=c[u>>2]|0;if(!(Pa>>>0<(c[v>>2]|0)>>>0)){wb=Ma;xb=fa;break}c[u>>2]=Pa+2;sa=Pa;wb=((de((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Ma;xb=fa-16|0}else{wb=Ma;xb=fa}}while(0);c[s>>2]=xb;fa=((da*196|0)-196>>8)+1|0;Ma=fa<<16;O=wb>>>0>=Ma>>>0;la=O?da-fa|0:fa;fa=wb-(O?Ma:0)|0;c[t>>2]=fa;Ma=Q+((O&1)<<6)|0;O=d[1086680+la|0]|0;sa=la<<O;c[r>>2]=sa;la=fa<<O;fa=O+xb|0;do{if((fa|0)>-1){O=c[u>>2]|0;if(!(O>>>0<(c[v>>2]|0)>>>0)){yb=la;zb=fa;break}c[u>>2]=O+2;Pa=O;yb=((de((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|la;zb=fa-16|0}else{yb=la;zb=fa}}while(0);c[s>>2]=zb;fa=((sa*177|0)-177>>8)+1|0;la=fa<<16;Q=yb>>>0>=la>>>0;da=Q?sa-fa|0:fa;fa=yb-(Q?la:0)|0;c[t>>2]=fa;la=Ma+((Q&1)<<5)|0;Q=d[1086680+da|0]|0;Pa=da<<Q;c[r>>2]=Pa;da=fa<<Q;fa=Q+zb|0;do{if((fa|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){Ab=da;Bb=fa;break}c[u>>2]=Q+2;O=Q;Ab=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|da;Bb=fa-16|0}else{Ab=da;Bb=fa}}while(0);c[s>>2]=Bb;fa=((Pa*153|0)-153>>8)+1|0;da=fa<<16;Ma=Ab>>>0>=da>>>0;sa=Ma?Pa-fa|0:fa;fa=Ab-(Ma?da:0)|0;c[t>>2]=fa;da=la+((Ma&1)<<4)|0;Ma=d[1086680+sa|0]|0;O=sa<<Ma;c[r>>2]=O;sa=fa<<Ma;fa=Ma+Bb|0;do{if((fa|0)>-1){Ma=c[u>>2]|0;if(!(Ma>>>0<(c[v>>2]|0)>>>0)){Cb=sa;Db=fa;break}c[u>>2]=Ma+2;Q=Ma;Cb=((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|sa;Db=fa-16|0}else{Cb=sa;Db=fa}}while(0);c[s>>2]=Db;fa=((O*140|0)-140>>8)+1|0;sa=fa<<16;la=Cb>>>0>=sa>>>0;Pa=la?O-fa|0:fa;fa=Cb-(la?sa:0)|0;c[t>>2]=fa;sa=da+((la&1)<<3)|0;la=d[1086680+Pa|0]|0;Q=Pa<<la;c[r>>2]=Q;Pa=fa<<la;fa=la+Db|0;do{if((fa|0)>-1){la=c[u>>2]|0;if(!(la>>>0<(c[v>>2]|0)>>>0)){Eb=Pa;Fb=fa;break}c[u>>2]=la+2;Ma=la;Eb=((de((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Pa;Fb=fa-16|0}else{Eb=Pa;Fb=fa}}while(0);c[s>>2]=Fb;fa=((Q*133|0)-133>>8)+1|0;Pa=fa<<16;da=Eb>>>0>=Pa>>>0;O=da?Q-fa|0:fa;fa=Eb-(da?Pa:0)|0;c[t>>2]=fa;Pa=sa+((da&1)<<2)|0;da=d[1086680+O|0]|0;Ma=O<<da;c[r>>2]=Ma;O=fa<<da;fa=da+Fb|0;do{if((fa|0)>-1){da=c[u>>2]|0;if(!(da>>>0<(c[v>>2]|0)>>>0)){Gb=O;Hb=fa;break}c[u>>2]=da+2;la=da;Gb=((de((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|O;Hb=fa-16|0}else{Gb=O;Hb=fa}}while(0);c[s>>2]=Hb;fa=((Ma*130|0)-130>>8)+1|0;O=fa<<16;sa=Gb>>>0>=O>>>0;Q=sa?Ma-fa|0:fa;fa=Gb-(sa?O:0)|0;c[t>>2]=fa;O=Pa+((sa&1)<<1)|0;sa=d[1086680+Q|0]|0;la=Q<<sa;c[r>>2]=la;Q=fa<<sa;fa=sa+Hb|0;do{if((fa|0)>-1){sa=c[u>>2]|0;if(!(sa>>>0<(c[v>>2]|0)>>>0)){Ib=Q;Jb=fa;break}c[u>>2]=sa+2;da=sa;Ib=((de((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Q;Jb=fa-16|0}else{Ib=Q;Jb=fa}}while(0);c[s>>2]=Jb;fa=((la*129|0)-129>>8)+1|0;Q=fa<<16;Pa=Ib>>>0>=Q>>>0;c[r>>2]=Pa?la-fa|0:fa;c[t>>2]=Ib-(Pa?Q:0);ea=O+(Pa&1)|0}}while(0);G=K-1|0;if((G|0)==0){H=E+1|0;Kb=b[n+(H<<1)>>1]|0;Lb=H}else{Kb=G;Lb=E}G=c[r>>2]|0;H=d[1086680+G|0]|0;S=c[s>>2]|0;F=c[t>>2]|0;D=G<<H;c[r>>2]=D;G=F<<H;F=S+H|0;do{if((F|0)>-1){H=c[u>>2]|0;if(!(H>>>0<(c[v>>2]|0)>>>0)){Mb=G;Nb=F;break}c[u>>2]=H+2;S=H;Mb=((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)<<F|G;Nb=F-16|0}else{Mb=G;Nb=F}}while(0);c[s>>2]=Nb;F=((D<<7)-128>>8)+1|0;G=F<<16;E=Mb>>>0>=G>>>0;K=E?D-F|0:F;c[r>>2]=K;F=Mb-(E?G:0)|0;c[t>>2]=F;b[f+(P<<1)>>1]=(ba(E?-ea|0:ea,b[o+(((N|0)!=0)<<1)>>1]|0)|0)/2|0;E=((d[q+(b[m+(N<<2)>>1]|0)|0]|0)+1+(d[q+(b[m+(N<<2)+2>>1]|0)|0]|0)|0)>>>1;G=N+1|0;if((G|0)<1024){e=E;w=j+(Lb*66|0)+(E*11|0)|0;k=Kb;y=Lb;z=G;A=K;B=Nb;C=F}else{_=G;M=154;break}}if((M|0)==6){c[r>>2]=L;c[t>>2]=I;I=h+(y*48|0)+(e<<3)|0;c[I>>2]=(c[I>>2]|0)+1;_=z;i=p;return _|0}else if((M|0)==154){i=p;return _|0}return 0}function O6a(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0;j=c[f+1084>>2]|0;if((h|0)==12){k=g;c[k>>2]=0;c[k+4>>2]=0;return}k=(h|0)==11|0;l=(h|0)==13;h=l?-1:i;P6a(f,g,d[j+3|0]|0,0,k,h);m=l|(i|0)==-1;a:do{if(m){do{if((a[f+1147|0]|0)==0){n=0}else{i=b[g>>1]|0;o=i<<16>>16;if(((i<<16>>16>-1?o:-o|0)|0)>=64){n=0;break}o=b[g+2>>1]|0;i=o<<16>>16;p=((o<<16>>16>-1?i:-i|0)|0)<64;i=p&1;if(p){q=i;break a}else{n=i}}}while(0);i=g+2|0;p=b[i>>1]|0;do{if(!((p&1)==0)){if(p<<16>>16<0){b[i>>1]=p+1;break}else{b[i>>1]=p-1;break}}}while(0);p=g|0;i=b[p>>1]|0;if((i&1)==0){q=n;break}if(i<<16>>16<0){b[p>>1]=i+1;q=n;break}else{b[p>>1]=i-1;q=n;break}}else{q=0}}while(0);do{if(l){n=f+1052|0;i=f+1056|0;p=f+1068|0;o=f+1060|0;r=f+1064|0;s=0;t=c[n>>2]|0;u=c[i>>2]|0;v=c[p>>2]|0;while(1){w=a[f+10162+s|0]|0;x=d[1086680+t|0]|0;y=t<<x;c[n>>2]=y;z=v<<x;A=x+u|0;do{if((A|0)>-1){x=c[o>>2]|0;if(!(x>>>0<(c[r>>2]|0)>>>0)){B=z;C=A;break}c[o>>2]=x+2;D=x;B=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<A|z;C=A-16|0}else{B=z;C=A}}while(0);c[i>>2]=C;A=((ba(y-1|0,w&255)|0)>>8)+1|0;z=A<<16;D=B>>>0>=z>>>0;x=D?y-A|0:A;c[n>>2]=x;A=B-(D?z:0)|0;c[p>>2]=A;z=a[(D&1)+(106472+(s<<1))|0]|0;E=z<<24>>24;if(z<<24>>24>0){s=E;t=x;u=C;v=A}else{break}}v=-E|0;u=f+17636+(v<<2)|0;c[u>>2]=(c[u>>2]|0)+1;if(v>>>0>1>>>0){u=a[f+10165|0]|0;t=c[n>>2]|0;s=d[1086680+t|0]|0;A=c[i>>2]|0;x=c[p>>2]|0;z=t<<s;c[n>>2]=z;t=x<<s;x=A+s|0;do{if((x|0)>-1){s=c[o>>2]|0;if(!(s>>>0<(c[r>>2]|0)>>>0)){F=t;G=x;break}c[o>>2]=s+2;A=s;F=((de((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535)<<x|t;G=x-16|0}else{F=t;G=x}}while(0);c[i>>2]=G;x=((ba(z-1|0,u&255)|0)>>8)+1|0;t=x<<16;A=F>>>0>=t>>>0;s=A?z-x|0:x;c[n>>2]=s;x=F-(A?t:0)|0;c[p>>2]=x;t=0;D=s;s=G;H=x;while(1){x=a[f+10166+t|0]|0;I=d[1086680+D|0]|0;J=D<<I;c[n>>2]=J;K=H<<I;L=I+s|0;do{if((L|0)>-1){I=c[o>>2]|0;if(!(I>>>0<(c[r>>2]|0)>>>0)){M=K;N=L;break}c[o>>2]=I+2;O=I;M=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<L|K;N=L-16|0}else{M=K;N=L}}while(0);c[i>>2]=N;L=((ba(J-1|0,x&255)|0)>>8)+1|0;K=L<<16;y=M>>>0>=K>>>0;w=y?J-L|0:L;c[n>>2]=w;L=M-(y?K:0)|0;c[p>>2]=L;P=a[(y&1)+(106488+(t<<1))|0]|0;Q=P<<24>>24;if(P<<24>>24>0){t=Q;D=w;s=N;H=L}else{break}}H=-Q|0;s=f+17652+((A&1)<<2)|0;c[s>>2]=(c[s>>2]|0)+1;s=f+17660+(H<<2)|0;c[s>>2]=(c[s>>2]|0)+1;do{if(P<<24>>24==0){s=a[f+10176|0]|0;D=c[n>>2]|0;t=d[1086680+D|0]|0;z=c[i>>2]|0;u=c[p>>2]|0;L=D<<t;c[n>>2]=L;D=u<<t;u=z+t|0;do{if((u|0)>-1){t=c[o>>2]|0;if(!(t>>>0<(c[r>>2]|0)>>>0)){R=D;S=u;break}c[o>>2]=t+2;z=t;R=((de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<u|D;S=u-16|0}else{R=D;S=u}}while(0);c[i>>2]=S;u=((ba(L-1|0,s&255)|0)>>8)+1|0;D=u<<16;J=R>>>0>=D>>>0;x=J&1;c[n>>2]=J?L-u|0:u;c[p>>2]=R-(J?D:0);D=f+17704+(x<<2)|0;c[D>>2]=(c[D>>2]|0)+1;D=0;J=c[n>>2]|0;u=c[i>>2]|0;z=c[p>>2]|0;while(1){t=a[f+10187+(x*3|0)+D|0]|0;w=d[1086680+J|0]|0;y=J<<w;c[n>>2]=y;K=z<<w;O=w+u|0;do{if((O|0)>-1){w=c[o>>2]|0;if(!(w>>>0<(c[r>>2]|0)>>>0)){T=K;U=O;break}c[o>>2]=w+2;I=w;T=((de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)<<O|K;U=O-16|0}else{T=K;U=O}}while(0);c[i>>2]=U;O=((ba(y-1|0,t&255)|0)>>8)+1|0;K=O<<16;I=T>>>0>=K>>>0;w=I?y-O|0:O;c[n>>2]=w;O=T-(I?K:0)|0;c[p>>2]=O;K=a[(I&1)+(106480+(D<<1))|0]|0;V=K<<24>>24;if(K<<24>>24>0){D=V;J=w;u=U;z=O}else{break}}z=-V|0;u=f+17792+(x<<4)+(z<<2)|0;c[u>>2]=(c[u>>2]|0)+1;u=z<<1|x<<3;if((q|0)==0){z=f+17844|0;c[z>>2]=(c[z>>2]|0)+1;W=u|1;break}z=a[f+10196|0]|0;J=c[n>>2]|0;D=d[1086680+J|0]|0;L=c[i>>2]|0;s=c[p>>2]|0;O=J<<D;c[n>>2]=O;J=s<<D;s=L+D|0;do{if((s|0)>-1){D=c[o>>2]|0;if(!(D>>>0<(c[r>>2]|0)>>>0)){X=J;Y=s;break}c[o>>2]=D+2;L=D;X=((de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<s|J;Y=s-16|0}else{X=J;Y=s}}while(0);c[i>>2]=Y;s=((ba(O-1|0,z&255)|0)>>8)+1|0;J=s<<16;x=X>>>0>=J>>>0;L=x&1;c[n>>2]=x?O-s|0:s;c[p>>2]=X-(x?J:0);J=f+17840+(L<<2)|0;c[J>>2]=(c[J>>2]|0)+1;W=L|u}else{L=0;J=0;do{x=a[f+10177+J|0]|0;s=c[n>>2]|0;D=d[1086680+s|0]|0;w=c[i>>2]|0;K=c[p>>2]|0;I=s<<D;c[n>>2]=I;s=K<<D;K=w+D|0;do{if((K|0)>-1){D=c[o>>2]|0;if(!(D>>>0<(c[r>>2]|0)>>>0)){Z=s;_=K;break}c[o>>2]=D+2;w=D;Z=((de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<K|s;_=K-16|0}else{Z=s;_=K}}while(0);c[i>>2]=_;K=((ba(I-1|0,x&255)|0)>>8)+1|0;s=K<<16;y=Z>>>0>=s>>>0;t=y&1;c[n>>2]=y?I-K|0:K;c[p>>2]=Z-(y?s:0);L=t<<J|L;s=f+17712+(J<<3)+(t<<2)|0;c[s>>2]=(c[s>>2]|0)+1;J=J+1|0;}while((J|0)<(H|0));J=0;u=c[n>>2]|0;O=c[i>>2]|0;z=c[p>>2]|0;while(1){s=a[f+10193+J|0]|0;t=d[1086680+u|0]|0;y=u<<t;c[n>>2]=y;K=z<<t;w=t+O|0;do{if((w|0)>-1){t=c[o>>2]|0;if(!(t>>>0<(c[r>>2]|0)>>>0)){$=K;aa=w;break}c[o>>2]=t+2;D=t;$=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<w|K;aa=w-16|0}else{$=K;aa=w}}while(0);c[i>>2]=aa;w=((ba(y-1|0,s&255)|0)>>8)+1|0;K=w<<16;I=$>>>0>=K>>>0;x=I?y-w|0:w;c[n>>2]=x;w=$-(I?K:0)|0;c[p>>2]=w;K=a[(I&1)+(106480+(J<<1))|0]|0;ca=K<<24>>24;if(K<<24>>24>0){J=ca;u=x;O=aa;z=w}else{break}}z=-ca|0;O=z<<1|L<<3;u=f+17824+(z<<2)|0;c[u>>2]=(c[u>>2]|0)+1;if((q|0)==0){u=f+17852|0;c[u>>2]=(c[u>>2]|0)+1;da=1}else{u=a[f+10197|0]|0;z=c[n>>2]|0;J=d[1086680+z|0]|0;w=c[i>>2]|0;x=c[p>>2]|0;K=z<<J;c[n>>2]=K;z=x<<J;x=w+J|0;do{if((x|0)>-1){J=c[o>>2]|0;if(!(J>>>0<(c[r>>2]|0)>>>0)){ea=z;fa=x;break}c[o>>2]=J+2;w=J;ea=((de((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<x|z;fa=x-16|0}else{ea=z;fa=x}}while(0);c[i>>2]=fa;x=((ba(K-1|0,u&255)|0)>>8)+1|0;z=x<<16;L=ea>>>0>=z>>>0;w=L&1;c[n>>2]=L?K-x|0:x;c[p>>2]=ea-(L?z:0);z=f+17848+(w<<2)|0;c[z>>2]=(c[z>>2]|0)+1;da=w}W=(O|da)+(8<<H)|0}}while(0);H=g+2|0;b[H>>1]=(e[H>>1]|0)+(A?W^65535:W+1|0)}if((v&1|0)==0){break}H=a[f+10198|0]|0;w=c[n>>2]|0;z=d[1086680+w|0]|0;L=c[i>>2]|0;x=c[p>>2]|0;J=w<<z;c[n>>2]=J;w=x<<z;x=L+z|0;do{if((x|0)>-1){z=c[o>>2]|0;if(!(z>>>0<(c[r>>2]|0)>>>0)){ga=w;ha=x;break}c[o>>2]=z+2;L=z;ga=((de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<x|w;ha=x-16|0}else{ga=w;ha=x}}while(0);c[i>>2]=ha;x=((ba(J-1|0,H&255)|0)>>8)+1|0;w=x<<16;v=ga>>>0>=w>>>0;A=v?J-x|0:x;c[n>>2]=A;x=ga-(v?w:0)|0;c[p>>2]=x;w=0;L=A;A=ha;z=x;while(1){x=a[f+10199+w|0]|0;I=d[1086680+L|0]|0;D=L<<I;c[n>>2]=D;t=z<<I;ia=I+A|0;do{if((ia|0)>-1){I=c[o>>2]|0;if(!(I>>>0<(c[r>>2]|0)>>>0)){ja=t;ka=ia;break}c[o>>2]=I+2;la=I;ja=((de((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535)<<ia|t;ka=ia-16|0}else{ja=t;ka=ia}}while(0);c[i>>2]=ka;ia=((ba(D-1|0,x&255)|0)>>8)+1|0;t=ia<<16;O=ja>>>0>=t>>>0;K=O?D-ia|0:ia;c[n>>2]=K;ia=ja-(O?t:0)|0;c[p>>2]=ia;ma=a[(O&1)+(106488+(w<<1))|0]|0;na=ma<<24>>24;if(ma<<24>>24>0){w=na;L=K;A=ka;z=ia}else{break}}z=-na|0;A=f+17856+((v&1)<<2)|0;c[A>>2]=(c[A>>2]|0)+1;A=f+17864+(z<<2)|0;c[A>>2]=(c[A>>2]|0)+1;do{if(ma<<24>>24==0){A=a[f+10209|0]|0;L=c[n>>2]|0;w=d[1086680+L|0]|0;J=c[i>>2]|0;H=c[p>>2]|0;ia=L<<w;c[n>>2]=ia;L=H<<w;H=J+w|0;do{if((H|0)>-1){w=c[o>>2]|0;if(!(w>>>0<(c[r>>2]|0)>>>0)){oa=L;pa=H;break}c[o>>2]=w+2;J=w;oa=((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)<<H|L;pa=H-16|0}else{oa=L;pa=H}}while(0);c[i>>2]=pa;H=((ba(ia-1|0,A&255)|0)>>8)+1|0;L=H<<16;D=oa>>>0>=L>>>0;x=D&1;c[n>>2]=D?ia-H|0:H;c[p>>2]=oa-(D?L:0);L=f+17908+(x<<2)|0;c[L>>2]=(c[L>>2]|0)+1;L=0;D=c[n>>2]|0;H=c[i>>2]|0;J=c[p>>2]|0;while(1){w=a[f+10220+(x*3|0)+L|0]|0;K=d[1086680+D|0]|0;O=D<<K;c[n>>2]=O;t=J<<K;u=K+H|0;do{if((u|0)>-1){K=c[o>>2]|0;if(!(K>>>0<(c[r>>2]|0)>>>0)){qa=t;ra=u;break}c[o>>2]=K+2;la=K;qa=((de((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535)<<u|t;ra=u-16|0}else{qa=t;ra=u}}while(0);c[i>>2]=ra;u=((ba(O-1|0,w&255)|0)>>8)+1|0;t=u<<16;y=qa>>>0>=t>>>0;s=y?O-u|0:u;c[n>>2]=s;u=qa-(y?t:0)|0;c[p>>2]=u;t=a[(y&1)+(106480+(L<<1))|0]|0;sa=t<<24>>24;if(t<<24>>24>0){L=sa;D=s;H=ra;J=u}else{break}}J=-sa|0;H=f+17996+(x<<4)+(J<<2)|0;c[H>>2]=(c[H>>2]|0)+1;H=J<<1|x<<3;if((q|0)==0){J=f+18048|0;c[J>>2]=(c[J>>2]|0)+1;ta=H|1;break}J=a[f+10229|0]|0;D=c[n>>2]|0;L=d[1086680+D|0]|0;ia=c[i>>2]|0;A=c[p>>2]|0;u=D<<L;c[n>>2]=u;D=A<<L;A=ia+L|0;do{if((A|0)>-1){L=c[o>>2]|0;if(!(L>>>0<(c[r>>2]|0)>>>0)){ua=D;va=A;break}c[o>>2]=L+2;ia=L;ua=((de((d[ia]|d[ia+1|0]<<8)<<16>>16|0)|0)&65535)<<A|D;va=A-16|0}else{ua=D;va=A}}while(0);c[i>>2]=va;A=((ba(u-1|0,J&255)|0)>>8)+1|0;D=A<<16;x=ua>>>0>=D>>>0;ia=x&1;c[n>>2]=x?u-A|0:A;c[p>>2]=ua-(x?D:0);D=f+18044+(ia<<2)|0;c[D>>2]=(c[D>>2]|0)+1;ta=ia|H}else{ia=0;D=0;do{x=a[f+10210+D|0]|0;A=c[n>>2]|0;L=d[1086680+A|0]|0;s=c[i>>2]|0;t=c[p>>2]|0;y=A<<L;c[n>>2]=y;A=t<<L;t=s+L|0;do{if((t|0)>-1){L=c[o>>2]|0;if(!(L>>>0<(c[r>>2]|0)>>>0)){wa=A;xa=t;break}c[o>>2]=L+2;s=L;wa=((de((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<t|A;xa=t-16|0}else{wa=A;xa=t}}while(0);c[i>>2]=xa;t=((ba(y-1|0,x&255)|0)>>8)+1|0;A=t<<16;O=wa>>>0>=A>>>0;w=O&1;c[n>>2]=O?y-t|0:t;c[p>>2]=wa-(O?A:0);ia=w<<D|ia;A=f+17916+(D<<3)+(w<<2)|0;c[A>>2]=(c[A>>2]|0)+1;D=D+1|0;}while((D|0)<(z|0));D=0;H=c[n>>2]|0;u=c[i>>2]|0;J=c[p>>2]|0;while(1){A=a[f+10226+D|0]|0;w=d[1086680+H|0]|0;O=H<<w;c[n>>2]=O;t=J<<w;s=w+u|0;do{if((s|0)>-1){w=c[o>>2]|0;if(!(w>>>0<(c[r>>2]|0)>>>0)){ya=t;za=s;break}c[o>>2]=w+2;L=w;ya=((de((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<s|t;za=s-16|0}else{ya=t;za=s}}while(0);c[i>>2]=za;s=((ba(O-1|0,A&255)|0)>>8)+1|0;t=s<<16;y=ya>>>0>=t>>>0;x=y?O-s|0:s;c[n>>2]=x;s=ya-(y?t:0)|0;c[p>>2]=s;t=a[(y&1)+(106480+(D<<1))|0]|0;Aa=t<<24>>24;if(t<<24>>24>0){D=Aa;H=x;u=za;J=s}else{break}}J=-Aa|0;u=J<<1|ia<<3;H=f+18028+(J<<2)|0;c[H>>2]=(c[H>>2]|0)+1;if((q|0)==0){H=f+18056|0;c[H>>2]=(c[H>>2]|0)+1;Ba=1}else{H=a[f+10230|0]|0;J=c[n>>2]|0;D=d[1086680+J|0]|0;s=c[i>>2]|0;x=c[p>>2]|0;t=J<<D;c[n>>2]=t;J=x<<D;x=s+D|0;do{if((x|0)>-1){D=c[o>>2]|0;if(!(D>>>0<(c[r>>2]|0)>>>0)){Ca=J;Da=x;break}c[o>>2]=D+2;s=D;Ca=((de((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<x|J;Da=x-16|0}else{Ca=J;Da=x}}while(0);c[i>>2]=Da;x=((ba(t-1|0,H&255)|0)>>8)+1|0;J=x<<16;ia=Ca>>>0>=J>>>0;s=ia&1;c[n>>2]=ia?t-x|0:x;c[p>>2]=Ca-(ia?J:0);J=f+18052+(s<<2)|0;c[J>>2]=(c[J>>2]|0)+1;Ba=s}ta=(u|Ba)+(8<<z)|0}}while(0);z=g|0;b[z>>1]=(e[z>>1]|0)+(v?ta^65535:ta+1|0)}}while(0);if((a[j+2|0]|0)==0){return}ta=g+4|0;P6a(f,ta,d[j+4|0]|0,1,k,h);b:do{if(m){do{if((a[f+1147|0]|0)==0){Ea=0}else{h=b[ta>>1]|0;k=h<<16>>16;if(((h<<16>>16>-1?k:-k|0)|0)>=64){Ea=0;break}k=b[g+6>>1]|0;h=k<<16>>16;j=((k<<16>>16>-1?h:-h|0)|0)<64;h=j&1;if(j){Fa=h;break b}else{Ea=h}}}while(0);v=g+6|0;h=b[v>>1]|0;do{if(!((h&1)==0)){if(h<<16>>16<0){b[v>>1]=h+1;break}else{b[v>>1]=h-1;break}}}while(0);h=ta|0;v=b[h>>1]|0;if((v&1)==0){Fa=Ea;break}if(v<<16>>16<0){b[h>>1]=v+1;Fa=Ea;break}else{b[h>>1]=v-1;Fa=Ea;break}}else{Fa=q}}while(0);if(!l){return}l=f+1052|0;q=f+1056|0;Ea=f+1068|0;m=f+1060|0;v=f+1064|0;h=0;j=c[l>>2]|0;k=c[q>>2]|0;Ba=c[Ea>>2]|0;while(1){Ca=a[f+10162+h|0]|0;Da=d[1086680+j|0]|0;Aa=j<<Da;c[l>>2]=Aa;za=Ba<<Da;ya=Da+k|0;do{if((ya|0)>-1){Da=c[m>>2]|0;if(!(Da>>>0<(c[v>>2]|0)>>>0)){Ga=za;Ha=ya;break}c[m>>2]=Da+2;wa=Da;Ga=((de((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)<<ya|za;Ha=ya-16|0}else{Ga=za;Ha=ya}}while(0);c[q>>2]=Ha;ya=((ba(Aa-1|0,Ca&255)|0)>>8)+1|0;za=ya<<16;wa=Ga>>>0>=za>>>0;Da=wa?Aa-ya|0:ya;c[l>>2]=Da;ya=Ga-(wa?za:0)|0;c[Ea>>2]=ya;za=a[(wa&1)+(106472+(h<<1))|0]|0;Ia=za<<24>>24;if(za<<24>>24>0){h=Ia;j=Da;k=Ha;Ba=ya}else{break}}Ba=-Ia|0;Ia=f+17636+(Ba<<2)|0;c[Ia>>2]=(c[Ia>>2]|0)+1;if(Ba>>>0>1>>>0){Ia=a[f+10165|0]|0;Ha=c[l>>2]|0;k=d[1086680+Ha|0]|0;j=c[q>>2]|0;h=c[Ea>>2]|0;Ga=Ha<<k;c[l>>2]=Ga;Ha=h<<k;h=j+k|0;do{if((h|0)>-1){k=c[m>>2]|0;if(!(k>>>0<(c[v>>2]|0)>>>0)){Ja=Ha;Ka=h;break}c[m>>2]=k+2;j=k;Ja=((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)<<h|Ha;Ka=h-16|0}else{Ja=Ha;Ka=h}}while(0);c[q>>2]=Ka;h=((ba(Ga-1|0,Ia&255)|0)>>8)+1|0;Ia=h<<16;Ha=Ja>>>0>=Ia>>>0;j=Ha?Ga-h|0:h;c[l>>2]=j;h=Ja-(Ha?Ia:0)|0;c[Ea>>2]=h;Ia=0;Ja=j;j=Ka;Ka=h;while(1){h=a[f+10166+Ia|0]|0;Ga=d[1086680+Ja|0]|0;k=Ja<<Ga;c[l>>2]=k;ya=Ka<<Ga;Da=Ga+j|0;do{if((Da|0)>-1){Ga=c[m>>2]|0;if(!(Ga>>>0<(c[v>>2]|0)>>>0)){La=ya;Ma=Da;break}c[m>>2]=Ga+2;za=Ga;La=((de((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|ya;Ma=Da-16|0}else{La=ya;Ma=Da}}while(0);c[q>>2]=Ma;Da=((ba(k-1|0,h&255)|0)>>8)+1|0;ya=Da<<16;Aa=La>>>0>=ya>>>0;Ca=Aa?k-Da|0:Da;c[l>>2]=Ca;Da=La-(Aa?ya:0)|0;c[Ea>>2]=Da;Na=a[(Aa&1)+(106488+(Ia<<1))|0]|0;Oa=Na<<24>>24;if(Na<<24>>24>0){Ia=Oa;Ja=Ca;j=Ma;Ka=Da}else{break}}Ka=-Oa|0;Oa=f+17652+((Ha&1)<<2)|0;c[Oa>>2]=(c[Oa>>2]|0)+1;Oa=f+17660+(Ka<<2)|0;c[Oa>>2]=(c[Oa>>2]|0)+1;do{if(Na<<24>>24==0){Oa=a[f+10176|0]|0;Ma=c[l>>2]|0;j=d[1086680+Ma|0]|0;Ja=c[q>>2]|0;Ia=c[Ea>>2]|0;La=Ma<<j;c[l>>2]=La;Ma=Ia<<j;Ia=Ja+j|0;do{if((Ia|0)>-1){j=c[m>>2]|0;if(!(j>>>0<(c[v>>2]|0)>>>0)){Pa=Ma;Qa=Ia;break}c[m>>2]=j+2;Ja=j;Pa=((de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)&65535)<<Ia|Ma;Qa=Ia-16|0}else{Pa=Ma;Qa=Ia}}while(0);c[q>>2]=Qa;Ia=((ba(La-1|0,Oa&255)|0)>>8)+1|0;Ma=Ia<<16;k=Pa>>>0>=Ma>>>0;h=k&1;c[l>>2]=k?La-Ia|0:Ia;c[Ea>>2]=Pa-(k?Ma:0);Ma=f+17704+(h<<2)|0;c[Ma>>2]=(c[Ma>>2]|0)+1;Ma=0;k=c[l>>2]|0;Ia=c[q>>2]|0;Ja=c[Ea>>2]|0;while(1){j=a[f+10187+(h*3|0)+Ma|0]|0;Da=d[1086680+k|0]|0;Ca=k<<Da;c[l>>2]=Ca;Aa=Ja<<Da;ya=Da+Ia|0;do{if((ya|0)>-1){Da=c[m>>2]|0;if(!(Da>>>0<(c[v>>2]|0)>>>0)){Ra=Aa;Sa=ya;break}c[m>>2]=Da+2;za=Da;Ra=((de((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<ya|Aa;Sa=ya-16|0}else{Ra=Aa;Sa=ya}}while(0);c[q>>2]=Sa;ya=((ba(Ca-1|0,j&255)|0)>>8)+1|0;Aa=ya<<16;u=Ra>>>0>=Aa>>>0;t=u?Ca-ya|0:ya;c[l>>2]=t;ya=Ra-(u?Aa:0)|0;c[Ea>>2]=ya;Aa=a[(u&1)+(106480+(Ma<<1))|0]|0;Ta=Aa<<24>>24;if(Aa<<24>>24>0){Ma=Ta;k=t;Ia=Sa;Ja=ya}else{break}}Ja=-Ta|0;Ia=f+17792+(h<<4)+(Ja<<2)|0;c[Ia>>2]=(c[Ia>>2]|0)+1;Ia=Ja<<1|h<<3;if((Fa|0)==0){Ja=f+17844|0;c[Ja>>2]=(c[Ja>>2]|0)+1;Ua=Ia|1;break}Ja=a[f+10196|0]|0;k=c[l>>2]|0;Ma=d[1086680+k|0]|0;La=c[q>>2]|0;Oa=c[Ea>>2]|0;ya=k<<Ma;c[l>>2]=ya;k=Oa<<Ma;Oa=La+Ma|0;do{if((Oa|0)>-1){Ma=c[m>>2]|0;if(!(Ma>>>0<(c[v>>2]|0)>>>0)){Va=k;Wa=Oa;break}c[m>>2]=Ma+2;La=Ma;Va=((de((d[La]|d[La+1|0]<<8)<<16>>16|0)|0)&65535)<<Oa|k;Wa=Oa-16|0}else{Va=k;Wa=Oa}}while(0);c[q>>2]=Wa;Oa=((ba(ya-1|0,Ja&255)|0)>>8)+1|0;k=Oa<<16;h=Va>>>0>=k>>>0;La=h&1;c[l>>2]=h?ya-Oa|0:Oa;c[Ea>>2]=Va-(h?k:0);k=f+17840+(La<<2)|0;c[k>>2]=(c[k>>2]|0)+1;Ua=La|Ia}else{La=0;k=0;do{h=a[f+10177+k|0]|0;Oa=c[l>>2]|0;Ma=d[1086680+Oa|0]|0;t=c[q>>2]|0;Aa=c[Ea>>2]|0;u=Oa<<Ma;c[l>>2]=u;Oa=Aa<<Ma;Aa=t+Ma|0;do{if((Aa|0)>-1){Ma=c[m>>2]|0;if(!(Ma>>>0<(c[v>>2]|0)>>>0)){Xa=Oa;Ya=Aa;break}c[m>>2]=Ma+2;t=Ma;Xa=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<Aa|Oa;Ya=Aa-16|0}else{Xa=Oa;Ya=Aa}}while(0);c[q>>2]=Ya;Aa=((ba(u-1|0,h&255)|0)>>8)+1|0;Oa=Aa<<16;Ca=Xa>>>0>=Oa>>>0;j=Ca&1;c[l>>2]=Ca?u-Aa|0:Aa;c[Ea>>2]=Xa-(Ca?Oa:0);La=j<<k|La;Oa=f+17712+(k<<3)+(j<<2)|0;c[Oa>>2]=(c[Oa>>2]|0)+1;k=k+1|0;}while((k|0)<(Ka|0));k=0;Ia=c[l>>2]|0;ya=c[q>>2]|0;Ja=c[Ea>>2]|0;while(1){Oa=a[f+10193+k|0]|0;j=d[1086680+Ia|0]|0;Ca=Ia<<j;c[l>>2]=Ca;Aa=Ja<<j;t=j+ya|0;do{if((t|0)>-1){j=c[m>>2]|0;if(!(j>>>0<(c[v>>2]|0)>>>0)){Za=Aa;_a=t;break}c[m>>2]=j+2;Ma=j;Za=((de((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<t|Aa;_a=t-16|0}else{Za=Aa;_a=t}}while(0);c[q>>2]=_a;t=((ba(Ca-1|0,Oa&255)|0)>>8)+1|0;Aa=t<<16;u=Za>>>0>=Aa>>>0;h=u?Ca-t|0:t;c[l>>2]=h;t=Za-(u?Aa:0)|0;c[Ea>>2]=t;Aa=a[(u&1)+(106480+(k<<1))|0]|0;$a=Aa<<24>>24;if(Aa<<24>>24>0){k=$a;Ia=h;ya=_a;Ja=t}else{break}}Ja=-$a|0;ya=Ja<<1|La<<3;Ia=f+17824+(Ja<<2)|0;c[Ia>>2]=(c[Ia>>2]|0)+1;if((Fa|0)==0){Ia=f+17852|0;c[Ia>>2]=(c[Ia>>2]|0)+1;ab=1}else{Ia=a[f+10197|0]|0;Ja=c[l>>2]|0;k=d[1086680+Ja|0]|0;t=c[q>>2]|0;h=c[Ea>>2]|0;Aa=Ja<<k;c[l>>2]=Aa;Ja=h<<k;h=t+k|0;do{if((h|0)>-1){k=c[m>>2]|0;if(!(k>>>0<(c[v>>2]|0)>>>0)){bb=Ja;cb=h;break}c[m>>2]=k+2;t=k;bb=((de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<h|Ja;cb=h-16|0}else{bb=Ja;cb=h}}while(0);c[q>>2]=cb;h=((ba(Aa-1|0,Ia&255)|0)>>8)+1|0;Ja=h<<16;La=bb>>>0>=Ja>>>0;t=La&1;c[l>>2]=La?Aa-h|0:h;c[Ea>>2]=bb-(La?Ja:0);Ja=f+17848+(t<<2)|0;c[Ja>>2]=(c[Ja>>2]|0)+1;ab=t}Ua=(ya|ab)+(8<<Ka)|0}}while(0);Ka=g+6|0;b[Ka>>1]=(e[Ka>>1]|0)+(Ha?Ua^65535:Ua+1|0)}if((Ba&1|0)==0){return}Ba=a[f+10198|0]|0;Ua=c[l>>2]|0;Ha=d[1086680+Ua|0]|0;Ka=c[q>>2]|0;g=c[Ea>>2]|0;ab=Ua<<Ha;c[l>>2]=ab;Ua=g<<Ha;g=Ka+Ha|0;do{if((g|0)>-1){Ha=c[m>>2]|0;if(!(Ha>>>0<(c[v>>2]|0)>>>0)){db=Ua;eb=g;break}c[m>>2]=Ha+2;Ka=Ha;db=((de((d[Ka]|d[Ka+1|0]<<8)<<16>>16|0)|0)&65535)<<g|Ua;eb=g-16|0}else{db=Ua;eb=g}}while(0);c[q>>2]=eb;g=((ba(ab-1|0,Ba&255)|0)>>8)+1|0;Ba=g<<16;Ua=db>>>0>=Ba>>>0;Ka=Ua?ab-g|0:g;c[l>>2]=Ka;g=db-(Ua?Ba:0)|0;c[Ea>>2]=g;Ba=0;db=Ka;Ka=eb;eb=g;while(1){g=a[f+10199+Ba|0]|0;ab=d[1086680+db|0]|0;Ha=db<<ab;c[l>>2]=Ha;bb=eb<<ab;cb=ab+Ka|0;do{if((cb|0)>-1){ab=c[m>>2]|0;if(!(ab>>>0<(c[v>>2]|0)>>>0)){fb=bb;gb=cb;break}c[m>>2]=ab+2;$a=ab;fb=((de((d[$a]|d[$a+1|0]<<8)<<16>>16|0)|0)&65535)<<cb|bb;gb=cb-16|0}else{fb=bb;gb=cb}}while(0);c[q>>2]=gb;cb=((ba(Ha-1|0,g&255)|0)>>8)+1|0;bb=cb<<16;ya=fb>>>0>=bb>>>0;Aa=ya?Ha-cb|0:cb;c[l>>2]=Aa;cb=fb-(ya?bb:0)|0;c[Ea>>2]=cb;hb=a[(ya&1)+(106488+(Ba<<1))|0]|0;ib=hb<<24>>24;if(hb<<24>>24>0){Ba=ib;db=Aa;Ka=gb;eb=cb}else{break}}eb=-ib|0;ib=f+17856+((Ua&1)<<2)|0;c[ib>>2]=(c[ib>>2]|0)+1;ib=f+17864+(eb<<2)|0;c[ib>>2]=(c[ib>>2]|0)+1;do{if(hb<<24>>24==0){ib=a[f+10209|0]|0;gb=c[l>>2]|0;Ka=d[1086680+gb|0]|0;db=c[q>>2]|0;Ba=c[Ea>>2]|0;fb=gb<<Ka;c[l>>2]=fb;gb=Ba<<Ka;Ba=db+Ka|0;do{if((Ba|0)>-1){Ka=c[m>>2]|0;if(!(Ka>>>0<(c[v>>2]|0)>>>0)){jb=gb;kb=Ba;break}c[m>>2]=Ka+2;db=Ka;jb=((de((d[db]|d[db+1|0]<<8)<<16>>16|0)|0)&65535)<<Ba|gb;kb=Ba-16|0}else{jb=gb;kb=Ba}}while(0);c[q>>2]=kb;Ba=((ba(fb-1|0,ib&255)|0)>>8)+1|0;gb=Ba<<16;Ha=jb>>>0>=gb>>>0;g=Ha&1;c[l>>2]=Ha?fb-Ba|0:Ba;c[Ea>>2]=jb-(Ha?gb:0);gb=f+17908+(g<<2)|0;c[gb>>2]=(c[gb>>2]|0)+1;gb=0;Ha=c[l>>2]|0;Ba=c[q>>2]|0;db=c[Ea>>2]|0;while(1){Ka=a[f+10220+(g*3|0)+gb|0]|0;cb=d[1086680+Ha|0]|0;Aa=Ha<<cb;c[l>>2]=Aa;ya=db<<cb;bb=cb+Ba|0;do{if((bb|0)>-1){cb=c[m>>2]|0;if(!(cb>>>0<(c[v>>2]|0)>>>0)){lb=ya;mb=bb;break}c[m>>2]=cb+2;Ia=cb;lb=((de((d[Ia]|d[Ia+1|0]<<8)<<16>>16|0)|0)&65535)<<bb|ya;mb=bb-16|0}else{lb=ya;mb=bb}}while(0);c[q>>2]=mb;bb=((ba(Aa-1|0,Ka&255)|0)>>8)+1|0;ya=bb<<16;Ca=lb>>>0>=ya>>>0;Oa=Ca?Aa-bb|0:bb;c[l>>2]=Oa;bb=lb-(Ca?ya:0)|0;c[Ea>>2]=bb;ya=a[(Ca&1)+(106480+(gb<<1))|0]|0;nb=ya<<24>>24;if(ya<<24>>24>0){gb=nb;Ha=Oa;Ba=mb;db=bb}else{break}}db=-nb|0;Ba=f+17996+(g<<4)+(db<<2)|0;c[Ba>>2]=(c[Ba>>2]|0)+1;Ba=db<<1|g<<3;if((Fa|0)==0){db=f+18048|0;c[db>>2]=(c[db>>2]|0)+1;ob=Ba|1;break}db=a[f+10229|0]|0;Ha=c[l>>2]|0;gb=d[1086680+Ha|0]|0;fb=c[q>>2]|0;ib=c[Ea>>2]|0;bb=Ha<<gb;c[l>>2]=bb;Ha=ib<<gb;ib=fb+gb|0;do{if((ib|0)>-1){gb=c[m>>2]|0;if(!(gb>>>0<(c[v>>2]|0)>>>0)){pb=Ha;qb=ib;break}c[m>>2]=gb+2;fb=gb;pb=((de((d[fb]|d[fb+1|0]<<8)<<16>>16|0)|0)&65535)<<ib|Ha;qb=ib-16|0}else{pb=Ha;qb=ib}}while(0);c[q>>2]=qb;ib=((ba(bb-1|0,db&255)|0)>>8)+1|0;Ha=ib<<16;g=pb>>>0>=Ha>>>0;fb=g&1;c[l>>2]=g?bb-ib|0:ib;c[Ea>>2]=pb-(g?Ha:0);Ha=f+18044+(fb<<2)|0;c[Ha>>2]=(c[Ha>>2]|0)+1;ob=fb|Ba}else{fb=0;Ha=0;do{g=a[f+10210+Ha|0]|0;ib=c[l>>2]|0;gb=d[1086680+ib|0]|0;Oa=c[q>>2]|0;ya=c[Ea>>2]|0;Ca=ib<<gb;c[l>>2]=Ca;ib=ya<<gb;ya=Oa+gb|0;do{if((ya|0)>-1){gb=c[m>>2]|0;if(!(gb>>>0<(c[v>>2]|0)>>>0)){rb=ib;sb=ya;break}c[m>>2]=gb+2;Oa=gb;rb=((de((d[Oa]|d[Oa+1|0]<<8)<<16>>16|0)|0)&65535)<<ya|ib;sb=ya-16|0}else{rb=ib;sb=ya}}while(0);c[q>>2]=sb;ya=((ba(Ca-1|0,g&255)|0)>>8)+1|0;ib=ya<<16;Aa=rb>>>0>=ib>>>0;Ka=Aa&1;c[l>>2]=Aa?Ca-ya|0:ya;c[Ea>>2]=rb-(Aa?ib:0);fb=Ka<<Ha|fb;ib=f+17916+(Ha<<3)+(Ka<<2)|0;c[ib>>2]=(c[ib>>2]|0)+1;Ha=Ha+1|0;}while((Ha|0)<(eb|0));Ha=0;Ba=c[l>>2]|0;bb=c[q>>2]|0;db=c[Ea>>2]|0;while(1){ib=a[f+10226+Ha|0]|0;Ka=d[1086680+Ba|0]|0;Aa=Ba<<Ka;c[l>>2]=Aa;ya=db<<Ka;Oa=Ka+bb|0;do{if((Oa|0)>-1){Ka=c[m>>2]|0;if(!(Ka>>>0<(c[v>>2]|0)>>>0)){tb=ya;ub=Oa;break}c[m>>2]=Ka+2;gb=Ka;tb=((de((d[gb]|d[gb+1|0]<<8)<<16>>16|0)|0)&65535)<<Oa|ya;ub=Oa-16|0}else{tb=ya;ub=Oa}}while(0);c[q>>2]=ub;Oa=((ba(Aa-1|0,ib&255)|0)>>8)+1|0;ya=Oa<<16;Ca=tb>>>0>=ya>>>0;g=Ca?Aa-Oa|0:Oa;c[l>>2]=g;Oa=tb-(Ca?ya:0)|0;c[Ea>>2]=Oa;ya=a[(Ca&1)+(106480+(Ha<<1))|0]|0;vb=ya<<24>>24;if(ya<<24>>24>0){Ha=vb;Ba=g;bb=ub;db=Oa}else{break}}db=-vb|0;bb=db<<1|fb<<3;Ba=f+18028+(db<<2)|0;c[Ba>>2]=(c[Ba>>2]|0)+1;if((Fa|0)==0){Ba=f+18056|0;c[Ba>>2]=(c[Ba>>2]|0)+1;wb=1}else{Ba=a[f+10230|0]|0;db=c[l>>2]|0;Ha=d[1086680+db|0]|0;Oa=c[q>>2]|0;g=c[Ea>>2]|0;ya=db<<Ha;c[l>>2]=ya;db=g<<Ha;g=Oa+Ha|0;do{if((g|0)>-1){Ha=c[m>>2]|0;if(!(Ha>>>0<(c[v>>2]|0)>>>0)){xb=db;yb=g;break}c[m>>2]=Ha+2;Oa=Ha;xb=((de((d[Oa]|d[Oa+1|0]<<8)<<16>>16|0)|0)&65535)<<g|db;yb=g-16|0}else{xb=db;yb=g}}while(0);c[q>>2]=yb;g=((ba(ya-1|0,Ba&255)|0)>>8)+1|0;db=g<<16;fb=xb>>>0>=db>>>0;Oa=fb&1;c[l>>2]=fb?ya-g|0:g;c[Ea>>2]=xb-(fb?db:0);db=f+18052+(Oa<<2)|0;c[db>>2]=(c[db>>2]|0)+1;wb=Oa}ob=(bb|wb)+(8<<eb)|0}}while(0);eb=ta|0;b[eb>>1]=(e[eb>>1]|0)+(Ua?ob^65535:ob+1|0);return}function P6a(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0;j=c[d+1084>>2]|0;k=c[d+1100>>2]|0;l=c[d+1108>>2]|0;m=c[d+1104>>2]|0;n=c[j+48>>2]|0;do{if((i|0)>-1){do{if((i-1|0)>>>0<2>>>0){o=c[j+16+(g<<2)>>2]|0;if((h|0)!=0){p=o;break}c[e>>2]=o;return}else{if((i|0)!=3){p=-2147450880;break}o=c[j+32+(g<<2)>>2]|0;if((h|0)==0){c[e>>2]=o;return}q=c[j+24+(g<<2)>>2]|0;do{if((o|0)==-2147450880){r=q}else{if((q|0)==(o|0)){r=o;break}c[e>>2]=q;return}}while(0);q=c[j+16+(g<<2)>>2]|0;if((r|0)==-2147450880){p=q;break}if((q|0)==(r|0)){p=r;break}c[e>>2]=q;return}}while(0);do{if((k|0)>0){q=(ba((k<<3)-8|0,c[d+1796>>2]|0)|0)+l|0;o=c[d+1380>>2]|0;if((a[o+(q*12|0)+8|0]|0)==(f|0)){s=l<<1|i&1;t=c[d+30144>>2]|0;u=t+(s<<3)|0;if((i|0)>0){v=b[u>>1]|0;w=c[d+35908>>2]|0;x=c[d+35916>>2]|0;if((v|0)<(w|0)){y=w&65535}else{y=((v|0)>(x|0)?x:v)&65535}v=b[t+(s<<3)+2>>1]|0;x=c[d+35912>>2]|0;w=c[d+35920>>2]|0;if((v|0)<(x|0)){z=x&65535}else{z=((v|0)>(w|0)?w:v)&65535}v=(z&65535)<<16|y&65535;if((h|0)==0){c[e>>2]=v;return}if((p|0)==-2147450880){A=v;break}if((v|0)==(p|0)){A=p;break}c[e>>2]=v;return}v=c[u>>2]|0;u=v&65535;if((h|0)==0){w=u<<16>>16;x=c[d+35908>>2]|0;B=c[d+35916>>2]|0;if((w|0)<(x|0)){C=x&65535}else{C=((w|0)>(B|0)?B:w)&65535}b[e>>1]=C;w=b[t+(s<<3)+2>>1]|0;B=c[d+35912>>2]|0;x=c[d+35920>>2]|0;if((w|0)<(B|0)){D=B&65535}else{D=((w|0)>(x|0)?x:w)&65535}b[e+2>>1]=D;return}if((p|0)==-2147450880){A=v;break}if((v|0)==(p|0)){A=p;break}v=u<<16>>16;u=c[d+35908>>2]|0;w=c[d+35916>>2]|0;if((v|0)<(u|0)){E=u&65535}else{E=((v|0)>(w|0)?w:v)&65535}b[e>>1]=E;v=b[t+(s<<3)+2>>1]|0;s=c[d+35912>>2]|0;t=c[d+35920>>2]|0;if((v|0)<(s|0)){F=s&65535}else{F=((v|0)>(t|0)?t:v)&65535}b[e+2>>1]=F;return}if((a[o+(q*12|0)+9|0]|0)!=(f|0)){A=p;break}q=l<<1|i&1;o=c[d+30144>>2]|0;v=o+(q<<3)+4|0;if((i|0)>0){t=b[v>>1]|0;s=c[d+35908>>2]|0;w=c[d+35916>>2]|0;if((t|0)<(s|0)){G=s&65535}else{G=((t|0)>(w|0)?w:t)&65535}t=b[o+(q<<3)+6>>1]|0;w=c[d+35912>>2]|0;s=c[d+35920>>2]|0;if((t|0)<(w|0)){H=w&65535}else{H=((t|0)>(s|0)?s:t)&65535}t=(H&65535)<<16|G&65535;if((h|0)==0){c[e>>2]=t;return}if((p|0)==-2147450880){A=t;break}if((t|0)==(p|0)){A=p;break}c[e>>2]=t;return}t=c[v>>2]|0;v=t&65535;if((h|0)==0){s=v<<16>>16;w=c[d+35908>>2]|0;u=c[d+35916>>2]|0;if((s|0)<(w|0)){I=w&65535}else{I=((s|0)>(u|0)?u:s)&65535}b[e>>1]=I;s=b[o+(q<<3)+6>>1]|0;u=c[d+35912>>2]|0;w=c[d+35920>>2]|0;if((s|0)<(u|0)){J=u&65535}else{J=((s|0)>(w|0)?w:s)&65535}b[e+2>>1]=J;return}if((p|0)==-2147450880){A=t;break}if((t|0)==(p|0)){A=p;break}t=v<<16>>16;v=c[d+35908>>2]|0;s=c[d+35916>>2]|0;if((t|0)<(v|0)){K=v&65535}else{K=((t|0)>(s|0)?s:t)&65535}b[e>>1]=K;t=b[o+(q<<3)+6>>1]|0;q=c[d+35912>>2]|0;o=c[d+35920>>2]|0;if((t|0)<(q|0)){L=q&65535}else{L=((t|0)>(o|0)?o:t)&65535}b[e+2>>1]=L;return}else{A=p}}while(0);t=c[d+1788>>2]|0;if(!(l>>>0>t>>>0)){M=A;N=2;O=t;break}o=l-1+(ba(k<<3,c[d+1796>>2]|0)|0)|0;q=c[d+1380>>2]|0;if((a[q+(o*12|0)+8|0]|0)==(f|0)){s=(m<<1)+(i>>1)|0;v=d+29888+(s<<3)|0;if((i|0)>0){w=b[v>>1]|0;u=c[d+35908>>2]|0;x=c[d+35916>>2]|0;if((w|0)<(u|0)){P=u&65535}else{P=((w|0)>(x|0)?x:w)&65535}w=b[d+29888+(s<<3)+2>>1]|0;x=c[d+35912>>2]|0;u=c[d+35920>>2]|0;if((w|0)<(x|0)){Q=x&65535}else{Q=((w|0)>(u|0)?u:w)&65535}w=(Q&65535)<<16|P&65535;if((h|0)==0){c[e>>2]=w;return}if((A|0)==-2147450880){M=w;N=2;O=t;break}if((w|0)==(A|0)){M=A;N=2;O=t;break}c[e>>2]=w;return}w=c[v>>2]|0;v=w&65535;if((h|0)==0){u=v<<16>>16;x=c[d+35908>>2]|0;B=c[d+35916>>2]|0;if((u|0)<(x|0)){R=x&65535}else{R=((u|0)>(B|0)?B:u)&65535}b[e>>1]=R;u=b[d+29888+(s<<3)+2>>1]|0;B=c[d+35912>>2]|0;x=c[d+35920>>2]|0;if((u|0)<(B|0)){S=B&65535}else{S=((u|0)>(x|0)?x:u)&65535}b[e+2>>1]=S;return}if((A|0)==-2147450880){M=w;N=2;O=t;break}if((w|0)==(A|0)){M=A;N=2;O=t;break}w=v<<16>>16;v=c[d+35908>>2]|0;u=c[d+35916>>2]|0;if((w|0)<(v|0)){T=v&65535}else{T=((w|0)>(u|0)?u:w)&65535}b[e>>1]=T;w=b[d+29888+(s<<3)+2>>1]|0;s=c[d+35912>>2]|0;u=c[d+35920>>2]|0;if((w|0)<(s|0)){U=s&65535}else{U=((w|0)>(u|0)?u:w)&65535}b[e+2>>1]=U;return}if((a[q+(o*12|0)+9|0]|0)!=(f|0)){M=A;N=2;O=t;break}o=(m<<1)+(i>>1)|0;q=d+29888+(o<<3)+4|0;if((i|0)>0){w=b[q>>1]|0;u=c[d+35908>>2]|0;s=c[d+35916>>2]|0;if((w|0)<(u|0)){V=u&65535}else{V=((w|0)>(s|0)?s:w)&65535}w=b[d+29888+(o<<3)+6>>1]|0;s=c[d+35912>>2]|0;u=c[d+35920>>2]|0;if((w|0)<(s|0)){W=s&65535}else{W=((w|0)>(u|0)?u:w)&65535}w=(W&65535)<<16|V&65535;if((h|0)==0){c[e>>2]=w;return}if((A|0)==-2147450880){M=w;N=2;O=t;break}if((w|0)==(A|0)){M=A;N=2;O=t;break}c[e>>2]=w;return}w=c[q>>2]|0;q=w&65535;if((h|0)==0){u=q<<16>>16;s=c[d+35908>>2]|0;v=c[d+35916>>2]|0;if((u|0)<(s|0)){X=s&65535}else{X=((u|0)>(v|0)?v:u)&65535}b[e>>1]=X;u=b[d+29888+(o<<3)+6>>1]|0;v=c[d+35912>>2]|0;s=c[d+35920>>2]|0;if((u|0)<(v|0)){Y=v&65535}else{Y=((u|0)>(s|0)?s:u)&65535}b[e+2>>1]=Y;return}if((A|0)==-2147450880){M=w;N=2;O=t;break}if((w|0)==(A|0)){M=A;N=2;O=t;break}t=q<<16>>16;q=c[d+35908>>2]|0;w=c[d+35916>>2]|0;if((t|0)<(q|0)){Z=q&65535}else{Z=((t|0)>(w|0)?w:t)&65535}b[e>>1]=Z;t=b[d+29888+(o<<3)+6>>1]|0;o=c[d+35912>>2]|0;w=c[d+35920>>2]|0;if((t|0)<(o|0)){_=o&65535}else{_=((t|0)>(w|0)?w:t)&65535}b[e+2>>1]=_;return}else{M=-2147450880;N=0;O=c[d+1788>>2]|0}}while(0);_=d+1788|0;Z=d+1808|0;A=d+1804|0;Y=d+1796|0;X=d+1380|0;V=(i|0)>0;i=d+35908|0;W=d+35916|0;m=d+35912|0;U=d+35920|0;T=(h|0)==0;h=N;N=M;a:while(1){M=(a[1058192+(n<<4)+(h<<1)|0]|0)+l|0;S=(a[1058192+(n<<4)+(h<<1)+1|0]|0)+k|0;do{if(M>>>0<O>>>0){$=N}else{if(!(M>>>0<(c[Z>>2]|0)>>>0&(S|0)>-1)){$=N;break}if(!(S>>>0<(c[A>>2]|0)>>>0)){$=N;break}aa=(ba(S<<3,c[Y>>2]|0)|0)+M|0;ca=c[X>>2]|0;if((a[ca+(aa*12|0)+8|0]|0)==(f|0)){R=ca+(aa*12|0)|0;if(!V){P=c[R>>2]|0;da=P&65535;if(T){ea=129;break a}if((N|0)==-2147450880){$=P;break}if((P|0)==(N|0)){$=N;break}else{ea=136;break a}}P=b[R>>1]|0;R=c[i>>2]|0;Q=c[W>>2]|0;if((P|0)<(R|0)){fa=R&65535}else{fa=((P|0)>(Q|0)?Q:P)&65535}P=b[ca+(aa*12|0)+2>>1]|0;Q=c[m>>2]|0;R=c[U>>2]|0;if((P|0)<(Q|0)){ga=Q&65535}else{ga=((P|0)>(R|0)?R:P)&65535}ha=(ga&65535)<<16|fa&65535;if(T){ea=124;break a}if((N|0)==-2147450880){$=ha;break}if((ha|0)==(N|0)){$=N;break}else{ea=127;break a}}if((a[ca+(aa*12|0)+9|0]|0)!=(f|0)){$=N;break}P=ca+(aa*12|0)+4|0;if(!V){R=c[P>>2]|0;ia=R&65535;if(T){ea=153;break a}if((N|0)==-2147450880){$=R;break}if((R|0)==(N|0)){$=N;break}else{ea=160;break a}}R=b[P>>1]|0;P=c[i>>2]|0;Q=c[W>>2]|0;if((R|0)<(P|0)){ja=P&65535}else{ja=((R|0)>(Q|0)?Q:R)&65535}R=b[ca+(aa*12|0)+6>>1]|0;Q=c[m>>2]|0;P=c[U>>2]|0;if((R|0)<(Q|0)){ka=Q&65535}else{ka=((R|0)>(P|0)?P:R)&65535}la=(ka&65535)<<16|ja&65535;if(T){ea=148;break a}if((N|0)==-2147450880){$=la;break}if((la|0)==(N|0)){$=N}else{ea=151;break a}}}while(0);M=h+1|0;if((M|0)<8){h=M;N=$}else{ea=166;break}}if((ea|0)==124){c[e>>2]=ha;return}else if((ea|0)==127){c[e>>2]=ha;return}else if((ea|0)==129){ha=da<<16>>16;N=c[i>>2]|0;h=c[W>>2]|0;if((ha|0)<(N|0)){ma=N&65535}else{ma=((ha|0)>(h|0)?h:ha)&65535}b[e>>1]=ma;ma=b[ca+(aa*12|0)+2>>1]|0;ha=c[m>>2]|0;h=c[U>>2]|0;if((ma|0)<(ha|0)){na=ha&65535}else{na=((ma|0)>(h|0)?h:ma)&65535}b[e+2>>1]=na;return}else if((ea|0)==136){na=da<<16>>16;da=c[i>>2]|0;ma=c[W>>2]|0;if((na|0)<(da|0)){oa=da&65535}else{oa=((na|0)>(ma|0)?ma:na)&65535}b[e>>1]=oa;oa=b[ca+(aa*12|0)+2>>1]|0;na=c[m>>2]|0;ma=c[U>>2]|0;if((oa|0)<(na|0)){pa=na&65535}else{pa=((oa|0)>(ma|0)?ma:oa)&65535}b[e+2>>1]=pa;return}else if((ea|0)==148){c[e>>2]=la;return}else if((ea|0)==151){c[e>>2]=la;return}else if((ea|0)==153){la=ia<<16>>16;pa=c[i>>2]|0;oa=c[W>>2]|0;if((la|0)<(pa|0)){qa=pa&65535}else{qa=((la|0)>(oa|0)?oa:la)&65535}b[e>>1]=qa;qa=b[ca+(aa*12|0)+6>>1]|0;la=c[m>>2]|0;oa=c[U>>2]|0;if((qa|0)<(la|0)){ra=la&65535}else{ra=((qa|0)>(oa|0)?oa:qa)&65535}b[e+2>>1]=ra;return}else if((ea|0)==160){ra=ia<<16>>16;ia=c[i>>2]|0;qa=c[W>>2]|0;if((ra|0)<(ia|0)){sa=ia&65535}else{sa=((ra|0)>(qa|0)?qa:ra)&65535}b[e>>1]=sa;sa=b[ca+(aa*12|0)+6>>1]|0;aa=c[m>>2]|0;ca=c[U>>2]|0;if((sa|0)<(aa|0)){ta=aa&65535}else{ta=((sa|0)>(ca|0)?ca:sa)&65535}b[e+2>>1]=ta;return}else if((ea|0)==166){ta=d+1140|0;do{if((a[ta]|0)==0){ua=$}else{sa=(ba(k<<3,c[Y>>2]|0)|0)+l|0;ca=c[d+1404>>2]|0;if((c[d+1096>>2]|0)==0){Z0a(d+1384|0,k>>3,0)}if((a[ca+(sa*12|0)+8|0]|0)==(f|0)){aa=ca+(sa*12|0)|0;if(V){ra=b[aa>>1]|0;qa=c[i>>2]|0;ia=c[W>>2]|0;if((ra|0)<(qa|0)){va=qa&65535}else{va=((ra|0)>(ia|0)?ia:ra)&65535}ra=b[ca+(sa*12|0)+2>>1]|0;ia=c[m>>2]|0;qa=c[U>>2]|0;if((ra|0)<(ia|0)){wa=ia&65535}else{wa=((ra|0)>(qa|0)?qa:ra)&65535}ra=(wa&65535)<<16|va&65535;if(T){c[e>>2]=ra;return}if(($|0)==-2147450880){ua=ra;break}if((ra|0)==($|0)){ua=$;break}c[e>>2]=ra;return}ra=c[aa>>2]|0;aa=ra&65535;if(T){qa=aa<<16>>16;ia=c[i>>2]|0;oa=c[W>>2]|0;if((qa|0)<(ia|0)){xa=ia&65535}else{xa=((qa|0)>(oa|0)?oa:qa)&65535}b[e>>1]=xa;qa=b[ca+(sa*12|0)+2>>1]|0;oa=c[m>>2]|0;ia=c[U>>2]|0;if((qa|0)<(oa|0)){ya=oa&65535}else{ya=((qa|0)>(ia|0)?ia:qa)&65535}b[e+2>>1]=ya;return}if(($|0)==-2147450880){ua=ra;break}if((ra|0)==($|0)){ua=$;break}ra=aa<<16>>16;aa=c[i>>2]|0;qa=c[W>>2]|0;if((ra|0)<(aa|0)){za=aa&65535}else{za=((ra|0)>(qa|0)?qa:ra)&65535}b[e>>1]=za;ra=b[ca+(sa*12|0)+2>>1]|0;qa=c[m>>2]|0;aa=c[U>>2]|0;if((ra|0)<(qa|0)){Aa=qa&65535}else{Aa=((ra|0)>(aa|0)?aa:ra)&65535}b[e+2>>1]=Aa;return}if((a[ca+(sa*12|0)+9|0]|0)!=(f|0)){ua=$;break}ra=ca+(sa*12|0)+4|0;if(V){aa=b[ra>>1]|0;qa=c[i>>2]|0;ia=c[W>>2]|0;if((aa|0)<(qa|0)){Ba=qa&65535}else{Ba=((aa|0)>(ia|0)?ia:aa)&65535}aa=b[ca+(sa*12|0)+6>>1]|0;ia=c[m>>2]|0;qa=c[U>>2]|0;if((aa|0)<(ia|0)){Ca=ia&65535}else{Ca=((aa|0)>(qa|0)?qa:aa)&65535}aa=(Ca&65535)<<16|Ba&65535;if(T){c[e>>2]=aa;return}if(($|0)==-2147450880){ua=aa;break}if((aa|0)==($|0)){ua=$;break}c[e>>2]=aa;return}aa=c[ra>>2]|0;ra=aa&65535;if(T){qa=ra<<16>>16;ia=c[i>>2]|0;oa=c[W>>2]|0;if((qa|0)<(ia|0)){Da=ia&65535}else{Da=((qa|0)>(oa|0)?oa:qa)&65535}b[e>>1]=Da;qa=b[ca+(sa*12|0)+6>>1]|0;oa=c[m>>2]|0;ia=c[U>>2]|0;if((qa|0)<(oa|0)){Ea=oa&65535}else{Ea=((qa|0)>(ia|0)?ia:qa)&65535}b[e+2>>1]=Ea;return}if(($|0)==-2147450880){ua=aa;break}if((aa|0)==($|0)){ua=$;break}aa=ra<<16>>16;ra=c[i>>2]|0;qa=c[W>>2]|0;if((aa|0)<(ra|0)){Fa=ra&65535}else{Fa=((aa|0)>(qa|0)?qa:aa)&65535}b[e>>1]=Fa;aa=b[ca+(sa*12|0)+6>>1]|0;sa=c[m>>2]|0;ca=c[U>>2]|0;if((aa|0)<(sa|0)){Ga=sa&65535}else{Ga=((aa|0)>(ca|0)?ca:aa)&65535}b[e+2>>1]=Ga;return}}while(0);Ga=c[_>>2]|0;_=d+1160+f|0;Fa=0;$=ua;b:while(1){ua=(a[1058192+(n<<4)+(Fa<<1)|0]|0)+l|0;Ea=(a[1058192+(n<<4)+(Fa<<1)+1|0]|0)+k|0;do{if(ua>>>0<Ga>>>0){Ha=$}else{if(!(ua>>>0<(c[Z>>2]|0)>>>0&(Ea|0)>-1)){Ha=$;break}if(!(Ea>>>0<(c[A>>2]|0)>>>0)){Ha=$;break}Ia=(ba(Ea<<3,c[Y>>2]|0)|0)+ua|0;Ja=c[X>>2]|0;Da=Ja+(Ia*12|0)|0;Ba=a[Ja+(Ia*12|0)+8|0]|0;Ca=Ba<<24>>24;do{if((Ca|0)!=(f|0)&Ba<<24>>24>-1){if((a[d+1160+Ca|0]|0)==(a[_]|0)){if(!V){Aa=c[Da>>2]|0;Ka=Aa&65535;if(T){ea=257;break b}if(($|0)==-2147450880){La=Aa;break}if((Aa|0)==($|0)){La=$;break}else{ea=264;break b}}Aa=b[Da>>1]|0;za=c[i>>2]|0;ya=c[W>>2]|0;if((Aa|0)<(za|0)){Ma=za&65535}else{Ma=((Aa|0)>(ya|0)?ya:Aa)&65535}Aa=b[Ja+(Ia*12|0)+2>>1]|0;ya=c[m>>2]|0;za=c[U>>2]|0;if((Aa|0)<(ya|0)){Na=ya&65535}else{Na=((Aa|0)>(za|0)?za:Aa)&65535}Oa=(Na&65535)<<16|Ma&65535;if(T){ea=252;break b}if(($|0)==-2147450880){La=Oa;break}if((Oa|0)==($|0)){La=$;break}else{ea=255;break b}}else{Pa=-(b[Da>>1]|0)&65535;Qa=-(b[Ja+(Ia*12|0)+2>>1]|0)&65535;if(!V){Aa=(Qa&65535)<<16|Pa&65535;if(T){ea=234;break b}if(($|0)==-2147450880){La=Aa;break}if((Aa|0)==($|0)){La=$;break}else{ea=241;break b}}Aa=Pa<<16>>16;za=c[i>>2]|0;ya=c[W>>2]|0;if((Aa|0)<(za|0)){Ra=za&65535}else{Ra=((Aa|0)>(ya|0)?ya:Aa)&65535}Aa=Qa<<16>>16;ya=c[m>>2]|0;za=c[U>>2]|0;if((Aa|0)<(ya|0)){Sa=ya&65535}else{Sa=((Aa|0)>(za|0)?za:Aa)&65535}Ta=(Sa&65535)<<16|Ra&65535;if(T){ea=229;break b}if(($|0)==-2147450880){La=Ta;break}if((Ta|0)==($|0)){La=$;break}else{ea=232;break b}}}else{La=$}}while(0);Ca=a[Ja+(Ia*12|0)+9|0]|0;Ba=Ca<<24>>24;if(!((Ba|0)!=(f|0)&Ca<<24>>24>-1)){Ha=La;break}Ca=c[Ja+(Ia*12|0)+4>>2]|0;Ua=Ca&65535;if((c[Da>>2]|0)==(Ca|0)){Ha=La;break}if((a[d+1160+Ba|0]|0)==(a[_]|0)){if(!V){if(T){ea=306;break b}if((La|0)==-2147450880){Ha=Ca;break}if((Ca|0)==(La|0)){Ha=La;break}else{ea=313;break b}}Ca=Ua<<16>>16;Ba=c[i>>2]|0;Aa=c[W>>2]|0;if((Ca|0)<(Ba|0)){Va=Ba&65535}else{Va=((Ca|0)>(Aa|0)?Aa:Ca)&65535}Ca=b[Ja+(Ia*12|0)+6>>1]|0;Aa=c[m>>2]|0;Ba=c[U>>2]|0;if((Ca|0)<(Aa|0)){Wa=Aa&65535}else{Wa=((Ca|0)>(Ba|0)?Ba:Ca)&65535}Xa=(Wa&65535)<<16|Va&65535;if(T){ea=301;break b}if((La|0)==-2147450880){Ha=Xa;break}if((Xa|0)==(La|0)){Ha=La;break}else{ea=304;break b}}else{Ya=-Ua&65535;Za=-(b[Ja+(Ia*12|0)+6>>1]|0)&65535;if(!V){Ca=(Za&65535)<<16|Ya&65535;if(T){ea=283;break b}if((La|0)==-2147450880){Ha=Ca;break}if((Ca|0)==(La|0)){Ha=La;break}else{ea=290;break b}}Ca=Ya<<16>>16;Ba=c[i>>2]|0;Aa=c[W>>2]|0;if((Ca|0)<(Ba|0)){_a=Ba&65535}else{_a=((Ca|0)>(Aa|0)?Aa:Ca)&65535}Ca=Za<<16>>16;Aa=c[m>>2]|0;Ba=c[U>>2]|0;if((Ca|0)<(Aa|0)){$a=Aa&65535}else{$a=((Ca|0)>(Ba|0)?Ba:Ca)&65535}ab=($a&65535)<<16|_a&65535;if(T){ea=278;break b}if((La|0)==-2147450880){Ha=ab;break}if((ab|0)==(La|0)){Ha=La;break}else{ea=281;break b}}}}while(0);ua=Fa+1|0;if((ua|0)<8){Fa=ua;$=Ha}else{ea=319;break}}if((ea|0)==229){c[e>>2]=Ta;return}else if((ea|0)==232){c[e>>2]=Ta;return}else if((ea|0)==234){Ta=Pa<<16>>16;$=c[i>>2]|0;Fa=c[W>>2]|0;if((Ta|0)<($|0)){bb=$&65535}else{bb=((Ta|0)>(Fa|0)?Fa:Ta)&65535}b[e>>1]=bb;bb=Qa<<16>>16;Ta=c[m>>2]|0;Fa=c[U>>2]|0;if((bb|0)<(Ta|0)){cb=Ta&65535}else{cb=((bb|0)>(Fa|0)?Fa:bb)&65535}b[e+2>>1]=cb;return}else if((ea|0)==241){cb=Pa<<16>>16;Pa=c[i>>2]|0;bb=c[W>>2]|0;if((cb|0)<(Pa|0)){db=Pa&65535}else{db=((cb|0)>(bb|0)?bb:cb)&65535}b[e>>1]=db;db=Qa<<16>>16;Qa=c[m>>2]|0;cb=c[U>>2]|0;if((db|0)<(Qa|0)){eb=Qa&65535}else{eb=((db|0)>(cb|0)?cb:db)&65535}b[e+2>>1]=eb;return}else if((ea|0)==252){c[e>>2]=Oa;return}else if((ea|0)==255){c[e>>2]=Oa;return}else if((ea|0)==257){Oa=Ka<<16>>16;eb=c[i>>2]|0;db=c[W>>2]|0;if((Oa|0)<(eb|0)){fb=eb&65535}else{fb=((Oa|0)>(db|0)?db:Oa)&65535}b[e>>1]=fb;fb=b[Ja+(Ia*12|0)+2>>1]|0;Oa=c[m>>2]|0;db=c[U>>2]|0;if((fb|0)<(Oa|0)){gb=Oa&65535}else{gb=((fb|0)>(db|0)?db:fb)&65535}b[e+2>>1]=gb;return}else if((ea|0)==264){gb=Ka<<16>>16;Ka=c[i>>2]|0;fb=c[W>>2]|0;if((gb|0)<(Ka|0)){hb=Ka&65535}else{hb=((gb|0)>(fb|0)?fb:gb)&65535}b[e>>1]=hb;hb=b[Ja+(Ia*12|0)+2>>1]|0;gb=c[m>>2]|0;fb=c[U>>2]|0;if((hb|0)<(gb|0)){ib=gb&65535}else{ib=((hb|0)>(fb|0)?fb:hb)&65535}b[e+2>>1]=ib;return}else if((ea|0)==278){c[e>>2]=ab;return}else if((ea|0)==281){c[e>>2]=ab;return}else if((ea|0)==283){ab=Ya<<16>>16;ib=c[i>>2]|0;hb=c[W>>2]|0;if((ab|0)<(ib|0)){jb=ib&65535}else{jb=((ab|0)>(hb|0)?hb:ab)&65535}b[e>>1]=jb;jb=Za<<16>>16;ab=c[m>>2]|0;hb=c[U>>2]|0;if((jb|0)<(ab|0)){kb=ab&65535}else{kb=((jb|0)>(hb|0)?hb:jb)&65535}b[e+2>>1]=kb;return}else if((ea|0)==290){kb=Ya<<16>>16;Ya=c[i>>2]|0;jb=c[W>>2]|0;if((kb|0)<(Ya|0)){lb=Ya&65535}else{lb=((kb|0)>(jb|0)?jb:kb)&65535}b[e>>1]=lb;lb=Za<<16>>16;Za=c[m>>2]|0;kb=c[U>>2]|0;if((lb|0)<(Za|0)){mb=Za&65535}else{mb=((lb|0)>(kb|0)?kb:lb)&65535}b[e+2>>1]=mb;return}else if((ea|0)==301){c[e>>2]=Xa;return}else if((ea|0)==304){c[e>>2]=Xa;return}else if((ea|0)==306){Xa=Ua<<16>>16;mb=c[i>>2]|0;lb=c[W>>2]|0;if((Xa|0)<(mb|0)){nb=mb&65535}else{nb=((Xa|0)>(lb|0)?lb:Xa)&65535}b[e>>1]=nb;nb=b[Ja+(Ia*12|0)+6>>1]|0;Xa=c[m>>2]|0;lb=c[U>>2]|0;if((nb|0)<(Xa|0)){ob=Xa&65535}else{ob=((nb|0)>(lb|0)?lb:nb)&65535}b[e+2>>1]=ob;return}else if((ea|0)==313){ob=Ua<<16>>16;Ua=c[i>>2]|0;nb=c[W>>2]|0;if((ob|0)<(Ua|0)){pb=Ua&65535}else{pb=((ob|0)>(nb|0)?nb:ob)&65535}b[e>>1]=pb;pb=b[Ja+(Ia*12|0)+6>>1]|0;Ia=c[m>>2]|0;Ja=c[U>>2]|0;if((pb|0)<(Ia|0)){qb=Ia&65535}else{qb=((pb|0)>(Ja|0)?Ja:pb)&65535}b[e+2>>1]=qb;return}else if((ea|0)==319){do{if((a[ta]|0)!=0){ea=(ba(k<<3,c[Y>>2]|0)|0)+l|0;qb=c[d+1404>>2]|0;pb=qb+(ea*12|0)|0;Ja=a[qb+(ea*12|0)+8|0]|0;Ia=Ja<<24>>24;do{if((Ia|0)!=(f|0)&Ja<<24>>24>-1){if((a[d+1160+Ia|0]|0)==(a[_]|0)){if(V){ob=b[pb>>1]|0;nb=c[i>>2]|0;Ua=c[W>>2]|0;if((ob|0)<(nb|0)){rb=nb&65535}else{rb=((ob|0)>(Ua|0)?Ua:ob)&65535}ob=b[qb+(ea*12|0)+2>>1]|0;Ua=c[m>>2]|0;nb=c[U>>2]|0;if((ob|0)<(Ua|0)){sb=Ua&65535}else{sb=((ob|0)>(nb|0)?nb:ob)&65535}ob=(sb&65535)<<16|rb&65535;if(T){c[e>>2]=ob;return}if((Ha|0)==-2147450880){tb=ob;break}if((ob|0)==(Ha|0)){tb=Ha;break}c[e>>2]=ob;return}ob=c[pb>>2]|0;nb=ob&65535;if(T){Ua=nb<<16>>16;lb=c[i>>2]|0;Xa=c[W>>2]|0;if((Ua|0)<(lb|0)){ub=lb&65535}else{ub=((Ua|0)>(Xa|0)?Xa:Ua)&65535}b[e>>1]=ub;Ua=b[qb+(ea*12|0)+2>>1]|0;Xa=c[m>>2]|0;lb=c[U>>2]|0;if((Ua|0)<(Xa|0)){vb=Xa&65535}else{vb=((Ua|0)>(lb|0)?lb:Ua)&65535}b[e+2>>1]=vb;return}if((Ha|0)==-2147450880){tb=ob;break}if((ob|0)==(Ha|0)){tb=Ha;break}ob=nb<<16>>16;nb=c[i>>2]|0;Ua=c[W>>2]|0;if((ob|0)<(nb|0)){wb=nb&65535}else{wb=((ob|0)>(Ua|0)?Ua:ob)&65535}b[e>>1]=wb;ob=b[qb+(ea*12|0)+2>>1]|0;Ua=c[m>>2]|0;nb=c[U>>2]|0;if((ob|0)<(Ua|0)){xb=Ua&65535}else{xb=((ob|0)>(nb|0)?nb:ob)&65535}b[e+2>>1]=xb;return}else{ob=-(b[pb>>1]|0)&65535;nb=-(b[qb+(ea*12|0)+2>>1]|0)&65535;if(V){Ua=ob<<16>>16;lb=c[i>>2]|0;Xa=c[W>>2]|0;if((Ua|0)<(lb|0)){yb=lb&65535}else{yb=((Ua|0)>(Xa|0)?Xa:Ua)&65535}Ua=nb<<16>>16;Xa=c[m>>2]|0;lb=c[U>>2]|0;if((Ua|0)<(Xa|0)){zb=Xa&65535}else{zb=((Ua|0)>(lb|0)?lb:Ua)&65535}Ua=(zb&65535)<<16|yb&65535;if(T){c[e>>2]=Ua;return}if((Ha|0)==-2147450880){tb=Ua;break}if((Ua|0)==(Ha|0)){tb=Ha;break}c[e>>2]=Ua;return}Ua=(nb&65535)<<16|ob&65535;if(T){lb=ob<<16>>16;Xa=c[i>>2]|0;mb=c[W>>2]|0;if((lb|0)<(Xa|0)){Ab=Xa&65535}else{Ab=((lb|0)>(mb|0)?mb:lb)&65535}b[e>>1]=Ab;lb=nb<<16>>16;mb=c[m>>2]|0;Xa=c[U>>2]|0;if((lb|0)<(mb|0)){Bb=mb&65535}else{Bb=((lb|0)>(Xa|0)?Xa:lb)&65535}b[e+2>>1]=Bb;return}if((Ha|0)==-2147450880){tb=Ua;break}if((Ua|0)==(Ha|0)){tb=Ha;break}Ua=ob<<16>>16;ob=c[i>>2]|0;lb=c[W>>2]|0;if((Ua|0)<(ob|0)){Cb=ob&65535}else{Cb=((Ua|0)>(lb|0)?lb:Ua)&65535}b[e>>1]=Cb;Ua=nb<<16>>16;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ua|0)<(nb|0)){Db=nb&65535}else{Db=((Ua|0)>(lb|0)?lb:Ua)&65535}b[e+2>>1]=Db;return}}else{tb=Ha}}while(0);Ia=a[qb+(ea*12|0)+9|0]|0;Ja=Ia<<24>>24;if(!((Ja|0)!=(f|0)&Ia<<24>>24>-1)){break}Ia=c[qb+(ea*12|0)+4>>2]|0;Ua=Ia&65535;if((c[pb>>2]|0)==(Ia|0)){break}if((a[d+1160+Ja|0]|0)==(a[_]|0)){if(V){Ja=Ua<<16>>16;lb=c[i>>2]|0;nb=c[W>>2]|0;if((Ja|0)<(lb|0)){Eb=lb&65535}else{Eb=((Ja|0)>(nb|0)?nb:Ja)&65535}Ja=b[qb+(ea*12|0)+6>>1]|0;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(nb|0)){Fb=nb&65535}else{Fb=((Ja|0)>(lb|0)?lb:Ja)&65535}Ja=(Fb&65535)<<16|Eb&65535;if(T){c[e>>2]=Ja;return}if((tb|0)==-2147450880|(Ja|0)==(tb|0)){break}c[e>>2]=Ja;return}if(T){Ja=Ua<<16>>16;lb=c[i>>2]|0;nb=c[W>>2]|0;if((Ja|0)<(lb|0)){Gb=lb&65535}else{Gb=((Ja|0)>(nb|0)?nb:Ja)&65535}b[e>>1]=Gb;Ja=b[qb+(ea*12|0)+6>>1]|0;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(nb|0)){Hb=nb&65535}else{Hb=((Ja|0)>(lb|0)?lb:Ja)&65535}b[e+2>>1]=Hb;return}if((tb|0)==-2147450880|(Ia|0)==(tb|0)){break}Ia=Ua<<16>>16;Ja=c[i>>2]|0;lb=c[W>>2]|0;if((Ia|0)<(Ja|0)){Ib=Ja&65535}else{Ib=((Ia|0)>(lb|0)?lb:Ia)&65535}b[e>>1]=Ib;Ia=b[qb+(ea*12|0)+6>>1]|0;lb=c[m>>2]|0;Ja=c[U>>2]|0;if((Ia|0)<(lb|0)){Jb=lb&65535}else{Jb=((Ia|0)>(Ja|0)?Ja:Ia)&65535}b[e+2>>1]=Jb;return}else{Ia=-Ua&65535;Ua=-(b[qb+(ea*12|0)+6>>1]|0)&65535;if(V){Ja=Ia<<16>>16;lb=c[i>>2]|0;nb=c[W>>2]|0;if((Ja|0)<(lb|0)){Kb=lb&65535}else{Kb=((Ja|0)>(nb|0)?nb:Ja)&65535}Ja=Ua<<16>>16;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(nb|0)){Lb=nb&65535}else{Lb=((Ja|0)>(lb|0)?lb:Ja)&65535}Ja=(Lb&65535)<<16|Kb&65535;if(T){c[e>>2]=Ja;return}if((tb|0)==-2147450880|(Ja|0)==(tb|0)){break}c[e>>2]=Ja;return}if(T){Ja=Ia<<16>>16;lb=c[i>>2]|0;nb=c[W>>2]|0;if((Ja|0)<(lb|0)){Mb=lb&65535}else{Mb=((Ja|0)>(nb|0)?nb:Ja)&65535}b[e>>1]=Mb;Ja=Ua<<16>>16;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(nb|0)){Nb=nb&65535}else{Nb=((Ja|0)>(lb|0)?lb:Ja)&65535}b[e+2>>1]=Nb;return}if((tb|0)==-2147450880|((Ua&65535)<<16|Ia&65535|0)==(tb|0)){break}Ja=Ia<<16>>16;Ia=c[i>>2]|0;lb=c[W>>2]|0;if((Ja|0)<(Ia|0)){Ob=Ia&65535}else{Ob=((Ja|0)>(lb|0)?lb:Ja)&65535}b[e>>1]=Ob;Ja=Ua<<16>>16;Ua=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(Ua|0)){Pb=Ua&65535}else{Pb=((Ja|0)>(lb|0)?lb:Ja)&65535}b[e+2>>1]=Pb;return}}}while(0);c[e>>2]=0;return}}}function Q6a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;e=a|0;f=c[e>>2]|0;g=d[1086680+f|0]|0;h=a+4|0;i=c[h>>2]|0;j=a+16|0;k=c[j>>2]|0;l=f<<g;c[e>>2]=l;f=k<<g;k=i+g|0;do{if((k|0)>-1){g=a+8|0;i=c[g>>2]|0;if(!(i>>>0<(c[a+12>>2]|0)>>>0)){m=f;n=k;break}c[g>>2]=i+2;g=i;m=((de((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535)<<k|f;n=k-16|0}else{m=f;n=k}}while(0);c[h>>2]=n;k=((l<<7)-128>>8)+1|0;f=k<<16;g=m>>>0>=f>>>0;i=g?l-k|0:k;c[e>>2]=i;k=m-(g?f:0)|0;c[j>>2]=k;do{if(g){f=d[1086680+i|0]|0;m=i<<f;c[e>>2]=m;l=k<<f;o=n+f|0;do{if((o|0)>-1){f=a+8|0;p=c[f>>2]|0;if(!(p>>>0<(c[a+12>>2]|0)>>>0)){q=l;r=o;break}c[f>>2]=p+2;f=p;q=((de((d[f]|d[f+1|0]<<8)<<16>>16|0)|0)&65535)<<o|l;r=o-16|0}else{q=l;r=o}}while(0);c[h>>2]=r;o=((m<<7)-128>>8)+1|0;l=o<<16;f=q>>>0>=l>>>0;p=f?m-o|0:o;c[e>>2]=p;o=q-(f?l:0)|0;c[j>>2]=o;if(!f){f=a+8|0;l=a+12|0;s=4;t=0;u=p;v=r;w=o;while(1){x=s-1|0;y=t<<1;z=d[1086680+u|0]|0;A=u<<z;c[e>>2]=A;B=w<<z;C=z+v|0;do{if((C|0)>-1){z=c[f>>2]|0;if(!(z>>>0<(c[l>>2]|0)>>>0)){D=B;E=C;break}c[f>>2]=z+2;F=z;D=((de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<C|B;E=C-16|0}else{D=B;E=C}}while(0);c[h>>2]=E;C=((A<<7)-128>>8)+1|0;B=C<<16;F=D>>>0>=B>>>0;z=F?A-C|0:C;c[e>>2]=z;C=D-(F?B:0)|0;c[j>>2]=C;G=F&1|y;if((x|0)==0){break}else{s=x;t=G;u=z;v=E;w=C}}H=G+16|0;break}w=d[1086680+p|0]|0;v=p<<w;c[e>>2]=v;u=o<<w;t=r+w|0;w=a+8|0;do{if((t|0)>-1){s=c[w>>2]|0;f=a+12|0;if(!(s>>>0<(c[f>>2]|0)>>>0)){I=u;J=t;K=f;break}c[w>>2]=s+2;l=s;I=((de((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&65535)<<t|u;J=t-16|0;K=f}else{I=u;J=t;K=a+12|0}}while(0);c[h>>2]=J;t=((v<<7)-128>>8)+1|0;u=t<<16;o=I>>>0>=u>>>0;p=o?v-t|0:t;c[e>>2]=p;t=I-(o?u:0)|0;c[j>>2]=t;if(o){L=7;M=0;N=p;O=J;P=t}else{o=5;u=0;f=p;p=J;l=t;while(1){t=o-1|0;s=u<<1;m=d[1086680+f|0]|0;C=f<<m;c[e>>2]=C;z=l<<m;F=m+p|0;do{if((F|0)>-1){m=c[w>>2]|0;if(!(m>>>0<(c[K>>2]|0)>>>0)){Q=z;R=F;break}c[w>>2]=m+2;B=m;Q=((de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)<<F|z;R=F-16|0}else{Q=z;R=F}}while(0);c[h>>2]=R;F=((C<<7)-128>>8)+1|0;z=F<<16;x=Q>>>0>=z>>>0;y=x?C-F|0:F;c[e>>2]=y;F=Q-(x?z:0)|0;c[j>>2]=F;S=x&1|s;if((t|0)==0){break}else{o=t;u=S;f=y;p=R;l=F}}H=S+32|0;break}while(1){l=L-1|0;p=M<<1;f=d[1086680+N|0]|0;u=N<<f;c[e>>2]=u;o=P<<f;v=f+O|0;do{if((v|0)>-1){f=c[w>>2]|0;if(!(f>>>0<(c[K>>2]|0)>>>0)){T=o;U=v;break}c[w>>2]=f+2;F=f;T=((de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<v|o;U=v-16|0}else{T=o;U=v}}while(0);c[h>>2]=U;v=((u<<7)-128>>8)+1|0;o=v<<16;t=T>>>0>=o>>>0;V=t?u-v|0:v;c[e>>2]=V;W=T-(t?o:0)|0;c[j>>2]=W;X=t&1|p;if((l|0)==0){break}else{L=l;M=X;N=V;O=U;P=W}}if((X|0)>64){t=(X<<1)-65|0;o=d[1086680+V|0]|0;v=V<<o;c[e>>2]=v;s=W<<o;C=U+o|0;do{if((C|0)>-1){o=c[w>>2]|0;if(!(o>>>0<(c[K>>2]|0)>>>0)){Y=s;Z=C;break}c[w>>2]=o+2;F=o;Y=((de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<C|s;Z=C-16|0}else{Y=s;Z=C}}while(0);c[h>>2]=Z;C=((v<<7)-128>>8)+1|0;s=C<<16;w=Y>>>0>=s>>>0;c[e>>2]=w?v-C|0:C;c[j>>2]=Y-(w?s:0);_=t+(w&1)|0}else{_=X}H=_+64|0}else{w=a+8|0;s=a+12|0;C=4;F=0;o=i;f=n;y=k;while(1){x=C-1|0;z=F<<1;A=d[1086680+o|0]|0;B=o<<A;c[e>>2]=B;m=y<<A;$=A+f|0;do{if(($|0)>-1){A=c[w>>2]|0;if(!(A>>>0<(c[s>>2]|0)>>>0)){aa=m;ba=$;break}c[w>>2]=A+2;ca=A;aa=((de((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0)&65535)<<$|m;ba=$-16|0}else{aa=m;ba=$}}while(0);c[h>>2]=ba;$=((B<<7)-128>>8)+1|0;m=$<<16;l=aa>>>0>=m>>>0;p=l?B-$|0:$;c[e>>2]=p;$=aa-(l?m:0)|0;c[j>>2]=$;m=l&1|z;if((x|0)==0){H=m;break}else{C=x;F=m;o=p;f=ba;y=$}}}}while(0);ba=c[161376+(H<<2)>>2]|0;if((b|0)<129){H=b-1|0;do{if((H<<1|0)<(ba|0)){da=ba}else{if((ba&1|0)==0){da=(ba>>1)+H|0;break}else{da=H-(ba+1>>1)|0;break}}}while(0);ea=da+1|0;return ea|0}else{da=255-b|0;do{if((da<<1|0)<(ba|0)){fa=ba}else{if((ba&1|0)==0){fa=(ba>>1)+da|0;break}else{fa=da-(ba+1>>1)|0;break}}}while(0);ea=255-fa|0;return ea|0}return 0}function R6a(a){a=a|0;c[a>>2]=582;c[a+4>>2]=328;c[a+8>>2]=286;c[a+12>>2]=848;c[a+16>>2]=410;c[a+20>>2]=860;c[a+24>>2]=496;c[a+28>>2]=836;c[a+32>>2]=560;c[a+36>>2]=634;c[a+40>>2]=256;c[a+44>>2]=754;c[a+48>>2]=306;c[a+52>>2]=390;c[a+56>>2]=700;c[a+60>>2]=10;c[a+64>>2]=84;c[a+68>>2]=378;c[a+72>>2]=132;c[a+76>>2]=618;c[a+80>>2]=654;c[a+84>>2]=154;c[a+88>>2]=726;c[a+92>>2]=770;c[a+96>>2]=744;c[a+100>>2]=104;c[a+104>>2]=656;c[a+108>>2]=374;c[a+112>>2]=70;c[a+116>>2]=462;c[a+120>>2]=602;c[a+124>>2]=106;c[a+128>>2]=348;c[a+132>>2]=180;c[a+136>>2]=728;c[a+140>>2]=562;c[a+144>>2]=358;c[a+148>>2]=252;c[a+152>>2]=540;c[a+156>>2]=450;c[a+160>>2]=318;c[a+164>>2]=544;c[a+168>>2]=782;c[a+172>>2]=598;c[a+176>>2]=284;c[a+180>>2]=400;c[a+184>>2]=822;c[a+188>>2]=858;c[a+192>>2]=240;c[a+196>>2]=266;c[a+200>>2]=840;c[a+204>>2]=88;c[a+208>>2]=338;c[a+212>>2]=638;c[a+216>>2]=144;c[a+220>>2]=380;c[a+224>>2]=24;c[a+228>>2]=852;c[a+232>>2]=110;c[a+236>>2]=758;c[a+240>>2]=294;c[a+244>>2]=808;c[a+248>>2]=772;c[a+252>>2]=706;c[a+256>>2]=184;c[a+260>>2]=828;c[a+264>>2]=786;c[a+268>>2]=234;c[a+272>>2]=716;c[a+276>>2]=798;c[a+280>>2]=646;c[a+284>>2]=324;c[a+300>>2]=766;c[a+292>>2]=766;c[a+296>>2]=766;c[a+288>>2]=766;c[a+316>>2]=736;c[a+308>>2]=736;c[a+312>>2]=736;c[a+304>>2]=736;c[a+320>>2]=48;c[a+324>>2]=362;c[a+328>>2]=364;c[a+332>>2]=500;c[a+336>>2]=518;c[a+340>>2]=2;c[a+344>>2]=252;c[a+348>>2]=238;c[a+352>>2]=30;c[a+356>>2]=472;c[a+360>>2]=544;c[a+364>>2]=416;c[a+368>>2]=316;c[a+372>>2]=482;c[a+376>>2]=338;c[a+380>>2]=424;c[a+384>>2]=324;c[a+416>>2]=324;c[a+448>>2]=324;c[a+480>>2]=324;c[a+400>>2]=564;c[a+432>>2]=564;c[a+464>>2]=564;c[a+496>>2]=564;c[a+512>>2]=40;c[a+544>>2]=40;c[a+576>>2]=40;c[a+608>>2]=40;c[a+528>>2]=398;c[a+560>>2]=398;c[a+592>>2]=398;c[a+624>>2]=398;c[a+640>>2]=72;c[a+672>>2]=72;c[a+704>>2]=72;c[a+736>>2]=72;c[a+656>>2]=110;c[a+688>>2]=110;c[a+720>>2]=110;c[a+752>>2]=110;c[a+768>>2]=58;c[a+800>>2]=58;c[a+832>>2]=58;c[a+864>>2]=58;c[a+784>>2]=332;c[a+816>>2]=332;c[a+848>>2]=332;c[a+880>>2]=332;c[a+896>>2]=388;c[a+928>>2]=388;c[a+960>>2]=388;c[a+992>>2]=388;c[a+912>>2]=18;c[a+944>>2]=18;c[a+976>>2]=18;c[a+1008>>2]=18;c[a+396>>2]=420;c[a+428>>2]=234;c[a+460>>2]=520;c[a+492>>2]=144;c[a+524>>2]=624;c[a+556>>2]=370;c[a+588>>2]=166;c[a+620>>2]=108;c[a+652>>2]=424;c[a+684>>2]=186;c[a+716>>2]=120;c[a+748>>2]=354;c[a+780>>2]=200;c[a+812>>2]=586;c[a+844>>2]=66;c[a+876>>2]=330;c[a+908>>2]=36;c[a+940>>2]=546;c[a+972>>2]=542;c[a+1004>>2]=404;c[a+388>>2]=462;c[a+420>>2]=608;c[a+452>>2]=14;c[a+484>>2]=62;c[a+516>>2]=260;c[a+548>>2]=46;c[a+580>>2]=176;c[a+612>>2]=266;c[a+644>>2]=430;c[a+676>>2]=626;c[a+708>>2]=576;c[a+740>>2]=614;c[a+772>>2]=450;c[a+804>>2]=38;c[a+836>>2]=508;c[a+868>>2]=118;c[a+900>>2]=98;c[a+932>>2]=122;c[a+964>>2]=116;c[a+996>>2]=302;c[a+392>>2]=606;c[a+424>>2]=154;c[a+456>>2]=178;c[a+488>>2]=532;c[a+520>>2]=106;c[a+552>>2]=526;c[a+584>>2]=4;c[a+616>>2]=438;c[a+648>>2]=242;c[a+680>>2]=168;c[a+712>>2]=100;c[a+744>>2]=152;c[a+776>>2]=578;c[a+808>>2]=534;c[a+840>>2]=16;c[a+872>>2]=282;c[a+904>>2]=496;c[a+936>>2]=590;c[a+968>>2]=568;c[a+1e3>>2]=214;c[a+412>>2]=222;c[a+444>>2]=224;c[a+476>>2]=618;c[a+508>>2]=372;c[a+540>>2]=418;c[a+572>>2]=566;c[a+604>>2]=10;c[a+636>>2]=416;c[a+668>>2]=346;c[a+700>>2]=544;c[a+732>>2]=68;c[a+764>>2]=336;c[a+796>>2]=202;c[a+828>>2]=378;c[a+860>>2]=286;c[a+892>>2]=454;c[a+924>>2]=288;c[a+956>>2]=436;c[a+988>>2]=426;c[a+1020>>2]=20;c[a+404>>2]=474;c[a+436>>2]=162;c[a+468>>2]=2;c[a+500>>2]=428;c[a+532>>2]=530;c[a+564>>2]=160;c[a+596>>2]=194;c[a+628>>2]=498;c[a+660>>2]=384;c[a+692>>2]=548;c[a+724>>2]=26;c[a+756>>2]=6;c[a+788>>2]=488;c[a+820>>2]=320;c[a+852>>2]=212;c[a+884>>2]=274;c[a+916>>2]=74;c[a+948>>2]=340;c[a+980>>2]=380;c[a+1012>>2]=138;c[a+408>>2]=230;c[a+440>>2]=610;c[a+472>>2]=356;c[a+504>>2]=318;c[a+536>>2]=44;c[a+568>>2]=294;c[a+600>>2]=34;c[a+632>>2]=22;c[a+664>>2]=518;c[a+696>>2]=386;c[a+728>>2]=360;c[a+760>>2]=492;c[a+792>>2]=328;c[a+824>>2]=486;c[a+856>>2]=382;c[a+888>>2]=128;c[a+920>>2]=554;c[a+952>>2]=494;c[a+984>>2]=510;c[a+1016>>2]=598;return}function S6a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;g=e;e=a;a=c;while(1){UGb(e|0,a|0,64)|0;c=g-1|0;if((c|0)==0){break}else{g=c;e=e+b|0;a=a+d|0}}return}function T6a(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=g;g=a;a=e;while(1){e=0;do{h=g+e|0;j=c[h>>2]|0;k=a+e|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[h>>2]=(l|j)-((l^j)>>>1&2139062143);e=e+4|0;}while((e|0)<64);e=i-1|0;if((e|0)==0){break}else{i=e;g=g+b|0;a=a+f|0}}return}function U6a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;g=e;e=a;a=c;while(1){UGb(e|0,a|0,32)|0;c=g-1|0;if((c|0)==0){break}else{g=c;e=e+b|0;a=a+d|0}}return}function V6a(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=a;a=e;while(1){e=g;h=c[e>>2]|0;j=a;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=g+4|0;k=c[h>>2]|0;e=a+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);k=g+8|0;j=c[k>>2]|0;h=a+8|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=(e|j)-((e^j)>>>1&2139062143);j=g+12|0;e=c[j>>2]|0;k=a+12|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[j>>2]=(h|e)-((h^e)>>>1&2139062143);e=g+16|0;h=c[e>>2]|0;j=a+16|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=g+20|0;k=c[h>>2]|0;e=a+20|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);k=g+24|0;j=c[k>>2]|0;h=a+24|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=(e|j)-((e^j)>>>1&2139062143);j=g+28|0;e=c[j>>2]|0;k=a+28|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[j>>2]=(h|e)-((h^e)>>>1&2139062143);e=i-1|0;if((e|0)==0){break}else{i=e;g=g+b|0;a=a+f|0}}return}function W6a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;g=e;e=a;a=c;while(1){UGb(e|0,a|0,16)|0;c=g-1|0;if((c|0)==0){break}else{g=c;e=e+b|0;a=a+d|0}}return}function X6a(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=a;a=e;while(1){e=g;h=c[e>>2]|0;j=a;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=g+4|0;k=c[h>>2]|0;e=a+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);k=g+8|0;j=c[k>>2]|0;h=a+8|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=(e|j)-((e^j)>>>1&2139062143);j=g+12|0;e=c[j>>2]|0;k=a+12|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[j>>2]=(h|e)-((h^e)>>>1&2139062143);e=i-1|0;if((e|0)==0){break}else{i=e;g=g+b|0;a=a+f|0}}return}function Y6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=b;b=e;while(1){e=b;h=g;j=e|0;k=e+4|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h|0;x=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+4|0;x=e;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=i-1|0;if((k|0)==0){break}else{i=k;g=g+c|0;b=b+f|0}}return}function Z6a(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=a;a=e;while(1){e=g;h=c[e>>2]|0;j=a;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=g+4|0;k=c[h>>2]|0;e=a+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);k=i-1|0;if((k|0)==0){break}else{i=k;g=g+b|0;a=a+f|0}}return}function _6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;i=g;g=b;b=e;while(1){e=b;h=g;x=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=i-1|0;if((h|0)==0){break}else{i=h;g=g+c|0;b=b+f|0}}return}function $6a(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=a;a=e;while(1){e=g;h=c[e>>2]|0;j=a;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=i-1|0;if((h|0)==0){break}else{i=h;g=g+b|0;a=a+f|0}}return}function a7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,64,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function b7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,64,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function c7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,64,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function d7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;w9a(a,b,c,d,64,e,f,g);return}function e7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,32,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function f7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,32,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function g7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,32,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function h7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;w9a(a,b,c,d,32,e,f,g);return}function i7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,16,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function j7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,16,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function k7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,16,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function l7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;w9a(a,b,c,d,16,e,f,g);return}function m7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,8,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function n7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,8,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function o7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,8,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function p7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;w9a(a,b,c,d,8,e,f,g);return}function q7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,4,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function r7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,4,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function s7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;x9a(a,b,c,d,4,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function t7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;w9a(a,b,c,d,4,e,f,g);return}function u7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,64,e,103912+(g-1<<3)|0);return}function v7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,64,e,104032+(g-1<<3)|0);return}function w7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,64,e,104152+(g-1<<3)|0);return}function x7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;u9a(a,b,c,d,64,e,g);return}function y7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,32,e,103912+(g-1<<3)|0);return}function z7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,32,e,104032+(g-1<<3)|0);return}function A7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,32,e,104152+(g-1<<3)|0);return}function B7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;u9a(a,b,c,d,32,e,g);return}function C7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,16,e,103912+(g-1<<3)|0);return}function D7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,16,e,104032+(g-1<<3)|0);return}function E7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,16,e,104152+(g-1<<3)|0);return}function F7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;u9a(a,b,c,d,16,e,g);return}function G7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,8,e,103912+(g-1<<3)|0);return}function H7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,8,e,104032+(g-1<<3)|0);return}function I7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,8,e,104152+(g-1<<3)|0);return}function J7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;u9a(a,b,c,d,8,e,g);return}function K7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,4,e,103912+(g-1<<3)|0);return}function L7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,4,e,104032+(g-1<<3)|0);return}function M7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;v9a(a,b,c,d,4,e,104152+(g-1<<3)|0);return}function N7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;u9a(a,b,c,d,4,e,g);return}function O7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,64,e,103912+(f-1<<3)|0);return}function P7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,64,e,104032+(f-1<<3)|0);return}function Q7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,64,e,104152+(f-1<<3)|0);return}function R7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;s9a(a,b,c,d,64,e,f);return}function S7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,32,e,103912+(f-1<<3)|0);return}function T7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,32,e,104032+(f-1<<3)|0);return}function U7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,32,e,104152+(f-1<<3)|0);return}function V7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;s9a(a,b,c,d,32,e,f);return}function W7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,16,e,103912+(f-1<<3)|0);return}function X7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,16,e,104032+(f-1<<3)|0);return}function Y7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,16,e,104152+(f-1<<3)|0);return}function Z7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;s9a(a,b,c,d,16,e,f);return}function _7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,8,e,103912+(f-1<<3)|0);return}function $7a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,8,e,104032+(f-1<<3)|0);return}function a8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,8,e,104152+(f-1<<3)|0);return}function b8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;s9a(a,b,c,d,8,e,f);return}function c8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,4,e,103912+(f-1<<3)|0);return}function d8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,4,e,104032+(f-1<<3)|0);return}function e8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;t9a(a,b,c,d,4,e,104152+(f-1<<3)|0);return}function f8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;s9a(a,b,c,d,4,e,f);return}function g8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,64,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function h8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,64,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function i8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,64,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function j8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;q9a(a,b,c,d,64,e,f,g);return}function k8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,32,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function l8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,32,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function m8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,32,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function n8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;q9a(a,b,c,d,32,e,f,g);return}function o8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,16,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function p8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,16,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function q8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,16,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function r8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;q9a(a,b,c,d,16,e,f,g);return}function s8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,8,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function t8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,8,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function u8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,8,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function v8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;q9a(a,b,c,d,8,e,f,g);return}function w8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,4,e,103912+(f-1<<3)|0,103912+(g-1<<3)|0);return}function x8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,4,e,104032+(f-1<<3)|0,104032+(g-1<<3)|0);return}function y8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;r9a(a,b,c,d,4,e,104152+(f-1<<3)|0,104152+(g-1<<3)|0);return}function z8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;q9a(a,b,c,d,4,e,f,g);return}function A8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,64,e,103912+(g-1<<3)|0);return}function B8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,64,e,104032+(g-1<<3)|0);return}function C8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,64,e,104152+(g-1<<3)|0);return}function D8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;o9a(a,b,c,d,64,e,g);return}function E8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,32,e,103912+(g-1<<3)|0);return}function F8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,32,e,104032+(g-1<<3)|0);return}function G8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,32,e,104152+(g-1<<3)|0);return}function H8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;o9a(a,b,c,d,32,e,g);return}function I8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,16,e,103912+(g-1<<3)|0);return}function J8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,16,e,104032+(g-1<<3)|0);return}function K8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,16,e,104152+(g-1<<3)|0);return}function L8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;o9a(a,b,c,d,16,e,g);return}function M8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,8,e,103912+(g-1<<3)|0);return}function N8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,8,e,104032+(g-1<<3)|0);return}function O8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,8,e,104152+(g-1<<3)|0);return}function P8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;o9a(a,b,c,d,8,e,g);return}function Q8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,4,e,103912+(g-1<<3)|0);return}function R8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,4,e,104032+(g-1<<3)|0);return}function S8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;p9a(a,b,c,d,4,e,104152+(g-1<<3)|0);return}function T8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;o9a(a,b,c,d,4,e,g);return}function U8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,64,e,103912+(f-1<<3)|0);return}function V8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,64,e,104032+(f-1<<3)|0);return}function W8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,64,e,104152+(f-1<<3)|0);return}function X8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;m9a(a,b,c,d,64,e,f);return}function Y8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,32,e,103912+(f-1<<3)|0);return}function Z8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,32,e,104032+(f-1<<3)|0);return}function _8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,32,e,104152+(f-1<<3)|0);return}function $8a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;m9a(a,b,c,d,32,e,f);return}function a9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,16,e,103912+(f-1<<3)|0);return}function b9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,16,e,104032+(f-1<<3)|0);return}function c9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,16,e,104152+(f-1<<3)|0);return}function d9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;m9a(a,b,c,d,16,e,f);return}function e9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,8,e,103912+(f-1<<3)|0);return}function f9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,8,e,104032+(f-1<<3)|0);return}function g9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,8,e,104152+(f-1<<3)|0);return}function h9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;m9a(a,b,c,d,8,e,f);return}function i9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,4,e,103912+(f-1<<3)|0);return}function j9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,4,e,104032+(f-1<<3)|0);return}function k9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;n9a(a,b,c,d,4,e,104152+(f-1<<3)|0);return}function l9a(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;m9a(a,b,c,d,4,e,f);return}function m9a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;j=(g|0)>0;k=b;b=e;e=h;while(1){if(j){h=0;do{l=k+h|0;m=d[b+h|0]|0;h=h+1|0;a[l]=((d[l]|0)+1+m+(((ba((d[b+h|0]|0)-m|0,i)|0)+8|0)>>>4)|0)>>>1;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{k=k+c|0;b=b+f|0;e=h}}return}function n9a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=(g|0)>0;k=i+1|0;l=i+2|0;m=i+3|0;n=i+4|0;o=i+5|0;p=i+6|0;q=i+7|0;r=b;b=e;e=h;while(1){if(j){h=0;while(1){s=r+h|0;t=ba(d[b+(h-3)|0]|0,a[i]|0)|0;u=ba(d[b+(h-2)|0]|0,a[k]|0)|0;v=ba(d[b+(h-1)|0]|0,a[l]|0)|0;w=ba(d[b+h|0]|0,a[m]|0)|0;x=h+1|0;y=ba(d[b+x|0]|0,a[n]|0)|0;z=ba(d[b+(h+2)|0]|0,a[o]|0)|0;A=ba(d[b+(h+3)|0]|0,a[p]|0)|0;B=t+64+u+v+w+y+z+A+(ba(d[b+(h+4)|0]|0,a[q]|0)|0)>>7;if(B>>>0>255>>>0){C=-B>>31&255}else{C=B&255}a[s]=((d[s]|0)+1+(C&255)|0)>>>1;if((x|0)<(g|0)){h=x}else{break}}}h=e-1|0;if((h|0)==0){break}else{r=r+c|0;b=b+f|0;e=h}}return}function o9a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;j=(g|0)>0;k=b;b=e;e=h;while(1){if(j){h=0;do{l=k+h|0;m=d[b+h|0]|0;a[l]=((d[l]|0)+1+m+(((ba((d[b+(h+f)|0]|0)-m|0,i)|0)+8|0)>>>4)|0)>>>1;h=h+1|0;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{k=k+c|0;b=b+f|0;e=h}}return}function p9a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;j=(g|0)>0;k=f*-3|0;l=i+1|0;m=f*-2|0;n=i+2|0;o=i+3|0;p=i+4|0;q=i+5|0;r=f<<1;s=i+6|0;t=f*3|0;u=i+7|0;v=f<<2;w=b;b=e;e=h;while(1){if(j){h=0;do{x=w+h|0;y=ba(d[b+(h+k)|0]|0,a[i]|0)|0;z=ba(d[b+(h+m)|0]|0,a[l]|0)|0;A=ba(d[b+(h-f)|0]|0,a[n]|0)|0;B=ba(d[b+h|0]|0,a[o]|0)|0;C=ba(d[b+(h+f)|0]|0,a[p]|0)|0;D=ba(d[b+(h+r)|0]|0,a[q]|0)|0;E=ba(d[b+(h+t)|0]|0,a[s]|0)|0;F=y+64+z+A+B+C+D+E+(ba(d[b+(h+v)|0]|0,a[u]|0)|0)>>7;if(F>>>0>255>>>0){G=-F>>31&255}else{G=F&255}a[x]=((d[x]|0)+1+(G&255)|0)>>>1;h=h+1|0;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{w=w+c|0;b=b+f|0;e=h}}return}function q9a(b,c,e,f,g,h,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=i;i=i+4160|0;m=l|0;n=(g|0)>0;o=h+1|0;p=m;q=e;while(1){if(n){e=0;r=a[q]|0;while(1){s=r&255;t=e+1|0;u=a[q+t|0]|0;a[p+e|0]=(((ba((u&255)-s|0,j)|0)+8|0)>>>4)+s;if((t|0)<(g|0)){e=t;r=u}else{break}}}r=o-1|0;if((r|0)==0){v=m;w=b;x=h;break}else{o=r;p=p+64|0;q=q+f|0}}while(1){if(n){f=0;do{q=w+f|0;p=d[v+f|0]|0;a[q]=((d[q]|0)+1+p+(((ba((d[v+(f+64)|0]|0)-p|0,k)|0)+8|0)>>>4)|0)>>>1;f=f+1|0;}while((f|0)<(g|0))}f=x-1|0;if((f|0)==0){break}else{v=v+64|0;w=w+c|0;x=f}}i=l;return}function r9a(b,c,e,f,g,h,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;l=i;i=i+4544|0;m=l|0;n=(g|0)>0;o=j+1|0;p=j+2|0;q=j+3|0;r=j+4|0;s=j+5|0;t=j+6|0;u=j+7|0;if(n){v=m|0;w=h+7|0;x=e+(f*-3|0)|0;while(1){e=0;y=a[x-3|0]|0;z=a[x-2|0]|0;A=a[x-1|0]|0;B=a[x]|0;C=a[x+1|0]|0;D=a[x+2|0]|0;E=a[x+3|0]|0;while(1){F=ba(a[j]|0,y&255)|0;G=ba(a[o]|0,z&255)|0;H=ba(a[p]|0,A&255)|0;I=ba(a[q]|0,B&255)|0;J=e+1|0;K=ba(a[r]|0,C&255)|0;L=ba(a[s]|0,D&255)|0;M=ba(a[t]|0,E&255)|0;N=a[x+(e+4)|0]|0;O=F+64+G+H+I+K+L+M+(ba(N&255,a[u]|0)|0)>>7;if(O>>>0>255>>>0){P=-O>>31&255}else{P=O&255}a[v+e|0]=P;if((J|0)<(g|0)){e=J;y=z;z=A;A=B;B=C;C=D;D=E;E=N}else{break}}E=w-1|0;if((E|0)==0){break}else{v=v+64|0;w=E;x=x+f|0}}}f=k+1|0;x=k+2|0;w=k+3|0;v=k+4|0;P=k+5|0;u=k+6|0;t=k+7|0;s=m+192|0;m=b;b=h;while(1){if(n){h=0;do{r=m+h|0;q=ba(d[s+(h-192)|0]|0,a[k]|0)|0;p=ba(d[s+(h-128)|0]|0,a[f]|0)|0;o=ba(d[s+(h-64)|0]|0,a[x]|0)|0;j=ba(d[s+h|0]|0,a[w]|0)|0;E=ba(d[s+(h+64)|0]|0,a[v]|0)|0;D=ba(d[s+(h+128)|0]|0,a[P]|0)|0;C=ba(d[s+(h+192)|0]|0,a[u]|0)|0;B=q+64+p+o+j+E+D+C+(ba(d[s+(h+256)|0]|0,a[t]|0)|0)>>7;if(B>>>0>255>>>0){Q=-B>>31&255}else{Q=B&255}a[r]=((d[r]|0)+1+(Q&255)|0)>>>1;h=h+1|0;}while((h|0)<(g|0))}h=b-1|0;if((h|0)==0){break}else{s=s+64|0;m=m+c|0;b=h}}i=l;return}function s9a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;j=(g|0)>0;k=b;b=e;e=h;while(1){if(j){h=0;while(1){l=d[b+h|0]|0;m=h+1|0;a[k+h|0]=(((ba((d[b+m|0]|0)-l|0,i)|0)+8|0)>>>4)+l;if((m|0)<(g|0)){h=m}else{break}}}h=e-1|0;if((h|0)==0){break}else{k=k+c|0;b=b+f|0;e=h}}return}function t9a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=(g|0)>0;k=i+1|0;l=i+2|0;m=i+3|0;n=i+4|0;o=i+5|0;p=i+6|0;q=i+7|0;r=b;b=e;e=h;while(1){if(j){h=0;while(1){s=ba(d[b+(h-3)|0]|0,a[i]|0)|0;t=ba(d[b+(h-2)|0]|0,a[k]|0)|0;u=ba(d[b+(h-1)|0]|0,a[l]|0)|0;v=ba(d[b+h|0]|0,a[m]|0)|0;w=h+1|0;x=ba(d[b+w|0]|0,a[n]|0)|0;y=ba(d[b+(h+2)|0]|0,a[o]|0)|0;z=ba(d[b+(h+3)|0]|0,a[p]|0)|0;A=s+64+t+u+v+x+y+z+(ba(d[b+(h+4)|0]|0,a[q]|0)|0)>>7;if(A>>>0>255>>>0){B=-A>>31&255}else{B=A&255}a[r+h|0]=B;if((w|0)<(g|0)){h=w}else{break}}}h=e-1|0;if((h|0)==0){break}else{r=r+c|0;b=b+f|0;e=h}}return}function u9a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=(g|0)>0;k=b;b=e;e=h;while(1){if(j){h=0;do{l=d[b+h|0]|0;a[k+h|0]=(((ba((d[b+(h+f)|0]|0)-l|0,i)|0)+8|0)>>>4)+l;h=h+1|0;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{k=k+c|0;b=b+f|0;e=h}}return}function v9a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;j=(g|0)>0;k=f*-3|0;l=i+1|0;m=f*-2|0;n=i+2|0;o=i+3|0;p=i+4|0;q=i+5|0;r=f<<1;s=i+6|0;t=f*3|0;u=i+7|0;v=f<<2;w=b;b=e;e=h;while(1){if(j){h=0;do{x=ba(d[b+(h+k)|0]|0,a[i]|0)|0;y=ba(d[b+(h+m)|0]|0,a[l]|0)|0;z=ba(d[b+(h-f)|0]|0,a[n]|0)|0;A=ba(d[b+h|0]|0,a[o]|0)|0;B=ba(d[b+(h+f)|0]|0,a[p]|0)|0;C=ba(d[b+(h+r)|0]|0,a[q]|0)|0;D=ba(d[b+(h+t)|0]|0,a[s]|0)|0;E=x+64+y+z+A+B+C+D+(ba(d[b+(h+v)|0]|0,a[u]|0)|0)>>7;if(E>>>0>255>>>0){F=-E>>31&255}else{F=E&255}a[w+h|0]=F;h=h+1|0;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{w=w+c|0;b=b+f|0;e=h}}return}function w9a(b,c,e,f,g,h,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=i;i=i+4160|0;m=l|0;n=(g|0)>0;o=h+1|0;p=m;q=e;while(1){if(n){e=0;r=a[q]|0;while(1){s=r&255;t=e+1|0;u=a[q+t|0]|0;a[p+e|0]=(((ba((u&255)-s|0,j)|0)+8|0)>>>4)+s;if((t|0)<(g|0)){e=t;r=u}else{break}}}r=o-1|0;if((r|0)==0){v=m;w=b;x=h;break}else{o=r;p=p+64|0;q=q+f|0}}while(1){if(n){f=0;do{q=d[v+f|0]|0;a[w+f|0]=(((ba((d[v+(f+64)|0]|0)-q|0,k)|0)+8|0)>>>4)+q;f=f+1|0;}while((f|0)<(g|0))}f=x-1|0;if((f|0)==0){break}else{v=v+64|0;w=w+c|0;x=f}}i=l;return}function x9a(b,c,e,f,g,h,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;l=i;i=i+4544|0;m=l|0;n=(g|0)>0;o=j+1|0;p=j+2|0;q=j+3|0;r=j+4|0;s=j+5|0;t=j+6|0;u=j+7|0;if(n){v=m|0;w=h+7|0;x=e+(f*-3|0)|0;while(1){e=0;y=a[x-3|0]|0;z=a[x-2|0]|0;A=a[x-1|0]|0;B=a[x]|0;C=a[x+1|0]|0;D=a[x+2|0]|0;E=a[x+3|0]|0;while(1){F=ba(a[j]|0,y&255)|0;G=ba(a[o]|0,z&255)|0;H=ba(a[p]|0,A&255)|0;I=ba(a[q]|0,B&255)|0;J=e+1|0;K=ba(a[r]|0,C&255)|0;L=ba(a[s]|0,D&255)|0;M=ba(a[t]|0,E&255)|0;N=a[x+(e+4)|0]|0;O=F+64+G+H+I+K+L+M+(ba(N&255,a[u]|0)|0)>>7;if(O>>>0>255>>>0){P=-O>>31&255}else{P=O&255}a[v+e|0]=P;if((J|0)<(g|0)){e=J;y=z;z=A;A=B;B=C;C=D;D=E;E=N}else{break}}E=w-1|0;if((E|0)==0){break}else{v=v+64|0;w=E;x=x+f|0}}}f=k+1|0;x=k+2|0;w=k+3|0;v=k+4|0;P=k+5|0;u=k+6|0;t=k+7|0;s=m+192|0;m=b;b=h;while(1){if(n){h=0;do{r=ba(d[s+(h-192)|0]|0,a[k]|0)|0;q=ba(d[s+(h-128)|0]|0,a[f]|0)|0;p=ba(d[s+(h-64)|0]|0,a[x]|0)|0;o=ba(d[s+h|0]|0,a[w]|0)|0;j=ba(d[s+(h+64)|0]|0,a[v]|0)|0;E=ba(d[s+(h+128)|0]|0,a[P]|0)|0;D=ba(d[s+(h+192)|0]|0,a[u]|0)|0;C=r+64+q+p+o+j+E+D+(ba(d[s+(h+256)|0]|0,a[t]|0)|0)>>7;if(C>>>0>255>>>0){Q=-C>>31&255}else{Q=C&255}a[m+h|0]=Q;h=h+1|0;}while((h|0)<(g|0))}h=b-1|0;if((h|0)==0){break}else{s=s+64|0;m=m+c|0;b=h}}i=l;return}function y9a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=0;i=b;while(1){b=d[i-3|0]|0;j=i-2|0;k=d[j]|0;l=i-1|0;m=d[l]|0;n=d[i]|0;o=i+1|0;p=d[o]|0;q=d[i+2|0]|0;r=d[i+3|0]|0;s=(d[i-4|0]|0)-b|0;a:do{if((((s|0)>-1?s:-s|0)|0)<=(f|0)){t=b-k|0;if((((t|0)>-1?t:-t|0)|0)>(f|0)){break}t=k-m|0;u=(t|0)>-1?t:-t|0;if((u|0)>(f|0)){break}t=p-n|0;v=(t|0)>-1?t:-t|0;if((v|0)>(f|0)){break}t=q-p|0;if((((t|0)>-1?t:-t|0)|0)>(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>(f|0)){break}t=m-n|0;w=k-p|0;if(((((w|0)>-1?w:-w|0)>>1)+(((t|0)>-1?t:-t|0)<<1)|0)>(e|0)){break}do{if((u|0)>(g|0)){x=(n-m|0)*3|0}else{t=(n-m|0)*3|0;if((v|0)>(g|0)){x=t;break}if((t+128|0)>>>0>255>>>0){y=(t>>31^127)&255}else{y=t&255}t=y<<24>>24;z=t+4|0;A=(z|0)>127?15:z>>3;z=t+3|0;t=((z|0)>127?15:z>>3)+m|0;if(t>>>0>255>>>0){B=-t>>31&255}else{B=t&255}a[l]=B;t=n-A|0;if(t>>>0>255>>>0){C=-t>>31&255}else{C=t&255}a[i]=C;t=A+1>>1;A=t+k|0;if(A>>>0>255>>>0){D=-A>>31&255}else{D=A&255}a[j]=D;A=p-t|0;if(A>>>0>255>>>0){E=-A>>31&255}else{E=A&255}a[o]=E;break a}}while(0);if((w+128|0)>>>0>255>>>0){F=(w>>31^127)&255}else{F=w&255}v=(F<<24>>24)+x|0;if((v+128|0)>>>0>255>>>0){G=(v>>31^127)&255}else{G=v&255}v=G<<24>>24;u=v+4|0;A=v+3|0;v=((A|0)>127?15:A>>3)+m|0;if(v>>>0>255>>>0){H=-v>>31&255}else{H=v&255}a[l]=H;v=n-((u|0)>127?15:u>>3)|0;if(v>>>0>255>>>0){I=-v>>31&255}else{I=v&255}a[i]=I}}while(0);n=h+1|0;if((n|0)<8){h=n;i=i+c|0}else{break}}return}function z9a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=c*-4|0;i=c*-3|0;j=c*-2|0;k=-c|0;l=c<<1;m=c*3|0;n=0;o=b;while(1){b=d[o+i|0]|0;p=o+j|0;q=d[p]|0;r=o+k|0;s=d[r]|0;t=d[o]|0;u=o+c|0;v=d[u]|0;w=d[o+l|0]|0;x=d[o+m|0]|0;y=(d[o+h|0]|0)-b|0;a:do{if((((y|0)>-1?y:-y|0)|0)<=(f|0)){z=b-q|0;if((((z|0)>-1?z:-z|0)|0)>(f|0)){break}z=q-s|0;A=(z|0)>-1?z:-z|0;if((A|0)>(f|0)){break}z=v-t|0;B=(z|0)>-1?z:-z|0;if((B|0)>(f|0)){break}z=w-v|0;if((((z|0)>-1?z:-z|0)|0)>(f|0)){break}z=x-w|0;if((((z|0)>-1?z:-z|0)|0)>(f|0)){break}z=s-t|0;C=q-v|0;if(((((C|0)>-1?C:-C|0)>>1)+(((z|0)>-1?z:-z|0)<<1)|0)>(e|0)){break}do{if((A|0)>(g|0)){D=(t-s|0)*3|0}else{z=(t-s|0)*3|0;if((B|0)>(g|0)){D=z;break}if((z+128|0)>>>0>255>>>0){E=(z>>31^127)&255}else{E=z&255}z=E<<24>>24;F=z+4|0;G=(F|0)>127?15:F>>3;F=z+3|0;z=((F|0)>127?15:F>>3)+s|0;if(z>>>0>255>>>0){H=-z>>31&255}else{H=z&255}a[r]=H;z=t-G|0;if(z>>>0>255>>>0){I=-z>>31&255}else{I=z&255}a[o]=I;z=G+1>>1;G=z+q|0;if(G>>>0>255>>>0){J=-G>>31&255}else{J=G&255}a[p]=J;G=v-z|0;if(G>>>0>255>>>0){K=-G>>31&255}else{K=G&255}a[u]=K;break a}}while(0);if((C+128|0)>>>0>255>>>0){L=(C>>31^127)&255}else{L=C&255}B=(L<<24>>24)+D|0;if((B+128|0)>>>0>255>>>0){M=(B>>31^127)&255}else{M=B&255}B=M<<24>>24;A=B+4|0;G=B+3|0;B=((G|0)>127?15:G>>3)+s|0;if(B>>>0>255>>>0){N=-B>>31&255}else{N=B&255}a[r]=N;B=t-((A|0)>127?15:A>>3)|0;if(B>>>0>255>>>0){O=-B>>31&255}else{O=B&255}a[o]=O}}while(0);t=n+1|0;if((t|0)<8){n=t;o=o+1|0}else{break}}return}function A9a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=0;i=b;while(1){b=d[i-4|0]|0;j=i-3|0;k=d[j]|0;l=i-2|0;m=d[l]|0;n=i-1|0;o=d[n]|0;p=d[i]|0;q=i+1|0;r=d[q]|0;s=i+2|0;t=d[s]|0;u=d[i+3|0]|0;v=b-k|0;a:do{if((((v|0)>-1?v:-v|0)|0)<=(f|0)){w=k-m|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=m-o|0;x=(w|0)>-1?w:-w|0;if((x|0)>(f|0)){break}w=r-p|0;y=(w|0)>-1?w:-w|0;if((y|0)>(f|0)){break}w=t-r|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=u-t|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=o-p|0;z=m-r|0;if(((((z|0)>-1?z:-z|0)>>1)+(((w|0)>-1?w:-w|0)<<1)|0)>(e|0)){break}w=b-o|0;do{if((((w|0)>-1?w:-w|0)|0)<2){A=k-o|0;if(!((((A|0)>-1?A:-A|0)|0)<2&(x|0)<2&(y|0)<2)){break}A=t-p|0;if((((A|0)>-1?A:-A|0)|0)>=2){break}A=u-p|0;if((((A|0)>-1?A:-A|0)|0)>=2){break}A=b<<1;B=b+4|0;a[j]=(B+A+(k<<1)+m+o+p|0)>>>3;C=k+4|0;a[l]=(C+A+(m<<1)+o+p+r|0)>>>3;a[n]=(B+k+m+(o<<1)+p+r+t|0)>>>3;a[i]=(C+m+o+(p<<1)+r+t+u|0)>>>3;a[q]=(m+4+o+p+t+(u+r<<1)|0)>>>3;a[s]=(o+4+p+r+(t<<1)+(u*3|0)|0)>>>3;break a}}while(0);do{if((x|0)>(g|0)){D=(p-o|0)*3|0}else{w=(p-o|0)*3|0;if((y|0)>(g|0)){D=w;break}if((w+128|0)>>>0>255>>>0){E=(w>>31^127)&255}else{E=w&255}w=E<<24>>24;C=w+4|0;B=(C|0)>127?15:C>>3;C=w+3|0;w=((C|0)>127?15:C>>3)+o|0;if(w>>>0>255>>>0){F=-w>>31&255}else{F=w&255}a[n]=F;w=p-B|0;if(w>>>0>255>>>0){G=-w>>31&255}else{G=w&255}a[i]=G;w=B+1>>1;B=w+m|0;if(B>>>0>255>>>0){H=-B>>31&255}else{H=B&255}a[l]=H;B=r-w|0;if(B>>>0>255>>>0){I=-B>>31&255}else{I=B&255}a[q]=I;break a}}while(0);if((z+128|0)>>>0>255>>>0){J=(z>>31^127)&255}else{J=z&255}y=(J<<24>>24)+D|0;if((y+128|0)>>>0>255>>>0){K=(y>>31^127)&255}else{K=y&255}y=K<<24>>24;x=y+4|0;B=y+3|0;y=((B|0)>127?15:B>>3)+o|0;if(y>>>0>255>>>0){L=-y>>31&255}else{L=y&255}a[n]=L;y=p-((x|0)>127?15:x>>3)|0;if(y>>>0>255>>>0){M=-y>>31&255}else{M=y&255}a[i]=M}}while(0);p=h+1|0;if((p|0)<8){h=p;i=i+c|0}else{break}}return}function B9a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=c*-4|0;i=c*-3|0;j=c*-2|0;k=-c|0;l=c<<1;m=c*3|0;n=0;o=b;while(1){b=d[o+h|0]|0;p=o+i|0;q=d[p]|0;r=o+j|0;s=d[r]|0;t=o+k|0;u=d[t]|0;v=d[o]|0;w=o+c|0;x=d[w]|0;y=o+l|0;z=d[y]|0;A=d[o+m|0]|0;B=b-q|0;a:do{if((((B|0)>-1?B:-B|0)|0)<=(f|0)){C=q-s|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=s-u|0;D=(C|0)>-1?C:-C|0;if((D|0)>(f|0)){break}C=x-v|0;E=(C|0)>-1?C:-C|0;if((E|0)>(f|0)){break}C=z-x|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=A-z|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=u-v|0;F=s-x|0;if(((((F|0)>-1?F:-F|0)>>1)+(((C|0)>-1?C:-C|0)<<1)|0)>(e|0)){break}C=b-u|0;do{if((((C|0)>-1?C:-C|0)|0)<2){G=q-u|0;if(!((((G|0)>-1?G:-G|0)|0)<2&(D|0)<2&(E|0)<2)){break}G=z-v|0;if((((G|0)>-1?G:-G|0)|0)>=2){break}G=A-v|0;if((((G|0)>-1?G:-G|0)|0)>=2){break}G=b<<1;H=b+4|0;a[p]=(H+G+(q<<1)+s+u+v|0)>>>3;I=q+4|0;a[r]=(I+G+(s<<1)+u+v+x|0)>>>3;a[t]=(H+q+s+(u<<1)+v+x+z|0)>>>3;a[o]=(I+s+u+(v<<1)+x+z+A|0)>>>3;a[w]=(s+4+u+v+z+(A+x<<1)|0)>>>3;a[y]=(u+4+v+x+(z<<1)+(A*3|0)|0)>>>3;break a}}while(0);do{if((D|0)>(g|0)){J=(v-u|0)*3|0}else{C=(v-u|0)*3|0;if((E|0)>(g|0)){J=C;break}if((C+128|0)>>>0>255>>>0){K=(C>>31^127)&255}else{K=C&255}C=K<<24>>24;I=C+4|0;H=(I|0)>127?15:I>>3;I=C+3|0;C=((I|0)>127?15:I>>3)+u|0;if(C>>>0>255>>>0){L=-C>>31&255}else{L=C&255}a[t]=L;C=v-H|0;if(C>>>0>255>>>0){M=-C>>31&255}else{M=C&255}a[o]=M;C=H+1>>1;H=C+s|0;if(H>>>0>255>>>0){N=-H>>31&255}else{N=H&255}a[r]=N;H=x-C|0;if(H>>>0>255>>>0){O=-H>>31&255}else{O=H&255}a[w]=O;break a}}while(0);if((F+128|0)>>>0>255>>>0){P=(F>>31^127)&255}else{P=F&255}E=(P<<24>>24)+J|0;if((E+128|0)>>>0>255>>>0){Q=(E>>31^127)&255}else{Q=E&255}E=Q<<24>>24;D=E+4|0;H=E+3|0;E=((H|0)>127?15:H>>3)+u|0;if(E>>>0>255>>>0){R=-E>>31&255}else{R=E&255}a[t]=R;E=v-((D|0)>127?15:D>>3)|0;if(E>>>0>255>>>0){S=-E>>31&255}else{S=E&255}a[o]=S}}while(0);v=n+1|0;if((v|0)<8){n=v;o=o+1|0}else{break}}return}function C9a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;h=0;i=b;while(1){b=i-4|0;j=d[b]|0;k=i-3|0;l=d[k]|0;m=i-2|0;n=d[m]|0;o=i-1|0;p=d[o]|0;q=d[i]|0;r=i+1|0;s=d[r]|0;t=i+2|0;u=d[t]|0;v=i+3|0;w=d[v]|0;x=j-l|0;a:do{if((((x|0)>-1?x:-x|0)|0)<=(f|0)){y=l-n|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=n-p|0;z=(y|0)>-1?y:-y|0;if((z|0)>(f|0)){break}y=s-q|0;A=(y|0)>-1?y:-y|0;if((A|0)>(f|0)){break}y=u-s|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=w-u|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=p-q|0;B=n-s|0;if(((((B|0)>-1?B:-B|0)>>1)+(((y|0)>-1?y:-y|0)<<1)|0)>(e|0)){break}y=d[i-8|0]|0;C=i-7|0;D=d[C]|0;E=i-6|0;F=d[E]|0;G=i-5|0;H=d[G]|0;I=i+4|0;J=d[I]|0;K=i+5|0;L=d[K]|0;M=i+6|0;N=d[M]|0;O=d[i+7|0]|0;P=y-p|0;do{if((((P|0)>-1?P:-P|0)|0)<2){Q=D-p|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=F-p|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=H-p|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=J-q|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=L-q|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=N-q|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=O-q|0;R=(((Q|0)>-1?Q:-Q|0)|0)<2|0}else{R=0}}while(0);P=j-p|0;do{if((((P|0)>-1?P:-P|0)|0)<2){Q=l-p|0;if(!((((Q|0)>-1?Q:-Q|0)|0)<2&(z|0)<2&(A|0)<2)){break}Q=u-q|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){break}Q=w-q|0;S=(((Q|0)>-1?Q:-Q|0)|0)<2;if(!((R|0)==0|S^1)){Q=y<<1;T=Q+y|0;U=T+y|0;V=U+y|0;W=V+y|0;X=j+8|0;Y=X+l|0;Z=Y+n|0;_=Z+p|0;$=_+q|0;a[C]=(y+$+F+(D<<1)+H+W|0)>>>4;aa=$+s|0;a[E]=(D+aa+H+(F<<1)+W|0)>>>4;W=aa+u|0;a[G]=(D+W+F+(H<<1)+V|0)>>>4;a[b]=((j<<1)+8+l+n+p+q+s+u+w+D+F+H+U|0)>>>4;a[k]=((l<<1)+X+n+p+q+s+u+w+D+F+T+H+J|0)>>>4;a[m]=((n<<1)+Y+p+q+s+u+w+D+Q+F+H+J+L|0)>>>4;a[o]=((p<<1)+Z+q+s+u+w+y+D+F+H+J+L+N|0)>>>4;a[i]=((q<<1)+_+s+u+w+D+F+H+J+L+N+O|0)>>>4;a[r]=(u+$+w+F+H+J+L+N+(O+s<<1)|0)>>>4;a[t]=((u<<1)+aa+w+H+J+L+N+(O*3|0)|0)>>>4;a[v]=((w<<1)+W+J+L+N+(O<<2)|0)>>>4;a[I]=(l+8+n+p+q+s+u+w+L+(J<<1)+N+(O*5|0)|0)>>>4;a[K]=(n+8+p+q+s+u+w+J+(L<<1)+N+(O*6|0)|0)>>>4;a[M]=(p+8+q+s+u+w+J+L+(N<<1)+(O*7|0)|0)>>>4;break a}if(!S){break}S=j<<1;W=j+4|0;a[k]=(W+S+(l<<1)+n+p+q|0)>>>3;aa=l+4|0;a[m]=(aa+S+(n<<1)+p+q+s|0)>>>3;a[o]=(W+l+n+(p<<1)+q+s+u|0)>>>3;a[i]=(aa+n+p+(q<<1)+s+u+w|0)>>>3;a[r]=(n+4+p+q+u+(w+s<<1)|0)>>>3;a[t]=(p+4+q+s+(u<<1)+(w*3|0)|0)>>>3;break a}}while(0);do{if((z|0)>(g|0)){ba=(q-p|0)*3|0}else{O=(q-p|0)*3|0;if((A|0)>(g|0)){ba=O;break}if((O+128|0)>>>0>255>>>0){ca=(O>>31^127)&255}else{ca=O&255}O=ca<<24>>24;N=O+4|0;L=(N|0)>127?15:N>>3;N=O+3|0;O=((N|0)>127?15:N>>3)+p|0;if(O>>>0>255>>>0){da=-O>>31&255}else{da=O&255}a[o]=da;O=q-L|0;if(O>>>0>255>>>0){ea=-O>>31&255}else{ea=O&255}a[i]=ea;O=L+1>>1;L=O+n|0;if(L>>>0>255>>>0){fa=-L>>31&255}else{fa=L&255}a[m]=fa;L=s-O|0;if(L>>>0>255>>>0){ga=-L>>31&255}else{ga=L&255}a[r]=ga;break a}}while(0);if((B+128|0)>>>0>255>>>0){ha=(B>>31^127)&255}else{ha=B&255}A=(ha<<24>>24)+ba|0;if((A+128|0)>>>0>255>>>0){ia=(A>>31^127)&255}else{ia=A&255}A=ia<<24>>24;z=A+4|0;L=A+3|0;A=((L|0)>127?15:L>>3)+p|0;if(A>>>0>255>>>0){ja=-A>>31&255}else{ja=A&255}a[o]=ja;A=q-((z|0)>127?15:z>>3)|0;if(A>>>0>255>>>0){ka=-A>>31&255}else{ka=A&255}a[i]=ka}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+c|0}else{break}}return}function D9a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;h=c*-4|0;i=c*-3|0;j=c*-2|0;k=-c|0;l=c<<1;m=c*3|0;n=c*-8|0;o=c*-7|0;p=c*-6|0;q=c*-5|0;r=c<<2;s=c*5|0;t=c*6|0;u=c*7|0;v=0;w=b;while(1){b=w+h|0;x=d[b]|0;y=w+i|0;z=d[y]|0;A=w+j|0;B=d[A]|0;C=w+k|0;D=d[C]|0;E=d[w]|0;F=w+c|0;G=d[F]|0;H=w+l|0;I=d[H]|0;J=w+m|0;K=d[J]|0;L=x-z|0;a:do{if((((L|0)>-1?L:-L|0)|0)<=(f|0)){M=z-B|0;if((((M|0)>-1?M:-M|0)|0)>(f|0)){break}M=B-D|0;N=(M|0)>-1?M:-M|0;if((N|0)>(f|0)){break}M=G-E|0;O=(M|0)>-1?M:-M|0;if((O|0)>(f|0)){break}M=I-G|0;if((((M|0)>-1?M:-M|0)|0)>(f|0)){break}M=K-I|0;if((((M|0)>-1?M:-M|0)|0)>(f|0)){break}M=D-E|0;P=B-G|0;if(((((P|0)>-1?P:-P|0)>>1)+(((M|0)>-1?M:-M|0)<<1)|0)>(e|0)){break}M=d[w+n|0]|0;Q=w+o|0;R=d[Q]|0;S=w+p|0;T=d[S]|0;U=w+q|0;V=d[U]|0;W=w+r|0;X=d[W]|0;Y=w+s|0;Z=d[Y]|0;_=w+t|0;$=d[_]|0;aa=d[w+u|0]|0;ba=M-D|0;do{if((((ba|0)>-1?ba:-ba|0)|0)<2){ca=R-D|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=T-D|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=V-D|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=X-E|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=Z-E|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=$-E|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=aa-E|0;da=(((ca|0)>-1?ca:-ca|0)|0)<2|0}else{da=0}}while(0);ba=x-D|0;do{if((((ba|0)>-1?ba:-ba|0)|0)<2){ca=z-D|0;if(!((((ca|0)>-1?ca:-ca|0)|0)<2&(N|0)<2&(O|0)<2)){break}ca=I-E|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){break}ca=K-E|0;ea=(((ca|0)>-1?ca:-ca|0)|0)<2;if(!((da|0)==0|ea^1)){ca=M<<1;fa=ca+M|0;ga=fa+M|0;ha=ga+M|0;ia=ha+M|0;ja=x+8|0;ka=ja+z|0;la=ka+B|0;ma=la+D|0;na=ma+E|0;a[Q]=(M+na+T+(R<<1)+V+ia|0)>>>4;oa=na+G|0;a[S]=(R+oa+V+(T<<1)+ia|0)>>>4;ia=oa+I|0;a[U]=(R+ia+T+(V<<1)+ha|0)>>>4;a[b]=((x<<1)+8+z+B+D+E+G+I+K+R+T+V+ga|0)>>>4;a[y]=((z<<1)+ja+B+D+E+G+I+K+R+T+fa+V+X|0)>>>4;a[A]=((B<<1)+ka+D+E+G+I+K+R+ca+T+V+X+Z|0)>>>4;a[C]=((D<<1)+la+E+G+I+K+M+R+T+V+X+Z+$|0)>>>4;a[w]=((E<<1)+ma+G+I+K+R+T+V+X+Z+$+aa|0)>>>4;a[F]=(I+na+K+T+V+X+Z+$+(aa+G<<1)|0)>>>4;a[H]=((I<<1)+oa+K+V+X+Z+$+(aa*3|0)|0)>>>4;a[J]=((K<<1)+ia+X+Z+$+(aa<<2)|0)>>>4;a[W]=(z+8+B+D+E+G+I+K+Z+(X<<1)+$+(aa*5|0)|0)>>>4;a[Y]=(B+8+D+E+G+I+K+X+(Z<<1)+$+(aa*6|0)|0)>>>4;a[_]=(D+8+E+G+I+K+X+Z+($<<1)+(aa*7|0)|0)>>>4;break a}if(!ea){break}ea=x<<1;ia=x+4|0;a[y]=(ia+ea+(z<<1)+B+D+E|0)>>>3;oa=z+4|0;a[A]=(oa+ea+(B<<1)+D+E+G|0)>>>3;a[C]=(ia+z+B+(D<<1)+E+G+I|0)>>>3;a[w]=(oa+B+D+(E<<1)+G+I+K|0)>>>3;a[F]=(B+4+D+E+I+(K+G<<1)|0)>>>3;a[H]=(D+4+E+G+(I<<1)+(K*3|0)|0)>>>3;break a}}while(0);do{if((N|0)>(g|0)){pa=(E-D|0)*3|0}else{aa=(E-D|0)*3|0;if((O|0)>(g|0)){pa=aa;break}if((aa+128|0)>>>0>255>>>0){qa=(aa>>31^127)&255}else{qa=aa&255}aa=qa<<24>>24;$=aa+4|0;Z=($|0)>127?15:$>>3;$=aa+3|0;aa=(($|0)>127?15:$>>3)+D|0;if(aa>>>0>255>>>0){ra=-aa>>31&255}else{ra=aa&255}a[C]=ra;aa=E-Z|0;if(aa>>>0>255>>>0){sa=-aa>>31&255}else{sa=aa&255}a[w]=sa;aa=Z+1>>1;Z=aa+B|0;if(Z>>>0>255>>>0){ta=-Z>>31&255}else{ta=Z&255}a[A]=ta;Z=G-aa|0;if(Z>>>0>255>>>0){ua=-Z>>31&255}else{ua=Z&255}a[F]=ua;break a}}while(0);if((P+128|0)>>>0>255>>>0){va=(P>>31^127)&255}else{va=P&255}O=(va<<24>>24)+pa|0;if((O+128|0)>>>0>255>>>0){wa=(O>>31^127)&255}else{wa=O&255}O=wa<<24>>24;N=O+4|0;Z=O+3|0;O=((Z|0)>127?15:Z>>3)+D|0;if(O>>>0>255>>>0){xa=-O>>31&255}else{xa=O&255}a[C]=xa;O=E-((N|0)>127?15:N>>3)|0;if(O>>>0>255>>>0){ya=-O>>31&255}else{ya=O&255}a[w]=ya}}while(0);E=v+1|0;if((E|0)<8){v=E;w=w+1|0}else{break}}return}function E9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;C9a(a,b,c,d,e);C9a(a+(b<<3)|0,b,c,d,e);return}function F9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;D9a(a,b,c,d,e);D9a(a+8|0,b,c,d,e);return}function G9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;y9a(a,b,c&255,d&255,e&255);y9a(a+(b<<3)|0,b,c>>8,d>>8,e>>8);return}function H9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;z9a(a,b,c&255,d&255,e&255);z9a(a+8|0,b,c>>8,d>>8,e>>8);return}function I9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;y9a(a,b,c&255,d&255,e&255);A9a(a+(b<<3)|0,b,c>>8,d>>8,e>>8);return}function J9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;z9a(a,b,c&255,d&255,e&255);B9a(a+8|0,b,c>>8,d>>8,e>>8);return}function K9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;A9a(a,b,c&255,d&255,e&255);y9a(a+(b<<3)|0,b,c>>8,d>>8,e>>8);return}function L9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;B9a(a,b,c&255,d&255,e&255);z9a(a+8|0,b,c>>8,d>>8,e>>8);return}function M9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;A9a(a,b,c&255,d&255,e&255);A9a(a+(b<<3)|0,b,c>>8,d>>8,e>>8);return}function N9a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;B9a(a,b,c&255,d&255,e&255);B9a(a+8|0,b,c>>8,d>>8,e>>8);return}function O9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+40|0;j=h|0;k=h+32|0;if((g|0)==1){g=((((b[f>>1]|0)*11585|0)+8192>>14)*11585|0)+8192>>14;b[f>>1]=0;l=g+8>>4;g=0;m=c;while(1){n=(d[m]|0)+l|0;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[m]=o;n=m+e|0;p=(d[n]|0)+l|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[n]=q;n=m+(e<<1)|0;p=(d[n]|0)+l|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[n]=r;n=m+(e*3|0)|0;p=(d[n]|0)+l|0;if(p>>>0>255>>>0){s=-p>>31&255}else{s=p&255}a[n]=s;n=g+1|0;if((n|0)<4){g=n;m=m+1|0}else{break}}i=h;return}else{t=0}do{m=t<<2;g=b[f+(t<<1)>>1]|0;s=b[f+(t+8<<1)>>1]|0;l=((s+g|0)*11585|0)+8192>>14;r=((g-s|0)*11585|0)+8192>>14;s=b[f+(t+4<<1)>>1]|0;g=b[f+(t+12<<1)>>1]|0;q=(s*6270|0)+8192+(g*-15137|0)>>14;o=(s*15137|0)+8192+(g*6270|0)>>14;b[j+(m<<1)>>1]=o+l;b[j+((m|1)<<1)>>1]=q+r;b[j+((m|2)<<1)>>1]=r-q;b[j+((m|3)<<1)>>1]=l-o;t=t+1|0;}while((t|0)<4);TGb(f|0,0,32)|0;f=k|0;t=k+2|0;o=k+4|0;l=k+6|0;k=0;m=c;while(1){c=b[j+(k<<1)>>1]|0;q=b[j+(k+8<<1)>>1]|0;r=((q+c|0)*11585|0)+8192>>14;g=((c-q|0)*11585|0)+8192>>14;q=b[j+(k+4<<1)>>1]|0;c=b[j+(k+12<<1)>>1]|0;s=(q*6270|0)+8192+(c*-15137|0)>>14;n=(q*15137|0)+8192+(c*6270|0)>>14;c=n+r&65535;b[f>>1]=c;b[t>>1]=s+g;b[o>>1]=g-s;b[l>>1]=r-n;n=((c<<16>>16)+8>>4)+(d[m]|0)|0;if(n>>>0>255>>>0){u=-n>>31&255}else{u=n&255}a[m]=u;n=m+e|0;c=((b[t>>1]|0)+8>>4)+(d[n]|0)|0;if(c>>>0>255>>>0){v=-c>>31&255}else{v=c&255}a[n]=v;n=m+(e<<1)|0;c=((b[o>>1]|0)+8>>4)+(d[n]|0)|0;if(c>>>0>255>>>0){w=-c>>31&255}else{w=c&255}a[n]=w;n=m+(e*3|0)|0;c=((b[l>>1]|0)+8>>4)+(d[n]|0)|0;if(c>>>0>255>>>0){x=-c>>31&255}else{x=c&255}a[n]=x;n=k+1|0;if((n|0)<4){k=n;m=m+1|0}else{break}}i=h;return}function P9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+40|0;h=g|0;j=g+32|0;k=0;do{l=k<<2;m=b[f+(k<<1)>>1]|0;n=b[f+(k+8<<1)>>1]|0;o=b[f+(k+12<<1)>>1]|0;p=(n*15212|0)+(m*5283|0)+(o*9929|0)|0;q=(n*-5283|0)+(m*9929|0)+(o*-15212|0)|0;r=(b[f+(k+4<<1)>>1]|0)*13377|0;s=r+8192|0;b[h+(l<<1)>>1]=(s+p|0)>>>14;b[h+((l|1)<<1)>>1]=(s+q|0)>>>14;b[h+((l|2)<<1)>>1]=(((m-n+o|0)*13377|0)+8192|0)>>>14;b[h+((l|3)<<1)>>1]=(q+8192+p-r|0)>>>14;k=k+1|0;}while((k|0)<4);TGb(f|0,0,32)|0;f=j|0;k=j+2|0;r=j+4|0;p=j+6|0;j=c;c=0;while(1){q=b[h+(c<<1)>>1]|0;l=b[h+(c+8<<1)>>1]|0;o=((l+q|0)*11585|0)+8192>>14;n=((q-l|0)*11585|0)+8192>>14;l=b[h+(c+4<<1)>>1]|0;q=b[h+(c+12<<1)>>1]|0;m=(l*6270|0)+8192+(q*-15137|0)>>14;s=(l*15137|0)+8192+(q*6270|0)>>14;q=s+o&65535;b[f>>1]=q;b[k>>1]=m+n;b[r>>1]=n-m;b[p>>1]=o-s;s=((q<<16>>16)+8>>4)+(d[j]|0)|0;if(s>>>0>255>>>0){t=-s>>31&255}else{t=s&255}a[j]=t;s=j+e|0;q=((b[k>>1]|0)+8>>4)+(d[s]|0)|0;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[s]=u;s=j+(e<<1)|0;q=((b[r>>1]|0)+8>>4)+(d[s]|0)|0;if(q>>>0>255>>>0){v=-q>>31&255}else{v=q&255}a[s]=v;s=j+(e*3|0)|0;q=((b[p>>1]|0)+8>>4)+(d[s]|0)|0;if(q>>>0>255>>>0){w=-q>>31&255}else{w=q&255}a[s]=w;s=c+1|0;if((s|0)<4){j=j+1|0;c=s}else{break}}i=g;return}function Q9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+40|0;h=g|0;j=g+32|0;k=0;do{l=k<<2;m=b[f+(k<<1)>>1]|0;n=b[f+(k+8<<1)>>1]|0;o=((n+m|0)*11585|0)+8192>>14;p=((m-n|0)*11585|0)+8192>>14;n=b[f+(k+4<<1)>>1]|0;m=b[f+(k+12<<1)>>1]|0;q=(n*6270|0)+8192+(m*-15137|0)>>14;r=(n*15137|0)+8192+(m*6270|0)>>14;b[h+(l<<1)>>1]=r+o;b[h+((l|1)<<1)>>1]=q+p;b[h+((l|2)<<1)>>1]=p-q;b[h+((l|3)<<1)>>1]=o-r;k=k+1|0;}while((k|0)<4);TGb(f|0,0,32)|0;f=j|0;k=j+2|0;r=j+4|0;o=j+6|0;j=c;c=0;while(1){l=b[h+(c<<1)>>1]|0;q=b[h+(c+8<<1)>>1]|0;p=b[h+(c+12<<1)>>1]|0;m=(q*15212|0)+(l*5283|0)+(p*9929|0)|0;n=(q*-5283|0)+(l*9929|0)+(p*-15212|0)|0;s=(b[h+(c+4<<1)>>1]|0)*13377|0;t=s+8192|0;u=(t+m|0)>>>14&65535;b[f>>1]=u;b[k>>1]=(t+n|0)>>>14;b[r>>1]=(((l-q+p|0)*13377|0)+8192|0)>>>14;b[o>>1]=(n+8192+m-s|0)>>>14;s=((u<<16>>16)+8>>4)+(d[j]|0)|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[j]=v;s=j+e|0;u=((b[k>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}a[s]=w;s=j+(e<<1)|0;u=((b[r>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){x=-u>>31&255}else{x=u&255}a[s]=x;s=j+(e*3|0)|0;u=((b[o>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){y=-u>>31&255}else{y=u&255}a[s]=y;s=c+1|0;if((s|0)<4){j=j+1|0;c=s}else{break}}i=g;return}function R9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+40|0;h=g|0;j=g+32|0;k=0;do{l=k<<2;m=b[f+(k<<1)>>1]|0;n=b[f+(k+8<<1)>>1]|0;o=b[f+(k+12<<1)>>1]|0;p=(n*15212|0)+(m*5283|0)+(o*9929|0)|0;q=(n*-5283|0)+(m*9929|0)+(o*-15212|0)|0;r=(b[f+(k+4<<1)>>1]|0)*13377|0;s=r+8192|0;b[h+(l<<1)>>1]=(s+p|0)>>>14;b[h+((l|1)<<1)>>1]=(s+q|0)>>>14;b[h+((l|2)<<1)>>1]=(((m-n+o|0)*13377|0)+8192|0)>>>14;b[h+((l|3)<<1)>>1]=(q+8192+p-r|0)>>>14;k=k+1|0;}while((k|0)<4);TGb(f|0,0,32)|0;f=j|0;k=j+2|0;r=j+4|0;p=j+6|0;j=c;c=0;while(1){q=b[h+(c<<1)>>1]|0;l=b[h+(c+8<<1)>>1]|0;o=b[h+(c+12<<1)>>1]|0;n=(l*15212|0)+(q*5283|0)+(o*9929|0)|0;m=(l*-5283|0)+(q*9929|0)+(o*-15212|0)|0;s=(b[h+(c+4<<1)>>1]|0)*13377|0;t=s+8192|0;u=(t+n|0)>>>14&65535;b[f>>1]=u;b[k>>1]=(t+m|0)>>>14;b[r>>1]=(((q-l+o|0)*13377|0)+8192|0)>>>14;b[p>>1]=(m+8192+n-s|0)>>>14;s=((u<<16>>16)+8>>4)+(d[j]|0)|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[j]=v;s=j+e|0;u=((b[k>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}a[s]=w;s=j+(e<<1)|0;u=((b[r>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){x=-u>>31&255}else{x=u&255}a[s]=x;s=j+(e*3|0)|0;u=((b[p>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){y=-u>>31&255}else{y=u&255}a[s]=y;s=c+1|0;if((s|0)<4){j=j+1|0;c=s}else{break}}i=g;return}function S9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+144|0;j=h|0;k=h+128|0;if((g|0)!=1){g=0;do{l=g<<3;m=b[f+(g<<1)>>1]|0;n=b[f+(g+32<<1)>>1]|0;o=((n+m|0)*11585|0)+8192>>14;p=((m-n|0)*11585|0)+8192>>14;n=b[f+(g+16<<1)>>1]|0;m=b[f+(g+48<<1)>>1]|0;q=(n*6270|0)+8192+(m*-15137|0)>>14;r=(n*15137|0)+8192+(m*6270|0)>>14;m=b[f+(g+8<<1)>>1]|0;n=b[f+(g+56<<1)>>1]|0;s=(m*3196|0)+8192+(n*-16069|0)>>14;t=b[f+(g+40<<1)>>1]|0;u=b[f+(g+24<<1)>>1]|0;v=(t*13623|0)+8192+(u*-9102|0)>>14;w=(t*9102|0)+8192+(u*13623|0)>>14;u=(m*16069|0)+8192+(n*3196|0)>>14;n=r+o|0;m=q+p|0;t=p-q|0;q=o-r|0;r=v+s|0;o=s-v|0;v=w+u|0;s=u-w|0;w=((s-o|0)*11585|0)+8192>>14;u=((s+o|0)*11585|0)+8192>>14;b[j+(l<<1)>>1]=v+n;b[j+((l|1)<<1)>>1]=u+m;b[j+((l|2)<<1)>>1]=w+t;b[j+((l|3)<<1)>>1]=r+q;b[j+((l|4)<<1)>>1]=q-r;b[j+((l|5)<<1)>>1]=t-w;b[j+((l|6)<<1)>>1]=m-u;b[j+((l|7)<<1)>>1]=n-v;g=g+1|0;}while((g|0)<8);TGb(f|0,0,128)|0;g=k|0;v=k+2|0;n=k+4|0;l=k+6|0;u=k+8|0;m=k+10|0;w=k+12|0;t=k+14|0;r=0;q=c;while(1){o=b[j+(r<<1)>>1]|0;s=b[j+(r+32<<1)>>1]|0;p=((s+o|0)*11585|0)+8192>>14;x=((o-s|0)*11585|0)+8192>>14;s=b[j+(r+16<<1)>>1]|0;o=b[j+(r+48<<1)>>1]|0;y=(s*6270|0)+8192+(o*-15137|0)>>14;z=(s*15137|0)+8192+(o*6270|0)>>14;o=b[j+(r+8<<1)>>1]|0;s=b[j+(r+56<<1)>>1]|0;A=(o*3196|0)+8192+(s*-16069|0)>>14;B=b[j+(r+40<<1)>>1]|0;C=b[j+(r+24<<1)>>1]|0;D=(B*13623|0)+8192+(C*-9102|0)>>14;E=(B*9102|0)+8192+(C*13623|0)>>14;C=(o*16069|0)+8192+(s*3196|0)>>14;s=z+p|0;o=y+x|0;B=x-y|0;y=p-z|0;z=D+A|0;p=A-D|0;D=E+C|0;A=C-E|0;E=((A-p|0)*11585|0)+8192>>14;C=((A+p|0)*11585|0)+8192>>14;p=D+s&65535;b[g>>1]=p;b[v>>1]=C+o;b[n>>1]=E+B;b[l>>1]=z+y;b[u>>1]=y-z;b[m>>1]=B-E;b[w>>1]=o-C;b[t>>1]=s-D;D=0;s=p;while(1){p=q+(ba(D,e)|0)|0;C=((s<<16>>16)+16>>5)+(d[p]|0)|0;if(C>>>0>255>>>0){F=-C>>31&255}else{F=C&255}a[p]=F;p=D+1|0;if((p|0)>=8){break}D=p;s=b[k+(p<<1)>>1]|0}s=r+1|0;if((s|0)<8){r=s;q=q+1|0}else{break}}i=h;return}q=((((b[f>>1]|0)*11585|0)+8192>>14)*11585|0)+8192>>14;b[f>>1]=0;f=q+16>>5;q=0;r=c;while(1){c=(d[r]|0)+f|0;if(c>>>0>255>>>0){G=-c>>31&255}else{G=c&255}a[r]=G;c=r+e|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){H=-k>>31&255}else{H=k&255}a[c]=H;c=r+(e<<1)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){I=-k>>31&255}else{I=k&255}a[c]=I;c=r+(e*3|0)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){J=-k>>31&255}else{J=k&255}a[c]=J;c=r+(e<<2)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){K=-k>>31&255}else{K=k&255}a[c]=K;c=r+(e*5|0)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){L=-k>>31&255}else{L=k&255}a[c]=L;c=r+(e*6|0)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){M=-k>>31&255}else{M=k&255}a[c]=M;c=r+(e*7|0)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){N=-k>>31&255}else{N=k&255}a[c]=N;c=q+1|0;if((c|0)<8){q=c;r=r+1|0}else{break}}i=h;return}function T9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;i=i+144|0;h=g|0;j=g+128|0;k=0;do{l=k<<3;m=b[f+(k+56<<1)>>1]|0;n=b[f+(k<<1)>>1]|0;o=b[f+(k+40<<1)>>1]|0;p=b[f+(k+16<<1)>>1]|0;q=b[f+(k+24<<1)>>1]|0;r=b[f+(k+32<<1)>>1]|0;s=(r*12665|0)+(q*10394|0)|0;t=(r*-10394|0)+(q*12665|0)|0;q=b[f+(k+8<<1)>>1]|0;r=b[f+(k+48<<1)>>1]|0;u=(r*15679|0)+(q*4756|0)|0;v=(r*-4756|0)+(q*15679|0)|0;q=(m*16305|0)+8192+(n*1606|0)|0;r=s+q>>14;w=(m*1606|0)+8192+(n*-16305|0)|0;n=t+w>>14;m=(o*14449|0)+8192+(p*7723|0)|0;x=u+m>>14;y=(o*7723|0)+8192+(p*-14449|0)|0;p=v+y>>14;o=q-s>>14;s=w-t>>14;t=m-u>>14;u=y-v>>14;v=(u*15137|0)+(t*-6270|0)|0;y=(u*6270|0)+(t*15137|0)|0;b[h+(l<<1)>>1]=x+r;b[h+((l|7)<<1)>>1]=-(n+p|0);t=r-x|0;x=n-p|0;p=(s*6270|0)+8192+(o*15137|0)|0;b[h+((l|1)<<1)>>1]=-((v+p|0)>>>14);n=(s*-15137|0)+8192+(o*6270|0)|0;b[h+((l|6)<<1)>>1]=(y+n|0)>>>14;o=p-v>>14;v=n-y>>14;b[h+((l|3)<<1)>>1]=-((((t+x|0)*11585|0)+8192|0)>>>14);b[h+((l|4)<<1)>>1]=(((t-x|0)*11585|0)+8192|0)>>>14;b[h+((l|2)<<1)>>1]=(((o+v|0)*11585|0)+8192|0)>>>14;b[h+((l|5)<<1)>>1]=-((((o-v|0)*11585|0)+8192|0)>>>14);k=k+1|0;}while((k|0)<8);TGb(f|0,0,128)|0;f=j|0;k=j+2|0;v=j+4|0;o=j+6|0;l=j+8|0;x=j+10|0;t=j+12|0;y=j+14|0;n=c;c=0;while(1){p=b[h+(c<<1)>>1]|0;s=b[h+(c+32<<1)>>1]|0;r=((s+p|0)*11585|0)+8192>>14;u=((p-s|0)*11585|0)+8192>>14;s=b[h+(c+16<<1)>>1]|0;p=b[h+(c+48<<1)>>1]|0;m=(s*6270|0)+8192+(p*-15137|0)>>14;w=(s*15137|0)+8192+(p*6270|0)>>14;p=b[h+(c+8<<1)>>1]|0;s=b[h+(c+56<<1)>>1]|0;q=(p*3196|0)+8192+(s*-16069|0)>>14;z=b[h+(c+40<<1)>>1]|0;A=b[h+(c+24<<1)>>1]|0;B=(z*13623|0)+8192+(A*-9102|0)>>14;C=(z*9102|0)+8192+(A*13623|0)>>14;A=(p*16069|0)+8192+(s*3196|0)>>14;s=w+r|0;p=m+u|0;z=u-m|0;m=r-w|0;w=B+q|0;r=q-B|0;B=C+A|0;q=A-C|0;C=((q-r|0)*11585|0)+8192>>14;A=((q+r|0)*11585|0)+8192>>14;r=B+s&65535;b[f>>1]=r;b[k>>1]=A+p;b[v>>1]=C+z;b[o>>1]=w+m;b[l>>1]=m-w;b[x>>1]=z-C;b[t>>1]=p-A;b[y>>1]=s-B;B=0;s=r;while(1){r=n+(ba(B,e)|0)|0;A=((s<<16>>16)+16>>5)+(d[r]|0)|0;if(A>>>0>255>>>0){D=-A>>31&255}else{D=A&255}a[r]=D;r=B+1|0;if((r|0)>=8){break}B=r;s=b[j+(r<<1)>>1]|0}s=c+1|0;if((s|0)<8){n=n+1|0;c=s}else{break}}i=g;return}function U9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+144|0;h=g|0;j=g+128|0;k=0;do{l=k<<3;m=b[f+(k<<1)>>1]|0;n=b[f+(k+32<<1)>>1]|0;o=((n+m|0)*11585|0)+8192>>14;p=((m-n|0)*11585|0)+8192>>14;n=b[f+(k+16<<1)>>1]|0;m=b[f+(k+48<<1)>>1]|0;q=(n*6270|0)+8192+(m*-15137|0)>>14;r=(n*15137|0)+8192+(m*6270|0)>>14;m=b[f+(k+8<<1)>>1]|0;n=b[f+(k+56<<1)>>1]|0;s=(m*3196|0)+8192+(n*-16069|0)>>14;t=b[f+(k+40<<1)>>1]|0;u=b[f+(k+24<<1)>>1]|0;v=(t*13623|0)+8192+(u*-9102|0)>>14;w=(t*9102|0)+8192+(u*13623|0)>>14;u=(m*16069|0)+8192+(n*3196|0)>>14;n=r+o|0;m=q+p|0;t=p-q|0;q=o-r|0;r=v+s|0;o=s-v|0;v=w+u|0;s=u-w|0;w=((s-o|0)*11585|0)+8192>>14;u=((s+o|0)*11585|0)+8192>>14;b[h+(l<<1)>>1]=v+n;b[h+((l|1)<<1)>>1]=u+m;b[h+((l|2)<<1)>>1]=w+t;b[h+((l|3)<<1)>>1]=r+q;b[h+((l|4)<<1)>>1]=q-r;b[h+((l|5)<<1)>>1]=t-w;b[h+((l|6)<<1)>>1]=m-u;b[h+((l|7)<<1)>>1]=n-v;k=k+1|0;}while((k|0)<8);TGb(f|0,0,128)|0;f=j|0;k=j+14|0;v=j+2|0;n=j+12|0;l=j+6|0;u=j+8|0;m=j+4|0;w=j+10|0;t=c;c=0;while(1){r=b[h+(c+56<<1)>>1]|0;q=b[h+(c<<1)>>1]|0;o=b[h+(c+40<<1)>>1]|0;s=b[h+(c+16<<1)>>1]|0;p=b[h+(c+24<<1)>>1]|0;x=b[h+(c+32<<1)>>1]|0;y=(x*12665|0)+(p*10394|0)|0;z=(x*-10394|0)+(p*12665|0)|0;p=b[h+(c+8<<1)>>1]|0;x=b[h+(c+48<<1)>>1]|0;A=(x*15679|0)+(p*4756|0)|0;B=(x*-4756|0)+(p*15679|0)|0;p=(r*16305|0)+8192+(q*1606|0)|0;x=y+p>>14;C=(r*1606|0)+8192+(q*-16305|0)|0;q=z+C>>14;r=(o*14449|0)+8192+(s*7723|0)|0;D=A+r>>14;E=(o*7723|0)+8192+(s*-14449|0)|0;s=B+E>>14;o=p-y>>14;y=C-z>>14;z=r-A>>14;A=E-B>>14;B=(A*15137|0)+(z*-6270|0)|0;E=(A*6270|0)+(z*15137|0)|0;z=D+x&65535;b[f>>1]=z;b[k>>1]=-(q+s|0);A=x-D|0;D=q-s|0;s=(y*6270|0)+8192+(o*15137|0)|0;b[v>>1]=-((B+s|0)>>>14);q=(y*-15137|0)+8192+(o*6270|0)|0;b[n>>1]=(E+q|0)>>>14;o=s-B>>14;B=q-E>>14;b[l>>1]=-((((A+D|0)*11585|0)+8192|0)>>>14);b[u>>1]=(((A-D|0)*11585|0)+8192|0)>>>14;b[m>>1]=(((o+B|0)*11585|0)+8192|0)>>>14;b[w>>1]=-((((o-B|0)*11585|0)+8192|0)>>>14);B=0;o=z;while(1){z=t+(ba(B,e)|0)|0;D=((o<<16>>16)+16>>5)+(d[z]|0)|0;if(D>>>0>255>>>0){F=-D>>31&255}else{F=D&255}a[z]=F;z=B+1|0;if((z|0)>=8){break}B=z;o=b[j+(z<<1)>>1]|0}o=c+1|0;if((o|0)<8){t=t+1|0;c=o}else{break}}i=g;return}function V9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+144|0;h=g|0;j=g+128|0;k=0;do{l=k<<3;m=b[f+(k+56<<1)>>1]|0;n=b[f+(k<<1)>>1]|0;o=b[f+(k+40<<1)>>1]|0;p=b[f+(k+16<<1)>>1]|0;q=b[f+(k+24<<1)>>1]|0;r=b[f+(k+32<<1)>>1]|0;s=(r*12665|0)+(q*10394|0)|0;t=(r*-10394|0)+(q*12665|0)|0;q=b[f+(k+8<<1)>>1]|0;r=b[f+(k+48<<1)>>1]|0;u=(r*15679|0)+(q*4756|0)|0;v=(r*-4756|0)+(q*15679|0)|0;q=(m*16305|0)+8192+(n*1606|0)|0;r=s+q>>14;w=(m*1606|0)+8192+(n*-16305|0)|0;n=t+w>>14;m=(o*14449|0)+8192+(p*7723|0)|0;x=u+m>>14;y=(o*7723|0)+8192+(p*-14449|0)|0;p=v+y>>14;o=q-s>>14;s=w-t>>14;t=m-u>>14;u=y-v>>14;v=(u*15137|0)+(t*-6270|0)|0;y=(u*6270|0)+(t*15137|0)|0;b[h+(l<<1)>>1]=x+r;b[h+((l|7)<<1)>>1]=-(n+p|0);t=r-x|0;x=n-p|0;p=(s*6270|0)+8192+(o*15137|0)|0;b[h+((l|1)<<1)>>1]=-((v+p|0)>>>14);n=(s*-15137|0)+8192+(o*6270|0)|0;b[h+((l|6)<<1)>>1]=(y+n|0)>>>14;o=p-v>>14;v=n-y>>14;b[h+((l|3)<<1)>>1]=-((((t+x|0)*11585|0)+8192|0)>>>14);b[h+((l|4)<<1)>>1]=(((t-x|0)*11585|0)+8192|0)>>>14;b[h+((l|2)<<1)>>1]=(((o+v|0)*11585|0)+8192|0)>>>14;b[h+((l|5)<<1)>>1]=-((((o-v|0)*11585|0)+8192|0)>>>14);k=k+1|0;}while((k|0)<8);TGb(f|0,0,128)|0;f=j|0;k=j+14|0;v=j+2|0;o=j+12|0;l=j+6|0;x=j+8|0;t=j+4|0;y=j+10|0;n=c;c=0;while(1){p=b[h+(c+56<<1)>>1]|0;s=b[h+(c<<1)>>1]|0;r=b[h+(c+40<<1)>>1]|0;u=b[h+(c+16<<1)>>1]|0;m=b[h+(c+24<<1)>>1]|0;w=b[h+(c+32<<1)>>1]|0;q=(w*12665|0)+(m*10394|0)|0;z=(w*-10394|0)+(m*12665|0)|0;m=b[h+(c+8<<1)>>1]|0;w=b[h+(c+48<<1)>>1]|0;A=(w*15679|0)+(m*4756|0)|0;B=(w*-4756|0)+(m*15679|0)|0;m=(p*16305|0)+8192+(s*1606|0)|0;w=q+m>>14;C=(p*1606|0)+8192+(s*-16305|0)|0;s=z+C>>14;p=(r*14449|0)+8192+(u*7723|0)|0;D=A+p>>14;E=(r*7723|0)+8192+(u*-14449|0)|0;u=B+E>>14;r=m-q>>14;q=C-z>>14;z=p-A>>14;A=E-B>>14;B=(A*15137|0)+(z*-6270|0)|0;E=(A*6270|0)+(z*15137|0)|0;z=D+w&65535;b[f>>1]=z;b[k>>1]=-(s+u|0);A=w-D|0;D=s-u|0;u=(q*6270|0)+8192+(r*15137|0)|0;b[v>>1]=-((B+u|0)>>>14);s=(q*-15137|0)+8192+(r*6270|0)|0;b[o>>1]=(E+s|0)>>>14;r=u-B>>14;B=s-E>>14;b[l>>1]=-((((A+D|0)*11585|0)+8192|0)>>>14);b[x>>1]=(((A-D|0)*11585|0)+8192|0)>>>14;b[t>>1]=(((r+B|0)*11585|0)+8192|0)>>>14;b[y>>1]=-((((r-B|0)*11585|0)+8192|0)>>>14);B=0;r=z;while(1){z=n+(ba(B,e)|0)|0;D=((r<<16>>16)+16>>5)+(d[z]|0)|0;if(D>>>0>255>>>0){F=-D>>31&255}else{F=D&255}a[z]=F;z=B+1|0;if((z|0)>=8){break}B=z;r=b[j+(z<<1)>>1]|0}r=c+1|0;if((r|0)<8){n=n+1|0;c=r}else{break}}i=g;return}function W9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;i=i+544|0;j=h|0;k=h+512|0;if((g|0)==1){g=((((b[f>>1]|0)*11585|0)+8192>>14)*11585|0)+8192>>14;b[f>>1]=0;l=g+32>>6;g=0;m=c;while(1){n=0;do{o=m+(ba(n,e)|0)|0;p=(d[o]|0)+l|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[o]=q;n=n+1|0;}while((n|0)<16);n=g+1|0;if((n|0)<16){g=n;m=m+1|0}else{break}}i=h;return}else{r=0}do{m=r<<4;g=b[f+(r<<1)>>1]|0;q=b[f+(r+128<<1)>>1]|0;l=((q+g|0)*11585|0)+8192>>14;n=((g-q|0)*11585|0)+8192>>14;q=b[f+(r+64<<1)>>1]|0;g=b[f+(r+192<<1)>>1]|0;o=(q*6270|0)+8192+(g*-15137|0)>>14;p=(q*15137|0)+8192+(g*6270|0)>>14;g=b[f+(r+32<<1)>>1]|0;q=b[f+(r+224<<1)>>1]|0;s=(g*3196|0)+8192+(q*-16069|0)>>14;t=(g*16069|0)+8192+(q*3196|0)>>14;q=b[f+(r+160<<1)>>1]|0;g=b[f+(r+96<<1)>>1]|0;u=(q*13623|0)+8192+(g*-9102|0)>>14;v=(q*9102|0)+8192+(g*13623|0)>>14;g=b[f+(r+16<<1)>>1]|0;q=b[f+(r+240<<1)>>1]|0;w=(g*1606|0)+8192+(q*-16305|0)>>14;x=(g*16305|0)+8192+(q*1606|0)>>14;q=b[f+(r+144<<1)>>1]|0;g=b[f+(r+112<<1)>>1]|0;y=(q*12665|0)+8192+(g*-10394|0)>>14;z=(q*10394|0)+8192+(g*12665|0)>>14;g=b[f+(r+80<<1)>>1]|0;q=b[f+(r+176<<1)>>1]|0;A=(g*7723|0)+8192+(q*-14449|0)>>14;B=(g*14449|0)+8192+(q*7723|0)>>14;q=b[f+(r+208<<1)>>1]|0;g=b[f+(r+48<<1)>>1]|0;C=(q*15679|0)+8192+(g*-4756|0)>>14;D=(q*4756|0)+8192+(g*15679|0)>>14;g=p+l|0;q=o+n|0;E=n-o|0;o=l-p|0;p=u+s|0;l=s-u|0;u=t-v|0;s=v+t|0;t=y+w|0;v=w-y|0;y=C-A|0;w=C+A|0;A=D+B|0;C=D-B|0;B=x-z|0;D=z+x|0;x=((u-l|0)*11585|0)+8192>>14;z=((u+l|0)*11585|0)+8192>>14;l=(v*-15137|0)+8192+(B*6270|0)>>14;u=(v*6270|0)+8192+(B*15137|0)>>14;B=(y*-6270|0)+8192+(C*-15137|0)>>14;v=(y*-15137|0)+8192+(C*6270|0)>>14;C=s+g|0;y=z+q|0;n=x+E|0;F=p+o|0;G=o-p|0;p=E-x|0;x=q-z|0;z=g-s|0;s=w+t|0;g=B+l|0;q=l-B|0;B=t-w|0;w=D-A|0;t=u-v|0;l=v+u|0;u=A+D|0;D=((t-q|0)*11585|0)+8192>>14;A=((t+q|0)*11585|0)+8192>>14;q=((w-B|0)*11585|0)+8192>>14;t=((w+B|0)*11585|0)+8192>>14;b[j+(m<<1)>>1]=u+C;b[j+((m|1)<<1)>>1]=l+y;b[j+((m|2)<<1)>>1]=A+n;b[j+((m|3)<<1)>>1]=t+F;b[j+((m|4)<<1)>>1]=q+G;b[j+((m|5)<<1)>>1]=D+p;b[j+((m|6)<<1)>>1]=g+x;b[j+((m|7)<<1)>>1]=s+z;b[j+((m|8)<<1)>>1]=z-s;b[j+((m|9)<<1)>>1]=x-g;b[j+((m|10)<<1)>>1]=p-D;b[j+((m|11)<<1)>>1]=G-q;b[j+((m|12)<<1)>>1]=F-t;b[j+((m|13)<<1)>>1]=n-A;b[j+((m|14)<<1)>>1]=y-l;b[j+((m|15)<<1)>>1]=C-u;r=r+1|0;}while((r|0)<16);TGb(f|0,0,512)|0;f=k|0;r=k+2|0;u=k+4|0;C=k+6|0;m=k+8|0;l=k+10|0;y=k+12|0;A=k+14|0;n=k+16|0;t=k+18|0;F=k+20|0;q=k+22|0;G=k+24|0;D=k+26|0;p=k+28|0;g=k+30|0;x=0;s=c;while(1){c=b[j+(x<<1)>>1]|0;z=b[j+(x+128<<1)>>1]|0;B=((z+c|0)*11585|0)+8192>>14;w=((c-z|0)*11585|0)+8192>>14;z=b[j+(x+64<<1)>>1]|0;c=b[j+(x+192<<1)>>1]|0;v=(z*6270|0)+8192+(c*-15137|0)>>14;E=(z*15137|0)+8192+(c*6270|0)>>14;c=b[j+(x+32<<1)>>1]|0;z=b[j+(x+224<<1)>>1]|0;o=(c*3196|0)+8192+(z*-16069|0)>>14;H=(c*16069|0)+8192+(z*3196|0)>>14;z=b[j+(x+160<<1)>>1]|0;c=b[j+(x+96<<1)>>1]|0;I=(z*13623|0)+8192+(c*-9102|0)>>14;J=(z*9102|0)+8192+(c*13623|0)>>14;c=b[j+(x+16<<1)>>1]|0;z=b[j+(x+240<<1)>>1]|0;K=(c*1606|0)+8192+(z*-16305|0)>>14;L=(c*16305|0)+8192+(z*1606|0)>>14;z=b[j+(x+144<<1)>>1]|0;c=b[j+(x+112<<1)>>1]|0;M=(z*12665|0)+8192+(c*-10394|0)>>14;N=(z*10394|0)+8192+(c*12665|0)>>14;c=b[j+(x+80<<1)>>1]|0;z=b[j+(x+176<<1)>>1]|0;O=(c*7723|0)+8192+(z*-14449|0)>>14;P=(c*14449|0)+8192+(z*7723|0)>>14;z=b[j+(x+208<<1)>>1]|0;c=b[j+(x+48<<1)>>1]|0;Q=(z*15679|0)+8192+(c*-4756|0)>>14;R=(z*4756|0)+8192+(c*15679|0)>>14;c=E+B|0;z=v+w|0;S=w-v|0;v=B-E|0;E=I+o|0;B=o-I|0;I=H-J|0;o=J+H|0;H=M+K|0;J=K-M|0;M=Q-O|0;K=Q+O|0;O=R+P|0;Q=R-P|0;P=L-N|0;R=N+L|0;L=((I-B|0)*11585|0)+8192>>14;N=((I+B|0)*11585|0)+8192>>14;B=(J*-15137|0)+8192+(P*6270|0)>>14;I=(J*6270|0)+8192+(P*15137|0)>>14;P=(M*-6270|0)+8192+(Q*-15137|0)>>14;J=(M*-15137|0)+8192+(Q*6270|0)>>14;Q=o+c|0;M=N+z|0;w=L+S|0;T=E+v|0;U=v-E|0;E=S-L|0;L=z-N|0;N=c-o|0;o=K+H|0;c=P+B|0;z=B-P|0;P=H-K|0;K=R-O|0;H=I-J|0;B=J+I|0;I=O+R|0;R=((H-z|0)*11585|0)+8192>>14;O=((H+z|0)*11585|0)+8192>>14;z=((K-P|0)*11585|0)+8192>>14;H=((K+P|0)*11585|0)+8192>>14;P=I+Q&65535;b[f>>1]=P;b[r>>1]=B+M;b[u>>1]=O+w;b[C>>1]=H+T;b[m>>1]=z+U;b[l>>1]=R+E;b[y>>1]=c+L;b[A>>1]=o+N;b[n>>1]=N-o;b[t>>1]=L-c;b[F>>1]=E-R;b[q>>1]=U-z;b[G>>1]=T-H;b[D>>1]=w-O;b[p>>1]=M-B;b[g>>1]=Q-I;I=0;Q=P;while(1){P=s+(ba(I,e)|0)|0;B=((Q<<16>>16)+32>>6)+(d[P]|0)|0;if(B>>>0>255>>>0){V=-B>>31&255}else{V=B&255}a[P]=V;P=I+1|0;if((P|0)>=16){break}I=P;Q=b[k+(P<<1)>>1]|0}Q=x+1|0;if((Q|0)<16){x=Q;s=s+1|0}else{break}}i=h;return}function X9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;g=i;i=i+544|0;h=g|0;j=g+512|0;k=0;do{l=k<<4;m=b[f+(k+240<<1)>>1]|0;n=b[f+(k<<1)>>1]|0;o=b[f+(k+208<<1)>>1]|0;p=b[f+(k+32<<1)>>1]|0;q=b[f+(k+176<<1)>>1]|0;r=b[f+(k+64<<1)>>1]|0;s=b[f+(k+144<<1)>>1]|0;t=b[f+(k+96<<1)>>1]|0;u=b[f+(k+112<<1)>>1]|0;v=b[f+(k+128<<1)>>1]|0;w=(v*12140|0)+(u*11003|0)|0;x=(v*-11003|0)+(u*12140|0)|0;u=b[f+(k+80<<1)>>1]|0;v=b[f+(k+160<<1)>>1]|0;y=(v*14053|0)+(u*8423|0)|0;z=(v*-8423|0)+(u*14053|0)|0;u=b[f+(k+48<<1)>>1]|0;v=b[f+(k+192<<1)>>1]|0;A=(v*15426|0)+(u*5520|0)|0;B=(v*-5520|0)+(u*15426|0)|0;u=b[f+(k+16<<1)>>1]|0;v=b[f+(k+224<<1)>>1]|0;C=(v*16207|0)+(u*2404|0)|0;D=(v*-2404|0)+(u*16207|0)|0;u=(m*16364|0)+8192+(n*804|0)|0;v=w+u>>14;E=(m*804|0)+8192+(n*-16364|0)|0;n=x+E>>14;m=(o*15893|0)+8192+(p*3981|0)|0;F=y+m>>14;G=(o*3981|0)+8192+(p*-15893|0)|0;p=z+G>>14;o=(q*14811|0)+8192+(r*7005|0)|0;H=A+o>>14;I=(q*7005|0)+8192+(r*-14811|0)|0;r=B+I>>14;q=(s*13160|0)+8192+(t*9760|0)|0;J=C+q>>14;K=(s*9760|0)+8192+(t*-13160|0)|0;t=D+K>>14;s=u-w>>14;w=E-x>>14;x=m-y>>14;y=G-z>>14;z=o-A>>14;A=I-B>>14;B=q-C>>14;C=K-D>>14;D=(A*16069|0)+(z*-3196|0)|0;K=(A*3196|0)+(z*16069|0)|0;z=(C*9102|0)+(B*-13623|0)|0;A=(C*13623|0)+(B*9102|0)|0;B=H+v|0;C=r+n|0;q=J+F|0;I=t+p|0;o=v-H|0;H=n-r|0;r=F-J|0;J=p-t|0;t=(w*3196|0)+8192+(s*16069|0)|0;p=D+t>>14;F=(w*-16069|0)+8192+(s*3196|0)|0;s=K+F>>14;w=(y*13623|0)+8192+(x*9102|0)|0;n=z+w>>14;v=(y*-9102|0)+8192+(x*13623|0)|0;x=A+v>>14;y=t-D>>14;D=F-K>>14;K=w-z>>14;z=v-A>>14;A=(J*15137|0)+(r*-6270|0)|0;v=(J*6270|0)+(r*15137|0)|0;r=(z*15137|0)+(K*-6270|0)|0;J=(z*6270|0)+(K*15137|0)|0;b[h+(l<<1)>>1]=q+B;b[h+((l|15)<<1)>>1]=-(C+I|0);K=B-q|0;q=C-I|0;I=(H*6270|0)+8192+(o*15137|0)|0;b[h+((l|3)<<1)>>1]=-((A+I|0)>>>14);C=(H*-15137|0)+8192+(o*6270|0)|0;b[h+((l|12)<<1)>>1]=(v+C|0)>>>14;o=I-A>>14;A=C-v>>14;b[h+((l|1)<<1)>>1]=-(p+n|0);b[h+((l|14)<<1)>>1]=x+s;v=p-n|0;n=s-x|0;x=(D*6270|0)+8192+(y*15137|0)|0;b[h+((l|2)<<1)>>1]=(r+x|0)>>>14;s=(D*-15137|0)+8192+(y*6270|0)|0;b[h+((l|13)<<1)>>1]=-((J+s|0)>>>14);y=x-r>>14;r=s-J>>14;b[h+((l|7)<<1)>>1]=(((K+q|0)*-11585|0)+8192|0)>>>14;b[h+((l|8)<<1)>>1]=(((K-q|0)*11585|0)+8192|0)>>>14;b[h+((l|4)<<1)>>1]=(((A+o|0)*11585|0)+8192|0)>>>14;b[h+((l|11)<<1)>>1]=(((A-o|0)*11585|0)+8192|0)>>>14;b[h+((l|6)<<1)>>1]=(((n+v|0)*11585|0)+8192|0)>>>14;b[h+((l|9)<<1)>>1]=(((n-v|0)*11585|0)+8192|0)>>>14;b[h+((l|5)<<1)>>1]=(((y+r|0)*-11585|0)+8192|0)>>>14;b[h+((l|10)<<1)>>1]=(((y-r|0)*11585|0)+8192|0)>>>14;k=k+1|0;}while((k|0)<16);TGb(f|0,0,512)|0;f=j|0;k=j+2|0;r=j+4|0;y=j+6|0;l=j+8|0;v=j+10|0;n=j+12|0;o=j+14|0;A=j+16|0;q=j+18|0;K=j+20|0;J=j+22|0;s=j+24|0;x=j+26|0;D=j+28|0;p=j+30|0;C=c;c=0;while(1){I=b[h+(c<<1)>>1]|0;H=b[h+(c+128<<1)>>1]|0;B=((H+I|0)*11585|0)+8192>>14;z=((I-H|0)*11585|0)+8192>>14;H=b[h+(c+64<<1)>>1]|0;I=b[h+(c+192<<1)>>1]|0;w=(H*6270|0)+8192+(I*-15137|0)>>14;F=(H*15137|0)+8192+(I*6270|0)>>14;I=b[h+(c+32<<1)>>1]|0;H=b[h+(c+224<<1)>>1]|0;t=(I*3196|0)+8192+(H*-16069|0)>>14;G=(I*16069|0)+8192+(H*3196|0)>>14;H=b[h+(c+160<<1)>>1]|0;I=b[h+(c+96<<1)>>1]|0;m=(H*13623|0)+8192+(I*-9102|0)>>14;E=(H*9102|0)+8192+(I*13623|0)>>14;I=b[h+(c+16<<1)>>1]|0;H=b[h+(c+240<<1)>>1]|0;u=(I*1606|0)+8192+(H*-16305|0)>>14;L=(I*16305|0)+8192+(H*1606|0)>>14;H=b[h+(c+144<<1)>>1]|0;I=b[h+(c+112<<1)>>1]|0;M=(H*12665|0)+8192+(I*-10394|0)>>14;N=(H*10394|0)+8192+(I*12665|0)>>14;I=b[h+(c+80<<1)>>1]|0;H=b[h+(c+176<<1)>>1]|0;O=(I*7723|0)+8192+(H*-14449|0)>>14;P=(I*14449|0)+8192+(H*7723|0)>>14;H=b[h+(c+208<<1)>>1]|0;I=b[h+(c+48<<1)>>1]|0;Q=(H*15679|0)+8192+(I*-4756|0)>>14;R=(H*4756|0)+8192+(I*15679|0)>>14;I=F+B|0;H=w+z|0;S=z-w|0;w=B-F|0;F=m+t|0;B=t-m|0;m=G-E|0;t=E+G|0;G=M+u|0;E=u-M|0;M=Q-O|0;u=Q+O|0;O=R+P|0;Q=R-P|0;P=L-N|0;R=N+L|0;L=((m-B|0)*11585|0)+8192>>14;N=((m+B|0)*11585|0)+8192>>14;B=(E*-15137|0)+8192+(P*6270|0)>>14;m=(E*6270|0)+8192+(P*15137|0)>>14;P=(M*-6270|0)+8192+(Q*-15137|0)>>14;E=(M*-15137|0)+8192+(Q*6270|0)>>14;Q=t+I|0;M=N+H|0;z=L+S|0;T=F+w|0;U=w-F|0;F=S-L|0;L=H-N|0;N=I-t|0;t=u+G|0;I=P+B|0;H=B-P|0;P=G-u|0;u=R-O|0;G=m-E|0;B=E+m|0;m=O+R|0;R=((G-H|0)*11585|0)+8192>>14;O=((G+H|0)*11585|0)+8192>>14;H=((u-P|0)*11585|0)+8192>>14;G=((u+P|0)*11585|0)+8192>>14;P=m+Q&65535;b[f>>1]=P;b[k>>1]=B+M;b[r>>1]=O+z;b[y>>1]=G+T;b[l>>1]=H+U;b[v>>1]=R+F;b[n>>1]=I+L;b[o>>1]=t+N;b[A>>1]=N-t;b[q>>1]=L-I;b[K>>1]=F-R;b[J>>1]=U-H;b[s>>1]=T-G;b[x>>1]=z-O;b[D>>1]=M-B;b[p>>1]=Q-m;m=0;Q=P;while(1){P=C+(ba(m,e)|0)|0;B=((Q<<16>>16)+32>>6)+(d[P]|0)|0;if(B>>>0>255>>>0){V=-B>>31&255}else{V=B&255}a[P]=V;P=m+1|0;if((P|0)>=16){break}m=P;Q=b[j+(P<<1)>>1]|0}Q=c+1|0;if((Q|0)<16){C=C+1|0;c=Q}else{break}}i=g;return}function Y9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;g=i;i=i+544|0;h=g|0;j=g+512|0;k=0;do{l=k<<4;m=b[f+(k<<1)>>1]|0;n=b[f+(k+128<<1)>>1]|0;o=((n+m|0)*11585|0)+8192>>14;p=((m-n|0)*11585|0)+8192>>14;n=b[f+(k+64<<1)>>1]|0;m=b[f+(k+192<<1)>>1]|0;q=(n*6270|0)+8192+(m*-15137|0)>>14;r=(n*15137|0)+8192+(m*6270|0)>>14;m=b[f+(k+32<<1)>>1]|0;n=b[f+(k+224<<1)>>1]|0;s=(m*3196|0)+8192+(n*-16069|0)>>14;t=(m*16069|0)+8192+(n*3196|0)>>14;n=b[f+(k+160<<1)>>1]|0;m=b[f+(k+96<<1)>>1]|0;u=(n*13623|0)+8192+(m*-9102|0)>>14;v=(n*9102|0)+8192+(m*13623|0)>>14;m=b[f+(k+16<<1)>>1]|0;n=b[f+(k+240<<1)>>1]|0;w=(m*1606|0)+8192+(n*-16305|0)>>14;x=(m*16305|0)+8192+(n*1606|0)>>14;n=b[f+(k+144<<1)>>1]|0;m=b[f+(k+112<<1)>>1]|0;y=(n*12665|0)+8192+(m*-10394|0)>>14;z=(n*10394|0)+8192+(m*12665|0)>>14;m=b[f+(k+80<<1)>>1]|0;n=b[f+(k+176<<1)>>1]|0;A=(m*7723|0)+8192+(n*-14449|0)>>14;B=(m*14449|0)+8192+(n*7723|0)>>14;n=b[f+(k+208<<1)>>1]|0;m=b[f+(k+48<<1)>>1]|0;C=(n*15679|0)+8192+(m*-4756|0)>>14;D=(n*4756|0)+8192+(m*15679|0)>>14;m=r+o|0;n=q+p|0;E=p-q|0;q=o-r|0;r=u+s|0;o=s-u|0;u=t-v|0;s=v+t|0;t=y+w|0;v=w-y|0;y=C-A|0;w=C+A|0;A=D+B|0;C=D-B|0;B=x-z|0;D=z+x|0;x=((u-o|0)*11585|0)+8192>>14;z=((u+o|0)*11585|0)+8192>>14;o=(v*-15137|0)+8192+(B*6270|0)>>14;u=(v*6270|0)+8192+(B*15137|0)>>14;B=(y*-6270|0)+8192+(C*-15137|0)>>14;v=(y*-15137|0)+8192+(C*6270|0)>>14;C=s+m|0;y=z+n|0;p=x+E|0;F=r+q|0;G=q-r|0;r=E-x|0;x=n-z|0;z=m-s|0;s=w+t|0;m=B+o|0;n=o-B|0;B=t-w|0;w=D-A|0;t=u-v|0;o=v+u|0;u=A+D|0;D=((t-n|0)*11585|0)+8192>>14;A=((t+n|0)*11585|0)+8192>>14;n=((w-B|0)*11585|0)+8192>>14;t=((w+B|0)*11585|0)+8192>>14;b[h+(l<<1)>>1]=u+C;b[h+((l|1)<<1)>>1]=o+y;b[h+((l|2)<<1)>>1]=A+p;b[h+((l|3)<<1)>>1]=t+F;b[h+((l|4)<<1)>>1]=n+G;b[h+((l|5)<<1)>>1]=D+r;b[h+((l|6)<<1)>>1]=m+x;b[h+((l|7)<<1)>>1]=s+z;b[h+((l|8)<<1)>>1]=z-s;b[h+((l|9)<<1)>>1]=x-m;b[h+((l|10)<<1)>>1]=r-D;b[h+((l|11)<<1)>>1]=G-n;b[h+((l|12)<<1)>>1]=F-t;b[h+((l|13)<<1)>>1]=p-A;b[h+((l|14)<<1)>>1]=y-o;b[h+((l|15)<<1)>>1]=C-u;k=k+1|0;}while((k|0)<16);TGb(f|0,0,512)|0;f=j|0;k=j+30|0;u=j+6|0;C=j+24|0;l=j+2|0;o=j+28|0;y=j+4|0;A=j+26|0;p=j+14|0;t=j+16|0;F=j+8|0;n=j+22|0;G=j+12|0;D=j+18|0;r=j+10|0;m=j+20|0;x=c;c=0;while(1){s=b[h+(c+240<<1)>>1]|0;z=b[h+(c<<1)>>1]|0;B=b[h+(c+208<<1)>>1]|0;w=b[h+(c+32<<1)>>1]|0;v=b[h+(c+176<<1)>>1]|0;E=b[h+(c+64<<1)>>1]|0;q=b[h+(c+144<<1)>>1]|0;H=b[h+(c+96<<1)>>1]|0;I=b[h+(c+112<<1)>>1]|0;J=b[h+(c+128<<1)>>1]|0;K=(J*12140|0)+(I*11003|0)|0;L=(J*-11003|0)+(I*12140|0)|0;I=b[h+(c+80<<1)>>1]|0;J=b[h+(c+160<<1)>>1]|0;M=(J*14053|0)+(I*8423|0)|0;N=(J*-8423|0)+(I*14053|0)|0;I=b[h+(c+48<<1)>>1]|0;J=b[h+(c+192<<1)>>1]|0;O=(J*15426|0)+(I*5520|0)|0;P=(J*-5520|0)+(I*15426|0)|0;I=b[h+(c+16<<1)>>1]|0;J=b[h+(c+224<<1)>>1]|0;Q=(J*16207|0)+(I*2404|0)|0;R=(J*-2404|0)+(I*16207|0)|0;I=(s*16364|0)+8192+(z*804|0)|0;J=K+I>>14;S=(s*804|0)+8192+(z*-16364|0)|0;z=L+S>>14;s=(B*15893|0)+8192+(w*3981|0)|0;T=M+s>>14;U=(B*3981|0)+8192+(w*-15893|0)|0;w=N+U>>14;B=(v*14811|0)+8192+(E*7005|0)|0;V=O+B>>14;W=(v*7005|0)+8192+(E*-14811|0)|0;E=P+W>>14;v=(q*13160|0)+8192+(H*9760|0)|0;X=Q+v>>14;Y=(q*9760|0)+8192+(H*-13160|0)|0;H=R+Y>>14;q=I-K>>14;K=S-L>>14;L=s-M>>14;M=U-N>>14;N=B-O>>14;O=W-P>>14;P=v-Q>>14;Q=Y-R>>14;R=(O*16069|0)+(N*-3196|0)|0;Y=(O*3196|0)+(N*16069|0)|0;N=(Q*9102|0)+(P*-13623|0)|0;O=(Q*13623|0)+(P*9102|0)|0;P=V+J|0;Q=E+z|0;v=X+T|0;W=H+w|0;B=J-V|0;V=z-E|0;E=T-X|0;X=w-H|0;H=(K*3196|0)+8192+(q*16069|0)|0;w=R+H>>14;T=(K*-16069|0)+8192+(q*3196|0)|0;q=Y+T>>14;K=(M*13623|0)+8192+(L*9102|0)|0;z=N+K>>14;J=(M*-9102|0)+8192+(L*13623|0)|0;L=O+J>>14;M=H-R>>14;R=T-Y>>14;Y=K-N>>14;N=J-O>>14;O=(X*15137|0)+(E*-6270|0)|0;J=(X*6270|0)+(E*15137|0)|0;E=(N*15137|0)+(Y*-6270|0)|0;X=(N*6270|0)+(Y*15137|0)|0;Y=v+P&65535;b[f>>1]=Y;b[k>>1]=-(Q+W|0);N=P-v|0;v=Q-W|0;W=(V*6270|0)+8192+(B*15137|0)|0;b[u>>1]=-((O+W|0)>>>14);Q=(V*-15137|0)+8192+(B*6270|0)|0;b[C>>1]=(J+Q|0)>>>14;B=W-O>>14;O=Q-J>>14;b[l>>1]=-(w+z|0);b[o>>1]=L+q;J=w-z|0;z=q-L|0;L=(R*6270|0)+8192+(M*15137|0)|0;b[y>>1]=(E+L|0)>>>14;q=(R*-15137|0)+8192+(M*6270|0)|0;b[A>>1]=-((X+q|0)>>>14);M=L-E>>14;E=q-X>>14;b[p>>1]=(((N+v|0)*-11585|0)+8192|0)>>>14;b[t>>1]=(((N-v|0)*11585|0)+8192|0)>>>14;b[F>>1]=(((O+B|0)*11585|0)+8192|0)>>>14;b[n>>1]=(((O-B|0)*11585|0)+8192|0)>>>14;b[G>>1]=(((z+J|0)*11585|0)+8192|0)>>>14;b[D>>1]=(((z-J|0)*11585|0)+8192|0)>>>14;b[r>>1]=(((M+E|0)*-11585|0)+8192|0)>>>14;b[m>>1]=(((M-E|0)*11585|0)+8192|0)>>>14;E=0;M=Y;while(1){Y=x+(ba(E,e)|0)|0;J=((M<<16>>16)+32>>6)+(d[Y]|0)|0;if(J>>>0>255>>>0){Z=-J>>31&255}else{Z=J&255}a[Y]=Z;Y=E+1|0;if((Y|0)>=16){break}E=Y;M=b[j+(Y<<1)>>1]|0}M=c+1|0;if((M|0)<16){x=x+1|0;c=M}else{break}}i=g;return}function Z9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;g=i;i=i+544|0;h=g|0;j=g+512|0;k=0;do{l=k<<4;m=b[f+(k+240<<1)>>1]|0;n=b[f+(k<<1)>>1]|0;o=b[f+(k+208<<1)>>1]|0;p=b[f+(k+32<<1)>>1]|0;q=b[f+(k+176<<1)>>1]|0;r=b[f+(k+64<<1)>>1]|0;s=b[f+(k+144<<1)>>1]|0;t=b[f+(k+96<<1)>>1]|0;u=b[f+(k+112<<1)>>1]|0;v=b[f+(k+128<<1)>>1]|0;w=(v*12140|0)+(u*11003|0)|0;x=(v*-11003|0)+(u*12140|0)|0;u=b[f+(k+80<<1)>>1]|0;v=b[f+(k+160<<1)>>1]|0;y=(v*14053|0)+(u*8423|0)|0;z=(v*-8423|0)+(u*14053|0)|0;u=b[f+(k+48<<1)>>1]|0;v=b[f+(k+192<<1)>>1]|0;A=(v*15426|0)+(u*5520|0)|0;B=(v*-5520|0)+(u*15426|0)|0;u=b[f+(k+16<<1)>>1]|0;v=b[f+(k+224<<1)>>1]|0;C=(v*16207|0)+(u*2404|0)|0;D=(v*-2404|0)+(u*16207|0)|0;u=(m*16364|0)+8192+(n*804|0)|0;v=w+u>>14;E=(m*804|0)+8192+(n*-16364|0)|0;n=x+E>>14;m=(o*15893|0)+8192+(p*3981|0)|0;F=y+m>>14;G=(o*3981|0)+8192+(p*-15893|0)|0;p=z+G>>14;o=(q*14811|0)+8192+(r*7005|0)|0;H=A+o>>14;I=(q*7005|0)+8192+(r*-14811|0)|0;r=B+I>>14;q=(s*13160|0)+8192+(t*9760|0)|0;J=C+q>>14;K=(s*9760|0)+8192+(t*-13160|0)|0;t=D+K>>14;s=u-w>>14;w=E-x>>14;x=m-y>>14;y=G-z>>14;z=o-A>>14;A=I-B>>14;B=q-C>>14;C=K-D>>14;D=(A*16069|0)+(z*-3196|0)|0;K=(A*3196|0)+(z*16069|0)|0;z=(C*9102|0)+(B*-13623|0)|0;A=(C*13623|0)+(B*9102|0)|0;B=H+v|0;C=r+n|0;q=J+F|0;I=t+p|0;o=v-H|0;H=n-r|0;r=F-J|0;J=p-t|0;t=(w*3196|0)+8192+(s*16069|0)|0;p=D+t>>14;F=(w*-16069|0)+8192+(s*3196|0)|0;s=K+F>>14;w=(y*13623|0)+8192+(x*9102|0)|0;n=z+w>>14;v=(y*-9102|0)+8192+(x*13623|0)|0;x=A+v>>14;y=t-D>>14;D=F-K>>14;K=w-z>>14;z=v-A>>14;A=(J*15137|0)+(r*-6270|0)|0;v=(J*6270|0)+(r*15137|0)|0;r=(z*15137|0)+(K*-6270|0)|0;J=(z*6270|0)+(K*15137|0)|0;b[h+(l<<1)>>1]=q+B;b[h+((l|15)<<1)>>1]=-(C+I|0);K=B-q|0;q=C-I|0;I=(H*6270|0)+8192+(o*15137|0)|0;b[h+((l|3)<<1)>>1]=-((A+I|0)>>>14);C=(H*-15137|0)+8192+(o*6270|0)|0;b[h+((l|12)<<1)>>1]=(v+C|0)>>>14;o=I-A>>14;A=C-v>>14;b[h+((l|1)<<1)>>1]=-(p+n|0);b[h+((l|14)<<1)>>1]=x+s;v=p-n|0;n=s-x|0;x=(D*6270|0)+8192+(y*15137|0)|0;b[h+((l|2)<<1)>>1]=(r+x|0)>>>14;s=(D*-15137|0)+8192+(y*6270|0)|0;b[h+((l|13)<<1)>>1]=-((J+s|0)>>>14);y=x-r>>14;r=s-J>>14;b[h+((l|7)<<1)>>1]=(((K+q|0)*-11585|0)+8192|0)>>>14;b[h+((l|8)<<1)>>1]=(((K-q|0)*11585|0)+8192|0)>>>14;b[h+((l|4)<<1)>>1]=(((A+o|0)*11585|0)+8192|0)>>>14;b[h+((l|11)<<1)>>1]=(((A-o|0)*11585|0)+8192|0)>>>14;b[h+((l|6)<<1)>>1]=(((n+v|0)*11585|0)+8192|0)>>>14;b[h+((l|9)<<1)>>1]=(((n-v|0)*11585|0)+8192|0)>>>14;b[h+((l|5)<<1)>>1]=(((y+r|0)*-11585|0)+8192|0)>>>14;b[h+((l|10)<<1)>>1]=(((y-r|0)*11585|0)+8192|0)>>>14;k=k+1|0;}while((k|0)<16);TGb(f|0,0,512)|0;f=j|0;k=j+30|0;r=j+6|0;y=j+24|0;l=j+2|0;v=j+28|0;n=j+4|0;o=j+26|0;A=j+14|0;q=j+16|0;K=j+8|0;J=j+22|0;s=j+12|0;x=j+18|0;D=j+10|0;p=j+20|0;C=c;c=0;while(1){I=b[h+(c+240<<1)>>1]|0;H=b[h+(c<<1)>>1]|0;B=b[h+(c+208<<1)>>1]|0;z=b[h+(c+32<<1)>>1]|0;w=b[h+(c+176<<1)>>1]|0;F=b[h+(c+64<<1)>>1]|0;t=b[h+(c+144<<1)>>1]|0;G=b[h+(c+96<<1)>>1]|0;m=b[h+(c+112<<1)>>1]|0;E=b[h+(c+128<<1)>>1]|0;u=(E*12140|0)+(m*11003|0)|0;L=(E*-11003|0)+(m*12140|0)|0;m=b[h+(c+80<<1)>>1]|0;E=b[h+(c+160<<1)>>1]|0;M=(E*14053|0)+(m*8423|0)|0;N=(E*-8423|0)+(m*14053|0)|0;m=b[h+(c+48<<1)>>1]|0;E=b[h+(c+192<<1)>>1]|0;O=(E*15426|0)+(m*5520|0)|0;P=(E*-5520|0)+(m*15426|0)|0;m=b[h+(c+16<<1)>>1]|0;E=b[h+(c+224<<1)>>1]|0;Q=(E*16207|0)+(m*2404|0)|0;R=(E*-2404|0)+(m*16207|0)|0;m=(I*16364|0)+8192+(H*804|0)|0;E=u+m>>14;S=(I*804|0)+8192+(H*-16364|0)|0;H=L+S>>14;I=(B*15893|0)+8192+(z*3981|0)|0;T=M+I>>14;U=(B*3981|0)+8192+(z*-15893|0)|0;z=N+U>>14;B=(w*14811|0)+8192+(F*7005|0)|0;V=O+B>>14;W=(w*7005|0)+8192+(F*-14811|0)|0;F=P+W>>14;w=(t*13160|0)+8192+(G*9760|0)|0;X=Q+w>>14;Y=(t*9760|0)+8192+(G*-13160|0)|0;G=R+Y>>14;t=m-u>>14;u=S-L>>14;L=I-M>>14;M=U-N>>14;N=B-O>>14;O=W-P>>14;P=w-Q>>14;Q=Y-R>>14;R=(O*16069|0)+(N*-3196|0)|0;Y=(O*3196|0)+(N*16069|0)|0;N=(Q*9102|0)+(P*-13623|0)|0;O=(Q*13623|0)+(P*9102|0)|0;P=V+E|0;Q=F+H|0;w=X+T|0;W=G+z|0;B=E-V|0;V=H-F|0;F=T-X|0;X=z-G|0;G=(u*3196|0)+8192+(t*16069|0)|0;z=R+G>>14;T=(u*-16069|0)+8192+(t*3196|0)|0;t=Y+T>>14;u=(M*13623|0)+8192+(L*9102|0)|0;H=N+u>>14;E=(M*-9102|0)+8192+(L*13623|0)|0;L=O+E>>14;M=G-R>>14;R=T-Y>>14;Y=u-N>>14;N=E-O>>14;O=(X*15137|0)+(F*-6270|0)|0;E=(X*6270|0)+(F*15137|0)|0;F=(N*15137|0)+(Y*-6270|0)|0;X=(N*6270|0)+(Y*15137|0)|0;Y=w+P&65535;b[f>>1]=Y;b[k>>1]=-(Q+W|0);N=P-w|0;w=Q-W|0;W=(V*6270|0)+8192+(B*15137|0)|0;b[r>>1]=-((O+W|0)>>>14);Q=(V*-15137|0)+8192+(B*6270|0)|0;b[y>>1]=(E+Q|0)>>>14;B=W-O>>14;O=Q-E>>14;b[l>>1]=-(z+H|0);b[v>>1]=L+t;E=z-H|0;H=t-L|0;L=(R*6270|0)+8192+(M*15137|0)|0;b[n>>1]=(F+L|0)>>>14;t=(R*-15137|0)+8192+(M*6270|0)|0;b[o>>1]=-((X+t|0)>>>14);M=L-F>>14;F=t-X>>14;b[A>>1]=(((N+w|0)*-11585|0)+8192|0)>>>14;b[q>>1]=(((N-w|0)*11585|0)+8192|0)>>>14;b[K>>1]=(((O+B|0)*11585|0)+8192|0)>>>14;b[J>>1]=(((O-B|0)*11585|0)+8192|0)>>>14;b[s>>1]=(((H+E|0)*11585|0)+8192|0)>>>14;b[x>>1]=(((H-E|0)*11585|0)+8192|0)>>>14;b[D>>1]=(((M+F|0)*-11585|0)+8192|0)>>>14;b[p>>1]=(((M-F|0)*11585|0)+8192|0)>>>14;F=0;M=Y;while(1){Y=C+(ba(F,e)|0)|0;E=((M<<16>>16)+32>>6)+(d[Y]|0)|0;if(E>>>0>255>>>0){Z=-E>>31&255}else{Z=E&255}a[Y]=Z;Y=F+1|0;if((Y|0)>=16){break}F=Y;M=b[j+(Y<<1)>>1]|0}M=c+1|0;if((M|0)<16){C=C+1|0;c=M}else{break}}i=g;return}function _9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;h=i;i=i+2112|0;j=h|0;k=h+2048|0;if((g|0)==1){g=((((b[f>>1]|0)*11585|0)+8192>>14)*11585|0)+8192>>14;b[f>>1]=0;l=g+32>>6;g=0;m=c;while(1){n=0;do{o=m+(ba(n,e)|0)|0;p=(d[o]|0)+l|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[o]=q;n=n+1|0;}while((n|0)<32);n=g+1|0;if((n|0)<32){g=n;m=m+1|0}else{break}}i=h;return}else{r=0}do{m=r<<5;g=b[f+(r<<1)>>1]|0;q=b[f+(r+512<<1)>>1]|0;l=((q+g|0)*11585|0)+8192>>14;n=((g-q|0)*11585|0)+8192>>14;q=b[f+(r+256<<1)>>1]|0;g=b[f+(r+768<<1)>>1]|0;o=(q*6270|0)+8192+(g*-15137|0)>>14;p=(q*15137|0)+8192+(g*6270|0)>>14;g=b[f+(r+128<<1)>>1]|0;q=b[f+(r+896<<1)>>1]|0;s=(g*3196|0)+8192+(q*-16069|0)>>14;t=(g*16069|0)+8192+(q*3196|0)>>14;q=b[f+(r+640<<1)>>1]|0;g=b[f+(r+384<<1)>>1]|0;u=(q*13623|0)+8192+(g*-9102|0)>>14;v=(q*9102|0)+8192+(g*13623|0)>>14;g=b[f+(r+64<<1)>>1]|0;q=b[f+(r+960<<1)>>1]|0;w=(g*1606|0)+8192+(q*-16305|0)>>14;x=(g*16305|0)+8192+(q*1606|0)>>14;q=b[f+(r+576<<1)>>1]|0;g=b[f+(r+448<<1)>>1]|0;y=(q*12665|0)+8192+(g*-10394|0)>>14;z=(q*10394|0)+8192+(g*12665|0)>>14;g=b[f+(r+320<<1)>>1]|0;q=b[f+(r+704<<1)>>1]|0;A=(g*7723|0)+8192+(q*-14449|0)>>14;B=(g*14449|0)+8192+(q*7723|0)>>14;q=b[f+(r+832<<1)>>1]|0;g=b[f+(r+192<<1)>>1]|0;C=(q*15679|0)+8192+(g*-4756|0)>>14;D=(q*4756|0)+8192+(g*15679|0)>>14;g=b[f+(r+32<<1)>>1]|0;q=b[f+(r+992<<1)>>1]|0;E=(g*804|0)+8192+(q*-16364|0)>>14;F=(g*16364|0)+8192+(q*804|0)>>14;q=b[f+(r+544<<1)>>1]|0;g=b[f+(r+480<<1)>>1]|0;G=(q*12140|0)+8192+(g*-11003|0)>>14;H=(q*11003|0)+8192+(g*12140|0)>>14;g=b[f+(r+288<<1)>>1]|0;q=b[f+(r+736<<1)>>1]|0;I=(g*7005|0)+8192+(q*-14811|0)>>14;J=(g*14811|0)+8192+(q*7005|0)>>14;q=b[f+(r+800<<1)>>1]|0;g=b[f+(r+224<<1)>>1]|0;K=(q*15426|0)+8192+(g*-5520|0)>>14;L=(q*5520|0)+8192+(g*15426|0)>>14;g=b[f+(r+160<<1)>>1]|0;q=b[f+(r+864<<1)>>1]|0;M=(g*3981|0)+8192+(q*-15893|0)>>14;N=(g*15893|0)+8192+(q*3981|0)>>14;q=b[f+(r+672<<1)>>1]|0;g=b[f+(r+352<<1)>>1]|0;O=(q*14053|0)+8192+(g*-8423|0)>>14;P=(q*8423|0)+8192+(g*14053|0)>>14;g=b[f+(r+416<<1)>>1]|0;q=b[f+(r+608<<1)>>1]|0;Q=(g*9760|0)+8192+(q*-13160|0)>>14;R=(g*13160|0)+8192+(q*9760|0)>>14;q=b[f+(r+928<<1)>>1]|0;g=b[f+(r+96<<1)>>1]|0;S=(q*16207|0)+8192+(g*-2404|0)>>14;T=(q*2404|0)+8192+(g*16207|0)>>14;g=p+l|0;q=o+n|0;U=n-o|0;o=l-p|0;p=u+s|0;l=s-u|0;u=t-v|0;s=v+t|0;t=y+w|0;v=w-y|0;y=C-A|0;w=C+A|0;A=D+B|0;C=D-B|0;B=x-z|0;D=z+x|0;x=G+E|0;z=E-G|0;G=K-I|0;E=K+I|0;I=O+M|0;K=M-O|0;O=S-Q|0;M=S+Q|0;Q=T+R|0;S=T-R|0;R=N-P|0;T=P+N|0;N=L+J|0;P=L-J|0;J=F-H|0;L=H+F|0;F=((u-l|0)*11585|0)+8192>>14;H=((u+l|0)*11585|0)+8192>>14;l=(v*-15137|0)+8192+(B*6270|0)>>14;u=(v*6270|0)+8192+(B*15137|0)>>14;B=(y*-6270|0)+8192+(C*-15137|0)>>14;v=(y*-15137|0)+8192+(C*6270|0)>>14;C=(z*-16069|0)+8192+(J*3196|0)>>14;y=(z*3196|0)+8192+(J*16069|0)>>14;J=(G*-3196|0)+8192+(P*-16069|0)>>14;z=(G*-16069|0)+8192+(P*3196|0)>>14;P=(K*-9102|0)+8192+(R*13623|0)>>14;G=(K*13623|0)+8192+(R*9102|0)>>14;R=(O*-13623|0)+8192+(S*-9102|0)>>14;K=(O*-9102|0)+8192+(S*13623|0)>>14;S=s+g|0;O=H+q|0;n=F+U|0;V=p+o|0;W=o-p|0;p=U-F|0;F=q-H|0;H=g-s|0;s=w+t|0;g=B+l|0;q=l-B|0;B=t-w|0;w=D-A|0;t=u-v|0;l=v+u|0;u=A+D|0;D=E+x|0;A=J+C|0;v=C-J|0;J=x-E|0;E=M-I|0;x=R-P|0;C=R+P|0;P=M+I|0;I=Q+T|0;M=K+G|0;R=K-G|0;G=Q-T|0;T=L-N|0;Q=y-z|0;K=z+y|0;y=N+L|0;L=((t-q|0)*11585|0)+8192>>14;N=((t+q|0)*11585|0)+8192>>14;q=((w-B|0)*11585|0)+8192>>14;t=((w+B|0)*11585|0)+8192>>14;B=(v*-15137|0)+8192+(Q*6270|0)>>14;w=(v*6270|0)+8192+(Q*15137|0)>>14;Q=(J*-15137|0)+8192+(T*6270|0)>>14;v=(J*6270|0)+8192+(T*15137|0)>>14;T=(E*-6270|0)+8192+(G*-15137|0)>>14;J=(E*-15137|0)+8192+(G*6270|0)>>14;G=(x*-6270|0)+8192+(R*-15137|0)>>14;E=(x*-15137|0)+8192+(R*6270|0)>>14;R=u+S|0;x=l+O|0;z=N+n|0;U=t+V|0;o=q+W|0;X=L+p|0;Y=g+F|0;Z=s+H|0;_=H-s|0;s=F-g|0;g=p-L|0;L=W-q|0;q=V-t|0;t=n-N|0;N=O-l|0;l=S-u|0;u=P+D|0;S=C+A|0;O=G+B|0;n=T+Q|0;V=Q-T|0;T=B-G|0;G=A-C|0;C=D-P|0;P=y-I|0;D=K-M|0;A=w-E|0;B=v-J|0;Q=J+v|0;v=E+w|0;w=M+K|0;K=I+y|0;y=((B-V|0)*11585|0)+8192>>14;I=((B+V|0)*11585|0)+8192>>14;V=((A-T|0)*11585|0)+8192>>14;B=((A+T|0)*11585|0)+8192>>14;T=((D-G|0)*11585|0)+8192>>14;A=((D+G|0)*11585|0)+8192>>14;G=((P-C|0)*11585|0)+8192>>14;D=((P+C|0)*11585|0)+8192>>14;b[j+(m<<1)>>1]=K+R;b[j+((m|1)<<1)>>1]=w+x;b[j+((m|2)<<1)>>1]=v+z;b[j+((m|3)<<1)>>1]=Q+U;b[j+((m|4)<<1)>>1]=I+o;b[j+((m|5)<<1)>>1]=B+X;b[j+((m|6)<<1)>>1]=A+Y;b[j+((m|7)<<1)>>1]=D+Z;b[j+((m|8)<<1)>>1]=G+_;b[j+((m|9)<<1)>>1]=T+s;b[j+((m|10)<<1)>>1]=V+g;b[j+((m|11)<<1)>>1]=y+L;b[j+((m|12)<<1)>>1]=n+q;b[j+((m|13)<<1)>>1]=O+t;b[j+((m|14)<<1)>>1]=S+N;b[j+((m|15)<<1)>>1]=u+l;b[j+((m|16)<<1)>>1]=l-u;b[j+((m|17)<<1)>>1]=N-S;b[j+((m|18)<<1)>>1]=t-O;b[j+((m|19)<<1)>>1]=q-n;b[j+((m|20)<<1)>>1]=L-y;b[j+((m|21)<<1)>>1]=g-V;b[j+((m|22)<<1)>>1]=s-T;b[j+((m|23)<<1)>>1]=_-G;b[j+((m|24)<<1)>>1]=Z-D;b[j+((m|25)<<1)>>1]=Y-A;b[j+((m|26)<<1)>>1]=X-B;b[j+((m|27)<<1)>>1]=o-I;b[j+((m|28)<<1)>>1]=U-Q;b[j+((m|29)<<1)>>1]=z-v;b[j+((m|30)<<1)>>1]=x-w;b[j+((m|31)<<1)>>1]=R-K;r=r+1|0;}while((r|0)<32);TGb(f|0,0,2048)|0;f=k|0;r=k+2|0;K=k+4|0;R=k+6|0;m=k+8|0;w=k+10|0;x=k+12|0;v=k+14|0;z=k+16|0;Q=k+18|0;U=k+20|0;I=k+22|0;o=k+24|0;B=k+26|0;X=k+28|0;A=k+30|0;Y=k+32|0;D=k+34|0;Z=k+36|0;G=k+38|0;_=k+40|0;T=k+42|0;s=k+44|0;V=k+46|0;g=k+48|0;y=k+50|0;L=k+52|0;n=k+54|0;q=k+56|0;O=k+58|0;t=k+60|0;S=k+62|0;N=0;u=c;while(1){c=b[j+(N<<1)>>1]|0;l=b[j+(N+512<<1)>>1]|0;C=((l+c|0)*11585|0)+8192>>14;P=((c-l|0)*11585|0)+8192>>14;l=b[j+(N+256<<1)>>1]|0;c=b[j+(N+768<<1)>>1]|0;M=(l*6270|0)+8192+(c*-15137|0)>>14;E=(l*15137|0)+8192+(c*6270|0)>>14;c=b[j+(N+128<<1)>>1]|0;l=b[j+(N+896<<1)>>1]|0;J=(c*3196|0)+8192+(l*-16069|0)>>14;W=(c*16069|0)+8192+(l*3196|0)>>14;l=b[j+(N+640<<1)>>1]|0;c=b[j+(N+384<<1)>>1]|0;p=(l*13623|0)+8192+(c*-9102|0)>>14;F=(l*9102|0)+8192+(c*13623|0)>>14;c=b[j+(N+64<<1)>>1]|0;l=b[j+(N+960<<1)>>1]|0;H=(c*1606|0)+8192+(l*-16305|0)>>14;$=(c*16305|0)+8192+(l*1606|0)>>14;l=b[j+(N+576<<1)>>1]|0;c=b[j+(N+448<<1)>>1]|0;aa=(l*12665|0)+8192+(c*-10394|0)>>14;ca=(l*10394|0)+8192+(c*12665|0)>>14;c=b[j+(N+320<<1)>>1]|0;l=b[j+(N+704<<1)>>1]|0;da=(c*7723|0)+8192+(l*-14449|0)>>14;ea=(c*14449|0)+8192+(l*7723|0)>>14;l=b[j+(N+832<<1)>>1]|0;c=b[j+(N+192<<1)>>1]|0;fa=(l*15679|0)+8192+(c*-4756|0)>>14;ga=(l*4756|0)+8192+(c*15679|0)>>14;c=b[j+(N+32<<1)>>1]|0;l=b[j+(N+992<<1)>>1]|0;ha=(c*804|0)+8192+(l*-16364|0)>>14;ia=(c*16364|0)+8192+(l*804|0)>>14;l=b[j+(N+544<<1)>>1]|0;c=b[j+(N+480<<1)>>1]|0;ja=(l*12140|0)+8192+(c*-11003|0)>>14;ka=(l*11003|0)+8192+(c*12140|0)>>14;c=b[j+(N+288<<1)>>1]|0;l=b[j+(N+736<<1)>>1]|0;la=(c*7005|0)+8192+(l*-14811|0)>>14;ma=(c*14811|0)+8192+(l*7005|0)>>14;l=b[j+(N+800<<1)>>1]|0;c=b[j+(N+224<<1)>>1]|0;na=(l*15426|0)+8192+(c*-5520|0)>>14;oa=(l*5520|0)+8192+(c*15426|0)>>14;c=b[j+(N+160<<1)>>1]|0;l=b[j+(N+864<<1)>>1]|0;pa=(c*3981|0)+8192+(l*-15893|0)>>14;qa=(c*15893|0)+8192+(l*3981|0)>>14;l=b[j+(N+672<<1)>>1]|0;c=b[j+(N+352<<1)>>1]|0;ra=(l*14053|0)+8192+(c*-8423|0)>>14;sa=(l*8423|0)+8192+(c*14053|0)>>14;c=b[j+(N+416<<1)>>1]|0;l=b[j+(N+608<<1)>>1]|0;ta=(c*9760|0)+8192+(l*-13160|0)>>14;ua=(c*13160|0)+8192+(l*9760|0)>>14;l=b[j+(N+928<<1)>>1]|0;c=b[j+(N+96<<1)>>1]|0;va=(l*16207|0)+8192+(c*-2404|0)>>14;wa=(l*2404|0)+8192+(c*16207|0)>>14;c=E+C|0;l=M+P|0;xa=P-M|0;M=C-E|0;E=p+J|0;C=J-p|0;p=W-F|0;J=F+W|0;W=aa+H|0;F=H-aa|0;aa=fa-da|0;H=fa+da|0;da=ga+ea|0;fa=ga-ea|0;ea=$-ca|0;ga=ca+$|0;$=ja+ha|0;ca=ha-ja|0;ja=na-la|0;ha=na+la|0;la=ra+pa|0;na=pa-ra|0;ra=va-ta|0;pa=va+ta|0;ta=wa+ua|0;va=wa-ua|0;ua=qa-sa|0;wa=sa+qa|0;qa=oa+ma|0;sa=oa-ma|0;ma=ia-ka|0;oa=ka+ia|0;ia=((p-C|0)*11585|0)+8192>>14;ka=((p+C|0)*11585|0)+8192>>14;C=(F*-15137|0)+8192+(ea*6270|0)>>14;p=(F*6270|0)+8192+(ea*15137|0)>>14;ea=(aa*-6270|0)+8192+(fa*-15137|0)>>14;F=(aa*-15137|0)+8192+(fa*6270|0)>>14;fa=(ca*-16069|0)+8192+(ma*3196|0)>>14;aa=(ca*3196|0)+8192+(ma*16069|0)>>14;ma=(ja*-3196|0)+8192+(sa*-16069|0)>>14;ca=(ja*-16069|0)+8192+(sa*3196|0)>>14;sa=(na*-9102|0)+8192+(ua*13623|0)>>14;ja=(na*13623|0)+8192+(ua*9102|0)>>14;ua=(ra*-13623|0)+8192+(va*-9102|0)>>14;na=(ra*-9102|0)+8192+(va*13623|0)>>14;va=J+c|0;ra=ka+l|0;P=ia+xa|0;ya=E+M|0;za=M-E|0;E=xa-ia|0;ia=l-ka|0;ka=c-J|0;J=H+W|0;c=ea+C|0;l=C-ea|0;ea=W-H|0;H=ga-da|0;W=p-F|0;C=F+p|0;p=da+ga|0;ga=ha+$|0;da=ma+fa|0;F=fa-ma|0;ma=$-ha|0;ha=pa-la|0;$=ua-sa|0;fa=ua+sa|0;sa=pa+la|0;la=ta+wa|0;pa=na+ja|0;ua=na-ja|0;ja=ta-wa|0;wa=oa-qa|0;ta=aa-ca|0;na=ca+aa|0;aa=qa+oa|0;oa=((W-l|0)*11585|0)+8192>>14;qa=((W+l|0)*11585|0)+8192>>14;l=((H-ea|0)*11585|0)+8192>>14;W=((H+ea|0)*11585|0)+8192>>14;ea=(F*-15137|0)+8192+(ta*6270|0)>>14;H=(F*6270|0)+8192+(ta*15137|0)>>14;ta=(ma*-15137|0)+8192+(wa*6270|0)>>14;F=(ma*6270|0)+8192+(wa*15137|0)>>14;wa=(ha*-6270|0)+8192+(ja*-15137|0)>>14;ma=(ha*-15137|0)+8192+(ja*6270|0)>>14;ja=($*-6270|0)+8192+(ua*-15137|0)>>14;ha=($*-15137|0)+8192+(ua*6270|0)>>14;ua=p+va|0;$=C+ra|0;ca=qa+P|0;xa=W+ya|0;M=l+za|0;Aa=oa+E|0;Ba=c+ia|0;Ca=J+ka|0;Da=ka-J|0;J=ia-c|0;c=E-oa|0;oa=za-l|0;l=ya-W|0;W=P-qa|0;qa=ra-C|0;C=va-p|0;p=sa+ga|0;va=fa+da|0;ra=ja+ea|0;P=wa+ta|0;ya=ta-wa|0;wa=ea-ja|0;ja=da-fa|0;fa=ga-sa|0;sa=aa-la|0;ga=na-pa|0;da=H-ha|0;ea=F-ma|0;ta=ma+F|0;F=ha+H|0;H=pa+na|0;na=la+aa|0;aa=((ea-ya|0)*11585|0)+8192>>14;la=((ea+ya|0)*11585|0)+8192>>14;ya=((da-wa|0)*11585|0)+8192>>14;ea=((da+wa|0)*11585|0)+8192>>14;wa=((ga-ja|0)*11585|0)+8192>>14;da=((ga+ja|0)*11585|0)+8192>>14;ja=((sa-fa|0)*11585|0)+8192>>14;ga=((sa+fa|0)*11585|0)+8192>>14;fa=na+ua&65535;b[f>>1]=fa;b[r>>1]=H+$;b[K>>1]=F+ca;b[R>>1]=ta+xa;b[m>>1]=la+M;b[w>>1]=ea+Aa;b[x>>1]=da+Ba;b[v>>1]=ga+Ca;b[z>>1]=ja+Da;b[Q>>1]=wa+J;b[U>>1]=ya+c;b[I>>1]=aa+oa;b[o>>1]=P+l;b[B>>1]=ra+W;b[X>>1]=va+qa;b[A>>1]=p+C;b[Y>>1]=C-p;b[D>>1]=qa-va;b[Z>>1]=W-ra;b[G>>1]=l-P;b[_>>1]=oa-aa;b[T>>1]=c-ya;b[s>>1]=J-wa;b[V>>1]=Da-ja;b[g>>1]=Ca-ga;b[y>>1]=Ba-da;b[L>>1]=Aa-ea;b[n>>1]=M-la;b[q>>1]=xa-ta;b[O>>1]=ca-F;b[t>>1]=$-H;b[S>>1]=ua-na;na=0;ua=fa;while(1){fa=u+(ba(na,e)|0)|0;H=((ua<<16>>16)+32>>6)+(d[fa]|0)|0;if(H>>>0>255>>>0){Ea=-H>>31&255}else{Ea=H&255}a[fa]=Ea;fa=na+1|0;if((fa|0)>=32){break}na=fa;ua=b[k+(fa<<1)>>1]|0}ua=N+1|0;if((ua|0)<32){N=ua;u=u+1|0}else{break}}i=h;return}function $9a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+40|0;h=g|0;j=g+32|0;k=0;do{l=k<<2;m=b[f+(k+12<<1)>>1]>>2;n=b[f+(k+4<<1)>>1]>>2;o=n+(b[f+(k<<1)>>1]>>2)|0;p=(b[f+(k+8<<1)>>1]>>2)-m|0;q=o-p>>1;r=q-m|0;m=q-n|0;b[h+(l<<1)>>1]=o-r;b[h+((l|1)<<1)>>1]=r;b[h+((l|2)<<1)>>1]=m;b[h+((l|3)<<1)>>1]=m+p;k=k+1|0;}while((k|0)<4);TGb(f|0,0,32)|0;f=j|0;k=j+2|0;p=j+4|0;m=j+6|0;j=c;c=0;while(1){l=b[h+(c+12<<1)>>1]|0;r=b[h+(c+4<<1)>>1]|0;o=r+(b[h+(c<<1)>>1]|0)|0;n=(b[h+(c+8<<1)>>1]|0)-l|0;q=o-n>>1;s=q-l|0;l=q-r|0;r=o-s&65535;b[f>>1]=r;b[k>>1]=s;b[p>>1]=l;b[m>>1]=l+n;n=(r<<16>>16)+(d[j]|0)|0;if(n>>>0>255>>>0){t=-n>>31&255}else{t=n&255}a[j]=t;n=j+e|0;r=(b[k>>1]|0)+(d[n]|0)|0;if(r>>>0>255>>>0){u=-r>>31&255}else{u=r&255}a[n]=u;n=j+(e<<1)|0;r=(b[p>>1]|0)+(d[n]|0)|0;if(r>>>0>255>>>0){v=-r>>31&255}else{v=r&255}a[n]=v;n=j+(e*3|0)|0;r=(b[m>>1]|0)+(d[n]|0)|0;if(r>>>0>255>>>0){w=-r>>31&255}else{w=r&255}a[n]=w;n=c+1|0;if((n|0)<4){j=j+1|0;c=n}else{break}}i=g;return}function aab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=c[e>>2]|0;c[a>>2]=d;c[a+b>>2]=d;c[a+(b<<1)>>2]=d;c[a+(b*3|0)>>2]=d;return}function bab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;c[a>>2]=ba(d[e+3|0]|0,16843009)|0;c[a+b>>2]=ba(d[e+2|0]|0,16843009)|0;c[a+(b<<1)>>2]=ba(d[e+1|0]|0,16843009)|0;c[a+(b*3|0)>>2]=ba(d[e]|0,16843009)|0;return}function cab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;g=ba((d[e]|0)+4+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[f]|0)+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)>>3,16843009)|0;c[a>>2]=g;c[a+b>>2]=g;c[a+(b<<1)>>2]=g;c[a+(b*3|0)>>2]=g;return}function dab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;e=d[f+1|0]|0;g=d[f+2|0]|0;h=d[f+3|0]|0;i=d[f+4|0]|0;j=d[f+5|0]|0;k=d[f+6|0]|0;l=a[f+7|0]|0;a[b]=((d[f]|0)+2+(e<<1)+g|0)>>>2;f=(e+2+(g<<1)+h|0)>>>2&255;a[b+c|0]=f;a[b+1|0]=f;f=(g+2+(h<<1)+i|0)>>>2&255;g=c<<1;a[b+g|0]=f;a[b+(c+1)|0]=f;a[b+2|0]=f;f=(h+2+(i<<1)+j|0)>>>2&255;h=c*3|0;a[b+h|0]=f;a[b+(g|1)|0]=f;a[b+(c+2)|0]=f;a[b+3|0]=f;f=(i+2+(j<<1)+k|0)>>>2&255;a[b+(h+1)|0]=f;a[b+(g+2)|0]=f;a[b+(c+3)|0]=f;f=(j+2+(k<<1)+(l&255)|0)>>>2&255;a[b+(h+2)|0]=f;a[b+(g+3)|0]=f;a[b+(h+3)|0]=l;return}function eab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=d[f-1|0]|0;h=d[f]|0;i=d[f+1|0]|0;j=d[f+2|0]|0;k=d[f+3|0]|0;f=d[e+3|0]|0;l=d[e+2|0]|0;m=d[e+1|0]|0;n=c*3|0;a[b+n|0]=(l+2+(m<<1)+(d[e]|0)|0)>>>2;e=(f+2+(l<<1)+m|0)>>>2&255;a[b+(n+1)|0]=e;m=c<<1;a[b+m|0]=e;e=g+2|0;o=(e+(f<<1)+l|0)>>>2&255;a[b+(n+2)|0]=o;a[b+(m|1)|0]=o;a[b+c|0]=o;o=((g<<1)+2+h+f|0)>>>2&255;a[b+(n+3)|0]=o;a[b+(m+2)|0]=o;a[b+(c+1)|0]=o;a[b]=o;o=(e+(h<<1)+i|0)>>>2&255;a[b+(m+3)|0]=o;a[b+(c+2)|0]=o;a[b+1|0]=o;o=(h+2+(i<<1)+j|0)>>>2&255;a[b+(c+3)|0]=o;a[b+2|0]=o;a[b+3|0]=(i+2+(j<<1)+k|0)>>>2;return}function fab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=d[f-1|0]|0;h=d[f]|0;i=d[f+1|0]|0;j=d[f+2|0]|0;k=d[f+3|0]|0;f=d[e+3|0]|0;l=d[e+2|0]|0;m=c*3|0;a[b+m|0]=(f+2+(l<<1)+(d[e+1|0]|0)|0)>>>2;e=g+2|0;n=c<<1;a[b+n|0]=(e+(f<<1)+l|0)>>>2;l=(g+1+h|0)>>>1&255;a[b+(n|1)|0]=l;a[b]=l;l=((g<<1)+2+h+f|0)>>>2&255;a[b+(m+1)|0]=l;a[b+c|0]=l;l=(h+1+i|0)>>>1&255;a[b+(n+2)|0]=l;a[b+1|0]=l;l=(e+(h<<1)+i|0)>>>2&255;a[b+(m+2)|0]=l;a[b+(c+1)|0]=l;l=(i+1+j|0)>>>1&255;a[b+(n+3)|0]=l;a[b+2|0]=l;l=(h+2+(i<<1)+j|0)>>>2&255;a[b+(m+3)|0]=l;a[b+(c+2)|0]=l;a[b+3|0]=(j+1+k|0)>>>1;a[b+(c+3)|0]=(i+2+(j<<1)+k|0)>>>2;return}function gab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d[e+3|0]|0;h=d[e+2|0]|0;i=d[e+1|0]|0;j=d[e]|0;e=d[f-1|0]|0;k=d[f]|0;l=d[f+1|0]|0;m=d[f+2|0]|0;a[b+2|0]=(e+2+(k<<1)+l|0)>>>2;a[b+3|0]=(k+2+(l<<1)+m|0)>>>2;m=g+1|0;l=(m+e|0)>>>1&255;a[b+(c+2)|0]=l;a[b]=l;l=g+2|0;f=(l+(e<<1)+k|0)>>>2&255;a[b+(c+3)|0]=f;a[b+1|0]=f;f=(m+h|0)>>>1&255;m=c<<1;a[b+(m+2)|0]=f;a[b+c|0]=f;f=((g<<1)+2+h+e|0)>>>2&255;a[b+(m+3)|0]=f;a[b+(c+1)|0]=f;f=(h+1+i|0)>>>1&255;e=c*3|0;a[b+(e+2)|0]=f;a[b+m|0]=f;f=(l+(h<<1)+i|0)>>>2&255;a[b+(e+3)|0]=f;a[b+(m|1)|0]=f;a[b+e|0]=(i+1+j|0)>>>1;a[b+(e+1)|0]=(h+2+(i<<1)+j|0)>>>2;return}function hab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;e=d[f]|0;g=d[f+1|0]|0;h=d[f+2|0]|0;i=d[f+3|0]|0;j=d[f+4|0]|0;k=d[f+5|0]|0;l=d[f+6|0]|0;a[b]=(e+1+g|0)>>>1;a[b+c|0]=(e+2+(g<<1)+h|0)>>>2;e=(g+1+h|0)>>>1&255;f=c<<1;a[b+f|0]=e;a[b+1|0]=e;e=(g+2+(h<<1)+i|0)>>>2&255;g=c*3|0;a[b+g|0]=e;a[b+(c+1)|0]=e;e=(h+1+i|0)>>>1&255;a[b+(f|1)|0]=e;a[b+2|0]=e;e=(h+2+(i<<1)+j|0)>>>2&255;a[b+(g+1)|0]=e;a[b+(c+2)|0]=e;e=(i+1+j|0)>>>1&255;a[b+(f+2)|0]=e;a[b+3|0]=e;e=(i+2+(j<<1)+k|0)>>>2&255;a[b+(g+2)|0]=e;a[b+(c+3)|0]=e;a[b+(f+3)|0]=(j+1+k|0)>>>1;a[b+(g+3)|0]=(j+2+(k<<1)+l|0)>>>2;return}function iab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0;f=d[e+3|0]|0;g=d[e+2|0]|0;h=d[e+1|0]|0;i=a[e]|0;e=i&255;a[b]=(f+1+g|0)>>>1;a[b+1|0]=(f+2+(g<<1)+h|0)>>>2;f=(g+1+h|0)>>>1&255;a[b+2|0]=f;a[b+c|0]=f;f=(g+2+(h<<1)+e|0)>>>2&255;a[b+3|0]=f;a[b+(c+1)|0]=f;f=(h+1+e|0)>>>1&255;a[b+(c+2)|0]=f;g=c<<1;a[b+g|0]=f;f=(h+2+(e*3|0)|0)>>>2&255;a[b+(c+3)|0]=f;a[b+(g|1)|0]=f;f=c*3|0;a[b+(f+3)|0]=i;a[b+(g+3)|0]=i;a[b+(f+2)|0]=i;a[b+(g+2)|0]=i;a[b+(f+1)|0]=i;a[b+f|0]=i;return}function jab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d[f-1|0]|0;h=f+1|0;i=f+2|0;j=f+3|0;k=0;l=b;while(1){b=(d[e+(3-k)|0]|0)-g|0;m=(d[f]|0)+b|0;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=(d[h]|0)+b|0;if(m>>>0>255>>>0){o=-m>>31&255}else{o=m&255}a[l+1|0]=o;m=(d[i]|0)+b|0;if(m>>>0>255>>>0){p=-m>>31&255}else{p=m&255}a[l+2|0]=p;m=(d[j]|0)+b|0;if(m>>>0>255>>>0){q=-m>>31&255}else{q=m&255}a[l+3|0]=q;m=k+1|0;if((m|0)<4){k=m;l=l+c|0}else{break}}return}function kab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;f=ba(((d[e]|0)+2+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)|0)>>>2,16843009)|0;c[a>>2]=f;c[a+b>>2]=f;c[a+(b<<1)>>2]=f;c[a+(b*3|0)>>2]=f;return}function lab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;e=ba(((d[f]|0)+2+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)|0)>>>2,16843009)|0;c[a>>2]=e;c[a+b>>2]=e;c[a+(b<<1)>>2]=e;c[a+(b*3|0)>>2]=e;return}function mab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=-2139062144;c[a+b>>2]=-2139062144;c[a+(b<<1)>>2]=-2139062144;c[a+(b*3|0)>>2]=-2139062144;return}function nab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=2139062143;c[a+b>>2]=2139062143;c[a+(b<<1)>>2]=2139062143;c[a+(b*3|0)>>2]=2139062143;return}function oab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=-2122219135;c[a+b>>2]=-2122219135;c[a+(b<<1)>>2]=-2122219135;c[a+(b*3|0)>>2]=-2122219135;return}function pab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;d=e;e=c[d>>2]|0;f=c[d+4>>2]|0;d=a;c[d>>2]=e;c[d+4>>2]=f;d=a+b|0;c[d>>2]=e;c[d+4>>2]=f;d=b<<1;g=a+d|0;c[g>>2]=e;c[g+4>>2]=f;g=d+b|0;d=a+g|0;c[d>>2]=e;c[d+4>>2]=f;d=g+b|0;g=a+d|0;c[g>>2]=e;c[g+4>>2]=f;g=d+b|0;d=a+g|0;c[d>>2]=e;c[d+4>>2]=f;d=g+b|0;g=a+d|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(d+b)|0;c[g>>2]=e;c[g+4>>2]=f;return}function qab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=gHb(d[e+7|0]|0,0,16843009,16843009)|0;g=a;c[g>>2]=f;c[g+4>>2]=F;g=gHb(d[e+6|0]|0,0,16843009,16843009)|0;f=a+b|0;c[f>>2]=g;c[f+4>>2]=F;f=b<<1;g=gHb(d[e+5|0]|0,0,16843009,16843009)|0;h=a+f|0;c[h>>2]=g;c[h+4>>2]=F;h=f+b|0;f=gHb(d[e+4|0]|0,0,16843009,16843009)|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=F;g=h+b|0;h=gHb(d[e+3|0]|0,0,16843009,16843009)|0;f=a+g|0;c[f>>2]=h;c[f+4>>2]=F;f=g+b|0;g=gHb(d[e+2|0]|0,0,16843009,16843009)|0;h=a+f|0;c[h>>2]=g;c[h+4>>2]=F;h=f+b|0;f=gHb(d[e+1|0]|0,0,16843009,16843009)|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=F;g=gHb(d[e]|0,0,16843009,16843009)|0;e=a+(h+b)|0;c[e>>2]=g;c[e+4>>2]=F;return}function rab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;g=(d[e]|0)+8+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[f]|0)+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)>>4;f=gHb(g,(g|0)<0|0?-1:0,16843009,16843009)|0;g=F;e=a;c[e>>2]=f;c[e+4>>2]=g;e=a+b|0;c[e>>2]=f;c[e+4>>2]=g;e=b<<1;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+b)|0;c[h>>2]=f;c[h+4>>2]=g;return}function sab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+8|0;g=e|0;h=d[f+1|0]|0;j=d[f+2|0]|0;k=g|0;a[k]=((d[f]|0)+2+(h<<1)+j|0)>>>2;l=d[f+3|0]|0;m=g+1|0;a[m]=(h+2+(j<<1)+l|0)>>>2;h=d[f+4|0]|0;n=g+2|0;a[n]=(j+2+(l<<1)+h|0)>>>2;j=d[f+5|0]|0;o=g+3|0;a[o]=(l+2+(h<<1)+j|0)>>>2;l=d[f+6|0]|0;p=g+4|0;a[p]=(h+2+(j<<1)+l|0)>>>2;h=f+7|0;f=d[h]|0;q=g+5|0;a[q]=(j+2+(l<<1)+f|0)>>>2;j=g+6|0;a[j]=(l+2+(f*3|0)|0)>>>2;a[b]=a[k]|0;a[b+1|0]=a[k+1|0]|0;a[b+2|0]=a[k+2|0]|0;a[b+3|0]=a[k+3|0]|0;a[b+4|0]=a[k+4|0]|0;a[b+5|0]=a[k+5|0]|0;a[b+6|0]=a[k+6|0]|0;TGb(b+7|0,a[h]|0,1)|0;k=b+c|0;a[k]=a[m]|0;a[k+1|0]=a[m+1|0]|0;a[k+2|0]=a[m+2|0]|0;a[k+3|0]=a[m+3|0]|0;a[k+4|0]=a[m+4|0]|0;a[k+5|0]=a[m+5|0]|0;TGb(b+(c+6)|0,a[h]|0,2)|0;m=c<<1;k=b+m|0;a[k]=a[n]|0;a[k+1|0]=a[n+1|0]|0;a[k+2|0]=a[n+2|0]|0;a[k+3|0]=a[n+3|0]|0;a[k+4|0]=a[n+4|0]|0;TGb(b+(m+5)|0,a[h]|0,3)|0;m=c*3|0;n=o;o=b+m|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;TGb(b+(m+4)|0,a[h]|0,4)|0;m=c<<2;o=b+m|0;a[o]=a[p]|0;a[o+1|0]=a[p+1|0]|0;a[o+2|0]=a[p+2|0]|0;TGb(b+(m|3)|0,a[h]|0,5)|0;m=c*5|0;p=q;q=b+m|0;x=(d[p]|d[p+1|0]<<8)<<16>>16;a[q]=x;x=x>>8;a[q+1|0]=x;TGb(b+(m+2)|0,a[h]|0,6)|0;m=c*6|0;a[b+m|0]=a[j]|0;TGb(b+(m|1)|0,a[h]|0,7)|0;TGb(b+(c*7|0)|0,a[h]|0,8)|0;i=e;return}function tab(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;i=i+16|0;k=j|0;l=a[h]|0;m=a[h+1|0]|0;n=0;o=a[g]|0;p=a[g+1|0]|0;q=l;r=m;while(1){s=n+1|0;t=n+2|0;u=a[g+t|0]|0;a[k+n|0]=((o&255)+2+((p&255)<<1)+(u&255)|0)>>>2;v=a[h+t|0]|0;a[k+(n+9)|0]=((q&255)+2+((r&255)<<1)+(v&255)|0)>>>2;if((s|0)<6){n=s;o=p;p=u;q=r;r=v}else{break}}r=d[g+7|0]|0;q=d[h-1|0]|0;h=k+6|0;a[h]=((d[g+6|0]|0)+2+(r<<1)+q|0)>>>2;g=l&255;l=k+7|0;a[l]=(r+2+(q<<1)+g|0)>>>2;a[k+8|0]=(q+2+(g<<1)+(m&255)|0)>>>2;m=l;l=b;g=m|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l|0;x=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+4|0;x=m;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=h;h=b+f|0;m=q|0;l=q+4|0;q=e[l>>1]|e[l+2>>1]<<16;l=h|0;x=e[m>>1]|e[m+2>>1]<<16;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+4|0;x=q;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+5|0;q=b+(f<<1)|0;h=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q|0;x=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=q+4|0;x=l;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+4|0;l=b+(f*3|0)|0;q=c[m+4>>2]|0;h=l|0;x=c[m>>2]|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=l+4|0;x=q;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=k+3|0;q=b+(f<<2)|0;l=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=q+4|0;x=h;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+2|0;h=b+(f*5|0)|0;q=m|0;l=m+4|0;m=e[l>>1]|e[l+2>>1]<<16;l=h|0;x=e[q>>1]|e[q+2>>1]<<16;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+4|0;x=m;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+1|0;m=b+(f*6|0)|0;h=l|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m|0;x=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+4|0;x=l;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=k;k=b+(f*7|0)|0;f=c[q+4>>2]|0;b=k|0;x=c[q>>2]|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=k+4|0;x=f;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;i=j;return}function uab(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;j=i;i=i+32|0;k=j|0;l=j+16|0;m=d[g+3|0]|0;n=d[g+2|0]|0;a[l|0]=(m+2+(n<<1)+(d[g+1|0]|0)|0)>>>2;o=d[g+4|0]|0;a[k|0]=(o+2+(m<<1)+n|0)>>>2;n=d[g+5|0]|0;p=l+1|0;a[p]=(n+2+(o<<1)+m|0)>>>2;m=d[g+6|0]|0;q=k+1|0;a[q]=(m+2+(n<<1)+o|0)>>>2;o=d[g+7|0]|0;g=o+2|0;r=l+2|0;a[r]=(g+(m<<1)+n|0)>>>2;n=a[h-1|0]|0;s=n&255;t=k+2|0;a[t]=(s+2+(o<<1)+m|0)>>>2;m=a[h]|0;o=m&255;u=k+3|0;a[u]=(s+1+o|0)>>>1;v=l+3|0;a[v]=(g+(s<<1)+o|0)>>>2;o=0;s=m;m=n;while(1){n=s&255;g=o+1|0;w=a[h+g|0]|0;y=w&255;z=o+4|0;a[k+z|0]=(n+1+y|0)>>>1;a[l+z|0]=((m&255)+2+(n<<1)+y|0)>>>2;if((g|0)<7){o=g;m=s;s=w}else{break}}s=u;u=b;m=s|0;o=s+4|0;s=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=u|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=u+4|0;x=s;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=v;v=b+f|0;s=o|0;u=o+4|0;o=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=v|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;u=v+4|0;x=o;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;u=t;t=b+(f<<1)|0;o=u|0;v=u+4|0;u=e[v>>1]|e[v+2>>1]<<16;v=t|0;x=e[o>>1]|e[o+2>>1]<<16;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;v=t+4|0;x=u;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;v=r;r=b+(f*3|0)|0;u=v|0;t=v+4|0;v=e[t>>1]|e[t+2>>1]<<16;t=r|0;x=e[u>>1]|e[u+2>>1]<<16;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=r+4|0;x=v;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=q;q=b+(f<<2)|0;v=t|0;r=t+4|0;t=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q|0;x=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=q+4|0;x=t;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=p;p=b+(f*5|0)|0;t=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p|0;x=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=r;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=k;k=b+(f*6|0)|0;r=c[q+4>>2]|0;p=k|0;x=c[q>>2]|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+4|0;x=r;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l;l=b+(f*7|0)|0;f=c[p+4>>2]|0;b=l|0;x=c[p>>2]|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=l+4|0;x=f;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;i=j;return}function vab(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;i=i+24|0;k=j|0;l=a[g]|0;m=a[h-1|0]|0;n=a[h]|0;o=0;p=a[g+1|0]|0;q=l;r=m;s=n;t=l;while(1){l=o+1|0;u=p&255;v=o<<1;a[k+v|0]=(u+1+(q&255)|0)>>>1;w=a[g+(o+2)|0]|0;a[k+(v|1)|0]=((w&255)+2+(u<<1)+(t&255)|0)>>>2;u=a[h+l|0]|0;a[k+(o+16)|0]=((r&255)+2+((s&255)<<1)+(u&255)|0)>>>2;if((l|0)>=6){break}o=l;q=p;p=w;r=s;s=u;t=a[g+l|0]|0}t=m&255;m=d[g+7|0]|0;s=k+14|0;a[s]=(t+1+m|0)>>>1;r=d[g+6|0]|0;g=k+12|0;a[g]=(m+1+r|0)>>>1;a[k+15|0]=((n&255)+2+(t<<1)+m|0)>>>2;a[k+13|0]=(t+2+(m<<1)+r|0)>>>2;r=s;s=b;m=r|0;t=r+4|0;r=e[t>>1]|e[t+2>>1]<<16;t=s|0;x=e[m>>1]|e[m+2>>1]<<16;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=s+4|0;x=r;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=g;g=b+f|0;r=c[t+4>>2]|0;s=g|0;x=c[t>>2]|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=g+4|0;x=r;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=k+10|0;r=b+(f<<1)|0;g=s|0;t=s+4|0;s=e[t>>1]|e[t+2>>1]<<16;t=r|0;x=e[g>>1]|e[g+2>>1]<<16;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=r+4|0;x=s;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=k+8|0;s=b+(f*3|0)|0;r=c[t+4>>2]|0;g=s|0;x=c[t>>2]|0;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;g=s+4|0;x=r;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;g=k+6|0;r=b+(f<<2)|0;s=g|0;t=g+4|0;g=e[t>>1]|e[t+2>>1]<<16;t=r|0;x=e[s>>1]|e[s+2>>1]<<16;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=r+4|0;x=g;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=k+4|0;g=b+(f*5|0)|0;r=c[t+4>>2]|0;s=g|0;x=c[t>>2]|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=g+4|0;x=r;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=k+2|0;r=b+(f*6|0)|0;g=s|0;t=s+4|0;s=e[t>>1]|e[t+2>>1]<<16;t=r|0;x=e[g>>1]|e[g+2>>1]<<16;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=r+4|0;x=s;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=k;k=b+(f*7|0)|0;f=c[t+4>>2]|0;b=k|0;x=c[t>>2]|0;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=k+4|0;x=f;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;i=j;return}function wab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+16|0;g=e|0;h=e+8|0;j=0;k=a[f]|0;l=a[f+1|0]|0;while(1){m=k&255;n=j+1|0;o=l&255;a[g+j|0]=(m+1+o|0)>>>1;p=a[f+(j+2)|0]|0;a[h+j|0]=(m+2+(o<<1)+(p&255)|0)>>>2;if((n|0)<6){j=n;k=l;l=p}else{break}}l=d[f+6|0]|0;k=f+7|0;f=d[k]|0;a[g+6|0]=(l+1+f|0)>>>1;a[h+6|0]=(l+2+(f*3|0)|0)>>>2;f=g|0;a[b]=a[f]|0;a[b+1|0]=a[f+1|0]|0;a[b+2|0]=a[f+2|0]|0;a[b+3|0]=a[f+3|0]|0;a[b+4|0]=a[f+4|0]|0;a[b+5|0]=a[f+5|0]|0;a[b+6|0]=a[f+6|0]|0;TGb(b+7|0,a[k]|0,1)|0;f=b+c|0;l=h|0;a[f]=a[l]|0;a[f+1|0]=a[l+1|0]|0;a[f+2|0]=a[l+2|0]|0;a[f+3|0]=a[l+3|0]|0;a[f+4|0]=a[l+4|0]|0;a[f+5|0]=a[l+5|0]|0;a[f+6|0]=a[l+6|0]|0;TGb(b+(c+7)|0,a[k]|0,1)|0;l=c<<1;f=b+l|0;j=g+1|0;a[f]=a[j]|0;a[f+1|0]=a[j+1|0]|0;a[f+2|0]=a[j+2|0]|0;a[f+3|0]=a[j+3|0]|0;a[f+4|0]=a[j+4|0]|0;a[f+5|0]=a[j+5|0]|0;TGb(b+(l+6)|0,a[k]|0,2)|0;l=c*3|0;j=b+l|0;f=h+1|0;a[j]=a[f]|0;a[j+1|0]=a[f+1|0]|0;a[j+2|0]=a[f+2|0]|0;a[j+3|0]=a[f+3|0]|0;a[j+4|0]=a[f+4|0]|0;a[j+5|0]=a[f+5|0]|0;TGb(b+(l+6)|0,a[k]|0,2)|0;l=c<<2;f=b+l|0;j=g+2|0;a[f]=a[j]|0;a[f+1|0]=a[j+1|0]|0;a[f+2|0]=a[j+2|0]|0;a[f+3|0]=a[j+3|0]|0;a[f+4|0]=a[j+4|0]|0;TGb(b+(l+5)|0,a[k]|0,3)|0;l=c*5|0;j=b+l|0;f=h+2|0;a[j]=a[f]|0;a[j+1|0]=a[f+1|0]|0;a[j+2|0]=a[f+2|0]|0;a[j+3|0]=a[f+3|0]|0;a[j+4|0]=a[f+4|0]|0;TGb(b+(l+5)|0,a[k]|0,3)|0;l=c*6|0;f=g+3|0;g=b+l|0;x=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;TGb(b+(l+4)|0,a[k]|0,4)|0;l=c*7|0;c=h+3|0;h=b+l|0;x=d[c]|d[c+1|0]<<8|d[c+2|0]<<16|d[c+3|0]<<24|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;TGb(b+(l+4)|0,a[k]|0,4)|0;i=e;return}function xab(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;j=i;i=i+16|0;k=j|0;l=0;do{m=8-l|0;n=d[h+(m-1)|0]|0;o=d[h+(m-2)|0]|0;p=l<<1;a[k+p|0]=(n+1+o|0)>>>1;a[k+(p|1)|0]=(n+2+(o<<1)+(d[h+(m-3)|0]|0)|0)>>>2;l=l+1|0;}while((l|0)<6);l=d[h+1|0]|0;m=d[h]|0;o=k+12|0;a[o]=(l+1+m|0)>>>1;a[k+13|0]=(l+2+(m*3|0)|0)>>>2;m=k;l=f;n=c[m+4>>2]|0;p=l|0;x=c[m>>2]|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+4|0;x=n;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+2|0;n=f+g|0;l=p|0;m=p+4|0;p=e[m>>1]|e[m+2>>1]<<16;m=n|0;x=e[l>>1]|e[l+2>>1]<<16;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=n+4|0;x=p;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+4|0;p=f+(g<<1)|0;n=c[m+4>>2]|0;l=p|0;x=c[m>>2]|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=p+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+6|0;n=f+(g*3|0)|0;p=l|0;m=l+4|0;l=e[m>>1]|e[m+2>>1]<<16;m=n|0;x=e[p>>1]|e[p+2>>1]<<16;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=n+4|0;x=l;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=g<<2;l=f+m|0;n=k+8|0;a[l]=a[n]|0;a[l+1|0]=a[n+1|0]|0;a[l+2|0]=a[n+2|0]|0;a[l+3|0]=a[n+3|0]|0;a[l+4|0]=a[n+4|0]|0;a[l+5|0]=a[n+5|0]|0;TGb(f+(m+6)|0,a[h]|0,2)|0;m=g*5|0;n=k+10|0;k=f+m|0;x=e[n>>1]|e[n+2>>1]<<16;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;TGb(f+(m+4)|0,a[h]|0,4)|0;m=g*6|0;k=f+m|0;x=b[o>>1]|0;a[k]=x;x=x>>8;a[k+1|0]=x;TGb(f+(m+2)|0,a[h]|0,6)|0;TGb(f+(g*7|0)|0,a[h]|0,8)|0;i=j;return}function yab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=d[f-1|0]|0;h=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=0;p=b;while(1){b=(d[e+(7-o)|0]|0)-g|0;q=(d[f]|0)+b|0;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[p]=r;q=(d[h]|0)+b|0;if(q>>>0>255>>>0){s=-q>>31&255}else{s=q&255}a[p+1|0]=s;q=(d[i]|0)+b|0;if(q>>>0>255>>>0){t=-q>>31&255}else{t=q&255}a[p+2|0]=t;q=(d[j]|0)+b|0;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[p+3|0]=u;q=(d[k]|0)+b|0;if(q>>>0>255>>>0){v=-q>>31&255}else{v=q&255}a[p+4|0]=v;q=(d[l]|0)+b|0;if(q>>>0>255>>>0){w=-q>>31&255}else{w=q&255}a[p+5|0]=w;q=(d[m]|0)+b|0;if(q>>>0>255>>>0){x=-q>>31&255}else{x=q&255}a[p+6|0]=x;q=(d[n]|0)+b|0;if(q>>>0>255>>>0){y=-q>>31&255}else{y=q&255}a[p+7|0]=y;q=o+1|0;if((q|0)<8){o=q;p=p+c|0}else{break}}return}function zab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=(d[e]|0)+4+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)>>3;e=gHb(f,(f|0)<0|0?-1:0,16843009,16843009)|0;f=F;g=a;c[g>>2]=e;c[g+4>>2]=f;g=a+b|0;c[g>>2]=e;c[g+4>>2]=f;g=b<<1;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+b)|0;c[h>>2]=e;c[h+4>>2]=f;return}function Aab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;e=(d[f]|0)+4+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)>>3;f=gHb(e,(e|0)<0|0?-1:0,16843009,16843009)|0;e=F;g=a;c[g>>2]=f;c[g+4>>2]=e;g=a+b|0;c[g>>2]=f;c[g+4>>2]=e;g=b<<1;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+b)|0;c[h>>2]=f;c[h+4>>2]=e;return}function Bab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+b|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=b<<1;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+b)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;return}function Cab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+b|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=b<<1;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+b)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;return}function Dab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+b|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=b<<1;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+b)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;return}function Eab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;d=e;f=c[d>>2]|0;g=c[d+4>>2]|0;d=e+8|0;e=c[d>>2]|0;h=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=a+8|0;c[d>>2]=e;c[d+4>>2]=h;d=a+b|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(b+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=b<<1;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;b=a+i|0;c[b>>2]=f;c[b+4>>2]=g;g=a+(i+8)|0;c[g>>2]=e;c[g+4>>2]=h;return}function Fab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;f=0;g=a;while(1){a=gHb(d[e+(15-f)|0]|0,0,16843009,16843009)|0;h=F;i=g;c[i>>2]=a;c[i+4>>2]=h;i=g+8|0;c[i>>2]=a;c[i+4>>2]=h;h=f+1|0;if((h|0)<16){f=h;g=g+b|0}else{break}}return}function Gab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;g=(d[e]|0)+16+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[e+8|0]|0)+(d[e+9|0]|0)+(d[e+10|0]|0)+(d[e+11|0]|0)+(d[e+12|0]|0)+(d[e+13|0]|0)+(d[e+14|0]|0)+(d[e+15|0]|0)+(d[f]|0)+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)+(d[f+8|0]|0)+(d[f+9|0]|0)+(d[f+10|0]|0)+(d[f+11|0]|0)+(d[f+12|0]|0)+(d[f+13|0]|0)+(d[f+14|0]|0)+(d[f+15|0]|0)>>5;f=gHb(g,(g|0)<0|0?-1:0,16843009,16843009)|0;g=F;e=a;c[e>>2]=f;c[e+4>>2]=g;e=a+8|0;c[e>>2]=f;c[e+4>>2]=g;e=a+b|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(b+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=b<<1;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;b=a+h|0;c[b>>2]=f;c[b+4>>2]=g;b=a+(h+8)|0;c[b>>2]=f;c[b+4>>2]=g;return}function Hab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;g=e|0;h=0;j=a[f]|0;k=a[f+1|0]|0;while(1){l=h+1|0;m=a[f+(h+2)|0]|0;a[g+h|0]=((j&255)+2+((k&255)<<1)+(m&255)|0)>>>2;if((l|0)<14){h=l;j=k;k=m}else{break}}k=f+15|0;a[g+14|0]=((d[f+14|0]|0)+2+((d[k]|0)*3|0)|0)>>>2;f=0;do{j=ba(f,c)|0;h=15-f|0;UGb(b+j|0,g+f|0,h)|0;f=f+1|0;TGb(b+(h+j)|0,a[k]|0,f|0)|0;}while((f|0)<16);i=e;return}function Iab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+32|0;h=g|0;j=a[f]|0;k=a[f+1|0]|0;l=0;m=a[e]|0;n=a[e+1|0]|0;o=j;p=k;while(1){q=l+1|0;r=l+2|0;s=a[e+r|0]|0;a[h+l|0]=((m&255)+2+((n&255)<<1)+(s&255)|0)>>>2;t=a[f+r|0]|0;a[h+(l+17)|0]=((o&255)+2+((p&255)<<1)+(t&255)|0)>>>2;if((q|0)<14){l=q;m=n;n=s;o=p;p=t}else{break}}p=d[e+15|0]|0;o=d[f-1|0]|0;f=h+14|0;a[f]=((d[e+14|0]|0)+2+(p<<1)+o|0)>>>2;e=j&255;j=h+15|0;a[j]=(p+2+(o<<1)+e|0)>>>2;a[h+16|0]=(o+2+(e<<1)+(k&255)|0)>>>2;UGb(b|0,j|0,16)|0;UGb(b+c|0,f|0,16)|0;UGb(b+(c<<1)|0,h+13|0,16)|0;UGb(b+(c*3|0)|0,h+12|0,16)|0;UGb(b+(c<<2)|0,h+11|0,16)|0;UGb(b+(c*5|0)|0,h+10|0,16)|0;UGb(b+(c*6|0)|0,h+9|0,16)|0;UGb(b+(c*7|0)|0,h+8|0,16)|0;UGb(b+(c<<3)|0,h+7|0,16)|0;UGb(b+(c*9|0)|0,h+6|0,16)|0;UGb(b+(c*10|0)|0,h+5|0,16)|0;UGb(b+(c*11|0)|0,h+4|0,16)|0;UGb(b+(c*12|0)|0,h+3|0,16)|0;UGb(b+(c*13|0)|0,h+2|0,16)|0;UGb(b+(c*14|0)|0,h+1|0,16)|0;UGb(b+(c*15|0)|0,h|0,16)|0;i=g;return}function Jab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+48|0;h=g|0;j=g+24|0;k=0;do{l=k<<1;m=d[e+(l+3)|0]|0;n=d[e+(l+2)|0]|0;a[j+k|0]=(m+2+(n<<1)+(d[e+(l|1)|0]|0)|0)>>>2;a[h+k|0]=((d[e+(l+4)|0]|0)+2+(m<<1)+n|0)>>>2;k=k+1|0;}while((k|0)<6);k=d[e+15|0]|0;n=d[e+14|0]|0;m=k+2|0;l=j+6|0;a[l]=(m+(n<<1)+(d[e+13|0]|0)|0)>>>2;e=a[f-1|0]|0;o=e&255;p=h+6|0;a[p]=(o+2+(k<<1)+n|0)>>>2;n=a[f]|0;k=n&255;q=h+7|0;a[q]=(o+1+k|0)>>>1;r=j+7|0;a[r]=(m+(o<<1)+k|0)>>>2;k=0;o=n;n=e;while(1){e=o&255;m=k+1|0;s=a[f+m|0]|0;t=s&255;u=k+8|0;a[h+u|0]=(e+1+t|0)>>>1;a[j+u|0]=((n&255)+2+(e<<1)+t|0)>>>2;if((m|0)<15){k=m;n=o;o=s}else{break}}UGb(b|0,q|0,16)|0;UGb(b+c|0,r|0,16)|0;UGb(b+(c<<1)|0,p|0,16)|0;UGb(b+(c*3|0)|0,l|0,16)|0;UGb(b+(c<<2)|0,h+5|0,16)|0;UGb(b+(c*5|0)|0,j+5|0,16)|0;UGb(b+(c*6|0)|0,h+4|0,16)|0;UGb(b+(c*7|0)|0,j+4|0,16)|0;UGb(b+(c<<3)|0,h+3|0,16)|0;UGb(b+(c*9|0)|0,j+3|0,16)|0;UGb(b+(c*10|0)|0,h+2|0,16)|0;UGb(b+(c*11|0)|0,j+2|0,16)|0;UGb(b+(c*12|0)|0,h+1|0,16)|0;UGb(b+(c*13|0)|0,j+1|0,16)|0;UGb(b+(c*14|0)|0,h|0,16)|0;UGb(b+(c*15|0)|0,j|0,16)|0;i=g;return}function Kab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+48|0;h=g|0;j=a[e]|0;k=a[f-1|0]|0;l=a[f]|0;m=0;n=a[e+1|0]|0;o=j;p=k;q=l;r=j;while(1){j=m+1|0;s=n&255;t=m<<1;a[h+t|0]=(s+1+(o&255)|0)>>>1;u=a[e+(m+2)|0]|0;a[h+(t|1)|0]=((u&255)+2+(s<<1)+(r&255)|0)>>>2;s=a[f+j|0]|0;a[h+(m+32)|0]=((p&255)+2+((q&255)<<1)+(s&255)|0)>>>2;if((j|0)>=14){break}m=j;o=n;n=u;p=q;q=s;r=a[e+j|0]|0}r=k&255;k=d[e+15|0]|0;q=h+30|0;a[q]=(r+1+k|0)>>>1;p=d[e+14|0]|0;e=h+28|0;a[e]=(k+1+p|0)>>>1;a[h+31|0]=((l&255)+2+(r<<1)+k|0)>>>2;a[h+29|0]=(r+2+(k<<1)+p|0)>>>2;UGb(b|0,q|0,16)|0;UGb(b+c|0,e|0,16)|0;UGb(b+(c<<1)|0,h+26|0,16)|0;UGb(b+(c*3|0)|0,h+24|0,16)|0;UGb(b+(c<<2)|0,h+22|0,16)|0;UGb(b+(c*5|0)|0,h+20|0,16)|0;UGb(b+(c*6|0)|0,h+18|0,16)|0;UGb(b+(c*7|0)|0,h+16|0,16)|0;UGb(b+(c<<3)|0,h+14|0,16)|0;UGb(b+(c*9|0)|0,h+12|0,16)|0;UGb(b+(c*10|0)|0,h+10|0,16)|0;UGb(b+(c*11|0)|0,h+8|0,16)|0;UGb(b+(c*12|0)|0,h+6|0,16)|0;UGb(b+(c*13|0)|0,h+4|0,16)|0;UGb(b+(c*14|0)|0,h+2|0,16)|0;UGb(b+(c*15|0)|0,h|0,16)|0;i=g;return}function Lab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+32|0;g=e|0;h=e+16|0;j=0;k=a[f]|0;l=a[f+1|0]|0;while(1){m=k&255;n=j+1|0;o=l&255;a[g+j|0]=(m+1+o|0)>>>1;p=a[f+(j+2)|0]|0;a[h+j|0]=(m+2+(o<<1)+(p&255)|0)>>>2;if((n|0)<14){j=n;k=l;l=p}else{break}}l=d[f+14|0]|0;k=f+15|0;f=d[k]|0;a[g+14|0]=(l+1+f|0)>>>1;a[h+14|0]=(l+2+(f*3|0)|0)>>>2;f=0;l=0;while(1){j=f<<1;p=ba(j,c)|0;n=16-f-1|0;UGb(b+p|0,g+f|0,n)|0;o=l+15|0;m=f+1|0;TGb(b+(o+p)|0,a[k]|0,m|0)|0;p=ba(j|1,c)|0;UGb(b+p|0,h+f|0,n)|0;TGb(b+(o+p)|0,a[k]|0,m|0)|0;p=~f;if((m|0)<8){f=m;l=p}else{break}}i=e;return}function Mab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+32|0;g=f|0;h=0;do{j=16-h|0;k=d[e+(j-1)|0]|0;l=d[e+(j-2)|0]|0;m=h<<1;a[g+m|0]=(k+1+l|0)>>>1;a[g+(m|1)|0]=(k+2+(l<<1)+(d[e+(j-3)|0]|0)|0)>>>2;h=h+1|0;}while((h|0)<14);h=d[e+1|0]|0;j=d[e]|0;l=g+28|0;a[l]=(h+1+j|0)>>>1;a[g+29|0]=(h+2+(j*3|0)|0)>>>2;UGb(b|0,g|0,16)|0;UGb(b+c|0,g+2|0,16)|0;UGb(b+(c<<1)|0,g+4|0,16)|0;UGb(b+(c*3|0)|0,g+6|0,16)|0;UGb(b+(c<<2)|0,g+8|0,16)|0;UGb(b+(c*5|0)|0,g+10|0,16)|0;UGb(b+(c*6|0)|0,g+12|0,16)|0;UGb(b+(c*7|0)|0,g+14|0,16)|0;j=c<<3;UGb(b+j|0,g+16|0,14)|0;TGb(b+(j+14)|0,a[e]|0,2)|0;j=c*9|0;UGb(b+j|0,g+18|0,12)|0;TGb(b+(j+12)|0,a[e]|0,4)|0;j=c*10|0;UGb(b+j|0,g+20|0,10)|0;TGb(b+(j+10)|0,a[e]|0,6)|0;j=c*11|0;h=g+22|0;k=b+j|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+4|0;x=h;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;TGb(b+(j+8)|0,a[e]|0,8)|0;j=c*12|0;n=b+j|0;h=g+24|0;a[n]=a[h]|0;a[n+1|0]=a[h+1|0]|0;a[n+2|0]=a[h+2|0]|0;a[n+3|0]=a[h+3|0]|0;a[n+4|0]=a[h+4|0]|0;a[n+5|0]=a[h+5|0]|0;TGb(b+(j+6)|0,a[e]|0,10)|0;j=c*13|0;h=g+26|0;g=b+j|0;x=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;TGb(b+(j+4)|0,a[e]|0,12)|0;j=c*14|0;g=l;l=b+j|0;x=(d[g]|d[g+1|0]<<8)<<16>>16;a[l]=x;x=x>>8;a[l+1|0]=x;TGb(b+(j+2)|0,a[e]|0,14)|0;TGb(b+(c*15|0)|0,a[e]|0,16)|0;i=f;return}function Nab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=d[f-1|0]|0;h=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=f+9|0;q=f+10|0;r=f+11|0;s=f+12|0;t=f+13|0;u=f+14|0;v=f+15|0;w=0;x=b;while(1){b=(d[e+(15-w)|0]|0)-g|0;y=(d[f]|0)+b|0;if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}a[x]=z;y=(d[h]|0)+b|0;if(y>>>0>255>>>0){A=-y>>31&255}else{A=y&255}a[x+1|0]=A;y=(d[i]|0)+b|0;if(y>>>0>255>>>0){B=-y>>31&255}else{B=y&255}a[x+2|0]=B;y=(d[j]|0)+b|0;if(y>>>0>255>>>0){C=-y>>31&255}else{C=y&255}a[x+3|0]=C;y=(d[k]|0)+b|0;if(y>>>0>255>>>0){D=-y>>31&255}else{D=y&255}a[x+4|0]=D;y=(d[l]|0)+b|0;if(y>>>0>255>>>0){E=-y>>31&255}else{E=y&255}a[x+5|0]=E;y=(d[m]|0)+b|0;if(y>>>0>255>>>0){F=-y>>31&255}else{F=y&255}a[x+6|0]=F;y=(d[n]|0)+b|0;if(y>>>0>255>>>0){G=-y>>31&255}else{G=y&255}a[x+7|0]=G;y=(d[o]|0)+b|0;if(y>>>0>255>>>0){H=-y>>31&255}else{H=y&255}a[x+8|0]=H;y=(d[p]|0)+b|0;if(y>>>0>255>>>0){I=-y>>31&255}else{I=y&255}a[x+9|0]=I;y=(d[q]|0)+b|0;if(y>>>0>255>>>0){J=-y>>31&255}else{J=y&255}a[x+10|0]=J;y=(d[r]|0)+b|0;if(y>>>0>255>>>0){K=-y>>31&255}else{K=y&255}a[x+11|0]=K;y=(d[s]|0)+b|0;if(y>>>0>255>>>0){L=-y>>31&255}else{L=y&255}a[x+12|0]=L;y=(d[t]|0)+b|0;if(y>>>0>255>>>0){M=-y>>31&255}else{M=y&255}a[x+13|0]=M;y=(d[u]|0)+b|0;if(y>>>0>255>>>0){N=-y>>31&255}else{N=y&255}a[x+14|0]=N;y=(d[v]|0)+b|0;if(y>>>0>255>>>0){O=-y>>31&255}else{O=y&255}a[x+15|0]=O;y=w+1|0;if((y|0)<16){w=y;x=x+c|0}else{break}}return}function Oab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=(d[e]|0)+8+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[e+8|0]|0)+(d[e+9|0]|0)+(d[e+10|0]|0)+(d[e+11|0]|0)+(d[e+12|0]|0)+(d[e+13|0]|0)+(d[e+14|0]|0)+(d[e+15|0]|0)>>4;e=gHb(f,(f|0)<0|0?-1:0,16843009,16843009)|0;f=F;g=a;c[g>>2]=e;c[g+4>>2]=f;g=a+8|0;c[g>>2]=e;c[g+4>>2]=f;g=a+b|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(b+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=b<<1;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;b=a+h|0;c[b>>2]=e;c[b+4>>2]=f;b=a+(h+8)|0;c[b>>2]=e;c[b+4>>2]=f;return}function Pab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;e=(d[f]|0)+8+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)+(d[f+8|0]|0)+(d[f+9|0]|0)+(d[f+10|0]|0)+(d[f+11|0]|0)+(d[f+12|0]|0)+(d[f+13|0]|0)+(d[f+14|0]|0)+(d[f+15|0]|0)>>4;f=gHb(e,(e|0)<0|0?-1:0,16843009,16843009)|0;e=F;g=a;c[g>>2]=f;c[g+4>>2]=e;g=a+8|0;c[g>>2]=f;c[g+4>>2]=e;g=a+b|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(b+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=b<<1;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;b=a+h|0;c[b>>2]=f;c[b+4>>2]=e;b=a+(h+8)|0;c[b>>2]=f;c[b+4>>2]=e;return}function Qab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a+b|0;TGb(a|0,-128|0,16)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(b+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=b<<1;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;b=a+d|0;c[b>>2]=-2139062144;c[b+4>>2]=-2139062144;b=a+(d+8)|0;c[b>>2]=-2139062144;c[b+4>>2]=-2139062144;return}function Rab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a+b|0;TGb(a|0,127,16)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(b+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=b<<1;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;b=a+d|0;c[b>>2]=2139062143;c[b+4>>2]=2139062143;b=a+(d+8)|0;c[b>>2]=2139062143;c[b+4>>2]=2139062143;return}function Sab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a+b|0;TGb(a|0,-127|0,16)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(b+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=b<<1;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;b=a+d|0;c[b>>2]=-2122219135;c[b+4>>2]=-2122219135;b=a+(d+8)|0;c[b>>2]=-2122219135;c[b+4>>2]=-2122219135;return}function Tab(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=e;f=c[d>>2]|0;g=c[d+4>>2]|0;d=e+8|0;h=c[d>>2]|0;i=c[d+4>>2]|0;d=e+16|0;j=c[d>>2]|0;k=c[d+4>>2]|0;d=e+24|0;e=c[d>>2]|0;l=c[d+4>>2]|0;d=a;a=0;while(1){m=d;c[m>>2]=f;c[m+4>>2]=g;m=d+8|0;c[m>>2]=h;c[m+4>>2]=i;m=d+16|0;c[m>>2]=j;c[m+4>>2]=k;m=d+24|0;c[m>>2]=e;c[m+4>>2]=l;m=a+1|0;if((m|0)<32){d=d+b|0;a=m}else{break}}return}function Uab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;f=0;g=a;while(1){a=gHb(d[e+(31-f)|0]|0,0,16843009,16843009)|0;h=F;i=g;c[i>>2]=a;c[i+4>>2]=h;i=g+8|0;c[i>>2]=a;c[i+4>>2]=h;i=g+16|0;c[i>>2]=a;c[i+4>>2]=h;i=g+24|0;c[i>>2]=a;c[i+4>>2]=h;h=f+1|0;if((h|0)<32){f=h;g=g+b|0}else{break}}return}function Vab(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;g=(d[e]|0)+32+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[e+8|0]|0)+(d[e+9|0]|0)+(d[e+10|0]|0)+(d[e+11|0]|0)+(d[e+12|0]|0)+(d[e+13|0]|0)+(d[e+14|0]|0)+(d[e+15|0]|0)+(d[e+16|0]|0)+(d[e+17|0]|0)+(d[e+18|0]|0)+(d[e+19|0]|0)+(d[e+20|0]|0)+(d[e+21|0]|0)+(d[e+22|0]|0)+(d[e+23|0]|0)+(d[e+24|0]|0)+(d[e+25|0]|0)+(d[e+26|0]|0)+(d[e+27|0]|0)+(d[e+28|0]|0)+(d[e+29|0]|0)+(d[e+30|0]|0)+(d[e+31|0]|0)+(d[f]|0)+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)+(d[f+8|0]|0)+(d[f+9|0]|0)+(d[f+10|0]|0)+(d[f+11|0]|0)+(d[f+12|0]|0)+(d[f+13|0]|0)+(d[f+14|0]|0)+(d[f+15|0]|0)+(d[f+16|0]|0)+(d[f+17|0]|0)+(d[f+18|0]|0)+(d[f+19|0]|0)+(d[f+20|0]|0)+(d[f+21|0]|0)+(d[f+22|0]|0)+(d[f+23|0]|0)+(d[f+24|0]|0)+(d[f+25|0]|0)+(d[f+26|0]|0)+(d[f+27|0]|0)+(d[f+28|0]|0)+(d[f+29|0]|0)+(d[f+30|0]|0)+(d[f+31|0]|0)>>6;f=gHb(g,(g|0)<0|0?-1:0,16843009,16843009)|0;g=F;e=a;a=0;while(1){h=e;c[h>>2]=f;c[h+4>>2]=g;h=e+8|0;c[h>>2]=f;c[h+4>>2]=g;h=e+16|0;c[h>>2]=f;c[h+4>>2]=g;h=e+24|0;c[h>>2]=f;c[h+4>>2]=g;h=a+1|0;if((h|0)<32){e=e+b|0;a=h}else{break}}return}function Wab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+32|0;g=e|0;h=0;j=a[f]|0;k=a[f+1|0]|0;while(1){l=h+1|0;m=a[f+(h+2)|0]|0;a[g+h|0]=((j&255)+2+((k&255)<<1)+(m&255)|0)>>>2;if((l|0)<30){h=l;j=k;k=m}else{break}}k=f+31|0;a[g+30|0]=((d[f+30|0]|0)+2+((d[k]|0)*3|0)|0)>>>2;f=0;do{j=ba(f,c)|0;h=31-f|0;UGb(b+j|0,g+f|0,h)|0;f=f+1|0;TGb(b+(h+j)|0,a[k]|0,f|0)|0;}while((f|0)<32);i=e;return}function Xab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+64|0;h=g|0;j=a[f]|0;k=a[f+1|0]|0;l=0;m=a[e]|0;n=a[e+1|0]|0;o=j;p=k;while(1){q=l+1|0;r=l+2|0;s=a[e+r|0]|0;a[h+l|0]=((m&255)+2+((n&255)<<1)+(s&255)|0)>>>2;t=a[f+r|0]|0;a[h+(l+33)|0]=((o&255)+2+((p&255)<<1)+(t&255)|0)>>>2;if((q|0)<30){l=q;m=n;n=s;o=p;p=t}else{break}}p=d[e+31|0]|0;o=d[f-1|0]|0;a[h+30|0]=((d[e+30|0]|0)+2+(p<<1)+o|0)>>>2;e=j&255;a[h+31|0]=(p+2+(o<<1)+e|0)>>>2;a[h+32|0]=(o+2+(e<<1)+(k&255)|0)>>>2;k=0;do{UGb(b+(ba(k,c)|0)|0,h+(31-k)|0,32)|0;k=k+1|0;}while((k|0)<32);i=g;return}function Yab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+96|0;h=g|0;j=g+48|0;k=0;do{l=k<<1;m=d[e+(l+3)|0]|0;n=d[e+(l+2)|0]|0;a[j+k|0]=(m+2+(n<<1)+(d[e+(l|1)|0]|0)|0)>>>2;a[h+k|0]=((d[e+(l+4)|0]|0)+2+(m<<1)+n|0)>>>2;k=k+1|0;}while((k|0)<14);k=d[e+31|0]|0;n=d[e+30|0]|0;m=k+2|0;a[j+14|0]=(m+(n<<1)+(d[e+29|0]|0)|0)>>>2;e=a[f-1|0]|0;l=e&255;a[h+14|0]=(l+2+(k<<1)+n|0)>>>2;n=a[f]|0;k=n&255;a[h+15|0]=(l+1+k|0)>>>1;a[j+15|0]=(m+(l<<1)+k|0)>>>2;k=0;l=n;n=e;while(1){e=l&255;m=k+1|0;o=a[f+m|0]|0;p=o&255;q=k+16|0;a[h+q|0]=(e+1+p|0)>>>1;a[j+q|0]=((n&255)+2+(e<<1)+p|0)>>>2;if((m|0)<31){k=m;n=l;l=o}else{r=0;break}}do{l=r<<1;n=15-r|0;UGb(b+(ba(l,c)|0)|0,h+n|0,32)|0;UGb(b+(ba(l|1,c)|0)|0,j+n|0,32)|0;r=r+1|0;}while((r|0)<16);i=g;return}function Zab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+96|0;h=g|0;j=a[e]|0;k=a[f-1|0]|0;l=a[f]|0;m=0;n=a[e+1|0]|0;o=j;p=k;q=l;r=j;while(1){j=m+1|0;s=n&255;t=m<<1;a[h+t|0]=(s+1+(o&255)|0)>>>1;u=a[e+(m+2)|0]|0;a[h+(t|1)|0]=((u&255)+2+(s<<1)+(r&255)|0)>>>2;s=a[f+j|0]|0;a[h+(m+64)|0]=((p&255)+2+((q&255)<<1)+(s&255)|0)>>>2;if((j|0)>=30){break}m=j;o=n;n=u;p=q;q=s;r=a[e+j|0]|0}r=k&255;k=d[e+31|0]|0;a[h+62|0]=(r+1+k|0)>>>1;q=d[e+30|0]|0;a[h+60|0]=(k+1+q|0)>>>1;a[h+63|0]=((l&255)+2+(r<<1)+k|0)>>>2;a[h+61|0]=(r+2+(k<<1)+q|0)>>>2;q=0;do{UGb(b+(ba(q,c)|0)|0,h+(62-(q<<1))|0,32)|0;q=q+1|0;}while((q|0)<32);i=g;return}function _ab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+64|0;g=e|0;h=e+32|0;j=0;k=a[f]|0;l=a[f+1|0]|0;while(1){m=k&255;n=j+1|0;o=l&255;a[g+j|0]=(m+1+o|0)>>>1;p=a[f+(j+2)|0]|0;a[h+j|0]=(m+2+(o<<1)+(p&255)|0)>>>2;if((n|0)<30){j=n;k=l;l=p}else{break}}l=d[f+30|0]|0;k=f+31|0;f=d[k]|0;a[g+30|0]=(l+1+f|0)>>>1;a[h+30|0]=(l+2+(f*3|0)|0)>>>2;f=0;l=0;while(1){j=f<<1;p=ba(j,c)|0;n=32-f-1|0;UGb(b+p|0,g+f|0,n)|0;o=l+31|0;m=f+1|0;TGb(b+(o+p)|0,a[k]|0,m|0)|0;p=ba(j|1,c)|0;UGb(b+p|0,h+f|0,n)|0;TGb(b+(o+p)|0,a[k]|0,m|0)|0;p=~f;if((m|0)<16){f=m;l=p}else{break}}i=e;return}function $ab(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+64|0;g=f|0;h=0;do{j=32-h|0;k=d[e+(j-1)|0]|0;l=d[e+(j-2)|0]|0;m=h<<1;a[g+m|0]=(k+1+l|0)>>>1;a[g+(m|1)|0]=(k+2+(l<<1)+(d[e+(j-3)|0]|0)|0)>>>2;h=h+1|0;}while((h|0)<30);h=d[e+1|0]|0;j=d[e]|0;a[g+60|0]=(h+1+j|0)>>>1;a[g+61|0]=(h+2+(j*3|0)|0)>>>2;UGb(b|0,g|0,32)|0;UGb(b+c|0,g+2|0,32)|0;UGb(b+(c<<1)|0,g+4|0,32)|0;UGb(b+(c*3|0)|0,g+6|0,32)|0;UGb(b+(c<<2)|0,g+8|0,32)|0;UGb(b+(c*5|0)|0,g+10|0,32)|0;UGb(b+(c*6|0)|0,g+12|0,32)|0;UGb(b+(c*7|0)|0,g+14|0,32)|0;UGb(b+(c<<3)|0,g+16|0,32)|0;UGb(b+(c*9|0)|0,g+18|0,32)|0;UGb(b+(c*10|0)|0,g+20|0,32)|0;UGb(b+(c*11|0)|0,g+22|0,32)|0;UGb(b+(c*12|0)|0,g+24|0,32)|0;UGb(b+(c*13|0)|0,g+26|0,32)|0;UGb(b+(c*14|0)|0,g+28|0,32)|0;UGb(b+(c*15|0)|0,g+30|0,32)|0;j=16;do{h=ba(j,c)|0;l=j<<1;UGb(b+h|0,g+l|0,62-l|0)|0;TGb(b+(h+62-l)|0,a[e]|0,l-30|0)|0;j=j+1|0;}while((j|0)<32);i=f;return}function abb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;g=d[f-1|0]|0;h=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=f+9|0;q=f+10|0;r=f+11|0;s=f+12|0;t=f+13|0;u=f+14|0;v=f+15|0;w=f+16|0;x=f+17|0;y=f+18|0;z=f+19|0;A=f+20|0;B=f+21|0;C=f+22|0;D=f+23|0;E=f+24|0;F=f+25|0;G=f+26|0;H=f+27|0;I=f+28|0;J=f+29|0;K=f+30|0;L=f+31|0;M=0;N=b;while(1){b=(d[e+(31-M)|0]|0)-g|0;O=(d[f]|0)+b|0;if(O>>>0>255>>>0){P=-O>>31&255}else{P=O&255}a[N]=P;O=(d[h]|0)+b|0;if(O>>>0>255>>>0){Q=-O>>31&255}else{Q=O&255}a[N+1|0]=Q;O=(d[i]|0)+b|0;if(O>>>0>255>>>0){R=-O>>31&255}else{R=O&255}a[N+2|0]=R;O=(d[j]|0)+b|0;if(O>>>0>255>>>0){S=-O>>31&255}else{S=O&255}a[N+3|0]=S;O=(d[k]|0)+b|0;if(O>>>0>255>>>0){T=-O>>31&255}else{T=O&255}a[N+4|0]=T;O=(d[l]|0)+b|0;if(O>>>0>255>>>0){U=-O>>31&255}else{U=O&255}a[N+5|0]=U;O=(d[m]|0)+b|0;if(O>>>0>255>>>0){V=-O>>31&255}else{V=O&255}a[N+6|0]=V;O=(d[n]|0)+b|0;if(O>>>0>255>>>0){W=-O>>31&255}else{W=O&255}a[N+7|0]=W;O=(d[o]|0)+b|0;if(O>>>0>255>>>0){X=-O>>31&255}else{X=O&255}a[N+8|0]=X;O=(d[p]|0)+b|0;if(O>>>0>255>>>0){Y=-O>>31&255}else{Y=O&255}a[N+9|0]=Y;O=(d[q]|0)+b|0;if(O>>>0>255>>>0){Z=-O>>31&255}else{Z=O&255}a[N+10|0]=Z;O=(d[r]|0)+b|0;if(O>>>0>255>>>0){_=-O>>31&255}else{_=O&255}a[N+11|0]=_;O=(d[s]|0)+b|0;if(O>>>0>255>>>0){$=-O>>31&255}else{$=O&255}a[N+12|0]=$;O=(d[t]|0)+b|0;if(O>>>0>255>>>0){aa=-O>>31&255}else{aa=O&255}a[N+13|0]=aa;O=(d[u]|0)+b|0;if(O>>>0>255>>>0){ba=-O>>31&255}else{ba=O&255}a[N+14|0]=ba;O=(d[v]|0)+b|0;if(O>>>0>255>>>0){ca=-O>>31&255}else{ca=O&255}a[N+15|0]=ca;O=(d[w]|0)+b|0;if(O>>>0>255>>>0){da=-O>>31&255}else{da=O&255}a[N+16|0]=da;O=(d[x]|0)+b|0;if(O>>>0>255>>>0){ea=-O>>31&255}else{ea=O&255}a[N+17|0]=ea;O=(d[y]|0)+b|0;if(O>>>0>255>>>0){fa=-O>>31&255}else{fa=O&255}a[N+18|0]=fa;O=(d[z]|0)+b|0;if(O>>>0>255>>>0){ga=-O>>31&255}else{ga=O&255}a[N+19|0]=ga;O=(d[A]|0)+b|0;if(O>>>0>255>>>0){ha=-O>>31&255}else{ha=O&255}a[N+20|0]=ha;O=(d[B]|0)+b|0;if(O>>>0>255>>>0){ia=-O>>31&255}else{ia=O&255}a[N+21|0]=ia;O=(d[C]|0)+b|0;if(O>>>0>255>>>0){ja=-O>>31&255}else{ja=O&255}a[N+22|0]=ja;O=(d[D]|0)+b|0;if(O>>>0>255>>>0){ka=-O>>31&255}else{ka=O&255}a[N+23|0]=ka;O=(d[E]|0)+b|0;if(O>>>0>255>>>0){la=-O>>31&255}else{la=O&255}a[N+24|0]=la;O=(d[F]|0)+b|0;if(O>>>0>255>>>0){ma=-O>>31&255}else{ma=O&255}a[N+25|0]=ma;O=(d[G]|0)+b|0;if(O>>>0>255>>>0){na=-O>>31&255}else{na=O&255}a[N+26|0]=na;O=(d[H]|0)+b|0;if(O>>>0>255>>>0){oa=-O>>31&255}else{oa=O&255}a[N+27|0]=oa;O=(d[I]|0)+b|0;if(O>>>0>255>>>0){pa=-O>>31&255}else{pa=O&255}a[N+28|0]=pa;O=(d[J]|0)+b|0;if(O>>>0>255>>>0){qa=-O>>31&255}else{qa=O&255}a[N+29|0]=qa;O=(d[K]|0)+b|0;if(O>>>0>255>>>0){ra=-O>>31&255}else{ra=O&255}a[N+30|0]=ra;O=(d[L]|0)+b|0;if(O>>>0>255>>>0){sa=-O>>31&255}else{sa=O&255}a[N+31|0]=sa;O=M+1|0;if((O|0)<32){M=O;N=N+c|0}else{break}}return}function bbb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=(d[e]|0)+16+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[e+8|0]|0)+(d[e+9|0]|0)+(d[e+10|0]|0)+(d[e+11|0]|0)+(d[e+12|0]|0)+(d[e+13|0]|0)+(d[e+14|0]|0)+(d[e+15|0]|0)+(d[e+16|0]|0)+(d[e+17|0]|0)+(d[e+18|0]|0)+(d[e+19|0]|0)+(d[e+20|0]|0)+(d[e+21|0]|0)+(d[e+22|0]|0)+(d[e+23|0]|0)+(d[e+24|0]|0)+(d[e+25|0]|0)+(d[e+26|0]|0)+(d[e+27|0]|0)+(d[e+28|0]|0)+(d[e+29|0]|0)+(d[e+30|0]|0)+(d[e+31|0]|0)>>5;e=gHb(f,(f|0)<0|0?-1:0,16843009,16843009)|0;f=F;g=a;a=0;while(1){h=g;c[h>>2]=e;c[h+4>>2]=f;h=g+8|0;c[h>>2]=e;c[h+4>>2]=f;h=g+16|0;c[h>>2]=e;c[h+4>>2]=f;h=g+24|0;c[h>>2]=e;c[h+4>>2]=f;h=a+1|0;if((h|0)<32){g=g+b|0;a=h}else{break}}return}function cbb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;e=(d[f]|0)+16+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)+(d[f+8|0]|0)+(d[f+9|0]|0)+(d[f+10|0]|0)+(d[f+11|0]|0)+(d[f+12|0]|0)+(d[f+13|0]|0)+(d[f+14|0]|0)+(d[f+15|0]|0)+(d[f+16|0]|0)+(d[f+17|0]|0)+(d[f+18|0]|0)+(d[f+19|0]|0)+(d[f+20|0]|0)+(d[f+21|0]|0)+(d[f+22|0]|0)+(d[f+23|0]|0)+(d[f+24|0]|0)+(d[f+25|0]|0)+(d[f+26|0]|0)+(d[f+27|0]|0)+(d[f+28|0]|0)+(d[f+29|0]|0)+(d[f+30|0]|0)+(d[f+31|0]|0)>>5;f=gHb(e,(e|0)<0|0?-1:0,16843009,16843009)|0;e=F;g=a;a=0;while(1){h=g;c[h>>2]=f;c[h+4>>2]=e;h=g+8|0;c[h>>2]=f;c[h+4>>2]=e;h=g+16|0;c[h>>2]=f;c[h+4>>2]=e;h=g+24|0;c[h>>2]=f;c[h+4>>2]=e;h=a+1|0;if((h|0)<32){g=g+b|0;a=h}else{break}}return}function dbb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=a;a=0;while(1){c=a+1|0;TGb(d|0,-128|0,32)|0;if((c|0)<32){d=d+b|0;a=c}else{break}}return}function ebb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=a;a=0;while(1){c=a+1|0;TGb(d|0,127,32)|0;if((c|0)<32){d=d+b|0;a=c}else{break}}return}function fbb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=a;a=0;while(1){c=a+1|0;TGb(d|0,-127|0,32)|0;if((c|0)<32){d=d+b|0;a=c}else{break}}return}function gbb(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=c[b+60>>2]|0;g=f;c[g>>2]=b;c[b+140>>2]=11;if((c[b+100>>2]|0)!=42){yDb(b,16,2207704,(h=i,i=i+8|0,c[h>>2]=42,h)|0);i=h;j=-22;i=e;return j|0}k=c[b+96>>2]|0;l=d[k]|0;c[f+1056>>2]=l;if((l|0)==1|(l|0)==2){m=k+6|0;n=(d[m]|d[m+1|0]<<8)<<16>>16&65535;m=f+1040|0;c[m>>2]=n;o=k+8|0;k=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=f+1044|0;c[o>>2]=k;p=b;q=hDb(n,k,0,p)|0;if((q|0)<0){c[o>>2]=0;c[m>>2]=0;j=q;i=e;return j|0}q=c[(c[g>>2]|0)+96>>2]|0;g=a[q+10|0]|0;k=f+1048|0;c[k>>2]=g&255;n=d[q+11|0]|0;r=f+1052|0;c[r>>2]=n;s=d[q+13|0]|0;c[f+1084>>2]=s;c[f+1088>>2]=s;if(!(g<<24>>24==4)){j=-1094995529;i=e;return j|0}if(!((n|0)==2|(n|0)==4)){j=-1094995529;i=e;return j|0}do{if((c[m>>2]&3|0)==0){if(((c[o>>2]|0)%(n|0)|0|0)!=0){break}g=f+1064|0;c[g>>2]=1048576;s=WDb(1048576)|0;q=f+1060|0;t=q;c[t>>2]=s;do{if((s|0)==0){u=f+1068|0}else{v=WDb(c[g>>2]|0)|0;w=f+1068|0;c[w>>2]=v;if((v|0)==0){u=w;break}v=ba(((c[m>>2]|0)/(c[k>>2]|0)|0)<<1,(c[o>>2]|0)/(c[r>>2]|0)|0)|0;c[f+1080>>2]=v;x=cEb(v)|0;c[f+1076>>2]=x;if((x|0)==0){u=w;break}if((c[r>>2]|0)==4){w=0;x=1044480;while(1){v=w&255;y=x|1;a[(c[t>>2]|0)+x|0]=v;a[(c[t>>2]|0)+y|0]=v;z=x|3;a[(c[t>>2]|0)+(y+1)|0]=v;a[(c[t>>2]|0)+z|0]=v;a[(c[t>>2]|0)+(z+1)|0]=v;a[(c[t>>2]|0)+(z+2)|0]=v;y=x|7;a[(c[t>>2]|0)+(z+3)|0]=v;a[(c[t>>2]|0)+y|0]=v;a[(c[t>>2]|0)+(y+1)|0]=v;a[(c[t>>2]|0)+(y+2)|0]=v;a[(c[t>>2]|0)+(y+3)|0]=v;a[(c[t>>2]|0)+(y+4)|0]=v;a[(c[t>>2]|0)+(y+5)|0]=v;a[(c[t>>2]|0)+(y+6)|0]=v;a[(c[t>>2]|0)+(y+7)|0]=v;a[(c[t>>2]|0)+(x|15)|0]=v;v=w+1|0;if((v|0)<256){w=v;x=x+16|0}else{break}}}else{x=0;w=30720;while(1){v=x&255;y=w|1;a[(c[t>>2]|0)+w|0]=v;a[(c[t>>2]|0)+y|0]=v;z=w|3;a[(c[t>>2]|0)+(y+1)|0]=v;a[(c[t>>2]|0)+z|0]=v;a[(c[t>>2]|0)+(z+1)|0]=v;a[(c[t>>2]|0)+(z+2)|0]=v;a[(c[t>>2]|0)+(z+3)|0]=v;a[(c[t>>2]|0)+(w|7)|0]=v;v=x+1|0;if((v|0)<256){x=v;w=w+8|0}else{break}}}c[f+1072>>2]=0;j=0;i=e;return j|0}}while(0);$Db(q);$Db(u);$Db(f+1076|0);j=-12;i=e;return j|0}}while(0);yDb(p,16,2174184,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1094995529;i=e;return j|0}else if((l|0)==3){EDb(b,2199440,(h=i,i=i+8|0,c[h>>2]=3,h)|0);i=h;j=-1163346256;i=e;return j|0}else{DDb(b,2190800,(h=i,i=i+8|0,c[h>>2]=l,h)|0);i=h;j=-1163346256;i=e;return j|0}return 0}function hbb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0;h=i;j=c[b+60>>2]|0;k=_$a(b,e,0)|0;if((k|0)<0){l=k;i=h;return l|0}k=j;b=c[g+24>>2]|0;m=g+28|0;g=c[m>>2]|0;if(!((g|0)>-1)){yDb(0,0,2240904,(n=i,i=i+24|0,c[n>>2]=2228824,c[n+8>>2]=2217040,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}o=j+4|0;c[o>>2]=b;p=j+12|0;c[p>>2]=b;q=b+g|0;r=j+8|0;c[r>>2]=q;s=j+1080|0;t=(c[s>>2]|0)/2|0;u=j;do{if(g>>>0>7>>>0){v=-1;w=-1;x=-1;y=-1;z=-1;A=-1;B=-1;C=b;D=q;E=b;while(1){F=C+4|0;c[o>>2]=F;G=C;H=fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0;G=F-E|0;I=C+8|0;c[o>>2]=I;J=F;F=fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0;if((H|0)==1128416858){K=B;L=A;M=z;N=y;O=x;P=G;Q=v;R=D;S=I}else if((H|0)==1448105050){K=G;L=A;M=z;N=y;O=x;P=w;Q=v;R=D;S=I}else if((H|0)==1129335898){K=B;L=G;M=z;N=y;O=x;P=w;Q=v;R=D;S=I}else if((H|0)==1128419418){K=B;L=A;M=z;N=G;O=x;P=w;Q=v;R=D;S=I}else if((H|0)==1128419376){K=B;L=A;M=z;N=y;O=G;P=w;Q=v;R=D;S=I}else if((H|0)==1128416816){K=B;L=A;M=z;N=y;O=x;P=w;Q=G;R=D;S=I}else if((H|0)==1129335856){K=B;L=A;M=G;N=y;O=x;P=w;Q=v;R=D;S=I}else{yDb(c[u>>2]|0,16,2178496,(n=i,i=i+40|0,c[n>>2]=H>>>24,c[n+8>>2]=H>>>16&255,c[n+16>>2]=H>>>8&255,c[n+24>>2]=H&255,c[n+32>>2]=H,n)|0);i=n;K=B;L=A;M=z;N=y;O=x;P=w;Q=v;R=c[r>>2]|0;S=c[o>>2]|0}H=(F&1)+F|0;T=R;F=T-S|0;I=S+(F>>>0>H>>>0?H:F)|0;c[o>>2]=I;if(!((T-I|0)>>>0>7>>>0)){break}v=Q;w=P;x=O;y=N;z=M;A=L;B=K;C=I;D=R;E=c[p>>2]|0}E=(M|0)!=-1;if(!((L|0)==-1|E^1)){yDb(c[u>>2]|0,16,2102232,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=-1094995529;i=h;return l|0}a:do{if(E){D=c[p>>2]|0;C=T-D|0;if((M|0)<0){U=0}else{U=(C|0)<(M|0)?C:M}C=D+U|0;c[o>>2]=C;if((T-C|0)<4){break}B=D+(U+4)|0;c[o>>2]=B;D=C;C=fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0;D=(C>>>0)/3|0;do{if(!(C>>>0>770>>>0)){if(C>>>0>(T-B|0)>>>0){break}if(C>>>0<3>>>0){break a}else{V=0;W=B}while(1){A=W+1|0;c[o>>2]=A;z=(d[W]|0)<<18;y=W+2|0;c[o>>2]=y;x=(d[A]|0)<<10;c[o>>2]=W+3;A=x&64512|z|(d[y]|0)<<2&252;c[k+16+(V<<2)>>2]=A|A>>>6&197379|-16777216;A=V+1|0;if(!(A>>>0<D>>>0)){break a}V=A;W=c[o>>2]|0}}}while(0);yDb(c[u>>2]|0,16,2046144,(n=i,i=i+8|0,c[n>>2]=D,n)|0);i=n;l=-1094995529;i=h;return l|0}}while(0);E=(Q|0)!=-1;B=(P|0)==-1;if(!(B|E^1)){yDb(c[u>>2]|0,16,2000440,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=-1094995529;i=h;return l|0}do{if(!B){C=c[p>>2]|0;A=c[r>>2]|0;y=A-C|0;if((P|0)<0){X=0}else{X=(y|0)<(P|0)?y:P}y=C+X|0;c[o>>2]=y;if((A-y|0)<4){Y=0}else{c[o>>2]=C+(X+4);C=y;Y=fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0}C=jbb(k,Y,c[j+1060>>2]|0,c[j+1064>>2]|0,0)|0;if((C|0)<0){l=C}else{break}i=h;return l|0}}while(0);if(E){B=c[p>>2]|0;C=c[r>>2]|0;y=C-B|0;if((Q|0)<0){Z=0}else{Z=(y|0)<(Q|0)?y:Q}y=B+Z|0;c[o>>2]=y;do{if((C-y|0)<4){_=0;$=y}else{A=B+(Z+4)|0;c[o>>2]=A;z=y;x=fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0;if(!(x>>>0>1048576>>>0)){_=x;$=A;break}yDb(c[u>>2]|0,16,1963464,(n=i,i=i+8|0,c[n>>2]=x,n)|0);i=n;l=-1094995529;i=h;return l|0}}while(0);y=C-$|0;B=y>>>0>_>>>0?_:y;UGb(c[j+1060>>2]|0,$|0,B)|0;c[o>>2]=(c[o>>2]|0)+B}if((K|0)==-1){break}B=c[p>>2]|0;y=c[r>>2]|0;E=y-B|0;if((K|0)<0){aa=0}else{aa=(E|0)<(K|0)?E:K}E=B+aa|0;c[o>>2]=E;if((y-E|0)<4){ca=0}else{c[o>>2]=B+(aa+4);B=E;ca=fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0}B=j+1076|0;E=jbb(k,ca,c[B>>2]|0,c[s>>2]|0,1)|0;if((E|0)<0){l=E;i=h;return l|0}E=j+1052|0;y=c[E>>2]|0;x=(y|0)==4?4:3;A=j+1044|0;z=c[A>>2]|0;if((z|0)>0){w=j+1040|0;v=e+32|0;I=j+1056|0;F=e;H=j+1060|0;G=0;J=0;da=0;ea=0;fa=t;ga=c[w>>2]|0;ha=y;y=z;while(1){if((ga|0)>0){z=0;ia=J;ja=da;ka=ea;la=fa;ma=c[v>>2]|0;while(1){na=z+(ba(ma,G)|0)|0;oa=c[I>>2]|0;do{if((oa|0)==3){pa=ja;qa=-1;ra=ma}else if((oa|0)==1){sa=ka<<1;ta=c[B>>2]|0;ua=a[ta+sa|0]|0;va=a[ta+(sa|1)|0]|0;sa=((va&255)<<8|ua&255)>>>3<<x;ta=c[E>>2]|0;if(!(va<<24>>24==-1)){wa=sa;xa=ta;ya=59;break}if((ta|0)==0){pa=sa;qa=-1;ra=ma;break}va=~ua;ua=ta;ta=na;while(1){za=ua-1|0;a[(c[F>>2]|0)+ta|0]=va;a[(c[F>>2]|0)+(ta+1)|0]=va;a[(c[F>>2]|0)+(ta+2)|0]=va;a[(c[F>>2]|0)+(ta+3)|0]=va;Aa=c[v>>2]|0;if((za|0)==0){pa=sa;qa=-1;ra=Aa;break}else{ua=za;ta=Aa+ta|0}}}else if((oa|0)==2){ta=c[B>>2]|0;wa=((d[ta+la|0]|0)<<8|(d[ta+ka|0]|0))<<x;xa=c[E>>2]|0;ya=59}else{wa=ja;xa=ia;ya=59}}while(0);do{if((ya|0)==59){ya=0;oa=xa-1|0;if((xa|0)==0){pa=wa;qa=oa;ra=ma;break}else{Ba=na;Ca=wa;Da=oa}while(1){a[(c[F>>2]|0)+Ba|0]=a[(c[H>>2]|0)+Ca|0]|0;a[(c[F>>2]|0)+(Ba+1)|0]=a[(c[H>>2]|0)+(Ca+1)|0]|0;a[(c[F>>2]|0)+(Ba+2)|0]=a[(c[H>>2]|0)+(Ca+2)|0]|0;a[(c[F>>2]|0)+(Ba+3)|0]=a[(c[H>>2]|0)+(Ca+3)|0]|0;Ea=c[v>>2]|0;if((Da|0)==0){break}else{Ba=Ea+Ba|0;Ca=Ca+4|0;Da=Da-1|0}}pa=wa+(xa<<2)|0;qa=-1;ra=Ea}}while(0);na=z+4|0;Fa=ka+1|0;Ga=la+1|0;Ha=c[w>>2]|0;if((na|0)<(Ha|0)){z=na;ia=qa;ja=pa;ka=Fa;la=Ga;ma=ra}else{break}}Ia=qa;Ja=pa;Ka=Fa;La=Ga;Ma=Ha;Na=c[E>>2]|0;Oa=c[A>>2]|0}else{Ia=J;Ja=da;Ka=ea;La=fa;Ma=ga;Na=ha;Oa=y}ma=Na+G|0;if((ma|0)<(Oa|0)){G=ma;J=Ia;da=Ja;ea=Ka;fa=La;ga=Ma;ha=Na;y=Oa}else{break}}}y=(O|0)!=-1;ha=(N|0)==-1;if(!(ha|y^1)){yDb(c[u>>2]|0,16,1912104,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=-1094995529;i=h;return l|0}do{if(y){ga=c[p>>2]|0;fa=c[r>>2]|0;ea=fa-ga|0;if((O|0)<0){Pa=0}else{Pa=(ea|0)<(O|0)?ea:O}ea=ga+Pa|0;c[o>>2]=ea;do{if((fa-ea|0)<4){da=j+1072|0;Qa=0;Ra=da;Sa=c[da>>2]|0;Ta=ea}else{da=ga+(Pa+4)|0;c[o>>2]=da;J=ea;G=fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0;J=j+1072|0;A=c[J>>2]|0;if(!(G>>>0>(1048576-A|0)>>>0)){Qa=G;Ra=J;Sa=A;Ta=da;break}yDb(c[u>>2]|0,16,1891584,(n=i,i=i+8|0,c[n>>2]=G,n)|0);i=n;l=-1094995529;i=h;return l|0}}while(0);ea=j+1068|0;ga=fa-Ta|0;G=ga>>>0>Qa>>>0?Qa:ga;UGb((c[ea>>2]|0)+Sa|0,Ta|0,G)|0;c[o>>2]=(c[o>>2]|0)+G;c[Ra>>2]=(c[Ra>>2]|0)+Qa;G=j+1084|0;ga=(c[G>>2]|0)-1|0;c[G>>2]=ga;if((ga|0)>=1){break}UGb(c[j+1060>>2]|0,c[ea>>2]|0,c[Ra>>2]|0)|0;c[Ra>>2]=0;c[G>>2]=c[j+1088>>2]}}while(0);do{if(!ha){y=c[p>>2]|0;G=c[r>>2]|0;ea=G-y|0;if((N|0)<0){Ua=0}else{Ua=(ea|0)<(N|0)?ea:N}ea=y+Ua|0;c[o>>2]=ea;do{if((G-ea|0)<4){ga=j+1072|0;Va=0;Wa=ga;Xa=c[ga>>2]|0;Ya=ea}else{ga=y+(Ua+4)|0;c[o>>2]=ga;da=ea;A=fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0;da=j+1072|0;J=c[da>>2]|0;if(!(A>>>0>(1048576-J|0)>>>0)){Va=A;Wa=da;Xa=J;Ya=ga;break}yDb(c[u>>2]|0,16,2349120,(n=i,i=i+8|0,c[n>>2]=A,n)|0);i=n;l=-1094995529;i=h;return l|0}}while(0);ea=j+1068|0;y=G-Ya|0;fa=y>>>0>Va>>>0?Va:y;UGb((c[ea>>2]|0)+Xa|0,Ya|0,fa)|0;c[o>>2]=(c[o>>2]|0)+fa;c[Wa>>2]=(c[Wa>>2]|0)+Va;fa=j+1084|0;y=(c[fa>>2]|0)-1|0;c[fa>>2]=y;if((y|0)>=1){break}y=c[ea>>2]|0;ea=c[Wa>>2]|0;if(!((ea|0)>-1)){yDb(0,0,2240904,(n=i,i=i+24|0,c[n>>2]=2228824,c[n+8>>2]=2217040,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}c[o>>2]=y;c[p>>2]=y;c[r>>2]=y+ea;ea=jbb(k,c[Wa>>2]|0,c[j+1060>>2]|0,c[j+1064>>2]|0,0)|0;if((ea|0)<0){l=ea;i=h;return l|0}else{c[Wa>>2]=0;c[fa>>2]=c[j+1088>>2];break}}}while(0);UGb(c[e+4>>2]|0,j+16|0,1024)|0;c[e+304>>2]=1;c[f>>2]=1;l=c[m>>2]|0;i=h;return l|0}}while(0);yDb(c[u>>2]|0,16,1935376,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=-1094995529;i=h;return l|0}function ibb(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+1060|0);$Db(b+1068|0);$Db(b+1076|0);return 0}function jbb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;j=i;k=b+4|0;l=c[k>>2]|0;m=b+12|0;n=(c[m>>2]|0)-l|0;a:do{if((e|0)>0){o=b+8|0;p=0;q=l;b:while(1){r=c[o>>2]|0;if((r-q|0)<1){s=0;t=q}else{u=q+1|0;c[k>>2]=u;v=a[q]|0;if(v<<24>>24==-128){w=p;break a}else{s=v&255;t=u}}if((p|0)>=(g|0)){x=6;break}c:do{if((s|0)==254){if((r-t|0)<2){y=0;z=t}else{u=t+2|0;c[k>>2]=u;v=t;y=(d[v]|d[v+1|0]<<8)<<16>>16&65535;z=u}if((r-z|0)<1){A=0}else{c[k>>2]=z+1;A=a[z]|0}u=y+p|0;if((u|0)>(g|0)){x=23;break b}TGb(f+p|0,A|0,y|0)|0;B=u}else if((s|0)==255){if((r-t|0)<2){C=0;D=t}else{u=t+2|0;c[k>>2]=u;v=t;C=(d[v]|d[v+1|0]<<8)<<16>>16&65535;D=u}if((r-D|0)<2){E=0}else{c[k>>2]=D+2;u=D;E=(d[u]|d[u+1|0]<<8)<<16>>16&65535}u=C+p|0;if((u|0)>(g|0)){x=13;break b}if((E+C|0)>(g|0)){x=16;break b}if((C|0)==0){B=u;break}else{F=0}while(1){a[f+(F+p)|0]=a[f+(F+E)|0]|0;v=F+1|0;if((v|0)<(C|0)){F=v}else{B=u;break}}}else{if((s&192|0)==192){G=(s&63)+3|0;if((r-t|0)<2){H=0}else{c[k>>2]=t+2;u=t;H=(d[u]|d[u+1|0]<<8)<<16>>16&65535}u=G+p|0;if((u|0)>(g|0)){x=30;break b}if((H+G|0)>(g|0)){x=32;break b}else{I=0}while(1){a[f+(I+p)|0]=a[f+(I+H)|0]|0;v=I+1|0;if((v|0)<(G|0)){I=v}else{B=u;break c}}}if(s>>>0>128>>>0){J=s&63;u=J+p|0;if((u|0)>(g|0)){x=36;break b}v=r-t|0;K=v>>>0>J>>>0?J:v;UGb(f+p|0,t|0,K)|0;c[k>>2]=(c[k>>2]|0)+K;B=u;break}L=(s>>>4&7)+3|0;if((r-t|0)<1){M=0}else{c[k>>2]=t+1;M=d[t]|0}N=M|s<<8&3840;u=L+p|0;if((u|0)>(g|0)){x=41;break b}K=p-N|0;if((K|0)<0){x=44;break b}if((K+L|0)>(g|0)){x=44;break b}else{O=0}while(1){a[f+(O+p)|0]=a[f+(O+K)|0]|0;v=O+1|0;if((v|0)<(L|0)){O=v}else{B=u;break}}}}while(0);r=c[k>>2]|0;if((n+r-(c[m>>2]|0)|0)<(e|0)){p=B;q=r}else{w=B;break a}}if((x|0)==6){yDb(c[b>>2]|0,16,2328928,(P=i,i=i+16|0,c[P>>2]=p,c[P+8>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==13){q=b|0;yDb(c[q>>2]|0,16,2304520,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;yDb(c[q>>2]|0,16,2286632,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=C,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==16){q=b|0;yDb(c[q>>2]|0,16,2304520,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;yDb(c[q>>2]|0,16,2270624,(P=i,i=i+24|0,c[P>>2]=E,c[P+8>>2]=C,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==23){q=b|0;yDb(c[q>>2]|0,16,2304520,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;yDb(c[q>>2]|0,16,2286632,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=y,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==30){q=b|0;yDb(c[q>>2]|0,16,2304520,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;yDb(c[q>>2]|0,16,2286632,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=G,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==32){q=b|0;yDb(c[q>>2]|0,16,2304520,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;yDb(c[q>>2]|0,16,2270624,(P=i,i=i+24|0,c[P>>2]=H,c[P+8>>2]=G,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==36){q=b|0;yDb(c[q>>2]|0,16,2304520,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;yDb(c[q>>2]|0,16,2286632,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=J,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==41){q=b|0;yDb(c[q>>2]|0,16,2304520,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;yDb(c[q>>2]|0,16,2286632,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=L,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==44){q=b|0;yDb(c[q>>2]|0,16,2304520,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;yDb(c[q>>2]|0,16,2270624,(P=i,i=i+24|0,c[P>>2]=N,c[P+8>>2]=L,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}}else{w=0}}while(0);if(!((h|0)!=0&(w|0)<(g|0))){Q=0;i=j;return Q|0}yDb(c[b>>2]|0,16,2255280,(P=i,i=i+16|0,c[P>>2]=w,c[P+8>>2]=g,P)|0);i=P;TGb(f+w|0,0,g-w|0)|0;Q=0;i=j;return Q|0}function kbb(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+60>>2]=0;return 0}function lbb(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0;k=i;i=i+56|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+32|0;q=k+48|0;r=e+60|0;s=c[r>>2]|0;t=c[j+24>>2]|0;u=j+28|0;j=c[u>>2]|0;v=f;if((j|0)<33){w=-1094995529;i=k;return w|0}x=s+64|0;c[x>>2]=0;y=s+72|0;c[y>>2]=0;z=t+20|0;A=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;c[s+68>>2]=A;s=t+24|0;z=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;if((A-1|0)>>>0>131071>>>0){yDb(e,16,2178464,(B=i,i=i+8|0,c[B>>2]=A,B)|0);i=B;w=-1094995529;i=k;return w|0}do{if((z&128|0)==0){A=z&3;s=e+420|0;if(A>>>0<2>>>0){c[s>>2]=6;break}else{c[s>>2]=7;c[e+796>>2]=(A<<3)+8;break}}else{c[e+420>>2]=8}}while(0);z=q|0;A=p|0;s=p+4|0;C=p+8|0;D=e+420|0;E=e;G=e+416|0;H=e+448|0;I=q+1|0;J=q+2|0;K=q+3|0;q=e+412|0;L=f+76|0;M=f+64|0;f=e+696|0;N=j;j=t;a:while(1){t=j+4|0;O=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;P=O-12|0;t=j+20|0;Q=N-20|0;R=c[x>>2]|0;if((P|0)<1|(P|0)>(Q|0)){S=11;break}T=c[r>>2]|0;c[A>>2]=v;c[s>>2]=0;c[C>>2]=0;U=T+60|0;V=c[U>>2]|0;if((V|0)<=(R|0)){W=T;if((V|0)==14){S=18;break}V=cEb(1644)|0;c[W+4+(c[U>>2]<<2)>>2]=V;V=c[U>>2]|0;X=W+4+(V<<2)|0;if((c[X>>2]|0)==0){S=18;break}c[U>>2]=V+1;c[c[X>>2]>>2]=c[T>>2];V=c[X>>2]|0;c[V+1608>>2]=0;c[V+1640>>2]=-1;c[V+1624>>2]=-1}V=c[T+4+(R<<2)>>2]|0;if((V|0)==0){S=20;break}TGb(V+84|0,0,1408)|0;TGb(V+1552|0,0,56)|0;X=V+1504|0;U=V+1516|0;W=V+1512|0;Y=V+1508|0;Z=V+44|0;c[Z>>2]=0;TGb(X|0,0,16)|0;if(!((P|0)>-1)){S=22;break}_=j+(O+8)|0;O=_;$=t;if((P|0)<4){aa=0;ca=t}else{da=t;aa=d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0;ca=j+24|0}da=V+76|0;c[da>>2]=aa;ea=c[T+68>>2]|0;if((aa|0)!=(ea|0)){S=26;break}if((O-ca|0)<4){fa=0;ga=ca}else{t=ca;fa=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;ga=ca+4|0}t=V+4|0;c[t>>2]=fa;ha=BFb(c[D>>2]|0)|0;ia=c[t>>2]|0;ja=ia<<3&24;ka=(ia&6144|0)==6144;la=ia>>>2&1^1;ma=V+8|0;c[ma>>2]=la;na=V+12|0;c[na>>2]=(ia&1073741824|0)==0?la:0;la=V+16|0;c[la>>2]=ia&16;oa=V+1524|0;c[oa>>2]=ia&8;pa=V+1528|0;c[pa>>2]=ia&512;qa=V+1520|0;c[qa>>2]=(ha<<3)-8-ja+(ia>>>13&31);ia=ja|7;ja=_Gb(1,0,ia|0)|0;ra=YGb(ja,F,-1,0)|0;ja=V+1532|0;c[ja>>2]=ra;ra=_Gb(-1|0,-1|0,ia|0)|0;ia=V+1536|0;c[ia>>2]=ra;if((O-ga|0)<4){sa=0;ta=ga}else{ra=ga;sa=d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0;ta=ga+4|0}ra=V+20|0;c[ra>>2]=sa;if((_|0)==(ta|0)){S=212;break}ua=V+80|0;va=(ha|0)==4;wa=V+1540|0;xa=V+1544|0;ya=V+1548|0;za=V+1612|0;Aa=V+1616|0;Ba=V+24|0;Ca=V+36|0;Da=V+40|0;Ea=V+28|0;Fa=V+32|0;Ga=V+72|0;Ha=V+1628|0;Ia=V+1632|0;Ja=V+52|0;Ka=V+64|0;La=V+68|0;Ma=V+56|0;Na=V+60|0;Oa=V+48|0;Pa=ta;Qa=0;Ra=0;Sa=0;Ta=0;Ua=0;Va=0;Wa=0;Xa=0;Ya=0;Za=0;b:while(1){if((O-Pa|0)<1){_a=0;$a=Pa}else{_a=d[Pa]|0;$a=Pa+1|0}if((O-$a|0)<1){ab=0;bb=$a}else{ab=d[$a]|0;bb=$a+1|0}if((_a&128|0)==0){cb=ab;db=bb}else{if((O-bb|0)<1){eb=0;fb=bb}else{eb=(d[bb]|0)<<8;fb=bb+1|0}if((O-fb|0)<1){gb=0;hb=fb}else{gb=(d[fb]|0)<<16;hb=fb+1|0}cb=eb|ab|gb;db=hb}ib=cb<<1;jb=(_a&64|0)!=0;kb=ib+(jb<<31>>31)|0;if((kb|0)<0){S=44;break}lb=db;mb=O-lb|0;if(mb>>>0<ib>>>0){S=46;break}c:do{switch(_a&63|0){case 3:{if((Za|0)==0){yDb(E,16,2328896,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;nb=0;ob=Ya;pb=Xa;qb=Wa;rb=Va;sb=Ua;tb=Ta;ub=Sa;vb=Ra;wb=Qa;xb=db;break c}yb=kb>>c[na>>2];do{if((yb|0)<=16){if((yb|0)>(c[ua>>2]|0)){break}if((yb|0)>0){zb=db;Ab=0;Bb=0}else{Cb=Za;Db=1;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=db;S=209;break c}while(1){do{if((O-zb|0)<1){Nb=Bb-1|0;Ob=(c[ua>>2]|0)+Nb|0;Pb=0;Qb=zb;Rb=Nb;Sb=Ob;Tb=V+84+(Ob*88|0)+8|0}else{Ob=zb+1|0;Nb=(d[zb]|0)<<24;Ub=Nb>>21;Vb=Bb-1|0;Wb=(c[ua>>2]|0)+Vb|0;Xb=V+84+(Wb*88|0)+8|0;if((Nb|0)<=0){Pb=Ub;Qb=Ob;Rb=Vb;Sb=Wb;Tb=Xb;break}Pb=(Ub+64>>7)+Ub|0;Qb=Ob;Rb=Vb;Sb=Wb;Tb=Xb}}while(0);c[Tb>>2]=Pb;do{if((c[na>>2]|0)==0){Yb=Qb}else{if((O-Qb|0)<1){Zb=0;_b=Qb}else{Zb=(d[Qb]|0)<<24>>21;_b=Qb+1|0}c[V+84+(Sb*88|0)+12>>2]=Zb;Xb=V+84+(((c[ua>>2]|0)+Rb|0)*88|0)+12|0;Wb=c[Xb>>2]|0;if((Wb|0)<=0){Yb=_b;break}c[Xb>>2]=(Wb+64>>7)+Wb;Yb=_b}}while(0);Wb=Ab+1|0;Xb=~Ab;if((Wb|0)<(yb|0)){zb=Yb;Ab=Wb;Bb=Xb}else{Cb=Za;Db=1;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=Yb;S=209;break c}}}}while(0);yDb(E,16,2304488,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;nb=Za;ob=Ya;pb=Xa;qb=Wa;rb=Va;sb=Ua;tb=Ta;ub=Sa;vb=Ra;wb=Qa;xb=db+(mb>>>0>ib>>>0?ib:mb)|0;break};case 9:{if((kb|0)!=4){yDb(E,16,2270592,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;yb=ib-4|0;nb=Za;ob=Ya;pb=Xa;qb=Wa;rb=Va;sb=Ua;tb=Ta;ub=Sa;vb=Ra;wb=Qa;xb=db+(mb>>>0>yb>>>0?yb:mb)|0;break c}yb=mb>>>0>4>>>0?4:mb;UGb(z|0,db|0,yb)|0;Xb=db+yb|0;yb=a[z]|0;do{if(yb<<24>>24==0){Wb=a[I]|0;if(!(Wb<<24>>24==0)){c[U>>2]=Wb&255;break}Wb=a[J]|0;if(!(Wb<<24>>24==0)){c[W>>2]=1;c[Y>>2]=1;c[U>>2]=Wb&255;break}Wb=a[K]|0;if(Wb<<24>>24==0){break}c[Y>>2]=1;c[U>>2]=Wb&255}else{c[X>>2]=yb&255}}while(0);if(!((c[oa>>2]|0)!=0&va)){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=Xb;S=209;break c}yb=c[qa>>2]|0;if((yb|0)>=8){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=Xb;S=209;break c}Wb=c[U>>2]|0;if((Wb|0)<=8){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=Xb;S=209;break c}c[qa>>2]=yb+8;c[U>>2]=Wb-8;c[ja>>2]=c[ja>>2]>>8;c[ia>>2]=c[ia>>2]>>8;Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=Xb;S=209;break};case 5:{Wb=c[na>>2]|0;yb=(Wb*6|0)+6|0;if((kb|0)!=(yb|0)){yDb(E,16,2286584,(B=i,i=i+16|0,c[B>>2]=yb,c[B+8>>2]=kb,B)|0);i=B;nb=Za;ob=Ya;pb=Xa;qb=Wa;rb=Va;sb=Ua;tb=Ta;ub=Sa;vb=Ra;wb=Qa;xb=db+(mb>>>0>ib>>>0?ib:mb)|0;break c}if((Wb|0)<0){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=1;Jb=Sa;Kb=Ra;Lb=Qa;Mb=db;S=209;break c}else{$b=db;ac=0}while(1){if((O-$b|0)<2){bc=0;cc=$b}else{Wb=$b;bc=(d[Wb]|d[Wb+1|0]<<8)<<16>>16;cc=$b+2|0}Wb=bc<<16>>16<0;yb=(Wb?-bc&65535:bc)<<16>>16;Vb=d[16648+(yb&255)|0]|0|256;Ob=yb>>>8<<16;yb=Ob>>16;if((Ob|0)>589824){dc=Vb<<yb-9}else{dc=Vb>>>((9-yb|0)>>>0)}c[V+1552+(ac*28|0)>>2]=Wb?-dc|0:dc;if((O-cc|0)<2){ec=0;fc=cc}else{Wb=cc;ec=(d[Wb]|d[Wb+1|0]<<8)<<16>>16;fc=cc+2|0}Wb=ec<<16>>16<0;yb=(Wb?-ec&65535:ec)<<16>>16;Vb=d[16648+(yb&255)|0]|0|256;Ob=yb>>>8<<16;yb=Ob>>16;if((Ob|0)>589824){gc=Vb<<yb-9}else{gc=Vb>>>((9-yb|0)>>>0)}c[V+1552+(ac*28|0)+4>>2]=Wb?-gc|0:gc;if((O-fc|0)<2){hc=0;ic=fc}else{Wb=fc;hc=(d[Wb]|d[Wb+1|0]<<8)<<16>>16;ic=fc+2|0}Wb=hc<<16>>16<0;yb=(Wb?-hc&65535:hc)<<16>>16;Vb=d[16648+(yb&255)|0]|0|256;Ob=yb>>>8<<16;yb=Ob>>16;if((Ob|0)>589824){jc=Vb<<yb-9}else{jc=Vb>>>((9-yb|0)>>>0)}c[V+1552+(ac*28|0)+8>>2]=Wb?-jc|0:jc;Wb=ac+1|0;if((Wb|0)>(c[na>>2]|0)){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=1;Jb=Sa;Kb=Ra;Lb=Qa;Mb=ic;S=209;break}else{$b=ic;ac=Wb}}break};case 13:{if((kb|0)<2){S=187;break a}if((mb|0)<1){kc=0;lc=db}else{kc=d[db]|0;lc=db+1|0}switch(kb|0){case 5:{if((O-lc|0)<4){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=0;Hb=kc;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=lc;S=209;break c}Xb=lc;Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0;Hb=kc;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=lc+4|0;S=209;break c;break};case 3:{if((O-lc|0)<2){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=0;Hb=kc;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=lc;S=209;break c}Xb=lc;Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=(d[Xb]|d[Xb+1|0]<<8)<<16>>16&65535;Hb=kc;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=lc+2|0;S=209;break c;break};case 7:{Xb=O-lc|0;Wb=Xb>>>0>1>>>0?1:Xb;Xb=lc+Wb|0;if((O-Xb|0)<1){mc=0;nc=Xb}else{mc=(d[Xb]|0)<<8&3840;nc=lc+(Wb+1)|0}Wb=mc|kc;if((O-nc|0)<2){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=0;Hb=Wb;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=nc;S=209;break c}Xb=nc;Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=(d[Xb]|d[Xb+1|0]<<8)<<16>>16&65535;Hb=Wb;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=nc+2|0;S=209;break c;break};case 4:{if((O-lc|0)<3){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=0;Hb=kc;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=lc;S=209;break c}Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=(d[lc+1|0]|0)<<8|(d[lc+2|0]|0)<<16|(d[lc]|0);Hb=kc;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=lc+3|0;S=209;break c;break};case 2:{if((O-lc|0)<1){Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=0;Hb=kc;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=lc;S=209;break c}Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=d[lc]|0;Hb=kc;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=lc+1|0;S=209;break c;break};default:{yDb(E,16,2217008,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=c[H>>2]|0;Hb=c[G>>2]|0;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=lc;S=209;break c}}break};case 4:{if((Za|0)==0){yDb(E,16,2328896,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;nb=0;ob=Ya;pb=Xa;qb=Wa;rb=Va;sb=Ua;tb=Ta;ub=Sa;vb=Ra;wb=Qa;xb=db;break c}Wb=c[ua>>2]|0;if((Wb|0)>0&(kb|0)>0){oc=db;pc=0;qc=Wb}else{Cb=Za;Db=Ya;Eb=Xa;Fb=1;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=db;S=209;break c}while(1){Wb=qc-1|0;Xb=V+84+(Wb*88|0)+4|0;yb=c[Xb>>2]|0;do{if((yb|0)>8){if((O-oc|0)<2){rc=0;sc=oc}else{Vb=oc;rc=(d[Vb]|d[Vb+1|0]<<8)<<16>>16;sc=oc+2|0}Vb=rc<<16>>16<0;Ob=(Vb?-rc&65535:rc)<<16>>16;Ub=d[16648+(Ob&255)|0]|0|256;Nb=Ob>>>8<<16;Ob=Nb>>16;if((Nb|0)>589824){tc=Ub<<Ob-9}else{tc=Ub>>>((9-Ob|0)>>>0)}c[V+84+(Wb*88|0)+16>>2]=Vb?-tc|0:tc;if((O-sc|0)<2){uc=0;vc=sc}else{Vb=sc;uc=(d[Vb]|d[Vb+1|0]<<8)<<16>>16;vc=sc+2|0}Vb=uc<<16>>16<0;Ob=(Vb?-uc&65535:uc)<<16>>16;Ub=d[16648+(Ob&255)|0]|0|256;Nb=Ob>>>8<<16;Ob=Nb>>16;if((Nb|0)>589824){wc=Ub<<Ob-9}else{wc=Ub>>>((9-Ob|0)>>>0)}c[V+84+(Wb*88|0)+20>>2]=Vb?-wc|0:wc;if((c[na>>2]|0)==0){xc=pc;yc=vc}else{if((O-vc|0)<2){zc=0;Ac=vc}else{Vb=vc;zc=(d[Vb]|d[Vb+1|0]<<8)<<16>>16;Ac=vc+2|0}Vb=zc<<16>>16<0;Ob=(Vb?-zc&65535:zc)<<16>>16;Ub=d[16648+(Ob&255)|0]|0|256;Nb=Ob>>>8<<16;Ob=Nb>>16;if((Nb|0)>589824){Bc=Ub<<Ob-9}else{Bc=Ub>>>((9-Ob|0)>>>0)}c[V+84+(Wb*88|0)+48>>2]=Vb?-Bc|0:Bc;if((O-Ac|0)<2){Cc=0;Dc=Ac}else{Vb=Ac;Cc=(d[Vb]|d[Vb+1|0]<<8)<<16>>16;Dc=Ac+2|0}Vb=Cc<<16>>16<0;Ob=(Vb?-Cc&65535:Cc)<<16>>16;Ub=d[16648+(Ob&255)|0]|0|256;Nb=Ob>>>8<<16;Ob=Nb>>16;if((Nb|0)>589824){Ec=Ub<<Ob-9}else{Ec=Ub>>>((9-Ob|0)>>>0)}c[V+84+(Wb*88|0)+52>>2]=Vb?-Ec|0:Ec;xc=pc+4|0;yc=Dc}Fc=xc+4|0;Gc=yc}else{if((yb|0)<0){if((O-oc|0)<2){Hc=0;Ic=oc}else{Vb=oc;Hc=(d[Vb]|d[Vb+1|0]<<8)<<16>>16;Ic=oc+2|0}Vb=Hc<<16>>16<0;Ob=(Vb?-Hc&65535:Hc)<<16>>16;Ub=d[16648+(Ob&255)|0]|0|256;Nb=Ob>>>8<<16;Ob=Nb>>16;if((Nb|0)>589824){Jc=Ub<<Ob-9}else{Jc=Ub>>>((9-Ob|0)>>>0)}c[V+84+(Wb*88|0)+16>>2]=Vb?-Jc|0:Jc;if((O-Ic|0)<2){Kc=0;Lc=Ic}else{Vb=Ic;Kc=(d[Vb]|d[Vb+1|0]<<8)<<16>>16;Lc=Ic+2|0}Vb=Kc<<16>>16<0;Ob=(Vb?-Kc&65535:Kc)<<16>>16;Ub=d[16648+(Ob&255)|0]|0|256;Nb=Ob>>>8<<16;Ob=Nb>>16;if((Nb|0)>589824){Mc=Ub<<Ob-9}else{Mc=Ub>>>((9-Ob|0)>>>0)}c[V+84+(Wb*88|0)+48>>2]=Vb?-Mc|0:Mc;Fc=pc+4|0;Gc=Lc;break}if((yb|0)>0){Vb=oc;Ob=0;while(1){if((O-Vb|0)<2){Nc=0;Oc=Vb}else{Ub=Vb;Nc=(d[Ub]|d[Ub+1|0]<<8)<<16>>16;Oc=Vb+2|0}Ub=Nc<<16>>16<0;Nb=(Ub?-Nc&65535:Nc)<<16>>16;Pc=d[16648+(Nb&255)|0]|0|256;Qc=Nb>>>8<<16;Nb=Qc>>16;if((Qc|0)>589824){Rc=Pc<<Nb-9}else{Rc=Pc>>>((9-Nb|0)>>>0)}c[V+84+(Wb*88|0)+16+(Ob<<2)>>2]=Ub?-Rc|0:Rc;if((c[na>>2]|0)==0){Sc=Oc}else{if((O-Oc|0)<2){Tc=0;Uc=Oc}else{Ub=Oc;Tc=(d[Ub]|d[Ub+1|0]<<8)<<16>>16;Uc=Oc+2|0}Ub=Tc<<16>>16<0;Nb=(Ub?-Tc&65535:Tc)<<16>>16;Pc=d[16648+(Nb&255)|0]|0|256;Qc=Nb>>>8<<16;Nb=Qc>>16;if((Qc|0)>589824){Vc=Pc<<Nb-9}else{Vc=Pc>>>((9-Nb|0)>>>0)}c[V+84+(Wb*88|0)+48+(Ob<<2)>>2]=Ub?-Vc|0:Vc;Sc=Uc}Ub=Ob+1|0;Wc=c[Xb>>2]|0;if((Ub|0)<(Wc|0)){Vb=Sc;Ob=Ub}else{break}}Xc=Sc;Yc=Wc<<1}else{Xc=oc;Yc=0}Fc=(ba(Yc,(c[na>>2]|0)+1|0)|0)+pc|0;Gc=Xc}}while(0);if((Wb|0)>0&(Fc|0)<(kb|0)){oc=Gc;pc=Fc;qc=Wb}else{Cb=Za;Db=Ya;Eb=Xa;Fb=1;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=Gc;S=209;break}}break};case 8:{if((kb|0)!=4){yDb(E,16,2255248,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;nb=Za;ob=Ya;pb=Xa;qb=Wa;rb=Va;sb=Ua;tb=Ta;ub=Sa;vb=Ra;wb=Qa;xb=db+(mb>>>0>ib>>>0?ib:mb)|0;break c}if((mb|0)<1){Zc=0;_c=db}else{Zc=d[db]|0;_c=db+1|0}c[wa>>2]=Zc;if((O-_c|0)<1){$c=0;ad=_c}else{$c=d[_c]|0;ad=_c+1|0}c[xa>>2]=$c;if((O-ad|0)<1){bd=0;cd=ad}else{bd=d[ad]|0;cd=ad+1|0}c[ya>>2]=bd;Xb=O-cd|0;Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=1;Lb=Qa;Mb=cd+(Xb>>>0>1>>>0?1:Xb)|0;S=209;break};case 6:{Xb=c[na>>2]|0;if((c[pa>>2]|0)==0|(Xb|0)<0){dd=kb;ed=db;fd=Xb}else{Xb=db;yb=0;Ob=kb;while(1){if((O-Xb|0)<2){gd=0;hd=Xb}else{Vb=Xb;gd=(d[Vb]|d[Vb+1|0]<<8)<<16>>16;hd=Xb+2|0}Vb=gd<<16>>16<0;Ub=(Vb?-gd&65535:gd)<<16>>16;Nb=d[16648+(Ub&255)|0]|0|256;Pc=Ub>>>8<<16;Ub=Pc>>16;if((Pc|0)>589824){id=Nb<<Ub-9}else{id=Nb>>>((9-Ub|0)>>>0)}c[V+1552+(yb*28|0)+12>>2]=Vb?-id|0:id;Vb=Ob-2|0;Ub=yb+1|0;Nb=c[na>>2]|0;if((Ub|0)>(Nb|0)){dd=Vb;ed=hd;fd=Nb;break}else{Xb=hd;yb=Ub;Ob=Vb}}}if((fd+1|0)>0){Ob=ed;yb=0;Xb=dd;while(1){if((O-Ob|0)<2){jd=0;kd=Ob}else{Vb=Ob;jd=((d[Vb]|d[Vb+1|0]<<8)<<16>>16&65535)<<16;kd=Ob+2|0}c[V+1552+(yb*28|0)+20>>2]=jd;Vb=Xb-2|0;Ub=yb+1|0;Nb=c[na>>2]|0;if((Ub|0)<(Nb+1|0)){Ob=kd;yb=Ub;Xb=Vb}else{ld=kd;md=Vb;nd=Nb;break}}}else{ld=ed;md=dd;nd=fd}Xb=(nd+1|0)>0;if((md|0)<=0){if(Xb){od=0}else{Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=1;Mb=ld;S=209;break c}while(1){c[V+1552+(od*28|0)+24>>2]=0;yb=od+1|0;if((yb|0)<((c[na>>2]|0)+1|0)){od=yb}else{Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=1;Mb=ld;S=209;break c}}}if(Xb){pd=ld;qd=0}else{Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=1;Mb=ld;S=209;break c}while(1){if((O-pd|0)<2){rd=0;sd=pd}else{yb=pd;rd=(d[yb]|d[yb+1|0]<<8)<<16>>16;sd=pd+2|0}yb=rd<<16>>16<0;Ob=(yb?-rd&65535:rd)<<16>>16;Nb=d[16648+(Ob&255)|0]|0|256;Vb=Ob>>>8<<16;Ob=Vb>>16;if((Vb|0)>589824){td=Nb<<Ob-9}else{td=Nb>>>((9-Ob|0)>>>0)}c[V+1552+(qd*28|0)+24>>2]=yb?-td|0:td;yb=qd+1|0;if((yb|0)<((c[na>>2]|0)+1|0)){pd=sd;qd=yb}else{Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=1;Mb=sd;S=209;break}}break};case 39:{if((kb|0)!=3){S=205;break a}if((mb|0)<3){Cb=Za;Db=Ya;Eb=0;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=db;S=209;break c}Cb=Za;Db=Ya;Eb=(d[db+1|0]|0)<<8|(d[db+2|0]|0)<<16|(d[db]|0);Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=db+3|0;S=209;break};case 2:{if((kb|0)>16){yDb(E,16,2349088,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;c[ua>>2]=0;nb=Za;ob=Ya;pb=Xa;qb=Wa;rb=Va;sb=Ua;tb=Ta;ub=Sa;vb=Ra;wb=Qa;xb=db+(mb>>>0>ib>>>0?ib:mb)|0;break c}c[ua>>2]=kb;if((kb|0)>0){ud=db;vd=0;wd=0;xd=kb}else{Cb=1;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=db;S=209;break c}while(1){if((O-ud|0)<1){yd=0;zd=ud}else{yd=d[ud]|0;zd=ud+1|0}Xb=wd-1|0;c[V+84+((Xb+xd|0)*88|0)+4>>2]=(yd&31)-5;yb=c[ua>>2]|0;c[V+84+((yb+Xb|0)*88|0)>>2]=yd>>>5;Xb=vd+1|0;Ob=~vd;if((Xb|0)<(yb|0)){ud=zd;vd=Xb;wd=Ob;xd=yb}else{Cb=1;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=zd;S=209;break}}break};case 10:{c[za>>2]=lb-$;yb=kb<<3;c[Aa>>2]=yb;Ob=kb>>>0>268435455>>>0?-8:yb;Xb=Ob>>>0>2147483639>>>0|(db|0)==0;Nb=Xb?0:db;Vb=Xb?0:Ob;c[Ba>>2]=Nb;c[Ca>>2]=Vb;c[Da>>2]=Vb+8;c[Ea>>2]=Nb+(Vb>>3);c[Fa>>2]=0;if(Xb){Ad=Xb?-1094995529:0;S=406;break b}c[Ga>>2]=yb;Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=1;Kb=Ra;Lb=Qa;Mb=db+(mb>>>0>kb>>>0?kb:mb)|0;S=209;break};case 12:{if((kb|0)<5){yDb(E,16,2240872,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;nb=Za;ob=Ya;pb=Xa;qb=Wa;rb=Va;sb=Ua;tb=Ta;ub=Sa;vb=Ra;wb=Qa;xb=db+(mb>>>0>kb>>>0?kb:mb)|0;break c}c[Ha>>2]=lb-$;yb=kb<<3;c[Ia>>2]=yb;Xb=kb>>>0>268435455>>>0?-8:yb;yb=Xb>>>0>2147483639>>>0|(db|0)==0;Vb=yb?0:db;Nb=yb?0:Xb;c[Ja>>2]=Vb;c[Ka>>2]=Nb;Xb=Nb+8|0;c[La>>2]=Xb;c[Ma>>2]=Vb+(Nb>>3);c[Na>>2]=0;if(yb){Ad=yb?-1094995529:0;S=406;break b}yb=Vb;Nb=(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24)&65535;yb=Xb>>>0>16>>>0?16:Xb;c[Na>>2]=yb;Ob=Vb+(yb>>>3)|0;Vb=d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0;Ob=yb+16|0;c[Na>>2]=Xb>>>0>Ob>>>0?Ob:Xb;c[Oa>>2]=Vb<<16|Nb;c[Z>>2]=1;Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=db+(mb>>>0>kb>>>0?kb:mb)|0;S=209;break};default:{Cb=Za;Db=Ya;Eb=Xa;Fb=Wa;Gb=Va;Hb=Ua;Ib=Ta;Jb=Sa;Kb=Ra;Lb=Qa;Mb=db+(mb>>>0>kb>>>0?kb:mb)|0;S=209}}}while(0);do{if((S|0)==209){S=0;if(!jb){nb=Cb;ob=Db;pb=Eb;qb=Fb;rb=Gb;sb=Hb;tb=Ib;ub=Jb;vb=Kb;wb=Lb;xb=Mb;break}mb=O-Mb|0;nb=Cb;ob=Db;pb=Eb;qb=Fb;rb=Gb;sb=Hb;tb=Ib;ub=Jb;vb=Kb;wb=Lb;xb=Mb+(mb>>>0>1>>>0?1:mb)|0}}while(0);if((_|0)==(xb|0)){Bd=wb;Dd=vb;Ed=ub;Fd=tb;Gd=sb;Hd=rb;Id=qb;Jd=pb;Kd=ob;Ld=nb;S=211;break}else{Pa=xb;Qa=wb;Ra=vb;Sa=ub;Ta=tb;Ua=sb;Va=rb;Wa=qb;Xa=pb;Ya=ob;Za=nb}}if((S|0)==44){S=0;yDb(E,16,1912064,(B=i,i=i+16|0,c[B>>2]=_a,c[B+8>>2]=kb,B)|0);i=B;Bd=Qa;Dd=Ra;Ed=Sa;Fd=Ta;Gd=Ua;Hd=Va;Id=Wa;Jd=Xa;Kd=Ya;Ld=Za;S=211}else if((S|0)==46){S=0;yDb(E,16,1891552,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;Bd=Qa;Dd=Ra;Ed=Sa;Fd=Ta;Gd=Ua;Hd=Va;Id=Wa;Jd=Xa;Kd=Ya;Ld=Za;S=211}do{if((S|0)==211){S=0;if((Ld|0)==0){S=212;break a}if((Kd|0)==0){S=214;break a}if((Id|0)==0){S=216;break a}if((Fd|0)==0){S=218;break a}if((c[oa>>2]|0)!=0&(Bd|0)==0){S=220;break a}if((Ed|0)==0){S=222;break a}if((Dd|0)==0){if((c[D>>2]|0)==8){S=225;break a}}do{if((c[Z>>2]|0)!=0){if((c[D>>2]|0)==8){break}Pa=ba(c[X>>2]|0,c[da>>2]|0)|0;if(((c[Ka>>2]|0)-(c[Na>>2]|0)|0)>=(Pa<<c[na>>2]|0)){break}yDb(E,16,2138096,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;c[Z>>2]=0}}while(0);Pa=T+72|0;O=c[Pa>>2]|0;if((O|0)==0){Ma=(c[t>>2]|0)>>>23&15;if((Ma|0)==15){if((Jd|0)==0){S=233;break a}else{Md=Jd}}else{Md=c[15512+(Ma<<2)>>2]|0}c[q>>2]=Md;do{if(ka){c[G>>2]=(c[ma>>2]|0)!=0?2:1;Ma=(c[ma>>2]|0)!=0;c[H>>2]=Ma?3:4;c[H+4>>2]=Ma?0:0}else{if((Gd|0)!=0){c[G>>2]=Gd}if((Hd|0)==0){break}c[H>>2]=Hd;c[H+4>>2]=(Hd|0)<0|0?-1:0}}while(0);c[L>>2]=(c[da>>2]|0)+1;Ma=W0a(e,p,0)|0;if((Ma|0)<0){Nd=Ma;break a}c[L>>2]=c[da>>2];Od=c[Pa>>2]|0}else{Od=O}Ma=c[ma>>2]|0;if((Ma+Od|0)>=(c[G>>2]|0)){yDb(E,24,2124976,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Ad=(c[f>>2]&8|0)!=0?-1094995529:0;S=406;break}Ia=c[M>>2]|0;$=c[Ia+(Od<<2)>>2]|0;Ha=Od+1|0;if((Ma|0)==0){Pd=0}else{Pd=c[Ia+(Ha<<2)>>2]|0}c[Pa>>2]=Ha+Ma;Ma=V+24|0;Ha=c[D>>2]|0;if((c[na>>2]|0)==0){Ia=V+1608|0;Ga=c[Ia>>2]|0;Fa=V+1624|0;Ea=c[Fa>>2]|0;Da=V+1640|0;c[o>>2]=c[Da>>2];c[V+1500>>2]=0;c[V+1492>>2]=0;c[V+1496>>2]=0;Ca=(Ha|0)==6;Ba=(Ha|0)==8;Aa=(Ha|0)==7;za=$;pa=$;ya=$;xa=Ea;Ea=Ga;Ga=0;d:while(1){wa=obb(V,Ma,0,n)|0;if((c[n>>2]|0)!=0){Qd=xa;Rd=Ga;S=385;break}if((c[ua>>2]|0)>0){if(Ca){va=wa;jb=0;while(1){mb=c[V+84+(jb*88|0)+4>>2]|0;if((mb|0)>8){lb=c[V+84+(jb*88|0)+16>>2]|0;if((mb&1|0)==0){Sd=(lb*3|0)-(c[V+84+(jb*88|0)+20>>2]|0)>>1}else{Sd=(lb<<1)-(c[V+84+(jb*88|0)+20>>2]|0)|0}c[V+84+(jb*88|0)+20>>2]=lb;Td=Sd;Ud=0}else{Td=c[V+84+(jb*88|0)+16+(Ea<<2)>>2]|0;Ud=mb+Ea&7}mb=V+84+(jb*88|0)+8|0;lb=c[mb>>2]|0;ib=((ba(lb,Td)|0)+512>>10)+va|0;if(!((Td|0)==0|(va|0)==0)){c[mb>>2]=lb-(ba(c[V+84+(jb*88|0)>>2]|0,((Td^va)>>>30&2)-1|0)|0)}c[V+84+(jb*88|0)+16+(Ud<<2)>>2]=ib;lb=jb+1|0;if((lb|0)<(c[ua>>2]|0)){va=ib;jb=lb}else{Vd=ib;break}}}else{jb=wa;va=0;while(1){ib=c[V+84+(va*88|0)+4>>2]|0;if((ib|0)>8){lb=c[V+84+(va*88|0)+16>>2]|0;if((ib&1|0)==0){Wd=(lb*3|0)-(c[V+84+(va*88|0)+20>>2]|0)>>1}else{Wd=(lb<<1)-(c[V+84+(va*88|0)+20>>2]|0)|0}c[V+84+(va*88|0)+20>>2]=lb;Xd=Wd;Yd=0}else{Xd=c[V+84+(va*88|0)+16+(Ea<<2)>>2]|0;Yd=ib+Ea&7}ib=V+84+(va*88|0)+8|0;lb=c[ib>>2]|0;mb=gHb(lb,(lb|0)<0|0?-1:0,Xd,(Xd|0)<0|0?-1:0)|0;Nb=YGb(mb,F,512,0)|0;mb=F;Vb=YGb(Nb>>>10|mb<<22,mb>>>10|0<<22,jb,0)|0;mb=Vb;if(!((Xd|0)==0|(jb|0)==0)){c[ib>>2]=lb-(ba(c[V+84+(va*88|0)>>2]|0,((Xd^jb)>>>30&2)-1|0)|0)}c[V+84+(va*88|0)+16+(Yd<<2)>>2]=mb;lb=va+1|0;if((lb|0)<(c[ua>>2]|0)){jb=mb;va=lb}else{Vd=mb;break}}}}else{Vd=0}va=Ea+1&7;Zd=Vd+(xa*3|0)|0;do{if(Ba){g[za>>2]=+pbb(V,o,Vd);_d=za+4|0;$d=ya;S=381}else{jb=c[X>>2]|0;do{if((jb|0)==0){ae=Vd}else{wa=Vd<<jb;if((c[Z>>2]|0)==0){ae=wa;break}mb=c[Na>>2]|0;if(((c[Ka>>2]|0)-mb|0)<(jb|0)){ae=wa;break}lb=c[La>>2]|0;ib=(c[Ja>>2]|0)+(mb>>>3)|0;Vb=32-jb|0;Nb=(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)>>>((mb&7)>>>0)<<Vb>>>(Vb>>>0);Vb=mb+jb|0;c[Na>>2]=lb>>>0>Vb>>>0?Vb:lb;lb=Nb|wa;c[o>>2]=(lb>>>16)+((c[o>>2]|0)*9|0)+((lb&65535)*3|0);ae=lb}}while(0);jb=c[Y>>2]&ae|c[W>>2];Wb=(jb+ae<<c[U>>2])-jb|0;do{if((c[oa>>2]|0)==0){be=Wb}else{jb=c[ia>>2]|0;lb=c[ja>>2]|0;if((Wb|0)<(jb|0)){be=jb;break}be=(Wb|0)>(lb|0)?lb:Wb}}while(0);Wb=be<<c[qa>>2];if(Aa){c[pa>>2]=Wb;lb=Ga+1|0;if((c[n>>2]|0)==0){ce=ya;de=pa+4|0;ee=za;fe=lb;break}else{Qd=Zd;Rd=lb;S=385;break d}}else{b[ya>>1]=Wb;_d=za;$d=ya+2|0;S=381;break}}}while(0);if((S|0)==381){S=0;ce=$d;de=pa;ee=_d;fe=Ga+1|0}if((fe|0)<(c[da>>2]|0)){za=ee;pa=de;ya=ce;xa=Zd;Ea=va;Ga=fe}else{S=384;break}}do{if((S|0)==384){S=0;c[Ia>>2]=0;c[Da>>2]=-1;c[Fa>>2]=-1;ge=Zd}else if((S|0)==385){S=0;c[Ia>>2]=0;c[Da>>2]=-1;c[Fa>>2]=-1;if((Rd|0)>=(c[da>>2]|0)){ge=Qd;break}Ga=BFb(Ha)|0;Ea=$+(ba(Ga,Rd)|0)|0;TGb(Ea|0,0,ba((c[da>>2]|0)-Rd|0,Ga)|0)|0;ge=Qd}}while(0);Fa=V|0;Da=c[Fa>>2]|0;do{if((c[Da+696>>2]&1|0)!=0){Ia=c[o>>2]|0;if((c[ra>>2]|0)==(ge|0)){if((c[Z>>2]|0)==0){break}if((c[Oa>>2]|0)==(Ia|0)){break}yDb(Da,16,2113336,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}else{yDb(Da,16,2119440,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}if((c[(c[Fa>>2]|0)+696>>2]&8|0)!=0){Nd=-1094995529;break a}}}while(0);if((c[ma>>2]|0)==0){break}UGb(Pd|0,$|0,ba(c[da>>2]|0,ha)|0)|0;break}Fa=V+1608|0;Da=c[Fa>>2]|0;Ia=V+1624|0;Ga=c[Ia>>2]|0;Ea=V+1640|0;c[m>>2]=c[Ea>>2];c[V+1500>>2]=0;c[V+1492>>2]=0;c[V+1496>>2]=0;xa=(Ha|0)==8;ya=(Ha|0)==7;pa=(Ha|0)==6;za=(Ha|0)!=6;Aa=Pd;Ba=$;Ca=Pd;Pa=$;O=Pd;Wb=$;lb=Ga;Ga=Da;Da=0;e:while(1){jb=obb(V,Ma,0,l)|0;if((c[l>>2]|0)!=0){he=lb;ie=Da;S=340;break}wa=obb(V,Ma,1,l)|0;if((c[l>>2]|0)!=0){he=lb;ie=Da;S=340;break}if((c[ua>>2]|0)>0){Nb=0;Vb=jb;mb=wa;while(1){ib=V+84+(Nb*88|0)|0;Xb=c[V+84+(Nb*88|0)+4>>2]|0;do{if((Xb|0)>0){if((Xb|0)>8){Ob=c[V+84+(Nb*88|0)+16>>2]|0;if((Xb&1|0)==0){yb=c[V+84+(Nb*88|0)+48>>2]|0;je=(yb*3|0)-(c[V+84+(Nb*88|0)+52>>2]|0)>>1;ke=(Ob*3|0)-(c[V+84+(Nb*88|0)+20>>2]|0)>>1;le=yb}else{yb=c[V+84+(Nb*88|0)+48>>2]|0;je=(yb<<1)-(c[V+84+(Nb*88|0)+52>>2]|0)|0;ke=(Ob<<1)-(c[V+84+(Nb*88|0)+20>>2]|0)|0;le=yb}c[V+84+(Nb*88|0)+20>>2]=Ob;c[V+84+(Nb*88|0)+52>>2]=le;me=je;ne=ke;oe=0}else{me=c[V+84+(Nb*88|0)+48+(Ga<<2)>>2]|0;ne=c[V+84+(Nb*88|0)+16+(Ga<<2)>>2]|0;oe=Xb+Ga&7}if(pa){Ob=c[V+84+(Nb*88|0)+8>>2]|0;yb=((ba(Ob,ne)|0)+512>>10)+Vb|0;Ub=c[V+84+(Nb*88|0)+12>>2]|0;pe=((ba(Ub,me)|0)+512>>10)+mb|0;qe=yb;re=Ub;se=Ob}else{Ob=c[V+84+(Nb*88|0)+8>>2]|0;Ub=gHb(Ob,(Ob|0)<0|0?-1:0,ne,(ne|0)<0|0?-1:0)|0;yb=YGb(Ub,F,512,0)|0;Ub=F;Pc=YGb(yb>>>10|Ub<<22,Ub>>>10|0<<22,Vb,0)|0;Ub=c[V+84+(Nb*88|0)+12>>2]|0;yb=gHb(Ub,(Ub|0)<0|0?-1:0,me,(me|0)<0|0?-1:0)|0;Qc=YGb(yb,F,512,0)|0;yb=F;te=YGb(Qc>>>10|yb<<22,yb>>>10|0<<22,mb,0)|0;pe=te;qe=Pc;re=Ub;se=Ob}if(!((ne|0)==0|(Vb|0)==0)){c[V+84+(Nb*88|0)+8>>2]=se-(ba(c[ib>>2]|0,((ne^Vb)>>>30&2)-1|0)|0)}if(!((me|0)==0|(mb|0)==0)){c[V+84+(Nb*88|0)+12>>2]=re-(ba(c[ib>>2]|0,((me^mb)>>>30&2)-1|0)|0)}c[V+84+(Nb*88|0)+16+(oe<<2)>>2]=qe;c[V+84+(Nb*88|0)+48+(oe<<2)>>2]=pe;ue=pe;ve=qe}else{if((Xb|0)==-1){if(za){Ob=c[V+84+(Nb*88|0)+8>>2]|0;Ub=c[V+84+(Nb*88|0)+16>>2]|0;Pc=gHb(Ub,(Ub|0)<0|0?-1:0,Ob,(Ob|0)<0|0?-1:0)|0;te=YGb(Pc,F,512,0)|0;Pc=F;yb=YGb(te>>>10|Pc<<22,Pc>>>10|0<<22,Vb,0)|0;we=yb;xe=Ub;ye=Ob}else{Ob=c[V+84+(Nb*88|0)+8>>2]|0;Ub=c[V+84+(Nb*88|0)+16>>2]|0;we=((ba(Ub,Ob)|0)+512>>10)+Vb|0;xe=Ub;ye=Ob}Ob=V+84+(Nb*88|0)+16|0;do{if(!((xe|0)==0|(Vb|0)==0)){Ub=c[ib>>2]|0;yb=V+84+(Nb*88|0)+8|0;if((xe^Vb|0)<0){Pc=ye-Ub|0;c[yb>>2]=Pc;if(!((Pc|0)<-1024)){break}c[yb>>2]=-1024;break}else{Pc=Ub+ye|0;c[yb>>2]=Pc;if((Pc|0)<=1024){break}c[yb>>2]=1024;break}}}while(0);if(za){yb=c[V+84+(Nb*88|0)+12>>2]|0;Pc=gHb(yb,(yb|0)<0|0?-1:0,we,(we|0)<0|0?-1:0)|0;Ub=YGb(Pc,F,512,0)|0;Pc=F;te=YGb(Ub>>>10|Pc<<22,Pc>>>10|0<<22,mb,0)|0;ze=te;Ae=yb}else{yb=c[V+84+(Nb*88|0)+12>>2]|0;ze=((ba(yb,we)|0)+512>>10)+mb|0;Ae=yb}do{if(!((we|0)==0|(mb|0)==0)){yb=c[ib>>2]|0;te=V+84+(Nb*88|0)+12|0;if((we^mb|0)<0){Pc=Ae-yb|0;c[te>>2]=Pc;if(!((Pc|0)<-1024)){break}c[te>>2]=-1024;break}else{Pc=yb+Ae|0;c[te>>2]=Pc;if((Pc|0)<=1024){break}c[te>>2]=1024;break}}}while(0);c[Ob>>2]=ze;ue=ze;ve=we;break}if(za){te=c[V+84+(Nb*88|0)+12>>2]|0;Pc=c[V+84+(Nb*88|0)+48>>2]|0;yb=gHb(Pc,(Pc|0)<0|0?-1:0,te,(te|0)<0|0?-1:0)|0;Ub=YGb(yb,F,512,0)|0;yb=F;Qc=YGb(Ub>>>10|yb<<22,yb>>>10|0<<22,mb,0)|0;Be=Qc;Ce=Pc;De=te}else{te=c[V+84+(Nb*88|0)+12>>2]|0;Pc=c[V+84+(Nb*88|0)+48>>2]|0;Be=((ba(Pc,te)|0)+512>>10)+mb|0;Ce=Pc;De=te}te=V+84+(Nb*88|0)+48|0;do{if(!((Ce|0)==0|(mb|0)==0)){Pc=c[ib>>2]|0;Qc=V+84+(Nb*88|0)+12|0;if((Ce^mb|0)<0){yb=De-Pc|0;c[Qc>>2]=yb;if(!((yb|0)<-1024)){break}c[Qc>>2]=-1024;break}else{yb=Pc+De|0;c[Qc>>2]=yb;if((yb|0)<=1024){break}c[Qc>>2]=1024;break}}}while(0);if((Xb|0)==-3){Ob=V+84+(Nb*88|0)+16|0;Qc=c[Ob>>2]|0;c[Ob>>2]=Be;Ee=Qc}else{Ee=Be}if(za){Qc=c[V+84+(Nb*88|0)+8>>2]|0;Ob=gHb(Qc,(Qc|0)<0|0?-1:0,Ee,(Ee|0)<0|0?-1:0)|0;yb=YGb(Ob,F,512,0)|0;Ob=F;Pc=YGb(yb>>>10|Ob<<22,Ob>>>10|0<<22,Vb,0)|0;Fe=Pc;Ge=Qc}else{Qc=c[V+84+(Nb*88|0)+8>>2]|0;Fe=((ba(Qc,Ee)|0)+512>>10)+Vb|0;Ge=Qc}do{if(!((Ee|0)==0|(Vb|0)==0)){Qc=c[ib>>2]|0;Pc=V+84+(Nb*88|0)+8|0;if((Ee^Vb|0)<0){Ob=Ge-Qc|0;c[Pc>>2]=Ob;if(!((Ob|0)<-1024)){break}c[Pc>>2]=-1024;break}else{Ob=Qc+Ge|0;c[Pc>>2]=Ob;if((Ob|0)<=1024){break}c[Pc>>2]=1024;break}}}while(0);c[te>>2]=Fe;ue=Be;ve=Fe}}while(0);ib=Nb+1|0;if((ib|0)<(c[ua>>2]|0)){Nb=ib;Vb=ve;mb=ue}else{He=ve;Ie=ue;break}}}else{He=jb;Ie=wa}mb=Ga+1&7;if((c[la>>2]|0)==0){Je=Ie;Ke=He}else{Vb=Ie-(He>>1)|0;Je=Vb;Ke=Vb+He|0}Le=((Ke+(lb*3|0)|0)*3|0)+Je|0;do{if(xa){g[Ba>>2]=+pbb(V,m,Ke);g[Aa>>2]=+pbb(V,m,Je);Me=Aa+4|0;Ne=Ba+4|0;Oe=O;Pe=Wb;S=336}else{Vb=c[X>>2]|0;Nb=(Vb|0)==0;do{if(Nb){Qe=Ke}else{va=Ke<<Vb;if((c[Z>>2]|0)==0){Qe=va;break}ib=c[Na>>2]|0;if(((c[Ka>>2]|0)-ib|0)<(Vb|0)){Qe=va;break}Xb=c[La>>2]|0;Pc=(c[Ja>>2]|0)+(ib>>>3)|0;Ob=32-Vb|0;Qc=(d[Pc]|d[Pc+1|0]<<8|d[Pc+2|0]<<16|d[Pc+3|0]<<24|0)>>>((ib&7)>>>0)<<Ob>>>(Ob>>>0);Ob=ib+Vb|0;c[Na>>2]=Xb>>>0>Ob>>>0?Ob:Xb;Xb=Qc|va;c[m>>2]=(Xb>>>16)+((c[m>>2]|0)*9|0)+((Xb&65535)*3|0);Qe=Xb}}while(0);Xb=c[Y>>2]|0;va=c[W>>2]|0;Qc=Xb&Qe|va;Ob=c[U>>2]|0;ib=(Qc+Qe<<Ob)-Qc|0;Qc=(c[oa>>2]|0)==0;do{if(Qc){Re=ib}else{Pc=c[ia>>2]|0;yb=c[ja>>2]|0;if((ib|0)<(Pc|0)){Re=Pc;break}Re=(ib|0)>(yb|0)?yb:ib}}while(0);ib=c[qa>>2]|0;yb=Re<<ib;if(ya){Pc=Pa+4|0;c[Pa>>2]=yb;Ub=c[X>>2]|0;do{if((Ub|0)==0){Se=Je}else{Te=Je<<Ub;if((c[Z>>2]|0)==0){Se=Te;break}Ue=c[Na>>2]|0;if(((c[Ka>>2]|0)-Ue|0)<(Ub|0)){Se=Te;break}Ve=c[La>>2]|0;We=(c[Ja>>2]|0)+(Ue>>>3)|0;Xe=32-Ub|0;Ye=(d[We]|d[We+1|0]<<8|d[We+2|0]<<16|d[We+3|0]<<24|0)>>>((Ue&7)>>>0)<<Xe>>>(Xe>>>0);Xe=Ue+Ub|0;c[Na>>2]=Ve>>>0>Xe>>>0?Xe:Ve;Ve=Ye|Te;c[m>>2]=(Ve>>>16)+((c[m>>2]|0)*9|0)+((Ve&65535)*3|0);Se=Ve}}while(0);Ub=c[Y>>2]&Se|c[W>>2];Ve=(Ub+Se<<c[U>>2])-Ub|0;do{if((c[oa>>2]|0)==0){Ze=Ve}else{Ub=c[ia>>2]|0;Te=c[ja>>2]|0;if((Ve|0)<(Ub|0)){Ze=Ub;break}Ze=(Ve|0)>(Te|0)?Te:Ve}}while(0);c[Ca>>2]=Ze<<c[qa>>2];Ve=Da+1|0;if((c[l>>2]|0)==0){_e=Wb;$e=O;af=Pc;bf=Ca+4|0;cf=Ba;df=Aa;ef=Ve;break}else{he=Le;ie=Ve;S=340;break e}}else{Ve=Wb+2|0;b[Wb>>1]=yb;do{if(Nb){ff=Je}else{Te=Je<<Vb;if((c[Z>>2]|0)==0){ff=Te;break}Ub=c[Na>>2]|0;if(((c[Ka>>2]|0)-Ub|0)<(Vb|0)){ff=Te;break}Ye=c[La>>2]|0;Xe=(c[Ja>>2]|0)+(Ub>>>3)|0;Ue=32-Vb|0;We=(d[Xe]|d[Xe+1|0]<<8|d[Xe+2|0]<<16|d[Xe+3|0]<<24|0)>>>((Ub&7)>>>0)<<Ue>>>(Ue>>>0);Ue=Ub+Vb|0;c[Na>>2]=Ye>>>0>Ue>>>0?Ue:Ye;Ye=We|Te;c[m>>2]=(Ye>>>16)+((c[m>>2]|0)*9|0)+((Ye&65535)*3|0);ff=Ye}}while(0);Vb=ff&Xb|va;Nb=(Vb+ff<<Ob)-Vb|0;do{if(Qc){gf=Nb}else{Vb=c[ia>>2]|0;yb=c[ja>>2]|0;if((Nb|0)<(Vb|0)){gf=Vb;break}gf=(Nb|0)>(yb|0)?yb:Nb}}while(0);b[O>>1]=gf<<ib;Me=Aa;Ne=Ba;Oe=O+2|0;Pe=Ve;S=336;break}}}while(0);if((S|0)==336){S=0;_e=Pe;$e=Oe;af=Pa;bf=Ca;cf=Ne;df=Me;ef=Da+1|0}if((ef|0)<(c[da>>2]|0)){Aa=df;Ba=cf;Ca=bf;Pa=af;O=$e;Wb=_e;lb=Le;Ga=mb;Da=ef}else{S=339;break}}do{if((S|0)==339){S=0;c[Fa>>2]=0;c[Ea>>2]=-1;c[Ia>>2]=-1;hf=Le}else if((S|0)==340){S=0;c[Fa>>2]=0;c[Ea>>2]=-1;c[Ia>>2]=-1;if((ie|0)>=(c[da>>2]|0)){hf=he;break}Da=BFb(Ha)|0;Ga=ba(Da,ie)|0;TGb($+Ga|0,0,ba((c[da>>2]|0)-ie|0,Da)|0)|0;TGb(Pd+Ga|0,0,ba((c[da>>2]|0)-ie|0,Da)|0)|0;hf=he}}while(0);jf=c[V>>2]|0;if((c[jf+696>>2]&1|0)==0){break}if((c[ra>>2]|0)!=(hf|0)){S=344;break a}if((c[Z>>2]|0)==0){break}if((c[Oa>>2]|0)!=(c[m>>2]|0)){S=347;break a}}}while(0);if((S|0)==406){S=0;if((Ad|0)<0){Nd=Ad;break}}c[x>>2]=(c[x>>2]|0)+1;Oa=Q-P|0;if((Oa|0)<33){S=411;break}else{N=Oa;j=_}}if((S|0)==11){yDb(E,16,2102176,(B=i,i=i+24|0,c[B>>2]=R,c[B+8>>2]=P,c[B+16>>2]=Q,B)|0);i=B;Q=c[r>>2]|0;P=Q+60|0;if((c[P>>2]|0)<=0){w=-1094995529;i=k;return w|0}j=Q+4|0;Q=0;while(1){N=c[j+(Q<<2)>>2]|0;c[N+1608>>2]=0;c[N+1640>>2]=-1;c[N+1624>>2]=-1;N=Q+1|0;if((N|0)<(c[P>>2]|0)){Q=N}else{w=-1094995529;break}}i=k;return w|0}else if((S|0)==18){yDb(E,16,2000400,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==20){yDb(E,16,1963424,(B=i,i=i+8|0,c[B>>2]=R,B)|0);i=B;Nd=-1094995529}else if((S|0)==22){yDb(0,0,2092760,(B=i,i=i+24|0,c[B>>2]=2087512,c[B+8>>2]=2082864,c[B+16>>2]=135,B)|0);i=B;Cd();return 0}else if((S|0)==26){yDb(E,16,1935320,(B=i,i=i+16|0,c[B>>2]=ea,c[B+8>>2]=aa,B)|0);i=B;Nd=-1094995529}else if((S|0)==187){yDb(E,16,2228784,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==205){yDb(E,16,2207672,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==212){yDb(E,16,2199400,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==214){yDb(E,16,2190760,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==216){yDb(E,16,2174144,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==218){yDb(E,16,2164144,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==220){yDb(E,16,2157240,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==222){yDb(E,16,2150480,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==225){yDb(E,16,2143544,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==233){yDb(E,16,2131456,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==344){yDb(jf,16,2119440,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==347){yDb(jf,16,2113336,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==411){if((c[y>>2]|0)==(c[G>>2]|0)){c[h>>2]=1;w=c[u>>2]|0;i=k;return w|0}else{yDb(e,16,2046104,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;w=-1094995529;i=k;return w|0}}B=c[r>>2]|0;r=B+60|0;if((c[r>>2]|0)<=0){w=Nd;i=k;return w|0}e=B+4|0;B=0;while(1){u=c[e+(B<<2)>>2]|0;c[u+1608>>2]=0;c[u+1640>>2]=-1;c[u+1624>>2]=-1;u=B+1|0;if((u|0)<(c[r>>2]|0)){B=u}else{w=Nd;break}}i=k;return w|0}function mbb(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;a=b+60|0;if((c[a>>2]|0)<=0){c[a>>2]=0;return 0}d=b+4|0;b=0;do{$Db(d+(b<<2)|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));c[a>>2]=0;return 0}function nbb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b+60|0;if((c[a>>2]|0)<=0){return}d=b+4|0;b=0;do{e=c[d+(b<<2)>>2]|0;c[e+1608>>2]=0;c[e+1640>>2]=-1;c[e+1624>>2]=-1;b=b+1|0;}while((b|0)<(c[a>>2]|0));return}function obb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=a+1552|0;l=a+1552+(e*28|0)|0;c[f>>2]=0;a:do{if((c[k>>2]|0)>>>0<2>>>0){m=a+1580|0;if(!((c[m>>2]|0)>>>0<2>>>0)){n=18;break}if((c[a+1492>>2]|0)!=0){n=18;break}if((c[a+1496>>2]|0)!=0){n=18;break}o=a+1500|0;p=c[o>>2]|0;if((p|0)!=0){q=p-1|0;c[o>>2]=q;if((q|0)==0){n=18;break}q=a+1552+(e*28|0)+12|0;p=c[q>>2]|0;c[q>>2]=p-(p+128>>8);r=0;i=g;return r|0}p=b+8|0;q=b|0;s=b+16|0;t=0;while(1){u=c[p>>2]|0;if((t|0)>=33){n=10;break}v=d[(c[q>>2]|0)+(u>>>3)|0]|0;w=((u|0)<(c[s>>2]|0))+u|0;c[p>>2]=w;if((v&1<<(u&7)|0)==0){n=12;break}else{t=t+1|0}}do{if((n|0)==10){x=(c[b+12>>2]|0)-u|0;y=u;n=13}else if((n|0)==12){v=(c[b+12>>2]|0)-w|0;if((t|0)>1){x=v;y=w;n=13;break}if((v|0)<0){break a}c[o>>2]=t;if((t|0)==0){n=18;break a}}}while(0);if((n|0)==13){v=t-1|0;if((x|0)<(v|0)){break}z=c[s>>2]|0;A=(c[q>>2]|0)+(y>>>3)|0;B=33-t|0;C=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((y&7)>>>0)<<B>>>(B>>>0);B=y+v|0;c[p>>2]=z>>>0>B>>>0?B:z;c[o>>2]=C|1<<v}TGb(k|0,0,12)|0;TGb(m|0,0,12)|0;v=a+1552+(e*28|0)+12|0;C=c[v>>2]|0;c[v>>2]=C-(C+128>>8);r=0;i=g;return r|0}else{n=18}}while(0);b:do{if((n|0)==18){k=a+1492|0;if((c[k>>2]|0)==0){y=b+8|0;x=b|0;w=b+16|0;u=0;while(1){C=c[y>>2]|0;if((u|0)>=33){D=C;break}v=d[(c[x>>2]|0)+(C>>>3)|0]|0;z=((C|0)<(c[w>>2]|0))+C|0;c[y>>2]=z;if((v&1<<(C&7)|0)==0){D=z;break}else{u=u+1|0}}m=c[b+12>>2]|0;if((m-D|0)<0){break}c:do{if((u|0)==16){o=0;p=D;while(1){if((o|0)>=33){n=25;break}t=d[(c[x>>2]|0)+(p>>>3)|0]|0;E=((p|0)<(c[w>>2]|0))+p|0;c[y>>2]=E;if((t&1<<(p&7)|0)==0){n=27;break}else{o=o+1|0;p=E}}do{if((n|0)==25){F=m-p|0;G=p}else if((n|0)==27){t=m-E|0;if((o|0)>=2){F=t;G=E;break}if((t|0)<0){break b}H=o+16|0;break c}}while(0);p=o-1|0;if((F|0)<(p|0)){break b}t=c[w>>2]|0;q=(c[x>>2]|0)+(G>>>3)|0;s=33-o|0;z=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((G&7)>>>0)<<s>>>(s>>>0);s=G+p|0;c[y>>2]=t>>>0>s>>>0?s:t;H=(z|1<<p)+16|0}else{H=u}}while(0);u=a+1496|0;y=c[u>>2]|0;x=H&1;c[u>>2]=x;I=((y|0)!=0)+(H>>1)|0;J=x^1}else{I=0;J=0}c[k>>2]=J;do{if((c[a+1524>>2]|0)!=0&(e|0)==0){x=a+12|0;y=c[x>>2]|0;do{if((y|0)<0){K=y;n=38}else{u=0;do{w=a+1552+(u*28|0)+20|0;m=(c[w>>2]|0)+(c[a+1552+(u*28|0)+24>>2]|0)|0;c[w>>2]=m;c[h+(u<<2)>>2]=m>>16;c[j+(u<<2)>>2]=(c[a+1552+(u*28|0)+12>>2]|0)+128>>8;u=u+1|0;L=c[x>>2]|0;}while((u|0)<=(L|0));if((L|0)!=0){K=L;n=38;break}M=a+1528|0}}while(0);if((n|0)==38){y=a+1528|0;do{if((c[y>>2]|0)!=0){o=h+4|0;u=(c[j+4>>2]|0)+1-(c[j>>2]|0)+(c[o>>2]|0)>>1;m=h|0;w=c[m>>2]|0;if((u|0)>(w|0)){c[o>>2]=w<<1;c[m>>2]=0;break}if((w|0)<(-u|0)){c[m>>2]=w<<1;c[o>>2]=0;break}else{c[o>>2]=u+w;c[m>>2]=w-u;break}}}while(0);if((K|0)<0){break}else{M=y}}u=0;do{do{if((c[M>>2]|0)==0){w=c[h+(u<<2)>>2]&65535;m=w<<16>>16<0;o=(m?-w&65535:w)<<16>>16;w=d[16648+(o&255)|0]|0|256;p=o>>>8<<16;o=p>>16;if((p|0)>589824){N=w<<o-9}else{N=w>>>((9-o|0)>>>0)}c[a+1552+(u*28|0)+16>>2]=m?-N|0:N}else{m=(c[j+(u<<2)>>2]|0)-(c[h+(u<<2)>>2]|0)|0;if(!((m|0)>-256)){c[a+1552+(u*28|0)+16>>2]=0;break}o=m+256&65535;m=o<<16>>16<0;w=(m?-o&65535:o)<<16>>16;o=d[16648+(w&255)|0]|0|256;p=w>>>8<<16;w=p>>16;if((p|0)>589824){O=o<<w-9}else{O=o>>>((9-w|0)>>>0)}c[a+1552+(u*28|0)+16>>2]=m?-O|0:O}}while(0);u=u+1|0;}while((u|0)<=(c[x>>2]|0))}}while(0);do{if((I|0)==0){k=l|0;x=c[k>>2]|0;c[k>>2]=x-(((x+126|0)/128|0)<<1);P=x>>4;Q=0}else if((I|0)==1){x=l|0;k=c[x>>2]|0;u=a+1552+(e*28|0)+4|0;y=c[u>>2]|0;c[x>>2]=(((k+128|0)/128|0)*5|0)+k;c[u>>2]=y-(((y+62|0)/64|0)<<1);P=y>>4;Q=(k>>4)+1|0}else{k=l|0;y=c[k>>2]|0;u=a+1552+(e*28|0)+4|0;x=c[u>>2]|0;m=(y>>4)+2+(x>>4)|0;w=a+1552+(e*28|0)+8|0;o=c[w>>2]|0;p=o>>4;if((I|0)==2){c[k>>2]=(((y+128|0)/128|0)*5|0)+y;c[u>>2]=(((x+64|0)/64|0)*5|0)+x;c[w>>2]=o-(((o+30|0)/32|0)<<1);P=p;Q=m;break}else{z=(ba(p+1|0,I-2|0)|0)+m|0;c[k>>2]=(((y+128|0)/128|0)*5|0)+y;c[u>>2]=(((x+64|0)/64|0)*5|0)+x;c[w>>2]=(((o+32|0)/32|0)*5|0)+o;P=p;Q=z;break}}}while(0);z=a+1552+(e*28|0)+16|0;p=c[z>>2]|0;do{if((p|0)==0){if(P>>>0>33554431>>>0){yDb(c[a>>2]|0,16,2099120,(o=i,i=i+8|0,c[o>>2]=P,o)|0);i=o;break b}do{if((P|0)<1){R=0}else{o=P>>>0>65535>>>0;w=o?P>>>16:P;x=o?16:0;if((w&65280|0)==0){S=x;T=w}else{S=x|8;T=w>>>8}w=(d[1191992+T|0]|0)+S|0;x=(1<<w+1)-P|0;if((w|0)==0){U=0}else{o=b+8|0;u=c[o>>2]|0;y=c[b+16>>2]|0;k=(c[b>>2]|0)+(u>>>3)|0;m=32-w|0;t=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((u&7)>>>0)<<m>>>(m>>>0);m=u+w|0;c[o>>2]=y>>>0>m>>>0?m:y;U=t}if((U|0)<(x-1|0)){R=U;break}t=b+8|0;y=c[t>>2]|0;m=(d[(c[b>>2]|0)+(y>>>3)|0]|0)>>>((y&7)>>>0);c[t>>2]=((y|0)<(c[b+16>>2]|0))+y;R=1-x+(U<<1)+(m&1)|0}}while(0);m=c[b+8>>2]|0;if(((c[b+12>>2]|0)-m|0)<1){break b}V=R+Q|0;W=m}else{m=(Q<<1)+P+1>>1;x=b+8|0;if((P|0)<=(p|0)){V=m;W=c[x>>2]|0;break}y=b|0;t=b+16|0;o=c[b+12>>2]|0;w=Q;u=P;k=m;m=c[x>>2]|0;while(1){if((o-m|0)<1){break b}s=d[(c[y>>2]|0)+(m>>>3)|0]|0;q=((m|0)<(c[t>>2]|0))+m|0;c[x>>2]=q;C=(s&1<<(m&7)|0)==0;s=k-w|0;v=C?w:k;B=C?s-1|0:u-s|0;s=(v<<1)+B+1>>1;if((B|0)>(c[z>>2]|0)){w=v;u=B;k=s;m=q}else{V=s;W=q;break}}}}while(0);z=W&7;p=d[(c[b>>2]|0)+(W>>>3)|0]|0;c[b+8>>2]=((W|0)<(c[b+16>>2]|0))+W;if((c[a+1528>>2]|0)!=0){do{if((V|0)==1){X=256}else if((V|0)==0){X=0}else{m=(V>>9)+V|0;k=m>>>0>65535>>>0;u=k?m>>>16:m;w=k?16:0;if((u&65280|0)==0){Y=w;Z=u}else{Y=w|8;Z=u>>>8}u=(d[1191992+Z|0]|0)+Y|0;w=u+1|0;k=w<<8;if((w|0)<9){X=d[16136+(m<<8-u&255)|0]|0|k;break}else{X=d[16136+(m>>u-8&255)|0]|0|k;break}}}while(0);k=a+1552+(e*28|0)+12|0;u=c[k>>2]|0;c[k>>2]=u+X-(u+128>>8)}r=((p&1<<z|0)!=0)<<31>>31^V;i=g;return r|0}}while(0);c[f>>2]=1;r=0;i=g;return r|0}function pbb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,h=0,i=0.0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=c[a+1548>>2]|0;h=(c[a+44>>2]|0)==0;do{if(!h){if((128-(c[a+60>>2]|0)+(c[a+64>>2]|0)|0)<33){i=0.0}else{break}return+i}}while(0);do{if((e|0)==0){if(h){j=0;l=0;m=0;break}n=c[a+1540>>2]|0;if((n&8|0)==0){j=0;l=0;m=0;break}o=a+60|0;p=c[o>>2]|0;q=c[a+52>>2]|0;r=d[q+(p>>>3)|0]|0;s=c[a+68>>2]|0;t=((p|0)<(s|0))+p|0;c[o>>2]=t;if((r&1<<(p&7)|0)==0){if((n&16|0)==0){j=0;l=0;m=0;break}n=(d[q+(t>>>3)|0]|0)>>>((t&7)>>>0);c[o>>2]=((t|0)<(s|0))+t;j=0;l=0;m=n&1;break}n=q+(t>>>3)|0;p=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((t&7)>>>0)&8388607;n=t+23|0;t=s>>>0>n>>>0?n:s;c[o>>2]=t;if((f|0)>24){n=q+(t>>>3)|0;r=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((t&7)>>>0)&255;n=t+8|0;u=s>>>0>n>>>0?n:s;c[o>>2]=u;v=r;w=u}else{v=0;w=t}t=(d[q+(w>>>3)|0]|0)>>>((w&7)>>>0);c[o>>2]=((w|0)<(s|0))+w;j=p;l=v;m=t&1}else{t=e<<c[a+1544>>2];p=t>>>31;s=(t|0)<0?-t|0:t;a:do{if((s|0)>16777215){if(h){x=0;y=255;break}t=a+60|0;o=c[t>>2]|0;q=c[a+52>>2]|0;u=d[q+(o>>>3)|0]|0;r=c[a+68>>2]|0;n=((o|0)<(r|0))+o|0;c[t>>2]=n;if((u&1<<(o&7)|0)==0){x=0;y=255;break}o=q+(n>>>3)|0;q=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((n&7)>>>0)&8388607;o=n+23|0;c[t>>2]=r>>>0>o>>>0?o:r;x=q;y=255}else{if((f|0)==0){x=s;y=0;break}q=s>>>0>65535>>>0;r=q?s>>>16:s;o=q?16:0;if((r&65280|0)==0){z=o;A=r}else{z=o|8;A=r>>>8}r=23-z-(d[1191992+A|0]|0)|0;o=(f|0)>(r|0);q=f-1|0;t=o?r:q;r=(o?f:q)-t|0;if((t|0)==0){x=s;y=r;break}q=s<<t;o=c[a+1540>>2]|0;do{if((o&1|0)==0){if(h){x=q;y=r;break a}if((o&2|0)!=0){n=a+60|0;u=c[n>>2]|0;B=d[(c[a+52>>2]|0)+(u>>>3)|0]|0;c[n>>2]=((u|0)<(c[a+68>>2]|0))+u;if((B&1<<(u&7)|0)!=0){break}}if((o&4|0)==0){x=q;y=r;break a}u=a+60|0;B=c[u>>2]|0;n=c[a+68>>2]|0;C=(c[a+52>>2]|0)+(B>>>3)|0;D=32-t|0;E=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((B&7)>>>0)<<D>>>(D>>>0);D=B+t|0;c[u>>2]=n>>>0>D>>>0?D:n;x=E|q;y=r;break a}}while(0);x=(1<<t)-1|q;y=r}}while(0);j=x&8388607;l=y;m=p}}while(0);c[b>>2]=(l*3|0)+m+(j*9|0)+((c[b>>2]|0)*27|0);i=(c[k>>2]=l<<23|m<<31|j,+g[k>>2]);return+i}function qbb(a){a=a|0;var b=0,d=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=c[a+60>>2]|0;c[d+4>>2]=a;f=a+424|0;h=c[f>>2]|0;do{if((h|0)==0){j=c[a+412>>2]|0;if((j&1|0)==0){k=(j|0)/2|0}else{k=j}j=c[a+416>>2]|0;if((ba(j,k)|0)>15e4){l=k;while(1){m=(l|0)/2|0;if((ba(j,m)|0)>15e4){l=m}else{n=m;break}}}else{n=k}while(1){if((ba(j,n)|0)<4e4){n=n<<1}else{break}}c[f>>2]=n}else{if(!((h-128|0)>>>0>130944>>>0)){break}yDb(a,16,2000376,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;o=-22;i=b;return o|0}}while(0);h=a+84|0;a=c[h>>2]|0;do{if((a|0)==-1){p=c[d+448>>2]|0}else{if((a|0)<=2){if((a|0)==2){c[d+448>>2]=2;c[d+596>>2]=4;p=2;break}else if((a|0)==1){c[d+448>>2]=1;c[d+596>>2]=2;p=1;break}else{c[d+448>>2]=0;c[d+596>>2]=0;p=0;break}}c[d+448>>2]=3;c[d+596>>2]=9;n=c[h>>2]|0;if((n|0)>7){c[d+456>>2]=4;c[d+440>>2]=31;p=3;break}if((n|0)>6){c[d+456>>2]=3;c[d+440>>2]=15;p=3;break}if((n|0)>5){c[d+456>>2]=2;c[d+440>>2]=15;p=3;break}if((n|0)>4){c[d+456>>2]=1;c[d+440>>2]=15;p=3;break}if((n|0)<=3){p=3;break}c[d+456>>2]=1;c[d+440>>2]=11;p=3}}while(0);c[d+592>>2]=e[1402768+(p<<1)>>1]|0;c[d+2016>>2]=c[1402752+(p<<2)>>2];g[d+2020>>2]=2.0;o=0;i=b;return o|0}function rbb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+8|0;j=h|0;k=c[d+60>>2]|0;l=k;m=f+76|0;n=c[m>>2]|0;o=k+32|0;c[o>>2]=n;p=k+56|0;q=p;O$a(p,k+64|0,n<<2);if((c[q>>2]|0)==0){r=-12;i=h;return r|0}n=d+416|0;p=c[n>>2]|0;do{if((p|0)>1){s=k+60|0;O$a(s,k+68|0,c[o>>2]<<2);if((c[s>>2]|0)==0){r=-12;i=h;return r|0}else{t=c[n>>2]|0;break}}else{t=p}}while(0);p=ba(c[o>>2]<<3,t)|0;t=r0a(d,e,p,(p|0)<0|0?-1:0)|0;if((t|0)<0){r=t;i=h;return r|0}t=e+24|0;p=c[t>>2]|0;s=e+28|0;u=c[s>>2]|0;v=k+52|0;c[v>>2]=0;do{if((c[n>>2]|0)>0){w=k+4|0;x=k+460|0;y=f+64|0;z=k+60|0;A=u;B=p;C=0;while(1){D=0;while(1){if((D|0)>=15){E=10;break}F=c[w>>2]|0;if((c[15448+(D<<2)>>2]|0)==(c[F+412>>2]|0)){G=F;break}else{D=D+1|0}}if((E|0)==10){E=0;G=c[w>>2]|0}F=D<<23;c[x>>2]=F;H=c[G+420>>2]|0;do{if((H|0)==6){c[x>>2]=F|1;I=c[q>>2]|0;J=c[o>>2]|0;K=c[(c[y>>2]|0)+(C<<2)>>2]|0;if((J|0)>0){L=0}else{break}do{c[I+(L<<2)>>2]=b[K+(L<<1)>>1]|0;L=L+1|0;}while((L|0)<(J|0))}else if((H|0)==7){c[x>>2]=((c[G+796>>2]|0)<25|F)^3;J=c[(c[y>>2]|0)+(C<<2)>>2]|0;K=c[q>>2]|0;I=c[o>>2]|0;if((c[G+796>>2]|0)>=25){M=J;N=K;O=I;E=21;break}P=J;if((I|0)>0){Q=0}else{break}do{c[K+(Q<<2)>>2]=c[P+(Q<<2)>>2]>>8;Q=Q+1|0;}while((Q|0)<(I|0))}else if((H|0)==8){c[x>>2]=F|131;M=c[(c[y>>2]|0)+(C<<2)>>2]|0;N=c[q>>2]|0;O=c[o>>2]|0;E=21}else{I=c[(c[y>>2]|0)+(C<<2)>>2]|0;P=c[q>>2]|0;K=c[o>>2]|0;if((H|0)==5&(K|0)>0){R=0}else{break}do{c[P+(R<<2)>>2]=(a[I+R|0]|0)-128;R=R+1|0;}while((R|0)<(K|0))}}while(0);if((E|0)==21){E=0;UGb(N|0,M|0,O<<2)|0}H=c[v>>2]|0;F=c[x>>2]|0;a:do{if(((c[n>>2]|0)-H|0)==1){c[x>>2]=F|4}else{c[x>>2]=F|32;D=c[(c[y>>2]|0)+(H+1<<2)>>2]|0;K=c[z>>2]|0;I=c[o>>2]|0;P=c[w>>2]|0;J=c[P+420>>2]|0;do{if((J|0)==7){if((c[P+796>>2]|0)>=25){break}S=D;if((I|0)>0){T=0}else{break a}while(1){c[K+(T<<2)>>2]=c[S+(T<<2)>>2]>>8;T=T+1|0;if((T|0)>=(I|0)){break a}}}else if((J|0)==5){if((I|0)>0){U=0}else{break a}while(1){c[K+(U<<2)>>2]=(a[D+U|0]|0)-128;U=U+1|0;if((U|0)>=(I|0)){break a}}}else if((J|0)==6){S=D;if((I|0)>0){V=0}else{break a}while(1){c[K+(V<<2)>>2]=b[S+(V<<1)>>1]|0;V=V+1|0;if((V|0)>=(I|0)){break a}}}else if((J|0)!=8){break a}}while(0);UGb(K|0,D|0,I<<2)|0}}while(0);H=c[x>>2]|0;c[x>>2]=(H<<21&6291456|1835008)+H;H=tbb(l,c[q>>2]|0,c[z>>2]|0,B,A)|0;if((H|0)<0){r=H;E=37;break}W=B+H|0;F=c[v>>2]|0;if((F|0)<(c[n>>2]|0)){A=A-H|0;B=W;C=F}else{E=35;break}}if((E|0)==35){X=W;Y=c[t>>2]|0;break}else if((E|0)==37){i=h;return r|0}}else{X=p;Y=p}}while(0);p=k+40|0;c[p>>2]=(c[p>>2]|0)+(c[m>>2]|0);p=f+136|0;f=c[p+4>>2]|0;k=e+8|0;c[k>>2]=c[p>>2];c[k+4>>2]=f;c[s>>2]=X-Y;Y=c[m>>2]|0;c[j>>2]=1;c[j+4>>2]=c[d+412>>2];m=KDb(Y,(Y|0)<0|0?-1:0,j,d+104|0)|0;c[e+48>>2]=m;c[g>>2]=1;r=0;i=h;return r|0}function sbb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b+72|0;d=b+216|0;e=0;do{$Db(a+(e<<3)|0);$Db(a+(e<<3)+4|0);c[d+(e<<3)+4>>2]=0;c[d+(e<<3)>>2]=0;e=e+1|0;}while((e|0)<18);$Db(b+56|0);c[b+64>>2]=0;$Db(b+392|0);c[b+400>>2]=0;$Db(b+360|0);$Db(b+364|0);c[b+380>>2]=0;c[b+376>>2]=0;$Db(b+60|0);c[b+68>>2]=0;$Db(b+396|0);c[b+404>>2]=0;$Db(b+368|0);$Db(b+372|0);c[b+388>>2]=0;c[b+384>>2]=0;$Db(b+408|0);$Db(b+412|0);c[b+420>>2]=0;c[b+416>>2]=0;$Db(b+424|0);$Db(b+428|0);c[b+436>>2]=0;c[b+432>>2]=0;return 0}function tbb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0;j=i;i=i+128|0;k=j|0;l=j+32|0;m=j+64|0;n=j+96|0;o=c[b+32>>2]|0;p=b+460|0;q=c[p>>2]|0;do{if((q&4|0)==0){if((c[b+444>>2]|0)==0){r=q;break}else{s=0;t=0;u=0}while(1){if((u|0)>=(o|0)){v=s;w=t;break}y=c[e+(u<<2)>>2]|0;z=c[f+(u<<2)>>2]|0;A=y|t|z;B=y-z|s;if((A|0)==0|(B|0)==0){s=B;t=A;u=u+1|0}else{v=B;w=A;break}}if((w|0)!=0&(u|0)==(o|0)&(v|0)==0){A=q&-1073741873|1073741824;c[p>>2]=A;B=b+588|0;if((c[B>>2]|0)!=0){r=A;break}c[B>>2]=1;c[b+576>>2]=0;TGb(b+468|0,0,76)|0;r=A;break}else{A=b+588|0;if((c[A>>2]|0)==0){r=q;break}c[A>>2]=0;c[b+576>>2]=0;TGb(b+468|0,0,76)|0;r=q;break}}else{r=q}}while(0);q=r&253952;do{if((q|0)==0){C=r}else{v=q>>>13;u=r>>>18&31;w=(o|0)>0;do{if((r&1073741828|0)==0){if(w){D=0}else{break}do{t=e+(D<<2)|0;c[t>>2]=c[t>>2]>>v;t=f+(D<<2)|0;c[t>>2]=c[t>>2]>>v;D=D+1|0;}while((D|0)<(o|0))}else{if(w){E=0}else{break}do{t=e+(E<<2)|0;c[t>>2]=c[t>>2]>>v;E=E+1|0;}while((E|0)<(o|0))}}while(0);if((u-v|0)<0){w=c[p>>2]&-8126465;c[p>>2]=w;C=w;break}else{w=(c[p>>2]|0)-(q<<5)|0;c[p>>2]=w;C=w;break}}}while(0);do{if((C&128|0)!=0|(C&6291456)>>>0>6029312>>>0){q=b+424|0;E=o<<2;O$a(q,b+432|0,E);UGb(c[q>>2]|0,e|0,E)|0;q=c[p>>2]|0;if((q&1073741828|0)==0){D=b+428|0;O$a(D,b+436|0,E);UGb(c[D>>2]|0,f|0,E)|0;G=c[p>>2]|0}else{G=q}do{if((G&128|0)==0){q=b+547|0;E=b+546|0;D=b+545|0;r=b+544|0;w=r;x=0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;w=(o|0)>0;do{if((G&1073741828|0)==0){if(w){H=0;I=-1;J=-1;K=0;L=0;M=0}else{N=69;break}while(1){t=c[e+(K<<2)>>2]|0;s=c[f+(K<<2)>>2]|0;A=((s&65535)*3|0)+(s>>>16)+(((t>>>16)+(J*9|0)+((t&65535)*3|0)|0)*9|0)|0;B=t>>31^t|M|s>>31^s;z=t^-(t&1)|H|s^-(s&1);y=t&I&s;O=t|L|s;s=K+1|0;if((s|0)<(o|0)){H=z;I=y;J=A;K=s;L=O;M=B}else{P=B;Q=O;R=A;S=y;T=z;N=70;break}}}else{if(w){U=0;V=-1;W=-1;X=0;Y=0;Z=0}else{N=69;break}while(1){z=c[e+(X<<2)>>2]|0;y=(z>>>16)+(W*9|0)+((z&65535)*3|0)|0;A=z>>31^z|Z;O=z^-(z&1)|U;B=z&V;s=z|Y;z=X+1|0;if((z|0)<(o|0)){U=O;V=B;W=y;X=z;Y=s;Z=A}else{P=A;Q=s;R=y;S=B;T=O;N=70;break}}}}while(0);do{if((N|0)==69){c[b+464>>2]=-1;O=G&-8126465;c[p>>2]=O;_=O;$=0;aa=-1;ca=0}else if((N|0)==70){c[b+464>>2]=R;O=G&-8126465;c[p>>2]=O;if((P|0)==0){_=O;$=T;aa=S;ca=Q;break}else{da=P;ea=O}do{ea=ea+262144|0;da=da>>>1;}while((da|0)!=0);c[p>>2]=ea;_=ea;$=T;aa=S;ca=Q}}while(0);if((_&8126464|0)==0){c[p>>2]=_&-257;fa=0;break}do{if((ca&1|0)==0){O=ca;B=0;y=_;s=0;do{y=y-262144|0;s=s+1&255;B=B+1|0;O=O>>>1;}while((O&1|0)==0);c[p>>2]=y;a[D]=s;ga=B;ha=y}else{if((aa&1|0)!=0){O=0;A=aa;z=_;t=0;do{z=z-262144|0;t=t+1&255;O=O+1|0;A=A>>>1;}while((A&1|0)!=0);c[p>>2]=z;a[E]=t;ga=O;ha=z;break}if(($&2|0)==0){ia=0;ja=$;ka=_;la=0}else{ga=0;ha=_;break}do{ka=ka-262144|0;la=la+1&255;ia=ia+1|0;ja=ja>>>1;}while((ja&2|0)==0);c[p>>2]=ka;a[q]=la;ga=ia;ha=ka}}while(0);q=ha>>>18&31;if(q>>>0>23>>>0){E=q+233|0;a[r]=E;q=ha&-8126465|6029312;c[p>>2]=q;ma=(E&255)+ga|0;na=q}else{ma=ga;na=ha}do{if((ma|0)!=0){c[p>>2]=na|256;if((na&1073741828|0)==0){if(w){oa=0}else{break}do{q=e+(oa<<2)|0;c[q>>2]=c[q>>2]>>ma;q=f+(oa<<2)|0;c[q>>2]=c[q>>2]>>ma;oa=oa+1|0;}while((oa|0)<(o|0))}else{if(w){pa=0}else{break}do{q=e+(pa<<2)|0;c[q>>2]=c[q>>2]>>ma;pa=pa+1|0;}while((pa|0)<(o|0))}}}while(0);fa=d[r]|0}else{w=b+572|0;q=b+560|0;E=b+556|0;D=b+552|0;z=b+548|0;a[z]=0;O=b+549|0;a[O]=0;t=b+568|0;A=b+564|0;y=b+551|0;TGb(y|0,0,25)|0;B=(G&1073741828|0)==0;s=(o|0)>0;do{if(B){if(s){qa=0;ra=-1;sa=0}else{c[b+464>>2]=-1;break}while(1){ta=c[e+(qa<<2)>>2]|0;ua=ta>>>23;va=ua&255;if(va>>>0<=(sa&255)>>>0|(va|0)==255){wa=sa}else{xa=ua&255;a[y]=xa;wa=xa}xa=c[f+(qa<<2)>>2]|0;ua=xa>>>23;ya=ua&255;za=(xa>>>31)+(((ta>>>31)+(ra*27|0)+((ta&8388607)*9|0)+(va*3|0)|0)*27|0)+((xa&8388607)*9|0)+(ya*3|0)|0;if(ya>>>0<=(wa&255)>>>0|(ya|0)==255){Aa=wa}else{ya=ua&255;a[y]=ya;Aa=ya}ya=qa+1|0;if((ya|0)<(o|0)){qa=ya;ra=za;sa=Aa}else{Ba=za;N=36;break}}}else{if(s){Ca=0;Da=-1;Ea=0}else{c[b+464>>2]=-1;break}while(1){za=c[e+(Ca<<2)>>2]|0;ya=za>>>23;ua=ya&255;xa=(za>>>31)+(Da*27|0)+((za&8388607)*9|0)+(ua*3|0)|0;if(ua>>>0<=(Ea&255)>>>0|(ua|0)==255){Fa=Ea}else{ua=ya&255;a[y]=ua;Fa=ua}ua=Ca+1|0;if((ua|0)<(o|0)){Ca=ua;Da=xa;Ea=Fa}else{Ba=xa;N=36;break}}}}while(0);do{if((N|0)==36){c[b+464>>2]=Ba;if(B){if(s){Ga=0}else{break}do{Nbb(b,e+(Ga<<2)|0);Nbb(b,f+(Ga<<2)|0);Ga=Ga+1|0;}while((Ga|0)<(o|0))}else{if(s){Ha=0}else{break}do{Nbb(b,e+(Ha<<2)|0);Ha=Ha+1|0;}while((Ha|0)<(o|0))}}}while(0);a[b+550|0]=a[y]|0;do{if((c[q>>2]|0)==0){if((c[D>>2]|0)!=0){B=a[z]|0;if((c[E>>2]|0)==0){a[z]=B|1;break}else{a[z]=B|2;break}}B=c[w>>2]|0;if(!((B|0)!=0&(B&1|0)==0)){break}r=a[O]|0;xa=B;do{r=r+1&255;xa=xa>>1;}while((xa&1|0)==0);a[O]=r;c[w>>2]=xa;B=r&255;if((c[p>>2]&1073741828|0)==0){if(s){Ia=0}else{break}do{ua=e+(Ia<<2)|0;c[ua>>2]=c[ua>>2]>>B;ua=f+(Ia<<2)|0;c[ua>>2]=c[ua>>2]>>B;Ia=Ia+1|0;}while((Ia|0)<(o|0))}else{if(s){Ja=0}else{break}do{r=e+(Ja<<2)|0;c[r>>2]=c[r>>2]>>B;Ja=Ja+1|0;}while((Ja|0)<(o|0))}}else{a[z]=a[z]|4}}while(0);s=c[p>>2]&-8126465;c[p>>2]=s;O=c[w>>2]|0;if((O|0)!=0){E=s;s=O;do{E=E+262144|0;s=s>>1;}while((s|0)!=0);c[p>>2]=E;c[w>>2]=0}s=c[t>>2]|0;do{if((c[A>>2]|0)==0){O=a[z]|0;if((s|0)==0){Ka=O;break}a[z]=O|8;La=O;N=62}else{O=a[z]|0;D=O|8;a[z]=D;if((s|0)==0){Ka=D}else{La=O;N=62}}}while(0);if((N|0)==62){s=La|24;a[z]=s;Ka=s}fa=Ka&46}}while(0);c[b+576>>2]=0;Ma=fa}else{v=b+547|0;u=b+546|0;s=b+545|0;A=b+544|0;x=0;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;A=(o|0)>0;a:do{if((C&1073741828|0)==0){if(A){Na=-1;Oa=0;Pa=0;Qa=0;Ra=0}else{N=105;break}while(1){t=c[e+(Oa<<2)>>2]|0;w=c[f+(Oa<<2)>>2]|0;E=t>>31^t|Ra|w>>31^w;O=t^-(t&1)|Pa|w^-(w&1);D=t&Na&w;q=t|Qa|w;do{if((q&1|0)!=0){if((D&1|0)!=0){break}if((O&2|0)!=0){break a}}}while(0);w=Oa+1|0;if((w|0)<(o|0)){Na=D;Oa=w;Pa=O;Qa=q;Ra=E}else{Sa=E;Ta=q;Ua=O;Va=D;N=106;break}}}else{if(A){Wa=-1;Xa=0;Ya=0;Za=0;_a=0}else{N=105;break}while(1){z=c[e+(Xa<<2)>>2]|0;w=z>>31^z|_a;t=z^-(z&1)|Ya;y=z&Wa;B=z|Za;do{if((B&1|0)!=0){if((y&1|0)!=0){break}if((t&2|0)!=0){break a}}}while(0);D=Xa+1|0;if((D|0)<(o|0)){Wa=y;Xa=D;Ya=t;Za=B;_a=w}else{Sa=w;Ta=B;Ua=t;Va=y;N=106;break}}}}while(0);do{if((N|0)==105){D=C&-8126465;c[p>>2]=D;$a=D;ab=-1;bb=0;cb=0;N=109}else if((N|0)==106){D=C&-8126465;c[p>>2]=D;if((Sa|0)==0){$a=D;ab=Va;bb=Ua;cb=Ta;N=109;break}else{db=Sa;eb=D}do{eb=eb+262144|0;db=db>>>1;}while((db|0)!=0);c[p>>2]=eb;$a=eb;ab=Va;bb=Ua;cb=Ta;N=109}}while(0);b:do{if((N|0)==109){if(($a&8126464|0)==0){break}do{if((cb&1|0)==0){D=cb;O=0;q=$a;E=0;do{q=q-262144|0;E=E+1&255;O=O+1|0;D=D>>>1;}while((D&1|0)==0);c[p>>2]=q;a[s]=E;fb=O;gb=q}else{if((ab&1|0)!=0){D=0;y=ab;t=$a;B=0;do{t=t-262144|0;B=B+1&255;D=D+1|0;y=y>>>1;}while((y&1|0)!=0);c[p>>2]=t;a[u]=B;fb=D;gb=t;break}if((bb&2|0)==0){hb=bb;ib=0;jb=$a;kb=0}else{break b}do{jb=jb-262144|0;kb=kb+1&255;ib=ib+1|0;hb=hb>>>1;}while((hb&2|0)==0);c[p>>2]=jb;a[v]=kb;fb=ib;gb=jb}}while(0);if((fb|0)==0){break}c[p>>2]=gb|256;if((gb&1073741828|0)==0){if(A){lb=0}else{break}do{t=e+(lb<<2)|0;c[t>>2]=c[t>>2]>>fb;t=f+(lb<<2)|0;c[t>>2]=c[t>>2]>>fb;lb=lb+1|0;}while((lb|0)<(o|0))}else{if(A){mb=0}else{break}do{t=e+(mb<<2)|0;c[t>>2]=c[t>>2]>>fb;mb=mb+1|0;}while((mb|0)<(o|0))}}}while(0);A=b+580|0;t=(d[u]|0)+(d[s]|0)+(d[v]|0)|0;if((c[A>>2]|0)==(t|0)){Ma=0;break}c[A>>2]=t;c[b+576>>2]=0;Ma=0}}while(0);mb=b+596|0;fb=c[mb>>2]|0;do{if((fb|0)==0){if((c[b+576>>2]|0)!=0){nb=0;ob=0;break}c[mb>>2]=1;if((c[p>>2]&1073741828|0)==0){pb=vbb(b,e,f,1,0)|0}else{pb=ubb(b,e,1,0)|0}c[mb>>2]=0;nb=pb;ob=0}else{nb=0;ob=fb}}while(0);fb=(o|0)>0;do{if((c[p>>2]&1073741828|0)==0){if(fb){pb=0;lb=-1;while(1){gb=c[e+(pb<<2)>>2]|0;jb=(lb*9|0)+gb+(gb<<1)+(c[f+(pb<<2)>>2]|0)|0;gb=pb+1|0;if((gb|0)<(o|0)){pb=gb;lb=jb}else{qb=jb;break}}}else{qb=-1}if((ob|0)==0){rb=qb;sb=nb;break}rb=qb;sb=vbb(b,e,f,(c[b+576>>2]|0)==0|0,1)|0}else{if(fb){lb=0;pb=-1;while(1){v=(pb*3|0)+(c[e+(lb<<2)>>2]|0)|0;s=lb+1|0;if((s|0)<(o|0)){lb=s;pb=v}else{tb=v;break}}}else{tb=-1}if((ob|0)==0){rb=tb;sb=nb;break}rb=tb;sb=ubb(b,e,(c[b+576>>2]|0)==0|0,1)|0}}while(0);if((sb|0)<0){ub=sb;i=j;return ub|0}sb=b+52|0;tb=c[sb>>2]|0;nb=c[p>>2]|0;if((tb|0)==0){ob=nb|2048;c[p>>2]=ob;vb=ob}else{vb=nb}nb=2-(vb>>>2&1)+tb|0;c[sb>>2]=nb;sb=b+4|0;if((nb|0)==(c[(c[sb>>2]|0)+416>>2]|0)){c[p>>2]=vb|4096}if(!((h|0)>-1)){yDb(0,0,2178432,(vb=i,i=i+24|0,c[vb>>2]=2102160,c[vb+8>>2]=2046080,c[vb+16>>2]=145,vb)|0);i=vb;Cd();return 0}vb=g+h|0;do{if((h|0)>3){nb=g;x=1802532471;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=g+4|0;tb=vb;if((tb-nb|0)<=3){wb=nb;xb=1;break}ob=nb;x=0;a[ob]=x;x=x>>8;a[ob+1|0]=x;x=x>>8;a[ob+2|0]=x;x=x>>8;a[ob+3|0]=x;ob=g+8|0;if((tb-ob|0)<=1){wb=ob;xb=1;break}nb=ob;x=1040;a[nb]=x;x=x>>8;a[nb+1|0]=x;nb=g+10|0;if((tb-nb|0)<=1){wb=nb;xb=1;break}ob=nb;x=0;a[ob]=x;x=x>>8;a[ob+1|0]=x;ob=g+12|0;if((tb-ob|0)<=3){wb=ob;xb=1;break}nb=ob;x=0;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=g+16|0;if((tb-nb|0)<=3){wb=nb;xb=1;break}ob=nb;x=c[b+40>>2]|0;a[ob]=x;x=x>>8;a[ob+1|0]=x;x=x>>8;a[ob+2|0]=x;x=x>>8;a[ob+3|0]=x;ob=g+20|0;if((tb-ob|0)<=3){wb=ob;xb=1;break}nb=ob;x=o;a[nb]=x;x=x>>8;a[nb+1|0]=x;x=x>>8;a[nb+2|0]=x;x=x>>8;a[nb+3|0]=x;nb=g+24|0;if((tb-nb|0)<=3){wb=nb;xb=1;break}ob=nb;x=c[p>>2]|0;a[ob]=x;x=x>>8;a[ob+1|0]=x;x=x>>8;a[ob+2|0]=x;x=x>>8;a[ob+3|0]=x;ob=g+28|0;if((tb-ob|0)<=3){wb=ob;xb=1;break}tb=ob;x=rb;a[tb]=x;x=x>>8;a[tb+1|0]=x;x=x>>8;a[tb+2|0]=x;x=x>>8;a[tb+3|0]=x;wb=g+32|0;xb=0}else{wb=g;xb=1}}while(0);do{if((c[p>>2]&2048|0)==0){yb=wb;zb=xb}else{rb=(c[sb>>2]|0)+448|0;h=YGb(c[rb>>2]|0,c[rb+4>>2]|0,-3,-1)|0;rb=F;tb=0;if(rb>>>0<tb>>>0|rb>>>0==tb>>>0&h>>>0<2>>>0){yb=wb;zb=xb;break}if((xb|0)!=0){yb=wb;zb=1;break}h=vb;if((h-wb|0)<=0){yb=wb;zb=1;break}a[wb]=77;tb=wb+1|0;if((h-tb|0)<=0){yb=tb;zb=1;break}a[tb]=3;tb=wb+2|0;if((h-tb|0)<=0){yb=tb;zb=1;break}a[tb]=c[(c[sb>>2]|0)+416>>2];tb=wb+3|0;if((h-tb|0)<=3){yb=tb;zb=1;break}rb=tb;x=c[(c[sb>>2]|0)+448>>2]|0;a[rb]=x;x=x>>8;a[rb+1|0]=x;x=x>>8;a[rb+2|0]=x;x=x>>8;a[rb+3|0]=x;rb=wb+7|0;if((h-rb|0)<=0){yb=rb;zb=1;break}a[rb]=0;yb=wb+8|0;zb=0}}while(0);c:do{if((c[p>>2]&125829120|0)==125829120){do{if((zb|0)==0){wb=vb;if((wb-yb|0)<=0){Ab=yb;break}a[yb]=103;xb=yb+1|0;if((wb-xb|0)<=0){Ab=xb;break}a[xb]=2;xb=yb+2|0;rb=c[(c[sb>>2]|0)+412>>2]|0;if((wb-xb|0)<=2){Ab=xb;break}a[xb]=rb;a[yb+3|0]=rb>>>8;a[yb+4|0]=rb>>>16;rb=yb+5|0;if((wb-rb|0)<=0){Ab=rb;break}a[rb]=0;Bb=yb+6|0;N=176;break c}else{Ab=yb}}while(0);Cb=Ab;Db=1;Eb=b+576|0}else{Bb=yb;N=176}}while(0);do{if((N|0)==176){yb=b+576|0;Ab=c[yb>>2]|0;if((zb|0)!=0){Cb=Bb;Db=1;Eb=yb;break}sb=vb;if((sb-Bb|0)<=0){Cb=Bb;Db=1;Eb=yb;break}a[Bb]=Ab<<6&64|2;rb=Bb+1|0;if((sb-rb|0)<=0){Cb=rb;Db=1;Eb=yb;break}a[rb]=(Ab+1|0)>>>1;Cb=Bb+2|0;Db=0;Eb=yb}}while(0);Bb=c[Eb>>2]|0;if((Bb|0)>0){zb=vb;yb=Db;Ab=Cb;rb=0;sb=Bb;while(1){wb=(c[b+608+(rb*88|0)+4>>2]|0)+5&31|c[b+608+(rb*88|0)>>2]<<5;do{if((yb|0)==0){if((zb-Ab|0)<=0){Fb=Ab;Gb=1;Hb=sb;break}a[Ab]=wb;Fb=Ab+1|0;Gb=0;Hb=c[Eb>>2]|0}else{Fb=Ab;Gb=1;Hb=sb}}while(0);wb=rb+1|0;if((wb|0)<(Hb|0)){yb=Gb;Ab=Fb;rb=wb;sb=Hb}else{Ib=Gb;Jb=Fb;Kb=Hb;break}}}else{Ib=Db;Jb=Cb;Kb=Bb}do{if((Kb&1|0)==0){Lb=Jb;N=190}else{if((Ib|0)!=0){Mb=Jb;Nb=1;break}if((vb-Jb|0)<=0){Mb=Jb;Nb=1;break}a[Jb]=0;Lb=Jb+1|0;N=190}}while(0);do{if((N|0)==190){if((Ib|0)!=0){Mb=Lb;Nb=1;break}Jb=vb;if((Jb-Lb|0)<=0){Mb=Lb;Nb=1;break}a[Lb]=3;Kb=Lb+1|0;if((Jb-Kb|0)<=0){Mb=Kb;Nb=1;break}a[Kb]=0;Mb=Lb+2|0;Nb=0}}while(0);Lb=g;Ib=Mb-Lb|0;Kb=c[Eb>>2]|0;Jb=(Kb|0)>0;do{if(Jb){Bb=Kb;while(1){Cb=Bb-1|0;Db=c[b+608+(Cb*88|0)+8>>2]|0;do{if((Db|0)<-1024){Ob=-1024}else{Hb=(Db|0)>1024?1024:Db;if((Hb|0)<=0){Ob=Hb;break}Ob=Hb-(Hb+64>>7)|0}}while(0);if(!(((Ob+4|0)>>>3&255)<<24>>24==0)){Pb=Bb;break}if((c[p>>2]&1073741828|0)==0){Db=c[b+608+(Cb*88|0)+12>>2]|0;do{if((Db|0)<-1024){Qb=-1024}else{Hb=(Db|0)>1024?1024:Db;if((Hb|0)<=0){Qb=Hb;break}Qb=Hb-(Hb+64>>7)|0}}while(0);if(!(((Qb+4|0)>>>3&255)<<24>>24==0)){Pb=Bb;break}}if((Cb|0)>0){Bb=Cb}else{Pb=Cb;break}}if(!Jb){Rb=Nb;Sb=Mb;break}Bb=vb;Db=Nb;Hb=Mb;Fb=0;while(1){do{if((Fb|0)<(Pb|0)){Gb=b+608+(Fb*88|0)+8|0;sb=c[Gb>>2]|0;do{if((sb|0)<-1024){Tb=-1024}else{rb=(sb|0)>1024?1024:sb;if((rb|0)<=0){Tb=rb;break}Tb=rb-(rb+64>>7)|0}}while(0);sb=(Tb+4|0)>>>3;rb=sb<<24;do{if((Db|0)==0){if((Bb-Hb|0)<=0){Ub=Hb;Vb=1;break}a[Hb]=sb;Ub=Hb+1|0;Vb=0}else{Ub=Hb;Vb=1}}while(0);sb=rb>>21;if((rb|0)>0){Wb=(sb+64>>7)+sb|0}else{Wb=sb}c[Gb>>2]=Wb;if((c[p>>2]&1073741828|0)!=0){Xb=Ub;Yb=Vb;break}sb=b+608+(Fb*88|0)+12|0;Ab=c[sb>>2]|0;do{if((Ab|0)<-1024){Zb=-1024}else{yb=(Ab|0)>1024?1024:Ab;if((yb|0)<=0){Zb=yb;break}Zb=yb-(yb+64>>7)|0}}while(0);Ab=(Zb+4|0)>>>3;Gb=Ab<<24;do{if((Vb|0)==0){if((Bb-Ub|0)<=0){_b=Ub;$b=1;break}a[Ub]=Ab;_b=Ub+1|0;$b=0}else{_b=Ub;$b=1}}while(0);Ab=Gb>>21;if((Gb|0)>0){ac=(Ab+64>>7)+Ab|0}else{ac=Ab}c[sb>>2]=ac;Xb=_b;Yb=$b}else{c[b+608+(Fb*88|0)+12>>2]=0;c[b+608+(Fb*88|0)+8>>2]=0;Xb=Hb;Yb=Db}}while(0);Cb=Fb+1|0;if((Cb|0)<(c[Eb>>2]|0)){Db=Yb;Hb=Xb;Fb=Cb}else{Rb=Yb;Sb=Xb;break}}}else{Rb=Nb;Sb=Mb}}while(0);Mb=Sb;Nb=Mb-Lb-Ib|0;Xb=Nb&1;a[g+(Ib-2)|0]=Xb<<6|3;a[g+(Ib-1)|0]=(Nb+1|0)>>>1;do{if((Xb|0)==0){bc=Sb;N=232}else{if((Rb|0)!=0){cc=Sb;dc=1;break}if((vb-Mb|0)<=0){cc=Sb;dc=1;break}a[Sb]=0;bc=Sb+1|0;N=232}}while(0);do{if((N|0)==232){if((Rb|0)!=0){cc=bc;dc=1;break}Sb=vb;if((Sb-bc|0)<=0){cc=bc;dc=1;break}a[bc]=4;Mb=bc+1|0;if((Sb-Mb|0)<=0){cc=Mb;dc=1;break}a[Mb]=0;cc=bc+2|0;dc=0}}while(0);bc=cc;Rb=bc-Lb|0;if((c[Eb>>2]|0)>0){Mb=vb;Sb=dc;Xb=cc;Nb=0;while(1){do{if((Nb|0)==0){Ib=b+612|0;Yb=c[Ib>>2]|0;if((Yb|0)>8){$b=b+624|0;_b=(wbb(c[$b>>2]|0)|0)&65535;ac=_b<<16>>16<0;Ub=(ac?-_b&65535:_b)<<16>>16;Vb=d[16392+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){ec=Vb<<Ub-9}else{ec=Vb>>>((9-Ub|0)>>>0)}c[$b>>2]=ac?-ec|0:ec;do{if((Sb|0)==0){if((Mb-Xb|0)<=1){fc=Xb;gc=1;break}ac=Xb;x=_b;a[ac]=x;x=x>>8;a[ac+1|0]=x;fc=Xb+2|0;gc=0}else{fc=Xb;gc=1}}while(0);_b=b+628|0;ac=(wbb(c[_b>>2]|0)|0)&65535;$b=ac<<16>>16<0;Ub=($b?-ac&65535:ac)<<16>>16;Vb=d[16392+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){hc=Vb<<Ub-9}else{hc=Vb>>>((9-Ub|0)>>>0)}c[_b>>2]=$b?-hc|0:hc;do{if((gc|0)==0){if((Mb-fc|0)<=1){ic=fc;jc=1;break}$b=fc;x=ac;a[$b]=x;x=x>>8;a[$b+1|0]=x;ic=fc+2|0;jc=0}else{ic=fc;jc=1}}while(0);if((c[p>>2]&1073741828|0)!=0){kc=ic;lc=jc;break}ac=b+656|0;$b=(wbb(c[ac>>2]|0)|0)&65535;_b=$b<<16>>16<0;Ub=(_b?-$b&65535:$b)<<16>>16;Vb=d[16392+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){mc=Vb<<Ub-9}else{mc=Vb>>>((9-Ub|0)>>>0)}c[ac>>2]=_b?-mc|0:mc;do{if((jc|0)==0){if((Mb-ic|0)<=1){nc=ic;oc=1;break}_b=ic;x=$b;a[_b]=x;x=x>>8;a[_b+1|0]=x;nc=ic+2|0;oc=0}else{nc=ic;oc=1}}while(0);$b=b+660|0;_b=(wbb(c[$b>>2]|0)|0)&65535;ac=_b<<16>>16<0;Ub=(ac?-_b&65535:_b)<<16>>16;Vb=d[16392+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){pc=Vb<<Ub-9}else{pc=Vb>>>((9-Ub|0)>>>0)}c[$b>>2]=ac?-pc|0:pc;if((oc|0)!=0){kc=nc;lc=1;break}if((Mb-nc|0)<=1){kc=nc;lc=1;break}ac=nc;x=_b;a[ac]=x;x=x>>8;a[ac+1|0]=x;kc=nc+2|0;lc=0;break}if((Yb|0)<0){ac=b+624|0;_b=(wbb(c[ac>>2]|0)|0)&65535;$b=_b<<16>>16<0;Ub=($b?-_b&65535:_b)<<16>>16;Vb=d[16392+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){qc=Vb<<Ub-9}else{qc=Vb>>>((9-Ub|0)>>>0)}c[ac>>2]=$b?-qc|0:qc;do{if((Sb|0)==0){if((Mb-Xb|0)<=1){rc=Xb;sc=1;break}$b=Xb;x=_b;a[$b]=x;x=x>>8;a[$b+1|0]=x;rc=Xb+2|0;sc=0}else{rc=Xb;sc=1}}while(0);_b=b+656|0;$b=(wbb(c[_b>>2]|0)|0)&65535;ac=$b<<16>>16<0;Ub=(ac?-$b&65535:$b)<<16>>16;Vb=d[16392+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){tc=Vb<<Ub-9}else{tc=Vb>>>((9-Ub|0)>>>0)}c[_b>>2]=ac?-tc|0:tc;if((sc|0)!=0){kc=rc;lc=1;break}if((Mb-rc|0)<=1){kc=rc;lc=1;break}ac=rc;x=$b;a[ac]=x;x=x>>8;a[ac+1|0]=x;kc=rc+2|0;lc=0;break}if((Yb|0)>0){uc=Sb;vc=Xb;wc=0}else{kc=Xb;lc=Sb;break}while(1){ac=b+624+(wc<<2)|0;$b=(wbb(c[ac>>2]|0)|0)&65535;_b=$b<<16>>16<0;Ub=(_b?-$b&65535:$b)<<16>>16;Vb=d[16392+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){xc=Vb<<Ub-9}else{xc=Vb>>>((9-Ub|0)>>>0)}c[ac>>2]=_b?-xc|0:xc;do{if((uc|0)==0){if((Mb-vc|0)<=1){yc=vc;zc=1;break}_b=vc;x=$b;a[_b]=x;x=x>>8;a[_b+1|0]=x;yc=vc+2|0;zc=0}else{yc=vc;zc=1}}while(0);do{if((c[p>>2]&1073741828|0)==0){$b=b+656+(wc<<2)|0;sb=(wbb(c[$b>>2]|0)|0)&65535;Gb=sb<<16>>16<0;_b=(Gb?-sb&65535:sb)<<16>>16;ac=d[16392+(_b&255)|0]|0|256;Ub=_b>>>8<<16;_b=Ub>>16;if((Ub|0)>589824){Ac=ac<<_b-9}else{Ac=ac>>>((9-_b|0)>>>0)}c[$b>>2]=Gb?-Ac|0:Ac;if((zc|0)!=0){Bc=yc;Cc=1;break}if((Mb-yc|0)<=1){Bc=yc;Cc=1;break}Gb=yc;x=sb;a[Gb]=x;x=x>>8;a[Gb+1|0]=x;Bc=yc+2|0;Cc=0}else{Bc=yc;Cc=zc}}while(0);Gb=wc+1|0;if((Gb|0)<(c[Ib>>2]|0)){uc=Cc;vc=Bc;wc=Gb}else{kc=Bc;lc=Cc;break}}}else{TGb(b+608+(Nb*88|0)+16|0,0,64)|0;kc=Xb;lc=Sb}}while(0);Ib=Nb+1|0;if((Ib|0)<(c[Eb>>2]|0)){Sb=lc;Xb=kc;Nb=Ib}else{Dc=lc;Ec=kc;break}}}else{Dc=dc;Ec=cc}cc=Ec;a[g+(Rb-1)|0]=(cc-bc|0)>>>1;bc=(c[p>>2]&1073741828|0)==0;Rb=vb;do{if((Dc|0)==0){if((Rb-cc|0)<=0){Fc=Ec;Gc=1;break}a[Ec]=5;vb=Ec+1|0;if((Rb-vb|0)<=0){Fc=vb;Gc=1;break}a[vb]=bc?6:3;Fc=Ec+2|0;Gc=0}else{Fc=Ec;Gc=1}}while(0);Ec=Gc;Gc=Fc;Fc=0;while(1){bc=b+488+(Fc<<2)|0;cc=c[bc>>2]|0;do{if((cc|0)==1){Hc=256}else if((cc|0)==0){Hc=0}else{Dc=(cc>>9)+cc|0;vb=Dc>>>0>65535>>>0;dc=vb?Dc>>>16:Dc;kc=vb?16:0;if((dc&65280|0)==0){Ic=kc;Jc=dc}else{Ic=kc|8;Jc=dc>>>8}dc=(d[1191992+Jc|0]|0)+Ic|0;kc=dc+1|0;vb=kc<<8;if((kc|0)<9){Hc=(d[15880+(Dc<<8-dc&255)|0]|0|vb)&65535;break}else{Hc=(d[15880+(Dc>>dc-8&255)|0]|0|vb)&65535;break}}}while(0);do{if((Ec|0)==0){if((Rb-Gc|0)<=1){Kc=Gc;Lc=1;break}cc=Gc;x=Hc;a[cc]=x;x=x>>8;a[cc+1|0]=x;Kc=Gc+2|0;Lc=0}else{Kc=Gc;Lc=1}}while(0);cc=Hc<<16>>16<0;vb=(cc?-Hc&65535:Hc)<<16>>16;dc=d[16392+(vb&255)|0]|0|256;Dc=vb>>>8<<16;vb=Dc>>16;if((Dc|0)>589824){Mc=dc<<vb-9}else{Mc=dc>>>((9-vb|0)>>>0)}c[bc>>2]=cc?-Mc|0:Mc;cc=Fc+1|0;if((cc|0)<3){Ec=Lc;Gc=Kc;Fc=cc}else{break}}Fc=c[p>>2]|0;if((Fc&1073741828|0)==0){Gc=Lc;Ec=Kc;Mc=0;while(1){Hc=b+516+(Mc<<2)|0;Ic=c[Hc>>2]|0;do{if((Ic|0)==1){Nc=256}else if((Ic|0)==0){Nc=0}else{Jc=(Ic>>9)+Ic|0;cc=Jc>>>0>65535>>>0;vb=cc?Jc>>>16:Jc;dc=cc?16:0;if((vb&65280|0)==0){Oc=dc;Pc=vb}else{Oc=dc|8;Pc=vb>>>8}vb=(d[1191992+Pc|0]|0)+Oc|0;dc=vb+1|0;cc=dc<<8;if((dc|0)<9){Nc=(d[15880+(Jc<<8-vb&255)|0]|0|cc)&65535;break}else{Nc=(d[15880+(Jc>>vb-8&255)|0]|0|cc)&65535;break}}}while(0);do{if((Gc|0)==0){if((Rb-Ec|0)<=1){Qc=Ec;Rc=1;break}Ic=Ec;x=Nc;a[Ic]=x;x=x>>8;a[Ic+1|0]=x;Qc=Ec+2|0;Rc=0}else{Qc=Ec;Rc=1}}while(0);Ic=Nc<<16>>16<0;bc=(Ic?-Nc&65535:Nc)<<16>>16;cc=d[16392+(bc&255)|0]|0|256;vb=bc>>>8<<16;bc=vb>>16;if((vb|0)>589824){Sc=cc<<bc-9}else{Sc=cc>>>((9-bc|0)>>>0)}c[Hc>>2]=Ic?-Sc|0:Sc;Ic=Mc+1|0;if((Ic|0)<3){Gc=Rc;Ec=Qc;Mc=Ic}else{break}}Tc=Qc;Uc=Rc;Vc=c[p>>2]|0}else{Tc=Kc;Uc=Lc;Vc=Fc}do{if((Vc&128|0)==0){Wc=Tc;Xc=Uc}else{if((Uc|0)!=0){Wc=Tc;Xc=1;break}if((Rb-Tc|0)<=0){Wc=Tc;Xc=1;break}a[Tc]=8;Fc=Tc+1|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=2;Fc=Tc+2|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=a[b+548|0]|0;Fc=Tc+3|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=a[b+549|0]|0;Fc=Tc+4|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=a[b+550|0]|0;Fc=Tc+5|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=127;Wc=Tc+6|0;Xc=0}}while(0);do{if((c[p>>2]&256|0)==0){Yc=Wc;Zc=Xc}else{if((Xc|0)!=0){Yc=Wc;Zc=1;break}if((Rb-Wc|0)<=0){Yc=Wc;Zc=1;break}a[Wc]=9;Tc=Wc+1|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=2;Tc=Wc+2|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=a[b+544|0]|0;Tc=Wc+3|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=a[b+545|0]|0;Tc=Wc+4|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=a[b+546|0]|0;Tc=Wc+5|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=a[b+547|0]|0;Yc=Wc+6|0;Zc=0}}while(0);Wc=c[p>>2]|0;Xc=(c[mb>>2]|0)==0;do{if((Wc&1073741828|0)==0){if(!Xc){break}if((Wc&16|0)!=0&(o|0)>0){mb=0;do{Tc=f+(mb<<2)|0;Uc=e+(mb<<2)|0;Vc=(c[Uc>>2]|0)-(c[Tc>>2]|0)|0;c[Uc>>2]=Vc;c[Tc>>2]=(Vc>>1)+(c[Tc>>2]|0);mb=mb+1|0;}while((mb|0)<(o|0))}if((c[Eb>>2]|0)<=0){break}mb=k;Hc=l;Tc=(o|0)>0;Vc=0;do{Uc=b+608+(Vc*88|0)|0;d:do{if((c[p>>2]&4194304)>>>0>3932160>>>0){N=378}else{if((c[Uc>>2]|0)!=2){N=378;break}Fc=c[b+608+(Vc*88|0)+4>>2]|0;switch(Fc|0){case-3:{if(!Tc){break d}Lc=b+608+(Vc*88|0)+16|0;Kc=b+608+(Vc*88|0)+48|0;Rc=b+608+(Vc*88|0)+12|0;Qc=b+608+(Vc*88|0)+8|0;Mc=0;do{Ec=c[Lc>>2]|0;Gc=c[Kc>>2]|0;Sc=f+(Mc<<2)|0;Nc=c[Sc>>2]|0;c[Lc>>2]=Nc;Oc=(ba(c[Rc>>2]|0,Gc)|0)+512>>10;Pc=Nc-Oc|0;c[Sc>>2]=Pc;if(!((Gc|0)==0|(Nc|0)==(Oc|0))){Oc=(Pc^Gc)>>31;Gc=(c[Rc>>2]^Oc)+(2-Oc)|0;c[Rc>>2]=(((Gc|0)>1024?1024:Gc)^Oc)-Oc}Oc=e+(Mc<<2)|0;Gc=c[Oc>>2]|0;c[Kc>>2]=Gc;Pc=(ba(c[Qc>>2]|0,Ec)|0)+512>>10;Nc=Gc-Pc|0;c[Oc>>2]=Nc;if(!((Ec|0)==0|(Gc|0)==(Pc|0))){Pc=(Nc^Ec)>>31;Ec=(c[Qc>>2]^Pc)+(2-Pc)|0;c[Qc>>2]=(((Ec|0)>1024?1024:Ec)^Pc)-Pc}Mc=Mc+1|0;}while((Mc|0)<(o|0));break};case 18:{if(!Tc){break d}Mc=b+608+(Vc*88|0)+16|0;Qc=b+608+(Vc*88|0)+20|0;Kc=b+608+(Vc*88|0)+8|0;Rc=b+608+(Vc*88|0)+48|0;Lc=b+608+(Vc*88|0)+52|0;Pc=b+608+(Vc*88|0)+12|0;Ec=0;do{Nc=c[Mc>>2]|0;Gc=(Nc-(c[Qc>>2]|0)>>1)+Nc|0;c[Qc>>2]=Nc;Nc=e+(Ec<<2)|0;Oc=c[Nc>>2]|0;c[Mc>>2]=Oc;Sc=(ba(Gc,c[Kc>>2]|0)|0)+512>>10;Ic=Oc-Sc|0;c[Nc>>2]=Ic;if(!((Gc|0)==0|(Oc|0)==(Sc|0))){c[Kc>>2]=(c[Kc>>2]|0)+(-((Ic^Gc)>>>29&4)|2)}Gc=c[Rc>>2]|0;Ic=(Gc-(c[Lc>>2]|0)>>1)+Gc|0;c[Lc>>2]=Gc;Gc=f+(Ec<<2)|0;Sc=c[Gc>>2]|0;c[Rc>>2]=Sc;Oc=(ba(Ic,c[Pc>>2]|0)|0)+512>>10;Nc=Sc-Oc|0;c[Gc>>2]=Nc;if(!((Ic|0)==0|(Sc|0)==(Oc|0))){c[Pc>>2]=(c[Pc>>2]|0)+(-((Nc^Ic)>>>29&4)|2)}Ec=Ec+1|0;}while((Ec|0)<(o|0));break};case-2:{if(!Tc){break d}Ec=b+608+(Vc*88|0)+48|0;Pc=b+608+(Vc*88|0)+12|0;Rc=b+608+(Vc*88|0)+8|0;Lc=0;do{Kc=c[Ec>>2]|0;Mc=f+(Lc<<2)|0;Qc=c[Mc>>2]|0;Ic=(ba(c[Pc>>2]|0,Kc)|0)+512>>10;Nc=Qc-Ic|0;c[Mc>>2]=Nc;if(!((Kc|0)==0|(Qc|0)==(Ic|0))){Ic=(Nc^Kc)>>31;Kc=(c[Pc>>2]^Ic)+(2-Ic)|0;c[Pc>>2]=(((Kc|0)>1024?1024:Kc)^Ic)-Ic}Ic=e+(Lc<<2)|0;Kc=c[Ic>>2]|0;c[Ec>>2]=Kc;Nc=(ba(c[Rc>>2]|0,Qc)|0)+512>>10;Mc=Kc-Nc|0;c[Ic>>2]=Mc;if(!((Qc|0)==0|(Kc|0)==(Nc|0))){Nc=(Mc^Qc)>>31;Qc=(c[Rc>>2]^Nc)+(2-Nc)|0;c[Rc>>2]=(((Qc|0)>1024?1024:Qc)^Nc)-Nc}Lc=Lc+1|0;}while((Lc|0)<(o|0));break};case-1:{if(!Tc){break d}Lc=b+608+(Vc*88|0)+16|0;Rc=b+608+(Vc*88|0)+8|0;Ec=b+608+(Vc*88|0)+12|0;Pc=0;do{Nc=c[Lc>>2]|0;Qc=e+(Pc<<2)|0;Mc=c[Qc>>2]|0;Kc=(ba(c[Rc>>2]|0,Nc)|0)+512>>10;Ic=Mc-Kc|0;c[Qc>>2]=Ic;if(!((Nc|0)==0|(Mc|0)==(Kc|0))){Kc=(Ic^Nc)>>31;Nc=(c[Rc>>2]^Kc)+(2-Kc)|0;c[Rc>>2]=(((Nc|0)>1024?1024:Nc)^Kc)-Kc}Kc=f+(Pc<<2)|0;Nc=c[Kc>>2]|0;c[Lc>>2]=Nc;Ic=(ba(c[Ec>>2]|0,Mc)|0)+512>>10;Qc=Nc-Ic|0;c[Kc>>2]=Qc;if(!((Mc|0)==0|(Nc|0)==(Ic|0))){Ic=(Qc^Mc)>>31;Mc=(c[Ec>>2]^Ic)+(2-Ic)|0;c[Ec>>2]=(((Mc|0)>1024?1024:Mc)^Ic)-Ic}Pc=Pc+1|0;}while((Pc|0)<(o|0));break};case 17:{if(!Tc){break d}Pc=b+608+(Vc*88|0)+16|0;Ec=b+608+(Vc*88|0)+20|0;Lc=b+608+(Vc*88|0)+8|0;Rc=b+608+(Vc*88|0)+48|0;Ic=b+608+(Vc*88|0)+52|0;Mc=b+608+(Vc*88|0)+12|0;Qc=0;do{Nc=c[Pc>>2]|0;Kc=Nc<<1;Oc=c[Ec>>2]|0;Sc=Kc-Oc|0;c[Ec>>2]=Nc;Nc=e+(Qc<<2)|0;Gc=c[Nc>>2]|0;c[Pc>>2]=Gc;bc=(ba(c[Lc>>2]|0,Sc)|0)+512>>10;cc=Gc-bc|0;c[Nc>>2]=cc;if(!((Kc|0)==(Oc|0)|(Gc|0)==(bc|0))){c[Lc>>2]=(c[Lc>>2]|0)+(-((cc^Sc)>>>29&4)|2)}Sc=c[Rc>>2]|0;cc=Sc<<1;bc=c[Ic>>2]|0;Gc=cc-bc|0;c[Ic>>2]=Sc;Sc=f+(Qc<<2)|0;Oc=c[Sc>>2]|0;c[Rc>>2]=Oc;Kc=(ba(c[Mc>>2]|0,Gc)|0)+512>>10;Nc=Oc-Kc|0;c[Sc>>2]=Nc;if(!((cc|0)==(bc|0)|(Oc|0)==(Kc|0))){c[Mc>>2]=(c[Mc>>2]|0)+(-((Nc^Gc)>>>29&4)|2)}Qc=Qc+1|0;}while((Qc|0)<(o|0));break};default:{if(!Tc){break d}Qc=b+608+(Vc*88|0)+8|0;Mc=b+608+(Vc*88|0)+12|0;Rc=0;Ic=0;Lc=Fc;while(1){Pc=Lc&7;Ec=c[b+608+(Vc*88|0)+16+(Rc<<2)>>2]|0;Gc=e+(Ic<<2)|0;Nc=c[Gc>>2]|0;c[b+608+(Vc*88|0)+16+(Pc<<2)>>2]=Nc;Kc=(ba(c[Qc>>2]|0,Ec)|0)+512>>10;Oc=Nc-Kc|0;c[Gc>>2]=Oc;if(!((Ec|0)==0|(Nc|0)==(Kc|0))){c[Qc>>2]=(c[Qc>>2]|0)+(-((Oc^Ec)>>>29&4)|2)}Ec=c[b+608+(Vc*88|0)+48+(Rc<<2)>>2]|0;Oc=f+(Ic<<2)|0;Kc=c[Oc>>2]|0;c[b+608+(Vc*88|0)+48+(Pc<<2)>>2]=Kc;Nc=(ba(c[Mc>>2]|0,Ec)|0)+512>>10;Gc=Kc-Nc|0;c[Oc>>2]=Gc;if(!((Ec|0)==0|(Kc|0)==(Nc|0))){c[Mc>>2]=(c[Mc>>2]|0)+(-((Gc^Ec)>>>29&4)|2)}_c=Rc+1&7;Ec=Ic+1|0;if((Ec|0)<(o|0)){Rc=_c;Ic=Ec;Lc=Pc+1|0}else{break}}if((_c|0)==0){break d}UGb(mb|0,b+608+(Vc*88|0)+16|0,32)|0;UGb(Hc|0,b+608+(Vc*88|0)+48|0,32)|0;c[b+608+(Vc*88|0)+16>>2]=c[k+(_c<<2)>>2];c[b+608+(Vc*88|0)+48>>2]=c[l+(_c<<2)>>2];Lc=Rc+2&7;c[b+608+(Vc*88|0)+20>>2]=c[k+(Lc<<2)>>2];c[b+608+(Vc*88|0)+52>>2]=c[l+(Lc<<2)>>2];Lc=Rc+3&7;c[b+608+(Vc*88|0)+24>>2]=c[k+(Lc<<2)>>2];c[b+608+(Vc*88|0)+56>>2]=c[l+(Lc<<2)>>2];Lc=Rc+4&7;c[b+608+(Vc*88|0)+28>>2]=c[k+(Lc<<2)>>2];c[b+608+(Vc*88|0)+60>>2]=c[l+(Lc<<2)>>2];Lc=Rc+5&7;c[b+608+(Vc*88|0)+32>>2]=c[k+(Lc<<2)>>2];c[b+608+(Vc*88|0)+64>>2]=c[l+(Lc<<2)>>2];Lc=Rc+6&7;c[b+608+(Vc*88|0)+36>>2]=c[k+(Lc<<2)>>2];c[b+608+(Vc*88|0)+68>>2]=c[l+(Lc<<2)>>2];Lc=Rc+7&7;c[b+608+(Vc*88|0)+40>>2]=c[k+(Lc<<2)>>2];c[b+608+(Vc*88|0)+72>>2]=c[l+(Lc<<2)>>2];c[b+608+(Vc*88|0)+44>>2]=c[k+(Rc<<2)>>2];c[b+608+(Vc*88|0)+76>>2]=c[l+(Rc<<2)>>2];break d}}}}while(0);e:do{if((N|0)==378){N=0;Lc=c[b+608+(Vc*88|0)+4>>2]|0;switch(Lc|0){case-2:{if(!Tc){break e}Ic=b+608+(Vc*88|0)+48|0;Mc=b+608+(Vc*88|0)+12|0;Qc=b+608+(Vc*88|0)+8|0;Fc=Uc|0;Pc=0;do{Ec=c[Ic>>2]|0;Gc=f+(Pc<<2)|0;Nc=c[Gc>>2]|0;if((Ec|0)==(Ec<<16>>16|0)){$c=(ba(c[Mc>>2]|0,Ec)|0)+512>>10}else{Kc=c[Mc>>2]|0;$c=(ba(Kc,Ec>>9&-128)|0|1)+((ba(Kc,Ec&65535)|0)>>9)>>1}Kc=Nc-$c|0;c[Gc>>2]=Kc;do{if(!((Ec|0)==0|(Nc|0)==($c|0))){Gc=c[Fc>>2]|0;Oc=c[Mc>>2]|0;if((Kc^Ec|0)<0){bc=Oc-Gc|0;c[Mc>>2]=bc;if(!((bc|0)<-1024)){break}c[Mc>>2]=-1024;break}else{bc=Oc+Gc|0;c[Mc>>2]=bc;if((bc|0)<=1024){break}c[Mc>>2]=1024;break}}}while(0);Ec=e+(Pc<<2)|0;Kc=c[Ec>>2]|0;c[Ic>>2]=Kc;if((Nc|0)==(Nc<<16>>16|0)){ad=(ba(c[Qc>>2]|0,Nc)|0)+512>>10}else{bc=c[Qc>>2]|0;ad=(ba(bc,Nc>>9&-128)|0|1)+((ba(bc,Nc&65535)|0)>>9)>>1}bc=Kc-ad|0;c[Ec>>2]=bc;do{if(!((Nc|0)==0|(Kc|0)==(ad|0))){Ec=c[Fc>>2]|0;Gc=c[Qc>>2]|0;if((bc^Nc|0)<0){Oc=Gc-Ec|0;c[Qc>>2]=Oc;if(!((Oc|0)<-1024)){break}c[Qc>>2]=-1024;break}else{Oc=Gc+Ec|0;c[Qc>>2]=Oc;if((Oc|0)<=1024){break}c[Qc>>2]=1024;break}}}while(0);Pc=Pc+1|0;}while((Pc|0)<(o|0));break};case 18:{if(!Tc){break e}Pc=b+608+(Vc*88|0)+16|0;Qc=b+608+(Vc*88|0)+20|0;Fc=b+608+(Vc*88|0)+8|0;Ic=b+608+(Vc*88|0)+48|0;Mc=b+608+(Vc*88|0)+52|0;Rc=b+608+(Vc*88|0)+12|0;Nc=Uc|0;bc=0;do{Kc=c[Pc>>2]|0;Oc=(Kc-(c[Qc>>2]|0)>>1)+Kc|0;c[Qc>>2]=Kc;Kc=e+(bc<<2)|0;Ec=c[Kc>>2]|0;c[Pc>>2]=Ec;if((Oc|0)==(Oc<<16>>16|0)){bd=(ba(c[Fc>>2]|0,Oc)|0)+512>>10}else{Gc=c[Fc>>2]|0;bd=(ba(Gc,Oc>>9&-128)|0|1)+((ba(Gc,Oc&65535)|0)>>9)>>1}Gc=Ec-bd|0;c[Kc>>2]=Gc;if(!((Oc|0)==0|(Ec|0)==(bd|0))){Ec=Gc^Oc;c[Fc>>2]=(c[Fc>>2]|0)+(Ec>>>31)+(c[Nc>>2]^Ec>>31)}Ec=c[Ic>>2]|0;Oc=(Ec-(c[Mc>>2]|0)>>1)+Ec|0;c[Mc>>2]=Ec;Ec=f+(bc<<2)|0;Gc=c[Ec>>2]|0;c[Ic>>2]=Gc;if((Oc|0)==(Oc<<16>>16|0)){cd=(ba(c[Rc>>2]|0,Oc)|0)+512>>10}else{Kc=c[Rc>>2]|0;cd=(ba(Kc,Oc>>9&-128)|0|1)+((ba(Kc,Oc&65535)|0)>>9)>>1}Kc=Gc-cd|0;c[Ec>>2]=Kc;if(!((Oc|0)==0|(Gc|0)==(cd|0))){Gc=Kc^Oc;c[Rc>>2]=(c[Rc>>2]|0)+(Gc>>>31)+(c[Nc>>2]^Gc>>31)}bc=bc+1|0;}while((bc|0)<(o|0));break};case 17:{if(!Tc){break e}bc=b+608+(Vc*88|0)+16|0;Nc=b+608+(Vc*88|0)+20|0;Rc=b+608+(Vc*88|0)+8|0;Ic=b+608+(Vc*88|0)+48|0;Mc=b+608+(Vc*88|0)+52|0;Fc=b+608+(Vc*88|0)+12|0;Pc=Uc|0;Qc=0;do{Gc=c[bc>>2]|0;Oc=Gc<<1;Kc=c[Nc>>2]|0;Ec=Oc-Kc|0;c[Nc>>2]=Gc;Gc=e+(Qc<<2)|0;cc=c[Gc>>2]|0;c[bc>>2]=cc;if((Ec|0)==(Ec<<16>>16|0)){dd=(ba(c[Rc>>2]|0,Ec)|0)+512>>10}else{Sc=c[Rc>>2]|0;dd=(ba(Sc,Ec>>9&-128)|0|1)+((ba(Sc,Ec&65535)|0)>>9)>>1}Sc=cc-dd|0;c[Gc>>2]=Sc;if(!((Oc|0)==(Kc|0)|(cc|0)==(dd|0))){cc=Sc^Ec;c[Rc>>2]=(c[Rc>>2]|0)+(cc>>>31)+(c[Pc>>2]^cc>>31)}cc=c[Ic>>2]|0;Ec=cc<<1;Sc=c[Mc>>2]|0;Kc=Ec-Sc|0;c[Mc>>2]=cc;cc=f+(Qc<<2)|0;Oc=c[cc>>2]|0;c[Ic>>2]=Oc;if((Kc|0)==(Kc<<16>>16|0)){ed=(ba(c[Fc>>2]|0,Kc)|0)+512>>10}else{Gc=c[Fc>>2]|0;ed=(ba(Gc,Kc>>9&-128)|0|1)+((ba(Gc,Kc&65535)|0)>>9)>>1}Gc=Oc-ed|0;c[cc>>2]=Gc;if(!((Ec|0)==(Sc|0)|(Oc|0)==(ed|0))){Oc=Gc^Kc;c[Fc>>2]=(c[Fc>>2]|0)+(Oc>>>31)+(c[Pc>>2]^Oc>>31)}Qc=Qc+1|0;}while((Qc|0)<(o|0));break};case-3:{if(!Tc){break e}Qc=b+608+(Vc*88|0)+16|0;Pc=b+608+(Vc*88|0)+48|0;Fc=b+608+(Vc*88|0)+12|0;Ic=b+608+(Vc*88|0)+8|0;Mc=Uc|0;Rc=0;do{bc=c[Qc>>2]|0;Nc=c[Pc>>2]|0;Oc=f+(Rc<<2)|0;Kc=c[Oc>>2]|0;c[Qc>>2]=Kc;if((Nc|0)==(Nc<<16>>16|0)){fd=(ba(c[Fc>>2]|0,Nc)|0)+512>>10}else{Gc=c[Fc>>2]|0;fd=(ba(Gc,Nc>>9&-128)|0|1)+((ba(Gc,Nc&65535)|0)>>9)>>1}Gc=Kc-fd|0;c[Oc>>2]=Gc;do{if(!((Nc|0)==0|(Kc|0)==(fd|0))){Oc=c[Mc>>2]|0;Sc=c[Fc>>2]|0;if((Gc^Nc|0)<0){Ec=Sc-Oc|0;c[Fc>>2]=Ec;if(!((Ec|0)<-1024)){break}c[Fc>>2]=-1024;break}else{Ec=Sc+Oc|0;c[Fc>>2]=Ec;if((Ec|0)<=1024){break}c[Fc>>2]=1024;break}}}while(0);Nc=e+(Rc<<2)|0;Gc=c[Nc>>2]|0;c[Pc>>2]=Gc;if((bc|0)==(bc<<16>>16|0)){gd=(ba(c[Ic>>2]|0,bc)|0)+512>>10}else{Kc=c[Ic>>2]|0;gd=(ba(Kc,bc>>9&-128)|0|1)+((ba(Kc,bc&65535)|0)>>9)>>1}Kc=Gc-gd|0;c[Nc>>2]=Kc;do{if(!((bc|0)==0|(Gc|0)==(gd|0))){Nc=c[Mc>>2]|0;Ec=c[Ic>>2]|0;if((Kc^bc|0)<0){Oc=Ec-Nc|0;c[Ic>>2]=Oc;if(!((Oc|0)<-1024)){break}c[Ic>>2]=-1024;break}else{Oc=Ec+Nc|0;c[Ic>>2]=Oc;if((Oc|0)<=1024){break}c[Ic>>2]=1024;break}}}while(0);Rc=Rc+1|0;}while((Rc|0)<(o|0));break};case-1:{if(!Tc){break e}Rc=b+608+(Vc*88|0)+16|0;Ic=b+608+(Vc*88|0)+8|0;Mc=b+608+(Vc*88|0)+12|0;Pc=Uc|0;Fc=0;do{Qc=c[Rc>>2]|0;bc=e+(Fc<<2)|0;Kc=c[bc>>2]|0;if((Qc|0)==(Qc<<16>>16|0)){hd=(ba(c[Ic>>2]|0,Qc)|0)+512>>10}else{Gc=c[Ic>>2]|0;hd=(ba(Gc,Qc>>9&-128)|0|1)+((ba(Gc,Qc&65535)|0)>>9)>>1}Gc=Kc-hd|0;c[bc>>2]=Gc;do{if(!((Qc|0)==0|(Kc|0)==(hd|0))){bc=c[Pc>>2]|0;Oc=c[Ic>>2]|0;if((Gc^Qc|0)<0){Nc=Oc-bc|0;c[Ic>>2]=Nc;if(!((Nc|0)<-1024)){break}c[Ic>>2]=-1024;break}else{Nc=Oc+bc|0;c[Ic>>2]=Nc;if((Nc|0)<=1024){break}c[Ic>>2]=1024;break}}}while(0);Qc=f+(Fc<<2)|0;Gc=c[Qc>>2]|0;c[Rc>>2]=Gc;if((Kc|0)==(Kc<<16>>16|0)){id=(ba(c[Mc>>2]|0,Kc)|0)+512>>10}else{Nc=c[Mc>>2]|0;id=(ba(Nc,Kc>>9&-128)|0|1)+((ba(Nc,Kc&65535)|0)>>9)>>1}Nc=Gc-id|0;c[Qc>>2]=Nc;do{if(!((Kc|0)==0|(Gc|0)==(id|0))){Qc=c[Pc>>2]|0;bc=c[Mc>>2]|0;if((Nc^Kc|0)<0){Oc=bc-Qc|0;c[Mc>>2]=Oc;if(!((Oc|0)<-1024)){break}c[Mc>>2]=-1024;break}else{Oc=bc+Qc|0;c[Mc>>2]=Oc;if((Oc|0)<=1024){break}c[Mc>>2]=1024;break}}}while(0);Fc=Fc+1|0;}while((Fc|0)<(o|0));break};default:{if(!Tc){break e}Fc=b+608+(Vc*88|0)+8|0;Mc=b+608+(Vc*88|0)+12|0;Pc=Uc|0;Rc=0;Ic=0;Kc=Lc;while(1){Nc=Kc&7;Gc=c[b+608+(Vc*88|0)+16+(Rc<<2)>>2]|0;Oc=e+(Ic<<2)|0;Qc=c[Oc>>2]|0;c[b+608+(Vc*88|0)+16+(Nc<<2)>>2]=Qc;if((Gc|0)==(Gc<<16>>16|0)){jd=(ba(c[Fc>>2]|0,Gc)|0)+512>>10}else{bc=c[Fc>>2]|0;jd=(ba(bc,Gc>>9&-128)|0|1)+((ba(bc,Gc&65535)|0)>>9)>>1}bc=Qc-jd|0;c[Oc>>2]=bc;if(!((Gc|0)==0|(Qc|0)==(jd|0))){Qc=bc^Gc;c[Fc>>2]=(c[Fc>>2]|0)+(Qc>>>31)+(c[Pc>>2]^Qc>>31)}Qc=c[b+608+(Vc*88|0)+48+(Rc<<2)>>2]|0;Gc=f+(Ic<<2)|0;bc=c[Gc>>2]|0;c[b+608+(Vc*88|0)+48+(Nc<<2)>>2]=bc;if((Qc|0)==(Qc<<16>>16|0)){kd=(ba(c[Mc>>2]|0,Qc)|0)+512>>10}else{Oc=c[Mc>>2]|0;kd=(ba(Oc,Qc>>9&-128)|0|1)+((ba(Oc,Qc&65535)|0)>>9)>>1}Oc=bc-kd|0;c[Gc>>2]=Oc;if(!((Qc|0)==0|(bc|0)==(kd|0))){bc=Oc^Qc;c[Mc>>2]=(c[Mc>>2]|0)+(bc>>>31)+(c[Pc>>2]^bc>>31)}ld=Rc+1&7;bc=Ic+1|0;if((bc|0)<(o|0)){Rc=ld;Ic=bc;Kc=Nc+1|0}else{break}}if((ld|0)==0){break e}UGb(mb|0,b+608+(Vc*88|0)+16|0,32)|0;UGb(Hc|0,b+608+(Vc*88|0)+48|0,32)|0;c[b+608+(Vc*88|0)+16>>2]=c[k+(ld<<2)>>2];c[b+608+(Vc*88|0)+48>>2]=c[l+(ld<<2)>>2];Kc=Rc+2&7;c[b+608+(Vc*88|0)+20>>2]=c[k+(Kc<<2)>>2];c[b+608+(Vc*88|0)+52>>2]=c[l+(Kc<<2)>>2];Kc=Rc+3&7;c[b+608+(Vc*88|0)+24>>2]=c[k+(Kc<<2)>>2];c[b+608+(Vc*88|0)+56>>2]=c[l+(Kc<<2)>>2];Kc=Rc+4&7;c[b+608+(Vc*88|0)+28>>2]=c[k+(Kc<<2)>>2];c[b+608+(Vc*88|0)+60>>2]=c[l+(Kc<<2)>>2];Kc=Rc+5&7;c[b+608+(Vc*88|0)+32>>2]=c[k+(Kc<<2)>>2];c[b+608+(Vc*88|0)+64>>2]=c[l+(Kc<<2)>>2];Kc=Rc+6&7;c[b+608+(Vc*88|0)+36>>2]=c[k+(Kc<<2)>>2];c[b+608+(Vc*88|0)+68>>2]=c[l+(Kc<<2)>>2];Kc=Rc+7&7;c[b+608+(Vc*88|0)+40>>2]=c[k+(Kc<<2)>>2];c[b+608+(Vc*88|0)+72>>2]=c[l+(Kc<<2)>>2];c[b+608+(Vc*88|0)+44>>2]=c[k+(Rc<<2)>>2];c[b+608+(Vc*88|0)+76>>2]=c[l+(Rc<<2)>>2];break e}}}}while(0);Vc=Vc+1|0;}while((Vc|0)<(c[Eb>>2]|0))}else{if(!(Xc&(o|0)>0)){break}Vc=b+608|0;Hc=0;mb=0;do{Tc=e+(Hc<<2)|0;Uc=c[Tc>>2]|0;Kc=c[Eb>>2]|0;if((Kc|0)==0){md=Uc}else{Ic=Vc;Pc=Uc;Uc=Kc;while(1){Kc=Uc-1|0;Mc=c[Ic+4>>2]|0;if((Mc|0)>8){Fc=Ic+16|0;Lc=c[Fc>>2]|0;if((Mc&1|0)==0){nd=(Lc*3|0)-(c[Ic+20>>2]|0)>>1}else{nd=(Lc<<1)-(c[Ic+20>>2]|0)|0}c[Ic+20>>2]=Lc;c[Fc>>2]=Pc;od=nd}else{Fc=c[Ic+16+(mb<<2)>>2]|0;c[Ic+16+((Mc+mb&7)<<2)>>2]=Pc;od=Fc}if((od|0)==(od<<16>>16|0)){Fc=c[Ic+8>>2]|0;pd=(ba(Fc,od)|0)+512>>10;qd=Fc}else{Fc=c[Ic+8>>2]|0;pd=(ba(Fc,od>>9&-128)|0|1)+((ba(Fc,od&65535)|0)>>9)>>1;qd=Fc}Fc=Pc-pd|0;if(!((od|0)==0|(Pc|0)==(pd|0))){Mc=Fc^od;c[Ic+8>>2]=qd+(Mc>>>31)+(c[Ic>>2]^Mc>>31)}if((Kc|0)==0){md=Fc;break}else{Ic=Ic+88|0;Pc=Fc;Uc=Kc}}}mb=mb+1&7;c[Tc>>2]=md;Hc=Hc+1|0;}while((Hc|0)<(o|0));if((mb|0)==0){break}Hc=c[Eb>>2]|0;if((Hc|0)==0){break}Vc=m;Uc=n;Pc=b+608|0;Ic=mb;Kc=Hc;while(1){Hc=Kc-1|0;if(((c[Pc+4>>2]|0)-1|0)>>>0<8>>>0){UGb(Vc|0,Pc+16|0,32)|0;UGb(Uc|0,Pc+48|0,32)|0;c[Pc+16>>2]=c[m+(Ic<<2)>>2];c[Pc+48>>2]=c[n+(Ic<<2)>>2];Fc=Ic+1&7;c[Pc+20>>2]=c[m+(Fc<<2)>>2];c[Pc+52>>2]=c[n+(Fc<<2)>>2];Fc=Ic+2&7;c[Pc+24>>2]=c[m+(Fc<<2)>>2];c[Pc+56>>2]=c[n+(Fc<<2)>>2];Fc=Ic+3&7;c[Pc+28>>2]=c[m+(Fc<<2)>>2];c[Pc+60>>2]=c[n+(Fc<<2)>>2];Fc=Ic+4&7;c[Pc+32>>2]=c[m+(Fc<<2)>>2];c[Pc+64>>2]=c[n+(Fc<<2)>>2];Fc=Ic+5&7;c[Pc+36>>2]=c[m+(Fc<<2)>>2];c[Pc+68>>2]=c[n+(Fc<<2)>>2];Fc=Ic+6&7;c[Pc+40>>2]=c[m+(Fc<<2)>>2];c[Pc+72>>2]=c[n+(Fc<<2)>>2];Fc=Ic+7&7;c[Pc+44>>2]=c[m+(Fc<<2)>>2];c[Pc+76>>2]=c[n+(Fc<<2)>>2];rd=Ic&7}else{rd=Ic}if((Hc|0)==0){break}else{Pc=Pc+88|0;Ic=rd;Kc=Hc}}}}while(0);do{if((Zc|0)==0){if((Rb-Yc|0)<=0){sd=Yc;td=1;break}a[Yc]=-118;sd=Yc+1|0;td=0}else{sd=Yc;td=1}}while(0);Yc=sd+3|0;Zc=Rb-sd|0;rd=(Zc|0)<0;n=rd?0:Yc;m=rd?0:Zc;rd=b+28|0;c[rd>>2]=m<<3;Eb=b+16|0;c[Eb>>2]=n;md=b+24|0;c[md>>2]=n+m;m=b+20|0;c[m>>2]=n;n=b+12|0;c[n>>2]=32;qd=b+8|0;c[qd>>2]=0;od=(o|0)>0;do{if((c[p>>2]&1073741828|0)==0){if(!od){break}pd=b+488|0;nd=b+56|0;e=b+516|0;Xc=b+60|0;l=0;do{xbb(b,pd,c[(c[nd>>2]|0)+(l<<2)>>2]|0);xbb(b,e,c[(c[Xc>>2]|0)+(l<<2)>>2]|0);l=l+1|0;}while((l|0)<(o|0))}else{if(!od){break}l=b+488|0;Xc=b+56|0;e=0;do{xbb(b,l,c[(c[Xc>>2]|0)+(e<<2)>>2]|0);e=e+1|0;}while((e|0)<(o|0))}}while(0);ybb(b);if((c[n>>2]|0)<32){od=c[qd>>2]&255;while(1){e=c[m>>2]|0;c[m>>2]=e+1;a[e]=od;e=(c[qd>>2]|0)>>>8;c[qd>>2]=e;Xc=(c[n>>2]|0)+8|0;c[n>>2]=Xc;if((Xc|0)<32){od=e&255}else{break}}}c[n>>2]=32;c[qd>>2]=0;od=(c[m>>2]|0)-(c[Eb>>2]|0)<<3>>3;e=od+1>>1;if((td|0)==0&(Zc|0)>2){a[sd]=e;a[sd+1|0]=e>>>8;a[sd+2|0]=e>>>16;e=Rb-Yc|0;Yc=e>>>0>od>>>0?od:e;ud=sd+(Yc+3)|0;vd=(Yc|0)!=(od|0)|0}else{ud=sd;vd=1}do{if((od&1|0)==0){wd=ud;xd=vd}else{if((vd|0)!=0){wd=ud;xd=1;break}if((Rb-ud|0)<=0){wd=ud;xd=1;break}a[ud]=0;wd=ud+1|0;xd=0}}while(0);do{if((Ma|0)==0){yd=wd}else{do{if((xd|0)==0){if((Rb-wd|0)<=0){zd=wd;Ad=1;break}a[wd]=-116;zd=wd+1|0;Ad=0}else{zd=wd;Ad=1}}while(0);ud=zd+7|0;vd=Rb-zd|0;od=(vd|0)<0;sd=od?0:ud;Yc=od?0:vd;c[rd>>2]=Yc<<3;c[Eb>>2]=sd;c[md>>2]=sd+Yc;c[m>>2]=sd;c[n>>2]=32;c[qd>>2]=0;Yc=c[p>>2]|0;od=c[b+424>>2]|0;e=c[b+428>>2]|0;f:do{if((Yc&128|0)==0){Zc=a[b+544|0]|0;td=Zc&255;Xc=(1<<td)-1|0;l=(d[b+546|0]|0)+(d[b+545|0]|0)+(d[b+547|0]|0)|0;if(Zc<<24>>24==0){N=570;break}Zc=(o|0)>0;if((Yc&1073741828|0)!=0){if(Zc){Bd=0;Dd=0;Ed=32;Fd=sd}else{N=570;break}while(1){nd=c[od+(Bd<<2)>>2]>>l&Xc;pd=nd<<32-Ed|Dd;if((Ed|0)>(td|0)){Gd=Ed;Hd=pd;Id=Fd}else{k=Fd;x=pd;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=(c[m>>2]|0)+4|0;c[m>>2]=k;Gd=Ed+32|0;Hd=(Ed|0)==32?0:nd>>>(Ed>>>0);Id=k}k=Gd-td|0;c[qd>>2]=Hd;c[n>>2]=k;nd=Bd+1|0;if((nd|0)<(o|0)){Bd=nd;Dd=Hd;Ed=k;Fd=Id}else{Jd=k;break f}}}if(Zc){Kd=0;Ld=0;Md=32;Nd=sd}else{N=570;break}while(1){Tc=c[od+(Kd<<2)>>2]>>l&Xc;k=Tc<<32-Md|Ld;if((Md|0)>(td|0)){Od=Md;Pd=k;Qd=Nd}else{nd=Nd;x=k;a[nd]=x;x=x>>8;a[nd+1|0]=x;x=x>>8;a[nd+2|0]=x;x=x>>8;a[nd+3|0]=x;nd=(c[m>>2]|0)+4|0;c[m>>2]=nd;Od=Md+32|0;Pd=(Md|0)==32?0:Tc>>>(Md>>>0);Qd=nd}nd=Od-td|0;c[qd>>2]=Pd;c[n>>2]=nd;Tc=c[e+(Kd<<2)>>2]>>l&Xc;k=Tc<<32-nd|Pd;if((nd|0)>(td|0)){Rd=nd;Sd=k;Td=Qd}else{pd=Qd;x=k;a[pd]=x;x=x>>8;a[pd+1|0]=x;x=x>>8;a[pd+2|0]=x;x=x>>8;a[pd+3|0]=x;pd=(c[m>>2]|0)+4|0;c[m>>2]=pd;Rd=nd+32|0;Sd=(nd|0)==32?0:Tc>>>(nd>>>0);Td=pd}pd=Rd-td|0;c[qd>>2]=Sd;c[n>>2]=pd;nd=Kd+1|0;if((nd|0)<(o|0)){Kd=nd;Ld=Sd;Md=pd;Nd=Td}else{Jd=pd;break}}}else{td=(o|0)>0;if((Yc&1073741828|0)==0){if(td){Ud=0}else{N=570;break}while(1){zbb(b,od+(Ud<<2)|0);zbb(b,e+(Ud<<2)|0);Xc=Ud+1|0;if((Xc|0)<(o|0)){Ud=Xc}else{N=570;break}}}else{if(td){Vd=0}else{N=570;break}while(1){zbb(b,od+(Vd<<2)|0);Xc=Vd+1|0;if((Xc|0)<(o|0)){Vd=Xc}else{N=570;break}}}}}while(0);if((N|0)==570){Jd=c[n>>2]|0}if((Jd|0)<32){od=c[qd>>2]&255;while(1){e=c[m>>2]|0;c[m>>2]=e+1;a[e]=od;e=(c[qd>>2]|0)>>>8;c[qd>>2]=e;Yc=(c[n>>2]|0)+8|0;c[n>>2]=Yc;if((Yc|0)<32){od=e&255}else{break}}}c[n>>2]=32;c[qd>>2]=0;od=(c[m>>2]|0)-(c[Eb>>2]|0)<<3>>3;e=od+5>>1;if(!((Ad|0)==0&(vd|0)>2)){yd=zd;break}a[zd]=e;a[zd+1|0]=e>>>8;a[zd+2|0]=e>>>16;e=zd+3|0;if((Rb-e|0)<=3){yd=e;break}Yc=e;x=c[b+464>>2]|0;a[Yc]=x;x=x>>8;a[Yc+1|0]=x;x=x>>8;a[Yc+2|0]=x;x=x>>8;a[Yc+3|0]=x;Yc=Rb-ud|0;e=Yc>>>0>od>>>0?od:Yc;Yc=zd+(e+7)|0;if(!((od&1|0)!=0&(e|0)==(od|0))){yd=Yc;break}if((Rb-Yc|0)<=0){yd=Yc;break}a[Yc]=0;yd=zd+(e+8)|0}}while(0);zd=yd-Lb|0;Lb=g+4|0;x=zd-8|0;a[Lb]=x;x=x>>8;a[Lb+1|0]=x;x=x>>8;a[Lb+2|0]=x;x=x>>8;a[Lb+3|0]=x;ub=zd;i=j;return ub|0}function ubb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;j=i;i=i+2920|0;k=j|0;l=j+1424|0;m=j+1512|0;n=m;TGb(n|0,0,1408)|0;o=b+32|0;p=c[o>>2]|0;q=p<<2;r=0;while(1){if((r|0)>=(p|0)){break}if((c[e+(r<<2)>>2]|0)==0){r=r+1|0}else{break}}if((r|0)==(p|0)){TGb(b+608|0,0,1408)|0;TGb(b+468|0,0,76)|0;c[b+576>>2]=0;s=0;i=j;return s|0}r=b+460|0;t=((c[r>>2]|0)>>>18<<8&7936)+1024|0;u=t>>>0<6912>>>0?t:6912;t=Abb(b)|0;if((t|0)<0){s=t;i=j;return s|0}t=(f|0)!=0;f=c[b+596>>2]|0;if(t|(f|0)>6){c[b+604>>2]=0;c[b+600>>2]=0}v=b+596|0;a:do{if((f|0)>0){w=b+604|0;x=b+600|0;y=b+592|0;z=b+2016|0;A=b+448|0;B=b+360|0;C=e;D=(p|0)==0;E=l;F=l|0;G=l+4|0;H=(p|0)>2048?2048:p;I=l+16|0;J=l+20|0;K=l+16|0;L=b+392|0;M=b+608|0;N=b+576|0;O=0;Q=-1;R=f;while(1){b:do{if((O|0)==0){S=c[x>>2]|0;T=0}else{U=c[w>>2]|0;while(1){V=(U|0)==0;W=c[x>>2]|0;if(V){X=0}else{X=W&U-1|U}if((X|0)!=(W|0)){S=X;T=1;break b}if(V){Y=1}else{Y=(c[y>>2]|0)-1&U<<1}c[w>>2]=Y;if((O|0)<(R|0)){U=Y}else{break a}}}}while(0);U=c[z>>2]|0;V=U+(S*19|0)+1|0;W=d[1402776+(c[A>>2]|0)|0]|0;c:while(1){UGb(c[B>>2]|0,C|0,q)|0;TGb(n|0,0,1408)|0;if((W|0)>0){Z=0;do{TGb(E|0,0,88)|0;c[F>>2]=a[V]|0;_=a[U+(S*19|0)+2+Z|0]|0;c[G>>2]=_<<24>>24<0?1:_<<24>>24;_=Z&1;$=b+360+(_<<3)|0;aa=b+360+((_^1)<<3)|0;Jbb(c[$>>2]|0,c[aa>>2]|0,H,l,-1);d:do{if((Z|0)==0){_=c[G>>2]|0;if((_|0)<=8){if((_|0)>1){ba=0;ca=_;da=0}else{break}while(1){ea=ba&7;fa=ca+7&7;ga=l+16+(fa<<2)|0;ha=l+16+(ea<<2)|0;ia=c[ha>>2]^c[ga>>2];c[ha>>2]=ia;ja=c[ga>>2]^ia;c[ga>>2]=ja;c[ha>>2]=c[ha>>2]^ja;ja=da+1|0;if((ja|0)<((c[G>>2]|0)/2|0|0)){ba=ea+1|0;ca=fa;da=ja}else{break d}}}ja=c[I>>2]|0;if((_&1|0)==0){fa=(ja*3|0)-(c[J>>2]|0)>>1;c[J>>2]=ja;c[I>>2]=fa;ka=(fa*3|0)-ja>>1}else{fa=(ja<<1)-(c[J>>2]|0)|0;c[J>>2]=ja;c[I>>2]=fa;ka=(fa<<1)-ja|0}c[J>>2]=ka}else{TGb(K|0,0,32)|0}}while(0);UGb(m+(Z*88|0)|0,E|0,88)|0;Jbb(c[$>>2]|0,c[aa>>2]|0,p,l,1);Z=Z+1|0;}while((Z|0)<(W|0));la=W&1}else{la=0}ma=b+360+(la<<3)|0;if(D){na=44;break}Z=c[ma>>2]|0;ja=p;while(1){fa=ja-1|0;ea=Z+4|0;ha=c[Z>>2]|0;ga=(ha|0)>-1?ha:-ha|0;ha=(ga>>>9)+ga|0;if(!(ha>>>0<256>>>0)){do{if(ha>>>0<65536>>>0){oa=(a[637664+(ha>>>8)|0]|0)+8|0}else{if(ha>>>0<16777216>>>0){oa=(a[637664+(ha>>>16)|0]|0)+16|0;break}else{oa=(a[637664+(ha>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[15880+(ha>>>((oa-9|0)>>>0)&255)|0]|oa<<8)>>>0<u>>>0)){break}}if((fa|0)==0){na=44;break c}else{Z=ea;ja=fa}}if((W|0)==0){pa=Q;break}else{W=W>>1}}do{if((na|0)==44){na=0;if((Q|0)==0){pa=Q;break}UGb(c[L>>2]|0,c[ma>>2]|0,q)|0;UGb(M|0,n|0,1408)|0;c[N>>2]=W;c[x>>2]=S;pa=0}}while(0);W=O+1|0;if(T){U=c[w>>2]|0;if((U|0)==0){qa=1}else{qa=(c[y>>2]|0)-1&U<<1}c[w>>2]=qa}U=c[v>>2]|0;if((W|0)<(U|0)){O=W;Q=pa;R=U}else{break}}}}while(0);pa=b+440|0;e:do{if((c[pa>>2]|0)==0){if((h|0)==0){break}UGb(e|0,c[b+392>>2]|0,q)|0}else{v=k;qa=((c[r>>2]|0)>>>18<<8&7936)+1024|0;T=k+1412|0;c[T>>2]=qa>>>0<6912>>>0?qa:6912;qa=b+576|0;S=c[qa>>2]|0;n=k+1408|0;c[n>>2]=S;ma=S+2|0;if((ma|0)>0){na=0;do{u=b+72+(na<<3)|0;O$a(u,b+216+(na<<3)|0,c[o>>2]<<2);if((c[u>>2]|0)==0){break e}if((c[r>>2]&1073741828|0)==0){u=b+72+(na<<3)+4|0;O$a(u,b+216+(na<<3)+4|0,c[o>>2]<<2);if((c[u>>2]|0)==0){break e}}na=na+1|0;}while((na|0)<(ma|0))}ma=b+608|0;na=ma;UGb(v|0,na|0,1408)|0;u=e;UGb(c[b+72>>2]|0,u|0,c[o>>2]<<2)|0;f:do{if((S|0)>0){oa=0;la=S;while(1){if((c[k+(oa*88|0)+4>>2]|0)==0){ra=oa;sa=la;break f}l=oa+1|0;Jbb(c[b+72+(oa<<3)>>2]|0,c[b+72+(l<<3)>>2]|0,c[o>>2]|0,k+(oa*88|0)|0,1);m=c[n>>2]|0;if((l|0)<(m|0)){oa=l;la=m}else{ra=l;sa=m;break}}}else{ra=0;sa=S}}while(0);S=c[o>>2]|0;la=k+1420|0;c[la>>2]=0;UGb(c[b+72+(sa+1<<3)>>2]|0,c[b+72+(ra<<3)>>2]|0,S<<2)|0;S=c[pa>>2]|0;if((S&8|0)==0){ta=S}else{Kbb(b,k,0,~~+P(+g[b+2020>>2]+.5),0);ta=c[pa>>2]|0}if((ta&4|0)==0){ua=ta}else{Lbb(b,k);ua=c[pa>>2]|0}g:do{if((ua&1|0)==0){va=ua}else{S=b+612|0;h:do{if((c[S>>2]|0)!=0){oa=c[ma>>2]|0;i:do{if((oa|0)>0){m=k|0;l=0;ka=oa;da=c[n>>2]|0;while(1){ca=ka-1|0;j:do{if((da|0)>0){ba=0;Y=da;while(1){X=c[b+608+(ba*88|0)+4>>2]|0;if((X|0)==0){wa=ba;xa=Y;break j}c[k+(ba*88|0)+4>>2]=X;c[k+(ba*88|0)>>2]=ca;X=ba+1|0;Mbb(c[b+72+(ba<<3)>>2]|0,c[b+72+(X<<3)>>2]|0,c[o>>2]|0,m,ba);f=c[n>>2]|0;if((X|0)<(f|0)){ba=X;Y=f}else{wa=X;xa=f;break}}}else{wa=0;xa=da}}while(0);_=b+72+(wa<<3)|0;Y=c[o>>2]|0;ba=c[T>>2]|0;if(!((Y|0)==0|(ba|0)==0)){f=c[_>>2]|0;X=Y;while(1){R=X-1|0;Q=f+4|0;O=c[f>>2]|0;w=(O|0)>-1?O:-O|0;O=(w>>>9)+w|0;if(!(O>>>0<256>>>0)){do{if(O>>>0<65536>>>0){ya=(a[637664+(O>>>8)|0]|0)+8|0}else{if(O>>>0<16777216>>>0){ya=(a[637664+(O>>>16)|0]|0)+16|0;break}else{ya=(a[637664+(O>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[15880+(O>>>((ya-9|0)>>>0)&255)|0]|ya<<8)>>>0<ba>>>0)){za=l;break i}}if((R|0)==0){break}else{f=Q;X=R}}}if((c[la>>2]|0)==0){za=l;break i}c[la>>2]=0;TGb(na|0,0,1408)|0;UGb(na|0,v|0,wa*88|0)|0;UGb(c[b+72+(xa+1<<3)>>2]|0,c[_>>2]|0,Y<<2)|0;if((ca|0)>0){l=1;ka=ca;da=xa}else{break h}}}else{za=0}}while(0);da=oa+1|0;if(!((za|0)==0&(da|0)<8)){break}ka=k|0;l=da;da=c[n>>2]|0;while(1){k:do{if((da|0)>0){m=0;fa=da;while(1){ea=c[b+608+(m*88|0)+4>>2]|0;if((ea|0)==0){Aa=m;Ba=fa;break k}c[k+(m*88|0)+4>>2]=ea;c[k+(m*88|0)>>2]=l;ea=m+1|0;Mbb(c[b+72+(m<<3)>>2]|0,c[b+72+(ea<<3)>>2]|0,c[o>>2]|0,ka,m);ha=c[n>>2]|0;if((ea|0)<(ha|0)){m=ea;fa=ha}else{Aa=ea;Ba=ha;break}}}else{Aa=0;Ba=da}}while(0);fa=b+72+(Aa<<3)|0;m=c[o>>2]|0;ca=c[T>>2]|0;if(!((m|0)==0|(ca|0)==0)){Y=c[fa>>2]|0;_=m;while(1){ha=_-1|0;ea=Y+4|0;X=c[Y>>2]|0;f=(X|0)>-1?X:-X|0;X=(f>>>9)+f|0;if(!(X>>>0<256>>>0)){do{if(X>>>0<65536>>>0){Ca=(a[637664+(X>>>8)|0]|0)+8|0}else{if(X>>>0<16777216>>>0){Ca=(a[637664+(X>>>16)|0]|0)+16|0;break}else{Ca=(a[637664+(X>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[15880+(X>>>((Ca-9|0)>>>0)&255)|0]|Ca<<8)>>>0<ca>>>0)){break h}}if((ha|0)==0){break}else{Y=ea;_=ha}}}if((c[la>>2]|0)==0){break h}c[la>>2]=0;TGb(na|0,0,1408)|0;UGb(na|0,v|0,Aa*88|0)|0;UGb(c[b+72+(Ba+1<<3)>>2]|0,c[fa>>2]|0,m<<2)|0;_=l+1|0;if((_|0)<8){l=_;da=Ba}else{break}}}}while(0);da=c[pa>>2]|0;do{if((da&2|0)!=0){if((c[S>>2]|0)==0){break}l=b+2020|0;g[l>>2]=(+g[l>>2]*2.0+ +(c[ma>>2]|0))/3.0;va=da;break g}}while(0);g[b+2020>>2]=2.0;va=da}}while(0);if((va&16|0)!=0){Lbb(b,k)}ma=c[n>>2]|0;if((h|0)==0){Da=0}else{UGb(u|0,c[b+72+(ma+1<<3)>>2]|0,c[o>>2]<<2)|0;Da=0}while(1){if((Da|0)>=(ma|0)){break}if((c[b+608+(Da*88|0)+4>>2]|0)==0){break}else{Da=Da+1|0}}c[qa>>2]=Da}}while(0);do{if(!t){if((c[pa>>2]|0)==0){s=0}else{break}i=j;return s|0}}while(0);TGb(b+468|0,0,76)|0;Fbb(b+488|0,c[b+392>>2]|0,p);s=0;i=j;return s|0}function vbb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;j=i;i=i+1496|0;k=j|0;l=j+88|0;m=l;TGb(m|0,0,1408)|0;n=c[b+32>>2]|0;o=n<<2;p=0;while(1){if((p|0)>=(n|0)){break}if((c[e+(p<<2)>>2]|0)!=0){break}if((c[f+(p<<2)>>2]|0)==0){p=p+1|0}else{break}}q=b+460|0;r=c[q>>2]|0;if((p|0)==(n|0)){c[q>>2]=r&-17;TGb(b+608|0,0,1408)|0;TGb(b+468|0,0,76)|0;c[b+576>>2]=0;s=0;i=j;return s|0}p=(r>>>18<<8&7936)+1024|0;r=p>>>0<6912>>>0?p:6912;p=c[b+452>>2]|0;if((p|0)==0){t=0;u=0}else{t=p>>>31;u=(p|0)>0|0}p=Abb(b)|0;if((p|0)<0){s=p;i=j;return s|0}p=c[b+596>>2]|0;if((g|0)!=0|(p|0)>6){c[b+604>>2]=0;c[b+600>>2]=0}v=b+596|0;a:do{if((p|0)>0){w=b+604|0;x=b+600|0;y=b+592|0;z=b+2016|0;A=b+448|0;B=(u|0)==0;C=(t|0)==0;D=b+360|0;E=e;F=b+364|0;G=f;H=b+408|0;I=H;J=b+416|0;K=b+412|0;L=K;M=b+420|0;N=(n|0)>0;O=(n|0)==0;P=k;Q=k|0;R=k+4|0;S=(n|0)<2048?n:2048;T=k+16|0;U=b+392|0;V=b+396|0;W=b+608|0;X=b+576|0;Y=0;Z=0;_=-1;$=p;while(1){b:do{if((Z|0)==0){aa=c[x>>2]|0;ba=0}else{ca=c[w>>2]|0;while(1){da=(ca|0)==0;ea=c[x>>2]|0;if(da){fa=0}else{fa=ea&ca-1|ca}if((fa|0)!=(ea|0)){aa=fa;ba=1;break b}if(da){ga=1}else{ga=(c[y>>2]|0)-1&ca<<1}c[w>>2]=ga;if((Z|0)<($|0)){ca=ga}else{break a}}}}while(0);ca=c[z>>2]|0;da=ca+(aa*19|0)|0;ea=ca+(aa*19|0)+1|0;ha=d[1402776+(c[A>>2]|0)|0]|0;ia=Y;c:while(1){do{if(B){if((a[da]|0)!=0&C){ja=26;break}UGb(c[D>>2]|0,E|0,o)|0;UGb(c[F>>2]|0,G|0,o)|0;ka=ia}else{ja=26}}while(0);if((ja|0)==26){ja=0;do{if((ia|0)==0){O$a(I,J,o);O$a(L,M,o);UGb(c[H>>2]|0,E|0,o)|0;UGb(c[K>>2]|0,G|0,o)|0;if(!N){la=1;break}ma=c[K>>2]|0;na=c[H>>2]|0;oa=0;while(1){pa=ma+(oa<<2)|0;qa=na+(oa<<2)|0;ra=(c[qa>>2]|0)-(c[pa>>2]|0)|0;c[qa>>2]=ra;c[pa>>2]=(c[pa>>2]|0)+(ra>>1);ra=oa+1|0;if((ra|0)<(n|0)){oa=ra}else{la=1;break}}}else{la=ia}}while(0);UGb(c[D>>2]|0,c[H>>2]|0,o)|0;UGb(c[F>>2]|0,c[K>>2]|0,o)|0;ka=la}TGb(m|0,0,1408)|0;if((ha|0)>0){oa=0;do{TGb(P|0,0,88)|0;c[Q>>2]=a[ea]|0;na=a[ca+(aa*19|0)+2+oa|0]|0;c[R>>2]=na<<24>>24;do{if(na<<24>>24<0){if((c[q>>2]&32|0)!=0){break}c[R>>2]=-3}}while(0);na=oa&1;ma=b+360+(na<<3)|0;ra=b+360+(na<<3)+4|0;pa=na^1;na=b+360+(pa<<3)|0;qa=b+360+(pa<<3)+4|0;Bbb(c[ma>>2]|0,c[ra>>2]|0,c[na>>2]|0,c[qa>>2]|0,S,k,-1);if((oa|0)==0){Cbb(k)}else{TGb(T|0,0,64)|0}UGb(l+(oa*88|0)|0,P|0,88)|0;pa=c[ma>>2]|0;ma=c[ra>>2]|0;ra=c[na>>2]|0;na=c[qa>>2]|0;if((c[q>>2]&4194304)>>>0>3932160>>>0){Bbb(pa,ma,ra,na,n,k,1)}else{Dbb(pa,ma,ra,na,n,k)}oa=oa+1|0;}while((oa|0)<(ha|0));sa=ha&1}else{sa=0}ta=b+360+(sa<<3)|0;ua=b+360+(sa<<3)+4|0;if(O){ja=62;break}oa=c[ta>>2]|0;na=c[ua>>2]|0;ra=n;while(1){ma=ra-1|0;pa=c[oa>>2]|0;qa=(pa|0)>-1?pa:-pa|0;pa=(qa>>>9)+qa|0;if(!(pa>>>0<256>>>0)){do{if(pa>>>0<65536>>>0){va=(a[637664+(pa>>>8)|0]|0)+8|0}else{if(pa>>>0<16777216>>>0){va=(a[637664+(pa>>>16)|0]|0)+16|0;break}else{va=(a[637664+(pa>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[15880+(pa>>>((va-9|0)>>>0)&255)|0]|va<<8)>>>0<r>>>0)){break}}qa=oa+4|0;wa=na+4|0;xa=c[na>>2]|0;ya=(xa|0)>-1?xa:-xa|0;xa=(ya>>>9)+ya|0;if(!(xa>>>0<256>>>0)){do{if(xa>>>0<65536>>>0){za=(a[637664+(xa>>>8)|0]|0)+8|0}else{if(xa>>>0<16777216>>>0){za=(a[637664+(xa>>>16)|0]|0)+16|0;break}else{za=(a[637664+(xa>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[15880+(xa>>>((za-9|0)>>>0)&255)|0]|za<<8)>>>0<r>>>0)){break}}if((ma|0)==0){ja=62;break c}else{oa=qa;na=wa;ra=ma}}if((ha|0)==0){Aa=_;break}else{ha=ha>>1;ia=ka}}do{if((ja|0)==62){ja=0;if((_|0)==0){Aa=_;break}UGb(c[U>>2]|0,c[ta>>2]|0,o)|0;UGb(c[V>>2]|0,c[ua>>2]|0,o)|0;UGb(W|0,m|0,1408)|0;c[X>>2]=ha;c[x>>2]=aa;Aa=0}}while(0);ha=Z+1|0;if(ba){ia=c[w>>2]|0;if((ia|0)==0){Ba=1}else{Ba=(c[y>>2]|0)-1&ia<<1}c[w>>2]=Ba}ia=c[v>>2]|0;if((ha|0)<(ia|0)){Y=ka;Z=ha;_=Aa;$=ia}else{break}}}}while(0);do{if((u|0)==0){if((a[(c[b+2016>>2]|0)+((c[b+600>>2]|0)*19|0)|0]|0)!=0&(t|0)==0){ja=71;break}Ca=c[q>>2]&-17}else{ja=71}}while(0);if((ja|0)==71){Ca=c[q>>2]|16}c[q>>2]=Ca;q=b+440|0;do{if((c[q>>2]|0)==0){if((h|0)==0){break}UGb(e|0,c[b+392>>2]|0,o)|0;UGb(f|0,c[b+396>>2]|0,o)|0}else{if((Ca&16|0)==0){Ebb(b,e,f,h);break}ja=b+408|0;t=b+412|0;Ebb(b,c[ja>>2]|0,c[t>>2]|0,h);if((h|0)==0){break}UGb(e|0,c[ja>>2]|0,o)|0;UGb(f|0,c[t>>2]|0,o)|0}}while(0);do{if((c[q>>2]|g|0)==0){o=b+584|0;f=a[(c[b+2016>>2]|0)+((c[b+600>>2]|0)*19|0)|0]|0;if((c[o>>2]|0)==(f<<24>>24|0)){s=0}else{Da=f;Ea=o;break}i=j;return s|0}else{Da=a[(c[b+2016>>2]|0)+((c[b+600>>2]|0)*19|0)|0]|0;Ea=b+584|0}}while(0);c[Ea>>2]=Da<<24>>24;TGb(b+468|0,0,76)|0;Fbb(b+488|0,c[b+392>>2]|0,n);Fbb(b+516|0,c[b+396>>2]|0,n);s=0;i=j;return s|0}function wbb(a){a=a|0;var b=0,c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)<0){b=-a|0;do{if((b|0)==1){c=256}else if((b|0)==0){c=0}else{e=(b>>9)-a|0;f=e>>>0>65535>>>0;g=f?e>>>16:e;h=f?16:0;if((g&65280|0)==0){i=h;j=g}else{i=h|8;j=g>>>8}g=(d[1191992+j|0]|0)+i|0;h=g+1|0;f=h<<8;if((h|0)<9){c=d[15880+(e<<8-g&255)|0]|0|f;break}else{c=d[15880+(e>>g-8&255)|0]|0|f;break}}}while(0);k=-c|0;return k|0}if((a|0)==0){k=0;return k|0}else if((a|0)==1){k=256;return k|0}else{c=(a>>9)+a|0;a=c>>>0>65535>>>0;i=a?c>>>16:c;j=a?16:0;if((i&65280|0)==0){l=j;m=i}else{l=j|8;m=i>>>8}i=(d[1191992+m|0]|0)+l|0;l=i+1|0;m=l<<8;if((l|0)<9){k=d[15880+(c<<8-i&255)|0]|0|m;return k|0}else{k=d[15880+(c>>i-8&255)|0]|0|m;return k|0}}return 0}function xbb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;f=b+468|0;g=e>>>31;h=b+488|0;do{if((c[h>>2]|0)<2){if((c[b+480>>2]|0)!=0){break}i=b+516|0;if((c[i>>2]|0)>=2){break}j=b+476|0;k=c[j>>2]|0;l=(e|0)!=0;if((k|0)!=0){if(l){ybb(b);break}c[j>>2]=k+1;return}if(!l){TGb(h|0,0,12)|0;TGb(i|0,0,12)|0;c[j>>2]=1;return}j=b+8|0;i=c[j>>2]|0;l=b+12|0;k=c[l>>2]|0;if((k|0)>1){m=k;n=i}else{o=b+20|0;p=c[o>>2]|0;x=i;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;m=k+32|0;n=0}c[j>>2]=n;c[l>>2]=m-1}}while(0);m=e>>31^e;e=d|0;n=c[e>>2]|0;h=n>>4;l=h+1|0;do{if((m|0)<(l|0)){c[e>>2]=n-(((n+126|0)/128|0)<<1);q=0;r=0;s=h}else{c[e>>2]=(((n+128|0)/128|0)*5|0)+n;j=d+4|0;k=c[j>>2]|0;o=k>>4;p=o+1|0;if((m-l|0)>>>0<p>>>0){c[j>>2]=k-(((k+62|0)/64|0)<<1);q=1;r=l;s=o+l|0;break}o=p+l|0;c[j>>2]=(((k+64|0)/64|0)*5|0)+k;k=m-o|0;j=d+8|0;p=c[j>>2]|0;i=p>>4;t=i+1|0;if(k>>>0<t>>>0){c[j>>2]=p-(((p+30|0)/32|0)<<1);q=2;r=o;s=i+o|0;break}else{u=(k>>>0)/(t>>>0)|0;k=(ba(u,t)|0)+o|0;c[j>>2]=(((p+32|0)/32|0)*5|0)+p;q=u+2|0;r=k;s=k+i|0;break}}}while(0);d=b+480|0;do{if((c[d>>2]|0)==0){c[d>>2]=1;v=q;w=1}else{if((q|0)==0){ybb(b);c[d>>2]=0;v=0;w=0;break}else{l=b+472|0;c[l>>2]=(c[l>>2]|0)+1;ybb(b);c[d>>2]=1;v=q-1|0;w=1;break}}}while(0);c[b+472>>2]=v<<1;do{if((s|0)==(r|0)){y=c[b+484>>2]|0;z=c[f>>2]|0}else{v=s-r|0;q=m-r|0;do{if(v>>>0<256>>>0){A=a[637664+v|0]|0}else{if(v>>>0<65536>>>0){A=(a[637664+(v>>>8)|0]|0)+8|0;break}if(v>>>0<16777216>>>0){A=(a[637664+(v>>>16)|0]|0)+16|0;break}else{A=(a[637664+(v>>>24)|0]|0)+24|0;break}}}while(0);d=(1<<A)-v-1|0;if(q>>>0<d>>>0){l=b+484|0;n=c[l>>2]|0;e=f|0;h=c[e>>2]|q<<n;c[e>>2]=h;e=A-1+n|0;c[l>>2]=e;y=e;z=h;break}else{h=d+q|0;d=b+484|0;e=c[d>>2]|0;l=f|0;n=c[l>>2]|h>>>1<<e;i=e+A|0;c[d>>2]=i;d=(h&1)<<A-1+e|n;c[l>>2]=d;y=i;z=d;break}}}while(0);c[b+484>>2]=y+1;c[f>>2]=z|g<<y;if((w|0)!=0){return}ybb(b);return}function ybb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=b+8|0;e=b+476|0;f=c[e>>2]|0;if((f|0)!=0){do{if((f|0)<256){g=a[637664+f|0]|0}else{if((f|0)<65536){g=(a[637664+(f>>8)|0]|0)+8|0;break}if((f|0)<16777216){g=(a[637664+(f>>16)|0]|0)+16|0;break}else{g=(a[637664+(f>>24)|0]|0)+24|0;break}}}while(0);f=d|0;h=b+12|0;i=b+20|0;j=g;while(1){if((j|0)<=31){k=13;break}g=c[h>>2]|0;l=2147483647<<32-g|c[f>>2];if((g|0)>31){m=g;n=l}else{o=c[i>>2]|0;x=l;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;m=g+32|0;n=2147483647>>>(g>>>0)}g=m-31|0;c[f>>2]=n;c[h>>2]=g;o=j-31|0;if((o|0)==0){p=n;q=g;break}else{j=o}}if((k|0)==13){n=(1<<j)-1|0;m=c[h>>2]|0;o=n<<32-m|c[f>>2];if((m|0)>(j|0)){r=m;s=o}else{g=c[i>>2]|0;x=o;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;r=m+32|0;s=(m|0)==32?0:n>>>(m>>>0)}m=r-j|0;c[f>>2]=s;c[h>>2]=m;p=s;q=m}if((q|0)>1){t=q;u=p}else{m=c[i>>2]|0;x=p;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;t=q+32|0;u=0}q=t-1|0;c[f>>2]=u;c[h>>2]=q;t=c[e>>2]|0;if((t|0)>1){m=t;t=u;u=q;while(1){q=m&1;p=q<<32-u|t;if((u|0)>1){v=u;w=p;y=m}else{s=c[i>>2]|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;v=u+32|0;w=q>>>(u>>>0);y=c[e>>2]|0}q=v-1|0;c[f>>2]=w;c[h>>2]=q;s=y>>1;c[e>>2]=s;if((s|0)>1){m=s;t=w;u=q}else{break}}}c[e>>2]=0}e=b+472|0;u=c[e>>2]|0;if((u|0)!=0){if((u|0)>15){w=d|0;t=b+12|0;m=c[t>>2]|0;y=65535<<32-m|c[w>>2];if((m|0)>16){z=m;A=y}else{h=b+20|0;f=c[h>>2]|0;x=y;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;z=m+32|0;A=65535>>>(m>>>0)}m=z-16|0;c[w>>2]=A;c[t>>2]=m;if((m|0)>1){B=m;C=A}else{m=b+20|0;h=c[m>>2]|0;x=A;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;B=z+16|0;C=0}z=B-1|0;c[w>>2]=C;c[t>>2]=z;B=(c[e>>2]|0)-16|0;c[e>>2]=B;do{if((B|0)<256){D=a[637664+B|0]|0}else{if((B|0)<65536){D=(a[637664+(B>>8)|0]|0)+8|0;break}if((B|0)<16777216){D=(a[637664+(B>>16)|0]|0)+16|0;break}else{D=(a[637664+(B>>24)|0]|0)+24|0;break}}}while(0);B=b+20|0;m=D;D=C;C=z;while(1){if((m|0)<=31){k=41;break}z=2147483647<<32-C|D;if((C|0)>31){E=C;F=z}else{h=c[B>>2]|0;x=z;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;E=C+32|0;F=2147483647>>>(C>>>0)}h=E-31|0;c[w>>2]=F;c[t>>2]=h;z=m-31|0;if((z|0)==0){G=h;H=F;break}else{m=z;D=F;C=h}}if((k|0)==41){k=(1<<m)-1|0;F=k<<32-C|D;if((C|0)>(m|0)){I=C;J=F}else{D=c[B>>2]|0;x=F;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;I=C+32|0;J=(C|0)==32?0:k>>>(C>>>0)}C=I-m|0;c[w>>2]=J;c[t>>2]=C;G=C;H=J}if((G|0)>1){K=G;L=H}else{J=c[B>>2]|0;x=H;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;K=G+32|0;L=0}G=K-1|0;c[w>>2]=L;c[t>>2]=G;K=c[e>>2]|0;if((K|0)>1){J=K;K=L;L=G;while(1){G=J&1;H=G<<32-L|K;if((L|0)>1){M=L;N=H;O=J}else{C=c[B>>2]|0;x=H;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;M=L+32|0;N=G>>>(L>>>0);O=c[e>>2]|0}G=M-1|0;c[w>>2]=N;c[t>>2]=G;C=O>>1;c[e>>2]=C;if((C|0)>1){J=C;K=N;L=G}else{break}}}c[b+480>>2]=0}else{L=(1<<u)-1|0;N=d|0;K=b+12|0;J=c[K>>2]|0;O=L<<32-J|c[N>>2];if((J|0)>(u|0)){P=J;Q=O}else{t=b+20|0;w=c[t>>2]|0;x=O;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;P=J+32|0;Q=(J|0)==32?0:L>>>(J>>>0)}c[N>>2]=Q;c[K>>2]=P-u}c[e>>2]=0}e=b+480|0;if((c[e>>2]|0)!=0){u=d|0;P=c[u>>2]|0;K=b+12|0;Q=c[K>>2]|0;if((Q|0)>1){R=Q;S=P}else{N=b+20|0;J=c[N>>2]|0;x=P;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;R=Q+32|0;S=0}c[u>>2]=S;c[K>>2]=R-1;c[e>>2]=0}e=b+484|0;R=c[e>>2]|0;if((R|0)==0){return}K=b+468|0;S=c[K>>2]|0;u=d|0;d=b+12|0;Q=c[d>>2]|0;N=S<<32-Q|c[u>>2];if((Q|0)>(R|0)){T=Q;U=N}else{J=b+20|0;b=c[J>>2]|0;x=N;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[J>>2]=(c[J>>2]|0)+4;T=Q+32|0;U=(Q|0)==32?0:S>>>(Q>>>0)}c[u>>2]=U;c[d>>2]=T-R;c[e>>2]=0;c[K>>2]=0;return}function zbb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=a[b+550|0]|0;g=f&255;h=b+8|0;i=c[e>>2]|0;j=i>>>23&255;do{if((j|0)==0){k=i&8388607;l=f<<24>>24==0?0:g-1|0;m=13}else if((j|0)==255){n=h|0;o=c[n>>2]|0;p=b+12|0;q=c[p>>2]|0;if((i&8388607|0)==0){if((q|0)>1){r=q;s=o}else{t=b+20|0;u=c[t>>2]|0;x=o;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;r=q+32|0;s=0}c[n>>2]=s;c[p>>2]=r-1;v=0;w=16777216;m=14;break}t=1<<32-q|o;if((q|0)>1){y=q;z=t}else{o=b+20|0;u=c[o>>2]|0;x=t;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;y=q+32|0;z=1>>>(q>>>0)}q=y-1|0;c[n>>2]=z;c[p>>2]=q;o=c[e>>2]&8388607;u=o<<33-y|z;if((q|0)>23){A=q;B=u}else{t=b+20|0;C=c[t>>2]|0;x=u;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;A=y+31|0;B=o>>>(q>>>0)}c[n>>2]=B;c[p>>2]=A-23;v=0;w=16777216;m=14}else{k=i&8388607|8388608;l=g-j|0;m=13}}while(0);if((m|0)==13){if((l|0)<25){v=l;w=k;m=14}}do{if((m|0)==14){if((w>>v|0)==0){break}if((v|0)==0){return}k=d[b+548|0]|0;if((k&4|0)!=0){l=(1<<v)+8388607&8388607&c[e>>2];j=h|0;g=b+12|0;i=c[g>>2]|0;A=l<<32-i|c[j>>2];if((i|0)>(v|0)){D=i;E=A}else{B=b+20|0;y=c[B>>2]|0;x=A;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;D=i+32|0;E=(i|0)==32?0:l>>>(i>>>0)}c[j>>2]=E;c[g>>2]=D-v;return}if((k&2|0)==0){return}k=c[e>>2]&1;g=h|0;j=b+12|0;i=c[j>>2]|0;l=k<<32-i|c[g>>2];if((i|0)>1){F=i;G=l}else{B=b+20|0;y=c[B>>2]|0;x=l;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;F=i+32|0;G=k>>>(i>>>0)}c[g>>2]=G;c[j>>2]=F-1;return}}while(0);F=b+548|0;G=a[F]|0;if((G&8)==0){return}v=h|0;h=c[v>>2]|0;D=b+12|0;E=c[D>>2]|0;if((c[e>>2]&2147483647|0)==0){if((E|0)>1){H=E;I=h;J=G}else{G=b+20|0;w=c[G>>2]|0;x=h;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;H=E+32|0;I=0;J=a[F]|0}F=H-1|0;c[v>>2]=I;c[D>>2]=F;if((J&16)==0){return}J=(c[e>>2]|0)>>>31;G=J<<33-H|I;if((F|0)>1){K=F;L=G}else{I=b+20|0;w=c[I>>2]|0;x=G;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;K=H+31|0;L=J>>>(F>>>0)}c[v>>2]=L;c[D>>2]=K-1;return}K=1<<32-E|h;if((E|0)>1){M=E;N=K}else{h=b+20|0;L=c[h>>2]|0;x=K;a[L]=x;x=x>>8;a[L+1|0]=x;x=x>>8;a[L+2|0]=x;x=x>>8;a[L+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;M=E+32|0;N=1>>>(E>>>0)}E=M-1|0;c[v>>2]=N;c[D>>2]=E;h=c[e>>2]&8388607;L=h<<33-M|N;if((E|0)>23){O=E;P=L}else{N=b+20|0;K=c[N>>2]|0;x=L;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;O=M+31|0;P=h>>>(E>>>0)}E=O-23|0;c[v>>2]=P;c[D>>2]=E;if((f&255)>>>0>24>>>0){f=(c[e>>2]|0)>>>23&255;h=f<<55-O|P;if((E|0)>8){Q=E;R=h}else{M=b+20|0;N=c[M>>2]|0;x=h;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[M>>2]=(c[M>>2]|0)+4;Q=O+9|0;R=f>>>(E>>>0)}f=Q-8|0;c[v>>2]=R;c[D>>2]=f;S=f;T=R}else{S=E;T=P}P=(c[e>>2]|0)>>>31;e=P<<32-S|T;if((S|0)>1){U=S;V=e}else{T=b+20|0;b=c[T>>2]|0;x=e;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[T>>2]=(c[T>>2]|0)+4;U=S+32|0;V=P>>>(S>>>0)}c[v>>2]=V;c[D>>2]=U-1;return}function Abb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+392|0;d=b|0;e=b;b=a+400|0;f=a+32|0;g=a+396|0;h=g;i=a+404|0;j=a+460|0;O$a(e,b,c[f>>2]<<2);if((c[d>>2]|0)==0){k=-12;return k|0}l=a+360|0;O$a(l,a+376|0,c[f>>2]<<2);if((c[l>>2]|0)==0){k=-12;return k|0}do{if((c[j>>2]&1073741828|0)==0){O$a(h,i,c[f>>2]<<2);if((c[g>>2]|0)==0){k=-12;return k|0}l=a+364|0;O$a(l,a+380|0,c[f>>2]<<2);if((c[l>>2]|0)==0){k=-12}else{break}return k|0}}while(0);O$a(e,b,c[f>>2]<<2);if((c[d>>2]|0)==0){k=-12;return k|0}d=a+368|0;O$a(d,a+384|0,c[f>>2]<<2);if((c[d>>2]|0)==0){k=-12;return k|0}do{if((c[j>>2]&1073741828|0)==0){O$a(h,i,c[f>>2]<<2);if((c[g>>2]|0)==0){k=-12;return k|0}d=a+372|0;O$a(d,a+388|0,c[f>>2]<<2);if((c[d>>2]|0)==0){k=-12}else{break}return k|0}}while(0);k=0;return k|0}function Bbb(a,b,e,f,g,h,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;k=i;i=i+64|0;l=k|0;m=k+32|0;n=h+84|0;c[n>>2]=0;o=h+80|0;c[o>>2]=0;if((j|0)<0){p=g-1|0;q=a+(p<<2)|0;r=b+(p<<2)|0;s=e+(p<<2)|0;t=f+(p<<2)|0}else{q=a;r=b;s=e;t=f}f=h+8|0;e=c[f>>2]|0;do{if((e|0)<-1024){u=-1024}else{b=(e|0)>1024?1024:e;if((b|0)>0){v=b-(b+64>>7)|0}else{v=b}b=(v+4|0)>>>3<<24;a=b>>21;if((b|0)<=0){u=a;break}u=(a+64>>7)+a|0}}while(0);c[f>>2]=u;u=h+12|0;v=c[u>>2]|0;do{if((v|0)<-1024){w=-1024}else{e=(v|0)>1024?1024:v;if((e|0)>0){x=e-(e+64>>7)|0}else{x=e}e=(x+4|0)>>>3<<24;a=e>>21;if((e|0)<=0){w=a;break}w=(a+64>>7)+a|0}}while(0);c[u>>2]=w;w=0;do{x=h+16+(w<<2)|0;v=(wbb(c[x>>2]|0)|0)&65535;a=v<<16>>16<0;e=(a?-v&65535:v)<<16>>16;v=d[16392+(e&255)|0]|0|256;b=e>>>8<<16;e=b>>16;if((b|0)>589824){y=v<<e-9}else{y=v>>>((9-e|0)>>>0)}c[x>>2]=a?-y|0:y;a=h+48+(w<<2)|0;x=(wbb(c[a>>2]|0)|0)&65535;e=x<<16>>16<0;v=(e?-x&65535:x)<<16>>16;x=d[16392+(v&255)|0]|0|256;b=v>>>8<<16;v=b>>16;if((b|0)>589824){z=x<<v-9}else{z=x>>>((9-v|0)>>>0)}c[a>>2]=e?-z|0:z;w=w+1|0;}while((w|0)<8);w=c[h+4>>2]|0;switch(w|0){case-2:{if((g|0)==0){i=k;return}z=h+48|0;y=h|0;e=t;a=s;v=r;x=q;b=g;while(1){p=b-1|0;A=c[z>>2]|0;B=c[v>>2]|0;if((A|0)==(A<<16>>16|0)){C=(ba(c[u>>2]|0,A)|0)+512>>10}else{D=c[u>>2]|0;C=(ba(D,A>>9&-128)|0|1)+((ba(D,A&65535)|0)>>9)>>1}D=B-C|0;c[e>>2]=D;do{if((A|0)==0|(B|0)==(C|0)){E=c[u>>2]|0}else{F=c[y>>2]|0;G=c[u>>2]|0;if((D^A|0)<0){H=G-F|0;c[u>>2]=H;if(!((H|0)<-1024)){E=H;break}c[u>>2]=-1024;E=-1024;break}else{H=G+F|0;c[u>>2]=H;if((H|0)<=1024){E=H;break}c[u>>2]=1024;E=1024;break}}}while(0);c[n>>2]=(c[n>>2]|0)+E;A=c[x>>2]|0;c[z>>2]=A;if((B|0)==(B<<16>>16|0)){I=(ba(c[f>>2]|0,B)|0)+512>>10}else{D=c[f>>2]|0;I=(ba(D,B>>9&-128)|0|1)+((ba(D,B&65535)|0)>>9)>>1}D=A-I|0;c[a>>2]=D;do{if((B|0)==0|(A|0)==(I|0)){J=c[f>>2]|0}else{H=c[y>>2]|0;F=c[f>>2]|0;if((D^B|0)<0){G=F-H|0;c[f>>2]=G;if(!((G|0)<-1024)){J=G;break}c[f>>2]=-1024;J=-1024;break}else{G=F+H|0;c[f>>2]=G;if((G|0)<=1024){J=G;break}c[f>>2]=1024;J=1024;break}}}while(0);c[o>>2]=(c[o>>2]|0)+J;if((p|0)==0){break}else{e=e+(j<<2)|0;a=a+(j<<2)|0;v=v+(j<<2)|0;x=x+(j<<2)|0;b=p}}i=k;return};case-3:{if((g|0)==0){i=k;return}b=h+16|0;x=h+48|0;v=h|0;a=t;e=s;J=r;y=q;I=g;while(1){z=I-1|0;E=c[b>>2]|0;C=c[x>>2]|0;B=c[J>>2]|0;c[b>>2]=B;if((C|0)==(C<<16>>16|0)){K=(ba(c[u>>2]|0,C)|0)+512>>10}else{D=c[u>>2]|0;K=(ba(D,C>>9&-128)|0|1)+((ba(D,C&65535)|0)>>9)>>1}D=B-K|0;c[a>>2]=D;do{if((C|0)==0|(B|0)==(K|0)){L=c[u>>2]|0}else{A=c[v>>2]|0;G=c[u>>2]|0;if((D^C|0)<0){H=G-A|0;c[u>>2]=H;if(!((H|0)<-1024)){L=H;break}c[u>>2]=-1024;L=-1024;break}else{H=G+A|0;c[u>>2]=H;if((H|0)<=1024){L=H;break}c[u>>2]=1024;L=1024;break}}}while(0);c[n>>2]=(c[n>>2]|0)+L;C=c[y>>2]|0;c[x>>2]=C;if((E|0)==(E<<16>>16|0)){M=(ba(c[f>>2]|0,E)|0)+512>>10}else{D=c[f>>2]|0;M=(ba(D,E>>9&-128)|0|1)+((ba(D,E&65535)|0)>>9)>>1}D=C-M|0;c[e>>2]=D;do{if((E|0)==0|(C|0)==(M|0)){N=c[f>>2]|0}else{B=c[v>>2]|0;p=c[f>>2]|0;if((D^E|0)<0){H=p-B|0;c[f>>2]=H;if(!((H|0)<-1024)){N=H;break}c[f>>2]=-1024;N=-1024;break}else{H=p+B|0;c[f>>2]=H;if((H|0)<=1024){N=H;break}c[f>>2]=1024;N=1024;break}}}while(0);c[o>>2]=(c[o>>2]|0)+N;if((z|0)==0){break}else{a=a+(j<<2)|0;e=e+(j<<2)|0;J=J+(j<<2)|0;y=y+(j<<2)|0;I=z}}i=k;return};case-1:{if((g|0)==0){i=k;return}I=h+16|0;y=h|0;J=t;e=s;a=r;N=q;v=g;while(1){M=v-1|0;x=c[I>>2]|0;L=c[N>>2]|0;if((x|0)==(x<<16>>16|0)){O=(ba(c[f>>2]|0,x)|0)+512>>10}else{K=c[f>>2]|0;O=(ba(K,x>>9&-128)|0|1)+((ba(K,x&65535)|0)>>9)>>1}K=L-O|0;c[e>>2]=K;do{if((x|0)==0|(L|0)==(O|0)){P=c[f>>2]|0}else{b=c[y>>2]|0;E=c[f>>2]|0;if((K^x|0)<0){D=E-b|0;c[f>>2]=D;if(!((D|0)<-1024)){P=D;break}c[f>>2]=-1024;P=-1024;break}else{D=E+b|0;c[f>>2]=D;if((D|0)<=1024){P=D;break}c[f>>2]=1024;P=1024;break}}}while(0);c[o>>2]=(c[o>>2]|0)+P;x=c[a>>2]|0;c[I>>2]=x;if((L|0)==(L<<16>>16|0)){Q=(ba(c[u>>2]|0,L)|0)+512>>10}else{K=c[u>>2]|0;Q=(ba(K,L>>9&-128)|0|1)+((ba(K,L&65535)|0)>>9)>>1}K=x-Q|0;c[J>>2]=K;do{if((L|0)==0|(x|0)==(Q|0)){R=c[u>>2]|0}else{z=c[y>>2]|0;D=c[u>>2]|0;if((K^L|0)<0){b=D-z|0;c[u>>2]=b;if(!((b|0)<-1024)){R=b;break}c[u>>2]=-1024;R=-1024;break}else{b=D+z|0;c[u>>2]=b;if((b|0)<=1024){R=b;break}c[u>>2]=1024;R=1024;break}}}while(0);c[n>>2]=(c[n>>2]|0)+R;if((M|0)==0){break}else{J=J+(j<<2)|0;e=e+(j<<2)|0;a=a+(j<<2)|0;N=N+(j<<2)|0;v=M}}i=k;return};case 2:{if((g|0)==0){i=k;return}v=h+16|0;N=h+20|0;a=h+48|0;e=h+52|0;J=h|0;R=t;y=s;Q=r;I=q;P=g;while(1){O=P-1|0;L=c[v>>2]|0;c[v>>2]=c[N>>2];K=c[I>>2]|0;c[N>>2]=K;if((L|0)==(L<<16>>16|0)){S=(ba(c[f>>2]|0,L)|0)+512>>10}else{x=c[f>>2]|0;S=(ba(x,L>>9&-128)|0|1)+((ba(x,L&65535)|0)>>9)>>1}x=K-S|0;c[y>>2]=x;if((L|0)==0|(K|0)==(S|0)){T=c[f>>2]|0}else{K=x^L;L=(c[f>>2]|0)+(K>>>31)+(c[J>>2]^K>>31)|0;c[f>>2]=L;T=L}c[o>>2]=(c[o>>2]|0)+T;L=c[a>>2]|0;c[a>>2]=c[e>>2];K=c[Q>>2]|0;c[e>>2]=K;if((L|0)==(L<<16>>16|0)){U=(ba(c[u>>2]|0,L)|0)+512>>10}else{x=c[u>>2]|0;U=(ba(x,L>>9&-128)|0|1)+((ba(x,L&65535)|0)>>9)>>1}x=K-U|0;c[R>>2]=x;if((L|0)==0|(K|0)==(U|0)){V=c[u>>2]|0}else{K=x^L;L=(c[u>>2]|0)+(K>>>31)+(c[J>>2]^K>>31)|0;c[u>>2]=L;V=L}c[n>>2]=(c[n>>2]|0)+V;if((O|0)==0){break}else{R=R+(j<<2)|0;y=y+(j<<2)|0;Q=Q+(j<<2)|0;I=I+(j<<2)|0;P=O}}i=k;return};case 17:{if((g|0)==0){i=k;return}P=h+16|0;I=h+20|0;Q=h+48|0;y=h+52|0;R=h|0;V=t;J=s;U=r;e=q;a=g;while(1){T=a-1|0;S=c[P>>2]|0;N=S<<1;v=c[I>>2]|0;O=N-v|0;c[I>>2]=S;S=c[e>>2]|0;c[P>>2]=S;if((O|0)==(O<<16>>16|0)){W=(ba(c[f>>2]|0,O)|0)+512>>10}else{L=c[f>>2]|0;W=(ba(L,O>>9&-128)|0|1)+((ba(L,O&65535)|0)>>9)>>1}L=S-W|0;c[J>>2]=L;if((N|0)==(v|0)|(S|0)==(W|0)){X=c[f>>2]|0}else{S=L^O;O=(c[f>>2]|0)+(S>>>31)+(c[R>>2]^S>>31)|0;c[f>>2]=O;X=O}c[o>>2]=(c[o>>2]|0)+X;O=c[Q>>2]|0;S=O<<1;L=c[y>>2]|0;v=S-L|0;c[y>>2]=O;O=c[U>>2]|0;c[Q>>2]=O;if((v|0)==(v<<16>>16|0)){Y=(ba(c[u>>2]|0,v)|0)+512>>10}else{N=c[u>>2]|0;Y=(ba(N,v>>9&-128)|0|1)+((ba(N,v&65535)|0)>>9)>>1}N=O-Y|0;c[V>>2]=N;if((S|0)==(L|0)|(O|0)==(Y|0)){Z=c[u>>2]|0}else{O=N^v;v=(c[u>>2]|0)+(O>>>31)+(c[R>>2]^O>>31)|0;c[u>>2]=v;Z=v}c[n>>2]=(c[n>>2]|0)+Z;if((T|0)==0){break}else{V=V+(j<<2)|0;J=J+(j<<2)|0;U=U+(j<<2)|0;e=e+(j<<2)|0;a=T}}i=k;return};case 18:{if((g|0)==0){i=k;return}a=h+16|0;e=h+20|0;U=h+48|0;J=h+52|0;V=h|0;Z=t;R=s;Y=r;Q=q;y=g;while(1){X=y-1|0;W=c[a>>2]|0;P=(W-(c[e>>2]|0)>>1)+W|0;c[e>>2]=W;W=c[Q>>2]|0;c[a>>2]=W;if((P|0)==(P<<16>>16|0)){_=(ba(c[f>>2]|0,P)|0)+512>>10}else{I=c[f>>2]|0;_=(ba(I,P>>9&-128)|0|1)+((ba(I,P&65535)|0)>>9)>>1}I=W-_|0;c[R>>2]=I;if((P|0)==0|(W|0)==(_|0)){$=c[f>>2]|0}else{W=I^P;P=(c[f>>2]|0)+(W>>>31)+(c[V>>2]^W>>31)|0;c[f>>2]=P;$=P}c[o>>2]=(c[o>>2]|0)+$;P=c[U>>2]|0;W=(P-(c[J>>2]|0)>>1)+P|0;c[J>>2]=P;P=c[Y>>2]|0;c[U>>2]=P;if((W|0)==(W<<16>>16|0)){aa=(ba(c[u>>2]|0,W)|0)+512>>10}else{I=c[u>>2]|0;aa=(ba(I,W>>9&-128)|0|1)+((ba(I,W&65535)|0)>>9)>>1}I=P-aa|0;c[Z>>2]=I;if((W|0)==0|(P|0)==(aa|0)){ca=c[u>>2]|0}else{P=I^W;W=(c[u>>2]|0)+(P>>>31)+(c[V>>2]^P>>31)|0;c[u>>2]=W;ca=W}c[n>>2]=(c[n>>2]|0)+ca;if((X|0)==0){break}else{Z=Z+(j<<2)|0;R=R+(j<<2)|0;Y=Y+(j<<2)|0;Q=Q+(j<<2)|0;y=X}}i=k;return};default:{if((g|0)==0){i=k;return}y=h|0;Q=0;Y=t;t=s;s=r;r=q;q=w;w=g;while(1){g=q&7;R=w-1|0;Z=c[h+16+(Q<<2)>>2]|0;ca=c[r>>2]|0;c[h+16+(g<<2)>>2]=ca;if((Z|0)==(Z<<16>>16|0)){da=(ba(c[f>>2]|0,Z)|0)+512>>10}else{V=c[f>>2]|0;da=(ba(V,Z>>9&-128)|0|1)+((ba(V,Z&65535)|0)>>9)>>1}V=ca-da|0;c[t>>2]=V;if((Z|0)==0|(ca|0)==(da|0)){ea=c[f>>2]|0}else{ca=V^Z;Z=(c[f>>2]|0)+(ca>>>31)+(c[y>>2]^ca>>31)|0;c[f>>2]=Z;ea=Z}c[o>>2]=(c[o>>2]|0)+ea;Z=c[h+48+(Q<<2)>>2]|0;ca=c[s>>2]|0;c[h+48+(g<<2)>>2]=ca;if((Z|0)==(Z<<16>>16|0)){fa=(ba(c[u>>2]|0,Z)|0)+512>>10}else{V=c[u>>2]|0;fa=(ba(V,Z>>9&-128)|0|1)+((ba(V,Z&65535)|0)>>9)>>1}V=ca-fa|0;c[Y>>2]=V;if((Z|0)==0|(ca|0)==(fa|0)){ga=c[u>>2]|0}else{ca=V^Z;Z=(c[u>>2]|0)+(ca>>>31)+(c[y>>2]^ca>>31)|0;c[u>>2]=Z;ga=Z}c[n>>2]=(c[n>>2]|0)+ga;ha=Q+1&7;if((R|0)==0){break}else{Q=ha;Y=Y+(j<<2)|0;t=t+(j<<2)|0;s=s+(j<<2)|0;r=r+(j<<2)|0;q=g+1|0;w=R}}if((ha|0)==0){i=k;return}UGb(l|0,h+16|0,32)|0;UGb(m|0,h+48|0,32)|0;c[h+16>>2]=c[l+(ha<<2)>>2];c[h+48>>2]=c[m+(ha<<2)>>2];ha=Q+2&7;c[h+20>>2]=c[l+(ha<<2)>>2];c[h+52>>2]=c[m+(ha<<2)>>2];ha=Q+3&7;c[h+24>>2]=c[l+(ha<<2)>>2];c[h+56>>2]=c[m+(ha<<2)>>2];ha=Q+4&7;c[h+28>>2]=c[l+(ha<<2)>>2];c[h+60>>2]=c[m+(ha<<2)>>2];ha=Q+5&7;c[h+32>>2]=c[l+(ha<<2)>>2];c[h+64>>2]=c[m+(ha<<2)>>2];ha=Q+6&7;c[h+36>>2]=c[l+(ha<<2)>>2];c[h+68>>2]=c[m+(ha<<2)>>2];ha=Q+7&7;c[h+40>>2]=c[l+(ha<<2)>>2];c[h+72>>2]=c[m+(ha<<2)>>2];c[h+44>>2]=c[l+(Q<<2)>>2];c[h+76>>2]=c[m+(Q<<2)>>2];i=k;return}}}function Cbb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a+4|0;d=c[b>>2]|0;if((d|0)<=8){if((d|0)>1){e=0;f=d;g=0}else{return}while(1){h=e&7;i=f+7&7;j=a+16+(i<<2)|0;k=a+16+(h<<2)|0;l=c[k>>2]^c[j>>2];c[k>>2]=l;m=c[j>>2]^l;c[j>>2]=m;c[k>>2]=c[k>>2]^m;m=a+48+(i<<2)|0;k=a+48+(h<<2)|0;j=c[k>>2]^c[m>>2];c[k>>2]=j;l=c[m>>2]^j;c[m>>2]=l;c[k>>2]=c[k>>2]^l;l=g+1|0;if((l|0)<((c[b>>2]|0)/2|0|0)){e=h+1|0;f=i;g=l}else{break}}return}g=(d&1|0)==0;d=a+16|0;f=c[d>>2]|0;if(g){e=c[a+48>>2]|0;n=(e*3|0)-(c[a+52>>2]|0)>>1;o=(f*3|0)-(c[a+20>>2]|0)>>1;p=e}else{e=c[a+48>>2]|0;n=(e<<1)-(c[a+52>>2]|0)|0;o=(f<<1)-(c[a+20>>2]|0)|0;p=e}e=a+20|0;c[e>>2]=f;b=a+52|0;c[b>>2]=p;c[d>>2]=o;c[a+48>>2]=n;if(g){q=(n*3|0)-p>>1;r=(o*3|0)-f>>1}else{q=(n<<1)-p|0;r=(o<<1)-f|0}c[e>>2]=r;c[b>>2]=q;return}function Dbb(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=i;i=i+64|0;k=j|0;l=j+32|0;m=h+8|0;n=c[m>>2]|0;do{if((n|0)<-1024){o=-1024}else{p=(n|0)>1024?1024:n;if((p|0)>0){q=p-(p+64>>7)|0}else{q=p}p=(q+4|0)>>>3<<24;r=p>>21;if((p|0)<=0){o=r;break}o=(r+64>>7)+r|0}}while(0);c[m>>2]=o;o=h+12|0;q=c[o>>2]|0;do{if((q|0)<-1024){s=-1024}else{n=(q|0)>1024?1024:q;if((n|0)>0){t=n-(n+64>>7)|0}else{t=n}n=(t+4|0)>>>3<<24;r=n>>21;if((n|0)<=0){s=r;break}s=(r+64>>7)+r|0}}while(0);c[o>>2]=s;s=0;do{t=h+16+(s<<2)|0;q=(wbb(c[t>>2]|0)|0)&65535;r=q<<16>>16<0;n=(r?-q&65535:q)<<16>>16;q=d[16392+(n&255)|0]|0|256;p=n>>>8<<16;n=p>>16;if((p|0)>589824){u=q<<n-9}else{u=q>>>((9-n|0)>>>0)}c[t>>2]=r?-u|0:u;r=h+48+(s<<2)|0;t=(wbb(c[r>>2]|0)|0)&65535;n=t<<16>>16<0;q=(n?-t&65535:t)<<16>>16;t=d[16392+(q&255)|0]|0|256;p=q>>>8<<16;q=p>>16;if((p|0)>589824){v=t<<q-9}else{v=t>>>((9-q|0)>>>0)}c[r>>2]=n?-v|0:v;s=s+1|0;}while((s|0)<8);s=c[h+4>>2]|0;switch(s|0){case-2:{if((g|0)<=0){i=j;return}v=h+48|0;u=h|0;n=0;do{r=c[v>>2]|0;q=c[b+(n<<2)>>2]|0;t=(ba(c[o>>2]|0,r)|0)+512>>10;p=q-t|0;c[f+(n<<2)>>2]=p;do{if(!((r|0)==0|(q|0)==(t|0))){w=c[u>>2]|0;x=c[o>>2]|0;if((p^r|0)<0){y=x-w|0;c[o>>2]=y;if(!((y|0)<-1024)){break}c[o>>2]=-1024;break}else{y=x+w|0;c[o>>2]=y;if((y|0)<=1024){break}c[o>>2]=1024;break}}}while(0);r=c[a+(n<<2)>>2]|0;c[v>>2]=r;p=(ba(c[m>>2]|0,q)|0)+512>>10;t=r-p|0;c[e+(n<<2)>>2]=t;do{if(!((q|0)==0|(r|0)==(p|0))){y=c[u>>2]|0;w=c[m>>2]|0;if((t^q|0)<0){x=w-y|0;c[m>>2]=x;if(!((x|0)<-1024)){break}c[m>>2]=-1024;break}else{x=w+y|0;c[m>>2]=x;if((x|0)<=1024){break}c[m>>2]=1024;break}}}while(0);n=n+1|0;}while((n|0)<(g|0));i=j;return};case-1:{if((g|0)<=0){i=j;return}n=h+16|0;u=h|0;v=0;do{q=c[n>>2]|0;t=c[a+(v<<2)>>2]|0;p=(ba(c[m>>2]|0,q)|0)+512>>10;r=t-p|0;c[e+(v<<2)>>2]=r;do{if(!((q|0)==0|(t|0)==(p|0))){x=c[u>>2]|0;y=c[m>>2]|0;if((r^q|0)<0){w=y-x|0;c[m>>2]=w;if(!((w|0)<-1024)){break}c[m>>2]=-1024;break}else{w=y+x|0;c[m>>2]=w;if((w|0)<=1024){break}c[m>>2]=1024;break}}}while(0);q=c[b+(v<<2)>>2]|0;c[n>>2]=q;r=(ba(c[o>>2]|0,t)|0)+512>>10;p=q-r|0;c[f+(v<<2)>>2]=p;do{if(!((t|0)==0|(q|0)==(r|0))){w=c[u>>2]|0;x=c[o>>2]|0;if((p^t|0)<0){y=x-w|0;c[o>>2]=y;if(!((y|0)<-1024)){break}c[o>>2]=-1024;break}else{y=x+w|0;c[o>>2]=y;if((y|0)<=1024){break}c[o>>2]=1024;break}}}while(0);v=v+1|0;}while((v|0)<(g|0));i=j;return};case 18:{if((g|0)<=0){i=j;return}v=h+16|0;u=h+20|0;n=h+48|0;t=h+52|0;p=h|0;r=0;do{q=c[v>>2]|0;y=(q-(c[u>>2]|0)>>1)+q|0;c[u>>2]=q;q=c[a+(r<<2)>>2]|0;c[v>>2]=q;w=(ba(y,c[m>>2]|0)|0)+512>>10;x=q-w|0;c[e+(r<<2)>>2]=x;if(!((y|0)==0|(q|0)==(w|0))){w=x^y;c[m>>2]=(c[m>>2]|0)+(w>>>31)+(c[p>>2]^w>>31)}w=c[n>>2]|0;y=(w-(c[t>>2]|0)>>1)+w|0;c[t>>2]=w;w=c[b+(r<<2)>>2]|0;c[n>>2]=w;x=(ba(y,c[o>>2]|0)|0)+512>>10;q=w-x|0;c[f+(r<<2)>>2]=q;if(!((y|0)==0|(w|0)==(x|0))){x=q^y;c[o>>2]=(c[o>>2]|0)+(x>>>31)+(c[p>>2]^x>>31)}r=r+1|0;}while((r|0)<(g|0));i=j;return};case 2:{if((g|0)<=0){i=j;return}r=h+16|0;p=h+20|0;n=h+48|0;t=h+52|0;v=h|0;u=0;do{x=c[r>>2]|0;c[r>>2]=c[p>>2];y=c[a+(u<<2)>>2]|0;c[p>>2]=y;q=(ba(c[m>>2]|0,x)|0)+512>>10;w=y-q|0;c[e+(u<<2)>>2]=w;if(!((x|0)==0|(y|0)==(q|0))){q=w^x;c[m>>2]=(c[m>>2]|0)+(q>>>31)+(c[v>>2]^q>>31)}q=c[n>>2]|0;c[n>>2]=c[t>>2];x=c[b+(u<<2)>>2]|0;c[t>>2]=x;w=(ba(c[o>>2]|0,q)|0)+512>>10;y=x-w|0;c[f+(u<<2)>>2]=y;if(!((q|0)==0|(x|0)==(w|0))){w=y^q;c[o>>2]=(c[o>>2]|0)+(w>>>31)+(c[v>>2]^w>>31)}u=u+1|0;}while((u|0)<(g|0));i=j;return};case-3:{if((g|0)<=0){i=j;return}u=h+16|0;v=h+48|0;t=h|0;n=0;do{p=c[u>>2]|0;r=c[v>>2]|0;w=c[b+(n<<2)>>2]|0;c[u>>2]=w;q=(ba(c[o>>2]|0,r)|0)+512>>10;y=w-q|0;c[f+(n<<2)>>2]=y;do{if(!((r|0)==0|(w|0)==(q|0))){x=c[t>>2]|0;z=c[o>>2]|0;if((y^r|0)<0){A=z-x|0;c[o>>2]=A;if(!((A|0)<-1024)){break}c[o>>2]=-1024;break}else{A=z+x|0;c[o>>2]=A;if((A|0)<=1024){break}c[o>>2]=1024;break}}}while(0);r=c[a+(n<<2)>>2]|0;c[v>>2]=r;y=(ba(c[m>>2]|0,p)|0)+512>>10;q=r-y|0;c[e+(n<<2)>>2]=q;do{if(!((p|0)==0|(r|0)==(y|0))){w=c[t>>2]|0;A=c[m>>2]|0;if((q^p|0)<0){x=A-w|0;c[m>>2]=x;if(!((x|0)<-1024)){break}c[m>>2]=-1024;break}else{x=A+w|0;c[m>>2]=x;if((x|0)<=1024){break}c[m>>2]=1024;break}}}while(0);n=n+1|0;}while((n|0)<(g|0));i=j;return};case 17:{if((g|0)<=0){i=j;return}n=h+16|0;t=h+20|0;v=h+48|0;u=h+52|0;p=h|0;q=0;do{y=c[n>>2]|0;r=y<<1;x=c[t>>2]|0;w=r-x|0;c[t>>2]=y;y=c[a+(q<<2)>>2]|0;c[n>>2]=y;A=(ba(c[m>>2]|0,w)|0)+512>>10;z=y-A|0;c[e+(q<<2)>>2]=z;if(!((r|0)==(x|0)|(y|0)==(A|0))){A=z^w;c[m>>2]=(c[m>>2]|0)+(A>>>31)+(c[p>>2]^A>>31)}A=c[v>>2]|0;w=A<<1;z=c[u>>2]|0;y=w-z|0;c[u>>2]=A;A=c[b+(q<<2)>>2]|0;c[v>>2]=A;x=(ba(c[o>>2]|0,y)|0)+512>>10;r=A-x|0;c[f+(q<<2)>>2]=r;if(!((w|0)==(z|0)|(A|0)==(x|0))){x=r^y;c[o>>2]=(c[o>>2]|0)+(x>>>31)+(c[p>>2]^x>>31)}q=q+1|0;}while((q|0)<(g|0));i=j;return};default:{if((g|0)<=0){i=j;return}q=h|0;p=0;v=0;u=s;while(1){s=u&7;n=c[h+16+(v<<2)>>2]|0;t=c[a+(p<<2)>>2]|0;c[h+16+(s<<2)>>2]=t;x=(ba(c[m>>2]|0,n)|0)+512>>10;y=t-x|0;c[e+(p<<2)>>2]=y;if(!((n|0)==0|(t|0)==(x|0))){x=y^n;c[m>>2]=(c[m>>2]|0)+(x>>>31)+(c[q>>2]^x>>31)}x=c[h+48+(v<<2)>>2]|0;n=c[b+(p<<2)>>2]|0;c[h+48+(s<<2)>>2]=n;y=(ba(c[o>>2]|0,x)|0)+512>>10;t=n-y|0;c[f+(p<<2)>>2]=t;if(!((x|0)==0|(n|0)==(y|0))){y=t^x;c[o>>2]=(c[o>>2]|0)+(y>>>31)+(c[q>>2]^y>>31)}B=v+1&7;y=p+1|0;if((y|0)<(g|0)){p=y;v=B;u=s+1|0}else{break}}if((B|0)==0){i=j;return}UGb(k|0,h+16|0,32)|0;UGb(l|0,h+48|0,32)|0;c[h+16>>2]=c[k+(B<<2)>>2];c[h+48>>2]=c[l+(B<<2)>>2];B=v+2&7;c[h+20>>2]=c[k+(B<<2)>>2];c[h+52>>2]=c[l+(B<<2)>>2];B=v+3&7;c[h+24>>2]=c[k+(B<<2)>>2];c[h+56>>2]=c[l+(B<<2)>>2];B=v+4&7;c[h+28>>2]=c[k+(B<<2)>>2];c[h+60>>2]=c[l+(B<<2)>>2];B=v+5&7;c[h+32>>2]=c[k+(B<<2)>>2];c[h+64>>2]=c[l+(B<<2)>>2];B=v+6&7;c[h+36>>2]=c[k+(B<<2)>>2];c[h+68>>2]=c[l+(B<<2)>>2];B=v+7&7;c[h+40>>2]=c[k+(B<<2)>>2];c[h+72>>2]=c[l+(B<<2)>>2];c[h+44>>2]=c[k+(v<<2)>>2];c[h+76>>2]=c[l+(v<<2)>>2];i=j;return}}}function Ebb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+1424|0;k=j|0;l=b+460|0;m=c[l>>2]|0;n=k+1416|0;c[n>>2]=(m&4194304)>>>0>3932160>>>0;o=(m>>>18<<8&7936)+1024|0;m=k+1412|0;c[m>>2]=o>>>0<6912>>>0?o:6912;o=b+576|0;p=c[o>>2]|0;q=k+1408|0;c[q>>2]=p;r=p+2|0;p=b+32|0;a:do{if((r|0)>0){s=0;while(1){t=b+72+(s<<3)|0;O$a(t,b+216+(s<<3)|0,c[p>>2]<<2);if((c[t>>2]|0)==0){u=79;break}if((c[l>>2]&1073741828|0)==0){t=b+72+(s<<3)+4|0;O$a(t,b+216+(s<<3)+4|0,c[p>>2]<<2);if((c[t>>2]|0)==0){u=79;break}}s=s+1|0;if((s|0)>=(r|0)){break a}}if((u|0)==79){i=j;return}}}while(0);u=k;r=b+608|0;l=r;UGb(u|0,l|0,1408)|0;s=e;UGb(c[b+72>>2]|0,s|0,c[p>>2]<<2)|0;e=f;UGb(c[b+76>>2]|0,e|0,c[p>>2]<<2)|0;f=c[q>>2]|0;b:do{if((f|0)>0){t=0;v=f;while(1){if((c[k+(t*88|0)+4>>2]|0)==0){w=t;x=v;break b}y=c[b+72+(t<<3)>>2]|0;z=c[b+72+(t<<3)+4>>2]|0;A=t+1|0;B=c[b+72+(A<<3)>>2]|0;C=c[b+72+(A<<3)+4>>2]|0;D=c[p>>2]|0;E=k+(t*88|0)|0;if((c[n>>2]|0)==0){Dbb(y,z,B,C,D,E)}else{Bbb(y,z,B,C,D,E,1)}E=c[q>>2]|0;if((A|0)<(E|0)){t=A;v=E}else{w=A;x=E;break}}}else{w=0;x=f}}while(0);f=c[p>>2]|0;n=k+1420|0;c[n>>2]=0;UGb(c[b+72+(x+1<<3)>>2]|0,c[b+72+(w<<3)>>2]|0,f<<2)|0;UGb(c[b+72+((c[q>>2]|0)+1<<3)+4>>2]|0,c[b+72+(w<<3)+4>>2]|0,c[p>>2]<<2)|0;w=b+440|0;f=c[w>>2]|0;if((f&8|0)==0){F=f}else{Gbb(b,k,0,~~+P(+g[b+2020>>2]+.5),0);F=c[w>>2]|0}if((F&4|0)==0){G=F}else{Hbb(b,k);G=c[w>>2]|0}c:do{if((G&1|0)==0){H=G}else{F=b+612|0;d:do{if((c[F>>2]|0)!=0){f=c[r>>2]|0;e:do{if((f|0)>0){x=0;v=f;while(1){t=v-1|0;E=c[q>>2]|0;f:do{if((E|0)>0){A=0;D=E;while(1){C=c[b+608+(A*88|0)+4>>2]|0;if((C|0)==0){I=A;J=D;break f}c[k+(A*88|0)+4>>2]=C;c[k+(A*88|0)>>2]=t;C=A+1|0;Ibb(k,c[b+72+(A<<3)>>2]|0,c[b+72+(A<<3)+4>>2]|0,c[b+72+(C<<3)>>2]|0,c[b+72+(C<<3)+4>>2]|0,c[p>>2]|0,A);B=c[q>>2]|0;if((C|0)<(B|0)){A=C;D=B}else{I=C;J=B;break}}}else{I=0;J=E}}while(0);E=b+72+(I<<3)|0;D=b+72+(I<<3)+4|0;A=c[p>>2]|0;B=c[m>>2]|0;if((A|0)!=0){C=(B|0)==0;z=c[E>>2]|0;y=c[D>>2]|0;K=A;while(1){L=K-1|0;M=c[z>>2]|0;N=(M|0)>-1?M:-M|0;M=(N>>>9)+N|0;do{if(!(M>>>0<256>>>0)){do{if(M>>>0<65536>>>0){O=(a[637664+(M>>>8)|0]|0)+8|0}else{if(M>>>0<16777216>>>0){O=(a[637664+(M>>>16)|0]|0)+16|0;break}else{O=(a[637664+(M>>>24)|0]|0)+24|0;break}}}while(0);if(C){break}if(!((d[15880+(M>>>((O-9|0)>>>0)&255)|0]|O<<8)>>>0<B>>>0)){Q=x;break e}}}while(0);M=z+4|0;N=y+4|0;R=c[y>>2]|0;S=(R|0)>-1?R:-R|0;R=(S>>>9)+S|0;do{if(!(R>>>0<256>>>0)){do{if(R>>>0<65536>>>0){T=(a[637664+(R>>>8)|0]|0)+8|0}else{if(R>>>0<16777216>>>0){T=(a[637664+(R>>>16)|0]|0)+16|0;break}else{T=(a[637664+(R>>>24)|0]|0)+24|0;break}}}while(0);if(C){break}if(!((d[15880+(R>>>((T-9|0)>>>0)&255)|0]|T<<8)>>>0<B>>>0)){Q=x;break e}}}while(0);if((L|0)==0){break}else{z=M;y=N;K=L}}}if((c[n>>2]|0)==0){Q=x;break e}c[n>>2]=0;TGb(l|0,0,1408)|0;UGb(l|0,u|0,I*88|0)|0;UGb(c[b+72+(J+1<<3)>>2]|0,c[E>>2]|0,A<<2)|0;UGb(c[b+72+((c[q>>2]|0)+1<<3)+4>>2]|0,c[D>>2]|0,c[p>>2]<<2)|0;if((t|0)>0){x=1;v=t}else{break d}}}else{Q=0}}while(0);v=f+1|0;if((Q|0)==0&(v|0)<8){U=v}else{break}do{v=c[q>>2]|0;g:do{if((v|0)>0){x=0;K=v;while(1){y=c[b+608+(x*88|0)+4>>2]|0;if((y|0)==0){V=x;W=K;break g}c[k+(x*88|0)+4>>2]=y;c[k+(x*88|0)>>2]=U;y=x+1|0;Ibb(k,c[b+72+(x<<3)>>2]|0,c[b+72+(x<<3)+4>>2]|0,c[b+72+(y<<3)>>2]|0,c[b+72+(y<<3)+4>>2]|0,c[p>>2]|0,x);z=c[q>>2]|0;if((y|0)<(z|0)){x=y;K=z}else{V=y;W=z;break}}}else{V=0;W=v}}while(0);v=b+72+(V<<3)|0;K=b+72+(V<<3)+4|0;x=c[p>>2]|0;t=c[m>>2]|0;if((x|0)!=0){D=(t|0)==0;A=c[v>>2]|0;E=c[K>>2]|0;z=x;while(1){y=z-1|0;B=c[A>>2]|0;C=(B|0)>-1?B:-B|0;B=(C>>>9)+C|0;do{if(!(B>>>0<256>>>0)){do{if(B>>>0<65536>>>0){X=(a[637664+(B>>>8)|0]|0)+8|0}else{if(B>>>0<16777216>>>0){X=(a[637664+(B>>>16)|0]|0)+16|0;break}else{X=(a[637664+(B>>>24)|0]|0)+24|0;break}}}while(0);if(D){break}if(!((d[15880+(B>>>((X-9|0)>>>0)&255)|0]|X<<8)>>>0<t>>>0)){break d}}}while(0);B=A+4|0;L=E+4|0;N=c[E>>2]|0;M=(N|0)>-1?N:-N|0;N=(M>>>9)+M|0;do{if(!(N>>>0<256>>>0)){do{if(N>>>0<65536>>>0){Y=(a[637664+(N>>>8)|0]|0)+8|0}else{if(N>>>0<16777216>>>0){Y=(a[637664+(N>>>16)|0]|0)+16|0;break}else{Y=(a[637664+(N>>>24)|0]|0)+24|0;break}}}while(0);if(D){break}if(!((d[15880+(N>>>((Y-9|0)>>>0)&255)|0]|Y<<8)>>>0<t>>>0)){break d}}}while(0);if((y|0)==0){break}else{A=B;E=L;z=y}}}if((c[n>>2]|0)==0){break d}c[n>>2]=0;TGb(l|0,0,1408)|0;UGb(l|0,u|0,V*88|0)|0;UGb(c[b+72+(W+1<<3)>>2]|0,c[v>>2]|0,x<<2)|0;UGb(c[b+72+((c[q>>2]|0)+1<<3)+4>>2]|0,c[K>>2]|0,c[p>>2]<<2)|0;U=U+1|0;}while((U|0)<8)}}while(0);f=c[w>>2]|0;do{if((f&2|0)!=0){if((c[F>>2]|0)==0){break}z=b+2020|0;g[z>>2]=(+g[z>>2]*2.0+ +(c[r>>2]|0))/3.0;H=f;break c}}while(0);g[b+2020>>2]=2.0;H=f}}while(0);if((H&16|0)!=0){Hbb(b,k)}k=c[q>>2]|0;if((h|0)==0){Z=0}else{h=k+1|0;UGb(s|0,c[b+72+(h<<3)>>2]|0,c[p>>2]<<2)|0;UGb(e|0,c[b+72+(h<<3)+4>>2]|0,c[p>>2]<<2)|0;Z=0}while(1){if((Z|0)>=(k|0)){break}if((c[b+608+(Z*88|0)+4>>2]|0)==0){break}else{Z=Z+1|0}}c[o>>2]=Z;i=j;return}function Fbb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((d|0)==0){return}e=a|0;f=a+4|0;g=a+8|0;a=b+(d-1<<2)|0;b=d;d=c[e>>2]|0;while(1){h=b-1|0;i=c[a>>2]|0;j=(i|0)>-1?i:-i|0;i=d>>4;k=i+1|0;do{if(j>>>0<k>>>0){l=d-(((d+126|0)/128|0)<<1)|0;c[e>>2]=l;m=l}else{l=(((d+128|0)/128|0)*5|0)+d|0;c[e>>2]=l;n=c[f>>2]|0;o=n>>4;if((j-k|0)>>>0<(o+1|0)>>>0){c[f>>2]=n-(((n+62|0)/64|0)<<1);m=l;break}c[f>>2]=(((n+64|0)/64|0)*5|0)+n;n=c[g>>2]|0;if((j+~i+~o|0)>>>0<((n>>4)+1|0)>>>0){c[g>>2]=n-(((n+30|0)/32|0)<<1);m=l;break}else{c[g>>2]=(((n+32|0)/32|0)*5|0)+n;m=l;break}}}while(0);if((h|0)==0){break}else{a=a-4|0;b=h;d=m}}return}function Gbb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;j=i;i=i+88|0;k=j|0;l=(c[b+456>>2]|0)-f|0;m=f+1|0;n=e+1408|0;if((l|0)<1){o=3}else{if((m|0)==(c[n>>2]|0)){o=3}else{p=l}}if((o|0)==3){p=1}TGb(k|0,0,88)|0;l=c[b+72+(f<<3)>>2]|0;q=c[b+72+(f<<3)+4>>2]|0;r=b+72+(m<<3)|0;s=c[r>>2]|0;t=b+72+(m<<3)+4|0;u=c[t>>2]|0;v=(p|0)==1;w=b+460|0;x=b+440|0;y=e+(f*88|0)+4|0;z=e+(f*88|0)|0;A=b+32|0;B=e+1412|0;C=e+1420|0;D=b+608|0;E=e;F=m*88|0;G=-3;do{do{if(!((G|0)==0|(G-9|0)>>>0<8>>>0)){if((G|0)==17&v){if((m|0)<(c[n>>2]|0)){break}}if(G>>>0>4294967293>>>0){if((c[w>>2]&32|0)==0){break}}if((c[x>>2]|0)==0){if((G-5|0)>>>0<12>>>0){break}}c[y>>2]=G;c[z>>2]=g;Ibb(e,l,q,s,u,c[A>>2]|0,f);H=c[A>>2]|0;I=c[B>>2]|0;a:do{if((H|0)==0){o=32}else{J=(I|0)==0;K=s;L=u;M=H;while(1){N=M-1|0;O=c[K>>2]|0;P=(O|0)>-1?O:-O|0;O=(P>>>9)+P|0;do{if(!(O>>>0<256>>>0)){do{if(O>>>0<65536>>>0){Q=(a[637664+(O>>>8)|0]|0)+8|0}else{if(O>>>0<16777216>>>0){Q=(a[637664+(O>>>16)|0]|0)+16|0;break}else{Q=(a[637664+(O>>>24)|0]|0)+24|0;break}}}while(0);if(J){break}if(!((d[15880+(O>>>((Q-9|0)>>>0)&255)|0]|Q<<8)>>>0<I>>>0)){R=-1;break a}}}while(0);O=K+4|0;P=L+4|0;S=c[L>>2]|0;T=(S|0)>-1?S:-S|0;S=(T>>>9)+T|0;do{if(!(S>>>0<256>>>0)){do{if(S>>>0<65536>>>0){U=(a[637664+(S>>>8)|0]|0)+8|0}else{if(S>>>0<16777216>>>0){U=(a[637664+(S>>>16)|0]|0)+16|0;break}else{U=(a[637664+(S>>>24)|0]|0)+24|0;break}}}while(0);if(J){break}if(!((d[15880+(S>>>((U-9|0)>>>0)&255)|0]|U<<8)>>>0<I>>>0)){R=-1;break a}}}while(0);if((N|0)==0){o=32;break}else{K=O;L=P;M=N}}}}while(0);do{if((o|0)==32){o=0;if((c[C>>2]|0)==0){R=0;break}c[C>>2]=0;TGb(D|0,0,1408)|0;UGb(D|0,E|0,F)|0;UGb(c[b+72+((c[n>>2]|0)+1<<3)>>2]|0,c[r>>2]|0,c[A>>2]<<2)|0;UGb(c[b+72+((c[n>>2]|0)+1<<3)+4>>2]|0,c[t>>2]|0,c[A>>2]<<2)|0;R=0}}while(0);c[k+(G+3<<2)>>2]=R}}while(0);G=G+1|0;}while((G|0)<19);if((m|0)<(c[n>>2]|0)){V=p}else{i=j;return}while(1){p=V-1|0;if((V|0)==0){o=40;break}else{W=h;X=0;Y=0}do{G=c[k+(Y<<2)>>2]|0;R=(G|0)!=0&G>>>0<W>>>0;W=R?G:W;X=R?Y-3|0:X;Y=Y+1|0;}while((Y|0)<22);if((X|0)==0){o=40;break}c[k+(X+3<<2)>>2]=0;c[y>>2]=X;c[z>>2]=g;Ibb(e,l,q,s,u,c[A>>2]|0,f);Gbb(b,e,m,g,W);if((m|0)<(c[n>>2]|0)){V=p}else{o=40;break}}if((o|0)==40){i=j;return}}function Hbb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=e;g=b+608|0;h=e+1408|0;i=b+32|0;j=e+1412|0;k=e+1420|0;l=c[h>>2]|0;a:while(1){UGb(f|0,g|0,1408)|0;if((l|0)>0){m=0;n=0;o=l}else{p=36;break}b:while(1){q=n;r=o;while(1){s=c[b+608+(q*88|0)+4>>2]|0;if((s|0)==0){t=r;break b}u=q+1|0;if((u|0)>=(r|0)){t=r;break b}v=c[b+608+(u*88|0)+4>>2]|0;if((v|0)==0){t=r;break b}if((s|0)==(v|0)){Ibb(e,c[b+72+(q<<3)>>2]|0,c[b+72+(q<<3)+4>>2]|0,c[b+72+(u<<3)>>2]|0,c[b+72+(u<<3)+4>>2]|0,c[i>>2]|0,q)}else{v=e+(q*88|0)|0;s=b+608+(u*88|0)|0;UGb(v|0,s|0,88)|0;w=e+(u*88|0)|0;x=b+608+(q*88|0)|0;UGb(w|0,x|0,88)|0;c:do{if((q|0)<(c[h>>2]|0)){y=q;while(1){if((c[b+608+(y*88|0)+4>>2]|0)==0){z=y;break c}A=y+1|0;Ibb(e,c[b+72+(y<<3)>>2]|0,c[b+72+(y<<3)+4>>2]|0,c[b+72+(A<<3)>>2]|0,c[b+72+(A<<3)+4>>2]|0,c[i>>2]|0,y);if((A|0)<(c[h>>2]|0)){y=A}else{z=A;break}}}else{z=q}}while(0);B=b+72+(z<<3)|0;C=b+72+(z<<3)+4|0;y=c[i>>2]|0;A=c[j>>2]|0;d:do{if((y|0)==0){p=32}else{D=(A|0)==0;E=c[B>>2]|0;F=c[C>>2]|0;G=y;while(1){H=G-1|0;I=c[E>>2]|0;J=(I|0)>-1?I:-I|0;I=(J>>>9)+J|0;do{if(!(I>>>0<256>>>0)){do{if(I>>>0<65536>>>0){K=(a[637664+(I>>>8)|0]|0)+8|0}else{if(I>>>0<16777216>>>0){K=(a[637664+(I>>>16)|0]|0)+16|0;break}else{K=(a[637664+(I>>>24)|0]|0)+24|0;break}}}while(0);if(D){break}if(!((d[15880+(I>>>((K-9|0)>>>0)&255)|0]|K<<8)>>>0<A>>>0)){break d}}}while(0);I=E+4|0;J=F+4|0;L=c[F>>2]|0;M=(L|0)>-1?L:-L|0;L=(M>>>9)+M|0;do{if(!(L>>>0<256>>>0)){do{if(L>>>0<65536>>>0){N=(a[637664+(L>>>8)|0]|0)+8|0}else{if(L>>>0<16777216>>>0){N=(a[637664+(L>>>16)|0]|0)+16|0;break}else{N=(a[637664+(L>>>24)|0]|0)+24|0;break}}}while(0);if(D){break}if(!((d[15880+(L>>>((N-9|0)>>>0)&255)|0]|N<<8)>>>0<A>>>0)){break d}}}while(0);if((H|0)==0){p=32;break}else{E=I;F=J;G=H}}}}while(0);if((p|0)==32){p=0;if((c[k>>2]|0)!=0){break}}UGb(v|0,x|0,88)|0;UGb(w|0,s|0,88)|0;Ibb(e,c[b+72+(q<<3)>>2]|0,c[b+72+(q<<3)+4>>2]|0,c[b+72+(u<<3)>>2]|0,c[b+72+(u<<3)+4>>2]|0,c[i>>2]|0,q)}A=c[h>>2]|0;if((u|0)<(A|0)){q=u;r=A}else{t=A;break b}}c[k>>2]=0;TGb(g|0,0,1408)|0;UGb(g|0,f|0,z*88|0)|0;UGb(c[b+72+((c[h>>2]|0)+1<<3)>>2]|0,c[B>>2]|0,c[i>>2]<<2)|0;UGb(c[b+72+((c[h>>2]|0)+1<<3)+4>>2]|0,c[C>>2]|0,c[i>>2]<<2)|0;r=c[h>>2]|0;if((u|0)<(r|0)){m=1;n=u;o=r}else{l=r;continue a}}if((m|0)==0){p=36;break}else{l=t}}if((p|0)==36){return}}function Ibb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=i;i=i+88|0;k=j|0;TGb(k|0,0,88)|0;l=c[a+(h*88|0)>>2]|0;if((l|0)==7){m=7}else{m=(l|0)<2?3:l+1|0}c[k+4>>2]=c[a+(h*88|0)+4>>2];n=k|0;c[n>>2]=m;Bbb(b,d,e,f,(g|0)<2048?g:2048,k,-1);c[n>>2]=l;if((h|0)==0){Cbb(k);o=k+16|0;p=k+48|0}else{m=k+16|0;TGb(m|0,0,64)|0;o=m;p=k+48|0}m=o;o=p;p=a+(h*88|0)+16|0;UGb(p|0,m|0,32)|0;q=a+(h*88|0)+48|0;UGb(q|0,o|0,32)|0;r=k+8|0;s=a+(h*88|0)+8|0;c[s>>2]=c[r>>2];t=k+12|0;u=a+(h*88|0)+12|0;c[u>>2]=c[t>>2];if((l|0)==0){c[n>>2]=1;Bbb(b,d,e,f,g,k,1);c[n>>2]=0;UGb(m|0,p|0,32)|0;UGb(o|0,q|0,32)|0;q=(c[k+80>>2]|0)/(g|0)|0;c[r>>2]=q;c[s>>2]=q;q=(c[k+84>>2]|0)/(g|0)|0;c[t>>2]=q;c[u>>2]=q}if((c[a+1416>>2]|0)==0){Dbb(b,d,e,f,g,k);i=j;return}else{Bbb(b,d,e,f,g,k,1);i=j;return}}function Jbb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+32|0;j=h|0;k=f+80|0;c[k>>2]=0;if((g|0)<0){l=e-1|0;m=a+(l<<2)|0;n=b+(l<<2)|0}else{m=a;n=b}b=f+8|0;a=c[b>>2]|0;do{if((a|0)<-1024){o=-1024}else{l=(a|0)>1024?1024:a;if((l|0)>0){p=l-(l+64>>7)|0}else{p=l}l=(p+4|0)>>>3<<24;q=l>>21;if((l|0)<=0){o=q;break}o=(q+64>>7)+q|0}}while(0);c[b>>2]=o;o=0;do{p=f+16+(o<<2)|0;a=(wbb(c[p>>2]|0)|0)&65535;q=a<<16>>16<0;l=(q?-a&65535:a)<<16>>16;a=d[16392+(l&255)|0]|0|256;r=l>>>8<<16;l=r>>16;if((r|0)>589824){s=a<<l-9}else{s=a>>>((9-l|0)>>>0)}c[p>>2]=q?-s|0:s;o=o+1|0;}while((o|0)<8);o=f+4|0;s=c[o>>2]|0;if((s|0)>8){if((e|0)==0){i=h;return}q=f+16|0;p=f+20|0;l=f|0;a=n;r=m;t=e;u=s;while(1){v=t-1|0;w=u&1;x=c[q>>2]|0;y=ba(w^3,x)|0;z=y-(c[p>>2]|0)>>(w^1);c[p>>2]=x;x=c[r>>2]|0;c[q>>2]=x;if((z|0)==(z<<16>>16|0)){w=c[b>>2]|0;A=(ba(w,z)|0)+512>>10;B=w}else{w=c[b>>2]|0;A=(ba(w,z>>9&-128)|0|1)+((ba(w,z&65535)|0)>>9)>>1;B=w}w=x-A|0;if((z|0)==0|(x|0)==(A|0)){C=B}else{x=w^z;z=B+(x>>>31)+(c[l>>2]^x>>31)|0;c[b>>2]=z;C=z}c[k>>2]=(c[k>>2]|0)+C;c[a>>2]=w;if((v|0)==0){break}a=a+(g<<2)|0;r=r+(g<<2)|0;t=v;u=c[o>>2]|0}i=h;return}if((s|0)<1|(e|0)==0){i=h;return}u=f|0;t=0;r=n;n=m;m=e;e=s;while(1){s=m-1|0;a=c[f+16+(t<<2)>>2]|0;C=c[n>>2]|0;c[f+16+((e+t&7)<<2)>>2]=C;D=t+1&7;if((a|0)==(a<<16>>16|0)){l=c[b>>2]|0;E=(ba(l,a)|0)+512>>10;F=l}else{l=c[b>>2]|0;E=(ba(l,a>>9&-128)|0|1)+((ba(l,a&65535)|0)>>9)>>1;F=l}l=C-E|0;if((a|0)==0|(C|0)==(E|0)){G=F}else{C=l^a;a=F+(C>>>31)+(c[u>>2]^C>>31)|0;c[b>>2]=a;G=a}c[k>>2]=(c[k>>2]|0)+G;c[r>>2]=l;if((s|0)==0){break}t=D;r=r+(g<<2)|0;n=n+(g<<2)|0;m=s;e=c[o>>2]|0}if((D|0)==0){i=h;return}if(!(((c[o>>2]|0)-1|0)>>>0<8>>>0)){i=h;return}UGb(j|0,f+16|0,32)|0;c[f+16>>2]=c[j+(D<<2)>>2];c[f+20>>2]=c[j+((t+2&7)<<2)>>2];c[f+24>>2]=c[j+((t+3&7)<<2)>>2];c[f+28>>2]=c[j+((t+4&7)<<2)>>2];c[f+32>>2]=c[j+((t+5&7)<<2)>>2];c[f+36>>2]=c[j+((t+6&7)<<2)>>2];c[f+40>>2]=c[j+((t+7&7)<<2)>>2];c[f+44>>2]=c[j+(t<<2)>>2];i=h;return}function Kbb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=i;i=i+88|0;k=j|0;l=(c[b+456>>2]|0)-f|0;m=f+1|0;n=e+1408|0;if((l|0)<1){o=3}else{if((m|0)==(c[n>>2]|0)){o=3}else{p=l}}if((o|0)==3){p=1}TGb(k|0,0,88)|0;l=c[b+72+(f<<3)>>2]|0;q=b+72+(m<<3)|0;r=c[q>>2]|0;s=(p|0)==1;t=b+440|0;u=e+(f*88|0)+4|0;v=e+(f*88|0)|0;w=b+32|0;x=e|0;y=e+1412|0;z=e+1420|0;A=b+608|0;B=e;C=m*88|0;D=1;do{if((D|0)==17&s){if((m|0)>=(c[n>>2]|0)){o=8}}else{o=8}do{if((o|0)==8){o=0;if((D-9|0)>>>0<8>>>0){break}if((c[t>>2]|0)==0){if((D-5|0)>>>0<12>>>0){break}}c[u>>2]=D;c[v>>2]=g;Mbb(l,r,c[w>>2]|0,x,f);E=c[w>>2]|0;F=c[y>>2]|0;a:do{if((E|0)==0|(F|0)==0){o=20}else{G=r;H=E;while(1){I=H-1|0;J=G+4|0;K=c[G>>2]|0;L=(K|0)>-1?K:-K|0;K=(L>>>9)+L|0;if(!(K>>>0<256>>>0)){do{if(K>>>0<65536>>>0){M=(a[637664+(K>>>8)|0]|0)+8|0}else{if(K>>>0<16777216>>>0){M=(a[637664+(K>>>16)|0]|0)+16|0;break}else{M=(a[637664+(K>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[15880+(K>>>((M-9|0)>>>0)&255)|0]|M<<8)>>>0<F>>>0)){N=-1;break a}}if((I|0)==0){o=20;break}else{G=J;H=I}}}}while(0);do{if((o|0)==20){o=0;if((c[z>>2]|0)==0){N=0;break}c[z>>2]=0;TGb(A|0,0,1408)|0;UGb(A|0,B|0,C)|0;UGb(c[b+72+((c[n>>2]|0)+1<<3)>>2]|0,c[q>>2]|0,c[w>>2]<<2)|0;N=0}}while(0);c[k+(D+3<<2)>>2]=N}}while(0);D=D+1|0;}while((D|0)<19);if((m|0)<(c[n>>2]|0)){O=p}else{i=j;return}while(1){p=O-1|0;if((O|0)==0){o=28;break}else{P=h;Q=0;R=0}do{D=c[k+(R<<2)>>2]|0;N=(D|0)!=0&D>>>0<P>>>0;P=N?D:P;Q=N?R-3|0:Q;R=R+1|0;}while((R|0)<22);if((Q|0)==0){o=28;break}c[k+(Q+3<<2)>>2]=0;c[u>>2]=Q;c[v>>2]=g;Mbb(l,r,c[w>>2]|0,x,f);Kbb(b,e,m,g,P);if((m|0)<(c[n>>2]|0)){O=p}else{o=28;break}}if((o|0)==28){i=j;return}}function Lbb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=e;g=b+608|0;h=e+1408|0;i=b+32|0;j=e|0;k=e+1412|0;l=e+1420|0;m=c[h>>2]|0;a:while(1){UGb(f|0,g|0,1408)|0;if((m|0)>0){n=0;o=0;p=m}else{q=27;break}b:while(1){r=o;s=p;while(1){t=c[b+608+(r*88|0)+4>>2]|0;if((t|0)==0){u=s;break b}v=r+1|0;if((v|0)>=(s|0)){u=s;break b}w=c[b+608+(v*88|0)+4>>2]|0;if((w|0)==0){u=s;break b}if((t|0)==(w|0)){Mbb(c[b+72+(r<<3)>>2]|0,c[b+72+(v<<3)>>2]|0,c[i>>2]|0,j,r)}else{w=e+(r*88|0)|0;t=b+608+(v*88|0)|0;UGb(w|0,t|0,88)|0;x=e+(v*88|0)|0;y=b+608+(r*88|0)|0;UGb(x|0,y|0,88)|0;c:do{if((r|0)<(c[h>>2]|0)){z=r;while(1){A=b+72+(z<<3)|0;B=c[A>>2]|0;if((c[b+608+(z*88|0)+4>>2]|0)==0){C=A;D=B;E=z;break c}A=z+1|0;Mbb(B,c[b+72+(A<<3)>>2]|0,c[i>>2]|0,j,z);if((A|0)<(c[h>>2]|0)){z=A}else{F=A;q=11;break}}}else{F=r;q=11}}while(0);if((q|0)==11){q=0;z=b+72+(F<<3)|0;C=z;D=c[z>>2]|0;E=F}z=c[i>>2]|0;A=c[k>>2]|0;d:do{if((z|0)==0|(A|0)==0){q=23}else{B=D;G=z;while(1){H=G-1|0;I=B+4|0;J=c[B>>2]|0;K=(J|0)>-1?J:-J|0;J=(K>>>9)+K|0;if(!(J>>>0<256>>>0)){do{if(J>>>0<65536>>>0){L=(a[637664+(J>>>8)|0]|0)+8|0}else{if(J>>>0<16777216>>>0){L=(a[637664+(J>>>16)|0]|0)+16|0;break}else{L=(a[637664+(J>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[15880+(J>>>((L-9|0)>>>0)&255)|0]|L<<8)>>>0<A>>>0)){break d}}if((H|0)==0){q=23;break}else{B=I;G=H}}}}while(0);if((q|0)==23){q=0;if((c[l>>2]|0)!=0){break}}UGb(w|0,y|0,88)|0;UGb(x|0,t|0,88)|0;Mbb(c[b+72+(r<<3)>>2]|0,c[b+72+(v<<3)>>2]|0,c[i>>2]|0,j,r)}A=c[h>>2]|0;if((v|0)<(A|0)){r=v;s=A}else{u=A;break b}}c[l>>2]=0;TGb(g|0,0,1408)|0;UGb(g|0,f|0,E*88|0)|0;UGb(c[b+72+((c[h>>2]|0)+1<<3)>>2]|0,c[C>>2]|0,c[i>>2]<<2)|0;s=c[h>>2]|0;if((v|0)<(s|0)){n=1;o=v;p=s}else{m=s;continue a}}if((n|0)==0){q=27;break}else{m=u}}if((q|0)==27){return}}function Mbb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+88|0;h=g|0;j=c[e+(f*88|0)>>2]|0;k=c[e+(f*88|0)+4>>2]|0;if((j|0)==7){l=7}else{l=(j|0)<2?3:j+1|0}TGb(h|0,0,88)|0;m=h+4|0;c[m>>2]=k;k=h|0;c[k>>2]=l;Jbb(a,b,(d|0)<2048?d:2048,h,-1);c[k>>2]=j;a:do{if((f|0)==0){l=c[m>>2]|0;if((l|0)<=8){if((l|0)>1){n=0;o=l;p=0}else{break}while(1){q=n&7;r=o+7&7;s=h+16+(r<<2)|0;t=h+16+(q<<2)|0;u=c[t>>2]^c[s>>2];c[t>>2]=u;v=c[s>>2]^u;c[s>>2]=v;c[t>>2]=c[t>>2]^v;v=p+1|0;if((v|0)<((c[m>>2]|0)/2|0|0)){n=q+1|0;o=r;p=v}else{break a}}}v=h+16|0;r=c[v>>2]|0;if((l&1|0)==0){q=h+20|0;t=(r*3|0)-(c[q>>2]|0)>>1;c[q>>2]=r;c[v>>2]=t;w=(t*3|0)-r>>1;x=q}else{q=h+20|0;t=(r<<1)-(c[q>>2]|0)|0;c[q>>2]=r;c[v>>2]=t;w=(t<<1)-r|0;x=q}c[x>>2]=w}else{TGb(h+16|0,0,32)|0}}while(0);w=e+(f*88|0)+16|0;x=h+16|0;UGb(w|0,x|0,32)|0;p=h+8|0;o=e+(f*88|0)+8|0;c[o>>2]=c[p>>2];if((j|0)!=0){Jbb(a,b,d,h,1);i=g;return}c[k>>2]=1;Jbb(a,b,d,h,1);c[k>>2]=0;UGb(x|0,w|0,32)|0;w=(c[h+80>>2]|0)/(d|0)|0;c[p>>2]=w;c[o>>2]=w;Jbb(a,b,d,h,1);i=g;return}function Nbb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[d>>2]|0;f=e>>>23&255;do{if((f|0)==255){g=b+548|0;a[g]=a[g]|32;h=0;i=16777216}else{g=a[b+551|0]|0;j=g&255;if((f|0)==0){h=g<<24>>24==0?0:j-1|0;i=e&8388607;break}else{h=j-f|0;i=e&8388607|8388608;break}}}while(0);j=(h|0)<25?i>>h:0;do{if((j|0)==0){if((f|e&8388607|0)!=0){i=b+564|0;c[i>>2]=(c[i>>2]|0)+1;break}if((e|0)>=0){break}i=b+568|0;c[i>>2]=(c[i>>2]|0)+1}else{if((h|0)==0){break}i=(1<<h)-1|0;g=e&8388607&i;if((g|0)==0){k=b+556|0;c[k>>2]=(c[k>>2]|0)+1;break}if((g|0)==(i|0)){i=b+552|0;c[i>>2]=(c[i>>2]|0)+1;break}else{i=b+560|0;c[i>>2]=(c[i>>2]|0)+1;break}}}while(0);h=b+572|0;c[h>>2]=c[h>>2]|j;c[d>>2]=(e|0)<0?-j|0:j;return}function Obb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;h=i;i=i+128|0;j=h|0;k=h+8|0;l=h+88|0;m=h+96|0;n=h+104|0;o=h+112|0;p=e;q=b+60|0;r=c[q>>2]|0;c[r+5460>>2]=b;s=r+5496|0;c[s>>2]=0;t=r+5500|0;c[t>>2]=0;c[f>>2]=0;u=r+5468|0;c[u>>2]=0;v=r+5488|0;c[v>>2]=0;w=g+24|0;x=c[w>>2]|0;y=g+28|0;g=c[y>>2]|0;if(!((g|0)>-1)){yDb(0,0,2143512,(z=i,i=i+24|0,c[z>>2]=2138080,c[z+8>>2]=2131408,c[z+16>>2]=135,z)|0);i=z;Cd();return 0}A=x+g|0;B=A;C=x;if(g>>>0<12>>>0){D=-1094995529;i=h;return D|0}E=x+4|0;F=x;if((d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)!=1179011410){yDb(b,16,2178408,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1094995529;i=h;return D|0}if((g-4|0)<4){G=0;H=E}else{g=E;G=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;H=x+8|0}x=B-H|0;if(x>>>0<G>>>0){D=-1094995529;i=h;return D|0}do{if((x|0)>=4){G=H;if((d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)!=1346520407){break}G=H+4|0;g=r+5492|0;DBb(g);a:do{if((A|0)!=(G|0)){E=l|0;F=l;I=b;J=b+140|0;K=k+24|0;L=k+28|0;M=e+44|0;N=e+12|0;O=e+68|0;P=e+72|0;Q=r+5480|0;R=r+5484|0;S=r+5472|0;T=r+5476|0;U=o|0;V=o+8|0;W=o+4|0;X=G;Y=0;b:while(1){TGb(E|0,0,5)|0;if((B-X|0)<4){Z=0;_=X}else{$=X;Z=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;_=X+4|0}if((B-_|0)<4){aa=_;ca=0}else{$=_;da=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;if((da|0)==-1){D=-1094995529;ea=119;break}else{aa=_+4|0;ca=da}}da=(ca&1)+ca|0;$=aa;fa=B-$|0;if(fa>>>0<da>>>0){D=-1094995529;ea=119;break}do{if((Z|0)==540561494){do{if((c[f>>2]|0)==0){ga=(c[w>>2]|0)+($-C)|0;ha=c[q>>2]|0;ia=ha+5464|0;do{if((c[ia>>2]|0)==0){y5a(b)|0;c[ia>>2]=1;if((c[ha+5468>>2]|0)==0){break}c[J>>2]=35}}while(0);c[ha+5504>>2]=0;if((da|0)<0){ea=25;break b}vZ(k);c[K>>2]=ga;c[L>>2]=da;ia=u5a(b,e,f,k)|0;if((c[ha+5468>>2]|0)==0){if((ia|0)<0){D=ia;ea=119;break b}else{break}}ia=c[ha+5480>>2]|0;ja=c[ha+5484>>2]|0;ka=c[q>>2]|0;la=c[ka+5472>>2]|0;do{if((la|0)==0){if(!((ja|0)>-1)){ea=29;break b}ma=ka+5500|0;if((c[ma>>2]|0)<=0){break}na=ka+5496|0;oa=ia+ja|0;pa=ia;qa=0;while(1){ra=(c[N>>2]|0)+(ba(c[M>>2]|0,qa)|0)|0;sa=c[na>>2]|0;ta=oa-pa|0;ua=ta>>>0>sa>>>0?sa:ta;UGb(ra|0,pa|0,ua)|0;ra=qa+1|0;if((ra|0)<(c[ma>>2]|0)){pa=pa+ua|0;qa=ra}else{break}}}else if((la|0)==1){c[j>>2]=0;qa=ICb()|0;va=ka+5456|0;c[va>>2]=qa;if((qa|0)==0){D=-12;ea=119;break b}wa=Qbb(b,qa,j,ia,ja,1)|0;if((wa|0)<0){ea=35;break b}if((c[j>>2]|0)==0){ea=39;break b}qa=ka+5500|0;pa=c[qa>>2]|0;if((pa|0)>0){ma=ka+5496|0;oa=0;na=c[ma>>2]|0;ra=pa;while(1){pa=c[va>>2]|0;if((na|0)>0){ua=ba(c[pa+32>>2]|0,oa)|0;ta=ba(c[M>>2]|0,oa)|0;sa=0;xa=(c[pa>>2]|0)+(ua+2)|0;ua=(c[N>>2]|0)+ta|0;while(1){a[ua]=a[xa]|0;ta=sa+1|0;ya=c[ma>>2]|0;if((ta|0)<(ya|0)){sa=ta;xa=xa+4|0;ua=ua+1|0}else{break}}za=ya;Aa=c[qa>>2]|0}else{za=na;Aa=ra}ua=oa+1|0;if((ua|0)<(Aa|0)){oa=ua;na=za;ra=Aa}else{break}}}JCb(va)}}while(0);ja=c[ka+5476>>2]|0;if((ja|0)==0){break}ia=c[M>>2]|0;la=c[N>>2]|0;if((c[O>>2]|0)>1){ha=1;ga=la;ra=a[la]|0;do{ga=ga+1|0;ra=(a[ga]|0)+ra&255;a[ga]=ra;ha=ha+1|0;}while((ha|0)<(c[O>>2]|0));Ba=c[N>>2]|0}else{Ba=la}ha=c[P>>2]|0;if((ha|0)>1){ra=1;ga=Ba;ka=a[Ba]|0;while(1){na=ga+ia|0;oa=(a[na]|0)+ka&255;a[na]=oa;qa=ra+1|0;ma=c[P>>2]|0;if((qa|0)<(ma|0)){ra=qa;ga=na;ka=oa}else{Ca=ma;break}}}else{Ca=ha}if((ja|0)==2){if((Ca|0)<=1){break}ka=-ia|0;ga=1;ra=c[O>>2]|0;la=Ca;while(1){if((ra|0)>1){ma=(ba(ga,ia)|0)+1|0;oa=1;na=(c[N>>2]|0)+ma|0;while(1){a[na]=(a[na]|0)+(a[na+ka|0]|0);ma=oa+1|0;Da=c[O>>2]|0;if((ma|0)<(Da|0)){oa=ma;na=na+1|0}else{break}}Ea=Da;Fa=c[P>>2]|0}else{Ea=ra;Fa=la}na=ga+1|0;if((na|0)<(Fa|0)){ga=na;ra=Ea;la=Fa}else{break}}}else if((ja|0)==3){if((Ca|0)<=1){break}la=-ia|0;ra=~ia;ga=1;ka=c[O>>2]|0;ha=Ca;while(1){if((ka|0)>1){na=(ba(ga,ia)|0)+1|0;oa=1;ma=(c[N>>2]|0)+na|0;while(1){na=(d[ma+la|0]|0)+(d[ma-1|0]|0)-(d[ma+ra|0]|0)|0;if(na>>>0>255>>>0){Ga=-na>>31&255}else{Ga=na&255}a[ma]=(a[ma]|0)+Ga;na=oa+1|0;Ha=c[O>>2]|0;if((na|0)<(Ha|0)){oa=na;ma=ma+1|0}else{break}}Ia=Ha;Ja=c[P>>2]|0}else{Ia=ka;Ja=ha}ma=ga+1|0;if((ma|0)<(Ja|0)){ga=ma;ka=Ia;ha=Ja}else{break}}}else if((ja|0)==1){if((Ca|0)<=1){break}ha=1;ka=c[O>>2]|0;ga=Ca;while(1){if((ka|0)>1){ra=(ba(ha,ia)|0)+1|0;la=1;ma=(c[N>>2]|0)+ra|0;while(1){a[ma]=(a[ma]|0)+(a[ma-1|0]|0);ra=la+1|0;Ka=c[O>>2]|0;if((ra|0)<(Ka|0)){la=ra;ma=ma+1|0}else{break}}La=Ka;Ma=c[P>>2]|0}else{La=ka;Ma=ga}ma=ha+1|0;if((ma|0)<(Ma|0)){ha=ma;ka=La;ga=Ma}else{break}}}else{break}}}while(0);Na=Y;Oa=aa+(fa>>>0>da>>>0?da:fa)|0}else if((Z|0)==1278758998){if((c[f>>2]|0)==0){ga=Qbb(b,p,f,(c[w>>2]|0)+($-C)|0,da,0)|0;if((ga|0)<0){D=ga;ea=119;break b}}Na=Y;Oa=aa+(fa>>>0>da>>>0?da:fa)|0}else if((Z|0)==1213221953){if((Y&16|0)==0){yDb(I,24,2046016,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}if((da|0)==0){ea=93;break b}if((fa|0)<1){Pa=0;Qa=aa}else{Pa=d[aa]|0;Qa=aa+1|0}ga=Qa;c[Q>>2]=(c[w>>2]|0)+(ga-C);ka=da-1|0;c[R>>2]=ka;ha=B-ga|0;ga=Qa+(ha>>>0>ka>>>0?ka:ha)|0;ha=Pa&3;if(ha>>>0>1>>>0){yDb(I,40,1963368,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;Na=Y;Oa=ga;break}else{c[u>>2]=1;c[S>>2]=ha;c[T>>2]=Pa>>>2&3;Na=Y;Oa=ga;break}}else if((Z|0)==1480085590){if((fa|0)<1){Ra=0;Sa=aa}else{Ra=d[aa]|0;Sa=aa+1|0}ga=B-Sa|0;ha=ga>>>0>3>>>0?3:ga;ga=Sa+ha|0;if((B-ga|0)<3){Ta=1;Ua=ga}else{Ta=((d[Sa+(ha+1)|0]|0)<<8|(d[Sa+(ha+2)|0]|0)<<16|(d[ga]|0))+1|0;Ua=Sa+(ha+3)|0}c[s>>2]=Ta;if((B-Ua|0)<3){Va=1;Wa=Ua}else{Va=((d[Ua+1|0]|0)<<8|(d[Ua+2|0]|0)<<16|(d[Ua]|0))+1|0;Wa=Ua+3|0}c[t>>2]=Va;ha=hDb(Ta,Va,0,I)|0;if((ha|0)<0){D=ha;ea=119;break b}else{Na=Ra;Oa=Wa}}else if((Z|0)==1346585417|(Z|0)==1296649793|(Z|0)==1179471425|(Z|0)==542133592){c[F>>2]=Z;yDb(I,40,2328848,(z=i,i=i+8|0,c[z>>2]=E,z)|0);i=z;Na=Y;Oa=aa+(fa>>>0>da>>>0?da:fa)|0}else if((Z|0)==1179211845){ha=$-C|0;do{if((c[v>>2]|0)==0){if((Y&8|0)==0){yDb(I,24,1912e3,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}c[v>>2]=1;ga=c[w>>2]|0;ka=ga+ha|0;ia=c[y>>2]|0;if(!((ia-ha|0)>-1)){ea=105;break b}c[U>>2]=ka;c[V>>2]=ka;c[W>>2]=ga+ia;if((P_a(o,m,n)|0)<0){yDb(I,16,1891504,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break}ia=c[n>>2]|0;ga=c[V>>2]|0;ka=(c[W>>2]|0)-ga|0;if((ia|0)<0){Xa=0}else{Xa=(ka|0)<(ia|0)?ka:ia}c[U>>2]=ga+Xa;if((Qkb(b,o,c[m>>2]|0,0,g)|0)<0){yDb(I,16,2349048,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break}else{ga=FCb(p)|0;EBb(ga,c[g>>2]|0,0);break}}else{yDb(I,40,1935272,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}}while(0);DBb(g);Na=Y;Oa=aa+(fa>>>0>da>>>0?da:fa)|0}else{c[F>>2]=Z;yDb(I,40,2304448,(z=i,i=i+8|0,c[z>>2]=E,z)|0);i=z;Na=Y;Oa=aa+(fa>>>0>da>>>0?da:fa)|0}}while(0);if((A|0)==(Oa|0)){break a}else{X=Oa;Y=Na}}if((ea|0)==25){yDb(I,16,2150456,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1163346256;i=h;return D|0}else if((ea|0)==29){yDb(0,0,2143512,(z=i,i=i+24|0,c[z>>2]=2138080,c[z+8>>2]=2131408,c[z+16>>2]=135,z)|0);i=z;Cd();return 0}else if((ea|0)==35){JCb(va);D=wa;i=h;return D|0}else if((ea|0)==39){JCb(va);D=-1094995529;i=h;return D|0}else if((ea|0)==93){yDb(I,16,2000344,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1094995529;i=h;return D|0}else if((ea|0)==105){yDb(0,0,2143512,(z=i,i=i+24|0,c[z>>2]=2138080,c[z+8>>2]=2131408,c[z+16>>2]=135,z)|0);i=z;Cd();return 0}else if((ea|0)==119){i=h;return D|0}}}while(0);if((c[f>>2]|0)==0){yDb(b,16,2286544,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1094995529;i=h;return D|0}else{D=c[y>>2]|0;i=h;return D|0}}}while(0);yDb(b,16,2102136,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1094995529;i=h;return D|0}function Pbb(a){a=a|0;var b=0;if((c[(c[a+60>>2]|0)+5464>>2]|0)==0){b=0;return b|0}b=w5a(a)|0;return b|0}function Qbb(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;k=i;i=i+8|0;l=k|0;m=c[b+60>>2]|0;n=m;o=(j|0)!=0;if(!o){c[m+5504>>2]=1;c[b+140>>2]=27}j=h<<3;p=j>>>0>2147483639>>>0|(g|0)==0;q=p?0:g;g=p?0:j;j=p?-1094995529:0;r=m+5436|0;c[r>>2]=q;c[m+5448>>2]=g;s=g+8|0;t=m+5452|0;c[t>>2]=s;c[m+5440>>2]=q+(g>>3);g=m+5444|0;c[g>>2]=0;if(p){u=j;i=k;return u|0}do{if(o){p=c[m+5496>>2]|0;if((p|0)==0){u=-558323010;i=k;return u|0}v=c[m+5500>>2]|0;if((v|0)==0){u=-558323010}else{w=j;x=v;y=p;break}i=k;return u|0}else{p=q;v=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24)&255;p=s>>>0>8>>>0?8:s;c[g>>2]=p;if((v|0)!=47){yDb(b,16,2270544,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;u=-1094995529;i=k;return u|0}v=q+(p>>>3)|0;A=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24)&16383;v=p+14|0;p=s>>>0>v>>>0?v:s;c[g>>2]=p;v=A+1|0;A=q+(p>>>3)|0;B=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((p&7)>>>0)&16383;A=p+14|0;c[g>>2]=s>>>0>A>>>0?A:s;A=B+1|0;B=m+5496|0;p=c[B>>2]|0;if(!((p|0)==0|(p|0)==(v|0))){yDb(b,24,2255200,(z=i,i=i+16|0,c[z>>2]=p,c[z+8>>2]=v,z)|0);i=z}c[B>>2]=v;p=m+5500|0;C=c[p>>2]|0;if((C|0)==0|(C|0)==(A|0)){D=v}else{yDb(b,24,2240824,(z=i,i=i+16|0,c[z>>2]=v,c[z+8>>2]=v,z)|0);i=z;D=c[B>>2]|0}c[p>>2]=A;p=V$a(b,D,A)|0;if((p|0)<0){u=p;i=k;return u|0}B=c[g>>2]|0;C=c[r>>2]|0;E=(d[C+(B>>>3)|0]|0)>>>((B&7)>>>0);F=c[t>>2]|0;G=((B|0)<(F|0))+B|0;c[g>>2]=G;c[m+5468>>2]=E&1;E=C+(G>>>3)|0;C=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=G+3|0;c[g>>2]=F>>>0>E>>>0?E:F;if((C&7<<(G&7)|0)==0){w=p;x=A;y=v;break}yDb(b,16,2228752,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;u=-1094995529;i=k;return u|0}}while(0);b=m+5508|0;c[b>>2]=0;D=m+5528|0;c[D>>2]=0;s=m+5512|0;q=m+5496|0;j=m+5500|0;v=m+5624|0;A=m+5656|0;p=m+5688|0;G=m+5668|0;C=w;a:while(1){w=(C|0)<0;while(1){F=c[g>>2]|0;E=c[r>>2]|0;B=d[E+(F>>>3)|0]|0;H=c[t>>2]|0;I=((F|0)<(H|0))+F|0;c[g>>2]=I;if((B&1<<(F&7)|0)==0){J=34;break a}F=E+(I>>>3)|0;E=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((I&7)>>>0)&3;F=I+2|0;c[g>>2]=H>>>0>F>>>0?F:H;H=c[b>>2]|0;c[b>>2]=H+1;c[s+(H<<2)>>2]=E;if((E|0)==0){J=20;break}else if((E|0)==3){J=24;break}else if((E|0)==1){J=22;break}if(w){K=C;break a}}if((J|0)==20){J=0;w=c[g>>2]|0;E=c[t>>2]|0;H=(c[r>>2]|0)+(w>>>3)|0;F=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((w&7)>>>0)&7;H=w+3|0;c[g>>2]=E>>>0>H>>>0?H:E;E=F+2|0;F=1<<E;H=-F|0;w=Rbb(n,2,((c[q>>2]|0)-1+F&H)>>E,((c[j>>2]|0)-1+F&H)>>E)|0;if((w|0)<0){K=w;break}c[v>>2]=E;C=0;continue}else if((J|0)==22){J=0;E=c[g>>2]|0;w=c[t>>2]|0;H=(c[r>>2]|0)+(E>>>3)|0;F=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((E&7)>>>0)&7;H=E+3|0;c[g>>2]=w>>>0>H>>>0?H:w;w=F+2|0;F=1<<w;H=-F|0;E=Rbb(n,3,((c[q>>2]|0)-1+F&H)>>w,((c[j>>2]|0)-1+F&H)>>w)|0;if((E|0)<0){K=E;break}c[A>>2]=w;C=0;continue}else if((J|0)==24){J=0;w=c[g>>2]|0;E=c[t>>2]|0;H=(c[r>>2]|0)+(w>>>3)|0;F=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((w&7)>>>0)&255;H=w+8|0;c[g>>2]=E>>>0>H>>>0?H:E;E=F+1|0;do{if(E>>>0<3>>>0){L=3}else{if(E>>>0<5>>>0){L=2;break}L=E>>>0<17>>>0|0}}while(0);F=Rbb(n,4,E,1)|0;if((F|0)<0){K=F;break}c[p>>2]=L;if((L|0)!=0){c[D>>2]=(1<<L)-1+(c[q>>2]|0)>>L}F=c[G>>2]|0;if((c[F+68>>2]<<2|0)<=4){C=0;continue}H=4;w=(c[F>>2]|0)+4|0;while(1){a[w]=(a[w]|0)+(a[w-4|0]|0);F=H+1|0;if((F|0)<(c[(c[G>>2]|0)+68>>2]<<2|0)){H=F;w=w+1|0}else{C=0;continue a}}}}b:do{if((J|0)==34){C=m+5540|0;c[C>>2]=e;if(o){c[m+5564>>2]=1}L=Rbb(n,0,y,x)|0;if((L|0)<0){K=L;break}q=c[b>>2]|0;c:do{if((q|0)>0){D=m+5604|0;g=l|0;r=l+1|0;t=l+2|0;j=l+3|0;w=m+5636|0;H=L;E=q;d:while(1){F=E-1|0;I=c[s+(F<<2)>>2]|0;do{if((I|0)==2){B=c[C>>2]|0;if((c[B+72>>2]|0)>0){M=0;N=B}else{O=0;break}while(1){if((c[N+68>>2]|0)>0){B=0;P=N;while(1){Q=c[P>>2]|0;R=(ba(c[P+32>>2]|0,M)|0)+(B<<2)|0;S=a[Q+(R+2)|0]|0;T=Q+(R+1)|0;a[T]=(a[T]|0)+S;T=Q+(R+3)|0;a[T]=(a[T]|0)+S;S=B+1|0;T=c[C>>2]|0;if((S|0)<(c[T+68>>2]|0)){B=S;P=T}else{U=T;break}}}else{U=N}P=M+1|0;if((P|0)<(c[U+72>>2]|0)){M=P;N=U}else{O=0;break}}}else if((I|0)==3){P=c[p>>2]|0;if((P|0)>0){B=8>>>(P>>>0);P=WDb(c[(c[C>>2]|0)+32>>2]|0)|0;if((P|0)==0){K=-12;break b}T=c[C>>2]|0;if((c[T+72>>2]|0)>0){S=32-B|0;R=0;Q=T;while(1){T=Q+32|0;V=c[T>>2]|0;UGb(P|0,(c[Q>>2]|0)+(ba(V,R)|0)|0,V)|0;V=c[T>>2]|0;T=V<<3;W=T>>>0>2147483639>>>0;X=W?0:P;Y=W?8:T+8|0;e:do{if((c[Q+68>>2]|0)>0){T=Y>>>0>16>>>0?16:Y;W=0;Z=0;_=Q;$=V;while(1){aa=ba($,R)|0;ca=X+(T>>>3)|0;da=T+B|0;ea=Y>>>0>da>>>0?da:Y;a[(c[_>>2]|0)+((W<<2|2)+aa)|0]=(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)>>>((T&7)>>>0)<<S>>>(S>>>0);ca=Z+1|0;if((ca|0)==(1<<c[p>>2]|0)){aa=ea+24|0;fa=0;ga=Y>>>0>aa>>>0?aa:Y}else{fa=ca;ga=ea}ea=W+1|0;ca=c[C>>2]|0;if((ea|0)>=(c[ca+68>>2]|0)){ha=ca;break e}T=ga;W=ea;Z=fa;_=ca;$=c[ca+32>>2]|0}}else{ha=Q}}while(0);Y=R+1|0;if((Y|0)<(c[ha+72>>2]|0)){R=Y;Q=ha}else{break}}}ZDb(P)}Q=c[C>>2]|0;if((c[Q+72>>2]|0)>0){ia=0;ja=Q}else{O=0;break}while(1){if((c[ja+68>>2]|0)>0){Q=0;R=ja;while(1){S=c[R>>2]|0;B=(ba(c[R+32>>2]|0,ia)|0)+(Q<<2)|0;ka=d[S+(B+2)|0]|0;Y=c[G>>2]|0;if((ka|0)>=(c[Y+68>>2]|0)){J=76;break d}c[S+B>>2]=c[(c[Y>>2]|0)+(ka<<2)>>2];Y=Q+1|0;B=c[C>>2]|0;if((Y|0)<(c[B+68>>2]|0)){Q=Y;R=B}else{la=B;break}}}else{la=ja}R=ia+1|0;if((R|0)<(c[la+72>>2]|0)){ia=R;ja=la}else{O=0;break}}}else if((I|0)==1){P=c[C>>2]|0;if((c[P+72>>2]|0)>0){ma=0;na=P}else{O=0;break}while(1){if((c[na+68>>2]|0)>0){P=0;R=na;while(1){Q=c[A>>2]|0;B=c[w>>2]|0;Y=c[B>>2]|0;S=(ba(c[B+32>>2]|0,ma>>Q)|0)+(P>>Q<<2)|0;Q=c[R>>2]|0;B=(ba(c[R+32>>2]|0,ma)|0)+(P<<2)|0;X=a[Q+(B+2)|0]|0;V=(ba(X,a[Y+(S+3)|0]|0)|0)>>>5&255;$=Q+(B+1)|0;_=V+(a[$]|0)&255;a[$]=_;$=(ba(a[Y+(S+2)|0]|0,X)|0)>>>5&255;X=(ba(_<<24>>24,a[Y+(S+1)|0]|0)|0)>>>5&255;S=Q+(B+3)|0;a[S]=($+(a[S]|0)&255)+X;X=P+1|0;S=c[C>>2]|0;if((X|0)<(c[S+68>>2]|0)){P=X;R=S}else{oa=S;break}}}else{oa=na}R=ma+1|0;if((R|0)<(c[oa+72>>2]|0)){ma=R;na=oa}else{O=0;break}}}else if((I|0)==0){R=c[C>>2]|0;if((c[R+72>>2]|0)>0){pa=0;qa=R}else{O=0;break}while(1){R=c[qa+68>>2]|0;f:do{if((R|0)>0){P=(pa|0)==0;S=P?0:2;X=pa-1|0;if(P){P=0;$=qa;B=R;while(1){Q=c[$>>2]|0;Y=P<<2;_=Q+Y|0;V=Y-4|0;Z=ba(c[$+32>>2]|0,X)|0;if((B-1|0)==(P|0)){ra=0}else{ra=Y+4+Z|0}le[c[904888+(((P|0)==0?S:1)<<2)>>2]&1023](g,Q+V|0,Q+(Z+V)|0,Q+(Z+Y)|0,Q+ra|0);a[_]=(a[_]|0)+(a[g]|0);_=Q+(Y|1)|0;a[_]=(a[_]|0)+(a[r]|0);_=Q+(Y|2)|0;a[_]=(a[_]|0)+(a[t]|0);_=Q+(Y|3)|0;a[_]=(a[_]|0)+(a[j]|0);_=P+1|0;Y=c[C>>2]|0;Q=c[Y+68>>2]|0;if((_|0)<(Q|0)){P=_;$=Y;B=Q}else{sa=Y;break f}}}else{ta=0;ua=qa;va=R}while(1){B=c[v>>2]|0;$=c[D>>2]|0;if((ta|0)==0){wa=S}else{P=(ba(c[$+32>>2]|0,pa>>B)|0)+(ta>>B<<2|2)|0;B=a[(c[$>>2]|0)+P|0]|0;xa=B&255;if((B&255)>>>0>13>>>0){J=48;break d}else{wa=xa}}B=c[ua>>2]|0;P=c[ua+32>>2]|0;$=ba(P,pa)|0;Y=ta<<2;Q=$+Y|0;_=B+Q|0;Z=Y-4|0;V=ba(P,X)|0;if((va-1|0)==(ta|0)){ya=$}else{ya=Y+4+V|0}le[c[904888+(wa<<2)>>2]&1023](g,B+($+Z)|0,B+(V+Z)|0,B+(V+Y)|0,B+ya|0);a[_]=(a[_]|0)+(a[g]|0);_=B+(Q+1)|0;a[_]=(a[_]|0)+(a[r]|0);_=B+(Q+2)|0;a[_]=(a[_]|0)+(a[t]|0);_=B+(Q+3)|0;a[_]=(a[_]|0)+(a[j]|0);_=ta+1|0;Q=c[C>>2]|0;B=c[Q+68>>2]|0;if((_|0)<(B|0)){ta=_;ua=Q;va=B}else{sa=Q;break}}}else{sa=qa}}while(0);R=pa+1|0;if((R|0)<(c[sa+72>>2]|0)){pa=R;qa=sa}else{O=0;break}}}else{if((H|0)<0){K=H;break b}else{O=H}}}while(0);if((F|0)>0){H=O;E=F}else{break c}}if((J|0)==48){yDb(c[m+5460>>2]|0,16,2207640,(z=i,i=i+8|0,c[z>>2]=xa,z)|0);i=z;K=-1094995529;break b}else if((J|0)==76){yDb(c[m+5460>>2]|0,16,2216952,(z=i,i=i+8|0,c[z>>2]=ka,z)|0);i=z;K=-1094995529;break b}}}while(0);c[f>>2]=1;c[e+88>>2]=1;c[e+84>>2]=1;K=h}}while(0);h=m+5536|0;m=0;while(1){e=h+(m<<5)|0;ZDb(c[h+(m<<5)+12>>2]|0);do{if((c[e>>2]|0)!=0){if((c[h+(m<<5)+28>>2]|0)!=0){break}JCb(h+(m<<5)+4|0)}}while(0);f=h+(m<<5)+20|0;z=c[f>>2]|0;if((z|0)!=0){ka=h+(m<<5)+16|0;if((c[ka>>2]|0)>0){J=0;xa=z;while(1){O=J*5|0;Q_(xa+(O<<5)|0);Q_((c[f>>2]|0)+(O+1<<5)|0);Q_((c[f>>2]|0)+(O+2<<5)|0);Q_((c[f>>2]|0)+(O+3<<5)|0);Q_((c[f>>2]|0)+(O+4<<5)|0);O=J+1|0;sa=c[f>>2]|0;if((O|0)<(c[ka>>2]|0)){J=O;xa=sa}else{za=sa;break}}}else{za=z}ZDb(za)}TGb(e|0,0,32)|0;xa=m+1|0;if((xa|0)<5){m=xa}else{u=K;break}}i=k;return u|0}function Rbb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;k=i;i=i+128|0;l=k|0;m=k+32|0;n=k+112|0;c[f+5536+(g<<5)>>2]=g;o=f+5536+(g<<5)+4|0;p=c[o>>2]|0;do{if((p|0)==0){q=ICb()|0;c[o>>2]=q;if((q|0)==0){r=-12}else{s=q;break}i=k;return r|0}else{s=p}}while(0);c[s+80>>2]=27;c[s+68>>2]=h;c[s+72>>2]=j;j=(g|0)==0;do{if(j){if((c[f+5564>>2]|0)!=0){t=6;break}c[n>>2]=s;c[n+4>>2]=0;c[n+8>>2]=0;u=W0a(c[f+5460>>2]|0,n,0)|0}else{t=6}}while(0);if((t|0)==6){u=LCb(s,1)|0}if((u|0)<0){r=u;i=k;return r|0}u=f+5436|0;s=f+5444|0;n=c[s>>2]|0;h=u|0;p=c[h>>2]|0;q=d[p+(n>>>3)|0]|0;v=f+5452|0;w=c[v>>2]|0;y=((n|0)<(w|0))+n|0;c[s>>2]=y;do{if((q&1<<(n&7)|0)==0){c[f+5536+(g<<5)+8>>2]=0}else{z=p+(y>>>3)|0;A=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((y&7)>>>0)&15;z=y+4|0;c[s>>2]=w>>>0>z>>>0?z:w;c[f+5536+(g<<5)+8>>2]=A;if((A|0)==0|A>>>0>11>>>0){yDb(c[f+5460>>2]|0,16,2199368,(B=i,i=i+8|0,c[B>>2]=A,B)|0);i=B;r=-1094995529;i=k;return r|0}z=1<<A;if(z>>>0<536870911>>>0){A=cEb(z<<2)|0;c[f+5536+(g<<5)+12>>2]=A;if((A|0)==0){r=-12}else{break}i=k;return r|0}else{c[f+5536+(g<<5)+12>>2]=0;r=-12;i=k;return r|0}}}while(0);w=f+5536+(g<<5)+16|0;c[w>>2]=1;a:do{if(j){y=c[s>>2]|0;p=c[h>>2]|0;n=d[p+(y>>>3)|0]|0;q=c[v>>2]|0;A=((y|0)<(q|0))+y|0;c[s>>2]=A;if((n&1<<(y&7)|0)==0){C=1;break}y=c[f+5528>>2]|0;n=(y|0)>0?y:c[f+5496>>2]|0;y=p+(A>>>3)|0;p=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((A&7)>>>0)&7;y=A+3|0;c[s>>2]=q>>>0>y>>>0?y:q;q=p+2|0;p=1<<q;y=-p|0;A=Rbb(f,1,(n-1+p&y)>>q,((c[f+5500>>2]|0)-1+p&y)>>q)|0;if((A|0)<0){r=A;i=k;return r|0}c[f+5592>>2]=q;q=c[f+5572>>2]|0;A=c[q+72>>2]|0;do{if((A|0)>0){y=c[q+68>>2]|0;if((y|0)>0){D=0;E=0}else{break}while(1){p=c[q>>2]|0;n=c[q+32>>2]|0;z=0;F=E;do{G=d[p+((z<<2|2)+(ba(n,D)|0))|0]|0;F=(F|0)>(G|0)?F:G;z=z+1|0;}while((z|0)<(y|0));z=D+1|0;if((z|0)<(A|0)){D=z;E=F}else{break}}y=F+1|0;c[f+5532>>2]=y;c[w>>2]=y;if((y*5|0)>>>0<67108863>>>0){C=y;break a}c[f+5536+(g<<5)+20>>2]=0;r=-12;i=k;return r|0}}while(0);c[f+5532>>2]=1;c[w>>2]=1;C=1}else{C=1}}while(0);F=cEb(C*160|0)|0;C=F;E=f+5536+(g<<5)+20|0;c[E>>2]=C;if((F|0)==0){r=-12;i=k;return r|0}b:do{if((c[w>>2]|0)>0){F=f+5536+(g<<5)+8|0;D=l;A=m;q=m|0;y=l|0;z=f+5460|0;n=0;p=C;c:while(1){G=n*5|0;H=0;do{I=e[1797024+(H<<1)>>1]|0;do{if((H|0)==0){J=c[F>>2]|0;if((J|0)<=0){K=I;break}K=(1<<J)+I|0}else{K=I}}while(0);I=c[s>>2]|0;J=c[h>>2]|0;L=d[J+(I>>>3)|0]|0;M=c[v>>2]|0;N=((I|0)<(M|0))+I|0;c[s>>2]=N;O=H+G|0;P=p+(O<<5)|0;if((L&1<<(I&7)|0)==0){TGb(D|0,0,32)|0;TGb(A|0,0,76)|0;I=J+(N>>>3)|0;L=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((N&7)>>>0)&15;I=N+4|0;Q=M>>>0>I>>>0?I:M;c[s>>2]=Q;I=L+4|0;if(I>>>0>19>>>0){r=-1094995529;t=101;break c}else{R=0;S=Q}do{Q=J+(S>>>3)|0;L=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((S&7)>>>0)&7;Q=S+3|0;S=M>>>0>Q>>>0?Q:M;c[s>>2]=S;c[m+(d[1484408+R|0]<<2)>>2]=L;R=R+1|0;}while((R|0)<(I|0));I=fcb(l,q,19)|0;d:do{if((I|0)<0){T=0;U=I}else{if(!(K>>>0<536870911>>>0)){T=0;U=-12;break}L=cEb(K<<2)|0;Q=L;if((L|0)==0){T=Q;U=-12;break}L=c[s>>2]|0;V=c[h>>2]|0;W=d[V+(L>>>3)|0]|0;X=c[v>>2]|0;Y=((L|0)<(X|0))+L|0;c[s>>2]=Y;do{if((W&1<<(L&7)|0)==0){Z=K}else{_=V+(Y>>>3)|0;$=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((Y&7)>>>0);_=Y+3|0;aa=X>>>0>_>>>0?_:X;c[s>>2]=aa;_=$<<1&14;$=V+(aa>>>3)|0;ca=30-_|0;da=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((aa&7)>>>0)<<ca>>>(ca>>>0);ca=aa+2+_|0;c[s>>2]=X>>>0>ca>>>0?ca:X;ca=da+2|0;if((ca|0)<=(K|0)){Z=ca;break}yDb(c[z>>2]|0,16,2164104,(B=i,i=i+16|0,c[B>>2]=ca,c[B+8>>2]=K,B)|0);i=B;T=Q;U=-1094995529;break d}}while(0);e:do{if((K|0)>0){X=0;V=Z;Y=8;f:while(1){ea=X;L=V;while(1){fa=L-1|0;if((L|0)==0){break e}ga=ecb(l,u)|0;if((ga|0)<16){break}if((ga|0)==18){W=c[s>>2]|0;ca=c[v>>2]|0;da=(c[h>>2]|0)+(W>>>3)|0;_=(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((W&7)>>>0)&127;da=W+7|0;c[s>>2]=ca>>>0>da>>>0?da:ca;ha=0;ia=_+11|0}else if((ga|0)==16){_=c[s>>2]|0;ca=c[v>>2]|0;da=(c[h>>2]|0)+(_>>>3)|0;W=(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((_&7)>>>0)&3;da=_+2|0;c[s>>2]=ca>>>0>da>>>0?da:ca;ha=Y;ia=W+3|0}else if((ga|0)==17){W=c[s>>2]|0;ca=c[v>>2]|0;da=(c[h>>2]|0)+(W>>>3)|0;_=(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((W&7)>>>0)&7;da=W+3|0;c[s>>2]=ca>>>0>da>>>0?da:ca;ha=0;ia=_+3|0}else{ha=0;ia=0}_=ia+ea|0;if((_|0)>(K|0)){break f}if((ia|0)>0){ca=ea;da=ia;while(1){W=da-1|0;c[Q+(ca<<2)>>2]=ha;if((W|0)>0){ca=ca+1|0;da=W}else{ja=_;break}}}else{ja=ea}if((ja|0)<(K|0)){ea=ja;L=fa}else{break e}}L=ea+1|0;c[Q+(ea<<2)>>2]=ga;if((L|0)<(K|0)){X=L;V=fa;Y=(ga|0)==0?Y:ga}else{break e}}yDb(c[z>>2]|0,16,2157184,(B=i,i=i+24|0,c[B>>2]=ea,c[B+8>>2]=ia,c[B+16>>2]=K,B)|0);i=B;T=Q;U=-1094995529;break d}}while(0);T=Q;U=fcb(P,Q,K)|0}}while(0);Q_(y);ZDb(T);if((U|0)<0){r=U;t=101;break c}}else{P=(d[J+(N>>>3)|0]|0)>>>((N&7)>>>0);c[s>>2]=((N|0)<(M|0))+N;I=p+(O<<5)+24|0;c[I>>2]=(P&1)+1;P=c[s>>2]|0;Y=d[J+(P>>>3)|0]|0;V=c[v>>2]|0;X=((P|0)<(V|0))+P|0;c[s>>2]=X;L=J+(X>>>3)|0;if((Y&1<<(P&7)|0)==0){P=(d[L]|0)>>>((X&7)>>>0);Y=((X|0)<(V|0))+X|0;c[s>>2]=Y;b[p+(O<<5)+28>>1]=P&1;ka=Y}else{Y=L;L=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((X&7)>>>0);Y=X+8|0;X=V>>>0>Y>>>0?Y:V;c[s>>2]=X;b[p+(O<<5)+28>>1]=L&255;ka=X}if((c[I>>2]|0)==2){I=J+(ka>>>3)|0;X=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((ka&7)>>>0);I=ka+8|0;c[s>>2]=V>>>0>I>>>0?I:V;b[p+(O<<5)+30>>1]=X&255}c[p+(O<<5)+20>>2]=1}H=H+1|0;}while((H|0)<5);H=n+1|0;if((H|0)>=(c[w>>2]|0)){break b}n=H;p=c[E>>2]|0}if((t|0)==101){i=k;return r|0}}}while(0);w=c[o>>2]|0;ka=c[w+68>>2]|0;if(j){j=c[f+5528>>2]|0;la=(j|0)>0?j:ka}else{la=ka}if((c[w+72>>2]|0)<=0){r=0;i=k;return r|0}w=f+5592|0;ka=f+5572|0;j=f+5536+(g<<5)+8|0;U=f+5536+(g<<5)+12|0;g=0;T=0;g:while(1){K=c[w>>2]|0;if((K|0)>0){ia=c[ka>>2]|0;ma=(d[(c[ia>>2]|0)+((ba(c[ia+32>>2]|0,g>>K)|0)+(T>>K<<2|2))|0]|0)*5|0}else{ma=0}K=c[E>>2]|0;ia=ecb(K+(ma<<5)|0,u)|0;h:do{if((ia|0)<256){ea=c[o>>2]|0;ga=c[ea>>2]|0;fa=(ba(c[ea+32>>2]|0,g)|0)+(T<<2)|0;ea=ga+fa|0;a[ga+(fa+2)|0]=ia;a[ga+(fa+1)|0]=ecb(K+(ma+1<<5)|0,u)|0;a[ga+(fa+3)|0]=ecb(K+(ma+2<<5)|0,u)|0;a[ea]=ecb(K+(ma+3<<5)|0,u)|0;fa=c[j>>2]|0;if((fa|0)!=0){ga=ea;ea=fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0;c[(c[U>>2]|0)+((ba(ea,506832829)|0)>>>((32-fa|0)>>>0)<<2)>>2]=ea}ea=T+1|0;fa=(ea|0)==(la|0);na=fa?0:ea;oa=(fa&1)+g|0}else{if((ia|0)>=280){fa=c[o>>2]|0;ea=(c[fa>>2]|0)+((ba(c[fa+32>>2]|0,g)|0)+(T<<2))|0;fa=ia-280|0;ga=c[j>>2]|0;if((ga|0)==0){t=97;break g}if((fa|0)>=(1<<ga|0)){t=99;break g}ga=ea;x=fe(c[(c[U>>2]|0)+(fa<<2)>>2]|0)|0;a[ga]=x;x=x>>8;a[ga+1|0]=x;x=x>>8;a[ga+2|0]=x;x=x>>8;a[ga+3|0]=x;ga=T+1|0;fa=(ga|0)==(la|0);na=fa?0:ga;oa=(fa&1)+g|0;break}fa=ia-256|0;if((fa|0)<4){pa=fa}else{ga=ia-258>>1;ea=c[s>>2]|0;ja=c[v>>2]|0;ha=(c[h>>2]|0)+(ea>>>3)|0;l=32-ga|0;Z=(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)>>>((ea&7)>>>0)<<l>>>(l>>>0);l=ea+ga|0;c[s>>2]=ja>>>0>l>>>0?l:ja;pa=Z+((fa&1|2)<<ga)|0}ga=pa+1|0;fa=ecb(K+(ma+4<<5)|0,u)|0;if((fa|0)<4){qa=fa}else{Z=fa-2>>1;ja=c[s>>2]|0;l=c[v>>2]|0;ea=(c[h>>2]|0)+(ja>>>3)|0;ha=32-Z|0;R=(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)>>>((ja&7)>>>0)<<ha>>>(ha>>>0);ha=ja+Z|0;c[s>>2]=l>>>0>ha>>>0?ha:l;qa=R+((fa&1|2)<<Z)|0}if((qa+1|0)<121){Z=(ba(a[687145+(qa<<1)|0]|0,la)|0)+(a[687144+(qa<<1)|0]|0)|0;ra=(Z|0)<1?1:Z}else{ra=qa-119|0}Z=(ra|0)>(T|0);fa=Z?ra-T|0:0;R=Z?0:T-ra|0;if((fa|0)<(la|0)){sa=fa;ta=g}else{Z=fa;fa=g;while(1){l=fa-1|0;ha=Z-la|0;if((ha|0)<(la|0)){sa=ha;ta=l;break}else{Z=ha;fa=l}}}if((sa|0)>0){ua=ta-1|0;va=la-sa|0}else{ua=ta;va=R}if((ga|0)<=0){na=T;oa=g;break}fa=(va|0)<0?0:va;Z=(ua|0)<0?0:ua;l=g;ha=T;ja=0;ea=c[o>>2]|0;while(1){m=c[ea>>2]|0;S=c[ea+32>>2]|0;C=m+((ba(S,l)|0)+(ha<<2))|0;p=c[m+((ba(S,Z)|0)+(fa<<2))>>2]|0;c[C>>2]=p;C=c[j>>2]|0;if((C|0)!=0){S=fe(p|0)|0;c[(c[U>>2]|0)+((ba(S,506832829)|0)>>>((32-C|0)>>>0)<<2)>>2]=S}S=ha+1|0;C=fa+1|0;p=(S|0)==(la|0);m=(p&1)+l|0;n=p?0:S;S=(C|0)==(la|0);p=(S&1)+Z|0;y=c[o>>2]|0;z=c[y+72>>2]|0;if((m|0)==(z|0)|(p|0)==(z|0)){na=n;oa=m;break h}z=ja+1|0;if((z|0)<(ga|0)){fa=S?0:C;Z=p;l=m;ha=n;ja=z;ea=y}else{na=n;oa=m;break}}}}while(0);if((oa|0)<(c[(c[o>>2]|0)+72>>2]|0)){g=oa;T=na}else{r=0;t=101;break}}if((t|0)==97){yDb(c[f+5460>>2]|0,16,2190736,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;r=-1094995529;i=k;return r|0}else if((t|0)==99){yDb(c[f+5460>>2]|0,16,2174104,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;r=-1094995529;i=k;return r|0}else if((t|0)==101){i=k;return r|0}return 0}function Sbb(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;f=b;x=255;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;return}function Tbb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a>>2]=c[b>>2];return}function Ubb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a>>2]=c[e>>2];return}function Vbb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a>>2]=c[f>>2];return}function Wbb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a>>2]=c[d>>2];return}function Xbb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((((d[g]|0)+(d[c]|0)|0)>>>1)+(d[f]|0)|0)>>>1;a[b+1|0]=((((d[g+1|0]|0)+(d[c+1|0]|0)|0)>>>1)+(d[f+1|0]|0)|0)>>>1;a[b+2|0]=((((d[g+2|0]|0)+(d[c+2|0]|0)|0)>>>1)+(d[f+2|0]|0)|0)>>>1;a[b+3|0]=((((d[g+3|0]|0)+(d[c+3|0]|0)|0)>>>1)+(d[f+3|0]|0)|0)>>>1;return}function Ybb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((d[e]|0)+(d[c]|0)|0)>>>1;a[b+1|0]=((d[e+1|0]|0)+(d[c+1|0]|0)|0)>>>1;a[b+2|0]=((d[e+2|0]|0)+(d[c+2|0]|0)|0)>>>1;a[b+3|0]=((d[e+3|0]|0)+(d[c+3|0]|0)|0)>>>1;return}function Zbb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((d[f]|0)+(d[c]|0)|0)>>>1;a[b+1|0]=((d[f+1|0]|0)+(d[c+1|0]|0)|0)>>>1;a[b+2|0]=((d[f+2|0]|0)+(d[c+2|0]|0)|0)>>>1;a[b+3|0]=((d[f+3|0]|0)+(d[c+3|0]|0)|0)>>>1;return}function _bb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((d[f]|0)+(d[e]|0)|0)>>>1;a[b+1|0]=((d[f+1|0]|0)+(d[e+1|0]|0)|0)>>>1;a[b+2|0]=((d[f+2|0]|0)+(d[e+2|0]|0)|0)>>>1;a[b+3|0]=((d[f+3|0]|0)+(d[e+3|0]|0)|0)>>>1;return}function $bb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((d[g]|0)+(d[f]|0)|0)>>>1;a[b+1|0]=((d[g+1|0]|0)+(d[f+1|0]|0)|0)>>>1;a[b+2|0]=((d[g+2|0]|0)+(d[f+2|0]|0)|0)>>>1;a[b+3|0]=((d[g+3|0]|0)+(d[f+3|0]|0)|0)>>>1;return}function acb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((((d[g]|0)+(d[f]|0)|0)>>>1)+(((d[e]|0)+(d[c]|0)|0)>>>1)|0)>>>1;a[b+1|0]=((((d[g+1|0]|0)+(d[f+1|0]|0)|0)>>>1)+(((d[e+1|0]|0)+(d[c+1|0]|0)|0)>>>1)|0)>>>1;a[b+2|0]=((((d[g+2|0]|0)+(d[f+2|0]|0)|0)>>>1)+(((d[e+2|0]|0)+(d[c+2|0]|0)|0)>>>1)|0)>>>1;a[b+3|0]=((((d[g+3|0]|0)+(d[f+3|0]|0)|0)>>>1)+(((d[e+3|0]|0)+(d[c+3|0]|0)|0)>>>1)|0)>>>1;return}function bcb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=d[e]|0;h=(d[b]|0)-g|0;i=(d[f]|0)-g|0;g=d[e+1|0]|0;j=(d[b+1|0]|0)-g|0;k=(d[f+1|0]|0)-g|0;g=d[e+2|0]|0;l=(d[b+2|0]|0)-g|0;m=(d[f+2|0]|0)-g|0;g=d[e+3|0]|0;e=(d[b+3|0]|0)-g|0;n=(d[f+3|0]|0)-g|0;if((((h|0)>-1?h:-h|0)-((i|0)>-1?i:-i|0)+((j|0)>-1?j:-j|0)-((k|0)>-1?k:-k|0)+((l|0)>-1?l:-l|0)-((m|0)>-1?m:-m|0)+((e|0)>-1?e:-e|0)-((n|0)>-1?n:-n|0)|0)<1){c[a>>2]=c[f>>2];return}else{c[a>>2]=c[b>>2];return}}function ccb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;g=(d[f]|0)+(d[c]|0)-(d[e]|0)|0;if(g>>>0>255>>>0){h=-g>>31&255}else{h=g&255}a[b]=h;h=(d[f+1|0]|0)+(d[c+1|0]|0)-(d[e+1|0]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[b+1|0]=i;i=(d[f+2|0]|0)+(d[c+2|0]|0)-(d[e+2|0]|0)|0;if(i>>>0>255>>>0){j=-i>>31&255}else{j=i&255}a[b+2|0]=j;j=(d[f+3|0]|0)+(d[c+3|0]|0)-(d[e+3|0]|0)|0;if(!(j>>>0>255>>>0)){k=j&255;l=b+3|0;a[l]=k;return}k=-j>>31&255;l=b+3|0;a[l]=k;return}function dcb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;g=((d[f]|0)+(d[c]|0)|0)>>>1;h=g+((g-(d[e]|0)|0)/2|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[b]=i;i=((d[f+1|0]|0)+(d[c+1|0]|0)|0)>>>1;h=i+((i-(d[e+1|0]|0)|0)/2|0)|0;if(h>>>0>255>>>0){j=-h>>31&255}else{j=h&255}a[b+1|0]=j;j=((d[f+2|0]|0)+(d[c+2|0]|0)|0)>>>1;h=j+((j-(d[e+2|0]|0)|0)/2|0)|0;if(h>>>0>255>>>0){k=-h>>31&255}else{k=h&255}a[b+2|0]=k;k=((d[f+3|0]|0)+(d[c+3|0]|0)|0)>>>1;c=k+((k-(d[e+3|0]|0)|0)/2|0)|0;if(!(c>>>0>255>>>0)){l=c&255;m=b+3|0;a[m]=l;return}l=-c>>31&255;m=b+3|0;a[m]=l;return}function ecb(a,f){a=a|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[a+20>>2]|0)==0){g=c[a+4>>2]|0;h=f+8|0;i=c[h>>2]|0;j=c[f+16>>2]|0;k=c[f>>2]|0;l=k+(i>>>3)|0;m=d[1148864+((d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)>>>((i&7)>>>0)&255)|0]|0;l=b[g+(m<<2)>>1]|0;n=b[g+(m<<2)+2>>1]|0;m=n<<16>>16;if(n<<16>>16<0){n=i+8|0;o=j>>>0>n>>>0?n:j;n=k+(o>>>3)|0;k=m+32|0;p=((d[1148864+((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((o&7)>>>0)<<k>>>(k>>>0))|0]|0)>>>((m+8|0)>>>0))+l|0;q=b[g+(p<<2)+2>>1]|0;r=o;s=b[g+(p<<2)>>1]|0}else{q=m;r=i;s=l}l=q+r|0;c[h>>2]=j>>>0>l>>>0?l:j;t=s;return t|0}if((c[a+24>>2]|0)==1){t=e[a+28>>1]|0;return t|0}else{s=f+8|0;j=c[s>>2]|0;l=(d[(c[f>>2]|0)+(j>>>3)|0]|0)>>>((j&7)>>>0);c[s>>2]=((j|0)<(c[f+16>>2]|0))+j;t=e[a+28+((l&1)<<1)>>1]|0;return t|0}return 0}function fcb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=(e|0)>0;if(f){g=0;h=0;i=0}else{j=-22;return j|0}while(1){if((c[d+(g<<2)>>2]|0)>0){k=i+1|0;l=g&65535;if((i|0)>0){m=k;n=l;break}else{o=k;p=l}}else{o=i;p=h}l=g+1|0;if((l|0)<(e|0)){g=l;h=p;i=o}else{m=o;n=p;break}}if((m|0)==1){c[a+24>>2]=1;b[a+28>>1]=n;c[a+20>>2]=1;j=0;return j|0}if(f){q=0;r=0}else{j=-22;return j|0}do{n=c[d+(q<<2)>>2]|0;r=(r|0)>(n|0)?r:n;q=q+1|0;}while((q|0)<(e|0));if((r|0)==0|(r|0)>15){j=-22;return j|0}q=WDb(e<<1)|0;n=q;if((q|0)==0){j=-12;return j|0}m=a+24|0;c[m>>2]=0;do{if(!((r|0)<1|f^1)){p=0;o=1;i=0;while(1){h=0;g=p;l=i;while(1){if((c[d+(h<<2)>>2]|0)==(o|0)){b[n+(h<<1)>>1]=g;k=l+1|0;c[m>>2]=k;s=g+1|0;t=k}else{s=g;t=l}k=h+1|0;if((k|0)<(e|0)){h=k;g=s;l=t}else{break}}l=o+1|0;if((l|0)>(r|0)){break}else{p=s<<1;o=l;i=t}}if((t|0)==0){break}i=N_(a|0,8,e,d,4,4,q,2,2,0,0,0,0)|0;if((i|0)<0){ZDb(q);j=i;return j|0}else{c[a+20>>2]=0;ZDb(q);j=0;return j|0}}}while(0);ZDb(q);j=-1094995529;return j|0}function gcb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;i=i+1040|0;h=g|0;j=g+1024|0;k=g+1032|0;l=d;m=c[f+24>>2]|0;IAb(h,0,-1);n=f+28|0;if((m|0)==0){o=d+12|0;p=o;q=c[p>>2]|0;r=(q|0)!=0;s=r&1;c[e>>2]=s;t=QAb(h,0)|0;u=c[n>>2]|0;i=g;return u|0}if((c[n>>2]|0)<=0){o=d+12|0;p=o;q=c[p>>2]|0;r=(q|0)!=0;s=r&1;c[e>>2]=s;t=QAb(h,0)|0;u=c[n>>2]|0;i=g;return u|0}v=a[m]|0;a:do{if(!(v<<24>>24==0)){w=0;x=m;y=v;while(1){z=0;while(1){if(!(z>>>0<8>>>0)){A=x;B=y;break}C=c[57840+(z<<3)>>2]|0;D=SGb(C|0)|0;if((RGb(x,C,D)|0)==0){E=7;break}else{z=z+1|0}}if((E|0)==7){E=0;KAb(h,2178400,(F=i,i=i+8|0,c[F>>2]=c[57844+(z<<3)>>2],F)|0);i=F;C=x+D|0;A=C;B=a[C]|0}do{if((B<<24>>24|0)==10){if((a[A+1|0]|0)==0){E=12;break}KAb(h,2102128,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;G=w}else if((B<<24>>24|0)==62){G=0}else if((B<<24>>24|0)==0){break a}else if((B<<24>>24|0)==60){G=1}else{E=12}}while(0);do{if((E|0)==12){E=0;if((w|0)!=0){G=w;break}if(B<<24>>24==13){G=0;break}MAb(h,B,1);G=0}}while(0);z=A+1|0;C=a[z]|0;if(C<<24>>24==0){break}else{w=G;x=z;y=C}}}}while(0);KAb(h,2046008,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;F=f+8|0;G=c[F>>2]|0;A=c[F+4>>2]|0;F=b+104|0;c[j>>2]=1;c[j+4>>2]=100;b=KDb(G,A,F,j)|0;j=c[f+48>>2]|0;if((j|0)==-1){H=-1}else{c[k>>2]=1;c[k+4>>2]=100;f=KDb(j,(j|0)<0|0?-1:0,F,k)|0;H=f}shb(l,c[h>>2]|0,b,H,0)|0;o=d+12|0;p=o;q=c[p>>2]|0;r=(q|0)!=0;s=r&1;c[e>>2]=s;t=QAb(h,0)|0;u=c[n>>2]|0;i=g;return u|0}function hcb(f,h){f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0.0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0;j=i;k=c[f+60>>2]|0;l=f+412|0;if(((c[l>>2]|0)-1|0)>>>0>49999>>>0){m=-1;i=j;return m|0}n=f+416|0;if(((c[n>>2]|0)-1|0)>>>0>1>>>0){m=-1;i=j;return m|0}o=f+72|0;if((c[o>>2]|0)<1){m=-1;i=j;return m|0}iba(k+159264|0,f);fCb(k+159284|0,c[f+88>>2]&8388608);p=k+48|0;q=(c[(c[f+12>>2]|0)+12>>2]|0)==86023?1:2;c[p>>2]=q;r=ncb(c[l>>2]|0,q,0)|0;q=k+1100|0;c[q>>2]=r;c[k+1116>>2]=r;c[k+1120>>2]=r;c[k+1112>>2]=r;s=k+1096|0;c[s>>2]=1<<r;if((c[k+56>>2]|0)==0){c[k+1104>>2]=1}else{t=(((c[o>>2]|0)/(c[n>>2]|0)|0|0)>31999?3:1)+(h>>>3&3)|0;h=r-7|0;c[k+1104>>2]=((t|0)>(h|0)?h:t)+1}t=k+64|0;c[t>>2]=1;h=c[l>>2]|0;u=+(h|0)*.5;do{if((c[p>>2]|0)==2){if((h|0)>44099){v=44100;break}if((h|0)>22049){v=22050;break}if((h|0)>15999){v=16e3;break}if((h|0)>11024){v=11025;break}v=(h|0)<8e3?h:8e3}else{v=h}}while(0);w=+(c[o>>2]|0)/+(ba(h,c[n>>2]|0)|0);h=~~(w*+(c[s>>2]|0)*.125+.5);o=h>>>0>65535>>>0;r=o?h>>>16:h;h=o?16:0;if((r&65280|0)==0){x=h;y=r}else{x=h|8;y=r>>>8}r=(d[1191992+y|0]|0)+x|0;x=r+2|0;c[k+68>>2]=x;if((r+5|0)>25){yDb(f,16,2197320,(f=i,i=i+8|0,c[f>>2]=x,f)|0);i=f;m=-1163346256;i=j;return m|0}if((c[n>>2]|0)==2){z=w*1.6}else{z=w}do{if((v|0)==11025){A=u*.7}else if((v|0)==22050){B=z;if(!(B<1.16)){c[t>>2]=0;A=u;break}C=u;if(B<.72){A=C*.6;break}else{A=C*.7;break}}else if((v|0)==16e3){if(w>.5){A=u*.5;break}else{A=u*.3;break}}else if((v|0)==44100){if(z<.61){A=u*.4;break}else{c[t>>2]=0;A=u;break}}else{C=w;if((v|0)==8e3){if(!(C>.625)){A=u*.5;break}if(w>.75){c[t>>2]=0;A=u;break}else{A=u*.65;break}}else{if(!(C<.8)){A=u*.75;break}if(w<.6){A=u*.5;break}else{A=u*.6;break}}}}while(0);v=c[p>>2]|0;c[k+384>>2]=(v|0)==1?3:0;n=k+1104|0;do{if((c[n>>2]|0)>0){f=k+388|0;x=k+364|0;r=k+92|0;y=r;h=k+408|0;o=k+112|0;D=o;E=k+428|0;F=o;o=r;r=0;G=v;while(1){H=c[s>>2]>>r;a:do{if((G|0)==1){I=H<<1;J=0;K=0;while(1){if((J|0)>=25){L=J;break}M=c[l>>2]|0;N=((ba(I,e[1082480+(J<<1)>>1]|0)|0)+(M>>1)|0)/(M|0)|0;M=(N|0)>(H|0)?H:N;b[F+(J<<1)>>1]=M-K;N=J+1|0;if((M|0)<(H|0)){J=N;K=M}else{L=N;break}}c[o>>2]=L;O=c[y+(r<<2)>>2]|0}else{K=-7-r+(c[q>>2]|0)|0;b:do{if((K|0)<3){J=c[l>>2]|0;do{if((J|0)>44099){P=1320752+(K*25|0)|0}else{if((J|0)>31999){P=1320832+(K*25|0)|0;break}if((J|0)<=22049){Q=0;R=0;S=0;break b}P=1320912+(K*25|0)|0}}while(0);J=a[P]|0;I=J&255;if(!(J<<24>>24==0)){J=0;while(1){N=J+1|0;b[D+(r*50|0)+(J<<1)>>1]=d[P+N|0]|0;if((N|0)<(I|0)){J=N}else{break}}}c[y+(r<<2)>>2]=I;O=I;break a}else{Q=0;R=0;S=0}}while(0);while(1){if((R|0)>=25){T=Q;break}K=c[l>>2]|0;J=(((ba(e[1082480+(R<<1)>>1]|0,H)|0)+K<<1|0)/(K<<2|0)|0)<<2;K=(J|0)>(H|0)?H:J;if((K|0)>(S|0)){b[D+(r*50|0)+(Q<<1)>>1]=K-S;U=Q+1|0}else{U=Q}if((K|0)<(H|0)){Q=U;R=R+1|0;S=K}else{T=U;break}}c[y+(r<<2)>>2]=T;O=T}}while(0);K=c[s>>2]|0;J=K-((K*9|0|0)/100|0)>>r;K=f+(r<<2)|0;c[K>>2]=J;N=~~(A*+(H<<1|0)/+(c[l>>2]|0)+.5);M=x+(r<<2)|0;c[M>>2]=N;c:do{if((O|0)>0){V=0;W=0;X=0;Y=N;Z=J;while(1){_=(e[D+(r*50|0)+(W<<1)>>1]|0)+V|0;$=(V|0)<(Y|0)?Y:V;aa=(_|0)>(Z|0)?Z:_;if((aa|0)>($|0)){c[E+(r<<6)+(X<<2)>>2]=aa-$;ca=X+1|0}else{ca=X}$=W+1|0;if(($|0)>=(O|0)){da=ca;break c}V=_;W=$;X=ca;Y=c[M>>2]|0;Z=c[K>>2]|0}}else{da=0}}while(0);c[h+(r<<2)>>2]=da;K=r+1|0;ea=c[n>>2]|0;if((K|0)>=(ea|0)){break}r=K;G=c[p>>2]|0}if((ea|0)<=0){break}G=k+67040|0;r=0;do{VXa((c[q>>2]|0)-r|0);c[G+(r<<2)>>2]=c[1138224+((c[q>>2]|0)-r<<2)>>2];r=r+1|0;}while((r|0)<(c[n>>2]|0))}}while(0);c[k+1108>>2]=1;if((c[t>>2]|0)!=0){A=(c[k+60>>2]|0)==0?.03999999910593033:.019999999552965164;g[k+149020>>2]=A;u=A*8.065490087349327e-10;t=k+116248|0;n=0;q=1;do{q=(q*314159|0)+1|0;g[t+(n<<2)>>2]=u*+(q|0);n=n+1|0;}while((n|0)<8192)}do{if((c[l>>2]|0)>31999){u=z;if(u<.72){fa=0;break}if(!(u<1.16)){fa=4;break}fa=2}else{fa=4}}while(0);l=1429720+(fa*20|0)|0;c[k+1088>>2]=l;n=k+1092|0;c[n>>2]=1429720+((fa|1)*20|0);icb(k+1024|0,k+1064|0,k+1072|0,k+1080|0,l);icb(k+1044|0,k+1068|0,k+1076|0,k+1084|0,c[n>>2]|0);m=0;i=j;return m|0}function icb(a,d,e,f,h){a=a|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0,x=0,y=0;i=c[h>>2]|0;j=c[h+16>>2]|0;N_(a,9,i,c[h+12>>2]|0,1,1,c[h+8>>2]|0,4,4,0,0,0,0)|0;h=i<<1;a=WDb(h)|0;k=WDb(h)|0;l=k;m=WDb(i<<2)|0;n=WDb(h)|0;if((i|0)>2){o=2;p=0;q=1}else{c[d>>2]=a;c[e>>2]=m;c[f>>2]=n;ZDb(k);return}while(1){b[n+(p<<1)>>1]=o;h=p+1|0;r=b[j+(p<<1)>>1]|0;s=r&65535;if(r<<16>>16==0){t=o}else{r=q&65535;u=+(q|0);v=s>>>0>1>>>0?s:1;w=o;x=0;while(1){b[a+(w<<1)>>1]=x;b[l+(w<<1)>>1]=r;g[m+(w<<2)>>2]=u;y=x+1|0;if((y|0)<(s|0)){w=w+1|0;x=y}else{break}}t=o+v|0}if((t|0)<(i|0)){o=t;p=h;q=q+1|0}else{break}}c[d>>2]=a;c[e>>2]=m;c[f>>2]=n;ZDb(k);return}function jcb(a){a=a|0;var b=0;do{if((a|0)<15){b=13}else{if((a|0)<32){b=12;break}if((a|0)<40){b=11;break}b=(a|0)<45?10:9}}while(0);return b|0}function kcb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b+1104|0;if((c[a>>2]|0)>0){d=b+66720|0;e=0;do{bLa(d+(e<<6)|0);e=e+1|0;}while((e|0)<(c[a>>2]|0))}if((c[b+60>>2]|0)!=0){Q_(b+72|0)}if((c[b+64>>2]|0)!=0){Q_(b+748|0)}Q_(b+1024|0);$Db(b+1064|0);$Db(b+1072|0);$Db(b+1080|0);Q_(b+1044|0);$Db(b+1068|0);$Db(b+1076|0);$Db(b+1084|0);return 0}function lcb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+8|0;e=c[b>>2]|0;f=c[a>>2]|0;g=d[f+(e>>>3)|0]|0;h=c[a+16>>2]|0;a=((e|0)<(h|0))+e|0;c[b>>2]=a;do{if((g&128>>>((e&7)>>>0)|0)==0){i=8;j=a}else{k=d[f+(a>>>3)|0]|0;l=((a|0)<(h|0))+a|0;c[b>>2]=l;if((k&128>>>((a&7)>>>0)|0)==0){i=16;j=l;break}k=d[f+(l>>>3)|0]|0;m=((l|0)<(h|0))+l|0;c[b>>2]=m;i=(k&128>>>((l&7)>>>0)|0)==0?24:31;j=m}}while(0);a=f+(j>>>3)|0;e=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(j&7);if(i>>>0<26>>>0){a=j+i|0;c[b>>2]=h>>>0>a>>>0?a:h;n=e>>>((32-i|0)>>>0);return n|0}else{a=j+16|0;j=h>>>0>a>>>0?a:h;c[b>>2]=j;a=i-16|0;g=f+(j>>>3)|0;f=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(j&7)>>>((48-i|0)>>>0);i=j+a|0;c[b>>2]=h>>>0>i>>>0?i:h;n=f|e>>>16<<a;return n|0}return 0}function mcb(a,f,h,j,k,l,m,n,o,p,q,r){a=a|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;s=i;t=p-1|0;a:do{if((n|0)<(o|0)){p=h+4|0;u=f+8|0;v=f+16|0;w=f|0;x=32-r|0;y=32-q|0;if((l|0)==0){z=c[p>>2]|0;A=c[w>>2]|0;B=n;while(1){C=c[u>>2]|0;D=c[v>>2]|0;E=A+(C>>>3)|0;F=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(C&7)>>>23;E=b[z+(F<<2)>>1]|0;G=b[z+(F<<2)+2>>1]|0;F=G<<16>>16;do{if(G<<16>>16<0){H=C+9|0;I=D>>>0>H>>>0?H:D;H=A+(I>>>3)|0;J=((fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(I&7)>>>((F+32|0)>>>0))+E|0;H=b[z+(J<<2)>>1]|0;K=b[z+(J<<2)+2>>1]|0;J=K<<16>>16;if(!(K<<16>>16<0)){L=J;M=H;N=I;break}K=I-F|0;I=D>>>0>K>>>0?K:D;K=A+(I>>>3)|0;O=((fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(I&7)>>>((J+32|0)>>>0))+H|0;L=b[z+(O<<2)+2>>1]|0;M=b[z+(O<<2)>>1]|0;N=I}else{L=F;M=E;N=C}}while(0);C=L+N|0;E=D>>>0>C>>>0?C:D;c[u>>2]=E;if((M|0)>1){C=(e[k+(M<<1)>>1]|0)+B|0;F=d[A+(E>>>3)|0]<<(E&7)>>>7;c[u>>2]=((E|0)<(D|0))+E;c[m+((C&t)<<2)>>2]=c[j+(M<<2)>>2]^-2147483648^F<<31;P=C}else{if((M|0)==1){Q=B;break a}C=A+(E>>>3)|0;F=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>(x>>>0);C=E+r|0;E=D>>>0>C>>>0?C:D;c[u>>2]=E;C=A+(E>>>3)|0;G=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>(y>>>0);C=E+q|0;E=D>>>0>C>>>0?C:D;c[u>>2]=E;C=G+B|0;G=d[A+(E>>>3)|0]<<(E&7)>>>7;c[u>>2]=((E|0)<(D|0))+E;E=(G&1)-1|0;g[m+((C&t)<<2)>>2]=+((E^F)-E|0);P=C}C=P+1|0;if((C|0)<(o|0)){B=C}else{Q=C;break a}}}B=n;A=c[w>>2]|0;b:while(1){x=c[p>>2]|0;z=c[u>>2]|0;C=c[v>>2]|0;E=A+(z>>>3)|0;F=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(z&7)>>>23;E=b[x+(F<<2)>>1]|0;G=b[x+(F<<2)+2>>1]|0;F=G<<16>>16;do{if(G<<16>>16<0){I=z+9|0;O=C>>>0>I>>>0?I:C;I=A+(O>>>3)|0;H=((fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(O&7)>>>((F+32|0)>>>0))+E|0;I=b[x+(H<<2)>>1]|0;J=b[x+(H<<2)+2>>1]|0;H=J<<16>>16;if(!(J<<16>>16<0)){R=H;S=I;T=O;break}J=O-F|0;O=C>>>0>J>>>0?J:C;J=A+(O>>>3)|0;K=((fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(O&7)>>>((H+32|0)>>>0))+I|0;R=b[x+(K<<2)+2>>1]|0;S=b[x+(K<<2)>>1]|0;T=O}else{R=F;S=E;T=z}}while(0);z=R+T|0;E=C>>>0>z>>>0?z:C;c[u>>2]=E;if((S|0)>1){z=(e[k+(S<<1)>>1]|0)+B|0;F=d[A+(E>>>3)|0]<<(E&7)>>>7;c[u>>2]=((E|0)<(C|0))+E;c[m+((z&t)<<2)>>2]=c[j+(S<<2)>>2]^-2147483648^F<<31;U=z;V=A}else{if((S|0)==1){Q=B;break a}z=lcb(f)|0;F=c[u>>2]|0;E=c[w>>2]|0;x=d[E+(F>>>3)|0]|0;G=c[v>>2]|0;D=((F|0)<(G|0))+F|0;c[u>>2]=D;do{if((x&128>>>((F&7)>>>0)|0)==0){W=B;X=D}else{O=d[E+(D>>>3)|0]|0;K=((D|0)<(G|0))+D|0;c[u>>2]=K;I=E+(K>>>3)|0;if((O&128>>>((D&7)>>>0)|0)==0){O=I;H=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(K&7)>>>30;O=K+2|0;J=G>>>0>O>>>0?O:G;c[u>>2]=J;W=B+1+H|0;X=J;break}J=d[I]|0;I=((K|0)<(G|0))+K|0;c[u>>2]=I;if((J&128>>>((K&7)>>>0)|0)!=0){break b}K=E+(I>>>3)|0;J=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(I&7)>>>(y>>>0);K=I+q|0;I=G>>>0>K>>>0?K:G;c[u>>2]=I;W=B+4+J|0;X=I}}while(0);D=d[E+(X>>>3)|0]<<(X&7)>>>7;c[u>>2]=((X|0)<(G|0))+X;F=(D&1)-1|0;g[m+((W&t)<<2)>>2]=+((F^z)-F|0);U=W;V=E}F=U+1|0;if((F|0)<(o|0)){B=F;A=V}else{Q=F;break a}}yDb(a,16,2311328,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;Z=-1;i=s;return Z|0}else{Q=n}}while(0);if((Q|0)<=(o|0)){Z=0;i=s;return Z|0}yDb(a,16,2178360,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;Z=-1;i=s;return Z|0}function ncb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;do{if((a|0)<16001){d=9}else{if((a|0)<22051){d=10;break}if((a|0)<32001&(b|0)==1){d=10;break}if((a|0)<48001|(b|0)<3){d=11;break}d=(a|0)<96001?12:13}}while(0);do{if((b|0)==3){a=c&6;if((a|0)==2){e=d+1|0;break}else if((a|0)==6){e=d-2|0;break}else if((a|0)==4){e=d-1|0;break}else{e=d;break}}else{e=d}}while(0);return e|0}function ocb(a){a=a|0;var b=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0.0;b=i;e=c[a+60>>2]|0;f=e;if((c[a+432>>2]|0)==0){yDb(a,16,2216920,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=b;return j|0}c[e>>2]=a;k=c[a+96>>2]|0;l=c[(c[a+12>>2]|0)+12>>2]|0;do{if((l|0)==86024){if((c[a+100>>2]|0)<=5){m=0;n=86024;break}o=k+4|0;m=(d[o]|d[o+1|0]<<8)<<16>>16&65535;n=86024}else if((l|0)==86023){if((c[a+100>>2]|0)<=3){m=0;n=86023;break}o=k+2|0;m=(d[o]|d[o+1|0]<<8)<<16>>16&65535;n=86023}else{m=0;n=l}}while(0);l=e+60|0;c[l>>2]=m&1;c[e+52>>2]=m&2;o=m&4;p=e+56|0;c[p>>2]=o;do{if((n|0)==86024){if((c[a+100>>2]|0)<=7){break}q=k+4|0;if((d[q]|d[q+1|0]<<8)<<16>>16<<16>>16!=13|(o|0)==0){break}yDb(a,24,2207528,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;c[p>>2]=0}}while(0);if((hcb(a,m)|0)<0){j=-1;i=b;return j|0}m=e+1104|0;if((c[m>>2]|0)>0){p=e+66720|0;h=e+1100|0;o=0;do{aLa(p+(o<<6)|0,1-o+(c[h>>2]|0)|0,1,30517578125.0e-15)|0;o=o+1|0;}while((o|0)<(c[m>>2]|0))}if((c[e+64>>2]|0)!=0){N_(e+748|0,9,37,1082440,1,1,1082360,2,2,0,0,0,0)|0}if((c[l>>2]|0)==0){l=c[e+1096>>2]|0;r=3.141592653589793/+(l|0);if((l|0)>0){m=0;while(1){g[f+149024+(m<<2)>>2]=+T(r*+(m|0))*2.0;o=m+1|0;if((o|0)<(l|0)){m=o}else{s=0;break}}}else{s=0}while(1){g[f+157216+(s<<2)>>2]=+Wc(+(+(s-126|0)*-.25));m=s+1|0;if((m|0)<256){s=m}else{t=127;u=1.0;break}}while(1){r=+S(+(+(t+128|0)*.00390625),+-.25);g[f+158240+(t<<2)>>2]=r*2.0-u;g[f+158752+(t<<2)>>2]=u-r;if((t|0)>0){t=t-1|0;u=r}else{break}}}else{N_(e+72|0,8,121,1277624,1,1,1277136,4,4,0,0,0,0)|0}c[a+420>>2]=8;j=0;i=b;return j|0}function pcb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=i;j=e;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=g;if((l|0)==0){c[g+116244>>2]=0;n=0;i=h;return n|0}o=c[b+432>>2]|0;if((l|0)<(o|0)){yDb(b,16,2000296,(p=i,i=i+16|0,c[p>>2]=l,c[p+8>>2]=o,p)|0);i=p;n=-1094995529;i=h;return n|0}q=(o|0)==0?l:o;o=q<<3;l=o>>>0>2147483639>>>0|(k|0)==0;r=l?0:k;s=l?0:o;l=g+4|0;c[l>>2]=r;t=g+16|0;c[t>>2]=s;u=s+8|0;v=g+20|0;c[v>>2]=u;w=g+8|0;c[w>>2]=r+(s>>3);s=g+12|0;c[s>>2]=0;x=g+52|0;do{if((c[x>>2]|0)==0){y=1}else{z=u>>>0>4>>>0?4:u;c[s>>2]=z;A=r+(z>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&4)>>>28;A=z+4|0;c[s>>2]=u>>>0>A>>>0?A:u;A=B-((c[g+116244>>2]|0)<1)|0;if((A|0)>=1){y=A;break}yDb(b,16,1963336,(p=i,i=i+8|0,c[p>>2]=A,p)|0);i=p;n=-1094995529;i=h;return n|0}}while(0);u=g+1096|0;c[e+76>>2]=ba(c[u>>2]|0,y)|0;r=_$a(b,j,0)|0;if((r|0)<0){n=r;i=h;return n|0}r=c[e+64>>2]|0;a:do{if((c[x>>2]|0)==0){if((rcb(m,r,0)|0)<0){C=37}else{C=36}}else{e=g+68|0;j=c[e>>2]|0;A=c[s>>2]|0;B=c[v>>2]|0;z=c[l>>2]|0;D=z+(A>>>3)|0;E=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(A&7)>>>((29-j|0)>>>0);D=j+3+A|0;A=B>>>0>D>>>0?D:B;c[s>>2]=A;D=(c[t>>2]|0)-A|0;if((E|0)>(D|0)){yDb(b,16,1935208,(p=i,i=i+24|0,c[p>>2]=E,c[p+8>>2]=D,c[p+16>>2]=q,p)|0);i=p;C=37;break}D=g+116244|0;F=c[D>>2]|0;if((F|0)>0){if((F+(E+7>>3)|0)>16384){C=37;break}G=g+99840|0;H=g+(F+99840)|0;if((E|0)>7){I=E-8|0;J=I>>>3;K=J<<3;L=F+J+99841|0;J=E;F=H;M=A;A=B;B=z;while(1){z=B+(M>>>3)|0;N=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(M&7)>>>24;z=M+8|0;c[s>>2]=A>>>0>z>>>0?z:A;a[F]=N;N=J-8|0;if((N|0)<=7){break}J=N;F=F+1|0;M=c[s>>2]|0;A=c[v>>2]|0;B=c[l>>2]|0}O=I-K|0;P=g+L|0}else{O=E;P=H}if((O|0)>0){B=c[s>>2]|0;A=c[v>>2]|0;M=(c[l>>2]|0)+(B>>>3)|0;F=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(B&7)>>>((32-O|0)>>>0);M=B+O|0;c[s>>2]=A>>>0>M>>>0?M:A;a[P]=F<<8-O;Q=P+1|0}else{Q=P}TGb(Q|0,0,16)|0;F=(c[D>>2]<<3)+E|0;A=F>>>0>2147483639>>>0|(G|0)==0;M=A?0:G;B=A?0:F;c[l>>2]=M;c[t>>2]=B;F=B+8|0;c[v>>2]=F;c[w>>2]=M+(B+7>>3);c[s>>2]=0;B=c[g+116240>>2]|0;if((B|0)>0){c[s>>2]=F>>>0>B>>>0?B:F}if((rcb(m,r,0)|0)<0){C=37;break}R=c[u>>2]|0;S=y-1|0;T=c[e>>2]|0}else{R=0;S=y;T=j}F=E+11|0;B=F+T|0;if((B|0)>131071|(B|0)>(o|0)){n=-1094995529;i=h;return n|0}M=B>>3;A=k+M|0;J=q-M<<3;M=J>>>0>2147483639>>>0|(A|0)==0;N=M?0:A;A=M?0:J;c[l>>2]=N;c[t>>2]=A;J=A+8|0;c[v>>2]=J;c[w>>2]=N+(A>>3);A=B&7;if((A|0)==0){U=0}else{U=J>>>0>A>>>0?A:J}c[s>>2]=U;c[g+1108>>2]=1;if((S|0)>0){J=0;A=R;while(1){if((rcb(m,r,A)|0)<0){C=37;break a}B=J+1|0;if((B|0)<(S|0)){J=B;A=(c[u>>2]|0)+A|0}else{break}}V=c[s>>2]|0;W=c[e>>2]|0}else{V=U;W=T}A=(F+W&-8)+V|0;c[g+116240>>2]=A&7;J=A>>3;A=q-J|0;if(A>>>0>16384>>>0){yDb(c[g>>2]|0,16,1911976,(p=i,i=i+8|0,c[p>>2]=A,p)|0);i=p;C=37;break}else{c[D>>2]=A;UGb(g+99840|0,k+J|0,A)|0;C=36;break}}}while(0);if((C|0)==36){c[f>>2]=1;n=q;i=h;return n|0}else if((C|0)==37){c[g+116244>>2]=0;n=-1;i=h;return n|0}return 0}function qcb(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+116244>>2]=0;c[b+116240>>2]=0;return}function rcb(f,h,j){f=f|0;h=h|0;j=j|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0.0,Cb=0.0,Db=0.0,Eb=0.0,Fb=0.0,Gb=0.0,Hb=0.0,Ib=0.0,Jb=0.0,Kb=0.0,Lb=0.0,Mb=0.0,Nb=0.0,Ob=0.0,Pb=0.0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0.0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0.0,kc=0.0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0.0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0.0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0.0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0;l=i;i=i+112|0;m=l|0;n=l+40|0;o=l+48|0;p=f+1128|0;c[p>>2]=0;q=f+1132|0;c[q>>2]=0;r=f+56|0;s=f+1100|0;t=f+1116|0;u=f+1120|0;v=f+1112|0;w=f+1104|0;x=f+1124|0;y=f+1096|0;z=f|0;A=f+12|0;B=f+4|0;C=f+20|0;D=f+1136|0;E=f+4|0;F=f+16|0;G=E|0;H=f+384|0;I=f+60|0;J=m|0;K=m+4|0;L=m+8|0;M=m+12|0;N=m+16|0;O=m+20|0;P=m+24|0;Q=m+28|0;T=m+32|0;U=m+36|0;V=f+48|0;W=f+76|0;X=f+149016|0;Y=f+149020|0;Z=f+1138|0;_=f+1137|0;$=f+33952|0;aa=f+159312|0;ba=f+33952|0;ca=f+42144|0;da=f+64|0;ea=f+752|0;fa=f+50336|0;ga=f+159304|0;ha=f+159308|0;ia=f+50336|0;ja=f+1108|0;ka=0;a:while(1){if((c[r>>2]|0)==0){la=c[s>>2]|0;c[t>>2]=la;c[u>>2]=la;c[v>>2]=la;ma=la;na=la;oa=c[w>>2]|0}else{la=c[w>>2]|0;pa=la-1|0;qa=pa>>>0>65535>>>0;ra=qa?pa>>>16:pa;pa=qa?16:0;if((ra&65280|0)==0){sa=pa;ta=ra}else{sa=pa|8;ta=ra>>>8}ra=(d[1191992+ta|0]|0)+sa|0;pa=ra+1|0;if((c[ja>>2]|0)==0){c[u>>2]=c[v>>2];qa=c[t>>2]|0;c[v>>2]=qa;ua=qa;va=c[A>>2]|0;wa=c[C>>2]|0;xa=c[B>>2]|0;ya=31-ra|0}else{c[ja>>2]=0;qa=c[A>>2]|0;za=c[C>>2]|0;Aa=c[B>>2]|0;Ba=Aa+(qa>>>3)|0;Ca=31-ra|0;Da=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(qa&7)>>>(Ca>>>0);Ba=qa+pa|0;qa=za>>>0>Ba>>>0?Ba:za;c[A>>2]=qa;if((Da|0)>=(la|0)){Ea=7;break}Fa=c[s>>2]|0;c[u>>2]=Fa-Da;Ba=Aa+(qa>>>3)|0;Ga=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(qa&7)>>>(Ca>>>0);Ba=qa+pa|0;qa=za>>>0>Ba>>>0?Ba:za;c[A>>2]=qa;if((Ga|0)>=(la|0)){Ea=9;break}Ba=Fa-Ga|0;c[v>>2]=Ba;ua=Ba;va=qa;wa=za;xa=Aa;ya=Ca}Ca=xa+(va>>>3)|0;Ha=(fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(va&7)>>>(ya>>>0);Ca=va+pa|0;c[A>>2]=wa>>>0>Ca>>>0?Ca:wa;if((Ha|0)>=(la|0)){Ea=13;break}Ca=c[s>>2]|0;c[t>>2]=Ca-Ha;ma=Ca;na=ua;oa=la}la=ma-na|0;if((la|0)>=(oa|0)){Ea=17;break}Ca=1<<na;c[x>>2]=Ca;Ia=c[z>>2]|0;if((ka+Ca|0)>(c[y>>2]|0)){Ea=19;break}Ca=Ia+416|0;pa=c[Ca>>2]|0;if((pa|0)==2){Aa=c[A>>2]|0;za=d[(c[B>>2]|0)+(Aa>>>3)|0]<<(Aa&7)>>>7;c[A>>2]=((Aa|0)<(c[C>>2]|0))+Aa;a[D]=za&1;Ja=c[Ca>>2]|0}else{Ja=pa}do{if((Ja|0)>0){pa=0;Ca=0;do{za=c[A>>2]|0;Aa=d[(c[B>>2]|0)+(za>>>3)|0]<<(za&7)>>>7;c[A>>2]=((za|0)<(c[C>>2]|0))+za;za=Aa&1;a[f+1137+pa|0]=za;Ca=za|Ca;pa=pa+1|0;Ka=c[z>>2]|0;}while((pa|0)<(c[Ka+416>>2]|0));pa=(c[s>>2]|0)-(c[v>>2]|0)|0;if((Ca|0)==0){La=Ka;Ma=pa;Na=Ka;break}za=c[F>>2]|0;Aa=1;qa=c[A>>2]|0;do{if((za-qa|0)<7){Ea=27;break a}Ba=c[C>>2]|0;ra=(c[G>>2]|0)+(qa>>>3)|0;Oa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(qa&7)>>>25;ra=qa+7|0;qa=Ba>>>0>ra>>>0?ra:Ba;c[A>>2]=qa;Aa=Oa+Aa|0;}while((Oa|0)==127);qa=jcb(Aa)|0;za=f+388+(pa<<2)|0;Ca=(c[za>>2]|0)-(c[H>>2]|0)|0;Oa=c[z>>2]|0;Ba=c[Oa+416>>2]|0;do{if((Ba|0)>0){ra=0;do{c[n+(ra<<2)>>2]=Ca;ra=ra+1|0;}while((ra|0)<(Ba|0));if((c[da>>2]|0)==0){Pa=Oa;Qa=Oa;Ra=Ba;break}ra=f+408+(pa<<2)|0;Sa=0;Ta=Oa;while(1){do{if((a[f+1137+Sa|0]|0)==0){Ua=Ta}else{Va=c[ra>>2]|0;if((Va|0)<=0){Ua=Ta;break}Wa=n+(Sa<<2)|0;Xa=0;do{Ya=c[A>>2]|0;Za=d[(c[G>>2]|0)+(Ya>>>3)|0]<<(Ya&7)>>>7;c[A>>2]=((Ya|0)<(c[C>>2]|0))+Ya;Ya=Za&1;c[f+768+(Sa<<6)+(Xa<<2)>>2]=Ya;if((Ya|0)!=0){c[Wa>>2]=(c[Wa>>2]|0)-(c[f+428+(pa<<6)+(Xa<<2)>>2]|0)}Xa=Xa+1|0;}while((Xa|0)<(Va|0));Ua=c[z>>2]|0}}while(0);Va=Sa+1|0;_a=c[Ua+416>>2]|0;if((Va|0)<(_a|0)){Sa=Va;Ta=Ua}else{break}}if((_a|0)>0){$a=0;ab=Ua;bb=Ua}else{Pa=Ua;Qa=Ua;Ra=_a;break}while(1){do{if((a[f+1137+$a|0]|0)==0){cb=ab;db=bb}else{Ta=c[ra>>2]|0;if((Ta|0)>0){eb=-2147483648;fb=0}else{cb=ab;db=bb;break}while(1){if((c[f+768+($a<<6)+(fb<<2)>>2]|0)==0){gb=eb}else{if((eb|0)==-2147483648){Sa=c[A>>2]|0;Va=c[C>>2]|0;Xa=(c[G>>2]|0)+(Sa>>>3)|0;Wa=(fe(d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0)|0)<<(Sa&7)>>>25;Xa=Sa+7|0;c[A>>2]=Va>>>0>Xa>>>0?Xa:Va;hb=Wa-19|0}else{Wa=c[ea>>2]|0;Va=c[A>>2]|0;Xa=c[C>>2]|0;Sa=c[G>>2]|0;Ya=Sa+(Va>>>3)|0;Za=(fe(d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0)|0)<<(Va&7)>>>23;Ya=b[Wa+(Za<<2)>>1]|0;ib=b[Wa+(Za<<2)+2>>1]|0;Za=ib<<16>>16;if(ib<<16>>16<0){ib=Va+9|0;jb=Xa>>>0>ib>>>0?ib:Xa;ib=Sa+(jb>>>3)|0;Sa=((fe(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)|0)<<(jb&7)>>>((Za+32|0)>>>0))+Ya|0;kb=b[Wa+(Sa<<2)+2>>1]|0;lb=b[Wa+(Sa<<2)>>1]|0;mb=jb}else{kb=Za;lb=Ya;mb=Va}Va=kb+mb|0;c[A>>2]=Xa>>>0>Va>>>0?Va:Xa;if((lb|0)<0){Ea=50;break a}hb=eb-18+lb|0}c[f+896+($a<<6)+(fb<<2)>>2]=hb;gb=hb}Xa=fb+1|0;if((Xa|0)<(Ta|0)){eb=gb;fb=Xa}else{break}}Ta=c[z>>2]|0;cb=Ta;db=Ta}}while(0);Ta=$a+1|0;Xa=c[cb+416>>2]|0;if((Ta|0)<(Xa|0)){$a=Ta;ab=cb;bb=db}else{Pa=cb;Qa=db;Ra=Xa;break}}}else{Pa=Oa;Qa=Oa;Ra=Ba}}while(0);if((c[v>>2]|0)==(c[s>>2]|0)){nb=Ra;Ea=58}else{Ba=c[A>>2]|0;Oa=d[(c[G>>2]|0)+(Ba>>>3)|0]|0;c[A>>2]=((Ba|0)<(c[C>>2]|0))+Ba;Ca=c[Pa+416>>2]|0;if((Oa&128>>>((Ba&7)>>>0)|0)==0){ob=Pa;pb=Qa;qb=Ca;Ea=59}else{nb=Ca;Ea=58}}do{if((Ea|0)==58){Ea=0;if((nb|0)>0){rb=0;sb=Pa;tb=Qa}else{ub=nb;vb=Qa;wb=Pa;Ea=60;break}while(1){if((a[f+1137+rb|0]|0)==0){xb=sb;yb=tb}else{if((c[I>>2]|0)==0){Ca=c[C>>2]|0;Ba=c[B>>2]|0;Oa=0;ra=c[A>>2]|0;while(1){Xa=Ba+(ra>>>3)|0;Ta=(fe(d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0)|0)<<(ra&7);if((Oa|0)==0|(Oa|0)>7){Xa=ra+3|0;zb=Ta>>>29;Ab=Ca>>>0>Xa>>>0?Xa:Ca}else{Xa=ra+4|0;zb=Ta>>>28;Ab=Ca>>>0>Xa>>>0?Xa:Ca}c[A>>2]=Ab;g[m+(Oa<<2)>>2]=+g[1081720+(Oa<<6)+(zb<<2)>>2];Xa=Oa+1|0;if((Xa|0)<10){Oa=Xa;ra=Ab}else{break}}ra=f+17536+(rb<<2)|0;Oa=c[x>>2]|0;if((Oa|0)>0){Bb=+g[J>>2];Cb=+g[K>>2];Db=+g[L>>2];Eb=+g[M>>2];Fb=+g[N>>2];Gb=+g[O>>2];Hb=+g[P>>2];Ib=+g[Q>>2];Jb=+g[T>>2];Kb=+g[U>>2];Ca=0;Lb=0.0;while(1){Mb=+g[f+149024+(Ca<<2)>>2];Nb=(Mb-Jb)*(Mb-Hb)*(Mb-Fb)*(Mb-Db)*(Mb-Bb)*.5;Ob=(Mb-Kb)*(Mb-Ib)*(Mb-Gb)*(Mb-Eb)*(Mb-Cb)*.5;Ba=(g[k>>2]=Nb*(Mb+2.0)*Nb+Ob*(2.0-Mb)*Ob,c[k>>2]|0);Xa=Ba>>>16&127;Ob=+g[f+157216+(Ba>>>23<<2)>>2]*(+g[f+158240+(Xa<<2)>>2]+ +g[f+158752+(Xa<<2)>>2]*(c[k>>2]=Ba<<7&8388480|1065353216,+g[k>>2]));Mb=Ob>Lb?Ob:Lb;g[f+1152+(rb<<13)+(Ca<<2)>>2]=Ob;Ba=Ca+1|0;if((Ba|0)<(Oa|0)){Ca=Ba;Lb=Mb}else{Pb=Mb;break}}}else{Pb=0.0}g[ra>>2]=Pb}else{Ca=(c[s>>2]|0)-(c[v>>2]|0)|0;Oa=f+112+(Ca*50|0)|0;Ba=f+1152+(rb<<13)|0;Xa=f+1152+(rb<<13)+(c[x>>2]<<2)|0;do{if((c[V>>2]|0)==1){Ta=c[A>>2]|0;Va=c[C>>2]|0;Ya=(c[B>>2]|0)+(Ta>>>3)|0;Za=(fe(d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0)|0)<<(Ta&7)>>>27;Ya=Ta+5|0;c[A>>2]=Va>>>0>Ya>>>0?Ya:Va;Va=Za+10|0;Lb=+g[562584+(Za+70<<2)>>2];Cb=+Lb;Za=f+112+(Ca*50|0)+2|0;Ya=e[Oa>>1]|0;Ta=Ya&3;if((Ta|0)==2){Qb=Ya;Rb=Ba;Ea=67}else if((Ta|0)==0){Sb=Ya;Tb=Ba;Ea=65}else if((Ta|0)==3){Ub=Ya;Vb=Ba;Ea=66}else if((Ta|0)==1){Wb=Ya;Xb=Ba;Ea=68}else{Yb=Va;Zb=Ba;_b=Lb;$b=Za;break}while(1){if((Ea|0)==65){Ea=0;g[Tb>>2]=Cb;Ub=Sb;Vb=Tb+4|0;Ea=66;continue}else if((Ea|0)==66){Ea=0;g[Vb>>2]=Cb;Qb=Ub;Rb=Vb+4|0;Ea=67;continue}else if((Ea|0)==67){Ea=0;g[Rb>>2]=Cb;Wb=Qb;Xb=Rb+4|0;Ea=68;continue}else if((Ea|0)==68){Ea=0;Ya=Xb+4|0;g[Xb>>2]=Cb;Ta=Wb-4|0;if((Ta|0)>0){Sb=Ta;Tb=Ya;Ea=65;continue}else{Yb=Va;Zb=Ya;_b=Lb;$b=Za;break}}}}else{Yb=36;Zb=Ba;_b=0.0;$b=Oa}}while(0);if(Zb>>>0<Xa>>>0){Oa=c[B>>2]|0;Ba=c[W>>2]|0;Ca=$b;Lb=_b;ra=Zb;Za=Yb;while(1){Va=c[C>>2]|0;Ya=Za;Cb=Lb;Ta=Ca;jb=c[A>>2]|0;while(1){Sa=Oa+(jb>>>3)|0;Wa=(fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(jb&7)>>>24;Sa=b[Ba+(Wa<<2)>>1]|0;ib=b[Ba+(Wa<<2)+2>>1]|0;Wa=ib<<16>>16;do{if(ib<<16>>16<0){ac=jb+8|0;bc=Va>>>0>ac>>>0?ac:Va;ac=Oa+(bc>>>3)|0;cc=((fe(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(bc&7)>>>((Wa+32|0)>>>0))+Sa|0;ac=b[Ba+(cc<<2)>>1]|0;dc=b[Ba+(cc<<2)+2>>1]|0;cc=dc<<16>>16;if(!(dc<<16>>16<0)){ec=cc;fc=ac;gc=bc;break}dc=bc-Wa|0;bc=Va>>>0>dc>>>0?dc:Va;dc=Oa+(bc>>>3)|0;hc=((fe(d[dc]|d[dc+1|0]<<8|d[dc+2|0]<<16|d[dc+3|0]<<24|0)|0)<<(bc&7)>>>((cc+32|0)>>>0))+ac|0;ec=b[Ba+(hc<<2)+2>>1]|0;fc=b[Ba+(hc<<2)>>1]|0;gc=bc}else{ec=Wa;fc=Sa;gc=jb}}while(0);Sa=ec+gc|0;Wa=Va>>>0>Sa>>>0?Sa:Va;c[A>>2]=Wa;if((fc|0)<0){Ea=79;break a}ic=Ya-60+fc|0;Sa=fc+Ya|0;if(Sa>>>0>155>>>0){Ea=80;break a}Eb=+g[562584+(Sa<<2)>>2];jc=+Eb;kc=Eb>Cb?Eb:Cb;lc=Ta+2|0;Sa=e[Ta>>1]|0;ib=Sa&3;if((ib|0)==3){mc=Sa;nc=ra;Ea=82;break}else if((ib|0)==2){oc=Sa;pc=ra;Ea=83;break}else if((ib|0)==0){qc=Sa;rc=ra;Ea=81;break}else if((ib|0)==1){sc=Sa;tc=ra;Ea=84;break}else{Ya=ic;Cb=kc;Ta=lc;jb=Wa}}while(1){if((Ea|0)==81){Ea=0;g[rc>>2]=jc;mc=qc;nc=rc+4|0;Ea=82;continue}else if((Ea|0)==82){Ea=0;g[nc>>2]=jc;oc=mc;pc=nc+4|0;Ea=83;continue}else if((Ea|0)==83){Ea=0;g[pc>>2]=jc;sc=oc;tc=pc+4|0;Ea=84;continue}else if((Ea|0)==84){Ea=0;uc=tc+4|0;g[tc>>2]=jc;jb=sc-4|0;if((jb|0)>0){qc=jb;rc=uc;Ea=81;continue}else{break}}}if(uc>>>0<Xa>>>0){Ca=lc;Lb=kc;ra=uc;Za=ic}else{vc=kc;break}}}else{vc=_b}g[f+17536+(rb<<2)>>2]=vc}c[f+1140+(rb<<2)>>2]=pa;Za=c[z>>2]|0;xb=Za;yb=Za}Za=rb+1|0;ra=c[xb+416>>2]|0;if((Za|0)<(ra|0)){rb=Za;sb=xb;tb=yb}else{ob=xb;pb=yb;qb=ra;Ea=59;break}}}}while(0);do{if((Ea|0)==59){Ea=0;if((qb|0)>0){wc=0;xc=pb}else{ub=qb;vb=pb;wb=ob;Ea=60;break}while(1){if((a[f+1137+wc|0]|0)==0){yc=xc}else{ra=f+17544+(wc<<13)|0;if((wc|0)==1){zc=(a[D]|0)!=0|0}else{zc=0}TGb(ra|0,0,c[x>>2]<<2|0)|0;mcb(c[z>>2]|0,E,f+1024+(zc*20|0)|0,c[f+1072+(zc<<2)>>2]|0,c[f+1064+(zc<<2)>>2]|0,0,ra,0,c[n+(wc<<2)>>2]|0,c[x>>2]|0,c[s>>2]|0,qa)|0;yc=c[z>>2]|0}ra=c[V>>2]|0;Za=yc+416|0;do{if((ra|0)==1){if((c[Za>>2]|0)<=1){break}Ca=c[A>>2]|0;Xa=-Ca&7;if((Xa|0)==0){break}Ba=c[C>>2]|0;Oa=Xa+Ca|0;c[A>>2]=Ba>>>0>Oa>>>0?Oa:Ba}}while(0);Ba=wc+1|0;Oa=c[Za>>2]|0;if((Ba|0)<(Oa|0)){wc=Ba;xc=yc}else{Ac=yc;Bc=Oa;Cc=ra;Dc=yc;break}}}}while(0);if((Ea|0)==60){Ea=0;Ac=wb;Bc=ub;Cc=c[V>>2]|0;Dc=vb}qa=(c[x>>2]|0)/2|0;Lb=1.0/+(qa|0);if((Cc|0)==1){Ec=Lb*+R(+(qa|0))}else{Ec=Lb}if((Bc|0)>0){Lb=+(Aa|0)*.05;qa=f+408+(pa<<2)|0;Oa=f+364+(pa<<2)|0;Ba=-1<<pa;Ca=0;Xa=Ac;jb=ba;Ta=Dc;while(1){Ya=f+33952+(Ca<<13)|0;Va=Ya;Wa=jb;do{if((a[f+1137+Ca|0]|0)==0){Fc=Xa;Gc=Ta}else{Sa=f+17544+(Ca<<13)|0;ib=c[f+1140+(Ca<<2)>>2]|0;Cb=+S(+10.0,+Lb);bc=f+17536+(Ca<<2)|0;Eb=Ec*(Cb/+g[bc>>2]);hc=c[H>>2]|0;ac=(hc|0)>0;if((c[da>>2]|0)==0){if(ac){cc=(hc|0)>1?hc<<2:4;TGb(Va|0,0,cc|0)|0;Hc=Wa+cc|0}else{Hc=Ya}cc=c[n+(Ca<<2)>>2]|0;if((cc|0)>0){dc=Hc;Ic=0;while(1){g[dc>>2]=Eb*+g[f+17544+(Ca<<13)+(Ic<<2)>>2]*+g[f+1152+(Ca<<13)+(Ic<<pa>>ib<<2)>>2];Jc=Ic+1|0;if((Jc|0)<(cc|0)){dc=dc+4|0;Ic=Jc}else{break}}Kc=Hc+(cc<<2)|0}else{Kc=Hc}Ic=(c[x>>2]|0)-(c[za>>2]|0)|0;if((Ic|0)>0){TGb(Kc|0,0,Ic<<2|0)|0}Ic=c[z>>2]|0;Fc=Ic;Gc=Ic;break}if(ac){Ic=jb+(hc<<2)|0;dc=Ya;ra=0;Za=c[X>>2]|0;while(1){g[dc>>2]=Eb*+g[f+116248+(Za<<2)>>2]*+g[f+1152+(Ca<<13)+(ra<<pa>>ib<<2)>>2];Jc=Za+1&8191;c[X>>2]=Jc;Lc=ra+1|0;if((Lc|0)<(hc|0)){dc=dc+4|0;ra=Lc;Za=Jc}else{Mc=Ic;break}}}else{Mc=Ya}Ic=c[qa>>2]|0;if((Ic|0)>0){Za=(c[s>>2]|0)-(c[v>>2]|0)|0;ra=f+1152+(Ca<<13)+(c[Oa>>2]<<pa>>ib<<2)|0;dc=0;ac=0;while(1){cc=c[f+428+(Za<<6)+(dc<<2)>>2]|0;if((c[f+768+(Ca<<6)+(dc<<2)>>2]|0)==0){Nc=ac}else{if((cc|0)>0){Jc=0;Cb=0.0;while(1){Gb=+g[ra+(Jc<<pa>>ib<<2)>>2];Ib=Cb+Gb*Gb;Lc=Jc+1|0;if((Lc|0)<(cc|0)){Jc=Lc;Cb=Ib}else{Oc=Ib;break}}}else{Oc=0.0}g[o+(dc<<2)>>2]=Oc/+(cc|0);Nc=dc}Jc=dc+1|0;if((Jc|0)<(Ic|0)){ra=ra+(cc<<pa>>ib<<2)|0;dc=Jc;ac=Nc}else{Pc=Nc;break}}}else{Pc=0}ac=f+1152+(Ca<<13)+(hc<<pa>>ib<<2)|0;if((Ic|0)>-1){dc=o+(Pc<<2)|0;ra=Sa;Za=Mc;Jc=ac;Lc=-1;while(1){do{if((Lc|0)<0){Qc=(c[Oa>>2]|0)-hc|0;Ea=128}else{Rc=c[f+428+((c[s>>2]|0)-(c[v>>2]|0)<<6)+(Lc<<2)>>2]|0;if((c[f+768+(Ca<<6)+(Lc<<2)>>2]|0)==0){Qc=Rc;Ea=128;break}Cb=+R(+g[o+(Lc<<2)>>2]/+g[dc>>2]);Ib=Cb*+S(+10.0,+(+(c[f+896+(Ca<<6)+(Lc<<2)>>2]|0)*.05));Cb=Ec*(Ib/(+g[bc>>2]*+g[Y>>2]));if((Rc|0)<=0){Sc=Za;Tc=ra;Uc=Rc;break}Vc=Za;Wc=0;Xc=c[X>>2]|0;while(1){Ib=+g[f+116248+(Xc<<2)>>2];Yc=Xc+1&8191;c[X>>2]=Yc;g[Vc>>2]=Cb*Ib*+g[Jc+(Wc<<pa>>ib<<2)>>2];Zc=Wc+1|0;if((Zc|0)<(Rc|0)){Vc=Vc+4|0;Wc=Zc;Xc=Yc}else{break}}Sc=Za+(Rc<<2)|0;Tc=ra;Uc=Rc}}while(0);do{if((Ea|0)==128){Ea=0;if((Qc|0)<=0){Sc=Za;Tc=ra;Uc=Qc;break}cc=ra;Xc=Za;Wc=0;Vc=c[X>>2]|0;while(1){Cb=+g[f+116248+(Vc<<2)>>2];Yc=Vc+1&8191;c[X>>2]=Yc;g[Xc>>2]=Eb*(Cb+ +g[cc>>2])*+g[Jc+(Wc<<pa>>ib<<2)>>2];Zc=Wc+1|0;if((Zc|0)<(Qc|0)){cc=cc+4|0;Xc=Xc+4|0;Wc=Zc;Vc=Yc}else{break}}Sc=Za+(Qc<<2)|0;Tc=ra+(Qc<<2)|0;Uc=Qc}}while(0);Vc=Jc+(Uc<<pa>>ib<<2)|0;Wc=Lc+1|0;if((Wc|0)<(Ic|0)){ra=Tc;Za=Sc;Jc=Vc;Lc=Wc}else{_c=Sc;$c=Vc;break}}}else{_c=Mc;$c=ac}Lc=(c[x>>2]|0)-(c[za>>2]|0)|0;Cb=Eb*+g[$c+(Ba>>ib<<2)>>2];if((Lc|0)<=0){Fc=Xa;Gc=Ta;break}Jc=_c;Za=0;ra=c[X>>2]|0;while(1){g[Jc>>2]=Cb*+g[f+116248+(ra<<2)>>2];Ic=ra+1&8191;c[X>>2]=Ic;bc=Za+1|0;if((bc|0)<(Lc|0)){Jc=Jc+4|0;Za=bc;ra=Ic}else{Fc=Xa;Gc=Ta;break}}}}while(0);Ya=Ca+1|0;if((Ya|0)<(c[Fc+416>>2]|0)){Ca=Ya;Xa=Fc;jb=jb+8192|0;Ta=Gc}else{ad=Fc;bd=Gc;break}}}else{ad=Ac;bd=Dc}if((a[D]|0)==0){La=ad;Ma=pa;Na=bd;break}if((a[Z]|0)==0){La=ad;Ma=pa;Na=bd;break}Ta=c[x>>2]|0;if((a[_]|0)==0){TGb($|0,0,Ta<<2|0)|0;a[_]=1}Xe[c[aa>>2]&4095](ba,ca,Ta);Ta=c[z>>2]|0;La=Ta;Ma=pa;Na=Ta}else{La=Ia;Ma=la;Na=Ia}}while(0);la=f+66720+(Ma<<6)|0;if((c[La+416>>2]|0)>0){Ta=f+66720+(Ma<<6)+40|0;jb=0;while(1){Xa=c[x>>2]|0;do{if((a[f+1137+jb|0]|0)==0){if((a[D]|0)!=0&(jb|0)==1){break}TGb(fa|0,0,16384)|0}else{Xe[c[Ta>>2]&4095](la,ia,f+33952+(jb<<13)|0)}}while(0);pa=(c[q>>2]|0)+((c[y>>2]|0)/2|0)+((Xa|0)/-2|0)|0;Ca=f+67072+(jb<<14)+(pa<<2)|0;Ba=c[v>>2]|0;za=c[u>>2]|0;if((Ba|0)>(za|0)){Oa=1<<za;qa=((c[x>>2]|0)-Oa|0)/2|0;Aa=f+67072+(jb<<14)+(qa+pa<<2)|0;le[c[ga>>2]&1023](Aa,f+50336+(qa<<2)|0,c[f+67040+((c[s>>2]|0)-za<<2)>>2]|0,Aa,Oa);Aa=qa+Oa|0;UGb(f+67072+(jb<<14)+(Aa+pa<<2)|0,f+50336+(Aa<<2)|0,qa<<2)|0}else{le[c[ga>>2]&1023](Ca,ia,c[f+67040+((c[s>>2]|0)-Ba<<2)>>2]|0,Ca,c[x>>2]|0)}Ca=c[x>>2]|0;Ba=f+67072+(jb<<14)+(Ca+pa<<2)|0;qa=f+50336+(Ca<<2)|0;Aa=c[v>>2]|0;Oa=c[t>>2]|0;if((Aa|0)>(Oa|0)){za=1<<Oa;Ya=(Ca-za|0)/2|0;Wa=(c[s>>2]|0)-Oa|0;Oa=Ya<<2;UGb(Ba|0,qa|0,Oa)|0;Va=Ya+Ca|0;cf[c[ha>>2]&1023](f+67072+(jb<<14)+(Va+pa<<2)|0,f+50336+(Va<<2)|0,c[f+67040+(Wa<<2)>>2]|0,za);TGb(f+67072+(jb<<14)+(za+pa+Va<<2)|0,0,Oa|0)|0}else{cf[c[ha>>2]&1023](Ba,qa,c[f+67040+((c[s>>2]|0)-Aa<<2)>>2]|0,Ca)}Ca=jb+1|0;Aa=c[z>>2]|0;if((Ca|0)<(c[Aa+416>>2]|0)){jb=Ca}else{cd=Aa;break}}}else{cd=Na}c[p>>2]=(c[p>>2]|0)+1;jb=(c[q>>2]|0)+(c[x>>2]|0)|0;c[q>>2]=jb;dd=c[y>>2]|0;if((jb|0)<(dd|0)){ka=jb}else{Ea=167;break}}if((Ea|0)==7){yDb(c[z>>2]|0,16,1891456,(ed=i,i=i+8|0,c[ed>>2]=(c[s>>2]|0)-Da,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==9){yDb(c[z>>2]|0,16,2349008,(ed=i,i=i+8|0,c[ed>>2]=Fa-Ga,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==13){yDb(c[z>>2]|0,16,2328800,(ed=i,i=i+8|0,c[ed>>2]=(c[s>>2]|0)-Ha,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==17){yDb(c[z>>2]|0,16,2304384,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==19){yDb(Ia,16,2286512,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==27){yDb(Ka,16,2270512,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==50){yDb(c[z>>2]|0,16,2255168,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==79){yDb(sb,16,2240792,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==80){yDb(sb,16,2228712,(ed=i,i=i+8|0,c[ed>>2]=ic,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==167){if((c[cd+416>>2]|0)>0){gd=0;hd=dd}else{fd=0;i=l;return fd|0}while(1){dd=f+67072+(gd<<14)|0;UGb((c[h+(gd<<2)>>2]|0)+(j<<2)|0,dd|0,hd<<2)|0;cd=c[y>>2]|0;VGb(dd|0,f+67072+(gd<<14)+(cd<<2)|0,cd<<2|0)|0;cd=gd+1|0;if((cd|0)>=(c[(c[z>>2]|0)+416>>2]|0)){fd=0;break}gd=cd;hd=c[y>>2]|0}i=l;return fd|0}return 0}function scb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=c[b+60>>2]|0;c[e>>2]=b;f=b+416|0;g=c[f>>2]|0;if((g|0)>2){yDb(b,16,2286464,(h=i,i=i+16|0,c[h>>2]=g,c[h+8>>2]=2,h)|0);i=h;j=-22;i=d;return j|0}g=b+412|0;k=c[g>>2]|0;if((k|0)>48e3){yDb(b,16,2270472,(h=i,i=i+8|0,c[h>>2]=k,h)|0);i=h;j=-22;i=d;return j|0}k=b+72|0;l=c[k>>2]|0;if((l|0)<24e3){yDb(b,16,2255120,(h=i,i=i+8|0,c[h>>2]=l,h)|0);i=h;j=-22;i=d;return j|0}l=c[(c[b+12>>2]|0)+12>>2]|0;if((l|0)==86023){m=WDb(4)|0;c[b+100>>2]=4;n=m;x=0;a[n]=x;x=x>>8;a[n+1|0]=x;n=m+2|0;x=1;a[n]=x;x=x>>8;a[n+1|0]=x;o=m}else if((l|0)==86024){l=cEb(10)|0;c[b+100>>2]=10;m=l;x=0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+4|0;x=1;a[m]=x;x=x>>8;a[m+1|0]=x;o=l}else{yDb(0,0,1963304,(h=i,i=i+24|0,c[h>>2]=2328792,c[h+8>>2]=1911952,c[h+16>>2]=69,h)|0);i=h;Cd();return 0}c[b+96>>2]=o;c[e+60>>2]=1;c[e+52>>2]=0;c[e+56>>2]=0;if((c[f>>2]|0)==2){a[e+1136|0]=1}hcb(b,1)|0;f=e+1104|0;if((c[f>>2]|0)>0){o=e+66720|0;h=e+1100|0;l=0;do{aLa(o+(l<<6)|0,1-l+(c[h>>2]|0)|0,0,1.0)|0;l=l+1|0;}while((l|0)<(c[f>>2]|0))}f=c[k>>2]|0;k=e+1096|0;e=c[k>>2]|0;l=gHb(e,(e|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=c[g>>2]<<3;g=eHb(l,F,f,(f|0)<0|0?-1:0)|0;f=g;c[b+432>>2]=(f|0)>16384?16384:f;f=c[k>>2]|0;c[b+116>>2]=f;c[b+424>>2]=f;j=0;i=d;return j|0}function tcb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0.0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;i=i+8|0;j=h|0;k=c[b+60>>2]|0;l=k;m=c[k+1100>>2]|0;c[k+1112>>2]=m;n=1<<m;m=k+1124|0;c[m>>2]=n;o=c[e+64>>2]|0;p=c[e+76>>2]|0;q=k+66720|0;r=c[k+67040>>2]|0;s=65536.0/+(n|0);t=b+416|0;if((c[t>>2]|0)>0){u=k+50336|0;v=k+67072|0;w=n<<2;y=k+159292|0;z=k+159308|0;A=u+(n<<2)|0;n=k+159284|0;B=k+66768|0;C=k+33952|0;D=u;E=0;do{G=v+(E<<14)|0;UGb(u|0,G|0,w)|0;H=G|0;te[c[y>>2]&7](H,c[o+(E<<2)>>2]|0,s,p);cf[c[z>>2]&1023](A,H,r,p);cf[c[n>>2]&1023](H,H,r,p);Xe[c[B>>2]&4095](q,C+(E<<13)|0,D);E=E+1|0;}while((E|0)<(c[t>>2]|0))}do{if((a[k+1136|0]|0)!=0){if((c[m>>2]|0)<=0){break}t=k+33952|0;E=k+42144|0;D=0;do{C=t+(D<<2)|0;s=+g[C>>2]*.5;q=E+(D<<2)|0;I=+g[q>>2]*.5;g[C>>2]=s+I;g[q>>2]=s-I;D=D+1|0;}while((D|0)<(c[m>>2]|0))}}while(0);m=r0a(b,d,32768,0)|0;if((m|0)<0){J=m;i=h;return J|0}m=k+33952|0;D=d+24|0;E=d+28|0;t=(ucb(l,m,c[D>>2]|0,c[E>>2]|0,64)|0)<1;q=t?64:128;t=q-32|0;C=(ucb(l,m,c[D>>2]|0,c[E>>2]|0,t)|0)<1;B=C?t:q;q=B-16|0;t=(ucb(l,m,c[D>>2]|0,c[E>>2]|0,q)|0)<1;C=t?q:B;B=C-8|0;q=(ucb(l,m,c[D>>2]|0,c[E>>2]|0,B)|0)<1;t=q?B:C;C=t-4|0;B=(ucb(l,m,c[D>>2]|0,c[E>>2]|0,C)|0)<1;q=B?C:t;t=q-2|0;C=(ucb(l,m,c[D>>2]|0,c[E>>2]|0,t)|0)<1;B=C?t:q;q=B-1|0;t=ucb(l,m,c[D>>2]|0,c[E>>2]|0,q)|0;C=(t|0)<1?q:B;B=(t|0)>0;if((C|0)<129&B){t=C;while(1){C=t+1|0;q=(ucb(l,m,c[D>>2]|0,c[E>>2]|0,t)|0)>0;if((C|0)<129&q){t=C}else{K=q;break}}}else{K=B}if(K){yDb(b,16,2000232,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;c[E>>2]=0;J=-22;i=h;return J|0}K=k+28|0;B=c[K>>2]|0;t=k+32|0;D=k+36|0;m=c[D>>2]|0;l=(m-(c[t>>2]|0)<<3)+(32-B)|0;if((l&7|0)!=0){yDb(0,0,1963304,(L=i,i=i+24|0,c[L>>2]=1935168,c[L+8>>2]=1911952,c[L+16>>2]=384,L)|0);i=L;Cd();return 0}q=b+432|0;C=c[q>>2]|0;p=(l+7|0)/8|0;l=C-p|0;if(!((l|0)>-1)){yDb(0,0,1963304,(L=i,i=i+24|0,c[L>>2]=1891448,c[L+8>>2]=1911952,c[L+16>>2]=386,L)|0);i=L;Cd();return 0}r=k+24|0;if((C|0)==(p|0)){M=B;N=m}else{p=l;l=m;m=c[r>>2]|0;C=B;while(1){B=p-1|0;if((C|0)>8){O=C-8|0;P=m<<8|78;Q=l}else{k=l;x=fe(78>>>((8-C|0)>>>0)|m<<C|0)|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=(c[D>>2]|0)+4|0;c[D>>2]=k;O=C+24|0;P=78;Q=k}c[r>>2]=P;c[K>>2]=O;if((B|0)==0){M=O;N=Q;break}else{p=B;l=Q;m=P;C=O}}}if((M|0)<32){O=c[r>>2]<<M;c[r>>2]=O;M=O>>>24&255;O=N;while(1){c[D>>2]=O+1;a[O]=M;C=c[r>>2]|0;c[r>>2]=C<<8;P=(c[K>>2]|0)+8|0;c[K>>2]=P;if((P|0)>=32){break}M=C>>>16&255;O=c[D>>2]|0}R=c[D>>2]|0}else{R=N}c[K>>2]=32;c[r>>2]=0;r=R-(c[t>>2]|0)|0;if((r|0)!=(c[q>>2]|0)){yDb(0,0,1963304,(L=i,i=i+24|0,c[L>>2]=2348952,c[L+8>>2]=1911952,c[L+16>>2]=391,L)|0);i=L;Cd();return 0}L=e+136|0;e=c[L>>2]|0;t=c[L+4>>2]|0;if((e|0)==0&(t|0)==(-2147483648|0)){S=r}else{r=c[b+116>>2]|0;c[j>>2]=1;c[j+4>>2]=c[b+412>>2];L=KDb(r,(r|0)<0|0?-1:0,j,b+104|0)|0;b=ZGb(e,t,L,F)|0;L=d+8|0;c[L>>2]=b;c[L+4>>2]=F;S=c[q>>2]|0}c[E>>2]=S;c[f>>2]=1;J=0;i=h;return J|0}function ucb(b,f,h,j,k){b=b|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0.0,D=0.0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0.0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;l=i;i=i+8|0;m=l|0;n=b+24|0;o=(j|0)<0;p=o?0:h;h=o?0:j;c[b+44>>2]=h<<3;j=b+32|0;c[j>>2]=p;c[b+40>>2]=p+h;h=b+36|0;c[h>>2]=p;p=b+28|0;c[p>>2]=32;o=n|0;c[o>>2]=0;if((c[b+52>>2]|0)!=0){yDb(0,0,1963304,(q=i,i=i+24|0,c[q>>2]=2328792,c[q+8>>2]=1911952,c[q+16>>2]=332,q)|0);i=q;Cd();return 0}if((c[b+56>>2]|0)!=0){yDb(0,0,1963304,(q=i,i=i+24|0,c[q>>2]=2328792,c[q+8>>2]=1911952,c[q+16>>2]=171,q)|0);i=q;Cd();return 0}r=b+1100|0;s=c[r>>2]|0;c[b+1116>>2]=s;c[b+1120>>2]=s;t=b+1112|0;c[t>>2]=s;u=1<<s;s=b+1124|0;c[s>>2]=u;v=b+384|0;w=(c[b+388>>2]|0)-(c[v>>2]|0)|0;y=b|0;z=c[y>>2]|0;A=c[z+416>>2]|0;if((A|0)>0){B=0;do{c[m+(B<<2)>>2]=w;B=B+1|0;}while((B|0)<(A|0))}B=(u|0)/2|0;C=1.0/+(B|0);u=b+48|0;if((c[u>>2]|0)==1){D=C*+R(+(B|0))}else{D=C}if((A|0)==2){c[b+24>>2]=(a[b+1136|0]|0)!=0;c[p>>2]=31;E=c[z+416>>2]|0}else{E=A}a:do{if((E|0)>0){A=0;do{a[b+1137+A|0]=1;z=c[s>>2]|0;B=b+1152+(A<<13)+(z<<2)|0;if((z|0)>0){z=b+112+(((c[r>>2]|0)-(c[t>>2]|0)|0)*50|0)|0;w=b+1152+(A<<13)|0;C=0.0;F=1343032;while(1){G=+S(+10.0,+(+(c[F>>2]|0)*.0625));H=e[z>>1]|0;I=w;J=H;while(1){g[I>>2]=G;K=J-1|0;if((K|0)==0){break}else{I=I+4|0;J=K}}L=C>G?C:G;J=w+(H<<2)|0;if(J>>>0<B>>>0){z=z+2|0;w=J;C=L;F=F+4|0}else{M=L;break}}}else{M=0.0}g[b+17536+(A<<2)>>2]=M;A=A+1|0;N=c[y>>2]|0;O=c[N+416>>2]|0;}while((A|0)<(O|0));if((O|0)<=0){break}C=+(k|0)*.05;A=0;F=N;b:while(1){do{if((a[b+1137+A|0]|0)==0){P=F}else{L=+S(+10.0,+C);Q=D*(L/+g[b+17536+(A<<2)>>2]);w=c[m+(A<<2)>>2]|0;if((w|0)<=0){P=F;break}z=0;B=f+(A<<13)+(c[v>>2]<<2)|0;while(1){L=+g[B>>2]/(Q*+g[b+1152+(A<<13)+(z<<2)>>2]);if(L<-32768.0|L>32767.0){T=2147483647;U=117;break b}g[b+17544+(A<<13)+(z<<2)>>2]=+(Gc(+L)|0);J=z+1|0;if((J|0)<(w|0)){z=J;B=B+4|0}else{break}}P=c[y>>2]|0}}while(0);B=A+1|0;V=c[P+416>>2]|0;if((B|0)<(V|0)){A=B;F=P}else{break}}if((U|0)==117){i=l;return T|0}if((V|0)<=0){break}F=b+24|0;A=0;B=0;z=c[F>>2]|0;w=c[p>>2]|0;H=P;while(1){J=d[b+1137+A|0]|0;if((w|0)>1){W=w-1|0;X=J|z<<1;Y=H}else{I=fe(J>>>((1-w|0)>>>0)|z<<w|0)|0;K=c[h>>2]|0;x=I;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;W=w+31|0;X=J;Y=c[y>>2]|0}c[F>>2]=X;c[p>>2]=W;Z=J|B;J=A+1|0;if((J|0)<(c[Y+416>>2]|0)){A=J;B=Z;z=X;w=W;H=Y}else{break}}if((Z|0)==0){break}H=k-1|0;w=(W|0)>7;if((H|0)>126){z=k-128|0;B=H;A=X;J=W;K=w;while(1){if(K){_=J-7|0;$=A<<7|127}else{I=fe(127>>>((7-J|0)>>>0)|A<<J|0)|0;aa=c[h>>2]|0;x=I;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;_=J+25|0;$=127}c[o>>2]=$;c[p>>2]=_;aa=B-127|0;ba=(_|0)>7;if((aa|0)>126){B=aa;A=$;J=_;K=ba}else{break}}K=(z>>>0)%127|0;if(ba){ca=_;da=$;ea=K;U=42}else{fa=_;ga=$;ha=K;U=43}}else{if(w){ca=W;da=X;ea=H;U=42}else{fa=W;ga=X;ha=H;U=43}}if((U|0)==42){ia=ca-7|0;ja=da<<7|ea}else if((U|0)==43){K=fe(ha>>>((7-fa|0)>>>0)|ga<<fa|0)|0;J=c[h>>2]|0;x=K;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;ia=fa+25|0;ja=ha}c[o>>2]=ja;c[p>>2]=ia;J=jcb(k)|0;do{if((c[b+64>>2]|0)!=0){K=c[y>>2]|0;if((c[K+416>>2]|0)<=0){break}A=b+408|0;B=0;aa=K;while(1){do{if((a[b+1137+B|0]|0)==0){ka=aa}else{K=c[A>>2]|0;if((K|0)>0){la=0}else{ka=aa;break}do{c[b+768+(B<<6)+(la<<2)>>2]=0;I=c[o>>2]|0;ma=c[p>>2]|0;if((ma|0)>1){na=ma-1|0;oa=I<<1}else{pa=fe(I<<ma|0)|0;I=c[h>>2]|0;x=pa;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;na=ma+31|0;oa=0}c[o>>2]=oa;c[p>>2]=na;la=la+1|0;}while((la|0)<(K|0));ka=c[y>>2]|0}}while(0);K=B+1|0;if((K|0)<(c[ka+416>>2]|0)){B=K;aa=ka}else{break}}}}while(0);if((c[t>>2]|0)!=(c[r>>2]|0)){H=c[o>>2]|0;w=c[p>>2]|0;if((w|0)>1){qa=w-1|0;ra=H<<1|1}else{z=fe(1>>>((1-w|0)>>>0)|H<<w|0)|0;H=c[h>>2]|0;x=z;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;qa=w+31|0;ra=1}c[o>>2]=ra;c[p>>2]=qa}if((c[(c[y>>2]|0)+416>>2]|0)<=0){break}w=b+60|0;H=0;c:do{do{if((a[b+1137+H|0]|0)!=0){if((c[w>>2]|0)==0){U=78;break c}z=(c[r>>2]|0)-(c[t>>2]|0)|0;aa=b+112+(z*50|0)|0;B=b+1152+(H<<13)+(c[s>>2]<<2)|0;if((c[u>>2]|0)==1){A=c[F>>2]|0;K=c[p>>2]|0;if((K|0)>5){sa=K-5|0;ta=A<<5|10}else{ma=fe(10>>>((5-K|0)>>>0)|A<<K|0)|0;A=c[h>>2]|0;x=ma;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;sa=K+27|0;ta=10}c[F>>2]=ta;c[p>>2]=sa;ua=1343036;va=20;wa=b+112+(z*50|0)+2|0;xa=b+1152+(H<<13)+(e[aa>>1]<<2)|0}else{ua=1343032;va=36;wa=aa;xa=b+1152+(H<<13)|0}if(!(xa>>>0<B>>>0)){break}aa=xa;z=wa;K=va;A=ua;ma=c[F>>2]|0;I=c[p>>2]|0;while(1){pa=c[A>>2]|0;ya=pa-K+60|0;za=d[1277624+ya|0]|0;Aa=c[1277136+(ya<<2)>>2]|0;if((I|0)>(za|0)){Ba=I;Ca=ma<<za|Aa}else{ya=fe(Aa>>>((za-I|0)>>>0)|ma<<I|0)|0;Da=c[h>>2]|0;x=ya;a[Da]=x;x=x>>8;a[Da+1|0]=x;x=x>>8;a[Da+2|0]=x;x=x>>8;a[Da+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Ba=I+32|0;Ca=Aa}Aa=Ba-za|0;c[F>>2]=Ca;c[p>>2]=Aa;za=aa+(e[z>>1]<<2)|0;if(za>>>0<B>>>0){aa=za;z=z+2|0;K=pa;A=A+4|0;ma=Ca;I=Aa}else{break}}}}while(0);H=H+1|0;Ea=c[(c[y>>2]|0)+416>>2]|0;}while((H|0)<(Ea|0));if((U|0)==78){yDb(0,0,1963304,(q=i,i=i+24|0,c[q>>2]=2328792,c[q+8>>2]=1911952,c[q+16>>2]=274,q)|0);i=q;Cd();return 0}if((Ea|0)<=0){break}H=b+1136|0;F=1<<J;w=32-J|0;I=0;d:while(1){do{if((a[b+1137+I|0]|0)!=0){if((I|0)==1){Fa=(a[H]|0)!=0|0}else{Fa=0}ma=c[m+(I<<2)>>2]|0;A=b+17544+(I<<13)+(ma<<2)|0;if((ma|0)<=0){break}ma=b+1088+(Fa<<2)|0;K=b+1080+(Fa<<2)|0;z=0;aa=b+17544+(I<<13)|0;while(1){C=+g[aa>>2];if(C!=0.0){B=~~C;Aa=(B|0)>-1?B:-B|0;pa=c[ma>>2]|0;do{if((Aa|0)>(c[pa+4>>2]|0)){Ga=0}else{za=Aa-1|0;if((z|0)>=(e[(c[pa+16>>2]|0)+(za<<1)>>1]|0)){Ga=0;break}Ga=(e[(c[K>>2]|0)+(za<<1)>>1]|0)+z|0}}while(0);za=d[(c[pa+12>>2]|0)+Ga|0]|0;Da=c[(c[pa+8>>2]|0)+(Ga<<2)>>2]|0;ya=c[o>>2]|0;Ha=c[p>>2]|0;if((Ha|0)>(za|0)){Ia=Ha-za|0;Ja=ya<<za|Da}else{Ka=fe(Da>>>((za-Ha|0)>>>0)|ya<<Ha|0)|0;ya=c[h>>2]|0;x=Ka;a[ya]=x;x=x>>8;a[ya+1|0]=x;x=x>>8;a[ya+2|0]=x;x=x>>8;a[ya+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Ia=32-za+Ha|0;Ja=Da}c[o>>2]=Ja;c[p>>2]=Ia;if((Ga|0)==0){if((F|0)<=(Aa|0)){T=2147483647;break d}if((Ia|0)>(J|0)){La=Ia-J|0;Ma=Ja<<J|Aa}else{Da=fe(Aa>>>((J-Ia|0)>>>0)|Ja<<Ia|0)|0;Ha=c[h>>2]|0;x=Da;a[Ha]=x;x=x>>8;a[Ha+1|0]=x;x=x>>8;a[Ha+2|0]=x;x=x>>8;a[Ha+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;La=w+Ia|0;Ma=Aa}c[o>>2]=Ma;c[p>>2]=La;Ha=c[r>>2]|0;if((La|0)>(Ha|0)){Na=La;Oa=Ma<<Ha|z}else{Da=fe(z>>>((Ha-La|0)>>>0)|Ma<<La|0)|0;za=c[h>>2]|0;x=Da;a[za]=x;x=x>>8;a[za+1|0]=x;x=x>>8;a[za+2|0]=x;x=x>>8;a[za+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Na=La+32|0;Oa=z}za=Na-Ha|0;c[o>>2]=Oa;c[p>>2]=za;Pa=za;Qa=Oa}else{Pa=Ia;Qa=Ja}za=B>>>31;if((Pa|0)>1){Ra=Pa-1|0;Sa=Qa<<1|za}else{Ha=fe(za>>>((1-Pa|0)>>>0)|Qa<<Pa|0)|0;Da=c[h>>2]|0;x=Ha;a[Da]=x;x=x>>8;a[Da+1|0]=x;x=x>>8;a[Da+2|0]=x;x=x>>8;a[Da+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Ra=Pa+31|0;Sa=za}c[o>>2]=Sa;c[p>>2]=Ra;Ta=0}else{Ta=z+1|0}za=aa+4|0;if(za>>>0<A>>>0){z=Ta;aa=za}else{break}}if((Ta|0)==0){break}aa=c[ma>>2]|0;z=d[(c[aa+12>>2]|0)+1|0]|0;A=c[(c[aa+8>>2]|0)+4>>2]|0;aa=c[o>>2]|0;K=c[p>>2]|0;if((K|0)>(z|0)){Ua=K-z|0;Va=aa<<z|A}else{za=fe(A>>>((z-K|0)>>>0)|aa<<K|0)|0;aa=c[h>>2]|0;x=za;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Ua=32-z+K|0;Va=A}c[o>>2]=Va;c[p>>2]=Ua}}while(0);do{if((c[u>>2]|0)==1){if((c[(c[y>>2]|0)+416>>2]|0)<=1){break}K_(n)}}while(0);I=I+1|0;if((I|0)>=(c[(c[y>>2]|0)+416>>2]|0)){break a}}i=l;return T|0}}while(0);K_(n);T=((32-(c[p>>2]|0)+((c[h>>2]|0)-(c[j>>2]|0)<<3)|0)/8|0)-(c[(c[y>>2]|0)+432>>2]|0)|0;i=l;return T|0}function vcb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;g=c[e+60>>2]|0;h=c[e+96>>2]|0;j=e+432|0;if((c[j>>2]|0)==0){yDb(e,16,2228688,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-22;i=f;return l|0}c[g>>2]=e;m=g+8|0;c[g+32812>>2]=262144;c[g+32800>>2]=m;c[g+32808>>2]=g+32776;c[g+32804>>2]=m;c[g+32796>>2]=32;c[g+32792>>2]=0;if((c[e+100>>2]|0)<=17){DDb(e,2199328,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=f;return l|0}m=h+14|0;n=(d[m]|d[m+1|0]<<8)<<16>>16&65535;m=g+32816|0;c[m>>2]=n;o=h+2|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h;h=(d[o]|d[o+1|0]<<8)<<16>>16;a[g+32828|0]=h;o=h&255;if((o<<16>>16|0)==24){c[e+420>>2]=7;EDb(e,2216888,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=f;return l|0}else if((o<<16>>16|0)==16){c[e+420>>2]=6;h=c[j>>2]|0;j=h>>>0>65535>>>0;q=j?h>>>16:h;h=j?16:0;if((q&65280|0)==0){r=h;s=q}else{r=h|8;s=q>>>8}b[g+32832>>1]=r+4+(d[1191992+s|0]|0);a[g+32981|0]=1;a[g+32884|0]=1;c[g+32820>>2]=n&64;s=1<<(ncb(c[e+412>>2]|0,3,n)|0);n=s&65535;b[g+32830>>1]=n;if(!((s&65535)>>>0<16385>>>0)){yDb(0,0,2190704,(k=i,i=i+24|0,c[k>>2]=2174064,c[k+8>>2]=2164072,c[k+16>>2]=225,k)|0);i=k;Cd();return 0}s=e+416|0;r=c[s>>2]|0;if((r|0)>0){q=g+32996|0;h=0;do{b[q+(h*144|0)>>1]=n;h=h+1|0;}while((h|0)<(r|0))}r=c[m>>2]|0;m=r>>>3&7;h=1<<m;q=h&255;a[g+32836|0]=q;a[g+32838|0]=0;a[g+32837|0]=(a[1191992+m|0]|0)+1;b[g+32840>>1]=(n&65535)/(h&65535&255)|0;c[g+32824>>2]=r&128;c[g+226880>>2]=r&256;if((q&255)>>>0>32>>>0){yDb(e,16,2157152,(k=i,i=i+8|0,c[k>>2]=h&255,k)|0);i=k;l=-1094995529;i=f;return l|0}h=c[s>>2]&255;a[g+32834|0]=h;s=g+32835|0;a[s]=-1;if((p&8|0)!=0){if((p&1|0)==0){t=-1}else{a[s]=0;t=0}if((p&2|0)==0){u=t}else{q=t+1&255;a[s]=q;u=q}if((p&4|0)==0){v=u}else{q=u+1&255;a[s]=q;v=q}a[s]=v+1}if(h<<24>>24<0){yDb(e,16,2150424,(k=i,i=i+8|0,c[k>>2]=h<<24>>24,k)|0);i=k;l=-1094995529;i=f;return l|0}if(h<<24>>24>8){DDb(e,2143488,(k=i,i=i+8|0,c[k>>2]=8,k)|0);i=k;l=-1163346256;i=f;return l|0}h=ICb()|0;c[g+4>>2]=h;if((h|0)==0){l=-12;i=f;return l|0}h=e+448|0;c[h>>2]=p;c[h+4>>2]=0;l=0;i=f;return l|0}else{yDb(e,16,2207504,(k=i,i=i+8|0,c[k>>2]=o&65535,k)|0);i=k;l=-1094995529;i=f;return l|0}return 0}function wcb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;j=i;k=c[b+60>>2]|0;l=k;m=k+32844|0;n=m;o=c[h+24>>2]|0;p=h+28|0;h=c[p>>2]|0;q=k+4|0;c[(c[q>>2]|0)+76>>2]=0;r=k+32885|0;a:do{if((a[r]|0)==0){if((a[k+32884|0]|0)!=0){s=3;break}t=(c[p>>2]|0)-(c[k+32864>>2]|0)<<3;c[k+32912>>2]=t;u=t>>>0>2147483639>>>0|(o|0)==0;v=u?0:o;w=u?0:t;c[m>>2]=v;c[k+32856>>2]=w;u=w+8|0;c[k+32860>>2]=u;c[k+32848>>2]=v+(w>>3);w=d[k+32868|0]|0;x=u>>>0>w>>>0?w:u;c[k+32852>>2]=x;do{if((c[k+32820>>2]|0)==0){if((c[k+32872>>2]|0)<=(c[k+32900>>2]|0)){break}u=(Acb(l)|0)==0|0;a[r]=u;y=u;s=26;break a}else{u=t-x|0;w=e[k+32832>>1]|0;if((u|0)<=(w|0)){break}z=v+(x>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>((32-w|0)>>>0);if((A|0)==0|(A|0)>(u|0)){break}zcb(l,n,A,0);A=(Acb(l)|0)==0|0;a[r]=A;y=A;s=26;break a}}while(0);a[r]=1;B=k+32884|0;s=28}else{s=3}}while(0);if((s|0)==3){a[r]=0;if((h|0)==0){C=0;i=j;return C|0}p=b+432|0;x=c[p>>2]|0;if((h|0)<(x|0)){yDb(b,16,2178320,(D=i,i=i+8|0,c[D>>2]=h,D)|0);i=D;C=-1094995529;i=j;return C|0}c[k+32864>>2]=h-x;x=c[p>>2]<<3;p=k+32912|0;c[p>>2]=x;h=x>>>0>2147483639>>>0|(o|0)==0;v=h?0:o;o=h?0:x;x=m;c[x>>2]=v;c[k+32856>>2]=o;m=o+8|0;h=k+32860|0;c[h>>2]=m;c[k+32848>>2]=v+(o>>3);o=k+32852|0;c[o>>2]=0;t=v;A=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>4&15;t=m>>>0>4>>>0?5:m|1;u=m>>>0>t>>>0?t:m;c[o>>2]=u;t=d[v+(u>>>3)|0]|0;w=((u|0)<(m|0))+u|0;c[o>>2]=w;if((128>>>((u&7)>>>0)&t|0)==0){E=w;F=m;G=v}else{DDb(b,2102056,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=c[o>>2]|0;F=c[h>>2]|0;G=c[x>>2]|0}x=e[k+32832>>1]|0;h=G+(E>>>3)|0;G=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(E&7)>>>((32-x|0)>>>0);h=E+x|0;c[o>>2]=F>>>0>h>>>0?h:F;F=k+32884|0;h=k+32869|0;do{if((a[F]|0)==0){x=d[h]|0;if((x+1&15|0)==(A|0)){break}a[F]=1;yDb(b,16,2045968,(D=i,i=i+16|0,c[D>>2]=x,c[D+8>>2]=A,D)|0);i=D}}while(0);a[h]=A;do{if((G|0)>0){A=(c[p>>2]|0)-(c[o>>2]|0)|0;if((G|0)>=(A|0)){a[r]=1;zcb(l,n,A,1);s=16;break}zcb(l,n,G,1);if((a[F]|0)!=0){s=17;break}Acb(l)|0;s=16}else{s=16}}while(0);if((s|0)==16){if((a[F]|0)!=0){s=17}}if((s|0)==17){c[k+32872>>2]=0;a[F]=0;F=k+8|0;c[k+32812>>2]=262144;c[k+32800>>2]=F;c[k+32808>>2]=k+32776;c[k+32804>>2]=F;c[k+32796>>2]=32;c[k+32792>>2]=0}y=a[r]|0;s=26}do{if((s|0)==26){r=k+32884|0;if(y<<24>>24==0){H=r;break}F=k+32884|0;if((a[r]|0)==0){B=F;s=28}else{H=F}}}while(0);do{if((s|0)==28){y=(c[k+32912>>2]|0)-(c[k+32852>>2]|0)|0;if((y|0)<=0){H=B;break}zcb(l,n,y,0);H=B}}while(0);B=c[q>>2]|0;c[g>>2]=(c[B+76>>2]|0)>0;QCb(f,B);B=c[k+32852>>2]|0;a[k+32868|0]=B&7;if((a[H]|0)!=0){C=-1094995529;i=j;return C|0}C=B>>3;i=j;return C|0}function xcb(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function ycb(b){b=b|0;var d=0;d=c[b+60>>2]|0;a[d+32884|0]=1;a[d+32885|0]=0;c[d+32872>>2]=0;c[d+32876>>2]=0;c[d+32864>>2]=0;c[d+41088>>2]=0;c[(c[d+4>>2]|0)+76>>2]=0;b=d+8|0;c[d+32812>>2]=262144;c[d+32800>>2]=b;c[d+32808>>2]=d+32776;c[d+32804>>2]=b;c[d+32796>>2]=32;c[d+32792>>2]=0;return}function zcb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;j=(g|0)!=0;if(j){k=c[b+32872>>2]|0}else{g=c[e+8>>2]&7;c[b+32876>>2]=g;c[b+32872>>2]=g;l=b+8|0;c[b+32812>>2]=262144;c[b+32800>>2]=l;c[b+32808>>2]=b+32776;c[b+32804>>2]=l;c[b+32796>>2]=32;c[b+32792>>2]=0;k=g}g=b+32872|0;l=k+f|0;do{if((f|0)>=1){if((l+8>>3|0)>32768){break}c[g>>2]=l;if(j){k=e+8|0;m=c[k>>2]|0;n=m&7;o=8-n|0;p=(o|0)>(f|0)?f:o;o=b+32792|0;q=e+16|0;r=c[q>>2]|0;s=e|0;t=c[s>>2]|0;u=t+(m>>>3)|0;v=32-p|0;w=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<n>>>(v>>>0);n=p+m|0;c[k>>2]=r>>>0>n>>>0?n:r;r=o|0;n=c[r>>2]|0;m=b+32796|0;u=c[m>>2]|0;if((u|0)>(p|0)){y=u-p|0;z=n<<p|w;A=t}else{t=fe(w>>>((p-u|0)>>>0)|n<<u|0)|0;n=b+32804|0;B=c[n>>2]|0;x=t;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;y=v+u|0;z=w;A=c[s>>2]|0}c[r>>2]=z;c[m>>2]=y;m=f-p|0;M_(o,A+(c[k>>2]>>3)|0,m);C=m;D=q}else{M_(b+32792|0,(c[e>>2]|0)+(c[e+8>>2]>>3)|0,l);C=f;D=e+16|0}q=e+8|0;m=c[q>>2]|0;k=-m|0;o=(c[D>>2]|0)-m|0;if((C|0)<(k|0)){E=k}else{E=(o|0)<(C|0)?o:C}c[q>>2]=E+m;m=c[b+32792>>2]|0;q=m;o=c[b+32796>>2]|0;if((o|0)<32){k=m<<o;q=k;m=k>>>24&255;k=o;o=c[b+32804>>2]|0;while(1){a[o]=m;p=q;q=p<<8;r=k+8|0;if((r|0)<32){m=p>>>16&255;k=r;o=o+1|0}else{break}}}q=0;o=b+8|0;k=c[g>>2]|0;m=k>>>0>2147483639>>>0|(o|0)==0;r=m?0:o;o=m?0:k;c[b+32892>>2]=r;c[b+32904>>2]=o;k=o+8|0;c[b+32908>>2]=k;c[b+32896>>2]=r+(o+7>>3);o=c[b+32876>>2]|0;c[b+32900>>2]=k>>>0>o>>>0?o:k;i=h;return}}while(0);DDb(c[b>>2]|0,2240768,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;a[b+32884|0]=1;i=h;return}function Acb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0;g=i;i=i+56|0;h=g|0;j=g+16|0;k=g+24|0;l=k;m=f+32892|0;n=f+32830|0;o=f+4|0;p=c[o>>2]|0;c[p+76>>2]=e[n>>1]|0;q=f|0;r=_$a(c[q>>2]|0,p,0)|0;if((r|0)<0){a[f+32884|0]=1;s=r;i=g;return s|0}r=f+32834|0;p=a[r]|0;if(p<<24>>24>0){t=0;while(1){c[f+32916+(t<<2)>>2]=c[(c[(c[o>>2]|0)+64>>2]|0)+(t<<2)>>2];c[f+32948+(t<<2)>>2]=c[(c[(c[o>>2]|0)+64>>2]|0)+(t<<2)>>2];u=t+1|0;v=a[r]|0;if((u|0)<(v<<24>>24|0)){t=u}else{w=v;break}}}else{w=p}p=f+32820|0;if((c[p>>2]|0)==0){x=0}else{t=e[f+32832>>1]|0;v=f+32900|0;u=c[v>>2]|0;y=c[f+32908>>2]|0;z=(c[m>>2]|0)+(u>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(u&7)>>>((32-t|0)>>>0);z=u+t|0;c[v>>2]=y>>>0>z>>>0?z:y;x=A}TGb(h|0,0,16)|0;A=w<<24>>24;if(w<<24>>24>0){y=0;do{a[f+32996+(y*144|0)+3|0]=0;y=y+1|0;}while((y|0)<(A|0))}y=f+32900|0;z=c[y>>2]|0;v=f+32892|0;t=d[(c[v>>2]|0)+(z>>>3)|0]|0;u=f+32908|0;c[y>>2]=((z|0)<(c[u>>2]|0))+z;B=f+32836|0;C=(t&128>>>((z&7)>>>0)|0)!=0|(a[B]|0)==1;z=f+32840|0;t=A;A=0;D=w;a:while(1){if(!(D<<24>>24>0)){E=24;break}w=D<<24>>24;if(C|(t|0)==1){G=0;H=0;while(1){I=j+G|0;if((e[h+(G<<1)>>1]|0)==(A|0)){a[I]=1;J=H|1}else{a[I]=0;J=H}I=G+1|0;if((I|0)<(w|0)){G=I;H=J}else{K=J;break}}}else{H=0;G=0;while(1){if((e[h+(H<<1)>>1]|0)==(A|0)){if((A|0)==((e[n>>1]|0)-(e[z>>1]|0)|0)){a[j+H|0]=1;L=1}else{I=c[y>>2]|0;M=d[(c[v>>2]|0)+(I>>>3)|0]<<(I&7)>>>7;c[y>>2]=((I|0)<(c[u>>2]|0))+I;I=M&1;a[j+H|0]=I;L=I&255}N=L|G}else{a[j+H|0]=0;N=G}I=H+1|0;if((I|0)<(w|0)){H=I;G=N}else{K=N;break}}}if((K|0)==0){E=24;break}G=b[n>>1]|0;H=G&65535;w=e[z>>1]|0;if((H-w|0)==(A|0)){O=w}else{I=(d[B]|0)-1|0;M=I>>>0>65535>>>0;P=M?I>>>16:I;I=M?16:0;if((P&65280|0)==0){Q=I;R=P}else{Q=I|8;R=P>>>8}P=(d[1191992+R|0]|0)+Q|0;I=c[y>>2]|0;M=c[u>>2]|0;S=(c[v>>2]|0)+(I>>>3)|0;T=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(I&7)>>>((31-P|0)>>>0);S=I+1+P|0;c[y>>2]=M>>>0>S>>>0?S:M;U=ba(T+1|0,w)|0;if((U|0)<(w|0)|(U|0)>(H|0)){E=29;break}else{O=U}}if((O|0)<1){break}H=O&65535;w=O+A|0;T=0;M=t;S=G;G=D;while(1){do{if((a[j+T|0]|0)==0){P=e[h+(T<<1)>>1]|0;if((P|0)>(w|0)){V=M;W=w;X=S;Y=G;break}I=(P|0)<(w|0);V=I?1:M+1|0;W=I?P:w;X=S;Y=G}else{P=f+32996+(T*144|0)+3|0;I=a[P]|0;if((I&255)>>>0>31>>>0){E=34;break a}b[f+32996+(T*144|0)+4+((I&255)<<1)>>1]=H;I=h+(T<<1)|0;Z=(e[I>>1]|0)+O|0;_=Z&65535;b[I>>1]=_;a[P]=(a[P]|0)+1;$=b[n>>1]|0;if((_&65535)>>>0>($&65535)>>>0){E=37;break a}V=M;W=w;X=$;Y=a[r]|0}}while(0);_=T+1|0;if((_|0)<(Y<<24>>24|0)){w=W;T=_;M=V;S=X;G=Y}else{break}}if((W|0)<(X&65535|0)){t=V;A=W;D=Y}else{E=42;break}}if((E|0)==24){yDb(c[q>>2]|0,16,2304360,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==29){yDb(c[q>>2]|0,16,2255088,(aa=i,i=i+8|0,c[aa>>2]=U,aa)|0);i=aa}else if((E|0)==34){yDb(c[q>>2]|0,16,2286424,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==37){yDb(c[q>>2]|0,16,2270416,(aa=i,i=i+16|0,c[aa>>2]=Z&65535,c[aa+8>>2]=$&65535,aa)|0);i=aa}else if((E|0)==42){if(Y<<24>>24>0){$=0;Z=Y;while(1){U=f+32996+($*144|0)+3|0;if((a[U]|0)==0){ca=Z}else{D=0;W=0;do{b[f+32996+($*144|0)+68+(D<<1)>>1]=W;W=(e[f+32996+($*144|0)+4+(D<<1)>>1]|0)+W|0;D=D+1|0;}while((D|0)<(d[U]|0));ca=a[r]|0}U=$+1|0;if((U|0)<(ca<<24>>24|0)){$=U;Z=ca}else{da=ca;break}}}else{da=Y}Y=c[y>>2]|0;if((c[f+32824>>2]|0)==0){ea=Y;fa=c[m>>2]|0;ga=c[u>>2]|0}else{ca=c[u>>2]|0;Z=c[m>>2]|0;$=Z+(Y>>>3)|0;U=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(Y&7)>>>24;$=Y+8|0;Y=ca>>>0>$>>>0?$:ca;c[y>>2]=Y;a[f+32980|0]=U;ea=Y;fa=Z;ga=ca}ca=m|0;m=d[fa+(ea>>>3)|0]|0;Z=((ea|0)<(ga|0))+ea|0;c[y>>2]=Z;do{if((m&128>>>((ea&7)>>>0)|0)==0){ha=Z}else{Y=d[fa+(Z>>>3)|0]|0;U=((Z|0)<(ga|0))+Z|0;c[y>>2]=U;if((Y&128>>>((Z&7)>>>0)|0)==0){ia=U}else{Y=e[n>>1]|0;$=Y<<1;D=$>>>0>65535>>>0;W=D?Y>>>15:$;$=D?16:0;if((W&65280|0)==0){ja=$;ka=W}else{ja=$|8;ka=W>>>8}W=(d[1191992+ka|0]|0)+ja+U|0;U=ga>>>0>W>>>0?W:ga;c[y>>2]=U;ia=U}U=d[fa+(ia>>>3)|0]|0;W=((ia|0)<(ga|0))+ia|0;c[y>>2]=W;if((U&128>>>((ia&7)>>>0)|0)==0){ha=W;break}U=e[n>>1]|0;$=U<<1;D=$>>>0>65535>>>0;Y=D?U>>>15:$;$=D?16:0;if((Y&65280|0)==0){la=$;ma=Y}else{la=$|8;ma=Y>>>8}Y=(d[1191992+ma|0]|0)+la+W|0;W=ga>>>0>Y>>>0?Y:ga;c[y>>2]=W;ha=W}}while(0);ga=f+32982|0;a[ga]=0;if(da<<24>>24>0){la=da<<24>>24;ma=0;do{b[f+32996+(ma*144|0)+134>>1]=0;a[f+32996+(ma*144|0)+132|0]=0;ma=ma+1|0;}while((ma|0)<(la|0))}la=f+33130|0;ma=f+32880|0;ia=f+227012|0;fa=f+41088|0;ja=f+32828|0;ka=f+34151|0;Z=f+34150|0;ea=f+34149|0;m=f+41084|0;W=f+34154|0;Y=f+34153|0;$=f+226884|0;D=f+226888|0;U=f+34800|0;A=f+34801|0;V=f+41076|0;t=f+39026|0;X=f+40050|0;O=f+32904|0;h=f+41080|0;j=f+226880|0;Q=f+34152|0;R=f+752616|0;B=f+752620|0;z=f+752624|0;K=f+751336|0;N=f+34160|0;L=f+34802|0;J=f+34148|0;C=f+32986|0;G=da;da=ha;b:while(1){ha=b[la>>1]|0;na=ha&65535;S=e[n>>1]|0;M=G<<24>>24;T=ba(M,S)|0;c[ma>>2]=da;c:do{if(G<<24>>24>0){w=0;H=S;_=S;P=ha;while(1){I=P&65535;if((_|0)>(I|0)){oa=I;pa=e[f+32996+(w*144|0)+4+(d[f+32996+(w*144|0)+132|0]<<1)>>1]|0}else{oa=_;pa=H}I=w+1|0;if((I|0)>=(M|0)){break}w=I;H=pa;_=oa;P=b[f+32996+(I*144|0)+134>>1]|0}a[C]=0;P=0;_=T;H=G;w=ha;while(1){I=f+32996+(P*144|0)+134|0;qa=w&65535;ra=_-qa|0;do{if((oa|0)==(qa|0)){sa=b[f+32996+(P*144|0)+4+(d[f+32996+(P*144|0)+132|0]<<1)>>1]|0;if((pa|0)!=(sa&65535|0)){ta=ra;ua=H;break}b[I>>1]=sa+w;a[(a[C]|0)+(f+32987)|0]=P;a[C]=(a[C]|0)+1;ta=ra-pa|0;ua=a[r]|0}else{ta=ra;ua=H}}while(0);ra=P+1|0;if((ra|0)>=(ua<<24>>24|0)){va=ta;wa=ua;xa=pa;break c}P=ra;_=ta;H=ua;w=b[f+32996+(ra*144|0)+134>>1]|0}}else{a[C]=0;va=T;wa=G;xa=S}}while(0);if((va|0)==0){a[ga]=1}S=c[y>>2]|0;T=c[v>>2]|0;ha=d[T+(S>>>3)|0]<<(S&7)>>>7;M=c[u>>2]|0;w=((S|0)<(M|0))+S|0;c[y>>2]=w;S=ha&1;c[ia>>2]=S;do{if((S|0)==0){if((c[fa>>2]|0)==0){E=129;break b}else{ya=w;za=T;Aa=M;Ba=wa}}else{TGb(K|0,0,1280)|0;TGb(N|0,0,640)|0;TGb(L|0,0,6272)|0;if(wa<<24>>24>0){ha=0;do{H=f+226848+(ha<<2)|0;if((c[H>>2]|0)>0){_=0;while(1){P=_+1|0;TGb(f+41088+(ha*23220|0)+(_*2580|0)+16|0,0,2560)|0;if((P|0)<(c[H>>2]|0)){_=P}else{break}}}c[f+227016+(ha<<2)>>2]=0;ha=ha+1|0;}while((ha|0)<(a[r]|0));Ca=c[y>>2]|0;Da=c[v>>2]|0;Ea=c[u>>2]|0}else{Ca=w;Da=T;Ea=M}ha=d[Da+(Ca>>>3)|0]<<(Ca&7)>>>7;_=((Ca|0)<(Ea|0))+Ca|0;c[y>>2]=_;H=ha&1;a[J]=H;if(!(H<<24>>24==0)){E=85;break b}H=d[Da+(_>>>3)|0]<<(_&7)>>>7;ha=((_|0)<(Ea|0))+_|0;c[y>>2]=ha;_=H&1;a[ea]=_;H=d[Da+(ha>>>3)|0]<<(ha&7)>>>7;P=((ha|0)<(Ea|0))+ha|0;c[y>>2]=P;a[Z]=H&1;H=d[Da+(P>>>3)|0]<<(P&7)>>>7;ha=((P|0)<(Ea|0))+P|0;c[y>>2]=ha;P=H&1;a[ka]=P;do{if(_<<24>>24==0){Fa=P}else{H=Da+(ha>>>3)|0;ra=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(ha&7)>>>28;H=ha+4|0;I=Ea>>>0>H>>>0?H:Ea;c[y>>2]=I;H=ra+1&255;a[Y]=H;ra=Da+(I>>>3)|0;qa=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(I&7)>>>28;ra=I+4|0;c[y>>2]=Ea>>>0>ra>>>0?ra:Ea;ra=qa&255;a[W]=ra;if(H<<24>>24==0){Fa=P;break}else{Ga=0;Ha=ra}while(1){if(Ha<<24>>24==0){Ia=0;Ja=1}else{ra=Ha<<24>>24;H=c[y>>2]|0;qa=c[u>>2]|0;I=(c[v>>2]|0)+(H>>>3)|0;sa=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(H&7)>>>((32-ra|0)>>>0);I=H+ra|0;c[y>>2]=qa>>>0>I>>>0?I:qa;Ia=0;Ja=sa+1|0}sa=f+34160+(Ga<<3)|0;c[sa>>2]=Ja;c[sa+4>>2]=Ia;sa=Ga+1|0;if((sa|0)>=(a[Y]|0)){break}Ga=sa;Ha=a[W]|0}Fa=a[ka]|0}}while(0);do{if(!(Fa<<24>>24==0)){P=c[y>>2]|0;ha=c[u>>2]|0;_=c[v>>2]|0;sa=_+(P>>>3)|0;qa=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(P&7)>>>28;sa=P+4|0;P=ha>>>0>sa>>>0?sa:ha;c[y>>2]=P;sa=(qa<<1)+2&255;a[U]=sa;qa=_+(P>>>3)|0;I=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(P&7)>>>28;qa=P+4|0;P=ha>>>0>qa>>>0?qa:ha;c[y>>2]=P;a[A]=I;qa=d[_+(P>>>3)|0]|0;ra=((P|0)<(ha|0))+P|0;c[y>>2]=ra;if((qa&128>>>((P&7)>>>0)|0)==0){break}P=I+1|0;I=(P&65280|0)==0;qa=(d[1191992+(I?P:P>>>8)|0]|0)+(I?0:8)|0;I=((1<<qa|0)<(P|0))+qa|0;if((I|0)==0){Ka=2;La=ra}else{qa=_+(ra>>>3)|0;P=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ra&7)>>>((32-I|0)>>>0);qa=I+ra|0;ra=ha>>>0>qa>>>0?qa:ha;c[y>>2]=ra;Ka=P+2|0;La=ra}ra=a[r]|0;P=ra<<24>>24;d:do{if((ba(ba(P,sa<<24>>24)|0,P)|0)>0){qa=32-Ka|0;I=0;H=La;Ma=ha;Na=_;while(1){Oa=Na+(H>>>3)|0;Pa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(H&7)>>>(qa>>>0);Oa=H+Ka|0;c[y>>2]=Ma>>>0>Oa>>>0?Oa:Ma;b[f+34802+(I<<1)>>1]=Pa;Pa=I+1|0;Oa=a[r]|0;Qa=Oa<<24>>24;if((Pa|0)>=(ba(ba(Qa,a[U]|0)|0,Qa)|0)){Ra=Oa;break d}I=Pa;H=c[y>>2]|0;Ma=c[u>>2]|0;Na=c[v>>2]|0}}else{Ra=ra}}while(0);if(!(Ra<<24>>24>0)){break}ra=32-Ka|0;_=0;ha=Ra;while(1){if((_|0)>0){P=0;sa=ha;while(1){Na=c[y>>2]|0;Ma=c[u>>2]|0;H=(c[v>>2]|0)+(Na>>>3)|0;I=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(Na&7)>>>(ra>>>0);H=Na+Ka|0;c[y>>2]=Ma>>>0>H>>>0?H:Ma;b[f+38898+((ba(sa<<24>>24,_)|0)+P<<1)>>1]=I;I=P+1|0;Ma=a[r]|0;if((I|0)<(_|0)){P=I;sa=Ma}else{Sa=Ma;break}}}else{Sa=ha}sa=_+1|0;if((sa|0)<(Sa<<24>>24|0)){_=sa;ha=Sa}else{break}}}}while(0);ha=c[y>>2]|0;_=c[v>>2]|0;ra=a[_+(ha>>>3)|0]|0;sa=c[u>>2]|0;P=((ha|0)<(sa|0))+ha|0;c[y>>2]=P;Ma=a[r]|0;if(Ma<<24>>24>0){I=(ra&255&128>>>((ha&7)>>>0)|0)!=0;Ta=0;ha=P;ra=sa;H=_;while(1){Na=H+(ha>>>3)|0;qa=(fe(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0)<<(ha&7)>>>29;Na=ha+3|0;c[y>>2]=ra>>>0>Na>>>0?Na:ra;Na=f+226848+(Ta<<2)|0;c[Na>>2]=qa+1;Ua=0;while(1){qa=c[y>>2]|0;Pa=c[u>>2]|0;Oa=(c[v>>2]|0)+(qa>>>3)|0;Qa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(qa&7)>>>25;Oa=qa+7|0;c[y>>2]=Pa>>>0>Oa>>>0?Oa:Pa;Va=(Qa<<3)+8|0;c[f+41088+(Ta*23220|0)+(Ua*2580|0)>>2]=Va;if(Va>>>0>256>>>0){E=123;break b}Qa=Ua+1|0;Wa=c[Na>>2]|0;if((Qa|0)<(Wa|0)){Ua=Qa}else{break}}do{if((Wa|0)>0){Qa=0;do{Pa=c[y>>2]|0;Oa=c[u>>2]|0;qa=(c[v>>2]|0)+(Pa>>>3)|0;Xa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Pa&7)>>>28;qa=Pa+4|0;c[y>>2]=Oa>>>0>qa>>>0?qa:Oa;c[f+41088+(Ta*23220|0)+(Qa*2580|0)+4>>2]=Xa;Qa=Qa+1|0;Ya=c[Na>>2]|0;}while((Qa|0)<(Ya|0));if(I&(Ya|0)>0){Za=0}else{break}do{Qa=c[f+41088+(Ta*23220|0)+(Za*2580|0)>>2]|0;Xa=Qa>>>0>65535>>>0;Oa=Xa?Qa>>>16:Qa;qa=Xa?16:0;if((Oa&65280|0)==0){_a=qa;$a=Oa}else{_a=qa|8;$a=Oa>>>8}Oa=(d[1191992+$a|0]|0)+_a|0;qa=((1<<Oa|0)<(Qa|0))+Oa|0;Oa=c[y>>2]|0;Qa=c[u>>2]|0;Xa=(c[v>>2]|0)+(Oa>>>3)|0;Pa=(fe(d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0)|0)<<(Oa&7)>>>((32-qa|0)>>>0);Xa=qa+Oa|0;c[y>>2]=Qa>>>0>Xa>>>0?Xa:Qa;Qa=f+41088+(Ta*23220|0)+(Za*2580|0)+8|0;c[Qa>>2]=Pa+1;Pa=f+41088+(Ta*23220|0)+(Za*2580|0)+4|0;Xa=(c[Pa>>2]|0)+1|0;Oa=Xa>>>0>65535>>>0;qa=Oa?Xa>>>16:Xa;ab=Oa?16:0;if((qa&65280|0)==0){bb=ab;cb=qa}else{bb=ab|8;cb=qa>>>8}qa=(d[1191992+cb|0]|0)+bb|0;ab=((1<<qa|0)<(Xa|0))+qa|0;qa=c[y>>2]|0;Xa=c[u>>2]|0;Oa=(c[v>>2]|0)+(qa>>>3)|0;db=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(qa&7)>>>((32-ab|0)>>>0);Oa=ab+qa|0;c[y>>2]=Xa>>>0>Oa>>>0?Oa:Xa;Xa=db+2|0;Oa=f+41088+(Ta*23220|0)+(Za*2580|0)+12|0;c[Oa>>2]=Xa;qa=30-db|0;db=30-(c[Pa>>2]|0)|0;e:do{if((c[Qa>>2]|0)>0){Pa=0;ab=Xa;while(1){eb=c[y>>2]|0;fb=c[u>>2]|0;gb=(c[v>>2]|0)+(eb>>>3)|0;hb=(fe(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(eb&7)>>>((32-ab|0)>>>0);gb=eb+ab|0;c[y>>2]=fb>>>0>gb>>>0?gb:fb;b[f+41088+(Ta*23220|0)+(Za*2580|0)+16+(Pa<<1)>>1]=hb<<qa>>>(db>>>0);hb=Pa+1|0;if((hb|0)>=(c[Qa>>2]|0)){break e}Pa=hb;ab=c[Oa>>2]|0}}}while(0);Za=Za+1|0;}while((Za|0)<(c[Na>>2]|0))}}while(0);Na=Ta+1|0;Oa=a[r]|0;Qa=c[y>>2]|0;db=c[u>>2]|0;qa=c[v>>2]|0;if((Na|0)<(Oa<<24>>24|0)){Ta=Na;ha=Qa;ra=db;H=qa}else{ib=Qa;jb=db;kb=qa;lb=Oa;break}}}else{ib=P;jb=sa;kb=_;lb=Ma}H=kb+(ib>>>3)|0;ra=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(ib&7)>>>29;H=ib+3|0;ha=jb>>>0>H>>>0?H:jb;c[y>>2]=ha;c[h>>2]=ra;ra=kb+(ha>>>3)|0;H=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ha&7)>>>24;ra=ha+8|0;ha=jb>>>0>ra>>>0?ra:jb;c[y>>2]=ha;c[m>>2]=H+1;c[V>>2]=ba(a[U]|0,lb<<24>>24)|0;if(lb<<24>>24>0){mb=0}else{ya=ha;za=kb;Aa=jb;Ba=lb;break}do{ha=f+226848+(mb<<2)|0;if((c[ha>>2]|0)>0){H=0;do{c[f+41088+(mb*23220|0)+(H*2580|0)+2576>>2]=c[f+41088+(mb*23220|0)+(H*2580|0)>>2];H=H+1|0;}while((H|0)<(c[ha>>2]|0))}c[f+32996+(mb*144|0)+140>>2]=e[n>>1]|0;c[f+226948+(mb<<2)>>2]=1;c[f+226980+(mb<<2)>>2]=0;mb=mb+1|0;nb=a[r]|0;}while((mb|0)<(nb<<24>>24|0));ya=c[y>>2]|0;za=c[v>>2]|0;Aa=c[u>>2]|0;Ba=nb}}while(0);M=ya&7;T=d[za+(ya>>>3)|0]|0;c[y>>2]=((ya|0)<(Aa|0))+ya;if(Ba<<24>>24>0){w=0;while(1){c[f+226884+(w<<2)>>2]=1;S=w+1|0;Ma=a[r]|0;if((S|0)<(Ma<<24>>24|0)){w=S}else{ob=Ma;break}}}else{ob=Ba}w=(T&128>>>(M>>>0)|0)!=0;do{if(!w){if(ob<<24>>24>0){Ma=0;while(1){S=c[y>>2]|0;_=d[(c[v>>2]|0)+(S>>>3)|0]<<(S&7)>>>7;c[y>>2]=((S|0)<(c[u>>2]|0))+S;c[f+226884+(Ma<<2)>>2]=_&1;_=Ma+1|0;S=a[r]|0;if((_|0)<(S<<24>>24|0)){Ma=_}else{pb=S;break}}}else{pb=ob}if((c[j>>2]|0)==0){a[Q]=0;break}Ma=c[y>>2]|0;S=c[v>>2]|0;_=d[S+(Ma>>>3)|0]<<(Ma&7)>>>7;sa=c[u>>2]|0;P=((Ma|0)<(sa|0))+Ma|0;c[y>>2]=P;Ma=_&1;a[Q]=Ma;if(Ma<<24>>24==0){break}Ma=S+(P>>>3)|0;_=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(P&7)>>>27;Ma=P+5|0;P=sa>>>0>Ma>>>0?Ma:sa;c[y>>2]=P;Ma=_+1|0;c[R>>2]=Ma;_=S+(P>>>3)|0;ha=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(P&7)>>>28;_=P+4|0;P=sa>>>0>_>>>0?_:sa;c[y>>2]=P;c[B>>2]=ha;_=S+(P>>>3)|0;S=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(P&7)>>>29;_=P+3|0;c[y>>2]=sa>>>0>_>>>0?_:sa;sa=S+1|0;c[z>>2]=sa;S=sa+ha|0;if(pb<<24>>24>0){ha=32-S|0;sa=0;_=Ma;Ma=pb;while(1){if((_|0)>0){P=0;do{H=c[y>>2]|0;ra=c[u>>2]|0;I=(c[v>>2]|0)+(H>>>3)|0;Oa=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(H&7)>>ha;I=H+S|0;c[y>>2]=ra>>>0>I>>>0?I:ra;c[f+751336+(sa*160|0)+(P<<2)>>2]=Oa;P=P+1|0;qb=c[R>>2]|0;}while((P|0)<(qb|0));rb=qb;sb=a[r]|0}else{rb=_;sb=Ma}P=sa+1|0;if((P|0)<(sb<<24>>24|0)){sa=P;_=rb;Ma=sb}else{break}}}DDb(c[q>>2]|0,1911904,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}}while(0);M=c[y>>2]|0;T=c[v>>2]|0;Ma=d[T+(M>>>3)|0]|0;_=c[u>>2]|0;sa=((M|0)<(_|0))+M|0;c[y>>2]=sa;if((Ma&128>>>((M&7)>>>0)|0)==0){tb=0}else{M=T+(sa>>>3)|0;T=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(sa&7)>>>27;M=sa+5|0;c[y>>2]=_>>>0>M>>>0?M:_;tb=T}do{if(w){T=d[ja]|0;_=T-tb|0;if((_|0)<1){E=154;break b}M=a[r]|0;if(!(M<<24>>24>0)){ub=M;break}sa=(xa|0)>0;Ma=(T|0)==(tb|0);T=32-_|0;S=(_|0)<26;ha=_-16|0;P=48-_|0;Oa=0;ra=M;while(1){if(sa){M=0;do{do{if(Ma){vb=0}else{I=c[y>>2]|0;H=c[u>>2]|0;qa=c[v>>2]|0;db=qa+(I>>>3)|0;Qa=(fe(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(I&7);if(S){db=I+_|0;c[y>>2]=H>>>0>db>>>0?db:H;vb=Qa>>>(T>>>0);break}else{db=I+16|0;I=H>>>0>db>>>0?db:H;c[y>>2]=I;db=qa+(I>>>3)|0;qa=(fe(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(I&7)>>>(P>>>0);db=I+ha|0;c[y>>2]=H>>>0>db>>>0?db:H;vb=qa|Qa>>>16<<ha;break}}}while(0);c[f+752628+(Oa<<16)+(M<<2)>>2]=vb<<T>>T;M=M+1|0;}while((M|0)<(xa|0));wb=a[r]|0}else{wb=ra}M=Oa+1|0;if((M|0)<(wb<<24>>24|0)){Oa=M;ra=wb}else{ub=wb;break}}}else{ra=a[r]|0;if(!(ra<<24>>24>0)){ub=ra;break}ra=xa<<2;Oa=(xa|0)>0;T=xa>>>0>65535>>>0;ha=T?xa>>>16:xa;P=T?16:0;T=(ha&65280|0)==0;_=T?P:P|8;P=1191992+(T?ha:ha>>>8)|0;ha=0;while(1){do{if((c[f+226884+(ha<<2)>>2]|0)==0){TGb(f+227048+(ha<<16)|0,0,ra|0)|0}else{T=c[y>>2]|0;S=d[(c[v>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[y>>2]=((T|0)<(c[u>>2]|0))+T;T=S&1;S=f+226948+(ha<<2)|0;c[S>>2]=T;do{if((T|0)==0){if((c[f+32996+(ha*144|0)+140>>2]|0)==0){break}c[S>>2]=1}else{Ma=(d[P]|0)+_|0;sa=c[y>>2]|0;M=c[u>>2]|0;Qa=(c[v>>2]|0)+(sa>>>3)|0;qa=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(sa&7)>>>((32-Ma|0)>>>0);Qa=Ma+sa|0;c[y>>2]=M>>>0>Qa>>>0?Qa:M;c[f+226980+(ha<<2)>>2]=qa;if((qa|0)!=0){c[S>>2]=0}qa=f+32996+(ha*144|0)+140|0;M=c[qa>>2]|0;Qa=(e[n>>1]|0)>>>1;c[qa>>2]=(M|0)>(Qa|0)?M:Qa}}while(0);do{if((c[ia>>2]|0)==0){xb=0}else{S=d[ja]|0;T=c[y>>2]|0;Qa=c[u>>2]|0;M=(c[v>>2]|0)+(T>>>3)|0;qa=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(T&7)>>>((32-S|0)>>>0);M=T+S|0;c[y>>2]=Qa>>>0>M>>>0?M:Qa;c[f+227016+(ha<<2)>>2]=qa<<(c[h>>2]|0)+1;if((c[ia>>2]|0)==0){xb=0;break}qa=a[ja]|0;Qa=qa&255;if((a[Z]|0)!=0){M=Qa+1|0;S=c[y>>2]|0;T=c[u>>2]|0;sa=c[v>>2]|0;Ma=sa+(S>>>3)|0;H=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(S&7);if(M>>>0<26>>>0){Ma=31-Qa|0;db=S+M|0;c[y>>2]=T>>>0>db>>>0?db:T;yb=H>>>(Ma>>>0);zb=Ma}else{Ma=S+16|0;S=T>>>0>Ma>>>0?Ma:T;c[y>>2]=S;Ma=Qa-15|0;db=sa+(S>>>3)|0;sa=(fe(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(S&7)>>>((47-Qa|0)>>>0);db=S+Ma|0;c[y>>2]=T>>>0>db>>>0?db:T;yb=sa|H>>>16<<Ma;zb=31-Qa|0}c[f+227048+(ha<<16)>>2]=yb<<zb>>zb;xb=1;break}do{if(qa<<24>>24==0){Ab=0}else{Ma=c[y>>2]|0;H=c[u>>2]|0;sa=c[v>>2]|0;T=sa+(Ma>>>3)|0;db=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(Ma&7);if((qa&255)>>>0<26>>>0){T=Ma+Qa|0;c[y>>2]=H>>>0>T>>>0?T:H;Ab=db>>>((32-Qa|0)>>>0);break}else{T=Ma+16|0;Ma=H>>>0>T>>>0?T:H;c[y>>2]=Ma;T=Qa-16|0;S=sa+(Ma>>>3)|0;sa=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Ma&7)>>>((48-Qa|0)>>>0);S=Ma+T|0;c[y>>2]=H>>>0>S>>>0?S:H;Ab=sa|db>>>16<<T;break}}}while(0);qa=32-Qa|0;c[f+227048+(ha<<16)>>2]=Ab<<qa>>qa;xb=1}}while(0);f:do{if((xb|0)<(xa|0)){qa=f+227016+(ha<<2)|0;T=xb;do{db=c[v>>2]|0;sa=c[u>>2]|0;H=0;S=c[y>>2]|0;while(1){Ma=d[db+(S>>>3)|0]|0;Bb=((S|0)<(sa|0))+S|0;c[y>>2]=Bb;if((Ma&128>>>((S&7)>>>0)|0)==0){break}if(((c[O>>2]|0)-Bb|0)<1){break f}else{H=H+1|0;S=Bb}}if((H|0)>31){S=db+(Bb>>>3)|0;Ma=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Bb&7)>>>27;S=Bb+5|0;M=sa>>>0>S>>>0?S:sa;c[y>>2]=M;S=Ma+1|0;I=db+(M>>>3)|0;Na=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(M&7);if(S>>>0<26>>>0){I=S+M|0;S=sa>>>0>I>>>0?I:sa;c[y>>2]=S;Cb=Na>>>((Ma^31)>>>0);Db=S}else{S=M+16|0;M=sa>>>0>S>>>0?S:sa;c[y>>2]=M;S=Ma-15|0;I=db+(M>>>3)|0;Xa=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(M&7)>>>((47-Ma|0)>>>0);Ma=S+M|0;M=sa>>>0>Ma>>>0?Ma:sa;c[y>>2]=M;Cb=Xa|Na>>>16<<S;Db=M}Eb=Cb+H|0;Fb=Db}else{Eb=H;Fb=Bb}M=c[qa>>2]|0;S=c[h>>2]|0;Na=(1<<S)+M>>S+1;if(Na>>>0<2>>>0){Gb=Eb;Hb=M}else{M=(Na<<1)-2|0;Na=M>>>0>65535>>>0;Xa=Na?M>>>16:M;M=Na?16:0;if((Xa&65280|0)==0){Ib=M;Jb=Xa}else{Ib=M|8;Jb=Xa>>>8}Xa=(d[1191992+Jb|0]|0)+Ib|0;do{if((Xa|0)==0){Kb=0}else{M=db+(Fb>>>3)|0;Na=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Fb&7);if((Xa|0)<26){M=Xa+Fb|0;c[y>>2]=sa>>>0>M>>>0?M:sa;Kb=Na>>>((32-Xa|0)>>>0);break}else{M=Fb+16|0;Ma=sa>>>0>M>>>0?M:sa;c[y>>2]=Ma;M=Xa-16|0;I=db+(Ma>>>3)|0;ab=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(Ma&7)>>>((48-Xa|0)>>>0);I=M+Ma|0;c[y>>2]=sa>>>0>I>>>0?I:sa;Kb=ab|Na>>>16<<M;break}}}while(0);Gb=Kb+(Eb<<Xa)|0;Hb=c[qa>>2]|0}c[qa>>2]=Gb+Hb-(Hb>>S);c[f+227048+(ha<<16)+(T<<2)>>2]=Gb<<31>>31^Gb>>1;T=T+1|0;}while((T|0)<(xa|0))}}while(0);T=f+226848+(ha<<2)|0;qa=c[T>>2]|0;Qa=(qa|0)>0;sa=f+226916+(ha<<2)|0;do{if((c[ia>>2]|0)==0){if(Qa){Lb=qa}else{Mb=8;break}while(1){db=Lb-1|0;H=c[f+41088+(ha*23220|0)+(db*2580|0)+2576>>2]|0;do{if((c[sa>>2]|0)!=8){M=f+41088+(ha*23220|0)+(db*2580|0)|0;Na=(c[M>>2]|0)>0;if((c[j>>2]|0)==0){if(Na){Nb=0}else{break}do{ab=f+41088+(ha*23220|0)+(db*2580|0)+1552+(Nb<<1)|0;b[ab>>1]=(b[ab>>1]|0)/2|0;Nb=Nb+1|0;}while((Nb|0)<(c[M>>2]|0))}else{if(Na){Ob=0}else{break}do{ab=f+41088+(ha*23220|0)+(db*2580|0)+1552+(Ob+H<<1)|0;b[ab>>1]=(b[ab>>1]|0)/2|0;Ob=Ob+1|0;}while((Ob|0)<(c[M>>2]|0))}}}while(0);if((db|0)>0){Lb=db}else{Mb=8;break}}}else{if(Qa){Pb=qa}else{Mb=16;break}while(1){H=Pb-1|0;S=c[f+41088+(ha*23220|0)+(H*2580|0)+2576>>2]|0;do{if((c[sa>>2]|0)!=16){Xa=f+41088+(ha*23220|0)+(H*2580|0)|0;M=(c[Xa>>2]|0)>0;if((c[j>>2]|0)==0){if(M){Qb=0}else{break}do{Na=f+41088+(ha*23220|0)+(H*2580|0)+1552+(Qb<<1)|0;b[Na>>1]=b[Na>>1]<<1;Qb=Qb+1|0;}while((Qb|0)<(c[Xa>>2]|0))}else{if(M){Rb=0}else{break}do{Na=f+41088+(ha*23220|0)+(H*2580|0)+1552+(Rb+S<<1)|0;b[Na>>1]=b[Na>>1]<<1;Rb=Rb+1|0;}while((Rb|0)<(c[Xa>>2]|0))}}}while(0);if((H|0)>0){Pb=H}else{Mb=16;break}}}}while(0);c[sa>>2]=Mb;qa=c[T>>2]|0;if((qa|0)>0){Sb=qa}else{break}do{Sb=Sb-1|0;if(Oa){qa=f+41088+(ha*23220|0)+(Sb*2580|0)+4|0;Qa=f+41088+(ha*23220|0)+(Sb*2580|0)+2576|0;S=f+41088+(ha*23220|0)+(Sb*2580|0)|0;db=f+41088+(ha*23220|0)+(Sb*2580|0)+528|0;Xa=f+41088+(ha*23220|0)+(Sb*2580|0)+1552|0;M=0;do{Na=c[qa>>2]|0;ab=1<<Na-1;I=f+227048+(ha<<16)+(M<<2)|0;Ma=c[I>>2]|0;Pa=c[Qa>>2]|0;hb=c[S>>2]|0;fb=(hb|0)>0;if(fb){gb=0;eb=0;while(1){Tb=(ba(b[f+41088+(ha*23220|0)+(Sb*2580|0)+528+(gb+Pa<<1)>>1]|0,b[f+41088+(ha*23220|0)+(Sb*2580|0)+16+(gb<<1)>>1]|0)|0)+eb|0;Ub=gb+1|0;if((Ub|0)<(hb|0)){gb=Ub;eb=Tb}else{Vb=Tb;break}}}else{Vb=0}eb=(Vb+ab>>Na)+Ma|0;gb=1<<(d[ja]|0)-1;do{if((Ma|0)<0){if(fb){Wb=0}else{Xb=hb;break}while(1){H=f+41088+(ha*23220|0)+(Sb*2580|0)+16+(Wb<<1)|0;b[H>>1]=(b[H>>1]|0)-(b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(Wb+Pa<<1)>>1]|0);H=Wb+1|0;Tb=c[S>>2]|0;if((H|0)<(Tb|0)){Wb=H}else{Xb=Tb;break}}}else{if((Ma|0)<1|fb^1){Xb=hb;break}else{Yb=0}while(1){Tb=f+41088+(ha*23220|0)+(Sb*2580|0)+16+(Yb<<1)|0;b[Tb>>1]=(b[Tb>>1]|0)+(b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(Yb+Pa<<1)>>1]|0);Tb=Yb+1|0;H=c[S>>2]|0;if((Tb|0)<(H|0)){Yb=Tb}else{Xb=H;break}}}}while(0);if((Pa|0)==0){UGb(f+41088+(ha*23220|0)+(Sb*2580|0)+528+(Xb<<1)|0,db|0,Xb<<1)|0;hb=c[S>>2]|0;UGb(f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(hb<<1)|0,Xa|0,hb<<1)|0;Zb=c[S>>2]|0}else{Zb=Pa}hb=Zb-1|0;fb=-gb|0;Ma=gb-1|0;if((eb|0)<(fb|0)){_b=fb&65535}else{_b=((Ma|0)<(eb|0)?Ma:eb)&65535}b[f+41088+(ha*23220|0)+(Sb*2580|0)+528+(hb<<1)>>1]=_b;do{if((eb|0)==0){b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(hb<<1)>>1]=0}else{Ma=c[sa>>2]|0;if((eb|0)<0){b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(hb<<1)>>1]=-Ma;break}else{b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(hb<<1)>>1]=Ma;break}}}while(0);gb=f+41088+(ha*23220|0)+(Sb*2580|0)+1552+((c[S>>2]>>4)+hb<<1)|0;b[gb>>1]=(b[gb>>1]|0)>>>2;gb=f+41088+(ha*23220|0)+(Sb*2580|0)+1552+((c[S>>2]>>3)+hb<<1)|0;b[gb>>1]=(b[gb>>1]|0)>>>1;c[Qa>>2]=hb;c[I>>2]=eb;M=M+1|0;}while((M|0)<(xa|0))}}while((Sb|0)>0)}}while(0);sa=ha+1|0;T=a[r]|0;if((sa|0)<(T<<24>>24|0)){ha=sa}else{ub=T;break}}}}while(0);g:do{if((a[ka]|0)!=0){TGb(l|0,0,32)|0;if((xa|0)>0){$b=0;ac=ub}else{break}while(1){w=ac<<24>>24;if(ac<<24>>24>0){ha=ba(a[U]|0,w)|0;if((ha|0)>0){Oa=0;do{_=k+(Oa<<2)|0;c[_>>2]=0;if((c[f+226884+(Oa<<2)>>2]|0)!=0){P=ba(Oa,ha)|0;ra=c[V>>2]|0;T=0;sa=0;do{sa=(ba(b[f+34802+(T+P<<1)>>1]|0,b[f+39026+(T+ra<<1)>>1]|0)|0)+sa|0;T=T+1|0;}while((T|0)<(ha|0));c[_>>2]=sa;if((Oa|0)>0){T=ba(Oa,w)|0;ra=0;P=sa;do{P=(ba(b[f+38898+(ra+T<<1)>>1]|0,c[f+227048+(ra<<16)+($b<<2)>>2]|0)|0)+P|0;ra=ra+1|0;}while((ra|0)<(Oa|0));c[_>>2]=P;bc=P}else{bc=sa}ra=a[A]|0;T=(1<<ra-1)+bc>>ra;c[_>>2]=T;ra=f+227048+(Oa<<16)+($b<<2)|0;c[ra>>2]=T+(c[ra>>2]|0)}Oa=Oa+1|0;}while((Oa|0)<(w|0))}else{Oa=0;do{ha=k+(Oa<<2)|0;c[ha>>2]=0;if((c[f+226884+(Oa<<2)>>2]|0)!=0){if((Oa|0)>0){ra=ba(Oa,w)|0;T=0;M=0;do{M=(ba(b[f+38898+(T+ra<<1)>>1]|0,c[f+227048+(T<<16)+($b<<2)>>2]|0)|0)+M|0;T=T+1|0;}while((T|0)<(Oa|0));c[ha>>2]=M;cc=M}else{cc=0}T=a[A]|0;ra=(1<<T-1)+cc>>T;c[ha>>2]=ra;T=f+227048+(Oa<<16)+($b<<2)|0;c[T>>2]=ra+(c[T>>2]|0)}Oa=Oa+1|0;}while((Oa|0)<(w|0))}dc=a[r]|0}else{dc=ac}w=a[U]|0;Oa=dc<<24>>24;T=1<<(d[ja]|0)-1;if(dc<<24>>24>0){ra=ba(w,Oa)|0;_=(ra|0)>0;sa=0;do{P=(c[f+227048+(sa<<16)+($b<<2)>>2]|0)-(c[k+(sa<<2)>>2]|0)|0;do{if((P|0)>0){if(_){Qa=ba(sa,ra)|0;S=0;do{Xa=f+34802+(S+Qa<<1)|0;b[Xa>>1]=(b[Xa>>1]|0)+(b[f+40050+((c[V>>2]|0)+S<<1)>>1]|0);S=S+1|0;}while((S|0)<(ra|0))}if((sa|0)<=0){break}S=ba(sa,Oa)|0;Qa=0;do{Xa=c[f+227048+(Qa<<16)+($b<<2)>>2]|0;do{if((Xa|0)>0){db=f+38898+(Qa+S<<1)|0;b[db>>1]=(b[db>>1]|0)+1}else{if((Xa|0)>=0){break}db=f+38898+(Qa+S<<1)|0;b[db>>1]=(b[db>>1]|0)-1}}while(0);Qa=Qa+1|0;}while((Qa|0)<(sa|0))}else{if((P|0)>=0){break}if(_){Qa=ba(sa,ra)|0;S=0;do{Xa=f+34802+(S+Qa<<1)|0;b[Xa>>1]=(b[Xa>>1]|0)-(b[f+40050+((c[V>>2]|0)+S<<1)>>1]|0);S=S+1|0;}while((S|0)<(ra|0))}if((sa|0)<=0){break}S=ba(sa,Oa)|0;Qa=0;do{Xa=c[f+227048+(Qa<<16)+($b<<2)>>2]|0;do{if((Xa|0)>0){eb=f+38898+(Qa+S<<1)|0;b[eb>>1]=(b[eb>>1]|0)-1}else{if((Xa|0)>=0){break}eb=f+38898+(Qa+S<<1)|0;b[eb>>1]=(b[eb>>1]|0)+1}}while(0);Qa=Qa+1|0;}while((Qa|0)<(sa|0))}}while(0);sa=sa+1|0;}while((sa|0)<(Oa|0));sa=T-1|0;ra=sa&65535;_=-T|0;P=_&65535;ha=Oa;M=c[V>>2]|0;while(1){Qa=ha-1|0;S=M-1|0;c[V>>2]=S;Xa=f+227048+(Qa<<16)+($b<<2)|0;b[f+39026+(S<<1)>>1]=c[Xa>>2];S=c[Xa>>2]|0;do{if((S|0)>(sa|0)){b[f+39026+(c[V>>2]<<1)>>1]=ra}else{if((S|0)>=(_|0)){break}b[f+39026+(c[V>>2]<<1)>>1]=P}}while(0);b[f+40050+(c[V>>2]<<1)>>1]=0;S=c[Xa>>2]|0;do{if((S|0)>0){b[f+40050+(c[V>>2]<<1)>>1]=1}else{if((S|0)>=0){break}b[f+40050+(c[V>>2]<<1)>>1]=-1}}while(0);S=c[V>>2]|0;if((Qa|0)>0){ha=Qa;M=S}else{ec=S;break}}}else{ec=c[V>>2]|0}if((ec|0)==0){M=ba(w,Oa)|0;ha=ba(w<<1,Oa)|0;UGb(f+39026+(M<<1)|0,t|0,ha)|0;UGb(f+40050+(M<<1)|0,X|0,ha)|0;c[V>>2]=M}M=$b+1|0;if((M|0)>=(xa|0)){break g}$b=M;ac=a[r]|0}}}while(0);do{if((a[Z]|0)!=0){if((a[r]|0)!=2){break}if((c[$>>2]|0)==0){if((c[D>>2]|0)!=0&(xa|0)>0){fc=0}else{break}}else{if((xa|0)>0){fc=0}else{break}}do{M=f+292584+(fc<<2)|0;ha=c[M>>2]|0;P=f+227048+(fc<<2)|0;_=(c[P>>2]|0)-(ha>>1)|0;c[P>>2]=_;c[M>>2]=_+ha;fc=fc+1|0;}while((fc|0)<(xa|0))}}while(0);do{if((a[ea]|0)!=0){ha=a[W]|0;_=a[Y]|0;M=_<<24>>24;if((a[r]|0)<=0){break}P=_<<24>>24>0;_=(M|0)<(xa|0);ra=xa-1|0;sa=0;do{if(P){T=0;do{S=T-1|0;Xa=0;eb=0;while(1){if((T|0)>(Xa|0)){I=c[f+227048+(sa<<16)+(S-Xa<<2)>>2]|0;hb=f+34160+(Xa<<3)|0;db=gHb(I,(I|0)<0|0?-1:0,c[hb>>2]|0,c[hb+4>>2]|0)|0;hb=YGb(db,F,eb,0)|0;gc=hb}else{hb=f+34160+(Xa<<3)|0;db=c[f+34288+(sa<<6)+(Xa-T<<2)>>2]|0;I=gHb(db,(db|0)<0|0?-1:0,c[hb>>2]|0,c[hb+4>>2]|0)|0;hb=YGb(I,F,eb,0)|0;gc=hb}hb=Xa+1|0;if((hb|0)<(M|0)){Xa=hb;eb=gc}else{break}}eb=f+227048+(sa<<16)+(T<<2)|0;c[eb>>2]=(c[eb>>2]|0)+(gc>>ha);T=T+1|0;}while((T|0)<(M|0))}if(_){T=M;do{if(P){Oa=T-1|0;w=0;eb=0;while(1){Xa=c[f+227048+(sa<<16)+(Oa-w<<2)>>2]|0;S=f+34160+(w<<3)|0;Qa=gHb(Xa,(Xa|0)<0|0?-1:0,c[S>>2]|0,c[S+4>>2]|0)|0;S=YGb(Qa,F,eb,0)|0;Qa=S;S=w+1|0;if((S|0)<(M|0)){w=S;eb=Qa}else{hc=Qa;break}}}else{hc=0}eb=f+227048+(sa<<16)+(T<<2)|0;c[eb>>2]=(c[eb>>2]|0)+(hc>>ha);T=T+1|0;}while((T|0)<(xa|0))}if(P){T=0;do{c[f+34288+(sa<<6)+(T<<2)>>2]=c[f+227048+(sa<<16)+(ra-T<<2)>>2];T=T+1|0;}while((T|0)<(M|0))}sa=sa+1|0;}while((sa|0)<(a[r]|0))}}while(0);do{if((c[m>>2]|0)!=1){sa=a[r]|0;if(!(sa<<24>>24>0)){break}M=(xa|0)>0;ra=0;P=sa;while(1){if(M){sa=0;do{ha=f+227048+(ra<<16)+(sa<<2)|0;c[ha>>2]=ba(c[ha>>2]|0,c[m>>2]|0)|0;sa=sa+1|0;}while((sa|0)<(xa|0));ic=a[r]|0}else{ic=P}sa=ra+1|0;if((sa|0)<(ic<<24>>24|0)){ra=sa;P=ic}else{break}}}}while(0);P=a[C]|0;do{if(P<<24>>24>0){ra=0;M=P;while(1){sa=a[f+32987+ra|0]|0;ha=b[f+32996+(sa*144|0)+4+(d[f+32996+(sa*144|0)+132|0]<<1)>>1]|0;_=ha&65535;if(ha<<16>>16==0){jc=M}else{ha=f+32916+(sa<<2)|0;T=f+32948+(sa<<2)|0;eb=0;do{w=c[f+227048+(sa<<16)+(eb<<2)>>2]|0;if((a[ja]|0)==16){Oa=c[ha>>2]|0;c[ha>>2]=Oa+2;b[Oa>>1]=w<<16>>16<<tb}else{Oa=c[T>>2]|0;c[T>>2]=Oa+4;c[Oa>>2]=w<<tb}eb=eb+1|0;}while((eb|0)<(_|0));jc=a[C]|0}_=ra+1|0;kc=jc<<24>>24;if((_|0)<(kc|0)){ra=_;M=jc}else{break}}if(jc<<24>>24>0){lc=0}else{break}do{M=a[f+32987+lc|0]|0;ra=f+32996+(M*144|0)+132|0;_=a[ra]|0;if(!((_&255)>>>0<(d[f+32996+(M*144|0)+3|0]|0)>>>0)){E=346;break b}a[ra]=_+1;lc=lc+1|0;}while((lc|0)<(kc|0))}}while(0);if((a[ga]|0)!=0){E=350;break}G=a[r]|0;da=c[y>>2]|0}if((E|0)==85){DDb(c[q>>2]|0,1963280,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==123){yDb(c[q>>2]|0,16,2328744,(aa=i,i=i+32|0,c[aa>>2]=Ta,c[aa+8>>2]=Ua,c[aa+16>>2]=Va,c[aa+24>>2]=256,aa)|0);i=aa;c[fa>>2]=0}else if((E|0)==129){yDb(c[q>>2]|0,48,1935136,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;KCb(c[o>>2]|0)}else if((E|0)==154){yDb(c[q>>2]|0,16,1891400,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==346){yDb(c[q>>2]|0,16,2348928,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==350){E=f+32981|0;if((a[E]|0)!=0){a[E]=0}E=c[y>>2]|0;if((c[p>>2]|0)==0){mc=E;nc=c[u>>2]|0}else{p=c[f+32876>>2]|0;if((x|0)!=(E+2-p|0)){yDb(c[q>>2]|0,16,2000184,(aa=i,i=i+16|0,c[aa>>2]=c[f+32888>>2],c[aa+8>>2]=x-1-E+p,aa)|0);i=aa;a[f+32884|0]=1;s=0;i=g;return s|0}aa=x-1-E+p|0;p=-E|0;x=c[u>>2]|0;u=x-E|0;if((aa|0)<(p|0)){oc=p}else{oc=(u|0)<(aa|0)?u:aa}aa=oc+E|0;c[y>>2]=aa;mc=aa;nc=x}x=d[(c[ca>>2]|0)+(mc>>>3)|0]<<(mc&7)>>>7;c[y>>2]=((mc|0)<(nc|0))+mc;mc=f+32888|0;c[mc>>2]=(c[mc>>2]|0)+1;s=x&1;i=g;return s|0}a[f+32884|0]=1;x=(c[o>>2]|0)+76|0;if((c[x>>2]|0)==0){s=0;i=g;return s|0}c[x>>2]=na;s=0;i=g;return s|0}a[f+32884|0]=1;KCb(c[o>>2]|0);s=-1094995529;i=g;return s|0}function Bcb(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;j=c[f+60>>2]|0;k=c[f+96>>2]|0;l=f+432|0;if((c[l>>2]|0)==0){yDb(f,16,2164048,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=h;return n|0}o=j;c[o>>2]=f;fCb(j+4|0,c[f+88>>2]&8388608);p=j+40|0;c[j+32844>>2]=262144;c[j+32832>>2]=p;c[j+32840>>2]=j+32808;c[j+32836>>2]=p;c[j+32828>>2]=32;c[j+32824>>2]=0;c[f+420>>2]=8;if((c[f+100>>2]|0)<=17){DDb(f,2157128,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1163346256;i=h;return n|0}p=k+14|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=q&65535;r=j+66176|0;c[r>>2]=p;s=k+2|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k;k=j+66182|0;a[k]=(d[s]|d[s+1|0]<<8)<<16>>16;s=c[l>>2]|0;l=s>>>0>65535>>>0;u=l?s>>>16:s;s=l?16:0;if((u&65280|0)==0){v=s;w=u}else{v=s|8;w=u>>>8}u=v+4+(d[1191992+w|0]|0)|0;w=j+66186|0;b[w>>1]=u;if((u&65534)>>>0>25>>>0){DDb(f,2150400,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1163346256;i=h;return n|0}a[j+68613|0]=1;a[j+68580|0]=1;u=j+66180|0;a[u]=q&64;q=ncb(c[f+412>>2]|0,3,p)|0;if((q|0)>13){DDb(f,2143464,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1163346256;i=h;return n|0}p=1<<q&65535;q=j+66184|0;b[q>>1]=p;v=c[r>>2]|0;s=v>>>3&7;l=1<<s;x=l&255;y=j+66189|0;a[y]=x;z=l&255;if((z|0)==16|(z|0)==4){a[j+66191|0]=1}a[j+66190|0]=(a[1191992+s|0]|0)+1;z=s+1|0;s=(p&65535)/(l&65535&255)|0;b[j+66192>>1]=s;a[j+66181|0]=v&255&-128;if((x&255)>>>0>32>>>0){yDb(f,16,2138048,(m=i,i=i+8|0,c[m>>2]=l&255,m)|0);i=m;n=-1094995529;i=h;return n|0}if((s&65535)>>>0<64>>>0){yDb(f,16,2131344,(m=i,i=i+8|0,c[m>>2]=s&65535,m)|0);i=m;n=-1094995529;i=h;return n|0}if((c[(c[o>>2]|0)+412>>2]|0)<1){yDb(f,16,2124936,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=h;return n|0}s=c[f+416>>2]|0;if((s|0)<0){yDb(f,16,2119384,(m=i,i=i+8|0,c[m>>2]=s,m)|0);i=m;n=-1094995529;i=h;return n|0}if((s|0)>8){DDb(f,2113304,(m=i,i=i+8|0,c[m>>2]=8,m)|0);i=m;n=-1163346256;i=h;return n|0}if((s|0)>0){l=j+71200|0;x=0;do{b[l+(x*49568|0)>>1]=p;x=x+1|0;}while((x|0)<(s|0))}s=j+66188|0;a[s]=-1;if((t&8|0)!=0){if((t&1|0)==0){A=-1}else{a[s]=0;A=0}if((t&2|0)==0){B=A}else{x=A+1&255;a[s]=x;B=x}if((t&4|0)==0){C=B}else{x=B+1&255;a[s]=x;C=x}a[s]=C+1}c[1077867]=8635576;c[1077869]=616;N_(4311464,8,121,478840,1,1,478592,2,2,0,0,0,4)|0;c[1077873]=8629952;c[1077875]=1406;N_(4311488,9,120,477176,1,1,476696,4,4,0,0,0,4)|0;c[2194061]=8621520;c[2194063]=2108;N_(8776240,9,272,1457376,1,1,1453624,4,4,0,0,0,4)|0;c[2194066]=8605872;c[2194068]=3912;N_(8776260,9,244,1451184,1,1,1447984,4,4,0,0,0,4)|0;c[646531]=8603456;c[646533]=604;N_(2586120,9,127,142264,1,1,142008,2,2,0,0,0,4)|0;c[646537]=8601208;c[646539]=562;N_(2586144,9,137,142672,1,1,142392,2,2,0,0,0,4)|0;c[646543]=8598960;c[646545]=562;N_(2586168,9,101,143024,1,1,142816,2,2,0,0,0,4)|0;C=j+66202|0;s=0;while(1){if((s|0)>=(z|0)){break}x=(e[q>>1]|0)>>>(s>>>0);b[C+(s*58|0)>>1]=0;B=x<<1;A=1;p=0;while(1){l=b[C+(s*58|0)+(A-1<<1)>>1]|0;if((l|0)>=(x|0)){D=A;break}v=ba(B,e[1417808+(p<<1)>>1]|0)|0;E=((v|0)/(c[(c[o>>2]|0)+412>>2]|0)|0)+2&-4;if((E|0)>(l|0)){b[C+(s*58|0)+(A<<1)>>1]=E;F=A+1|0}else{F=A}E=p+1|0;if((E|0)<28){A=F;p=E}else{D=F;break}}p=D-1|0;b[C+(s*58|0)+(p<<1)>>1]=x;A=p&255;a[j+(s+66194)|0]=A;if(A<<24>>24<1){G=39;break}else{s=s+1|0}}if((G|0)==39){yDb(f,16,2067784,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=h;return n|0}s=j+66666|0;D=0;a:do{F=j+(D+66194)|0;if((a[F]|0)>0){A=0;while(1){p=A+1|0;B=(b[C+(D*58|0)+(A<<1)>>1]|0)-1+(b[C+(D*58|0)+(p<<1)>>1]|0)<<D>>1;E=0;do{l=0;while(1){v=l+1|0;if((b[C+(E*58|0)+(v<<1)>>1]<<E|0)>=(B|0)){break}if((v|0)<29){l=v}else{G=47;break a}}a[s+(D*232|0)+(E*29|0)+A|0]=l;E=E+1|0;}while((E|0)<(z|0));if((p|0)<(a[F]|0)){A=p}else{break}}}D=D+1|0;}while((D|0)<(z|0));if((G|0)==47){yDb(0,0,1935104,(m=i,i=i+24|0,c[m>>2]=2063392,c[m+8>>2]=1891376,c[m+16>>2]=448,m)|0);i=m;Cd();return 0}G=j+32848|0;D=0;do{aLa(G+(D<<6)|0,D+7|0,1,1.0/+(1<<D+5|0)/+(1<<(d[k]|0)-1|0))|0;D=D+1|0;}while((D|0)<8);VXa(13);c[j+66172>>2]=c[284569];VXa(12);c[j+66168>>2]=c[284568];VXa(11);c[j+66164>>2]=c[284567];VXa(10);c[j+66160>>2]=c[284566];VXa(9);c[j+66156>>2]=c[284565];VXa(8);c[j+66152>>2]=c[284564];VXa(7);c[j+66148>>2]=c[284563];VXa(6);c[j+66144>>2]=c[284562];D=j+68522|0;j=0;while(1){G=(e[q>>1]|0)>>>(j>>>0);s=c[(c[o>>2]|0)+412>>2]|0;C=((G*440|0)-1+((s>>1)*3|0)|0)/(s|0)|0;if((C|0)<4){H=4}else{H=((C|0)>(G|0)?G:C)&65535}b[D+(j<<1)>>1]=H;C=j+1|0;if((C|0)<(z|0)){j=C}else{I=0;break}}do{g[4311160+(I<<2)>>2]=+U(+(I|0)*3.141592653589793*.015625);I=I+1|0;}while((I|0)<33);if((c[f+688>>2]&4|0)!=0){I=d[k]|0;yDb(c[o>>2]|0,48,2059688,(m=i,i=i+16|0,c[m>>2]=2054656,c[m+8>>2]=I,m)|0);i=m;I=c[r>>2]|0;yDb(c[o>>2]|0,48,2043824,(m=i,i=i+16|0,c[m>>2]=2039008,c[m+8>>2]=I,m)|0);i=m;I=e[q>>1]|0;yDb(c[o>>2]|0,48,2059688,(m=i,i=i+16|0,c[m>>2]=2035944,c[m+8>>2]=I,m)|0);i=m;I=e[w>>1]|0;yDb(c[o>>2]|0,48,2059688,(m=i,i=i+16|0,c[m>>2]=2032048,c[m+8>>2]=I,m)|0);i=m;I=d[y]|0;yDb(c[o>>2]|0,48,2059688,(m=i,i=i+16|0,c[m>>2]=2027968,c[m+8>>2]=I,m)|0);i=m;I=d[u]|0;yDb(c[o>>2]|0,48,2059688,(m=i,i=i+16|0,c[m>>2]=2024328,c[m+8>>2]=I,m)|0);i=m;I=c[o>>2]|0;o=c[I+416>>2]|0;yDb(I,48,2059688,(m=i,i=i+16|0,c[m>>2]=2021032,c[m+8>>2]=o,m)|0);i=m}m=f+448|0;c[m>>2]=t;c[m+4>>2]=0;n=0;i=h;return n|0}function Ccb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;j=i;k=c[b+60>>2]|0;l=k;m=k+68540|0;n=m;o=c[h+24>>2]|0;p=h+28|0;h=c[p>>2]|0;c[g>>2]=0;q=k+68581|0;a:do{if((a[q]|0)==0){r=k+68580|0;if((a[r]|0)!=0){s=3;break}t=(c[p>>2]|0)-(c[k+68560>>2]|0)<<3;c[k+68608>>2]=t;u=t>>>0>2147483639>>>0|(o|0)==0;v=u?0:o;w=u?0:t;c[m>>2]=v;c[k+68552>>2]=w;u=w+8|0;c[k+68556>>2]=u;c[k+68544>>2]=v+(w>>3);w=d[k+68564|0]|0;x=u>>>0>w>>>0?w:u;c[k+68548>>2]=x;do{if((a[k+66180|0]|0)==0){if((c[k+68568>>2]|0)<=(c[k+68596>>2]|0)){break}u=(Gcb(l,f,g)|0)==0|0;a[q]=u;y=u;s=24;break a}else{u=t-x|0;w=e[k+66186>>1]|0;if((u|0)<=(w|0)){break}z=v+(x>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>((32-w|0)>>>0);if((A|0)==0|(A|0)>(u|0)){break}Fcb(l,n,A,0);if((a[r]|0)!=0){s=23;break a}A=(Gcb(l,f,g)|0)==0|0;a[q]=A;y=A;s=24;break a}}while(0);a[q]=1;B=k+68580|0;s=26}else{s=3}}while(0);do{if((s|0)==3){a[q]=0;p=b+432|0;r=c[p>>2]|0;if((h|0)<(r|0)){yDb(b,16,2178280,(C=i,i=i+16|0,c[C>>2]=h,c[C+8>>2]=r,C)|0);i=C;D=-1094995529;i=j;return D|0}c[k+68560>>2]=h-r;r=c[p>>2]<<3;p=k+68608|0;c[p>>2]=r;x=r>>>0>2147483639>>>0|(o|0)==0;v=x?0:o;t=x?0:r;c[m>>2]=v;c[k+68552>>2]=t;r=t+8|0;c[k+68556>>2]=r;c[k+68544>>2]=v+(t>>3);t=k+68548|0;c[t>>2]=0;x=v;A=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>4&15;x=r>>>0>4>>>0?6:r|2;u=r>>>0>x>>>0?x:r;c[t>>2]=u;x=e[k+66186>>1]|0;w=v+(u>>>3)|0;v=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>((32-x|0)>>>0);w=u+x|0;c[t>>2]=r>>>0>w>>>0?w:r;r=k+68580|0;w=k+68565|0;do{if((a[r]|0)==0){x=d[w]|0;if((x+1&15|0)==(A|0)){break}a[r]=1;yDb(b,16,2102016,(C=i,i=i+16|0,c[C>>2]=x,c[C+8>>2]=A,C)|0);i=C}}while(0);a[w]=A;do{if((v|0)>0){x=(c[p>>2]|0)-(c[t>>2]|0)|0;if((v|0)<(x|0)){E=v}else{a[q]=1;E=x}Fcb(l,n,E,1);if((a[r]|0)!=0){break}Gcb(l,f,g)|0;s=13}else{s=13}}while(0);if((s|0)==13){if((a[r]|0)==0){s=23;break}}c[k+68568>>2]=0;a[r]=0;s=23}}while(0);if((s|0)==23){y=a[q]|0;s=24}do{if((s|0)==24){q=k+68580|0;if(y<<24>>24==0){F=q;break}g=k+68580|0;if((a[q]|0)==0){B=g;s=26}else{F=g}}}while(0);do{if((s|0)==26){y=(c[k+68608>>2]|0)-(c[k+68548>>2]|0)|0;if((y|0)<=0){F=B;break}Fcb(l,n,y,0);F=B}}while(0);B=c[k+68548>>2]|0;a[k+68564|0]=B&7;if((a[F]|0)!=0){D=-1094995529;i=j;return D|0}D=B>>3;i=j;return D|0}function Dcb(a){a=a|0;var b=0;b=c[a+60>>2]|0;bLa(b+32848|0);bLa(b+32912|0);bLa(b+32976|0);bLa(b+33040|0);bLa(b+33104|0);bLa(b+33168|0);bLa(b+33232|0);bLa(b+33296|0);return 0}function Ecb(b){b=b|0;var d=0,f=0,g=0,h=0,i=0;d=c[b+60>>2]|0;f=b+416|0;if((c[f>>2]|0)<=0){g=d+68580|0;a[g]=1;return}b=d+71200|0;h=d+66184|0;i=0;do{TGb(b+(i*49568|0)+416|0,0,(e[h>>1]|0)<<2|0)|0;i=i+1|0;}while((i|0)<(c[f>>2]|0));g=d+68580|0;a[g]=1;return}function Fcb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=i;j=(g|0)!=0;if(j){k=c[b+32828>>2]|0;l=c[b+32836>>2]|0}else{g=c[e+8>>2]&7;c[b+68572>>2]=g;c[b+68568>>2]=g;g=b+40|0;c[b+32844>>2]=262144;c[b+32832>>2]=g;c[b+32840>>2]=b+32808;c[b+32836>>2]=g;c[b+32828>>2]=32;c[b+32824>>2]=0;k=32;l=g}g=b+32824|0;m=b+32828|0;n=b+32836|0;o=l;do{if((f|0)>=1){if((f+40-k+(o-(c[b+32832>>2]|0)<<3)>>3|0)>32768){break}if((k-32+((c[b+32840>>2]|0)-o<<3)|0)<(f|0)){yDb(0,0,1935104,(p=i,i=i+24|0,c[p>>2]=2174032,c[p+8>>2]=1891376,c[p+16>>2]=1485,p)|0);i=p;Cd()}q=b+68568|0;r=(c[q>>2]|0)+f|0;c[q>>2]=r;if(j){s=e+8|0;t=c[s>>2]|0;u=t&7;v=8-u|0;w=(v|0)>(f|0)?f:v;v=e+16|0;y=c[v>>2]|0;z=e|0;A=c[z>>2]|0;B=A+(t>>>3)|0;C=32-w|0;D=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<u>>>(C>>>0);u=w+t|0;c[s>>2]=y>>>0>u>>>0?u:y;y=g|0;u=c[y>>2]|0;t=c[m>>2]|0;if((t|0)>(w|0)){E=t-w|0;F=u<<w|D;G=A}else{A=l;x=fe(D>>>((w-t|0)>>>0)|u<<t|0)|0;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;E=C+t|0;F=D;G=c[z>>2]|0}c[y>>2]=F;c[m>>2]=E;y=f-w|0;M_(g,G+(c[s>>2]>>3)|0,y);H=y;I=v}else{M_(g,(c[e>>2]|0)+(c[e+8>>2]>>3)|0,r);H=f;I=e+16|0}r=e+8|0;v=c[r>>2]|0;y=-v|0;s=(c[I>>2]|0)-v|0;if((H|0)<(y|0)){J=y}else{J=(s|0)<(H|0)?s:H}c[r>>2]=J+v;v=c[b+32824>>2]|0;r=v;s=c[m>>2]|0;if((s|0)<32){y=v<<s;r=y;v=y>>>24&255;y=s;s=c[n>>2]|0;while(1){a[s]=v;w=r;r=w<<8;z=y+8|0;if((z|0)<32){v=w>>>16&255;y=z;s=s+1|0}else{break}}}r=0;s=b+40|0;y=c[q>>2]|0;v=y>>>0>2147483639>>>0|(s|0)==0;z=v?0:s;s=v?0:y;c[b+68588>>2]=z;c[b+68600>>2]=s;y=s+8|0;c[b+68604>>2]=y;c[b+68592>>2]=z+(s+7>>3);s=c[b+68572>>2]|0;c[b+68596>>2]=y>>>0>s>>>0?s:y;i=h;return}}while(0);DDb(c[b>>2]|0,2190680,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;a[b+68580|0]=1;i=h;return}function Gcb(f,h,j){f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0.0,sb=0.0,tb=0.0,ub=0.0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0.0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0;k=i;i=i+136|0;l=k|0;m=k+16|0;n=k+24|0;o=k+88|0;p=k+104|0;q=f|0;r=c[q>>2]|0;s=f+68588|0;t=f+66180|0;if((a[t]|0)==0){u=0}else{v=e[f+66186>>1]|0;w=f+68596|0;x=c[w>>2]|0;y=c[f+68604>>2]|0;z=(c[s>>2]|0)+(x>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>((32-v|0)>>>0);z=x+v|0;c[w>>2]=y>>>0>z>>>0?z:y;u=A}TGb(l|0,0,16)|0;A=r+416|0;y=c[A>>2]|0;if((y|0)>0){z=0;while(1){a[f+71200+(z*49568|0)+3|0]=0;w=z+1|0;v=c[q>>2]|0;if((w|0)<(c[v+416>>2]|0)){z=w}else{B=v;break}}}else{B=r}z=f+68596|0;if((a[f+66189|0]|0)==1){C=f+68588|0;D=f+68604|0;E=8}else{v=c[z>>2]|0;w=f+68588|0;x=d[(c[w>>2]|0)+(v>>>3)|0]|0;F=f+68604|0;c[z>>2]=((v|0)<(c[F>>2]|0))+v;if((x&128>>>((v&7)>>>0)|0)==0){G=0;H=w;I=F;J=w}else{C=w;D=F;E=8}}if((E|0)==8){G=1;H=C;I=D;J=f+68588|0}D=f+66184|0;C=f+66192|0;F=f+68600|0;w=f+66191|0;v=f+66190|0;x=y;y=0;K=B;L=c[B+416>>2]|0;M=B;a:while(1){B=K+416|0;b:do{if((L|0)>0){if(G|(x|0)==1){N=0;while(1){a[m+N|0]=(e[l+(N<<1)>>1]|0)==(y|0)|0;N=N+1|0;if((N|0)>=(c[B>>2]|0)){break b}}}else{O=0}do{do{if((e[l+(O<<1)>>1]|0)==(y|0)){if((y|0)==((e[D>>1]|0)-(e[C>>1]|0)|0)){a[m+O|0]=1;break}else{N=c[z>>2]|0;P=d[(c[H>>2]|0)+(N>>>3)|0]<<(N&7)>>>7;c[z>>2]=((N|0)<(c[I>>2]|0))+N;a[m+O|0]=P&1;break}}else{a[m+O|0]=0}}while(0);O=O+1|0;}while((O|0)<(c[B>>2]|0))}}while(0);P=b[D>>1]|0;N=P&65535;Q=e[C>>1]|0;if((N-Q|0)==(y|0)){R=Q}else{T=c[z>>2]|0;if(((c[F>>2]|0)-T|0)<1){break}do{if((a[w]|0)==0){U=d[v]|0;V=c[I>>2]|0;W=(c[J>>2]|0)+(T>>>3)|0;X=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(T&7)>>>((32-U|0)>>>0);W=U+T|0;c[z>>2]=V>>>0>W>>>0?W:V;Y=X}else{X=c[J>>2]|0;V=d[X+(T>>>3)|0]|0;W=c[I>>2]|0;U=((T|0)<(W|0))+T|0;c[z>>2]=U;if((V&128>>>((T&7)>>>0)|0)==0){Y=0;break}V=d[v]|0;Z=X+(U>>>3)|0;X=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(U&7)>>>((33-V|0)>>>0);Z=U-1+V|0;c[z>>2]=W>>>0>Z>>>0?Z:W;Y=X+1|0}}while(0);_=N>>>(Y>>>0);if((_|0)<(Q|0)|(_|0)>(N|0)){E=26;break}else{R=_}}if((R|0)<1){break}T=R+y|0;X=c[B>>2]|0;if((X|0)>0){W=R&65535;Z=T;V=0;U=x;$=K;aa=P;ca=M;while(1){do{if((a[m+V|0]|0)==0){da=e[l+(V<<1)>>1]|0;if((da|0)>(Z|0)){ea=U;fa=Z;ga=aa;ha=$;ia=ca;break}ja=(da|0)<(Z|0);ea=ja?1:U+1|0;fa=ja?da:Z;ga=aa;ha=$;ia=ca}else{da=f+71200+(V*49568|0)+3|0;ja=a[da]|0;if((ja&255)>>>0>31>>>0){E=32;break a}b[f+71200+(V*49568|0)+4+((ja&255)<<1)>>1]=W;ja=l+(V<<1)|0;ka=(e[ja>>1]|0)+R&65535;b[ja>>1]=ka;a[da]=(a[da]|0)+1;da=b[D>>1]|0;la=c[q>>2]|0;if((ka&65535)>>>0>(da&65535)>>>0){E=34;break a}else{ea=U;fa=Z;ga=da;ha=la;ia=la}}}while(0);da=V+1|0;ka=c[ha+416>>2]|0;if((da|0)<(ka|0)){Z=fa;V=da;U=ea;$=ha;aa=ga;ca=ia}else{ma=fa;na=ea;oa=ha;pa=ga;qa=ka;ra=ia;break}}}else{ma=T;na=x;oa=K;pa=P;qa=X;ra=M}if((ma|0)<(pa&65535|0)){x=na;y=ma;K=oa;L=qa;M=ra}else{E=39;break}}if((E|0)==26){yDb(K,16,2199296,(sa=i,i=i+8|0,c[sa>>2]=_,sa)|0);i=sa}else if((E|0)==32){yDb($,16,2216848,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==34){yDb(la,16,2207456,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==39){if((qa|0)>0){qa=0;la=oa;oa=ra;while(1){$=f+71200+(qa*49568|0)+3|0;if((a[$]|0)==0){ta=la;ua=oa}else{_=0;K=0;do{b[f+71200+(qa*49568|0)+68+(_<<1)>>1]=K;K=(e[f+71200+(qa*49568|0)+4+(_<<1)>>1]|0)+K|0;_=_+1|0;}while((_|0)<(d[$]|0));$=c[q>>2]|0;ta=$;ua=$}$=qa+1|0;if(($|0)<(c[ta+416>>2]|0)){qa=$;la=ta;oa=ua}else{va=ua;break}}}else{va=ra}do{if((c[va+416>>2]|0)>1){ra=c[z>>2]|0;ua=c[s>>2]|0;oa=d[ua+(ra>>>3)|0]|0;ta=c[f+68604>>2]|0;la=((ra|0)<(ta|0))+ra|0;c[z>>2]=la;if((oa&128>>>((ra&7)>>>0)|0)==0){break}ra=d[ua+(la>>>3)|0]|0;ua=((la|0)<(ta|0))+la|0;c[z>>2]=ua;if((ra&128>>>((la&7)>>>0)|0)==0){break}la=c[A>>2]|0;if((ba(la,la)|0)==0){break}else{wa=0;xa=ua}do{ua=xa+4|0;xa=ta>>>0>ua>>>0?ua:ta;c[z>>2]=xa;wa=wa+1|0;ua=c[A>>2]|0;}while((wa|0)<(ba(ua,ua)|0))}}while(0);wa=c[z>>2]|0;if((a[f+66181|0]|0)==0){ya=wa;za=c[s>>2]|0;Aa=c[f+68604>>2]|0}else{xa=c[f+68604>>2]|0;ta=c[s>>2]|0;ua=ta+(wa>>>3)|0;la=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(wa&7)>>>24;ua=wa+8|0;wa=xa>>>0>ua>>>0?ua:xa;c[z>>2]=wa;a[f+68612|0]=la;ya=wa;za=ta;Aa=xa}xa=s|0;ta=d[za+(ya>>>3)|0]|0;wa=f+68604|0;la=((ya|0)<(Aa|0))+ya|0;c[z>>2]=la;do{if((ta&128>>>((ya&7)>>>0)|0)==0){Ba=la}else{ua=d[za+(la>>>3)|0]|0;ra=((la|0)<(Aa|0))+la|0;c[z>>2]=ra;if((ua&128>>>((la&7)>>>0)|0)==0){Ca=ra}else{ua=e[D>>1]|0;oa=ua<<1;qa=oa>>>0>65535>>>0;$=qa?ua>>>15:oa;oa=qa?16:0;if(($&65280|0)==0){Da=oa;Ea=$}else{Da=oa|8;Ea=$>>>8}$=(d[1191992+Ea|0]|0)+Da+ra|0;ra=Aa>>>0>$>>>0?$:Aa;c[z>>2]=ra;Ca=ra}ra=d[za+(Ca>>>3)|0]|0;$=((Ca|0)<(Aa|0))+Ca|0;c[z>>2]=$;if((ra&128>>>((Ca&7)>>>0)|0)==0){Ba=$;break}ra=e[D>>1]|0;oa=ra<<1;qa=oa>>>0>65535>>>0;ua=qa?ra>>>15:oa;oa=qa?16:0;if((ua&65280|0)==0){Fa=oa;Ga=ua}else{Fa=oa|8;Ga=ua>>>8}ua=(d[1191992+Ga|0]|0)+Fa+$|0;$=Aa>>>0>ua>>>0?ua:Aa;c[z>>2]=$;Ba=$}}while(0);Aa=f+68614|0;a[Aa]=0;if((c[A>>2]|0)>0){Fa=0;do{b[f+71200+(Fa*49568|0)+134>>1]=0;a[f+71200+(Fa*49568|0)+132|0]=0;a[f+71200+(Fa*49568|0)+144|0]=0;Fa=Fa+1|0;}while((Fa|0)<(c[A>>2]|0));Fa=e[D>>1]|0;if((a[Aa]|0)==0){Ha=Fa;E=65}else{Ia=Fa}}else{Ha=e[D>>1]|0;E=65}c:do{if((E|0)==65){Fa=f+68576|0;Ga=f+68618|0;Ca=f+68636|0;za=f+68627|0;Da=f+68632|0;Ea=f+68616|0;la=f+68637|0;ya=f+68638|0;ta=f+66182|0;$=f+68628|0;ua=f+68619|0;oa=f+68568|0;qa=o|0;ra=o+4|0;_=o+8|0;K=o+12|0;X=f+66188|0;P=f+33376|0;T=f+12|0;M=p|0;L=p+4|0;ma=~p;y=f+20|0;na=Ha;x=va;pa=Ba;d:while(1){ia=x+416|0;ga=ba(c[ia>>2]|0,na)|0;c[Fa>>2]=pa;if((c[ia>>2]|0)>0){ha=0;ea=na;fa=na;while(1){a[f+71200+(ha*49568|0)+136|0]=0;R=e[f+71200+(ha*49568|0)+134>>1]|0;if((fa|0)>(R|0)){Ja=R;Ka=e[f+71200+(ha*49568|0)+4+(d[f+71200+(ha*49568|0)+132|0]<<1)>>1]|0}else{Ja=fa;Ka=ea}R=ha+1|0;if((R|0)<(c[ia>>2]|0)){ha=R;ea=Ka;fa=Ja}else{La=Ka;Ma=Ja;break}}}else{La=na;Ma=na}a[Ga]=0;if((c[ia>>2]|0)>0){fa=ga;ea=0;ha=0;R=x;while(1){l=f+71200+(ea*49568|0)+134|0;m=b[l>>1]|0;Y=m&65535;v=fa-Y|0;do{if((Ma|0)==(Y|0)){I=b[f+71200+(ea*49568|0)+4+(d[f+71200+(ea*49568|0)+132|0]<<1)>>1]|0;if((La|0)!=(I&65535|0)){Na=v;Oa=ha;Pa=R;break}b[l>>1]=I+m;a[(ha<<24>>24)+(f+68619)|0]=ea;I=(a[Ga]|0)+1&255;a[Ga]=I;Na=v-La|0;Oa=I;Pa=c[q>>2]|0}else{Na=v;Oa=ha;Pa=R}}while(0);v=ea+1|0;if((v|0)<(c[Pa+416>>2]|0)){fa=Na;ea=v;ha=Oa;R=Pa}else{Qa=Na;Ra=Oa;Sa=Pa;break}}}else{Qa=ga;Ra=0;Sa=x}if((Qa|0)==0){a[Aa]=1}R=e[D>>1]|0;ha=(R|0)/(La|0)|0;ea=ha>>>0>65535>>>0;fa=ea?ha>>>16:ha;ha=ea?16:0;if((fa&65280|0)==0){Ta=ha;Ua=fa}else{Ta=ha|8;Ua=fa>>>8}fa=(d[1191992+Ua|0]|0)+Ta|0;a[Ca]=fa;ha=fa&255;a[za]=a[f+66194+ha|0]|0;c[Da>>2]=f+66202+(ha*58|0);fa=b[f+68522+(ha<<1)>>1]|0;ha=(R>>>1)+Ma|0;R=Ra<<24>>24>0;if(R){ea=Ra<<24>>24;ia=0;do{v=a[f+68619+ia|0]|0;c[f+71200+(v*49568|0)+396>>2]=f+71200+(v*49568|0)+416+(ha<<2);ia=ia+1|0;}while((ia|0)<(ea|0))}ea=La&65535;b[Ea>>1]=ea;ia=(ea<<16>>16)-1|0;ea=ia>>>0>65535>>>0;ga=ea?ia>>>16:ia;ia=ea?16:0;if((ga&65280|0)==0){Va=ia;Wa=ga}else{Va=ia|8;Wa=ga>>>8}a[la]=Va+1+(d[1191992+Wa|0]|0);ga=c[z>>2]|0;ia=c[xa>>2]|0;ea=d[ia+(ga>>>3)|0]|0;v=c[wa>>2]|0;m=((ga|0)<(v|0))+ga|0;c[z>>2]=m;e:do{if((ea&128>>>((ga&7)>>>0)|0)==0){Xa=m}else{l=ia+(m>>>3)|0;Y=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>30;l=m+2|0;I=v>>>0>l>>>0?l:v;c[z>>2]=I;do{if((Y|0)==0){l=ia+(I>>>3)|0;w=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(I&7)>>>28;l=I+4|0;F=v>>>0>l>>>0?l:v;c[z>>2]=F;if((w|0)==0){Ya=1;Za=F;break}l=ia+(F>>>3)|0;C=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(F&7)>>>((32-w|0)>>>0);l=w+F|0;F=v>>>0>l>>>0?l:v;c[z>>2]=F;l=C+1|0;if((l|0)>-1){Ya=l;Za=F}else{Xa=F;break e}}else{Ya=Y;Za=I}}while(0);if((Ya+Za|0)>(c[oa>>2]|0)){E=90;break d}I=-Za|0;Y=v-Za|0;if((Ya|0)<(I|0)){_a=I}else{_a=(Y|0)<(Ya|0)?Y:Ya}Y=_a+Za|0;c[z>>2]=Y;Xa=Y}}while(0);m=d[ia+(Xa>>>3)|0]|0;ga=((Xa|0)<(v|0))+Xa|0;c[z>>2]=ga;if((m&128>>>((Xa&7)>>>0)|0)!=0){E=95;break}a[ya]=0;f:do{if((c[Sa+416>>2]|0)>1){m=d[ia+(ga>>>3)|0]|0;c[z>>2]=((ga|0)<(v|0))+ga;if((m&128>>>((ga&7)>>>0)|0)!=0){E=98;break d}a[ya]=0;if(Ra<<24>>24==0|R^1){$a=0;ab=Ra;bb=Ra<<24>>24>0;break}m=Ra;ea=Ra<<24>>24;Y=0;while(1){I=f+68640+(Y*320|0)+288|0;F=f+68640+(Y*320|0)|0;a[F]=0;l=f+68640+(Y*320|0)+1|0;a[l]=0;do{if((ea|0)>2){if(m<<24>>24>0){cb=I;db=0;eb=m}else{E=115;break}while(1){C=a[f+68619+db|0]|0;w=f+71200+(C*49568|0)+136|0;do{if((a[w]|0)==0){O=c[z>>2]|0;H=d[(c[J>>2]|0)+(O>>>3)|0]|0;c[z>>2]=((O|0)<(c[wa>>2]|0))+O;if((H&128>>>((O&7)>>>0)|0)==0){fb=cb;gb=eb;break}a[F]=(a[F]|0)+1;a[w]=1;c[cb>>2]=c[f+71200+(C*49568|0)+396>>2];fb=cb+4|0;gb=a[Ga]|0}else{fb=cb;gb=eb}}while(0);C=db+1|0;if((C|0)<(gb<<24>>24|0)){cb=fb;db=C;eb=gb}else{E=115;break}}}else{C=ea&255;a[F]=C;if(m<<24>>24>0){hb=I;ib=0;jb=m}else{kb=C;break}while(1){C=a[f+68619+ib|0]|0;w=f+71200+(C*49568|0)+136|0;if((a[w]|0)==0){c[hb>>2]=c[f+71200+(C*49568|0)+396>>2];lb=hb+4|0;mb=a[Ga]|0}else{lb=hb;mb=jb}a[w]=1;w=ib+1|0;if((w|0)<(mb<<24>>24|0)){hb=lb;ib=w;jb=mb}else{E=115;break}}}}while(0);if((E|0)==115){E=0;kb=a[F]|0}do{if(kb<<24>>24==2){I=c[z>>2]|0;w=c[J>>2]|0;C=d[w+(I>>>3)|0]|0;O=c[wa>>2]|0;H=((I|0)<(O|0))+I|0;c[z>>2]=H;if((C&128>>>((I&7)>>>0)|0)!=0){I=d[w+(H>>>3)|0]|0;c[z>>2]=((H|0)<(O|0))+H;if((I&128>>>((H&7)>>>0)|0)==0){break}else{E=119;break d}}a[l]=1;H=f+68640+(Y*320|0)+32|0;if((c[(c[q>>2]|0)+416>>2]|0)==2){g[H>>2]=1.0;g[f+68640+(Y*320|0)+36>>2]=-1.0;g[f+68640+(Y*320|0)+40>>2]=1.0;g[f+68640+(Y*320|0)+44>>2]=1.0;break}else{g[H>>2]=.70703125;g[f+68640+(Y*320|0)+36>>2]=-.70703125;g[f+68640+(Y*320|0)+40>>2]=.70703125;g[f+68640+(Y*320|0)+44>>2]=.70703125;break}}else{if(!((kb&255)>>>0>2>>>0)){break}H=c[z>>2]|0;I=c[J>>2]|0;O=d[I+(H>>>3)|0]|0;w=c[wa>>2]|0;C=((H|0)<(w|0))+H|0;c[z>>2]=C;if((O&128>>>((H&7)>>>0)|0)==0){break}a[l]=1;H=d[I+(C>>>3)|0]|0;c[z>>2]=((C|0)<(w|0))+C;if((H&128>>>((C&7)>>>0)|0)==0){C=kb&255;if((kb&255)>>>0>6>>>0){DDb(c[q>>2]|0,2228664,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa;break}else{UGb(f+68640+(Y*320|0)+32|0,c[1402640+(C<<2)>>2]|0,ba(C<<2,C)|0)|0;break}}C=c[(c[q>>2]|0)+416>>2]|0;TGb(f+68640+(Y*320|0)+32|0,0,ba(C<<2,C)|0)|0;C=kb&255;H=(ba(C-1|0,C)|0)>>1;if((H|0)>0){C=c[wa>>2]|0;w=c[J>>2]|0;I=0;O=c[z>>2]|0;do{G=w+(O>>>3)|0;ca=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(O&7)>>>26;G=O+6|0;O=C>>>0>G>>>0?G:C;c[z>>2]=O;a[n+I|0]=ca;I=I+1|0;}while((I|0)<(H|0))}if(kb<<24>>24==0){break}H=c[J>>2]|0;I=c[wa>>2]|0;O=0;C=c[z>>2]|0;w=kb;while(1){ca=d[H+(C>>>3)|0]|0;G=((C|0)<(I|0))+C|0;c[z>>2]=G;g[f+68640+(Y*320|0)+32+((ba(O,w&255)|0)+O<<2)>>2]=(ca&128>>>((C&7)>>>0)|0)!=0?1.0:-1.0;ca=O+1|0;nb=a[F]|0;if((ca|0)<(nb&255|0)){O=ca;C=G;w=nb}else{break}}if((nb&255)>>>0>1>>>0){ob=0;pb=1;qb=nb}else{break}while(1){w=pb+1|0;if((pb|0)>0&(w|0)>0){C=0;do{O=a[n+(C+ob)|0]|0;I=O<<24>>24;H=4311160+(32-I<<2)|0;G=4311160+(I-32<<2)|0;if(O<<24>>24<32){O=4311160+(I<<2)|0;ca=0;do{aa=d[F]|0;U=f+68640+(Y*320|0)+32+((ba(aa,C)|0)+ca<<2)|0;rb=+g[U>>2];sb=+g[f+68640+(Y*320|0)+32+((ba(aa,pb)|0)+ca<<2)>>2];tb=+g[H>>2];ub=+g[O>>2];g[U>>2]=rb*ub-sb*tb;g[f+68640+(Y*320|0)+32+((ba(d[F]|0,pb)|0)+ca<<2)>>2]=rb*tb+sb*ub;ca=ca+1|0;}while((ca|0)<(w|0))}else{ca=4311160+(64-I<<2)|0;O=0;do{H=d[F]|0;U=f+68640+(Y*320|0)+32+((ba(H,C)|0)+O<<2)|0;ub=+g[U>>2];sb=+g[f+68640+(Y*320|0)+32+((ba(H,pb)|0)+O<<2)>>2];tb=-0.0- +g[G>>2];rb=+g[ca>>2];g[U>>2]=ub*rb-sb*tb;g[f+68640+(Y*320|0)+32+((ba(d[F]|0,pb)|0)+O<<2)>>2]=ub*tb+sb*rb;O=O+1|0;}while((O|0)<(w|0))}C=C+1|0;}while((C|0)<(pb|0));vb=a[F]|0}else{vb=qb}if((w|0)<(vb&255|0)){ob=ob+pb|0;pb=w;qb=vb}else{break}}}}while(0);g:do{if((a[l]|0)!=0){C=c[z>>2]|0;O=c[J>>2]|0;ca=d[O+(C>>>3)|0]|0;G=c[wa>>2]|0;I=((C|0)<(G|0))+C|0;c[z>>2]=I;if((ca&128>>>((C&7)>>>0)|0)!=0){TGb(f+68640+(Y*320|0)+2|0,1,a[za]|0)|0;break}if((a[za]|0)>0){wb=0;xb=I;yb=O;zb=G}else{break}while(1){G=d[yb+(xb>>>3)|0]<<(xb&7)>>>7;c[z>>2]=((xb|0)<(zb|0))+xb;a[f+68640+(Y*320|0)+2+wb|0]=G&1;G=wb+1|0;if((G|0)>=(a[za]|0)){break g}wb=G;xb=c[z>>2]|0;yb=c[J>>2]|0;zb=c[wa>>2]|0}}}while(0);l=d[F]|0;G=(a[ya]|0)+1&255;a[ya]=G;if((ea|0)==(l|0)){break}O=a[Ga]|0;I=G&255;if((I|0)<(O<<24>>24|0)){m=O;ea=ea-l|0;Y=I}else{Ab=O;E=102;break f}}Ab=a[Ga]|0;E=102}else{Ab=Ra;E=102}}while(0);do{if((E|0)==102){E=0;if(!(Ab<<24>>24>0)){$a=0;ab=Ab;bb=0;break}R=c[xa>>2]|0;ga=c[wa>>2]|0;v=Ab<<24>>24;ia=0;Y=0;ea=c[z>>2]|0;while(1){m=a[f+68619+Y|0]|0;O=d[R+(ea>>>3)|0]<<(ea&7)>>>7;I=((ea|0)<(ga|0))+ea|0;c[z>>2]=I;l=O&1;a[f+71200+(m*49568|0)+2|0]=l;m=l<<24>>24==0?ia:1;l=Y+1|0;if((l|0)<(v|0)){ia=m;Y=l;ea=I}else{$a=m;ab=Ab;bb=1;break}}}}while(0);ea=b[Ea>>1]|0;if(!(ea<<16>>16<8193)){E=155;break}Y=($a|0)!=0;do{if(Y){ia=((d[ta]|0)*90|0)>>>4;v=c[z>>2]|0;ga=c[xa>>2]|0;R=d[ga+(v>>>3)|0]<<(v&7)>>>7;m=c[wa>>2]|0;I=((v|0)<(m|0))+v|0;c[z>>2]=I;v=R&1;a[$]=v;do{if(v<<24>>24==0){if(!bb){Bb=I;break}R=ab<<24>>24;l=0;while(1){b[f+71200+((a[f+68619+l|0]|0)*49568|0)+400>>1]=ea;O=l+1|0;if((O|0)<(R|0)){l=O}else{Bb=I;break}}}else{l=ea<<16>>16;R=(l+3|0)/4|0;F=R>>>0>65535>>>0;O=F?R>>>16:R;R=F?16:0;if((O&65280|0)==0){Cb=R;Db=O}else{Cb=R|8;Db=O>>>8}O=(d[1191992+Db|0]|0)+Cb|0;R=O+1|0;if(!bb){Bb=I;break}F=31-O|0;O=ab<<24>>24;G=0;C=I;while(1){ca=a[f+68619+G|0]|0;U=ga+(C>>>3)|0;H=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(C&7)>>>(F>>>0);U=R+C|0;aa=m>>>0>U>>>0?U:m;c[z>>2]=aa;Eb=H<<2;if((Eb|0)>(l|0)){E=165;break d}if(!((Eb+ha|0)>>>0<12289>>>0)){E=167;break d}b[f+71200+(ca*49568|0)+400>>1]=Eb;ca=G+1|0;if((ca|0)<(O|0)){G=ca;C=aa}else{Bb=aa;break}}}}while(0);I=ga+(Bb>>>3)|0;v=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(Bb&7)>>26;I=Bb+6|0;C=m>>>0>I>>>0?I:m;c[z>>2]=C;I=v+ia|0;if((v|0)==(-32|0)|(v|0)==31){G=((v|0)!=31)<<31>>31;O=c[oa>>2]|0;l=v;v=0;R=C;while(1){C=R+5|0;if((C|0)>=(O|0)){Fb=l;break}F=ga+(R>>>3)|0;aa=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(R&7)>>>27;F=m>>>0>C>>>0?C:m;c[z>>2]=F;if((aa|0)==31){l=31;v=v+31|0;R=F}else{Fb=aa;break}}Gb=I-G+(Fb+v^G)|0}else{Gb=I}if((Gb|0)<0){yDb(c[q>>2]|0,48,2304336,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa;Hb=a[Ga]|0}else{Hb=ab}if(Hb<<24>>24==1){c[f+71200+((a[ua]|0)*49568|0)+140>>2]=Gb;Ib=0}else{R=c[z>>2]|0;l=c[wa>>2]|0;m=(c[xa>>2]|0)+(R>>>3)|0;ga=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(R&7)>>>29;m=R+3|0;R=l>>>0>m>>>0?m:l;c[z>>2]=R;if(!(Hb<<24>>24>0)){Jb=Hb;break}m=(ga|0)==0;O=32-ga|0;ia=Hb<<24>>24;aa=Gb+1|0;F=0;C=R;while(1){R=f+71200+((a[f+68619+F|0]|0)*49568|0)+140|0;c[R>>2]=Gb;ca=c[xa>>2]|0;H=d[ca+(C>>>3)|0]|0;U=((C|0)<(l|0))+C|0;c[z>>2]=U;do{if((H&128>>>((C&7)>>>0)|0)==0){Kb=U}else{if(m){c[R>>2]=aa;Kb=U;break}else{V=ca+(U>>>3)|0;Z=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(U&7)>>>(O>>>0);V=U+ga|0;W=l>>>0>V>>>0?V:l;c[z>>2]=W;c[R>>2]=aa+Z;Kb=W;break}}}while(0);R=F+1|0;if((R|0)<(ia|0)){F=R;C=Kb}else{Ib=0;break}}}while(1){C=a[f+68619+Ib|0]|0;F=f+71200+(C*49568|0)+384|0;ia=a[F]|0;aa=ia<<24>>24==0|0;l=f+71200+(C*49568|0)+152+(aa*116|0)|0;c[f+71200+(C*49568|0)+388>>2]=l;ga=a[za]|0;O=f+71200+(C*49568|0)+152+(aa*116|0)+(ga<<24>>24<<2)|0;m=f+71200+(C*49568|0)+144|0;I=ga<<24>>24>0;do{if((a[m]|0)!=0&I){G=f+66666+((d[Ca]|0)*232|0)+((d[f+71200+(C*49568|0)+392|0]|0)*29|0)|0;c[l>>2]=c[f+71200+(C*49568|0)+152+((ia<<24>>24)*116|0)+(a[G]<<2)>>2];v=a[za]|0;if(v<<24>>24>1){Lb=G;Mb=1}else{Nb=v;break}while(1){v=Lb+1|0;c[f+71200+(C*49568|0)+152+(aa*116|0)+(Mb<<2)>>2]=c[f+71200+(C*49568|0)+152+((a[F]|0)*116|0)+(a[v]<<2)>>2];G=Mb+1|0;R=a[za]|0;if((G|0)<(R<<24>>24|0)){Lb=v;Mb=G}else{Nb=R;break}}}else{Nb=ga}}while(0);if((a[f+71200+(C*49568|0)+132|0]|0)==0){E=193}else{ia=c[z>>2]|0;R=d[(c[J>>2]|0)+(ia>>>3)|0]|0;c[z>>2]=((ia|0)<(c[wa>>2]|0))+ia;if((R&128>>>((ia&7)>>>0)|0)!=0){E=193}}if((E|0)==193){E=0;h:do{if((a[m]|0)==0){ia=c[z>>2]|0;R=c[wa>>2]|0;G=c[J>>2]|0;v=G+(ia>>>3)|0;U=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(ia&7)>>>30;v=ia+2|0;ia=R>>>0>v>>>0?v:R;c[z>>2]=ia;v=U+1&255;a[f+71200+(C*49568|0)+145|0]=v;if(!I){break}U=c[1077867]|0;ca=l;H=45/(v<<24>>24|0)|0;v=ia;ia=R;while(1){R=G+(v>>>3)|0;W=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(v&7)>>>24;R=b[U+(W<<2)>>1]|0;Z=b[U+(W<<2)+2>>1]|0;W=Z<<16>>16;do{if(Z<<16>>16<0){V=v+8|0;B=ia>>>0>V>>>0?V:ia;V=G+(B>>>3)|0;N=((fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(B&7)>>>((W+32|0)>>>0))+R|0;V=b[U+(N<<2)>>1]|0;Q=b[U+(N<<2)+2>>1]|0;N=Q<<16>>16;if(!(Q<<16>>16<0)){Ob=N;Pb=V;Qb=B;break}Q=B-W|0;B=ia>>>0>Q>>>0?Q:ia;Q=G+(B>>>3)|0;ka=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(B&7)>>>((N+32|0)>>>0))+V|0;Ob=b[U+(ka<<2)+2>>1]|0;Pb=b[U+(ka<<2)>>1]|0;Qb=B}else{Ob=W;Pb=R;Qb=v}}while(0);R=Ob+Qb|0;c[z>>2]=ia>>>0>R>>>0?R:ia;R=H-60+Pb|0;c[ca>>2]=R;W=ca+4|0;if(!(W>>>0<O>>>0)){break h}ca=W;H=R;v=c[z>>2]|0;ia=c[wa>>2]|0}}else{if(!(Nb<<24>>24>0)){break}ia=c[1077873]|0;v=c[J>>2]|0;H=0;ca=Nb;do{U=c[z>>2]|0;G=c[wa>>2]|0;R=v+(U>>>3)|0;W=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(U&7)>>>23;R=b[ia+(W<<2)>>1]|0;Z=b[ia+(W<<2)+2>>1]|0;W=Z<<16>>16;do{if(Z<<16>>16<0){w=U+9|0;B=G>>>0>w>>>0?w:G;w=v+(B>>>3)|0;ka=((fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(B&7)>>>((W+32|0)>>>0))+R|0;w=b[ia+(ka<<2)>>1]|0;V=b[ia+(ka<<2)+2>>1]|0;ka=V<<16>>16;if(!(V<<16>>16<0)){Rb=ka;Sb=w;Tb=B;break}V=B-W|0;B=G>>>0>V>>>0?V:G;V=v+(B>>>3)|0;N=((fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(B&7)>>>((ka+32|0)>>>0))+w|0;Rb=b[ia+(N<<2)+2>>1]|0;Sb=b[ia+(N<<2)>>1]|0;Tb=B}else{Rb=W;Sb=R;Tb=U}}while(0);U=Rb+Tb|0;R=G>>>0>U>>>0?U:G;c[z>>2]=R;if((Sb|0)==0){U=v+(R>>>3)|0;W=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(R&7);U=R+14|0;c[z>>2]=G>>>0>U>>>0?U:G;Ub=W>>>18;Vb=W>>>24;Wb=W>>>19&31}else if((Sb|0)==1){break h}else{W=d[476456+Sb|0]|0;U=d[476576+Sb|0]|0;Z=d[v+(R>>>3)|0]<<(R&7)>>>7;c[z>>2]=((R|0)<(G|0))+R;Ub=Z;Vb=U;Wb=W}W=Ub&1;U=Wb+H|0;if((U|0)>=(ca<<24>>24|0)){E=216;break d}Z=f+71200+(C*49568|0)+152+(aa*116|0)+(U<<2)|0;c[Z>>2]=(W-1^Vb)+(W^1)+(c[Z>>2]|0);H=U+1|0;ca=a[za]|0;}while((H|0)<(ca<<24>>24|0))}}while(0);a[F]=(a[F]|0)==0|0;a[f+71200+(C*49568|0)+392|0]=a[Ca]|0;a[m]=1}I=c[l>>2]|0;ca=f+71200+(C*49568|0)+148|0;c[ca>>2]=I;if(ga<<24>>24>1){H=f+71200+(C*49568|0)+152+(aa*116|0)+4|0;v=I;do{I=c[H>>2]|0;v=(v|0)>(I|0)?v:I;c[ca>>2]=v;H=H+4|0;}while(H>>>0<O>>>0)}O=Ib+1|0;H=a[Ga]|0;if((O|0)<(H<<24>>24|0)){Ib=O}else{Xb=H;E=186;break}}}else{Xb=ab;E=186}}while(0);do{if((E|0)==186){E=0;if(!(Xb<<24>>24>0)){Jb=Xb;break}ha=La<<2;ea=0;while(1){H=a[f+68619+ea|0]|0;do{if((a[f+71200+(H*49568|0)+2|0]|0)==0){E=248}else{O=c[z>>2]|0;if((O|0)>=(c[oa>>2]|0)){E=248;break}v=d[(c[xa>>2]|0)+(O>>>3)|0]<<(O&7)>>>7;c[z>>2]=((O|0)<(c[wa>>2]|0))+O;O=v&1;v=8776240+(O*20|0)|0;ca=(O|0)==0;O=ca?1451992:1446520;aa=ca?1452536:1447008;ca=f+71200+(H*49568|0)+400|0;C=f+71200+(H*49568|0)+396|0;ga=0;l=0;m=0;while(1){if((l|3|0)>=(e[ca>>1]|0)){Yb=l;break}F=c[646531]|0;I=c[z>>2]|0;ia=c[wa>>2]|0;U=c[xa>>2]|0;Z=U+(I>>>3)|0;W=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(I&7)>>>23;Z=b[F+(W<<2)>>1]|0;R=b[F+(W<<2)+2>>1]|0;W=R<<16>>16;if(R<<16>>16<0){R=I+9|0;B=ia>>>0>R>>>0?R:ia;R=U+(B>>>3)|0;N=((fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(B&7)>>>((W+32|0)>>>0))+Z|0;Zb=b[F+(N<<2)+2>>1]|0;_b=b[F+(N<<2)>>1]|0;$b=B}else{Zb=W;_b=Z;$b=I}I=Zb+$b|0;Z=ia>>>0>I>>>0?I:ia;c[z>>2]=Z;i:do{if((_b|0)==126){I=0;W=Z;B=ia;N=U;while(1){F=c[646537]|0;R=N+(W>>>3)|0;w=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(W&7)>>>23;R=b[F+(w<<2)>>1]|0;ka=b[F+(w<<2)+2>>1]|0;w=ka<<16>>16;if(ka<<16>>16<0){ka=W+9|0;V=B>>>0>ka>>>0?ka:B;ka=N+(V>>>3)|0;Q=((fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(V&7)>>>((w+32|0)>>>0))+R|0;ac=b[F+(Q<<2)+2>>1]|0;bc=b[F+(Q<<2)>>1]|0;cc=V}else{ac=w;bc=R;cc=W}R=ac+cc|0;w=B>>>0>R>>>0?R:B;c[z>>2]=w;if((bc|0)==136){R=c[646543]|0;V=N+(w>>>3)|0;Q=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(w&7)>>>23;V=b[R+(Q<<2)>>1]|0;F=b[R+(Q<<2)+2>>1]|0;Q=F<<16>>16;if(F<<16>>16<0){F=w+9|0;ka=B>>>0>F>>>0?F:B;F=N+(ka>>>3)|0;da=((fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(ka&7)>>>((Q+32|0)>>>0))+V|0;dc=b[R+(da<<2)+2>>1]|0;ec=b[R+(da<<2)>>1]|0;fc=ka}else{dc=Q;ec=V;fc=w}w=dc+fc|0;V=B>>>0>w>>>0?w:B;c[z>>2]=V;if((ec|0)==100){w=(lcb(s)|0)+100|0;gc=w;hc=c[646543]|0;ic=c[z>>2]|0;jc=c[wa>>2]|0;kc=c[xa>>2]|0}else{gc=ec;hc=R;ic=V;jc=B;kc=N}V=kc+(ic>>>3)|0;R=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(ic&7)>>>23;V=b[hc+(R<<2)>>1]|0;w=b[hc+(R<<2)+2>>1]|0;R=w<<16>>16;if(w<<16>>16<0){w=ic+9|0;Q=jc>>>0>w>>>0?w:jc;w=kc+(Q>>>3)|0;ka=((fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(Q&7)>>>((R+32|0)>>>0))+V|0;lc=b[hc+(ka<<2)+2>>1]|0;mc=b[hc+(ka<<2)>>1]|0;nc=Q}else{lc=R;mc=V;nc=ic}V=lc+nc|0;c[z>>2]=jc>>>0>V>>>0?V:jc;if((mc|0)==100){oc=(lcb(s)|0)+100|0}else{oc=mc}g[o+(I<<2)>>2]=+(gc>>>0>>>0);g[o+((I|1)<<2)>>2]=+(oc>>>0>>>0)}else{V=d[400696+bc|0]|0;c[o+(I<<2)>>2]=c[1403304+(V>>>4<<2)>>2];c[o+((I|1)<<2)>>2]=c[1403304+((V&15)<<2)>>2]}V=I+2|0;if((V|0)>=4){pc=ga;qc=l;rc=m;sc=0;break i}I=V;W=c[z>>2]|0;B=c[wa>>2]|0;N=c[xa>>2]|0}}else{N=e[400440+(_b<<1)>>1]|0;c[qa>>2]=c[1403304+(N>>>12<<2)>>2];c[ra>>2]=c[1403304+((N>>>8&15)<<2)>>2];c[_>>2]=c[1403304+((N>>>4&15)<<2)>>2];c[K>>2]=c[1403304+((N&15)<<2)>>2];pc=ga;qc=l;rc=m;sc=0}}while(0);while(1){U=c[o+(sc<<2)>>2]|0;if((U|0)==0){g[(c[C>>2]|0)+(qc<<2)>>2]=0.0;ia=rc+1|0;tc=ia;uc=(ia|0)>(b[Ea>>1]>>8|0)|pc}else{ia=c[z>>2]|0;Z=d[(c[xa>>2]|0)+(ia>>>3)|0]<<(ia&7)>>>7;c[z>>2]=((ia|0)<(c[wa>>2]|0))+ia;c[(c[C>>2]|0)+(qc<<2)>>2]=U^-2147483648^Z<<31;tc=0;uc=pc}Z=sc+1|0;if((Z|0)>=4){break}pc=uc;qc=qc+1|0;rc=tc;sc=Z}Z=l+4|0;if((a[$]|0)!=0|(uc|0)==0){ga=uc;l=Z;m=tc}else{Yb=Z;break}}m=b[Ea>>1]|0;if((Yb|0)>=(m|0)){break}TGb((c[C>>2]|0)+(Yb<<2)|0,0,m-Yb<<2|0)|0;m=b[Ea>>1]|0;mcb(c[q>>2]|0,s,v,aa,O,1,c[C>>2]|0,Yb,m,m,a[la]|0,0)|0}}while(0);if((E|0)==248){E=0;TGb(c[f+71200+(H*49568|0)+396>>2]|0,0,ha|0)|0}m=ea+1|0;l=a[Ga]|0;if((m|0)<(l<<24>>24|0)){ea=m}else{Jb=l;break}}}}while(0);do{if(Y){ea=La>>>0>65535>>>0;ha=ea?La>>>16:La;l=ea?16:0;if((ha&65280|0)==0){vc=l;wc=ha}else{vc=l|8;wc=ha>>>8}ha=vc-6+(d[1191992+wc|0]|0)|0;l=f+32848+(ha<<6)|0;ea=a[ya]|0;if(ea<<24>>24==0){xc=Jb}else{m=0;ga=ea;while(1){do{if((a[f+68640+(m*320|0)+1|0]|0)==0){yc=ga}else{ea=a[f+68640+(m*320|0)|0]|0;ca=ea&255;Z=f+68640+(m*320|0)+288|0;U=f+68640+(m*320|0)+288+(ca<<2)|0;if((a[za]|0)<=0){yc=ga;break}ia=c[Da>>2]|0;G=f+68640+(m*320|0)+32|0;N=p+(ca<<2)|0;ca=ea<<24>>24==0;ea=f+68640+(m*320|0)+292|0;B=N;W=(((B>>>0>L>>>0?B:L)+ma|0)>>>2)+1|0;B=ia;I=f+68640+(m*320|0)+2|0;V=ia;while(1){ia=I+1|0;do{if((a[I]|0)==1){R=b[B>>1]|0;Q=B+2|0;ka=b[Q>>1]|0;w=b[Ea>>1]|0;da=ka<<16>>16>w<<16>>16?w:ka;if(!(R<<16>>16<da<<16>>16)){zc=V;Ac=Q;break}ka=da<<16>>16;da=R<<16>>16;while(1){if(!ca){R=M;w=Z;while(1){g[R>>2]=+g[(c[w>>2]|0)+(da<<2)>>2];F=w+4|0;if(F>>>0<U>>>0){R=R+4|0;w=F}else{Bc=G;Cc=Z;break}}while(1){w=Bc;R=M;rb=0.0;while(1){F=R+4|0;Dc=rb+ +g[R>>2]*+g[w>>2];if(F>>>0<N>>>0){w=w+4|0;R=F;rb=Dc}else{break}}g[(c[Cc>>2]|0)+(da<<2)>>2]=Dc;R=Cc+4|0;if(R>>>0<U>>>0){Bc=Bc+(W<<2)|0;Cc=R}else{break}}}R=da+1|0;if((R|0)<(ka|0)){da=R}else{zc=V;Ac=Q;break}}}else{Q=B+2|0;if((c[(c[q>>2]|0)+416>>2]|0)!=2){zc=V;Ac=Q;break}da=b[Q>>1]|0;ka=b[Ea>>1]|0;R=b[B>>1]|0;w=((da<<16>>16>ka<<16>>16?ka:da)<<16>>16)-R|0;da=(c[Z>>2]|0)+(R<<2)|0;te[c[T>>2]&7](da,da,1.4140625,w);da=(c[ea>>2]|0)+(b[B>>1]<<2)|0;te[c[T>>2]&7](da,da,1.4140625,w);zc=c[Da>>2]|0;Ac=Q}}while(0);if(Ac>>>0<(zc+(a[za]<<1)|0)>>>0){B=Ac;I=ia;V=zc}else{break}}yc=a[ya]|0}}while(0);H=m+1|0;if((H|0)<(yc&255|0)){m=H;ga=yc}else{break}}xc=a[Ga]|0}if(!(xc<<24>>24>0)){break}ga=f+33376+(fa<<2)|0;m=La-fa<<2;H=f+32848+(ha<<6)+44|0;V=0;while(1){I=a[f+68619+V|0]|0;B=I<<24>>24;ea=c[f+71200+(B*49568|0)+388>>2]|0;if(I<<24>>24==(a[X]|0)){TGb(ga|0,0,m|0)|0}j:do{if((a[za]|0)>0){I=f+71200+(B*49568|0)+140|0;Z=f+71200+(B*49568|0)+148|0;W=f+71200+(B*49568|0)+145|0;U=f+71200+(B*49568|0)+396|0;N=ea;G=0;while(1){ca=G+1|0;C=c[Da>>2]|0;O=b[C+(ca<<1)>>1]|0;aa=b[Ea>>1]|0;rb=+S(+10.0,+(+((c[I>>2]|0)-(ba(a[W]|0,(c[Z>>2]|0)-(c[N>>2]|0)|0)|0)|0)/20.0));v=b[C+(G<<1)>>1]|0;te[c[T>>2]&7](f+33376+(v<<2)|0,(c[U>>2]|0)+(v<<2)|0,rb,((O<<16>>16>aa<<16>>16?aa:O)<<16>>16)-v|0);if((ca|0)>=(a[za]|0)){Ec=U;break j}N=N+4|0;G=ca}}else{Ec=f+71200+(B*49568|0)+396|0}}while(0);Xe[c[H>>2]&4095](l,c[Ec>>2]|0,P);B=V+1|0;ea=a[Ga]|0;if((B|0)<(ea<<24>>24|0)){V=B}else{Fc=ea;E=282;break}}}else{Fc=Jb;E=282}}while(0);do{if((E|0)==282){E=0;if(!(Fc<<24>>24>0)){break}fa=0;Y=b[Ea>>1]|0;do{V=a[f+68619+fa|0]|0;l=f+71200+(V*49568|0)|0;H=b[l>>1]|0;m=H<<16>>16;ga=c[f+71200+(V*49568|0)+396>>2]|0;V=Y<<16>>16;if(Y<<16>>16<H<<16>>16){Gc=m-V>>1;Hc=V}else{Gc=0;Hc=m}V=Gc-(m>>1)|0;m=ga+(V<<2)|0;H=Hc>>>0>65535>>>0;ha=H?Hc>>>16:Hc;ea=H?16:0;if((ha&65280|0)==0){Ic=ea;Jc=ha}else{Ic=ea|8;Jc=ha>>>8}ha=Hc>>1;le[c[y>>2]&1023](m,m,ga+(V+ha<<2)|0,c[f+66144+(Ic-6+(d[1191992+Jc|0]|0)<<2)>>2]|0,ha);Y=b[Ea>>1]|0;b[l>>1]=Y;fa=fa+1|0;Kc=a[Ga]|0;Lc=Kc<<24>>24;}while((fa|0)<(Lc|0));if(Kc<<24>>24>0){Mc=0}else{break}do{fa=a[f+68619+Mc|0]|0;Y=f+71200+(fa*49568|0)+132|0;l=a[Y]|0;if(!((l&255)>>>0<(d[f+71200+(fa*49568|0)+3|0]|0)>>>0)){E=293;break d}a[Y]=l+1;Mc=Mc+1|0;}while((Mc|0)<(Lc|0))}}while(0);l=e[D>>1]|0;if((a[Aa]|0)!=0){Ia=l;break c}na=l;x=c[q>>2]|0;pa=c[z>>2]|0}if((E|0)==90){yDb(Sa,16,2000152,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==95){DDb(Sa,1963264,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==98){DDb(Sa,2255064,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==119){DDb(c[q>>2]|0,2240736,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==155){yDb(0,0,1935104,(sa=i,i=i+24|0,c[sa>>2]=1911872,c[sa+8>>2]=1891376,c[sa+16>>2]=1188,sa)|0);i=sa;Cd();return 0}else if((E|0)==165){yDb(c[q>>2]|0,16,2348896,(sa=i,i=i+8|0,c[sa>>2]=Eb,sa)|0);i=sa}else if((E|0)==167){yDb(0,0,1935104,(sa=i,i=i+24|0,c[sa>>2]=2328656,c[sa+8>>2]=1891376,c[sa+16>>2]=1203,sa)|0);i=sa;Cd();return 0}else if((E|0)==216){yDb(c[q>>2]|0,16,2270384,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==293){yDb(c[q>>2]|0,16,2286400,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}a[f+68580|0]=1;Nc=0;i=k;return Nc|0}}while(0);c[h+76>>2]=Ia;if((_$a(r,h,0)|0)<0){a[f+68580|0]=1;Nc=0;i=k;return Nc|0}do{if((c[A>>2]|0)>0){r=h+64|0;Ia=0;do{UGb(c[(c[r>>2]|0)+(Ia<<2)>>2]|0,f+71200+(Ia*49568|0)+416|0,e[D>>1]<<2)|0;Ia=Ia+1|0;Oc=c[A>>2]|0;}while((Ia|0)<(Oc|0));if((Oc|0)>0){Pc=0}else{break}do{Ia=e[D>>1]|0;UGb(f+71200+(Pc*49568|0)+416|0,f+71200+(Pc*49568|0)+416+(Ia<<2)|0,Ia<<1)|0;Pc=Pc+1|0;}while((Pc|0)<(c[A>>2]|0))}}while(0);A=f+68613|0;if((a[A]|0)==0){c[j>>2]=1}else{a[A]=0;c[j>>2]=0;KCb(h)}k:do{if((a[t]|0)==0){h=c[f+68568>>2]|0;j=c[z>>2]|0;while(1){if((j|0)>=(h|0)){break}A=d[(c[xa>>2]|0)+(j>>>3)|0]|0;Pc=c[wa>>2]|0;D=((j|0)<(Pc|0))+j|0;c[z>>2]=D;if((A&128>>>((j&7)>>>0)|0)==0){j=D}else{Qc=D;Rc=Pc;break k}}Qc=j;Rc=c[wa>>2]|0}else{h=c[z>>2]|0;Pc=c[f+68572>>2]|0;if((u|0)!=(h+2-Pc|0)){yDb(c[q>>2]|0,16,2045928,(sa=i,i=i+16|0,c[sa>>2]=c[f+68584>>2],c[sa+8>>2]=u-1-h+Pc,sa)|0);i=sa;a[f+68580|0]=1;Nc=0;i=k;return Nc|0}D=u-1-h+Pc|0;Pc=-h|0;A=c[wa>>2]|0;Oc=A-h|0;if((D|0)<(Pc|0)){Sc=Pc}else{Sc=(Oc|0)<(D|0)?Oc:D}D=Sc+h|0;c[z>>2]=D;Qc=D;Rc=A}}while(0);Sc=d[(c[xa>>2]|0)+(Qc>>>3)|0]<<(Qc&7)>>>7;c[z>>2]=((Qc|0)<(Rc|0))+Qc;Qc=f+68584|0;c[Qc>>2]=(c[Qc>>2]|0)+1;Nc=Sc&1;i=k;return Nc|0}a[f+68580|0]=1;Nc=0;i=k;return Nc|0}function Hcb(a){a=a|0;c[1305353]=2546480;c[1305355]=132;N_(5221408,6,22,35504,1,1,35456,2,2,0,0,0,4)|0;return}function Icb(e){e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+32|0;j=f|0;k=c[e+60>>2]|0;l=e+100|0;m=c[l>>2]|0;if((m|0)!=46){yDb(e,16,1891328,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-1094995529;i=f;return o|0}m=e+96|0;p=(c[m>>2]|0)+18|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=(c[e+432>>2]<<1)-2|0;r=p>>>0>65535>>>0;s=r?p>>>16:p;p=r?16:0;if((s&65280|0)==0){t=p;u=s}else{t=p|8;u=s>>>8}c[k+48>>2]=t+3+(d[1191992+u|0]|0);u=q&1;c[k+56>>2]=u;if((u|0)!=0){BUa(k+2368|0,7,0)|0;BUa(k+2456|0,7,1)|0;U0(k+2544|0,6,2)|0;U0(k+2656|0,6,3)|0;u=k+4812|0;t=u;UXa(u,256);s=k+2768|0;UGb(k+3788|0,u|0,1024)|0;u=0;do{p=510-u|0;g[s+(u<<2)>>2]=-0.0- +g[s+(p<<2)>>2];g[t+(p<<2)>>2]=+g[t+(u<<2)>>2];u=u+1|0;}while((u|0)<255)}u=q>>>2&15;c[k+60>>2]=u;if(u>>>0>11>>>0){yDb(e,16,2348848,(n=i,i=i+8|0,c[n>>2]=u,n)|0);i=n;o=-1094995529;i=f;return o|0}c[k+64>>2]=q>>>6&1;c[k+68>>2]=q>>>7&15;c[k+76>>2]=q>>>13&1;c[k+80>>2]=q>>>14&1;u=k+72|0;if((q&4096|0)==0){c[u>>2]=10;c[k+84>>2]=24;c[k+88>>2]=48;v=10}else{c[u>>2]=16;c[k+84>>2]=34;c[k+88>>2]=60;v=16}q=k+440|0;t=0;s=v;do{h[q+(t<<3)>>3]=(+(t|0)+1.0)*3.141592653589793/(+(s|0)+1.0);t=t+1|0;s=c[u>>2]|0;}while((t|0)<(s|0));s=(c[m>>2]|0)+22|0;m=(c[l>>2]<<3)-176|0;l=m>>>0>2147483639>>>0|(s|0)==0;t=l?0:s;s=l?0:m;m=k;c[m>>2]=t;c[k+12>>2]=s;l=s+8|0;u=k+16|0;c[u>>2]=l;c[k+4>>2]=t+(s>>3);s=k+8|0;c[s>>2]=0;TGb(j|0,0,32)|0;TGb(k+20|0,-1|0,25)|0;q=0;v=0;p=l;l=t;while(1){t=l+(v>>>3)|0;r=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>29;t=v+3|0;c[s>>2]=p>>>0>t>>>0?t:p;t=j+(r<<2)|0;w=c[t>>2]|0;if((w|0)>3){x=19;break}c[t>>2]=w+1;a[k+(w+20+(r*3|0))|0]=q;r=q+1|0;if((r|0)>=17){break}q=r;v=c[s>>2]|0;p=c[u>>2]|0;l=c[m>>2]|0}if((x|0)==19){yDb(e,16,2328616,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=f;return o|0}x=e+412|0;m=((c[x>>2]<<8|0)/400|0)+50>>8;c[k+92>>2]=m;l=(((c[x>>2]|0)*9472|0|0)/2e3|0)+50>>8;c[k+96>>2]=l;u=l-m|0;if((u|0)<1){yDb(e,16,2304264,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=f;return o|0}p=(u<<1)-2|0;s=p>>>0>65535>>>0;v=s?p>>>16:p;p=s?16:0;if((v&65280|0)==0){y=p;z=v}else{y=p|8;z=v>>>8}c[k+100>>2]=(d[1191992+z|0]|0)+y;c[k+568>>2]=40;c[k+572>>2]=0;y=l+8|0;c[k+52>>2]=y;if((m|0)<1|(y|0)>416){yDb(e,16,2286352,(n=i,i=i+24|0,c[n>>2]=c[x>>2],c[n+8>>2]=322,c[n+16>>2]=22097,n)|0);i=n;o=-38;i=f;return o|0}b[k+120>>1]=m;x=(u*25|0)>>>6;b[k+122>>1]=x;y=(u*44|0)>>>6;b[k+124>>1]=y;z=l+65535|0;b[k+126>>1]=z;l=u>>3&-16;c[k+116>>2]=l;if((l|0)<1){yDb(e,16,2270336,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=f;return o|0}n=(l<<1)-2|0;l=n>>>0>65535>>>0;u=l?n>>>16:n;n=l?16:0;if((u&65280|0)==0){A=n;B=u}else{A=n|8;B=u>>>8}c[k+112>>2]=A+1+(d[1191992+B|0]|0);B=(y&65535)+1+(z&65535)+((x&65535)-(m<<1)<<1)|0;c[k+108>>2]=B;m=(B<<1)-2|0;B=m>>>0>65535>>>0;x=B?m>>>16:m;m=B?16:0;if((x&65280|0)==0){C=m;D=x}else{C=m|8;D=x>>>8}c[k+104>>2]=(d[1191992+D|0]|0)+C;c[e+416>>2]=1;C=e+448|0;c[C>>2]=4;c[C+4>>2]=0;c[e+420>>2]=3;o=0;i=f;return o|0}function Jcb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=c[b+60>>2]|0;i=b+432|0;j=c[i>>2]|0;k=c[g+28>>2]|0;while(1){if((k|0)>(j|0)){k=k-j|0}else{break}}j=h;if((k|0)==0){c[f>>2]=0;l=0;return l|0}m=g+24|0;g=c[m>>2]|0;n=k<<3;o=n>>>0>2147483639>>>0;p=o|(g|0)==0;q=p?0:g;g=p?0:n;p=h;c[p>>2]=q;r=h+12|0;c[r>>2]=g;s=g+8|0;t=h+16|0;c[t>>2]=s;u=h+4|0;c[u>>2]=q+(g>>3);v=h+8|0;c[v>>2]=0;do{if((k|0)==(c[i>>2]|0)){a:do{if((g|0)<11){w=0}else{x=s>>>0>4>>>0?4:s;c[v>>2]=x;y=(d[q+(x>>>3)|0]|0)<<(x&4)>>>7;z=(x|0)<(s|0)|x;c[v>>2]=z;c[h+132>>2]=y&1;y=c[h+48>>2]|0;x=z;do{z=q+(x>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7);z=x+6|0;x=s>>>0>z>>>0?z:s;c[v>>2]=x;z=(A&-67108864|0)==-67108864;if((g-x|0)<((-(z&1)&6)+y|0)){w=x;break a}}while(z);z=q+(x>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>((32-y|0)>>>0);z=x+y|0;B=s>>>0>z>>>0?z:s;c[v>>2]=B;c[h+128>>2]=A;w=B}}while(0);B=h+128|0;A=c[B>>2]|0;if((A|0)<=0){C=w;D=g;break}z=h+412|0;if((c[z>>2]|0)<=0){E=-w|0;F=s-w|0;if((A|0)<(E|0)){G=E}else{G=(F|0)<(A|0)?F:A}F=G+w|0;c[v>>2]=F;C=F;D=g;break}F=h+416|0;Mcb(F,c[m>>2]|0,k,j,A);A=h+420|0;E=c[A>>2]|0;H=F;if((E|0)<32){F=c[H>>2]<<E;c[H>>2]=F;E=h+428|0;I=F>>>24&255;while(1){F=c[E>>2]|0;c[E>>2]=F+1;a[F]=I;F=c[H>>2]|0;c[H>>2]=F<<8;J=(c[A>>2]|0)+8|0;c[A>>2]=J;if((J|0)<32){I=F>>>16&255}else{break}}}c[A>>2]=32;c[H>>2]=0;c[z>>2]=(c[z>>2]|0)+(c[B>>2]|0);do{if((Ncb(b,e,f)|0)==0){if((c[f>>2]|0)==0){break}I=(c[B>>2]|0)+w|0;c[h+136>>2]=I&7;l=I>>3;return l|0}}while(0);z=c[v>>2]|0;H=(c[B>>2]|0)-w+z|0;A=-z|0;I=(c[t>>2]|0)-z|0;if((H|0)<(A|0)){K=A}else{K=(I|0)<(H|0)?I:H}H=K+z|0;c[v>>2]=H;C=H;D=c[r>>2]|0}else{H=c[h+136>>2]|0;if((H|0)==0){C=0;D=g;break}z=s>>>0>H>>>0?H:s;c[v>>2]=z;C=z;D=g}}while(0);g=h+412|0;c[g>>2]=0;s=h+136|0;c[s>>2]=0;K=D-C|0;C=Ncb(b,e,f)|0;if((C|0)<0){l=C;return l|0}if((c[f>>2]|0)!=0){f=c[v>>2]|0;c[s>>2]=f&7;l=f>>3;return l|0}c[g>>2]=K;if((K|0)<=0){l=k;return l|0}g=c[m>>2]|0;f=o|(g|0)==0;o=f?0:g;g=f?0:n;c[p>>2]=o;c[r>>2]=g;r=g+8|0;c[t>>2]=r;c[u>>2]=o+(g>>3);c[v>>2]=0;g=n-K|0;if((g|0)<0){L=0}else{L=(r|0)<(g|0)?r:g}c[v>>2]=L;L=h+416|0;v=h+140|0;c[h+436>>2]=2048;c[h+424>>2]=v;c[h+432>>2]=h+396;c[h+428>>2]=v;c[h+420>>2]=32;c[L>>2]=0;Mcb(L,c[m>>2]|0,k,j,K);l=k;return l|0}function Kcb(a){a=a|0;var b=0;b=c[a+60>>2]|0;if((c[b+56>>2]|0)==0){return 0}DUa(b+2368|0);DUa(b+2456|0);_0(b+2544|0);_0(b+2656|0);return 0}function Lcb(a){a=a|0;var b=0,d=0,e=0,f=0,i=0,j=0,k=0,l=0;b=c[a+60>>2]|0;g[b+6856>>2]=0.0;c[b+412>>2]=0;c[b+136>>2]=0;a=b+72|0;d=c[a>>2]|0;if((d|0)>0){e=b+440|0;f=0;i=d;while(1){h[e+(f<<3)>>3]=(+(f|0)+1.0)*3.141592653589793/(+(i|0)+1.0);j=f+1|0;k=c[a>>2]|0;if((j|0)<(k|0)){f=j;i=k}else{l=k;break}}}else{l=d}TGb(b+616|0,0,1752)|0;if((c[b+56>>2]|0)==0){return}TGb(b+12128+(16-l<<2)|0,0,l<<2|0)|0;l=b+6860|0;c[l>>2]=0;c[l+4>>2]=0;TGb(b+6868|0,0,c[b+52>>2]<<2|0)|0;TGb(b+10452|0,0,640)|0;return}function Mcb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=g+8|0;j=c[i>>2]|0;k=(c[g+12>>2]|0)-j|0;if((k|0)<(h|0)){return}l=b+4|0;m=b+12|0;n=c[m>>2]|0;if(((c[b+20>>2]|0)-32+(c[l>>2]|0)-(n-(c[b+8>>2]|0)<<3)|0)<(h|0)){return}o=k&7;p=k>>3;k=(o|0)>(h|0)?h:o;if((k|0)>0){o=c[g+16>>2]|0;q=(c[g>>2]|0)+(j>>>3)|0;g=32-k|0;r=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(j&7)>>>(g>>>0);q=j+k|0;c[i>>2]=o>>>0>q>>>0?q:o;o=b|0;q=c[o>>2]|0;i=c[l>>2]|0;if((i|0)>(k|0)){s=i-k|0;t=q<<k|r}else{j=n;x=fe(r>>>((k-i|0)>>>0)|q<<i|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;s=g+i|0;t=r}c[o>>2]=t;c[l>>2]=s}s=h-k|0;k=p<<3;M_(b,e+(f-p)|0,(s|0)>(k|0)?k:s);return}function Ncb(f,j,k){f=f|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0.0,Ha=0.0,Ia=0,Ja=0,Ka=0,La=0.0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0.0,gb=0,hb=0.0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0.0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0.0,jd=0,kd=0.0,ld=0,md=0,nd=0.0;l=i;i=i+7520|0;m=l|0;n=l+24|0;o=l+344|0;p=l+440|0;q=l+568|0;r=l+632|0;s=l+664|0;t=l+792|0;u=l+856|0;v=l+880|0;w=l+1264|0;y=l+4896|0;z=l+6880|0;A=l+7008|0;B=l+7264|0;C=f+60|0;D=c[C>>2]|0;E=D;G=D+72|0;H=c[G>>2]|0;I=c[D+80>>2]|0;if((H|0)==16){J=20984+(I<<7)|0}else{J=21240+(I*80|0)|0}I=D+2304|0;UGb(y|0,I|0,H<<2)|0;H=D+640|0;K=D+52|0;UGb(w|0,H|0,c[K>>2]<<2)|0;L=D+412|0;M=c[L>>2]|0;if((M|0)>0){N=D+140|0;O=M>>>0>2147483639>>>0|(N|0)==0;P=O?0:N;N=O?0:M;c[u>>2]=P;c[u+12>>2]=N;c[u+16>>2]=N+8;c[u+4>>2]=P+(N+7>>3);c[u+8>>2]=0;c[L>>2]=0;Q=u;R=P;S=0;U=N}else{Q=D;R=c[D>>2]|0;S=c[D+8>>2]|0;U=c[D+12>>2]|0}N=Q|0;P=Q+8|0;u=U>>>0>2147483639>>>0|(R|0)==0;L=u?0:R;M=u?0:U;U=M+8|0;if((S|0)<0){V=0}else{V=(U|0)<(S|0)?U:S}a:do{if((M-V|0)>=14){u=((V|0)<(U|0))+V|0;if((d[L+(V>>>3)|0]&128>>>((V&7)>>>0)|0)==0){W=-38;i=l;return W|0}O=((u|0)<(U|0))+u|0;if((d[L+(u>>>3)|0]&128>>>((u&7)>>>0)|0)==0){X=O}else{u=O+12|0;X=U>>>0>u>>>0?u:U}u=D+132|0;O=(c[u>>2]|0)==0;if(O){Y=X}else{Z=c[D+88>>2]|0;if((M-X|0)<(Z|0)){break}$=-X|0;aa=U-X|0;if((Z|0)<($|0)){ca=$}else{ca=(aa|0)<(Z|0)?aa:Z}Y=ca+X|0}Z=D+84|0;aa=c[1305353]|0;$=D+100|0;da=D+104|0;ea=D+112|0;fa=Y;ga=0;while(1){if(O){ha=c[Z>>2]|0;if((M-fa|0)<(ha|0)){break a}ia=-fa|0;ja=U-fa|0;if((ha|0)<(ia|0)){ka=ia}else{ka=(ja|0)<(ha|0)?ja:ha}la=ka+fa|0}else{la=fa}ha=L+(la>>>3)|0;ja=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(la&7)>>>26;ha=b[aa+(ja<<2)>>1]|0;ia=b[aa+(ja<<2)+2>>1]|0;ja=ia<<16>>16;do{if(ia<<16>>16<0){ma=la+6|0;na=U>>>0>ma>>>0?ma:U;ma=L+(na>>>3)|0;oa=((fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(na&7)>>>((ja+32|0)>>>0))+ha|0;ma=b[aa+(oa<<2)>>1]|0;pa=b[aa+(oa<<2)+2>>1]|0;oa=pa<<16>>16;if(!(pa<<16>>16<0)){qa=oa;ra=ma;sa=na;break}pa=na-ja|0;na=U>>>0>pa>>>0?pa:U;pa=L+(na>>>3)|0;ta=((fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(na&7)>>>((oa+32|0)>>>0))+ma|0;qa=b[aa+(ta<<2)+2>>1]|0;ra=b[aa+(ta<<2)>>1]|0;sa=na}else{qa=ja;ra=ha;sa=la}}while(0);ha=qa+sa|0;ja=U>>>0>ha>>>0?ha:U;ha=a[E+20+ra|0]|0;if(ha<<24>>24<0){W=-1094995529;ua=253;break}ia=ha<<24>>24;if((ia-2|0)>>>0<6>>>0){na=c[$>>2]|0;if((M-ja|0)<(na|0)){break a}ta=-ja|0;ma=U-ja|0;if((na|0)<(ta|0)){va=ta}else{va=(ma|0)<(na|0)?ma:na}wa=va+ja|0}else{wa=ja}do{if((ha<<24>>24|0)==0){ja=wa+8|0;xa=2;ya=U>>>0>ja>>>0?ja:U}else if((ha<<24>>24|0)==2){ja=L+(wa>>>3)|0;na=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(wa&7);ja=wa+6|0;ma=U>>>0>ja>>>0?ja:U;if(!(na>>>0>3623878655>>>0)){xa=2;ya=ma;break}na=ma+2|0;xa=0;ya=U>>>0>na>>>0?na:U}else{xa=2;ya=wa}}while(0);if((ia-8|0)>>>0<9>>>0){za=(ba((d[1047224+(ia<<3)|0]|0)-1|0,c[ea>>2]|0)|0)+(c[da>>2]|0)|0}else{za=ha<<24>>24==2?xa:0}na=(e[1047230+(ia<<3)>>1]|0)+za|0;if((M-ya|0)<(na|0)){break a}ma=-ya|0;ja=U-ya|0;if((na|0)<(ma|0)){Aa=ma}else{Aa=(ja|0)<(na|0)?ja:na}na=ga+1|0;if((na|0)<3){fa=Aa+ya|0;ga=na}else{break}}if((ua|0)==253){i=l;return W|0}ga=d[R+(S>>>3)|0]|0;fa=Q+16|0;da=c[fa>>2]|0;ea=((S|0)<(da|0))+S|0;c[P>>2]=ea;if((ga&128>>>((S&7)>>>0)|0)==0){DDb(f,2178216,(Ba=i,i=i+1|0,i=i+7&-8,c[Ba>>2]=0,Ba)|0);i=Ba;W=-1163346256;i=l;return W|0}ga=d[R+(ea>>>3)|0]|0;$=((ea|0)<(da|0))+ea|0;c[P>>2]=$;do{if((ga&128>>>((ea&7)>>>0)|0)==0){Ca=480}else{aa=R+($>>>3)|0;Z=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<($&7);aa=Z>>>20;O=$+12|0;c[P>>2]=da>>>0>O>>>0?O:da;if(!(Z>>>0>504365055>>>0)){Ca=aa;break}yDb(f,16,2101944,(Ba=i,i=i+8|0,c[Ba>>2]=aa,Ba)|0);i=Ba;W=-1094995529;i=l;return W|0}}while(0);b:do{if((c[u>>2]|0)!=0){da=c[G>>2]|0;do{if((da|0)>0){$=D+440|0;ea=0;do{h[z+(ea<<3)>>3]=+h[$+(ea<<3)>>3]- +h[J+(ea<<3)>>3];ea=ea+1|0;}while((ea|0)<(da|0));ea=v+256|0;$=B|0;ga=(c[D+76>>2]|0)!=0;if((da|0)!=10){Da=ea;Ea=$;Fa=ga;ua=65;break}aa=ga?29592:32152;Ocb(Q,ea);ga=c[P>>2]|0;Z=c[fa>>2]|0;O=c[N>>2]|0;na=O+(ga>>>3)|0;ja=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ga&7)>>>27;na=ga+5|0;ga=Z>>>0>na>>>0?na:Z;c[P>>2]=ga;na=O+(ga>>>3)|0;ma=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ga&7);na=ga+7|0;ga=Z>>>0>na>>>0?na:Z;c[P>>2]=ga;na=O+(ga>>>3)|0;ta=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ga&7);na=ga+6|0;ga=Z>>>0>na>>>0?na:Z;c[P>>2]=ga;na=O+(ga>>>3)|0;O=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ga&7);na=ga+6|0;c[P>>2]=Z>>>0>na>>>0?na:Z;Z=0;do{Ga=+h[v+256+(Z<<3)>>3];Ha=+h[z+(Z<<3)>>3]-Ga;h[A+(Z<<3)>>3]=Ga+Ha*+g[aa+(ja*80|0)+(Z<<2)>>2];h[A+(Z+10<<3)>>3]=Ga+Ha*+g[aa+(ja*80|0)+40+(Z<<2)>>2];Z=Z+1|0;}while((Z|0)<10);Z=ta>>>26;ja=O>>>26;TGb(B|0,0,160)|0;aa=(ma>>>25)*20|0;h[$>>3]=+(d[45768+aa|0]|0)*.0025807601174+-.3375578474429161+0.0;na=1;Ha=0.0;while(1){h[B+(na<<3)>>3]=Ha+(+(d[45768+(na+aa)|0]|0)*.0025807601174+-.3375578474429161);ga=na+1|0;if((ga|0)>=20){break}na=ga;Ha=+h[B+(ga<<3)>>3]}na=(Z*20|0)+2560|0;aa=0;do{$=B+(aa<<3)|0;h[$>>3]=+h[$>>3]+(+(d[45768+(na+aa)|0]|0)*.0012354460219+-.16558078240010365);aa=aa+1|0;}while((aa|0)<20);aa=(ja*20|0)+3840|0;na=0;while(1){Z=B+(na<<3)|0;h[Z>>3]=+h[Z>>3]+(+(d[45768+(aa+na)|0]|0)*.0011763821673+-.16221299507545536);Z=na+1|0;if((Z|0)<20){na=Z}else{Ia=ea;break}}}else{Da=v+256|0;Ea=B|0;Fa=(c[D+76>>2]|0)!=0;ua=65}}while(0);if((ua|0)==65){da=Fa?21400:25496;Pcb(Q,Da);ia=c[P>>2]|0;ha=c[fa>>2]|0;ea=c[N>>2]|0;na=ea+(ia>>>3)|0;aa=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ia&7)>>>27;na=ia+5|0;ia=ha>>>0>na>>>0?na:ha;c[P>>2]=ia;na=ea+(ia>>>3)|0;ja=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ia&7);na=ia+7|0;ia=ha>>>0>na>>>0?na:ha;c[P>>2]=ia;na=ea+(ia>>>3)|0;Z=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ia&7);na=ia+7|0;ia=ha>>>0>na>>>0?na:ha;c[P>>2]=ia;na=ea+(ia>>>3)|0;ea=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ia&7);na=ia+7|0;c[P>>2]=ha>>>0>na>>>0?na:ha;ha=0;do{Ha=+h[v+256+(ha<<3)>>3];Ga=+h[z+(ha<<3)>>3]-Ha;h[A+(ha<<3)>>3]=Ha+Ga*+g[da+(aa<<7)+(ha<<2)>>2];h[A+(ha+16<<3)>>3]=Ha+Ga*+g[da+(aa<<7)+64+(ha<<2)>>2];ha=ha+1|0;}while((ha|0)<16);TGb(B|0,0,64)|0;ha=(ja>>>25)*10|0;h[Ea>>3]=+(d[41160+ha|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+8>>3]=+(d[41160+(ha|1)|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+16>>3]=+(d[ha+41162|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+24>>3]=+(d[ha+41163|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+32>>3]=+(d[ha+41164|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+40>>3]=+(d[ha+41165|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+48>>3]=+(d[ha+41166|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+56>>3]=+(d[ha+41167|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+64>>3]=+(d[ha+41168|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+72>>3]=+(d[ha+41169|0]|0)*.0012232979501+-.17539511784991815+0.0;ha=B+80|0;TGb(ha|0,0,64)|0;aa=(Z>>>25)*10|0;h[ha>>3]=+(d[39880+aa|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+88>>3]=+(d[39880+(aa|1)|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+96>>3]=+(d[aa+39882|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+104>>3]=+(d[aa+39883|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+112>>3]=+(d[aa+39884|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+120>>3]=+(d[aa+39885|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+128>>3]=+(d[aa+39886|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+136>>3]=+(d[aa+39887|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+144>>3]=+(d[aa+39888|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+152>>3]=+(d[aa+39889|0]|0)*.0014062241527+-.16621538411612877+0.0;TGb(B+160|0,0,96)|0;aa=(ea>>>25)*12|0;ha=0;while(1){da=B+(ha+20<<3)|0;h[da>>3]=+h[da>>3]+(+(d[38344+(ha+aa)|0]|0)*.0016114744851+-.1720838791930345);da=ha+1|0;if((da|0)<12){ha=da}else{Ia=Da;break}}}ha=c[G>>2]|0;do{if((ha|0)>0){aa=0;do{Ga=+h[J+(aa<<3)>>3];ea=aa<<1;h[v+(aa<<3)>>3]=Ga+(+h[A+(aa<<3)>>3]- +h[B+(ea<<3)>>3]);h[v+128+(aa<<3)>>3]=Ga+(+h[A+(ha+aa<<3)>>3]- +h[B+((ea|1)<<3)>>3]);ea=v+256+(aa<<3)|0;h[ea>>3]=Ga+ +h[ea>>3];aa=aa+1|0;}while((aa|0)<(ha|0));aa=ha-1|0;if((ha|0)>1){Ja=0}else{Ka=aa;break}while(1){ea=v+(Ja<<7)|0;Ga=+h[ea>>3];Ha=Ga>.00471238898038469?Ga:.00471238898038469;h[ea>>3]=Ha;ea=1;Ga=Ha;do{Z=v+(Ja<<7)+(ea<<3)|0;Ha=+h[Z>>3];La=Ga+.039269908169872414;Ga=Ha>La?Ha:La;h[Z>>3]=Ga;ea=ea+1|0;}while((ea|0)<(ha|0));ea=v+(Ja<<7)+(aa<<3)|0;Ga=+h[ea>>3];h[ea>>3]=Ga>3.1368802646094087?3.1368802646094087:Ga;ea=1;while(1){if((ea|0)>=(ha|0)){break}if(+h[v+(Ja<<7)+(ea<<3)>>3]<+h[v+(Ja<<7)+(ea-1<<3)>>3]){Ma=1;ua=76;break}else{ea=ea+1|0}}if((ua|0)==76){while(1){ua=0;Ga=+h[v+(Ja<<7)+(Ma<<3)>>3];ea=Ma;while(1){Z=ea-1|0;La=+h[v+(Ja<<7)+(Z<<3)>>3];if(!(La>Ga)){Na=ea;break}h[v+(Ja<<7)+(ea<<3)>>3]=La;if((Z|0)>0){ea=Z}else{Na=Z;break}}h[v+(Ja<<7)+(Na<<3)>>3]=Ga;ea=Ma+1|0;if((ea|0)<(ha|0)){Ma=ea;ua=76}else{break}}}Ja=Ja+1|0;if((Ja|0)>=3){break b}}}else{Ka=ha-1|0}}while(0);aa=v|0;La=+h[aa>>3];h[aa>>3]=La>.00471238898038469?La:.00471238898038469;aa=v+(Ka<<3)|0;La=+h[aa>>3];h[aa>>3]=La>3.1368802646094087?3.1368802646094087:La;aa=1;while(1){if((aa|0)>=(ha|0)){break}if(+h[v+(aa<<3)>>3]<+h[v+(aa-1<<3)>>3]){break}else{aa=aa+1|0}}aa=v+128|0;La=+h[aa>>3];h[aa>>3]=La>.00471238898038469?La:.00471238898038469;aa=v+128+(Ka<<3)|0;La=+h[aa>>3];h[aa>>3]=La>3.1368802646094087?3.1368802646094087:La;aa=1;while(1){if((aa|0)>=(ha|0)){break}if(+h[v+128+(aa<<3)>>3]<+h[v+128+(aa-1<<3)>>3]){break}else{aa=aa+1|0}}La=+h[Ia>>3];h[Ia>>3]=La>.00471238898038469?La:.00471238898038469;aa=v+256+(Ka<<3)|0;La=+h[aa>>3];h[aa>>3]=La>3.1368802646094087?3.1368802646094087:La;aa=1;while(1){if((aa|0)>=(ha|0)){break b}if(+h[v+256+(aa<<3)>>3]<+h[v+256+(aa-1<<3)>>3]){break}else{aa=aa+1|0}}}}while(0);aa=j+76|0;c[aa>>2]=480;ha=_$a(f,j,0)|0;if((ha|0)<0){W=ha;i=l;return W|0}c[aa>>2]=Ca;aa=c[j>>2]|0;ha=D+440|0;ea=ha;Z=f;ja=p|0;da=q|0;na=n;ia=o+88|0;$=o+92|0;ma=o+84|0;O=o|0;ta=m+4|0;ga=m;oa=ta;pa=m+14|0;Oa=m+6|0;Pa=m+8|0;Qa=m+10|0;Ra=m+12|0;Sa=o+4|0;Ta=o+44|0;Ua=o+8|0;Va=o+48|0;Wa=n|0;Xa=s|0;Ya=t|0;Za=r|0;_a=r+4|0;$a=0;c:while(1){if(($a|0)>=3){ua=249;break}d:do{if((c[u>>2]|0)==0){ab=v+($a<<7)|0;if((c[G>>2]|0)==10){Ocb(Q,ab)}else{Pcb(Q,ab)}bb=c[G>>2]|0;do{if((bb|0)>0){cb=0;do{db=v+($a<<7)+(cb<<3)|0;h[db>>3]=+h[J+(cb<<3)>>3]+ +h[db>>3];cb=cb+1|0;}while((cb|0)<(bb|0));La=+h[ab>>3];Ha=La>.00471238898038469?La:.00471238898038469;h[ab>>3]=Ha;cb=(bb|0)>1;if(cb){eb=1;fb=Ha}else{gb=0;break}while(1){db=v+($a<<7)+(eb<<3)|0;Ha=+h[db>>3];La=fb+.039269908169872414;hb=Ha>La?Ha:La;h[db>>3]=hb;db=eb+1|0;if((db|0)<(bb|0)){eb=db;fb=hb}else{gb=cb;break}}}else{hb=+h[ab>>3];h[ab>>3]=hb>.00471238898038469?hb:.00471238898038469;gb=0}}while(0);ab=v+($a<<7)+(bb-1<<3)|0;hb=+h[ab>>3];h[ab>>3]=hb>3.1368802646094087?3.1368802646094087:hb;ab=1;while(1){if((ab|0)>=(bb|0)){break d}if(+h[v+($a<<7)+(ab<<3)>>3]<+h[v+($a<<7)+(ab-1<<3)>>3]){break}else{ab=ab+1|0}}if(gb){ib=1}else{break}do{hb=+h[v+($a<<7)+(ib<<3)>>3];ab=ib;while(1){cb=ab-1|0;La=+h[v+($a<<7)+(cb<<3)>>3];if(!(La>hb)){jb=ab;break}h[v+($a<<7)+(ab<<3)>>3]=La;if((cb|0)>0){ab=cb}else{jb=cb;break}}h[v+($a<<7)+(jb<<3)>>3]=hb;ib=ib+1|0;}while((ib|0)<(bb|0))}}while(0);bb=$a*160|0;ab=aa+(bb<<2)|0;if(($a|0)==0){kb=ea}else{kb=v+($a-1<<7)|0}cb=(c[K>>2]|0)+bb|0;db=(c[G>>2]|0)+bb|0;lb=y+(db<<2)|0;mb=c[C>>2]|0;nb=mb;ob=c[1305353]|0;pb=c[P>>2]|0;qb=c[fa>>2]|0;rb=c[N>>2]|0;sb=rb+(pb>>>3)|0;tb=(fe(d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)|0)<<(pb&7)>>>26;sb=b[ob+(tb<<2)>>1]|0;ub=b[ob+(tb<<2)+2>>1]|0;tb=ub<<16>>16;do{if(ub<<16>>16<0){vb=pb+6|0;wb=qb>>>0>vb>>>0?vb:qb;vb=rb+(wb>>>3)|0;xb=((fe(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(wb&7)>>>((tb+32|0)>>>0))+sb|0;vb=b[ob+(xb<<2)>>1]|0;yb=b[ob+(xb<<2)+2>>1]|0;xb=yb<<16>>16;if(!(yb<<16>>16<0)){zb=xb;Ab=vb;Bb=wb;break}yb=wb-tb|0;wb=qb>>>0>yb>>>0?yb:qb;yb=rb+(wb>>>3)|0;Cb=((fe(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(wb&7)>>>((xb+32|0)>>>0))+vb|0;zb=b[ob+(Cb<<2)+2>>1]|0;Ab=b[ob+(Cb<<2)>>1]|0;Bb=wb}else{zb=tb;Ab=sb;Bb=pb}}while(0);pb=zb+Bb|0;sb=qb>>>0>pb>>>0?pb:qb;c[P>>2]=sb;pb=a[mb+(Ab+20)|0]|0;do{if(pb<<24>>24<0){yDb(Z,16,2045888,(Ba=i,i=i+1|0,i=i+7&-8,c[Ba>>2]=0,Ba)|0);i=Ba;Db=-1094995529}else{tb=pb<<24>>24;ob=d[1047224+(tb<<3)|0]|0;ub=160/(ob>>>0)|0;wb=1047226+(tb<<3)|0;Cb=(tb-2|0)>>>0<6>>>0;if(Cb){vb=ob<<1;xb=(d[1047225+(tb<<3)|0]|0)+1|0;yb=c[mb+92>>2]|0;Eb=c[mb+100>>2]|0;Fb=rb+(sb>>>3)|0;Gb=(fe(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(sb&7)>>>((32-Eb|0)>>>0);Fb=Eb+sb|0;c[P>>2]=qb>>>0>Fb>>>0?Fb:qb;Fb=Gb+yb|0;yb=(c[mb+96>>2]|0)-1|0;Gb=(Fb|0)>(yb|0)?yb:Fb;Fb=mb+568|0;if((c[mb+572>>2]|0)==0){ua=116}else{yb=c[Fb>>2]|0;Eb=Gb-yb|0;if((((Eb|0)>-1?Eb:-Eb|0)*20|0|0)>(yb+Gb|0)){ua=116}else{Hb=yb}}if((ua|0)==116){ua=0;c[Fb>>2]=Gb;Hb=Gb}Fb=0;do{yb=Fb<<1|1;c[r+(Fb<<2)>>2]=(ba(yb,Gb)|0)+ob+(ba(vb-yb|0,Hb)|0)>>xb;Fb=Fb+1|0;}while((Fb|0)<(ob|0));c[mb+576>>2]=(Gb-Hb<<16|0)/160|0;Ib=Gb}else{Ib=0}Fb=d[1047227+(tb<<3)|0]|0;do{if((Fb|0)==0){xb=c[P>>2]|0;vb=c[fa>>2]|0;yb=rb+(xb>>>3)|0;Eb=(fe(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(xb&7)>>>24;yb=xb+8|0;c[P>>2]=vb>>>0>yb>>>0?yb:vb;g[mb+580>>2]=+g[35784+(Eb<<2)>>2]}else if((Fb|0)==2){Eb=mb+584|0;c[Eb>>2]=0;vb=c[P>>2]|0;yb=c[fa>>2]|0;xb=rb+(vb>>>3)|0;Jb=(fe(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0)<<(vb&7);xb=Jb>>>26;Kb=vb+6|0;c[P>>2]=yb>>>0>Kb>>>0?Kb:yb;if(Jb>>>0>3623878655>>>0){c[Eb>>2]=1;Eb=c[P>>2]|0;Jb=c[fa>>2]|0;yb=rb+(Eb>>>3)|0;Kb=(fe(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(Eb&7)>>>30;yb=Eb+2|0;c[P>>2]=Jb>>>0>yb>>>0?yb:Jb;Lb=xb-162+(xb*3|0)+Kb|0}else{Lb=xb}xb=c[Za>>2]|0;Kb=c[_a>>2]|0;Jb=(((xb|0)>(Kb|0)?Kb:xb)|0)>32?24:16;c[mb+588>>2]=Jb;yb=b[1739208+(Lb<<1)>>1]|0;while(1){if((yb|0)<0){yb=yb+xb|0}else{break}}Eb=(xb+79-yb|0)/(xb|0)|0;c[mb+592>>2]=Eb;vb=Jb>>>1;Mb=yb-vb|0;Nb=mb+600|0;c[Nb>>2]=Mb;Ob=(ba(Eb,xb)|0)+yb|0;c[mb+596>>2]=(Kb+159-Ob|0)/(Kb|0)|0;Eb=Ob-(vb|80)|0;vb=mb+604|0;c[vb>>2]=Eb;if(!(Lb>>>0<54>>>0)){break}Ob=Eb-Kb|0;if((Ob+Jb|0)>0){Eb=Ob;while(1){Ob=Eb-Kb|0;if((Ob+Jb|0)>0){Eb=Ob}else{break}}c[vb>>2]=Eb}if(!(Lb>>>0<6>>>0)){break}Kb=Mb-xb|0;if((Kb+Jb|0)>0){Pb=Kb}else{break}while(1){Kb=Pb-xb|0;if((Kb+Jb|0)>0){Pb=Kb}else{break}}c[Nb>>2]=Pb}}while(0);Gb=d[wb]|0;Jb=(pb&255)>>>0<2>>>0;xb=pb<<24>>24==0;Mb=mb+612|0;Eb=1e3-ub|0;vb=mb+580|0;Kb=mb+616|0;yb=(ub|0)==0;Ob=mb+72|0;Qb=ub>>>0<81>>>0;Rb=ub<<2;Sb=pb<<24>>24==2;Tb=mb+584|0;Ub=mb+588|0;Vb=mb+592|0;Wb=mb+608|0;Xb=Kb;Yb=1047225+(tb<<3)|0;Zb=mb+568|0;_b=mb+576|0;$b=1047228+(tb<<3)|0;ac=mb+122|0;bc=mb+120|0;cc=mb+124|0;dc=mb+126|0;ec=mb+104|0;fc=mb+116|0;gc=mb+108|0;hc=mb+112|0;hb=+(ob|0);ic=0;jc=0;while(1){if((Gb|0)==1){kc=c[r+(jc<<2)>>2]<<2;lc=ic}else if((Gb|0)==2){mc=e[ac>>1]|0;nc=e[bc>>1]|0;oc=mc-nc<<2;pc=e[cc>>1]|0;qc=pc-mc<<1;rc=e[dc>>1]|0;sc=1-pc+rc|0;if((jc|0)==0){tc=c[ec>>2]|0;uc=c[P>>2]|0;vc=c[fa>>2]|0;wc=(c[N>>2]|0)+(uc>>>3)|0;xc=(fe(d[wc]|d[wc+1|0]<<8|d[wc+2|0]<<16|d[wc+3|0]<<24|0)|0)<<(uc&7)>>>((32-tc|0)>>>0);wc=uc+tc|0;c[P>>2]=vc>>>0>wc>>>0?wc:vc;yc=xc}else{xc=ic-(c[fc>>2]|0)|0;vc=c[hc>>2]|0;wc=c[P>>2]|0;tc=c[fa>>2]|0;uc=(c[N>>2]|0)+(wc>>>3)|0;zc=(fe(d[uc]|d[uc+1|0]<<8|d[uc+2|0]<<16|d[uc+3|0]<<24|0)|0)<<(wc&7)>>>((32-vc|0)>>>0);uc=wc+vc|0;c[P>>2]=tc>>>0>uc>>>0?uc:tc;yc=xc+zc|0}zc=c[fc>>2]|0;xc=(c[gc>>2]|0)-zc|0;if((yc|0)<(zc|0)){Ac=zc}else{Ac=(yc|0)>(xc|0)?xc:yc}do{if((yc|0)<(oc|0)){Bc=yc+(nc<<2)|0}else{xc=yc-oc|0;if((xc|0)<(qc|0)){Bc=(xc<<1)+(mc<<2)|0;break}zc=xc-qc|0;if((zc|0)<(sc|0)){Bc=zc+pc<<2;break}else{Bc=rc<<2;break}}}while(0);c[r+(jc<<2)>>2]=Bc>>2;kc=Bc;lc=Ac}else{kc=0;lc=ic}rc=ba(jc,ub)|0;pc=rc+cb|0;sc=w+(pc<<2)|0;qc=y+(rc+db<<2)|0;e:do{if(Jb){if(xb){mc=(c[Mb>>2]|0)+(jc*1877|0)|0;oc=mc>>>0>65534>>>0?mc-65535|0:mc;gHb(oc,(oc|0)<0|0?-1:0,477218589,0)|0;mc=(F*-9|0)+oc|0;nc=ba(oc,c[594040+(mc<<3)>>2]|0)|0;gHb(oc,0,c[594044+(mc<<3)>>2]|0,0)|0;Cc=((F+nc&65535)>>>0)%(Eb>>>0)|0;Dc=vb}else{nc=c[P>>2]|0;mc=c[fa>>2]|0;oc=c[N>>2]|0;Nb=oc+(nc>>>3)|0;zc=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(nc&7)>>>24;Nb=nc+8|0;nc=mc>>>0>Nb>>>0?Nb:mc;c[P>>2]=nc;Nb=oc+(nc>>>3)|0;oc=(fe(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(nc&7)>>>26;Nb=nc+6|0;c[P>>2]=mc>>>0>Nb>>>0?Nb:mc;Cc=zc;Dc=35528+(oc<<2)|0}La=+g[Dc>>2];TGb(Kb|0,0,24)|0;if(yb){break}else{Ec=0}do{g[w+(pc+Ec<<2)>>2]=La*+g[16984+(Ec+Cc<<2)>>2];Ec=Ec+1|0;}while((Ec|0)<(ub|0))}else{if(!Qb){ua=157;break c}TGb(na|0,0,Rb|0)|0;oc=kc>>2;c[ia>>2]=oc;g[$>>2]=1.0;c[ma>>2]=0;c[O>>2]=0;f:do{if(Sb){if((c[Tb>>2]|0)==0){Fc=0}else{Fc=((jc|0)==0)<<1}zc=12-Fc|0;mc=c[P>>2]|0;Nb=c[fa>>2]|0;nc=c[N>>2]|0;xc=nc+(mc>>>3)|0;tc=(fe(d[xc]|d[xc+1|0]<<8|d[xc+2|0]<<16|d[xc+3|0]<<24|0)|0)<<(mc&7)>>>((32-zc|0)>>>0);xc=mc+zc|0;zc=Nb>>>0>xc>>>0?xc:Nb;c[P>>2]=zc;xc=(c[nb+592+(jc<<2)>>2]|0)>0;if(xc){mc=(c[Ub>>2]|0)==24;uc=mc?8:4;vc=mc?7:3;wc=mc?4:3;Gc=mc?3:4;mc=c[nb+600+(jc<<2)>>2]|0;Hc=tc;Ic=Gc;Jc=0;while(1){Kc=Ic-1|0;g[o+44+(Jc<<2)>>2]=(Hc&uc|0)!=0?-1.0:1.0;Lc=Kc+mc+(ba(Hc&vc,Gc)|0)|0;c[o+4+(c[O>>2]<<2)>>2]=Lc;Lc=c[O>>2]|0;Mc=o+4+(Lc<<2)|0;Nc=c[Mc>>2]|0;if((Nc|0)<0){Oc=Mc;Mc=Nc;while(1){c[Oc>>2]=(c[ia>>2]|0)+Mc;Pc=c[O>>2]|0;Qc=o+4+(Pc<<2)|0;Rc=c[Qc>>2]|0;if((Rc|0)<0){Oc=Qc;Mc=Rc}else{Sc=Rc;Tc=Pc;break}}}else{Sc=Nc;Tc=Lc}if((Sc|0)<80){Mc=Tc+1|0;c[O>>2]=Mc;Uc=Mc}else{Uc=Tc}if((Kc|0)>0){Hc=Hc>>wc;Ic=Kc;Jc=Uc}else{Vc=mc;Wc=Uc;break}}}else{mc=tc>>>1&255;do{if(mc>>>0<79>>>0){Xc=mc+1|0;Yc=1}else{if(mc>>>0<156>>>0){Xc=mc-76|0;Yc=3;break}if(mc>>>0<231>>>0){Xc=mc-151|0;Yc=5;break}else{Xc=mc-224|0;Yc=7;break}}}while(0);La=(tc&512|0)!=0?-1.0:1.0;c[ma>>2]=3;c[Sa>>2]=Xc-Yc;g[Ta>>2]=La;c[Ua>>2]=Xc;if((tc&1|0)==0){Zc=La}else{Zc=-0.0-La}g[Va>>2]=Zc;c[O>>2]=2;Vc=c[nb+600+(jc<<2)>>2]|0;Wc=2}do{if(xc){mc=c[Ub>>2]|0;if((mc+Vc|0)>=1){_c=Vc;break}Jc=c[ia>>2]|0;Ic=Vc;while(1){wc=Ic+Jc|0;if((wc+mc|0)<1){Ic=wc}else{_c=wc;break}}}else{_c=Vc}}while(0);tc=(c[Vb>>2]|0)>0;do{if(tc){Ic=(jc|0)==0;if(Ic|xc^1){$c=_c;ad=Ic?16:4;break}$c=c[Wb>>2]|0;ad=4}else{$c=_c;ad=8}}while(0);Ic=xc?$c-ad|0:0;c[ga>>2]=0;TGb(oa|0,-1|0,10)|0;x=0;b[pa>>1]=x;b[pa+2>>1]=x>>16;if(xc&($c|0)<80){mc=c[Ub>>2]|0;Jc=c[ia>>2]|0;Kc=$c;do{Lc=Kc>>4;Nc=m+(Lc+2<<1)|0;wc=16-(Kc&15)|0;Hc=m+(Lc+3<<1)|0;b[Nc>>1]=65535<<wc&e[Nc>>1];Nc=mc-wc|0;if((Nc|0)>15){wc=m+(Lc+4<<1)|0;b[Hc>>1]=0;b[wc>>1]=e[wc>>1]&65535>>>((Nc-16|0)>>>0)}else{b[Hc>>1]=e[Hc>>1]&65535>>>(Nc>>>0)}Kc=Kc+Jc|0;}while((Kc|0)<80)}if(tc){bd=5-(jc<<1)|0}else{bd=4}Kc=nc+(zc>>>3)|0;Jc=(fe(d[Kc]|d[Kc+1|0]<<8|d[Kc+2|0]<<16|d[Kc+3|0]<<24|0)|0)<<(zc&7)>>>((32-bd|0)>>>0);Kc=bd+zc|0;mc=Nb>>>0>Kc>>>0?Kc:Nb;c[P>>2]=mc;g:do{if((Jc|0)<0){cd=0}else{Kc=c[ia>>2]|0;xc=Ic;Nc=0;Hc=0;h:while(1){if((xc|0)<0){wc=xc;while(1){Lc=wc+Kc|0;if((Lc|0)<0){wc=Lc}else{dd=Lc;break}}}else{dd=xc}if((dd|0)>79){do{if((b[ta>>1]|0)==0){if((b[Oa>>1]|0)!=0){ed=31;break}if((b[Pa>>1]|0)!=0){ed=47;break}if((b[Qa>>1]|0)!=0){ed=63;break}if((b[Ra>>1]|0)==0){break h}else{ed=79}}else{ed=15}}while(0);wc=e[m+((ed>>>4)+2<<1)>>1]|0;Lc=(wc&65280|0)==0;fd=ed-(d[1191992+(Lc?wc:wc>>>8)|0]|0)+(Lc?0:-8)|0}else{fd=dd}Lc=m+((fd>>4)+2<<1)|0;wc=e[Lc>>1]|0;Gc=32768>>>((fd&15)>>>0);if((wc&Gc|0)==0){gd=Hc;hd=Nc}else{b[Lc>>1]=(Gc^65535)&wc;gd=fd;hd=Nc+1|0}if((hd|0)>(Jc|0)){cd=gd;break g}else{xc=xc+1|0;Nc=hd;Hc=gd}}Hc=(c[Mb>>2]|0)+(jc*1877|0)|0;Nc=Hc>>>0>65534>>>0?Hc-65535|0:Hc;gHb(Nc,(Nc|0)<0|0?-1:0,477218589,0)|0;Hc=(F*-9|0)+Nc|0;xc=ba(Nc,c[594040+(Hc<<3)>>2]|0)|0;gHb(Nc,0,c[594044+(Hc<<3)>>2]|0,0)|0;Hc=((F+xc&65535)>>>0)%(Eb>>>0)|0;if(!yb){xc=0;do{g[w+(pc+xc<<2)>>2]=+g[16984+(xc+Hc<<2)>>2]*+g[vb>>2];xc=xc+1|0;}while((xc|0)<(ub|0))}xc=mc+8|0;c[P>>2]=Nb>>>0>xc>>>0?xc:Nb;break e}}while(0);c[o+4+(Wc<<2)>>2]=cd;Jc=d[nc+(mc>>>3)|0]|0;c[P>>2]=((mc|0)<(Nb|0))+mc;g[o+44+(c[O>>2]<<2)>>2]=(Jc&128>>>((mc&7)>>>0)|0)!=0?-1.0:1.0;c[O>>2]=(c[O>>2]|0)+1;Jc=c[ia>>2]|0;Ic=(80-cd|0)%(Jc|0)|0;c[Wb>>2]=(Ic|0)==0?0:Jc-Ic|0}else{Ic=5-(d[Yb]|0)|0;c[ma>>2]=-1;Jc=32-Ic|0;zc=c[N>>2]|0;tc=c[fa>>2]|0;xc=d[$b]|0;Hc=0;Nc=c[P>>2]|0;Kc=0;while(1){wc=d[zc+(Nc>>>3)|0]|0;Gc=((Nc|0)<(tc|0))+Nc|0;c[P>>2]=Gc;La=(wc&128>>>((Nc&7)>>>0)|0)!=0?1.0:-1.0;wc=zc+(Gc>>>3)|0;Lc=(fe(d[wc]|d[wc+1|0]<<8|d[wc+2|0]<<16|d[wc+3|0]<<24|0)|0)<<(Gc&7)>>>(Jc>>>0);wc=Gc+Ic|0;Gc=tc>>>0>wc>>>0?wc:tc;c[P>>2]=Gc;c[o+4+(Kc<<2)>>2]=(Lc*5|0)+Hc;wc=c[O>>2]|0;c[O>>2]=wc+1;g[o+44+(wc<<2)>>2]=La;if((Hc|0)<(xc|0)){wc=zc+(Gc>>>3)|0;vc=(fe(d[wc]|d[wc+1|0]<<8|d[wc+2|0]<<16|d[wc+3|0]<<24|0)|0)<<(Gc&7)>>>(Jc>>>0);wc=Gc+Ic|0;uc=tc>>>0>wc>>>0?wc:tc;c[P>>2]=uc;c[o+4+(c[O>>2]<<2)>>2]=(vc*5|0)+Hc;if((Lc|0)<(vc|0)){id=-0.0-La}else{id=La}vc=c[O>>2]|0;c[O>>2]=vc+1;g[o+44+(vc<<2)>>2]=id;jd=uc}else{jd=Gc}Gc=Hc+1|0;if((Gc|0)>=5){break f}Hc=Gc;Nc=jd;Kc=c[O>>2]|0}}}while(0);Pgb(Wa,o,1.0,ub);Kc=c[P>>2]|0;Nc=c[fa>>2]|0;Hc=(c[N>>2]|0)+(Kc>>>3)|0;tc=(fe(d[Hc]|d[Hc+1|0]<<8|d[Hc+2|0]<<16|d[Hc+3|0]<<24|0)|0)<<(Kc&7)>>>25;Hc=Kc+7|0;c[P>>2]=Nc>>>0>Hc>>>0?Hc:Nc;La=+eCb(Xb,399760,6)+ -5.240916164;Ga=+g[36808+(tc<<2)>>2];Ha=+_(La+Ga);La=+g[37320+(tc<<2)>>2];if((tc|0)==99){kd=-2.995732307434082}else{kd=(tc|0)==95?1.6094379425048828:Ga}tc=8>>>((d[Yb]|0)>>>0);VGb(nb+616+(tc<<2)|0,Kb|0,6-tc<<2|0)|0;if((tc|0)>0){Nc=0;do{g[nb+616+(Nc<<2)>>2]=kd;Nc=Nc+1|0;}while((Nc|0)<(tc|0))}do{if(Cb){if(yb){break}else{ld=0}do{tc=ld+rc|0;Nc=c[_b>>2]|0;Hc=(ba(Nc,tc)|0)+(c[Zb>>2]<<16)|0;Kc=Hc+28671>>16;Ic=(Kc<<16)-Hc<<3;Hc=Ic+360448|0;Jc=Hc>>16;do{if((Nc|0)==0){md=ub}else{zc=(Hc-(((Nc|0)>0?Hc:Ic+425984|0)&-65536)|0)/(Nc|0)|0;xc=(zc|0)/8|0;mc=ub-ld|0;if((zc|0)<8){md=1;break}md=(xc|0)>(mc|0)?mc:xc}}while(0);Nc=tc+cb|0;xgb(w+(Nc<<2)|0,w+(Nc-Kc<<2)|0,34840,17,Jc,9,md);ld=md+ld|0;}while((ld|0)<(ub|0))}else{Nc=kc&3;if((Nc|0)==0){iEb(sc,oc<<2,Rb);break}else{xgb(sc,w+(pc-oc<<2)|0,34712,4,Nc,8,ub);break}}}while(0);Mgb(sc,sc,Wa,La,Ha,ub)}}while(0);pc=c[Ob>>2]|0;if((pc|0)>0){Ga=(+(jc|0)+.5)/hb;rc=0;do{nd=+h[kb+(rc<<3)>>3];h[p+(rc<<3)>>3]=+T(nd+Ga*(+h[v+($a<<7)+(rc<<3)>>3]-nd));rc=rc+1|0;}while((rc|0)<(pc|0))}QKa(ja,da,pc>>1);y$(qc,da,sc,ub,c[Ob>>2]|0);rc=jc+1|0;if((rc|0)<(ob|0)){ic=lc;jc=rc}else{break}}if((c[mb+56>>2]|0)==0){UGb(ab|0,lb|0,640)|0}else{jc=c[Ob>>2]|0;if((jc|0)>0){ic=0;do{h[s+(ic<<3)>>3]=+T((+h[kb+(ic<<3)>>3]+ +h[v+($a<<7)+(ic<<3)>>3])*.5);ic=ic+1|0;}while((ic|0)<(jc|0))}QKa(Xa,Ya,jc>>1);ic=mb+52|0;ub=mb+6868|0;Rb=c[Za>>2]|0;Qcb(nb,lb,ab,Ya,ub+((c[ic>>2]|0)+bb<<2)|0,Fb,Rb);_b=c[Ob>>2]|0;if((_b|0)>0){yb=0;do{h[s+(yb<<3)>>3]=+T(+h[v+($a<<7)+(yb<<3)>>3]);yb=yb+1|0;}while((yb|0)<(_b|0))}QKa(Xa,Ya,_b>>1);yb=bb+80|0;Qcb(nb,y+(db+80<<2)|0,aa+(yb<<2)|0,Ya,ub+(yb+(c[ic>>2]|0)<<2)|0,Fb,Rb)}yb=c[Mb>>2]|0;Ob=yb+1|0;c[Mb>>2]=(Ob|0)>65534?yb-65534|0:Ob;c[mb+572>>2]=Gb;if((Gb|0)==0){c[Zb>>2]=0;Db=0;break}else if((Gb|0)==1){c[Zb>>2]=Ib;Db=0;break}else if((Gb|0)==2){c[Zb>>2]=c[r+(ob-1<<2)>>2];Db=0;break}else{Db=0;break}}}while(0);if((Db|0)==0){$a=$a+1|0}else{ua=248;break}}if((ua|0)==157){yDb(0,0,2000120,(Ba=i,i=i+24|0,c[Ba>>2]=1963248,c[Ba+8>>2]=1935080,c[Ba+16>>2]=1286,Ba)|0);i=Ba;Cd();return 0}else if((ua|0)==248){c[k>>2]=0;W=Db;i=l;return W|0}else if((ua|0)==249){$a=c[P>>2]|0;Ya=c[N>>2]|0;aa=d[Ya+($a>>>3)|0]|0;Xa=c[fa>>2]|0;Za=(($a|0)<(Xa|0))+$a|0;c[P>>2]=Za;if((aa&128>>>(($a&7)>>>0)|0)!=0){$a=Ya+(Za>>>3)|0;Ya=(fe(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(Za&7)>>>28;$a=Za+4|0;Za=(Xa>>>0>$a>>>0?$a:Xa)+10+(Ya*10|0)|0;c[P>>2]=Xa>>>0>Za>>>0?Za:Xa}c[k>>2]=1;Xa=c[G>>2]|0;UGb(ha|0,v+256|0,Xa<<3)|0;UGb(I|0,y+1920|0,Xa<<2)|0;Xa=c[K>>2]<<2;UGb(H|0,w+1920|0,Xa)|0;if((c[D+56>>2]|0)==0){W=0;i=l;return W|0}VGb(D+6868|0,D+8788|0,Xa|0)|0;W=0;i=l;return W|0}}}while(0);c[k>>2]=0;W=1;i=l;return W|0}function Ocb(a,f){a=a|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0;g=i;i=i+8|0;j=g|0;k=a+8|0;l=c[k>>2]|0;m=c[a+16>>2]|0;n=c[a>>2]|0;a=n+(l>>>3)|0;o=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(l&7)>>>24;a=l+8|0;l=m>>>0>a>>>0?a:m;c[k>>2]=l;a=o&65535;b[j>>1]=a;o=n+(l>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>26;o=l+6|0;l=m>>>0>o>>>0?o:m;c[k>>2]=l;b[j+2>>1]=p;p=n+(l>>>3)|0;o=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(l&7)>>>27;p=l+5|0;l=m>>>0>p>>>0?p:m;c[k>>2]=l;b[j+4>>1]=o;o=n+(l>>>3)|0;n=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>27;o=l+5|0;c[k>>2]=m>>>0>o>>>0?o:m;b[j+6>>1]=n;TGb(f|0,0,80)|0;n=0;m=50888;q=0.0;r=0.0;s=0.0;t=0.0;u=0.0;v=0.0;w=0.0;x=0.0;y=0.0;z=0.0;o=a;while(1){a=(o&65535)*10|0;A=+h[1381368+(n<<3)>>3];B=+h[1381336+(n<<3)>>3];C=q+(A+B*+(d[m+a|0]|0|0));h[f>>3]=C;D=r+(A+B*+(d[m+(a|1)|0]|0|0));h[f+8>>3]=D;E=s+(A+B*+(d[m+(a+2)|0]|0|0));h[f+16>>3]=E;F=t+(A+B*+(d[m+(a+3)|0]|0|0));h[f+24>>3]=F;G=u+(A+B*+(d[m+(a+4)|0]|0|0));h[f+32>>3]=G;H=v+(A+B*+(d[m+(a+5)|0]|0|0));h[f+40>>3]=H;I=w+(A+B*+(d[m+(a+6)|0]|0|0));h[f+48>>3]=I;J=x+(A+B*+(d[m+(a+7)|0]|0|0));h[f+56>>3]=J;K=y+(A+B*+(d[m+(a+8)|0]|0|0));h[f+64>>3]=K;L=z+(A+B*+(d[m+(a+9)|0]|0|0));h[f+72>>3]=L;a=n+1|0;if((a|0)>=4){break}k=m+((e[1381328+(n<<1)>>1]|0)*10|0)|0;n=a;m=k;q=C;r=D;s=E;t=F;u=G;v=H;w=I;x=J;y=K;z=L;o=b[j+(a<<1)>>1]|0}i=g;return}function Pcb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;i=c[a>>2]|0;a=i+(f>>>3)|0;j=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>24;a=f+8|0;f=g>>>0>a>>>0?a:g;c[e>>2]=f;a=i+(f>>>3)|0;k=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>26;a=f+6|0;f=g>>>0>a>>>0?a:g;c[e>>2]=f;a=i+(f>>>3)|0;l=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>25;a=f+7|0;f=g>>>0>a>>>0?a:g;c[e>>2]=f;a=i+(f>>>3)|0;m=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>26;a=f+6|0;f=g>>>0>a>>>0?a:g;c[e>>2]=f;a=i+(f>>>3)|0;i=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>25;a=f+7|0;c[e>>2]=g>>>0>a>>>0?a:g;TGb(b|0,0,24)|0;g=j*5|0;n=+(d[g+44169|0]|0|0)*.003343958628+-.40079182437437144+0.0;o=+(d[g+44170|0]|0|0)*.003343958628+-.40079182437437144+0.0;p=+(d[g+44171|0]|0|0)*.003343958628+-.40079182437437144+0.0;q=+(d[g+44172|0]|0|0)*.003343958628+-.40079182437437144+0.0;j=k*5|0;h[b>>3]=+(d[44168+g|0]|0|0)*.003343958628+-.40079182437437144+0.0+(+(d[j+45448|0]|0|0)*.00069908173703+-.07631556874100326);h[b+8>>3]=n+(+(d[j+45449|0]|0|0)*.00069908173703+-.07631556874100326);h[b+16>>3]=o+(+(d[j+45450|0]|0|0)*.00069908173703+-.07631556874100326);h[b+24>>3]=p+(+(d[j+45451|0]|0|0)*.00069908173703+-.07631556874100326);h[b+32>>3]=q+(+(d[j+45452|0]|0|0)*.00069908173703+-.07631556874100326);j=b+40|0;TGb(j|0,0,24)|0;g=l*5|0;q=+(d[g+43209|0]|0|0)*.0033216608306+-.402419169368931+0.0;p=+(d[g+43210|0]|0|0)*.0033216608306+-.402419169368931+0.0;o=+(d[g+43211|0]|0|0)*.0033216608306+-.402419169368931+0.0;n=+(d[g+43212|0]|0|0)*.0033216608306+-.402419169368931+0.0;l=m*5|0;h[j>>3]=+(d[43208+g|0]|0|0)*.0033216608306+-.402419169368931+0.0+(+(d[l+43848|0]|0|0)*.0010334960326+-.10093308877453286);h[b+48>>3]=q+(+(d[l+43849|0]|0|0)*.0010334960326+-.10093308877453286);h[b+56>>3]=p+(+(d[l+43850|0]|0|0)*.0010334960326+-.10093308877453286);h[b+64>>3]=o+(+(d[l+43851|0]|0|0)*.0010334960326+-.10093308877453286);h[b+72>>3]=n+(+(d[l+43852|0]|0|0)*.0010334960326+-.10093308877453286);l=b+80|0;TGb(l|0,0,40)|0;g=i*6|0;h[l>>3]=+(d[42440+g|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+88>>3]=+(d[42440+(g|1)|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+96>>3]=+(d[g+42442|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+104>>3]=+(d[g+42443|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+112>>3]=+(d[g+42444|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+120>>3]=+(d[g+42445|0]|0|0)*.0031899104283+-.40782899191841254+0.0;return}function Qcb(a,b,d,e,f,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0,H=0,I=0;k=i;i=i+352|0;l=k|0;m=k+8|0;n=k+16|0;o=k+336|0;p=k+344|0;q=a+12192|0;r=a+72|0;z$(f,e,b,80,c[r>>2]|0);do{if((h|0)>1){s=c[a+92>>2]|0;t=c[a+96>>2]|0;u=j-3|0;v=j+3|0;w=f+(-((v|0)<(t|0)?v:t)<<2)|0;t=0;v=f+(-((u|0)<(s|0)?s:u)<<2)|0;x=0.0;do{y=+eCb(f,v,80);u=y>x;x=u?y:x;t=u?v:t;v=v-4|0;}while(!(v>>>0<w>>>0));w=n|0;if(!(x>0.0)){z=f;break}y=+eCb(t,t,80);if(!(y>0.0)){z=f;break}if(x>y){A=.625}else{B=y;A=B/(x*.6+B)}v=0;while(1){B=+g[t+(v<<2)>>2];g[n+(v<<2)>>2]=B+A*(+g[f+(v<<2)>>2]-B);u=v+1|0;if((u|0)<80){v=u}else{z=w;break}}}else{z=f}}while(0);y$(q,e,z,80,c[r>>2]|0);z=c[r>>2]|0;UGb(a+12128+(16-z<<2)|0,a+12128+(96-z<<2)|0,z<<2)|0;z=(h|0)!=0;if(z){f=a+11104|0;g[m>>2]=0.0;g[f>>2]=1.0;n=a+11108|0;j=c[r>>2]|0;UGb(n|0,e|0,j<<2)|0;TGb(a+11104+(j+1<<2)|0,0,(128-j<<2)-4|0)|0;j=c[r>>2]|0;A=+eCb(e,e,j)+1.0;x=+g[e>>2];B=(x+ +eCb(e,e+4|0,j-1|0))/A*.7;Agb(m,B,f,(c[r>>2]|0)+2|0);r=a+2368|0;m=a+2452|0;ne[c[m>>2]&1023](r,f);B=+g[n>>2];A=+ad(+(B*B));n=1;B=A<-15.0?-15.0:A;x=A<15.0?A:15.0;do{j=n<<1;y=+g[a+11104+(j<<2)>>2];C=+g[a+11104+((j|1)<<2)>>2];D=+ad(+(y*y+C*C));g[a+11104+(n<<2)>>2]=D;B=B>D?B:D;x=x>D?D:x;n=n+1|0;}while((n|0)<64);D=+g[f>>2];C=+ad(+(D*D));g[f>>2]=C;D=B>C?B:C;B=D-(x>C?C:x);n=a+11360|0;g[n>>2]=A;A=64.0/B;x=((h|0)==1?.38461538461538464:.3401360544217687)*B;B=x*5.863484791035423;h=a+60|0;j=0;y=C;while(1){e=a+11104+(j<<2)|0;if(((Gc(+(A*(D-y)))|0)-1|0)<0){E=0}else{E=(Gc(+(A*(D- +g[e>>2])))|0)-1|0}C=+g[54728+(c[h>>2]<<8)+(E<<2)>>2];g[e>>2]=B*C;e=~~((x*C+-.0295)*70.570526123);if((e|0)>127){g[a+11616+(j<<2)>>2]=+S(1.0331662893295288,+(+(e-127|0)))*1.07157564163208}else{g[a+11616+(j<<2)>>2]=+g[37832+(((e|0)<0?0:e)<<2)>>2]}e=j+1|0;if((e|0)>=65){break}j=e;y=+g[a+11104+(e<<2)>>2]}j=a+11616|0;ne[c[a+2648>>2]&1023](a+2544|0,f);ne[c[a+2760>>2]&1023](a+2656|0,f);y=+g[n>>2];f=~~y;if((f|0)<-255){F=0}else{F=(f|0)>255?510:f+255|0}g[j>>2]=+g[j>>2]*+g[a+4812+(F<<2)>>2];F=~~(y- +g[a+11356>>2]*2.0);if((F|0)<-255){G=0}else{G=(F|0)>255?510:F+255|0}x=+g[a+11872>>2];B=+g[a+4812+(G<<2)>>2];G=63;D=y;while(1){F=G-1|0;f=~~(-0.0-D- +g[a+11104+(F<<2)>>2]*2.0);if((f|0)<-255){H=0}else{H=(f|0)>255?510:f+255|0}f=a+11616+(G<<2)|0;E=G<<1;g[a+11616+((E|1)<<2)>>2]=+g[f>>2]*+g[a+2768+(H<<2)>>2];g[a+11616+(E<<2)>>2]=+g[f>>2]*+g[a+4812+(H<<2)>>2];if((F|0)==0){break}f=G-2|0;E=~~(+g[n>>2]- +g[a+11104+(f<<2)>>2]*2.0);if((E|0)<-255){I=0}else{I=(E|0)>255?510:E+255|0}E=a+11616+(F<<2)|0;h=F<<1;g[a+11616+((h|1)<<2)>>2]=+g[E>>2]*+g[a+2768+(I<<2)>>2];g[a+11616+(h<<2)>>2]=+g[E>>2]*+g[a+4812+(I<<2)>>2];G=f;D=+g[n>>2]}n=a+11620|0;g[n>>2]=x*B;G=a+2456|0;I=a+2540|0;ne[c[I>>2]&1023](G,j);TGb(a+11804|0,0,324)|0;if((c[a+64>>2]|0)!=0){g[l>>2]=0.0;g[a+11800>>2]=0.0;B=+eCb(j,j,46)+1.0;x=+g[j>>2];Agb(l,(x+ +eCb(j,n,45))/B*-1.8,j,47)}B=+R(1.0/+eCb(j,j,47))*.015625;l=0;do{H=a+11616+(l<<2)|0;g[H>>2]=B*+g[H>>2];l=l+1|0;}while((l|0)<47);TGb(a+12512|0,0,192)|0;ne[c[m>>2]&1023](r,q);ne[c[m>>2]&1023](r,j);g[q>>2]=+g[j>>2]*+g[q>>2];j=a+12196|0;g[j>>2]=+g[n>>2]*+g[j>>2];j=1;do{n=j<<1;r=a+12128+(n+16<<2)|0;B=+g[r>>2];m=n|1;l=a+12128+(m+16<<2)|0;x=+g[l>>2];D=+g[a+11616+(n<<2)>>2];y=+g[a+11616+(m<<2)>>2];g[r>>2]=B*D-x*y;g[l>>2]=x*D+B*y;j=j+1|0;}while((j|0)<64);ne[c[I>>2]&1023](G,q)}q=a+11092|0;G=c[q>>2]|0;if((G|0)!=0){I=(G|0)>80?80:G;if((I|0)>0){j=0;do{l=a+12128+(j+16<<2)|0;g[l>>2]=+g[a+10452+(j<<2)>>2]+ +g[l>>2];j=j+1|0;}while((j|0)<(I|0))}j=G-I|0;c[q>>2]=j;VGb(a+10452|0,a+10772|0,j<<2|0)|0}do{if(z){j=c[q>>2]|0;I=(j|0)<47;G=I?j:47;if((G|0)>0){j=0;do{l=a+10452+(j<<2)|0;g[l>>2]=+g[a+12128+(j+96<<2)>>2]+ +g[l>>2];j=j+1|0;}while((j|0)<(G|0))}if(!I){break}UGb(a+10452+(G<<2)|0,a+12128+(G+96<<2)|0,47-G<<2)|0;c[q>>2]=47}}while(0);q=a+6856|0;y=+g[q>>2];B=0.0;D=0.0;z=0;do{B=B+ +Q(+(+g[b+(z<<2)>>2]));D=D+ +Q(+(+g[a+12128+(z+16<<2)>>2]));z=z+1|0;}while((z|0)<80);x=B*.009999990463256836/D;z=0;D=y;do{D=x+D*.9900000095367432;g[d+(z<<2)>>2]=D*+g[a+12128+(z+16<<2)>>2];z=z+1|0;}while((z|0)<80);g[q>>2]=D;if((c[a+68>>2]|0)<=8){i=k;return}q=o|0;g[q>>2]=-1.9999699592590332;g[o+4>>2]=1.0;o=p|0;g[o>>2]=-1.9330735206604004;g[p+4>>2]=.9358919858932495;zgb(d,d,q,o,.939805805683136,a+6860|0,80);i=k;return}function Rcb(a){a=a|0;var b=0,d=0,e=0;b=a+15300|0;_cb(b);d=c[a+15308>>2]|0;c[a+11248>>2]=d;e=a+11184|0;y2(e,d);x2(e,a+15384|0,1080128);x2(e,a+15516|0,1080064);x2(e,a+364|0,1080560);x2(e,a+496|0,1080624);x2(e,a+628|0,1080688);x2(e,a+232|0,1080496);c[a+11176>>2]=c[a+15304>>2];c[a+11180>>2]=c[b>>2];c[a+11172>>2]=0;return}function Scb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=a;h=a+148|0;Tcb(g,b|0,d,c[h>>2]|0,0);Tcb(g,b+128|0,d+8|0,c[h>>2]|0,1);i=c[h>>2]|0;Tcb(g,b+256|0,d+(i<<3)|0,i,2);i=c[h>>2]|0;Tcb(g,b+384|0,d+((i<<3)+8)|0,i,3);if((c[a+60>>2]&8192|0)!=0){return}i=a+152|0;Tcb(g,b+512|0,e,c[i>>2]|0,4);Tcb(g,b+640|0,f,c[i>>2]|0,5);return}function Tcb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;if(!((c[a+180+(f<<2)>>2]|0)>-1)){i=g;return}h=c[a+15328+(f<<2)>>2]|0;if((h|0)==0){Xe[c[a+15300>>2]&4095](d,e,b);i=g;return}else if((h|0)==1){PXa(d,e,b);j=a+15648+(f<<7)|0;PXa(d+(e<<2)|0,e,j);me[c[a+10092>>2]&511](j);i=g;return}else if((h|0)==2){RXa(d,e,b);b=a+15648+(f<<7)|0;RXa(d+4|0,e,b);me[c[a+10092>>2]&511](b);i=g;return}else{yDb(c[a+4>>2]|0,16,2196448,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=g;return}}function Ucb(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;k=(c[a+15380>>2]|0)+((i<<1&2|h&1)<<1)|0;l=a+12476|0;m=(c[l>>2]<<4)+(h>>1)|0;n=a+12480|0;o=(c[n>>2]<<4)+(i>>1)|0;p=a+140|0;q=c[p>>2]|0;r=a+8|0;s=c[r>>2]|0;if((m|0)<-16){t=-16}else{t=(m|0)>(s|0)?s:m}m=a+12|0;u=c[m>>2]|0;if((o|0)<-16){v=-16;w=(t|0)>-16&(t|0)<(s|0)?k:k&-4;x=6}else{y=(o|0)>(u|0)?u:o;o=(t|0)>-16&(t|0)<(s|0)?k:k&-4;if((y|0)>-16&(y|0)<(u|0)){z=o;A=y}else{v=y;w=o;x=6}}if((x|0)==6){z=w&-5;A=v}v=a+148|0;w=c[v>>2]|0;o=a+152|0;y=c[o>>2]|0;u=c[f>>2]|0;k=(ba(w,A)|0)+t|0;s=u+k|0;do{if((t|0)<1|(A|0)<1){B=c[a+136>>2]|0;x=11}else{C=c[a+136>>2]|0;if((t+17|0)>=(C|0)){B=C;x=11;break}if((j+1+A|0)<(q|0)){D=0;E=s}else{B=C;x=11}}}while(0);if((x|0)==11){x=a+9944|0;Ne[c[a+11540>>2]&127](c[x>>2]|0,u+(k-1-w)|0,w,w,19,19,t-1|0,A-1|0,B,q);D=1;E=(c[x>>2]|0)+((c[v>>2]|0)+1)|0}v=a+11064+(z<<2)|0;Xe[c[v>>2]&4095](b,E,w);Xe[c[v>>2]&4095](b+8|0,E+8|0,w);z=w<<3;Xe[c[v>>2]&4095](b+z|0,E+z|0,w);x=z+8|0;Xe[c[v>>2]&4095](b+x|0,E+x|0,w);if((c[a+60>>2]&8192|0)!=0){return}if((c[a+28>>2]|0)==2){w=(h&3|0)!=0|0;F=(i&3|0)==0?w:w|2;G=h>>2;H=i>>2}else{w=(h|0)/2|0;h=(i|0)/2|0;F=h<<1&2|w&1;G=w>>1;H=h>>1}h=(c[l>>2]<<3)+G|0;G=(c[n>>2]<<3)+H|0;H=c[r>>2]>>1;if((h|0)<-8){I=-8}else{I=(h|0)>(H|0)?H:h}h=(I|0)==(H|0)?F&-2:F;F=c[m>>2]>>1;if((G|0)<-8){J=-8}else{J=(G|0)>(F|0)?F:G}G=(ba(J,y)|0)+I|0;m=(c[f+4>>2]|0)+G|0;H=(D|0)!=0;if(H){D=a+9944|0;r=c[o>>2]|0;Ne[c[a+11540>>2]&127](c[D>>2]|0,m,r,r,9,9,I,J,c[a+136>>2]>>1,c[p>>2]>>1);K=c[D>>2]|0}else{K=m}m=g+16+(((J|0)==(F|0)?h&-3:h)<<2)|0;h=j>>1;cf[c[m>>2]&1023](d,K,y,h);K=(c[f+8>>2]|0)+G|0;if(H){H=a+9944|0;G=c[o>>2]|0;Ne[c[a+11540>>2]&127](c[H>>2]|0,K,G,G,9,9,I,J,c[a+136>>2]>>1,c[p>>2]>>1);L=c[H>>2]|0}else{L=K}cf[c[m>>2]&1023](e,L,y,h);return}function Vcb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=i;do{if((c[a+108>>2]|0)==0){e=c[a+4>>2]|0;if((c[e+100>>2]|0)<4){break}f=c[e+96>>2]|0;g=(f|0)==0;h=g?8:40;j=f;k=fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;j=g?8:16;l=k>>>16<<10&2096128;c[a+24>>2]=l;m=f+(j>>>3)|0;n=(d[m]|0)>>>7;o=g&1^1;g=o|j;c[a+15360>>2]=n;j=(g>>>0<h>>>0)+g|0;g=(d[m]|0)<<o>>>7&1;c[a+13836>>2]=g;o=((j|0)<(h|0))+j|0;m=(d[f+(j>>>3)|0]|0)<<(j&7)>>>7&1;c[a+15320>>2]=m;j=((o|0)<(h|0))+o|0;p=(d[f+(o>>>3)|0]|0)<<(o&7)>>>7&1;c[a+15312>>2]=p;o=((j|0)<(h|0))+j|0;q=(d[f+(j>>>3)|0]|0)<<(j&7)>>>7&1;c[a+15368>>2]=q;j=((o|0)<(h|0))+o|0;h=(d[f+(o>>>3)|0]|0)<<(o&7)>>>7&1;c[a+15372>>2]=h;o=f+(j>>>3)|0;f=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(j&7)>>>29;if((f|0)==0){break}c[a+14080>>2]=(c[a+120>>2]|0)/(f|0)|0;if((c[e+688>>2]&1|0)==0){break}yDb(e,48,2348728,(r=i,i=i+80|0,c[r>>2]=k>>>27,c[r+8>>2]=l,c[r+16>>2]=n,c[r+24>>2]=m,c[r+32>>2]=p,c[r+40>>2]=q,c[r+48>>2]=h,c[r+56>>2]=f,c[r+64>>2]=g,c[r+72>>2]=f,r)|0);i=r}}while(0);f=a+14128|0;g=c[f>>2]|0;h=a+14120|0;q=c[h>>2]|0;p=(d[q+(g>>>3)|0]|0)<<(g&7)>>>7;m=a+14136|0;n=c[m>>2]|0;l=((g|0)<(n|0))+g|0;c[f>>2]=l;g=p&1;c[a+9992>>2]=g+1;if((g|0)!=0){s=l;t=n;u=q;v=s>>>3;w=u+v|0;x=w;y=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;z=fe(y|0)|0;A=s&7;B=z<<A;C=B>>>27;D=s+5|0;E=t>>>0>D>>>0;F=E?D:t;c[f>>2]=F;G=a+9960|0;c[G>>2]=C;H=a+9964|0;c[H>>2]=C;I=(C|0)==0;J=I<<31>>31;i=b;return J|0}g=q+(l>>>3)|0;q=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(l&7)>>>25;g=l+7|0;c[f>>2]=n>>>0>g>>>0?g:n;yDb(c[a+4>>2]|0,48,2196400,(r=i,i=i+8|0,c[r>>2]=q,r)|0);i=r;s=c[f>>2]|0;t=c[m>>2]|0;u=c[h>>2]|0;v=s>>>3;w=u+v|0;x=w;y=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;z=fe(y|0)|0;A=s&7;B=z<<A;C=B>>>27;D=s+5|0;E=t>>>0>D>>>0;F=E?D:t;c[f>>2]=F;G=a+9960|0;c[G>>2]=C;H=a+9964|0;c[H>>2]=C;I=(C|0)==0;J=I<<31>>31;i=b;return J|0}function Wcb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;b=i;do{if((c[a+9992>>2]|0)==1){if((c[a+15312>>2]|0)==0){c[a+15316>>2]=0;e=5}else{f=a+14128|0;g=c[f>>2]|0;h=(d[(c[a+14120>>2]|0)+(g>>>3)|0]|0)<<(g&7)>>>7;c[f>>2]=((g|0)<(c[a+14136>>2]|0))+g;g=h&1;c[a+15316>>2]=g;if((g|0)==0){e=5}else{j=g}}if((e|0)==5){do{if((c[a+15372>>2]|0)==0){c[a+14096>>2]=0;e=9}else{g=a+14128|0;h=c[g>>2]|0;f=(d[(c[a+14120>>2]|0)+(h>>>3)|0]|0)<<(h&7)>>>7;c[g>>2]=((h|0)<(c[a+14136>>2]|0))+h;h=f&1;c[a+14096>>2]=h;if((h|0)==0){e=9;break}k=c[a+14128>>2]|0;l=c[a+14120>>2]|0;m=c[a+14136>>2]|0}}while(0);if((e|0)==9){h=a+14128|0;f=c[h>>2]|0;g=c[a+14120>>2]|0;n=d[g+(f>>>3)|0]|0;o=c[a+14136>>2]|0;p=((f|0)<(o|0))+f|0;c[h>>2]=p;if((n&128>>>((f&7)>>>0)|0)==0){q=0;r=p}else{f=(d[g+(p>>>3)|0]|0)<<(p&7)>>>7;n=((p|0)<(o|0))+p|0;c[h>>2]=n;q=(f&1)+1|0;r=n}c[a+14068>>2]=q;n=d[g+(r>>>3)|0]|0;f=((r|0)<(o|0))+r|0;c[h>>2]=f;if((n&128>>>((r&7)>>>0)|0)==0){s=0;t=f}else{n=(d[g+(f>>>3)|0]|0)<<(f&7)>>>7;p=((f|0)<(o|0))+f|0;c[h>>2]=p;s=(n&1)+1|0;t=p}c[a+14064>>2]=s;k=t;l=g;m=o}o=(d[l+(k>>>3)|0]|0)<<(k&7)>>>7;c[a+14128>>2]=((k|0)<(m|0))+k;c[a+14072>>2]=o&1;j=0}c[a+14112>>2]=0;c[a+12472>>2]=1;o=c[a+4>>2]|0;if((c[o+688>>2]&1|0)==0){break}g=c[a+14068>>2]|0;p=c[a+14064>>2]|0;n=c[a+14072>>2]|0;h=c[a+14096>>2]|0;yDb(o,48,2311040,(u=i,i=i+48|0,c[u>>2]=c[a+9960>>2],c[u+8>>2]=g,c[u+16>>2]=p,c[u+24>>2]=n,c[u+32>>2]=h,c[u+40>>2]=j,u)|0);i=u}else{c[a+15316>>2]=0;h=c[(c[a+9856>>2]|0)+1536>>2]|0;n=a+14128|0;p=c[n>>2]|0;g=a+14136|0;o=c[g>>2]|0;f=c[a+14120>>2]|0;v=f+(p>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(p&7)>>>30;v=p+2|0;p=o>>>0>v>>>0?v:o;c[n>>2]=p;c[a+15376>>2]=w;a:do{if((w|0)==1){v=a+120|0;x=c[v>>2]|0;if((x|0)<=0){break}y=a+116|0;z=a+124|0;A=0;B=c[y>>2]|0;C=x;while(1){if((B|0)>0){x=0;do{D=c[n>>2]|0;E=(d[f+(D>>>3)|0]|0)<<(D&7);c[n>>2]=((D|0)<(c[g>>2]|0))+D;c[h+((ba(c[z>>2]|0,A)|0)+x<<2)>>2]=E<<4&2048|12296;x=x+1|0;F=c[y>>2]|0;}while((x|0)<(F|0));G=F;H=c[v>>2]|0}else{G=B;H=C}x=A+1|0;if((x|0)<(H|0)){A=x;B=G;C=H}else{break}}}else if((w|0)==2){C=a+120|0;if((c[C>>2]|0)<=0){break}B=a+116|0;A=a+124|0;v=0;y=p;z=o;x=c[B>>2]|0;while(1){E=d[f+(y>>>3)|0]|0;D=((y|0)<(z|0))+y|0;c[n>>2]=D;I=(x|0)>0;b:do{if((E&128>>>((y&7)>>>0)|0)==0){if(I){J=0;K=D;L=z}else{M=x;break}while(1){N=(d[f+(K>>>3)|0]|0)<<(K&7);c[n>>2]=((K|0)<(L|0))+K;c[h+((ba(c[A>>2]|0,v)|0)+J<<2)>>2]=N<<4&2048|12296;N=J+1|0;O=c[B>>2]|0;if((N|0)>=(O|0)){M=O;break b}J=N;K=c[n>>2]|0;L=c[g>>2]|0}}else{if(I){P=0}else{M=x;break}while(1){c[h+((ba(c[A>>2]|0,v)|0)+P<<2)>>2]=14344;N=P+1|0;O=c[B>>2]|0;if((N|0)<(O|0)){P=N}else{M=O;break}}}}while(0);I=v+1|0;if((I|0)>=(c[C>>2]|0)){break a}v=I;y=c[n>>2]|0;z=c[g>>2]|0;x=M}}else if((w|0)==0){x=a+120|0;z=c[x>>2]|0;if((z|0)<=0){break}y=a+116|0;v=a+124|0;C=0;B=c[y>>2]|0;A=z;while(1){if((B|0)>0){z=0;do{c[h+((ba(c[v>>2]|0,C)|0)+z<<2)>>2]=12296;z=z+1|0;Q=c[y>>2]|0;}while((z|0)<(Q|0));R=Q;S=c[x>>2]|0}else{R=B;S=A}z=C+1|0;if((z|0)<(S|0)){C=z;B=R;A=S}else{break}}}else if((w|0)==3){A=a+116|0;if((c[A>>2]|0)<=0){break}B=a+120|0;C=a+124|0;x=0;y=p;v=o;z=c[B>>2]|0;while(1){I=d[f+(y>>>3)|0]|0;D=((y|0)<(v|0))+y|0;c[n>>2]=D;E=(z|0)>0;c:do{if((I&128>>>((y&7)>>>0)|0)==0){if(E){T=0;U=D;V=v}else{W=z;break}while(1){O=(d[f+(U>>>3)|0]|0)<<(U&7);c[n>>2]=((U|0)<(V|0))+U;c[h+((ba(c[C>>2]|0,T)|0)+x<<2)>>2]=O<<4&2048|12296;O=T+1|0;N=c[B>>2]|0;if((O|0)>=(N|0)){W=N;break c}T=O;U=c[n>>2]|0;V=c[g>>2]|0}}else{if(E){X=0}else{W=z;break}while(1){c[h+((ba(c[C>>2]|0,X)|0)+x<<2)>>2]=14344;O=X+1|0;N=c[B>>2]|0;if((O|0)<(N|0)){X=O}else{W=N;break}}}}while(0);E=x+1|0;if((E|0)>=(c[A>>2]|0)){break a}x=E;y=c[n>>2]|0;v=c[g>>2]|0;z=W}}}while(0);h=c[n>>2]|0;o=d[f+(h>>>3)|0]|0;p=c[g>>2]|0;w=((h|0)<(p|0))+h|0;c[n>>2]=w;if((o&128>>>((h&7)>>>0)|0)==0){Y=0;Z=w}else{h=(d[f+(w>>>3)|0]|0)<<(w&7)>>>7;o=((w|0)<(p|0))+w|0;c[n>>2]=o;Y=(h&1)+1|0;Z=o}o=c[a+9960>>2]|0;do{if((o|0)<11){h=c[1080448+(Y<<2)>>2]|0;c[a+15364>>2]=h;_=h}else{if((o|0)<21){h=c[1080432+(Y<<2)>>2]|0;c[a+15364>>2]=h;_=h;break}else{h=c[1080416+(Y<<2)>>2]|0;c[a+15364>>2]=h;_=h;break}}}while(0);if((c[a+15360>>2]|0)==0){c[a+14116>>2]=0;$=Z;aa=0}else{g=(d[f+(Z>>>3)|0]|0)<<(Z&7)>>>7;h=((Z|0)<(p|0))+Z|0;c[n>>2]=h;w=g&1;c[a+14116>>2]=w;$=h;aa=w}do{if((c[a+15320>>2]|0)==0){ca=$}else{w=(d[f+($>>>3)|0]|0)<<($&7)>>>7;h=(($|0)<(p|0))+$|0;c[n>>2]=h;g=w&1;c[a+15352>>2]=g^1;if((g|0)==0){ca=h;break}g=d[f+(h>>>3)|0]|0;w=((h|0)<(p|0))+h|0;c[n>>2]=w;if((g&128>>>((h&7)>>>0)|0)==0){da=0;ea=w}else{h=(d[f+(w>>>3)|0]|0)<<(w&7)>>>7;g=((w|0)<(p|0))+w|0;c[n>>2]=g;da=(h&1)+1|0;ea=g}c[a+15324>>2]=da;ca=ea}}while(0);if((c[a+15372>>2]|0)==0){c[a+14096>>2]=0;fa=ca;e=68}else{g=(d[f+(ca>>>3)|0]|0)<<(ca&7)>>>7;h=((ca|0)<(p|0))+ca|0;c[n>>2]=h;w=g&1;c[a+14096>>2]=w;if((w|0)==0){fa=h;e=68}else{ga=h;ha=w}}if((e|0)==68){w=d[f+(fa>>>3)|0]|0;h=((fa|0)<(p|0))+fa|0;c[n>>2]=h;if((w&128>>>((fa&7)>>>0)|0)==0){ia=0;ja=h}else{w=(d[f+(h>>>3)|0]|0)<<(h&7)>>>7;g=((h|0)<(p|0))+h|0;c[n>>2]=g;ia=(w&1)+1|0;ja=g}c[a+14064>>2]=ia;c[a+14068>>2]=ia;ga=ja;ha=0}g=(d[f+(ga>>>3)|0]|0)<<(ga&7)>>>7;w=((ga|0)<(p|0))+ga|0;c[n>>2]=w;h=g&1;c[a+14072>>2]=h;g=(d[f+(w>>>3)|0]|0)<<(w&7)>>>7;c[n>>2]=((w|0)<(p|0))+w;w=g&1;c[a+14060>>2]=w;c[a+14112>>2]=0;g=a+12472|0;c[g>>2]=c[g>>2]^1;g=c[a+4>>2]|0;if((c[g+688>>2]&1|0)==0){break}z=c[a+14068>>2]|0;v=c[a+15352>>2]|0;y=c[a+15324>>2]|0;yDb(g,48,2045800,(u=i,i=i+88|0,c[u>>2]=c[a+14064>>2],c[u+8>>2]=z,c[u+16>>2]=h,c[u+24>>2]=w,c[u+32>>2]=ha,c[u+40>>2]=o,c[u+48>>2]=aa,c[u+56>>2]=v,c[u+64>>2]=y,c[u+72>>2]=_,c[u+80>>2]=0,u)|0);i=u}}while(0);c[a+14100>>2]=0;c[a+14104>>2]=0;u=a+108|0;c[u>>2]=(c[u>>2]|0)+1;if((c[a+15316>>2]|0)==0){ka=0;i=b;return ka|0}u=c[a+9960>>2]|0;nlb(a+14672|0,u<<1,u-1|1)|0;ka=1;i=b;return ka|0}function Xcb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=e;if((c[e+15316>>2]|0)!=0){m=0;i=g;return m|0}do{if((c[e+9992>>2]|0)==2){n=ba(c[e+124>>2]|0,c[e+12480>>2]|0)|0;if((c[(c[e+9160>>2]|0)+(n+(c[e+12476>>2]|0)<<2)>>2]&2048|0)!=0){c[e+12488>>2]=0;TGb(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11744>>2]=0;c[e+11748>>2]=0;c[e+9924>>2]=1;c[e+15380>>2]=0;m=0;i=g;return m|0}n=c[6876188+((c[e+15364>>2]|0)*20|0)>>2]|0;o=e+14128|0;p=c[o>>2]|0;q=c[e+14136>>2]|0;r=c[e+14120>>2]|0;s=r+(p>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(p&7)>>>23;s=b[n+(t<<2)>>1]|0;u=b[n+(t<<2)+2>>1]|0;t=u<<16>>16;do{if(u<<16>>16<0){v=p+9|0;w=q>>>0>v>>>0?v:q;v=r+(w>>>3)|0;x=((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(w&7)>>>((t+32|0)>>>0))+s|0;v=b[n+(x<<2)>>1]|0;y=b[n+(x<<2)+2>>1]|0;x=y<<16>>16;if(!(y<<16>>16<0)){z=x;A=v;B=w;break}y=w-t|0;w=q>>>0>y>>>0?y:q;y=r+(w>>>3)|0;C=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>((x+32|0)>>>0))+v|0;z=b[n+(C<<2)+2>>1]|0;A=b[n+(C<<2)>>1]|0;B=w}else{z=t;A=s;B=p}}while(0);p=z+B|0;c[o>>2]=q>>>0>p>>>0?p:q;if((A|0)<0){m=-1;i=g;return m|0}else{p=A>>>6&1^1;c[e+12488>>2]=p;D=A&63;E=p;break}}else{p=e+12488|0;c[p>>2]=1;s=c[1620609]|0;t=e+14128|0;n=c[t>>2]|0;r=c[e+14136>>2]|0;u=c[e+14120>>2]|0;w=u+(n>>>3)|0;C=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(n&7)>>>23;w=b[s+(C<<2)>>1]|0;v=b[s+(C<<2)+2>>1]|0;C=v<<16>>16;if(v<<16>>16<0){v=n+9|0;x=r>>>0>v>>>0?v:r;v=u+(x>>>3)|0;u=((fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(x&7)>>>((C+32|0)>>>0))+w|0;F=b[s+(u<<2)+2>>1]|0;G=b[s+(u<<2)>>1]|0;H=x}else{F=C;G=w;H=n}n=F+H|0;c[t>>2]=r>>>0>n>>>0?n:r;if((G|0)>=0){r=(Pmb(e,0,h)|0)^G>>>5&1;a[c[h>>2]|0]=r;n=(Pmb(e,1,h)|0)^G>>>4&1;a[c[h>>2]|0]=n;t=(Pmb(e,2,h)|0)^G>>>3&1;a[c[h>>2]|0]=t;w=(Pmb(e,3,h)|0)^G>>>2&1;a[c[h>>2]|0]=w;D=G&1|(G&2|(w<<2|(t<<3|(n<<4|r<<5))));E=c[p>>2]|0;break}p=c[e+12480>>2]|0;yDb(c[e+4>>2]|0,16,2000088,(I=i,i=i+16|0,c[I>>2]=c[e+12476>>2],c[I+8>>2]=p,I)|0);i=I;m=-1;i=g;return m|0}}while(0);if((E|0)!=0){E=e+14128|0;G=c[E>>2]|0;h=c[e+14120>>2]|0;H=d[h+(G>>>3)|0]<<(G&7)>>>7;F=c[e+14136>>2]|0;A=((G|0)<(F|0))+G|0;c[E>>2]=A;c[e+176>>2]=H&1;if((c[e+14112>>2]|0)==0){J=A}else{H=c[1850529]|0;G=h+(A>>>3)|0;B=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(A&7)>>>29;G=b[H+(B<<2)>>1]|0;z=(b[H+(B<<2)+2>>1]|0)+A|0;A=F>>>0>z>>>0?z:F;c[E>>2]=A;c[e+13820>>2]=G;J=A}if(!((c[e+14096>>2]|0)==0|(D|0)==0)){A=d[h+(J>>>3)|0]|0;G=((J|0)<(F|0))+J|0;c[E>>2]=G;if((A&128>>>((J&7)>>>0)|0)==0){K=0}else{J=d[h+(G>>>3)|0]<<(G&7)>>>7;c[E>>2]=((G|0)<(F|0))+G;K=(J&1)+1|0}c[e+14064>>2]=K;c[e+14068>>2]=K}me[c[e+10096>>2]&511](c[e+14340>>2]|0);K=0;while(1){if((K|0)>=6){m=0;L=82;break}if((XPa(e,f+(K<<7)|0,K,D>>>((5-K|0)>>>0)&1,0)|0)<0){break}else{K=K+1|0}}if((L|0)==82){i=g;return m|0}J=c[e+12480>>2]|0;yDb(c[e+4>>2]|0,16,1935024,(I=i,i=i+24|0,c[I>>2]=c[e+12476>>2],c[I+8>>2]=J,c[I+16>>2]=K,I)|0);i=I;m=-1;i=g;return m|0}K=c[e+128>>2]|0;J=c[e+12496>>2]|0;G=c[e+9148>>2]|0;F=J-1|0;E=G+(F<<2)|0;h=J-K|0;A=G+(h<<2)|0;z=2-K+J|0;J=G+(z<<2)|0;K=e+12476|0;B=(c[e+14084>>2]|0)==0;a:do{if((c[K>>2]|0)==0){H=b[E>>1]|0;p=H<<16>>16;if(B){M=H;N=p;L=27}else{O=p;L=26}}else{if(!B){O=b[E>>1]|0;L=26;break}do{if((c[e+14116>>2]|0)==0){if((c[e+15368>>2]|0)==0){break}p=b[E>>1]|0;H=b[A>>1]|0;r=p-H|0;n=(r|0)>-1?r:-r|0;r=b[G+(F<<2)+2>>1]|0;t=b[G+(h<<2)+2>>1]|0;w=r-t|0;C=(w|0)>-1?w:-w|0;if((((n|0)>(C|0)?n:C)|0)<=7){break}C=e+14128|0;n=c[C>>2]|0;w=d[(c[e+14120>>2]|0)+(n>>>3)|0]<<(n&7)>>>7;c[C>>2]=((n|0)<(c[e+14136>>2]|0))+n;n=w&1;if((n|0)==1){c[j>>2]=H;c[k>>2]=t;break a}else if((n|0)==0){c[j>>2]=p;c[k>>2]=r;break a}else{break}}}while(0);q=b[E>>1]|0;M=q;N=q<<16>>16;L=27}}while(0);if((L|0)==26){c[j>>2]=O;c[k>>2]=b[G+(F<<2)+2>>1]|0}else if((L|0)==27){O=b[A>>1]|0;A=O<<16>>16;E=b[J>>1]|0;J=E<<16>>16;do{if(M<<16>>16>O<<16>>16){if(!(E<<16>>16>O<<16>>16)){P=A;break}P=(J|0)>(N|0)?N:J}else{if(!(O<<16>>16>E<<16>>16)){P=A;break}P=(J|0)>(N|0)?J:N}}while(0);c[j>>2]=P;P=b[G+(F<<2)+2>>1]|0;F=P<<16>>16;N=b[G+(h<<2)+2>>1]|0;h=N<<16>>16;J=b[G+(z<<2)+2>>1]|0;z=J<<16>>16;do{if(P<<16>>16>N<<16>>16){if(!(J<<16>>16>N<<16>>16)){Q=h;break}Q=(z|0)>(F|0)?F:z}else{if(!(N<<16>>16>J<<16>>16)){Q=h;break}Q=(z|0)>(F|0)?z:F}}while(0);c[k>>2]=Q}b:do{if((D|0)!=0){me[c[e+10096>>2]&511](c[e+14340>>2]|0);if((c[e+14096>>2]|0)!=0){Q=e+14128|0;F=c[Q>>2]|0;z=c[e+14120>>2]|0;h=d[z+(F>>>3)|0]|0;J=c[e+14136>>2]|0;N=((F|0)<(J|0))+F|0;c[Q>>2]=N;if((h&128>>>((F&7)>>>0)|0)==0){R=0}else{F=d[z+(N>>>3)|0]<<(N&7)>>>7;c[Q>>2]=((N|0)<(J|0))+N;R=(F&1)+1|0}c[e+14064>>2]=R;c[e+14068>>2]=R}do{if((c[e+15320>>2]|0)!=0){if((c[e+15352>>2]|0)==0){break}F=e+14128|0;N=c[F>>2]|0;J=c[e+14120>>2]|0;Q=d[J+(N>>>3)|0]<<(N&7)>>>7;z=c[e+14136>>2]|0;h=((N|0)<(z|0))+N|0;c[F>>2]=h;N=Q&1;c[e+15356>>2]=N;if((N|0)!=0){break b}N=d[J+(h>>>3)|0]|0;Q=((h|0)<(z|0))+h|0;c[F>>2]=Q;if((N&128>>>((h&7)>>>0)|0)==0){S=0}else{h=d[J+(Q>>>3)|0]<<(Q&7)>>>7;c[F>>2]=((Q|0)<(z|0))+Q;S=(h&1)+1|0}c[e+15324>>2]=S;break b}}while(0);c[e+15356>>2]=0}}while(0);if((YPa(e,j,k)|0)<0){m=-1;i=g;return m|0}S=c[j>>2]|0;j=c[k>>2]|0;do{if(((j|S)&1|0)==0){L=54}else{if((c[e+14116>>2]|0)==0){L=54;break}k=e+14128|0;R=c[k>>2]|0;h=e+14120|0;Q=d[(c[h>>2]|0)+(R>>>3)|0]<<(R&7)>>>7;z=e+14136|0;c[k>>2]=((R|0)<(c[z>>2]|0))+R;c[e+15380>>2]=Q&1;T=k;U=h;V=z}}while(0);if((L|0)==54){c[e+15380>>2]=0;T=e+14128|0;U=e+14120|0;V=e+14136|0}c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11744>>2]=S;c[e+11748>>2]=j;j=e+15356|0;S=e+15324|0;z=e+236|0;h=0;c:while(1){k=f+(h<<7)|0;do{if((1<<5-h&D|0)==0){c[l+180+(h<<2)>>2]=-1}else{if((c[j>>2]|0)==0){W=c[S>>2]|0}else{Q=c[T>>2]|0;R=c[U>>2]|0;F=d[R+(Q>>>3)|0]|0;J=c[V>>2]|0;N=((Q|0)<(J|0))+Q|0;c[T>>2]=N;if((F&128>>>((Q&7)>>>0)|0)==0){X=0}else{Q=d[R+(N>>>3)|0]<<(N&7)>>>7;c[T>>2]=((N|0)<(J|0))+N;X=(Q&1)+1|0}c[S>>2]=X;W=X}c[l+15328+(h<<2)>>2]=W;Q=c[S>>2]|0;if((Q|0)==0){if((XPa(e,k,h,1,z)|0)<0){break c}else{break}}N=c[l+15384+((Q-1|0)*132|0)>>2]|0;Q=c[T>>2]|0;J=c[U>>2]|0;R=d[J+(Q>>>3)|0]|0;F=c[V>>2]|0;P=((Q|0)<(F|0))+Q|0;c[T>>2]=P;if((R&128>>>((Q&7)>>>0)|0)==0){L=67}else{Q=a[J+(P>>>3)|0]|0;c[T>>2]=((P|0)<(F|0))+P;if((XPa(e,k,h,1,N)|0)<0){break c}if((((Q&255)<<(P&7)>>>7&1)+1|0)>>>0<2>>>0){L=67}}if((L|0)==67){L=0;if((XPa(e,l+15648+(h<<7)|0,h,1,N)|0)<0){break c}}c[l+180+(h<<2)>>2]=63}}while(0);k=h+1|0;if((k|0)<6){h=k}else{m=0;L=82;break}}if((L|0)==82){i=g;return m|0}L=c[e+12480>>2]|0;yDb(c[e+4>>2]|0,16,1963192,(I=i,i=i+24|0,c[I>>2]=c[K>>2],c[I+8>>2]=L,c[I+16>>2]=h,I)|0);i=I;m=-1;i=g;return m|0}function Ycb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=a+88|0;c[d>>2]=c[d>>2]|16384;if((SPa(a)|0)<0){e=-1;return e|0}Rcb(b);llb(b+14672|0,b);e=0;return e|0}function Zcb(a){a=a|0;mlb((c[a+60>>2]|0)+14672|0);return Gca(a)|0}function _cb(a){a=a|0;c[a>>2]=2232;c[a+4>>2]=2018;c[a+8>>2]=1;return}function $cb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;bdb(f);bdb(f+16|0);bdb(f+32|0);bdb(f+48|0);bdb(f+64|0);bdb(f+80|0);bdb(f+96|0);bdb(f+112|0);cdb(f);cdb(f+2|0);cdb(f+4|0);cdb(f+6|0);cdb(f+8|0);cdb(f+10|0);cdb(f+12|0);cdb(f+14|0);g=c;c=f;f=0;while(1){h=(b[c>>1]|0)+(d[g]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[g]=i;h=g+1|0;j=(b[c+2>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=g+2|0;j=(b[c+4>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=g+3|0;j=(b[c+6>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=g+4|0;j=(b[c+8>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[h]=n;h=g+5|0;j=(b[c+10>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[h]=o;h=g+6|0;j=(b[c+12>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[h]=p;h=g+7|0;j=(b[c+14>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[h]=q;h=f+1|0;if((h|0)<8){g=g+e|0;c=c+16|0;f=h}else{break}}return}function adb(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;bdb(e);bdb(e+16|0);bdb(e+32|0);bdb(e+48|0);bdb(e+64|0);bdb(e+80|0);bdb(e+96|0);bdb(e+112|0);cdb(e);cdb(e+2|0);cdb(e+4|0);cdb(e+6|0);cdb(e+8|0);cdb(e+10|0);cdb(e+12|0);cdb(e+14|0);f=c;c=e;e=0;while(1){g=b[c>>1]|0;if((g&65535)>>>0>255>>>0){h=-(g<<16>>16)>>31&255}else{h=g&255}a[f]=h;g=b[c+2>>1]|0;if((g&65535)>>>0>255>>>0){i=-(g<<16>>16)>>31&255}else{i=g&255}a[f+1|0]=i;g=b[c+4>>1]|0;if((g&65535)>>>0>255>>>0){j=-(g<<16>>16)>>31&255}else{j=g&255}a[f+2|0]=j;g=b[c+6>>1]|0;if((g&65535)>>>0>255>>>0){k=-(g<<16>>16)>>31&255}else{k=g&255}a[f+3|0]=k;g=b[c+8>>1]|0;if((g&65535)>>>0>255>>>0){l=-(g<<16>>16)>>31&255}else{l=g&255}a[f+4|0]=l;g=b[c+10>>1]|0;if((g&65535)>>>0>255>>>0){m=-(g<<16>>16)>>31&255}else{m=g&255}a[f+5|0]=m;g=b[c+12>>1]|0;if((g&65535)>>>0>255>>>0){n=-(g<<16>>16)>>31&255}else{n=g&255}a[f+6|0]=n;g=b[c+14>>1]|0;if((g&65535)>>>0>255>>>0){o=-(g<<16>>16)>>31&255}else{o=g&255}a[f+7|0]=o;g=e+1|0;if((g|0)<8){f=f+d|0;c=c+16|0;e=g}else{break}}return}function bdb(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=a+2|0;d=b[c>>1]|0;e=a+14|0;f=b[e>>1]|0;g=(f*565|0)+(d*2841|0)|0;h=(f*-2841|0)+(d*565|0)|0;d=a+10|0;f=b[d>>1]|0;i=a+6|0;j=b[i>>1]|0;k=(j*2408|0)+(f*1609|0)|0;l=(j*-1609|0)+(f*2408|0)|0;f=a+4|0;j=b[f>>1]|0;m=a+12|0;n=b[m>>1]|0;o=(n*1108|0)+(j*2676|0)|0;p=(n*-2676|0)+(j*1108|0)|0;j=b[a>>1]<<11;n=a+8|0;q=b[n>>1]<<11;r=q+j|0;s=j-q|0;q=g-k|0;j=((h-l+q|0)*181|0)+128>>8;t=((l-h+q|0)*181|0)+128>>8;q=r+o|0;b[a>>1]=(g+128+k+q|0)>>>8;a=s+p|0;b[c>>1]=(j+128+a|0)>>>8;c=s-p|0;b[f>>1]=(t+128+c|0)>>>8;f=r-o|0;b[i>>1]=(h+128+l+f|0)>>>8;b[n>>1]=(128-h-l+f|0)>>>8;b[d>>1]=(128-t+c|0)>>>8;b[m>>1]=(128-j+a|0)>>>8;b[e>>1]=(128-g-k+q|0)>>>8;return}function cdb(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=a+16|0;d=b[c>>1]|0;e=a+112|0;f=b[e>>1]|0;g=(d*2841|0)+4+(f*565|0)>>3;h=(d*565|0)+4+(f*-2841|0)>>3;f=a+80|0;d=b[f>>1]|0;i=a+48|0;j=b[i>>1]|0;k=(d*1609|0)+4+(j*2408|0)>>3;l=(d*2408|0|4)+(j*-1609|0)>>3;j=a+32|0;d=b[j>>1]|0;m=a+96|0;n=b[m>>1]|0;o=(d*2676|0)+4+(n*1108|0)>>3;p=(d*1108|0)+4+(n*-2676|0)>>3;n=b[a>>1]<<11;d=a+64|0;q=b[d>>1]<<11;r=q+n>>3;s=n-q>>3;q=g-k|0;n=((h-l+q|0)*181|0)+128>>8;t=((l-h+q|0)*181|0)+128>>8;q=r+o|0;b[a>>1]=(g+8192+k+q|0)>>>14;a=s+p|0;b[c>>1]=(n+8192+a|0)>>>14;c=s-p|0;b[j>>1]=(t+8192+c|0)>>>14;j=r-o|0;b[i>>1]=(h+8192+l+j|0)>>>14;b[d>>1]=(8192-h-l+j|0)>>>14;b[f>>1]=(8192-t+c|0)>>>14;b[m>>1]=(8192-n+a|0)>>>14;b[e>>1]=(8192-g-k+q|0)>>>14;return}function ddb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;e=b+784|0;f=b+9992|0;g=c[f>>2]|0;h=g-1|0;j=e|0;k=c[j>>2]|0;l=b+788|0;m=c[l>>2]|0;if((m|0)>1){n=m-1|0;o=k<<1|h;p=g}else{g=fe(h>>>((1-m|0)>>>0)|k<<m|0)|0;k=b+796|0;q=c[k>>2]|0;x=g;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;n=m+31|0;o=h;p=c[f>>2]|0}c[j>>2]=o;c[l>>2]=n;if((p|0)==1){if((n|0)>7){r=n-7|0;s=o<<7}else{p=fe(o<<n|0)|0;h=b+796|0;m=c[h>>2]|0;x=p;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;r=n+25|0;s=0}c[j>>2]=s;c[l>>2]=r;t=r;u=s}else{t=n;u=o}o=b+9960|0;n=c[o>>2]|0;if((t|0)>5){v=t-5|0;w=u<<5|n}else{s=fe(u<<t|n>>>((5-t|0)>>>0)|0)|0;u=b+796|0;r=c[u>>2]|0;x=s;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=t+27|0;w=n}c[j>>2]=w;c[l>>2]=v;n=b+14072|0;c[n>>2]=1;t=b+14060|0;c[t>>2]=1;u=b+14096|0;c[u>>2]=0;r=b+14116|0;c[r>>2]=0;s=b+15352|0;c[s>>2]=0;h=b+15324|0;c[h>>2]=0;c[b+15316>>2]=0;if((c[b+14088>>2]|0)==0){yDb(0,0,2196200,(y=i,i=i+24|0,c[y>>2]=2310952,c[y+8>>2]=2178192,c[y+16>>2]=87,y)|0);i=y;Cd();return 0}if((c[f>>2]|0)==1){if((c[b+12472>>2]|0)!=1){yDb(0,0,2196200,(y=i,i=i+24|0,c[y>>2]=2101920,c[y+8>>2]=2178192,c[y+16>>2]=90,y)|0);i=y;Cd();return 0}if((c[b+15312>>2]|0)==0){z=w;A=v}else{if((v|0)>1){B=v-1|0;C=w<<1}else{y=fe(w<<v|0)|0;f=b+796|0;m=c[f>>2]|0;x=y;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;B=v+31|0;C=0}c[j>>2]=C;c[l>>2]=B;z=C;A=B}if((c[b+15372>>2]|0)==0){D=z;E=A}else{B=c[u>>2]|0;if((A|0)>1){F=A-1|0;G=z<<1|B}else{C=fe(B>>>((1-A|0)>>>0)|z<<A|0)|0;z=b+796|0;f=c[z>>2]|0;x=C;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;F=A+31|0;G=B}c[j>>2]=G;c[l>>2]=F;D=G;E=F}if((c[u>>2]|0)==0){_Pa(e,c[b+14068>>2]|0);_Pa(e,c[b+14064>>2]|0);H=c[j>>2]|0;I=c[l>>2]|0}else{H=D;I=E}E=c[n>>2]|0;if((I|0)>1){J=I-1|0;K=H<<1|E}else{D=fe(E>>>((1-I|0)>>>0)|H<<I|0)|0;H=b+796|0;F=c[H>>2]|0;x=D;a[F]=x;x=x>>8;a[F+1|0]=x;x=x>>8;a[F+2|0]=x;x=x>>8;a[F+3|0]=x;c[H>>2]=(c[H>>2]|0)+4;J=I+31|0;K=E}c[j>>2]=K;c[l>>2]=J;c[b+14112>>2]=0;L=b+14100|0;c[L>>2]=0;M=b+14104|0;c[M>>2]=0;i=d;return 0}if((v|0)>2){N=v-2|0;O=w<<2}else{J=fe(w<<v|0)|0;w=b+796|0;K=c[w>>2]|0;x=J;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;N=v+30|0;O=0}c[j>>2]=O;c[l>>2]=N;_Pa(e,0);N=c[o>>2]|0;do{if((N|0)<11){c[b+15364>>2]=0}else{o=b+15364|0;if((N|0)<21){c[o>>2]=1;break}else{c[o>>2]=2;break}}}while(0);if((c[b+15360>>2]|0)!=0){N=c[r>>2]|0;r=c[j>>2]|0;o=c[l>>2]|0;if((o|0)>1){P=o-1|0;Q=r<<1|N}else{O=fe(N>>>((1-o|0)>>>0)|r<<o|0)|0;r=b+796|0;v=c[r>>2]|0;x=O;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;P=o+31|0;Q=N}c[j>>2]=Q;c[l>>2]=P}do{if((c[b+15320>>2]|0)!=0){P=c[s>>2]|0;Q=P^1;N=c[j>>2]|0;o=c[l>>2]|0;if((o|0)>1){R=o-1|0;S=N<<1|Q;T=P}else{P=fe(Q>>>((1-o|0)>>>0)|N<<o|0)|0;N=b+796|0;r=c[N>>2]|0;x=P;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;c[N>>2]=(c[N>>2]|0)+4;R=o+31|0;S=Q;T=c[s>>2]|0}c[j>>2]=S;c[l>>2]=R;if((T|0)!=0){break}_Pa(e,c[h>>2]|0)}}while(0);if((c[b+15372>>2]|0)!=0){h=c[u>>2]|0;T=c[j>>2]|0;R=c[l>>2]|0;if((R|0)>1){U=R-1|0;V=T<<1|h}else{S=fe(h>>>((1-R|0)>>>0)|T<<R|0)|0;T=b+796|0;s=c[T>>2]|0;x=S;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;c[T>>2]=(c[T>>2]|0)+4;U=R+31|0;V=h}c[j>>2]=V;c[l>>2]=U}if((c[u>>2]|0)==0){u=b+14064|0;_Pa(e,c[u>>2]|0);c[b+14068>>2]=c[u>>2]}u=c[n>>2]|0;n=c[j>>2]|0;e=c[l>>2]|0;if((e|0)>1){W=e-1|0;X=n<<1|u}else{U=fe(u>>>((1-e|0)>>>0)|n<<e|0)|0;n=b+796|0;V=c[n>>2]|0;x=U;a[V]=x;x=x>>8;a[V+1|0]=x;x=x>>8;a[V+2|0]=x;x=x>>8;a[V+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;W=e+31|0;X=u}c[j>>2]=X;c[l>>2]=W;u=c[t>>2]|0;if((W|0)>1){Y=W-1|0;Z=X<<1|u}else{t=fe(X<<W|u>>>((1-W|0)>>>0)|0)|0;X=b+796|0;e=c[X>>2]|0;x=t;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;c[X>>2]=(c[X>>2]|0)+4;Y=W+31|0;Z=u}c[j>>2]=Z;c[l>>2]=Y;c[b+14112>>2]=0;L=b+14100|0;c[L>>2]=0;M=b+14104|0;c[M>>2]=0;i=d;return 0}function edb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;dQa(b);n=b+12488|0;o=c[b+180>>2]|0;if((c[n>>2]|0)==0){p=(o>>31)+32&-32;q=(c[b+184>>2]|0)>-1?p|16:p;p=(c[b+188>>2]|0)>-1?q|8:q;q=(c[b+192>>2]|0)>-1?p|4:p;p=(((c[b+196>>2]|0)>-1?q|2:q)|(c[b+200>>2]|0)>>>31^1)+64|0;q=c[1080192+(c[b+15364>>2]<<2)>>2]|0;r=c[q+(p<<3)+4>>2]|0;s=c[q+(p<<3)>>2]|0;p=b+784|0;q=c[p>>2]|0;t=b+788|0;u=c[t>>2]|0;if((u|0)>(r|0)){v=u-r|0;w=q<<r|s;y=c[b+796>>2]|0}else{z=fe(s>>>((r-u|0)>>>0)|q<<u|0)|0;q=b+796|0;A=c[q>>2]|0;x=z;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;A=(c[q>>2]|0)+4|0;c[q>>2]=A;v=32-r+u|0;w=s;y=A}c[p>>2]=w;c[t>>2]=v;w=b+792|0;p=(y-(c[w>>2]|0)<<3)+(32-v)|0;v=b+13700|0;y=c[v>>2]|0;c[v>>2]=p;A=b+13696|0;c[A>>2]=(c[A>>2]|0)-y+p;Bca(b,0,0,k,l)|0;cQa(b,g-(c[k>>2]|0)|0,h-(c[l>>2]|0)|0);l=((c[b+796>>2]|0)-(c[w>>2]|0)<<3)+(32-(c[t>>2]|0))|0;t=c[v>>2]|0;c[v>>2]=l;v=b+13664|0;c[v>>2]=(c[v>>2]|0)-t+l}else{l=(o|0)>0;o=l&1;t=Pmb(b,0,m)|0;a[c[m>>2]|0]=l&1;l=(c[b+184>>2]|0)>0;v=l&1;w=Pmb(b,1,m)|0;a[c[m>>2]|0]=l&1;l=(c[b+188>>2]|0)>0;h=l&1;k=Pmb(b,2,m)|0;a[c[m>>2]|0]=l&1;l=(c[b+192>>2]|0)>0;g=l&1;p=Pmb(b,3,m)|0;a[c[m>>2]|0]=l&1;l=(c[b+196>>2]|0)>0|0;m=(c[b+200>>2]|0)>0|0;y=m|(l<<1|(g<<2|(h<<3|(v<<4|o<<5))));A=m|(l<<1|((p^g)<<2|((k^h)<<3|((w^v)<<4|(t^o)<<5))));o=b+784|0;if((c[b+9992>>2]|0)==1){t=e[1174082+(A<<2)>>1]|0;v=e[1174080+(A<<2)>>1]|0;A=o|0;w=c[A>>2]|0;h=b+788|0;k=c[h>>2]|0;if((k|0)>(t|0)){B=k-t|0;C=w<<t|v}else{g=fe(v>>>((t-k|0)>>>0)|w<<k|0)|0;w=b+796|0;p=c[w>>2]|0;x=g;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;B=32-t+k|0;C=v}c[A>>2]=C;c[h>>2]=B;D=C;E=B}else{B=c[1080192+(c[b+15364>>2]<<2)>>2]|0;C=c[B+(y<<3)+4>>2]|0;h=c[B+(y<<3)>>2]|0;y=o|0;B=c[y>>2]|0;A=b+788|0;v=c[A>>2]|0;if((v|0)>(C|0)){F=v-C|0;G=B<<C|h}else{k=fe(h>>>((C-v|0)>>>0)|B<<v|0)|0;B=b+796|0;t=c[B>>2]|0;x=k;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;F=32-C+v|0;G=h}c[y>>2]=G;c[A>>2]=F;D=G;E=F}F=o|0;o=b+788|0;if((E|0)>1){H=E-1|0;I=D<<1}else{G=fe(D<<E|0)|0;D=b+796|0;A=c[D>>2]|0;x=G;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;H=E+31|0;I=0}c[F>>2]=I;c[o>>2]=H;if((c[b+14112>>2]|0)==0){J=H}else{c[b+13820>>2]=0;E=d[1126081]|0;D=d[1126080]|0;if((H|0)>(E|0)){K=H-E|0;L=I<<E|D}else{A=fe(D>>>((E-H|0)>>>0)|I<<H|0)|0;I=b+796|0;G=c[I>>2]|0;x=A;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[I>>2]=(c[I>>2]|0)+4;K=32-E+H|0;L=D}c[F>>2]=L;c[o>>2]=K;J=K}K=((c[b+796>>2]|0)-(c[b+792>>2]|0)<<3)+(32-J)|0;J=b+13700|0;o=c[J>>2]|0;c[J>>2]=K;J=b+13696|0;c[J>>2]=(c[J>>2]|0)-o+K}gQa(b,f|0,0);gQa(b,f+128|0,1);gQa(b,f+256|0,2);gQa(b,f+384|0,3);gQa(b,f+512|0,4);gQa(b,f+640|0,5);f=(c[n>>2]|0)==0;n=((c[b+796>>2]|0)-(c[b+792>>2]|0)<<3)+(32-(c[b+788>>2]|0))|0;K=b+13700|0;o=c[K>>2]|0;c[K>>2]=n;K=n-o|0;if(f){f=b+13676|0;c[f>>2]=(c[f>>2]|0)+K;i=j;return}else{f=b+13672|0;c[f>>2]=(c[f>>2]|0)+K;i=j;return}}function fdb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[b+60>>2]|0;if((pPa(b)|0)<0){e=-1;return e|0}Rcb(d);c[b+100>>2]=4;c[b+96>>2]=cEb(14)|0;b=c[d+4>>2]|0;f=(c[b+100>>2]|0)<0?0:c[b+96>>2]|0;g=c[d+24>>2]|0;if((g|0)>2097151){h=2047}else{h=(g|0)/1024|0}g=h|((c[b+108>>2]|0)/(c[b+104>>2]|0)|0)<<11;c[d+15360>>2]=1;b=c[d+13836>>2]|0;h=g<<2|b;c[d+15320>>2]=1;c[d+15312>>2]=1;c[d+15368>>2]=0;c[d+15372>>2]=1;a[f]=h>>>10;a[f+1|0]=h>>>2;a[f+2|0]=b<<6|180;a[f+3|0]=-128;c[d+14080>>2]=c[d+120>>2];e=0;return e|0}function gdb(a){a=a|0;c[a+140>>2]=4;c[2194075]=8646232;c[2194077]=512;N_(8776296,9,16,1484346,4,2,1484344,4,2,0,0,0,4)|0;return 0}function hdb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;j=i;k=c[e+60>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;if((m|0)<9){yDb(e,16,2178160,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-1094995529;i=j;return o|0}h=WDb(m+16|0)|0;if((h|0)==0){yDb(e,16,2101880,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=j;return o|0}TGb(h+m|0,0,16)|0;p=_$a(e,f,0)|0;if((p|0)<0){ZDb(h);o=p;i=j;return o|0}c[f+84>>2]=1;if((m|0)>8){p=8;do{a[h+p|0]=a[1148864+(d[l+p|0]|0)|0]|0;p=p+1|0;}while((p|0)<(m|0))}p=h+8|0;q=(m<<3)-64|0;r=q>>>0>2147483639>>>0|(p|0)==0;s=r?0:p;p=r?0:q;q=k+4|0;c[q>>2]=s;c[k+16>>2]=p;r=k+20|0;c[r>>2]=p+8;c[k+8>>2]=s+(p>>3);p=k+12|0;c[p>>2]=0;s=l+2|0;l=(d[s]|0)>>>4;do{if((l|0)==6){c[k>>2]=2}else{t=8-l|0;u=k;c[u>>2]=t;if((t|0)>4){DDb(e,2045760,(n=i,i=i+8|0,c[n>>2]=(d[s]|0)>>>4,n)|0);i=n;c[u>>2]=4;break}if((t|0)>=1){break}DDb(e,2045760,(n=i,i=i+8|0,c[n>>2]=(d[s]|0)>>>4,n)|0);i=n;c[u>>2]=1}}while(0);n=e+124|0;s=c[n>>2]|0;if((s|0)>0){l=e+120|0;e=f+32|0;u=f+36|0;t=f+40|0;v=k;k=c[f+4>>2]|0;w=c[f+8>>2]|0;x=0;y=c[f>>2]|0;f=0;z=0;A=0;B=c[l>>2]|0;C=s;while(1){if((B|0)>1){s=0;D=f;E=z;F=A;do{G=c[2194075]|0;H=c[p>>2]|0;I=c[r>>2]|0;J=c[q>>2]|0;K=J+(H>>>3)|0;L=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(H&7)>>>23;K=b[G+(L<<2)>>1]|0;M=(b[G+(L<<2)+2>>1]|0)+H|0;H=I>>>0>M>>>0?M:I;c[p>>2]=H;if(K<<16>>16==15){M=8-(c[v>>2]|0)|0;L=J+(H>>>3)|0;J=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(H&7)>>>((32-M|0)>>>0);L=M+H|0;c[p>>2]=I>>>0>L>>>0?L:I;N=a[1148864+J|0]|0}else{N=((K<<16>>16)-7<<c[v>>2])+D&255}K=s<<1;J=y+K|0;a[J]=N;I=c[2194075]|0;L=c[p>>2]|0;H=c[r>>2]|0;M=c[q>>2]|0;G=M+(L>>>3)|0;O=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(L&7)>>>23;G=b[I+(O<<2)>>1]|0;P=(b[I+(O<<2)+2>>1]|0)+L|0;L=H>>>0>P>>>0?P:H;c[p>>2]=L;if(G<<16>>16==15){P=8-(c[v>>2]|0)|0;O=M+(L>>>3)|0;M=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>((32-P|0)>>>0);O=P+L|0;c[p>>2]=H>>>0>O>>>0?O:H;Q=d[1148864+M|0]|0}else{Q=((G<<16>>16)-7<<c[v>>2])+E|0}a[k+s|0]=Q;E=Q&255;G=a[J]|0;J=c[2194075]|0;M=c[p>>2]|0;H=c[r>>2]|0;O=c[q>>2]|0;L=O+(M>>>3)|0;P=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>23;L=b[J+(P<<2)>>1]|0;I=(b[J+(P<<2)+2>>1]|0)+M|0;M=H>>>0>I>>>0?I:H;c[p>>2]=M;if(L<<16>>16==15){I=8-(c[v>>2]|0)|0;P=O+(M>>>3)|0;O=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7)>>>((32-I|0)>>>0);P=I+M|0;c[p>>2]=H>>>0>P>>>0?P:H;R=d[1148864+O|0]|0}else{R=((L<<16>>16)-7<<c[v>>2])+(G&255)|0}a[y+(K|1)|0]=R;D=R&255;K=c[2194075]|0;G=c[p>>2]|0;L=c[r>>2]|0;O=c[q>>2]|0;H=O+(G>>>3)|0;P=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(G&7)>>>23;H=b[K+(P<<2)>>1]|0;M=(b[K+(P<<2)+2>>1]|0)+G|0;G=L>>>0>M>>>0?M:L;c[p>>2]=G;if(H<<16>>16==15){M=8-(c[v>>2]|0)|0;P=O+(G>>>3)|0;O=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(G&7)>>>((32-M|0)>>>0);P=M+G|0;c[p>>2]=L>>>0>P>>>0?P:L;S=d[1148864+O|0]|0}else{S=((H<<16>>16)-7<<c[v>>2])+F|0}a[w+s|0]=S;F=S&255;s=s+1|0;T=c[l>>2]|0;}while((s|0)<((T|0)/2|0|0));U=D;V=E;W=F;X=T;Y=c[n>>2]|0}else{U=f;V=z;W=A;X=B;Y=C}s=x+1|0;if((s|0)<(Y|0)){k=k+(c[u>>2]|0)|0;w=w+(c[t>>2]|0)|0;x=s;y=y+(c[e>>2]|0)|0;f=U;z=V;A=W;B=X;C=Y}else{break}}}c[g>>2]=1;ZDb(h);o=m;i=j;return o|0}function idb(a){a=a|0;var b=0;c[a+416>>2]=1;b=a+448|0;c[b>>2]=4;c[b+4>>2]=0;c[a+420>>2]=0;return 0}function jdb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;j=g+24|0;k=c[j>>2]|0;l=c[g+28>>2]|0;if((l|0)==0){m=0;i=h;return m|0}if((l|0)<4){yDb(b,16,2178136,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-22;i=h;return m|0}g=k;o=(d[g]|d[g+1|0]<<8)<<16>>16;g=o&65535;p=k+2|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=k+4|0;if((q&65535|0)>(l|0)){yDb(b,16,2101840,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}n=e+76|0;c[n>>2]=g;k=_$a(b,e,0)|0;if((k|0)<0){m=k;i=h;return m|0}k=e;e=c[k>>2]|0;b=e+g|0;if(q<<16>>16==o<<16>>16){UGb(e|0,p|0,g)|0;c[f>>2]=1;m=l;i=h;return m|0}a:do{if(o<<16>>16==0){r=e}else{g=b;q=e;s=128;t=p;while(1){u=s&255;v=q;w=t;while(1){x=c[j>>2]|0;if((w-x|0)>=(l|0)){r=v;break a}y=a[w]|0;z=(y&255)>>>6;A=y&63;B=w+1|0;if((z|0)==2){C=A&255;D=(C&32|0)==0?C+1|0:1}else if((z|0)==1){D=((A&255)<<1)+2|0}else if((z|0)==0){D=((A&255)<<2)+4|0}else{D=(A&255)+1|0}if((g-v|0)<(D|0)){r=v;break a}E=(y&32)==0;if((z|0)==3|((z|0)!=2|E)^1){F=0}else{F=(A&255)+1|0}if((F+B-x|0)>(l|0)){r=v;break a}if((z|0)==0){G=25;break}else if((z|0)==2){G=41;break}else if((z|0)==1){G=35;break}TGb(v|0,u|0,D|0)|0;z=v+D|0;if(z>>>0<b>>>0){v=z;w=B}else{r=z;break a}}do{if((G|0)==25){G=0;u=A&255;z=u<<2;x=v;C=s;H=B;I=A+1&255;while(1){J=d[H]|0;K=C-2+(J&3)|0;if(K>>>0>255>>>0){L=-K>>31&255}else{L=K&255}a[x]=L;K=(J>>>2&3)-2+(L&255)|0;if(K>>>0>255>>>0){M=-K>>31&255}else{M=K&255}a[x+1|0]=M;K=(J>>>4&3)-2+(M&255)|0;if(K>>>0>255>>>0){N=-K>>31&255}else{N=K&255}a[x+2|0]=N;K=(J>>>6)-2+(N&255)|0;if(K>>>0>255>>>0){O=-K>>31&255}else{O=K&255}P=O&255;a[x+3|0]=O;K=I-1&255;if(K<<24>>24==0){break}else{x=x+4|0;C=P;H=H+1|0;I=K}}Q=w+(u+2)|0;R=P;S=v+(z+4)|0}else if((G|0)==35){G=0;I=A&255;H=I<<1;C=v;x=s;K=B;J=A+1&255;while(1){T=d[K]|0;U=(a[15752+(T&15)|0]|0)+x|0;if(U>>>0>255>>>0){V=-U>>31&255}else{V=U&255}a[C]=V;U=(a[15752+(T>>>4)|0]|0)+(V&255)|0;if(U>>>0>255>>>0){W=-U>>31&255}else{W=U&255}X=W&255;a[C+1|0]=W;U=J-1&255;if(U<<24>>24==0){break}else{C=C+2|0;x=X;K=K+1|0;J=U}}Q=w+(I+2)|0;R=X;S=v+(H+2)|0}else if((G|0)==41){G=0;if(E){UGb(v|0,B|0,D)|0;Q=w+(D+1)|0;R=d[w+D|0]|0;S=v+D|0;break}J=(y<<3<<24>>24>>3)+s|0;if(J>>>0>255>>>0){Y=-J>>31&255}else{Y=J&255}a[v]=Y;Q=B;R=Y&255;S=v+1|0}}while(0);if(S>>>0<b>>>0){q=S;s=R;t=Q}else{r=S;break}}}}while(0);c[n>>2]=r-(c[k>>2]|0);c[f>>2]=1;m=l;i=h;return m|0}function kdb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+60|0;d=c[b>>2]|0;c[d>>2]=a;c[d+44>>2]=0;c[a+140>>2]=11;e=a+120|0;f=a+124|0;a=ba(c[f>>2]|0,c[e>>2]|0)|0;c[d+20>>2]=a;g=WDb(a)|0;a=d+16|0;c[a>>2]=g;if((g|0)==0){h=-12;return h|0}g=ba(c[f>>2]|0,c[e>>2]|0)|0;c[d+28>>2]=g;e=WDb(g+130|0)|0;c[d+24>>2]=e;if((e|0)==0){$Db(a);h=-12;return h|0}a=ICb()|0;c[d+4>>2]=a;if((a|0)!=0){h=0;return h|0}a=c[b>>2]|0;JCb(a+4|0);$Db(a+16|0);$Db(a+24|0);$Db(a+32|0);h=-12;return h|0}function ldb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;h=i;j=e;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=g;if(!((l|0)>-1)){yDb(0,0,1911832,(n=i,i=i+24|0,c[n>>2]=1891288,c[n+8>>2]=2348704,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}o=k+l|0;p=g+36|0;a:do{if(l>>>0<9>>>0){q=k;r=l}else{s=g+32|0;t=g+40|0;u=b;v=k;w=l;b:while(1){if((w|0)<4){x=0;y=v}else{z=v;x=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;y=v+4|0}z=o-y|0;if((z|0)<4){A=0;B=y;C=z}else{z=y+4|0;D=y;E=fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0;if((E|0)<0){F=9;break}D=o-z|0;A=E>>>0>D>>>0?D:E;B=z;C=D}do{if((x|0)==1414283600){if((A|0)<768){G=-1094995529;F=120;break b}D=c[p>>2]|0;if((D|0)>255){G=-1094995529;F=120;break b}z=XDb(c[s>>2]|0,(D<<10)+1024|0)|0;D=z;if((z|0)==0){G=-12;F=120;break b}c[s>>2]=D;z=B;H=D+(c[p>>2]<<8<<2)|0;D=0;while(1){c[H>>2]=d[1034952+(d[z]|0)|0]<<16|d[1034952+(d[z+1|0]|0)|0]<<8|d[1034952+(d[z+2|0]|0)|0]|-16777216;I=D+1|0;if((I|0)<256){z=z+3|0;H=H+4|0;D=I}else{break}}c[p>>2]=(c[p>>2]|0)+1;J=1414283600;K=B+768|0}else if((x|0)==1414482003){if((A|0)<4){G=-1094995529;F=120;break b}if((C|0)<4){L=0;M=B}else{D=B;L=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;M=B+4|0}if(L>>>0<(c[p>>2]|0)>>>0){c[t>>2]=L;J=1414482003;K=M;break}else{yDb(u,16,2101808,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;J=1414482003;K=M;break}}else if((x|0)==541149014){F=12;break b}else{J=x;K=B+(C>>>0>A>>>0?A:C)|0}}while(0);D=o-K|0;if(D>>>0<9>>>0|(J|0)==541149014){q=K;r=D;break a}else{v=K;w=D}}if((F|0)==9){yDb(u,16,2178112,(n=i,i=i+8|0,c[n>>2]=E,n)|0);i=n;G=-1094995529;i=h;return G|0}else if((F|0)==12){q=B;r=o-B|0;break}else if((F|0)==120){i=h;return G|0}}}while(0);if((c[p>>2]|0)<1){yDb(c[g>>2]|0,16,2045736,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}p=_$a(b,j,1)|0;if((p|0)<0){G=p;i=h;return G|0}p=g+44|0;if((c[p>>2]|0)==0){b=g;c[p>>2]=ba(c[(c[b>>2]|0)+124>>2]|0,c[e+32>>2]|0)|0;N=b}else{N=g}UGb(c[e+4>>2]|0,(c[g+32>>2]|0)+(c[g+40>>2]<<8<<2)|0,1024)|0;c[g+8>>2]=q;b=g+12|0;c[b>>2]=r;B=c[N>>2]|0;o=c[B+120>>2]|0;E=ba(c[B+124>>2]|0,o)|0;B=c[g+16>>2]|0;K=c[g+20>>2]|0;J=g+24|0;C=c[J>>2]|0;if((r|0)<8){G=-1094995529;i=h;return G|0}A=q;x=(d[A]|d[A+1|0]<<8)<<16>>16&65535;A=q+2|0;M=(d[A]|d[A+1|0]<<8)<<16>>16&65535;A=q+4|0;L=(d[A]|d[A+1|0]<<8)<<16>>16&65535;A=q+6|0;y=(d[A]|d[A+1|0]<<8)<<16>>16&65535;if(!((x|0)<(r|0)&(M|0)<(r|0)&(L|0)<(r|0)&(y|0)<(r|0))){G=-1094995529;i=h;return G|0}A=q+M|0;if(!((r-M|0)>-1)){yDb(0,0,1911832,(n=i,i=i+24|0,c[n>>2]=1891288,c[n+8>>2]=2348704,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}M=q+r|0;l=q+L|0;if(!((r-L|0)>-1)){yDb(0,0,1911832,(n=i,i=i+24|0,c[n>>2]=1891288,c[n+8>>2]=2348704,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}L=a[q+x|0]|0;k=L&255;w=L+22&255;L=k<<1;v=q+((L|1)+x)|0;t=r-1-x-L|0;s=B+K|0;D=t>>>0>268435455>>>0?-8:t<<3;t=D>>>0>2147483639>>>0|(v|0)==0;H=t?0:v;v=t?8:D+8|0;c:do{if(t){O=t?-1094995529:0}else{D=x+1|0;z=B;I=0;d:while(1){P=w;Q=I;while(1){if(P<<24>>24==22){F=47;break d}R=((Q|0)<(v|0))+Q|0;S=(P&255)-23+(k&-((d[H+(Q>>>3)|0]|0)>>>((Q&7)>>>0)&1))|0;if(!(S>>>0<L>>>0)){G=-1094995529;F=120;break d}T=a[q+(D+S)|0]|0;if((T&255)>>>0<22>>>0){break}else{P=T;Q=R}}if(!(z>>>0<s>>>0)){O=K;break c}a[z]=T;z=z+1|0;I=R}if((F|0)==47){O=z-B|0;break}else if((F|0)==120){i=h;return G|0}}}while(0);if((O|0)<0){G=-1094995529;i=h;return G|0}R=B+O|0;do{if((a[q+y|0]|0)==2){T=c[J>>2]|0;K=g+28|0;s=c[K>>2]|0;L=c[b>>2]|0;H=L-y|0;k=T+s|0;if((H|0)<=0){yDb(0,0,1911832,(n=i,i=i+24|0,c[n>>2]=1891288,c[n+8>>2]=2348704,c[n+16>>2]=135,n)|0);i=n;Cd();return 0}v=q+L|0;L=v;if((s|0)<1|(H|0)==1){U=s;V=C;break}s=k;H=T;w=q+(y+1)|0;x=T;e:while(1){do{if((L-w|0)<1){W=0;X=w;F=57}else{T=w+1|0;t=a[w]|0;I=t&255;if(!((t&255)>>>0<224>>>0)){D=(t&255)>>>0>251>>>0;if(D){Y=I&3}else{Y=(I<<2&124)+4|0}if((s-x|0)<(Y|0)){break e}t=L-T|0;if(t>>>0<Y>>>0){break e}u=t>>>0>Y>>>0?Y:t;UGb(x|0,T|0,u)|0;if(D){break e}else{Z=Y;_=w+(u+1)|0;break}}if((I&128|0)==0){W=I;X=T;F=57;break}if((I&64|0)==0){u=L-T|0;do{if((u|0)<1){$=0;aa=T;ca=0}else{D=(d[T]|0)>>>6;if((u|0)<2){$=0;aa=T;ca=D;break}t=T;$=(de((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&16383;aa=w+3|0;ca=D}}while(0);da=$;ea=(I&63)+4|0;fa=ca;ga=aa;F=70;break}if((L-T|0)<2){ha=0;ia=T}else{u=T;ha=(de((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535;ia=w+3|0}if((L-ia|0)<1){ja=0;ka=ia}else{ja=d[ia]|0;ka=ia+1|0}da=ha|I<<12&65536;ea=(ja|I<<6&768)+5|0;fa=I&3;ga=ka;F=70}}while(0);if((F|0)==57){F=0;if((L-X|0)<1){la=0;ma=X}else{la=d[X]|0;ma=X+1|0}da=la|W<<3&768;ea=(W>>>2&7)+3|0;fa=W&3;ga=ma;F=70}if((F|0)==70){F=0;u=da+1|0;D=ea+fa|0;if((s-x|0)<(D|0)){break}t=x+fa|0;if((t-H|0)<(u|0)){break}Q=L-ga|0;if(Q>>>0<fa>>>0){break}P=Q>>>0>fa>>>0?fa:Q;UGb(x|0,ga|0,P)|0;iEb(t,u,ea);Z=D;_=ga+P|0}P=x+Z|0;if(P>>>0>=k>>>0|(v|0)==(_|0)){break}else{w=_;x=P}}U=c[K>>2]|0;V=C}else{U=(c[b>>2]|0)+~y|0;V=q+(y+1)|0}}while(0);f:do{if((E|0)!=0&(O|0)>0){y=e;q=e+32|0;b=M;C=A;_=l;Z=V;ga=B;ea=0;fa=0;da=0;ma=E;W=U;g:while(1){la=ga;X=da;h:while(1){na=la+1|0;oa=a[la]|0;pa=oa&255;switch(pa|0){case 11:case 21:{F=97;break h;break};case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:{F=101;break h;break};case 0:{break};case 10:case 20:{F=93;break h;break};case 12:case 13:case 14:case 15:case 16:case 17:case 18:{F=88;break h;break};case 9:case 19:{F=89;break h;break};default:{qa=0;ra=C;break h}}if(na>>>0<R>>>0){la=na;X=X^1}else{break f}}do{if((F|0)==88){F=0;qa=pa-10|0;ra=C}else if((F|0)==89){F=0;if((M|0)==(C|0)){F=90;break g}if((b-C|0)<1){qa=0;ra=C;break}qa=d[C]|0;ra=C+1|0}else if((F|0)==93){F=0;la=b-C|0;if(la>>>0<2>>>0){F=94;break g}if((la|0)<2){qa=0;ra=C;break}la=C;qa=(de((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535;ra=C+2|0}else if((F|0)==97){F=0;la=b-C|0;if(la>>>0<3>>>0){F=98;break g}if((la|0)<3){qa=0;ra=C;break}qa=d[C+1|0]<<8|d[C]<<16|d[C+2|0];ra=C+3|0}else if((F|0)==101){F=0;qa=pa;ra=C}}while(0);if((qa|0)>(ma|0)){break f}do{if((oa&255)>>>0<12>>>0){la=X^1;if(!(X<<24>>24==1)){ndb(m,j,fa,ea,qa,0,0);sa=W;ta=la;ua=Z;va=_;break}if((W|0)<(qa|0)){break f}ka=c[y>>2]|0;ja=c[q>>2]|0;ha=c[(c[N>>2]|0)+120>>2]|0;ia=ja-ha|0;i:do{if((qa|0)!=0){aa=(ba(ja,ea)|0)+fa|0;if((aa|0)<(c[p>>2]|0)){wa=Z;xa=qa;ya=aa;za=fa}else{break}while(1){aa=ha-za|0;ca=(xa|0)>(aa|0)?aa:xa;UGb(ka+ya|0,wa|0,ca)|0;aa=ca+za|0;$=(aa|0)<(ha|0);if((xa|0)==(ca|0)){break i}Y=ca+ya+($?0:ia)|0;if((Y|0)<(c[p>>2]|0)){wa=wa+ca|0;xa=xa-ca|0;ya=Y;za=$?aa:0}else{break}}}}while(0);sa=W-qa|0;ta=la;ua=Z+qa|0;va=_}else{if((M|0)==(_|0)){F=113;break g}if((b-_|0)<1){Aa=0;Ba=_}else{Aa=d[_]|0;Ba=_+1|0}ndb(m,j,fa,ea,qa,Aa>>>4<<28>>28,Aa<<28>>28);sa=W;ta=0;ua=Z;va=Ba}}while(0);X=qa+fa|0;if((ma|0)!=(qa|0)&na>>>0<R>>>0){C=ra;_=va;Z=ua;ga=na;ea=((X|0)/(o|0)|0)+ea|0;fa=(X|0)%(o|0)|0;da=ta;ma=ma-qa|0;W=sa}else{break f}}if((F|0)==90){yDb(c[N>>2]|0,16,2000064,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}else if((F|0)==94){yDb(c[N>>2]|0,16,2000064,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}else if((F|0)==98){yDb(c[N>>2]|0,16,2000064,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}else if((F|0)==113){yDb(c[N>>2]|0,16,1963152,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}}}while(0);n=g+4|0;KCb(c[n>>2]|0);g=MCb(c[n>>2]|0,j)|0;if((g|0)<0){G=g;i=h;return G|0}c[f>>2]=1;G=r;i=h;return G|0}function mdb(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);$Db(b+16|0);$Db(b+24|0);$Db(b+32|0);return 0}function ndb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=i;k=c[a>>2]|0;l=c[k+120>>2]|0;m=h+e|0;if((m|0)<0){i=j;return}if((m|0)>=(c[k+124>>2]|0)){i=j;return}h=g+d|0;if(!((h|0)>-1&(h|0)<(l|0))){i=j;return}g=c[b>>2]|0;n=c[c[a+4>>2]>>2]|0;o=(n|0)==0?g:n;n=c[b+32>>2]|0;b=n-l|0;p=(ba(n,e)|0)+d|0;e=h+(ba(n,m)|0)|0;do{if((o|0)==(g|0)){m=p-e|0;if((((m|0)>-1?m:-m|0)|0)>=(f|0)){break}DDb(k,1934976,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;i=j;return}}while(0);if((f|0)==0){i=j;return}k=a+44|0;a=d;d=h;h=e;e=p;p=f;while(1){f=c[k>>2]|0;if(!((e|0)<(f|0)&(h|0)<(f|0))){q=11;break}f=l-a|0;m=(p|0)>(f|0)?f:p;f=l-d|0;n=(m|0)>(f|0)?f:m;UGb(g+e|0,o+h|0,n)|0;m=n+a|0;f=n+d|0;r=(m|0)<(l|0);s=(f|0)<(l|0);if((p|0)==(n|0)){q=11;break}else{a=r?m:0;d=s?f:0;h=n+h+(s?0:b)|0;e=n+e+(r?0:b)|0;p=p-n|0}}if((q|0)==11){i=j;return}}function odb(a){a=a|0;c[a+140>>2]=9;return 0}function pdb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=i;i=i+264|0;j=h|0;k=h+256|0;l=e;m=c[g+24>>2]|0;n=g+28|0;g=m+(c[n>>2]|0)|0;o=b+120|0;p=j|0;q=b+124|0;r=m;while(1){if((c[o>>2]|0)!=0){if((c[q>>2]|0)!=0){s=16;break}}m=hc(r|0,2178104)|0;t=r+m|0;u=xd(t|0,2101784,(v=i,i=i+16|0,c[v>>2]=p,c[v+8>>2]=k,v)|0)|0;i=v;if((u|0)!=2){s=5;break}u=SGb(p|0)|0;do{if((u|0)>6){if((c[q>>2]|0)!=0){s=11;break}if((PGb(j+(u-7)|0,2000056,7)|0)!=0){s=10;break}c[q>>2]=c[k>>2]}else{s=10}}while(0);if((s|0)==10){s=0;if((u|0)>5){s=11}else{s=14;break}}if((s|0)==11){s=0;if((c[o>>2]|0)!=0){s=14;break}if((PGb(j+(u-6)|0,1963144,6)|0)!=0){s=14;break}c[o>>2]=c[k>>2]}r=r+(m+1+(hc(t|0,1911824)|0))|0}if((s|0)==5){yDb(b,16,2045696,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=h;return w|0}else if((s|0)==14){yDb(b,16,1934952,(v=i,i=i+8|0,c[v>>2]=p,v)|0);i=v;w=-1094995529;i=h;return w|0}else if((s|0)==16){s=_$a(b,l,0)|0;if((s|0)<0){w=s;i=h;return w|0}s=c[o>>2]|0;o=(s+7|0)/8|0;l=c[q>>2]|0;a:do{if((l|0)>0){p=r+((hc(r|0,1891280)|0)+1)|0;k=e;j=e+32|0;if((s|0)>0){x=p;y=0}else{p=0;while(1){p=p+1|0;if((p|0)>=(l|0)){break a}}}b:while(1){p=ba(c[j>>2]|0,y)|0;t=(c[k>>2]|0)+p|0;p=x;m=0;while(1){u=hc(p|0,2348696)|0;z=p+(u+1)|0;if(!(z>>>0<g>>>0)){break b}if((FAb(d[z]|0)|0)==0){break b}A=a[z]|0;do{if((A&255)>>>0>96>>>0){B=A-87&255}else{if((A&255)>>>0>64>>>0){B=A-55&255;break}else{B=A-48&255;break}}}while(0);C=p+(u+2)|0;if((FAb(d[C]|0)|0)==0){D=B}else{A=B<<4;E=a[C]|0;do{if((E&255)>>>0>96>>>0){F=E-87&255}else{if((E&255)>>>0>64>>>0){F=E-55&255;break}else{F=E-48&255;break}}}while(0);D=F+A&255}a[t]=a[1148864+(D&255)|0]|0;E=m+1|0;if((E|0)<(o|0)){t=t+1|0;p=C;m=E}else{break}}m=y+1|0;if((m|0)<(c[q>>2]|0)){x=C;y=m}else{break a}}yDb(b,16,2328552,(v=i,i=i+8|0,c[v>>2]=z,v)|0);i=v;w=-1094995529;i=h;return w|0}}while(0);c[e+84>>2]=1;c[e+88>>2]=1;c[f>>2]=1;w=c[n>>2]|0;i=h;return w|0}return 0}function qdb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=a+120|0;j=c[h>>2]|0;k=(j+7|0)/8|0;l=a+124|0;m=(ba((k*7|0)+2|0,c[l>>2]|0)|0)+110|0;n=r0a(a,b,m,(m|0)<0|0?-1:0)|0;if((n|0)<0){o=n;i=g;return o|0}n=b+24|0;m=c[n>>2]|0;a=c[e>>2]|0;p=Lb(m|0,32,2178080,(q=i,i=i+8|0,c[q>>2]=c[h>>2],q)|0)|0;i=q;h=Lb(m+p|0,33,2101752,(q=i,i=i+8|0,c[q>>2]=c[l>>2],q)|0)|0;i=q;r=h+p|0;p=Lb(m+r|0,40,2045656,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;h=m+(r+p)|0;a:do{if((c[l>>2]|0)>0){p=e+32|0;if((j|0)<=0){r=0;m=h;while(1){s=Lb(m|0,2,1963136,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;t=m+s|0;s=r+1|0;if((s|0)<(c[l>>2]|0)){r=s;m=t}else{u=t;break a}}}m=(k|0)>1?k:1;r=0;t=a;s=h;while(1){v=0;w=t;x=s;while(1){y=Lb(x|0,7,2000040,(q=i,i=i+8|0,c[q>>2]=d[1148864+(d[w]|0)|0]|0,q)|0)|0;i=q;z=x+y|0;A=v+1|0;if((A|0)<(k|0)){v=A;w=w+1|0;x=z}else{break}}w=t+(m+((c[p>>2]|0)-k))|0;v=Lb(z|0,2,1963136,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;A=x+(y+v)|0;v=r+1|0;if((v|0)<(c[l>>2]|0)){r=v;t=w;s=A}else{u=A;break}}}else{u=h}}while(0);h=Lb(u|0,5,1934944,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;c[b+28>>2]=u+h-(c[n>>2]|0);n=b+36|0;c[n>>2]=c[n>>2]|1;c[f>>2]=1;o=0;i=g;return o|0}function rdb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a+120|0;e=c[d>>2]|0;if((e|0)==0){if((c[a+124>>2]|0)==0){f=6}else{f=3}}else if((e|0)==48){g=c[a+124>>2]|0;if((g|0)==48){f=6}else{h=g}}else{f=3}if((f|0)==3){h=c[a+124>>2]|0}else if((f|0)==6){c[d>>2]=48;c[a+124>>2]=48;c[a+140>>2]=9;j=0;i=b;return j|0}yDb(a,16,2101688,(a=i,i=i+32|0,c[a>>2]=e,c[a+8>>2]=h,c[a+16>>2]=48,c[a+24>>2]=48,a)|0);i=a;j=-22;i=b;return j|0}function sdb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+584|0;h=g|0;j=c[b+60>>2]|0;TGb(h|0,0,580)|0;k=_$a(b,d,0)|0;if((k|0)<0){l=k;i=g;return l|0}k=f+24|0;m=c[k>>2]|0;n=a[m]|0;a:do{if(!(n<<24>>24==0)){o=f+28|0;p=0;q=0;r=n;s=m;while(1){if((q|0)>=(c[o>>2]|0)){break a}t=r-33&255;if((t&255)>>>0>93>>>0){u=p;v=s}else{w=p+1|0;if((w|0)>354){break}epb(h,94);cpb(h,t);u=w;v=c[k>>2]|0}w=q+1|0;t=a[v+w|0]|0;if(t<<24>>24==0){break a}else{p=u;q=w;r=t;s=v}}yDb(b,24,2178024,(s=i,i=i+8|0,c[s>>2]=q,s)|0);i=s}}while(0);TGb(j|0,0,2304)|0;tdb(h,j,16,16,0);tdb(h,j+16|0,16,16,0);tdb(h,j+32|0,16,16,0);tdb(h,j+768|0,16,16,0);tdb(h,j+784|0,16,16,0);tdb(h,j+800|0,16,16,0);tdb(h,j+1536|0,16,16,0);tdb(h,j+1552|0,16,16,0);tdb(h,j+1568|0,16,16,0);fpb(j,j);h=d+32|0;b=0;v=0;u=0;k=c[d>>2]|0;d=0;while(1){m=(a[j+d|0]|0)+u&255;if((v|0)==7){a[k+b|0]=m;x=0;y=0;z=b+1|0}else{x=m<<1;y=v+1|0;z=b}if((z|0)==6){A=k+(c[h>>2]|0)|0;B=0}else{A=k;B=z}m=d+1|0;if((m|0)<2304){b=B;v=y;u=x;k=A;d=m}else{break}}c[e>>2]=1;l=c[f+28>>2]|0;i=g;return l|0}function tdb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+8|0;j=h|0;dpb(a,0,j);k=d[j]|0;l=0;m=1077888+(g*24|0)|0;while(1){n=m+4|0;o=c[n>>2]|0;if((k|0)>=(o|0)){p=c[m>>2]|0;if((k|0)<(p+o|0)){break}}l=l+1|0;m=m+8|0}epb(a,p&255);cpb(a,(d[j]|0)-(c[n>>2]|0)&255);if((l|0)==0){udb(a,b,e,f);i=h;return}else if((l|0)==2){i=h;return}else{l=(e|0)/2|0;e=(f|0)/2|0;f=g+1|0;tdb(a,b,l,e,f);tdb(a,b+l|0,l,e,f);g=e*48|0;tdb(a,b+g|0,l,e,f);tdb(a,b+(g+l)|0,l,e,f);i=h;return}}function udb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;i=i+8|0;j=h|0;if((f|0)>3){k=(f|0)/2|0;f=(g|0)/2|0;udb(b,e,k,f);udb(b,e+k|0,k,f);g=f*48|0;udb(b,e+g|0,k,f);udb(b,e+(g+k)|0,k,f);i=h;return}dpb(b,0,j);f=d[j]|0;k=0;g=1077984;while(1){l=g+4|0;m=c[l>>2]|0;if((f|0)>=(m|0)){n=c[g>>2]|0;if((f|0)<(n+m|0)){break}}k=k+1|0;g=g+8|0}epb(b,n&255);cpb(b,(d[j]|0)-(c[l>>2]|0)&255);if((k&1|0)!=0){a[e]=1}if((k&2|0)!=0){a[e+1|0]=1}if((k&4|0)!=0){a[e+48|0]=1}if((k&8|0)==0){i=h;return}a[e+49|0]=1;i=h;return}function vdb(a){a=a|0;var b=0,d=0;b=ICb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+88>>2]=1;d=0;return d|0}function wdb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+21704|0;j=h|0;k=h+8|0;l=h+18448|0;m=h+20752|0;n=h+21336|0;o=h+21696|0;p=c[b+60>>2]|0;TGb(k|0,0,18436)|0;TGb(m|0,0,580)|0;q=b+120|0;r=c[q>>2]|0;if((r|0)==0){if((c[b+124>>2]|0)==0){s=6}else{s=3}}else if((r|0)==48){t=c[b+124>>2]|0;if((t|0)==48){s=6}else{u=t}}else{s=3}if((s|0)==3){u=c[b+124>>2]|0}else if((s|0)==6){c[q>>2]=48;c[b+124>>2]=48;q=f+32|0;s=c[f>>2]|0;f=0;t=0;while(1){v=s+f|0;a[p+(t|4)|0]=(d[v]|0)>>>7;a[p+(t|5)|0]=(d[v]|0)>>>6&1;w=t|3;a[p+((t|1)+5)|0]=(d[v]|0)>>>5&1;a[p+(t|7)|0]=(d[v]|0)>>>4&1;a[p+(w+5)|0]=(d[v]|0)>>>3&1;a[p+(w+6)|0]=(d[v]|0)>>>2&1;a[p+(w+7)|0]=(d[v]|0)>>>1&1;a[p+((t|7)+4)|0]=a[v]&1;v=t+8|0;w=f+1|0;if((w|0)==6){x=s+(c[q>>2]|0)|0;y=0}else{x=s;y=w}if((v|0)<2304){s=x;f=y;t=v}else{break}}t=l|0;l=p+4|0;UGb(t|0,l|0,2304)|0;fpb(l,t);ydb(l,16,16,0,k);ydb(p+20|0,16,16,0,k);ydb(p+36|0,16,16,0,k);ydb(p+772|0,16,16,0,k);ydb(p+788|0,16,16,0,k);ydb(p+804|0,16,16,0,k);ydb(p+1540|0,16,16,0,k);ydb(p+1556|0,16,16,0,k);ydb(p+1572|0,16,16,0,k);p=k+18432|0;l=c[p>>2]|0;if((l|0)>0){t=l;do{l=t-1|0;c[p>>2]=l;y=c[k+(l<<2)>>2]|0;dpb(m,c[y>>2]&255,j);epb(m,0);cpb(m,(d[j]|0)+(c[y+4>>2]|0)&255);t=c[p>>2]|0;}while((t|0)>0)}t=m|0;if((c[t>>2]|0)==0){z=0}else{p=0;while(1){dpb(m,94,o);j=p+1|0;a[n+p|0]=(a[o]|0)+33;if((c[t>>2]|0)==0){z=j;break}else{p=j}}}p=z+2|0;t=r0a(b,e,p,(p|0)<0|0?-1:0)|0;if((t|0)<0){A=t;i=h;return A|0}t=c[e+24>>2]|0;if((z|0)>0){p=t;o=z;while(1){m=o-1|0;a[p]=a[n+m|0]|0;if((m|0)>0){p=p+1|0;o=m}else{break}}B=t+z|0}else{B=t}a[B]=10;a[B+1|0]=0;B=e+36|0;c[B>>2]=c[B>>2]|1;c[g>>2]=1;A=0;i=h;return A|0}yDb(b,16,2177960,(b=i,i=i+32|0,c[b>>2]=r,c[b+8>>2]=u,c[b+16>>2]=48,c[b+24>>2]=48,b)|0);i=b;A=-22;i=h;return A|0}function xdb(a){a=a|0;$Db(a+804|0);return 0}function ydb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=g+18432|0;i=f;f=e;e=d;d=b;a:while(1){b:do{if((a[d]|0)==0){if((f|0)==0){j=8;break a}else{k=d;l=f}while(1){b=l-1|0;m=e;n=k;while(1){if((m|0)==0){break}if((a[n]|0)==0){m=m-1|0;n=n+1|0}else{break b}}if((b|0)==0){j=8;break a}else{k=k+48|0;l=b}}}}while(0);n=(zdb(d,e,f)|0)==0;o=c[h>>2]|0;p=(o|0)>4606;if(!n){j=11;break}if(!p){c[h>>2]=o+1;c[g+(o<<2)>>2]=1077896+(i*24|0)}n=(e|0)/2|0;m=(f|0)/2|0;q=i+1|0;ydb(d,n,m,q,g);ydb(d+n|0,n,m,q,g);r=m*48|0;ydb(d+r|0,n,m,q,g);i=q;f=m;e=n;d=d+(r+n)|0}if((j|0)==8){l=c[h>>2]|0;if((l|0)>4606){return}c[h>>2]=l+1;c[g+(l<<2)>>2]=1077904+(i*24|0);return}else if((j|0)==11){if(!p){c[h>>2]=o+1;c[g+(o<<2)>>2]=1077888+(i*24|0)}Adb(g,d,e,f);return}}function zdb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;if((c|0)>3){e=(c|0)/2|0;c=(d|0)/2|0;if((zdb(b,e,c)|0)==0){f=0;return f|0}if((zdb(b+e|0,e,c)|0)==0){f=0;return f|0}d=c*48|0;if((zdb(b+d|0,e,c)|0)==0){f=0;return f|0}else{return(zdb(b+(d+e)|0,e,c)|0)!=0|0}}if((a[b]|0)!=0){f=1;return f|0}if((a[b+1|0]|0)!=0){f=1;return f|0}if((a[b+48|0]|0)!=0){f=1;return f|0}f=(a[b+49|0]|0)!=0|0;return f|0}function Adb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((e|0)>3){g=d;h=e;e=f;while(1){f=(h|0)/2|0;i=(e|0)/2|0;Adb(b,g,f,i);Adb(b,g+f|0,f,i);j=i*48|0;Adb(b,g+j|0,f,i);k=g+(j+f)|0;if((h|0)>7){g=k;h=f;e=i}else{l=k;break}}}else{l=d}d=b+18432|0;e=c[d>>2]|0;if((e|0)>4606){return}h=1077984+((a[l]|0)+(a[l+1|0]<<1)+(a[l+48|0]<<2)+(a[l+49|0]<<3)<<3)|0;c[d>>2]=e+1;c[b+(e<<2)>>2]=h;return}function Bdb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;do{if((e|0)>5){i=b;if(((de((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535|0)!=(f|0)){break}c[h>>2]=f;c[g>>2]=b+2;if((e-f|0)<6){j=-1;return j|0}i=f+2|0;k=f+6|0;l=b+i|0;m=(de((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&65535;c[h+4>>2]=m;c[g+4>>2]=b+(f+4);if((k|0)>(e-m|0)){j=-1;return j|0}else{l=i+(m+2)|0;i=b+l|0;n=(de((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535;c[h+8>>2]=n;c[g+8>>2]=b+(l+2);return((m+k|0)>(e-n|0))<<31>>31|0}}}while(0);if(!((e-3|0)>>>0<2147483133>>>0)){j=-1;return j|0}if((a[b]|0)==2){o=3;p=0;q=b}else{j=-1;return j|0}while(1){r=q+1|0;if((p|0)>=2){break}b=h+(p<<2)|0;c[b>>2]=0;a:do{if((o|0)<(e|0)){f=r;n=o;k=0;while(1){if(!((a[f]|0)==-1)){s=f;t=n;u=k;break a}m=k+255|0;c[b>>2]=m;l=n+256|0;i=f+1|0;if((l|0)<(e|0)){f=i;n=l;k=m}else{s=i;t=l;u=m;break}}}else{s=r;t=o;u=0}}while(0);c[b>>2]=u+(d[s]|0);k=(d[s]|0)+t|0;if((k|0)>(e|0)){j=-1;v=13;break}else{o=k;p=p+1|0;q=s}}if((v|0)==13){return j|0}c[h+8>>2]=e-o;c[g>>2]=r;r=(c[h>>2]|0)+1|0;c[g+4>>2]=q+r;c[g+8>>2]=q+(r+(c[h+4>>2]|0));j=0;return j|0}function Cdb(a){a=a|0;c[a+140>>2]=7;return 0}function Ddb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=b+120|0;l=c[g>>2]|0;if((l&3|0)!=0){yDb(b,16,2177888,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=h;return n|0}o=b+124|0;if((k|0)<(ba(c[o>>2]|0,l)|0)){yDb(b,16,2101664,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=h;return n|0}m=_$a(b,e,0)|0;if((m|0)<0){n=m;i=h;return n|0}c[e+88>>2]=1;c[e+84>>2]=1;m=c[g>>2]|0;b=m-4|0;l=c[o>>2]|0;if((l|0)>0){p=e+32|0;q=e+36|0;r=e+40|0;s=c[e+8>>2]|0;t=0;u=c[e+4>>2]|0;v=c[e>>2]|0;e=j;j=0;w=0;x=0;y=m;m=l;while(1){l=e+b|0;if((y|0)>0){z=0;A=l;B=j;C=w;D=x;while(1){E=A;F=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;G=A-4|0;E=F>>>16;H=(z|0)!=0;if(H){I=(c[1712+((E&31)<<2)>>2]|0)+B|0}else{I=E<<2&124}E=(c[1712+((F>>>21&31)<<2)>>2]|0)+I|0;J=E+(c[1712+((F>>>26&31)<<2)>>2]|0)|0;K=J+(c[1712+((F&31)<<2)>>2]|0)|0;L=F>>>5&31;if(H){M=(c[1712+((F>>>10&31)<<2)>>2]|0)+D|0;N=(c[1712+(L<<2)>>2]|0)+C|0}else{M=F>>>10<<2&124;N=L<<2}a[v+z|0]=I<<1;a[v+(z|1)|0]=E<<1;a[v+(z|2)|0]=J<<1;a[v+(z|3)|0]=K<<1;J=z>>2;a[u+J|0]=N<<1;a[s+J|0]=M<<1;J=z+4|0;O=c[g>>2]|0;if((J|0)<(O|0)){z=J;A=G;B=K;C=N;D=M}else{break}}P=G;Q=K;R=N;S=M;T=O;U=c[o>>2]|0}else{P=l;Q=j;R=w;S=x;T=y;U=m}D=t+1|0;if((D|0)<(U|0)){s=s+(c[r>>2]|0)|0;t=D;u=u+(c[q>>2]|0)|0;v=v+(c[p>>2]|0)|0;e=P+(T+4)|0;j=Q;w=R;x=S;y=T;m=U}else{break}}}c[f>>2]=1;n=k;i=h;return n|0}function Edb(a){a=a|0;c[a+140>>2]=11;return 0}function Fdb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[g+24>>2]|0;m=c[g+28>>2]|0;n=l+m|0;o=(c[b+52>>2]|0)==1095981124;if((m|0)<53){yDb(b,16,2177856,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;q=-1;i=h;return q|0}do{if((a[l]|0)==91){if((a[l+13|0]|0)!=45){break}if((a[l+26|0]|0)!=93){break}r=g+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;if((s|0)==0&(t|0)==(-2147483648|0)){u=0;v=0}else{c[j>>2]=1;c[j+4>>2]=1e6;c[k>>2]=1;c[k+4>>2]=1e3;r=KDb(s,t,j,k)|0;u=F;v=r}a:do{if((a[l+3|0]|0)==58){if((a[l+6|0]|0)!=58){w=0;break}if((a[l+9|0]|0)==46){x=0;y=0;z=0}else{w=0;break}do{r=(a[l+((d[189168+x|0]|0)+1)|0]|0)-48&255;if((r&255)>>>0>9>>>0){w=0;break a}t=YGb(r&255,0,z,y)|0;z=gHb(d[189184+x|0]|0,0,t,F)|0;y=F;x=x+1|0;}while(x>>>0<9>>>0);t=ZGb(z,y,v,u)|0;w=t}else{w=0}}while(0);c[e+4>>2]=w;b:do{if((a[l+16|0]|0)==58){if((a[l+19|0]|0)!=58){A=0;break}if((a[l+22|0]|0)==46){B=0;C=0;D=0}else{A=0;break}do{t=(a[l+((d[189168+B|0]|0)+14)|0]|0)-48&255;if((t&255)>>>0>9>>>0){A=0;break b}r=YGb(t&255,0,D,C)|0;D=gHb(d[189184+B|0]|0,0,r,F)|0;C=F;B=B+1|0;}while(B>>>0<9>>>0);r=ZGb(D,C,v,u)|0;A=r}else{A=0}}while(0);c[e+8>>2]=A;r=l+27|0;t=(d[r]|d[r+1|0]<<8)<<16>>16;r=t&65535;s=l+29|0;E=(d[s]|d[s+1|0]<<8)<<16>>16;s=E&65535;if((hDb(r,s,0,b)|0)<0){q=-1;i=h;return q|0}G=l+31|0;H=(d[G]|d[G+1|0]<<8)<<16>>16&65535;G=l+33|0;I=(d[G]|d[G+1|0]<<8)<<16>>16&65535;G=l+41|0;J=e+16|0;c[J>>2]=cEb(4)|0;K=cEb(100)|0;c[c[J>>2]>>2]=K;c[e+12>>2]=1;K=c[c[J>>2]>>2]|0;c[K>>2]=H;c[K+4>>2]=I;c[K+8>>2]=r;c[K+12>>2]=s;c[K+84>>2]=1;c[K+52>>2]=r;K=WDb(ba(s,r)|0)|0;c[(c[c[J>>2]>>2]|0)+20>>2]=K;c[(c[c[J>>2]>>2]|0)+16>>2]=4;K=cEb(1024)|0;c[(c[c[J>>2]>>2]|0)+24>>2]=K;K=c[c[J>>2]>>2]|0;I=K+16|0;do{if((c[I>>2]|0)>0){H=c[K+24>>2]|0;L=G;M=0;while(1){N=L+3|0;c[H+(M<<2)>>2]=d[L+1|0]<<8|d[L]<<16|d[L+2|0];O=M+1|0;P=c[I>>2]|0;if((O|0)<(P|0)){L=N;M=O}else{break}}if((P|0)<=0){Q=N;break}if(o){M=N;L=0;while(1){H=M+1|0;O=(c[K+24>>2]|0)+(L<<2)|0;c[O>>2]=c[O>>2]|d[M]<<24;O=L+1|0;if((O|0)<(c[I>>2]|0)){M=H;L=O}else{Q=H;break}}}else{L=0;while(1){M=(c[K+24>>2]|0)+(L<<2)|0;c[M>>2]=c[M>>2]|((L|0)!=0?-16777216:0);M=L+1|0;if((M|0)<(c[I>>2]|0)){L=M}else{Q=N;break}}}}else{Q=G}}while(0);G=n-Q<<3;I=G>>>0>2147483639>>>0|(Q|0)==0;L=I?0:Q;M=I?8:G+8|0;do{if(!(E<<16>>16==0)){G=(s+1|0)>>>1;if(t<<16>>16==0){break}else{R=0;S=0;T=c[K+20>>2]|0}while(1){if((S|0)==(G|0)){U=R;V=0;W=(c[(c[c[J>>2]>>2]|0)+20>>2]|0)+r|0}else{U=R;V=0;W=T}while(1){I=L+(U>>>3)|0;H=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(U&7);I=14-((d[1191992+(H>>>24)|0]|0)>>>1<<2)|0;O=H>>>((32-I|0)>>>0);H=I+U|0;I=M>>>0>H>>>0?H:M;H=L+(I>>>3)|0;X=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(I&7)>>>30;H=I+2|0;Y=M>>>0>H>>>0?H:M;H=r-V|0;I=(O|0)>(H|0)?H:O;Z=(I|0)==0?H:I;TGb(W|0,X&255|0,Z|0)|0;X=Z+V|0;if((X|0)<(r|0)){U=Y;V=X;W=W+Z|0}else{break}}X=-Y&7;if((X|0)==0){_=Y}else{I=X+Y|0;_=M>>>0>I>>>0?I:M}I=S+1|0;if((I|0)<(s|0)){R=_;S=I;T=W+(Z+r)|0}else{break}}}}while(0);c[f>>2]=1;q=m;i=h;return q|0}}while(0);yDb(b,16,2101640,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0}function Gdb(a){a=a|0;var b=0;b=a+52|0;if((c[b>>2]|0)==0){c[b>>2]=1112758340}c[a+792>>2]=4;return 0}function Hdb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+24|0;j=h|0;k=g+24|0;l=eHb(c[k>>2]|0,c[k+4>>2]|0,1e3,0)|0;k=F;m=YGb(c[g+8>>2]|0,0,l,k)|0;n=ZGb(m,F,c[g+4>>2]|0,0)|0;m=F;o=e+27|0;if((f|0)<53){yDb(b,16,2177816,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0}r=c[g+12>>2]|0;if((r|0)!=1){yDb(b,24,2101592,(p=i,i=i+8|0,c[p>>2]=r,p)|0);i=p}r=g+16|0;g=c[c[r>>2]>>2]|0;do{if((c[g+20>>2]|0)!=0){s=c[g+24>>2]|0;if((s|0)==0){break}t=c[g+16>>2]|0;if((t|0)>4){yDb(b,24,1999984,(p=i,i=i+8|0,c[p>>2]=t,p)|0);i=p;u=c[(c[c[r>>2]>>2]|0)+24>>2]|0}else{u=s}if((c[u>>2]|0)>>>0>16777215>>>0){yDb(b,24,1963064,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}s=0;t=0;if(k>>>0>s>>>0|k>>>0==s>>>0&l>>>0>359999999>>>0|(m>>>0>t>>>0|m>>>0==t>>>0&n>>>0>359999999>>>0)){yDb(b,24,1934912,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0}t=hHb(l,k,6e4,0)|0;s=F;v=hHb(l,k,1e3,0)|0;w=F;y=hHb(l,k,36e5,0)|0;z=iHb(t,s,60,0)|0;s=iHb(v,w,60,0)|0;w=iHb(l,k,1e3,0)|0;v=hHb(n,m,6e4,0)|0;t=F;A=hHb(n,m,1e3,0)|0;B=F;C=hHb(n,m,36e5,0)|0;D=iHb(v,t,60,0)|0;t=iHb(A,B,60,0)|0;B=iHb(n,m,1e3,0)|0;Lb(e|0,28,1911768,(p=i,i=i+64|0,c[p>>2]=y,c[p+8>>2]=z,c[p+16>>2]=s,c[p+24>>2]=w,c[p+32>>2]=C,c[p+40>>2]=D,c[p+48>>2]=t,c[p+56>>2]=B,p)|0)|0;i=p;B=c[c[r>>2]>>2]|0;t=(c[B+12>>2]|0)+1|0;D=(c[B+8>>2]|0)+1&65534;B=o;x=D&65535;a[B]=x;x=x>>8;a[B+1|0]=x;B=t&65534;t=e+29|0;x=B&65535;a[t]=x;x=x>>8;a[t+1|0]=x;t=e+31|0;x=c[c[c[r>>2]>>2]>>2]&65535;a[t]=x;x=x>>8;a[t+1|0]=x;t=e+33|0;x=c[(c[c[r>>2]>>2]|0)+4>>2]&65535;a[t]=x;x=x>>8;a[t+1|0]=x;t=e+35|0;x=D+65535+(c[c[c[r>>2]>>2]>>2]|0)&65535;a[t]=x;x=x>>8;a[t+1|0]=x;t=e+37|0;x=B+65535+(c[(c[c[r>>2]>>2]|0)+4>>2]|0)&65535;a[t]=x;x=x>>8;a[t+1|0]=x;t=c[c[(c[c[r>>2]>>2]|0)+24>>2]>>2]|0;a[e+43|0]=t;a[e+42|0]=t>>>8;a[e+41|0]=t>>>16;t=c[(c[(c[c[r>>2]>>2]|0)+24>>2]|0)+4>>2]|0;a[e+46|0]=t;a[e+45|0]=t>>>8;a[e+44|0]=t>>>16;t=c[(c[(c[c[r>>2]>>2]|0)+24>>2]|0)+8>>2]|0;a[e+49|0]=t;a[e+48|0]=t>>>8;a[e+47|0]=t>>>16;t=c[(c[(c[c[r>>2]>>2]|0)+24>>2]|0)+12>>2]|0;a[e+52|0]=t;a[e+51|0]=t>>>8;a[e+50|0]=t>>>16;t=e+53|0;B=e-2+f-t|0;D=(B|0)<0;C=D?0:t;t=D?0:B;c[j+20>>2]=t<<3;B=j+8|0;c[B>>2]=C;c[j+16>>2]=C+t;t=j+12|0;c[t>>2]=C;C=j+4|0;c[C>>2]=32;D=j|0;c[D>>2]=0;w=c[c[r>>2]>>2]|0;if((Idb(j,c[w+20>>2]|0,c[w+52>>2]<<1,c[w+8>>2]|0,(c[w+12>>2]|0)+1>>1)|0)!=0){q=-1;i=h;return q|0}w=e+39|0;x=(32-(c[C>>2]|0)+((c[t>>2]|0)-(c[B>>2]|0)<<3)|0)>>>3&65535;a[w]=x;x=x>>8;a[w+1|0]=x;w=c[c[r>>2]>>2]|0;s=c[w+52>>2]|0;if((Idb(j,(c[w+20>>2]|0)+s|0,s<<1,c[w+8>>2]|0,c[w+12>>2]>>1)|0)!=0){q=-1;i=h;return q|0}w=c[c[r>>2]>>2]|0;if((c[w+12>>2]&1|0)!=0){s=c[w+8>>2]|0;do{if((s|0)<256){w=(d[1191992+s|0]|0)>>>1<<2|2;z=c[D>>2]|0;y=c[C>>2]|0;if((y|0)>(w|0)){E=y;G=z<<w|s}else{A=fe(s>>>((w-y|0)>>>0)|z<<y|0)|0;z=c[t>>2]|0;x=A;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;E=y+32|0;G=s}H=E-w|0;I=G}else{w=c[D>>2]|0;y=c[C>>2]|0;if((y|0)>14){H=y-14|0;I=w<<14;break}else{z=fe(w<<y|0)|0;w=c[t>>2]|0;x=z;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;H=y+18|0;I=0;break}}}while(0);c[D>>2]=I;c[C>>2]=H;if((H|0)>2){J=H-2|0;K=I<<2}else{s=fe(I<<H|0)|0;y=c[t>>2]|0;x=s;a[y]=x;x=x>>8;a[y+1|0]=x;x=x>>8;a[y+2|0]=x;x=x>>8;a[y+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;J=H+30|0;K=0}c[D>>2]=K;c[C>>2]=J;K_(j)}y=c[C>>2]|0;if((y|0)<32){s=c[D>>2]<<y;c[D>>2]=s;y=s>>>24&255;while(1){s=c[t>>2]|0;c[t>>2]=s+1;a[s]=y;s=c[D>>2]|0;c[D>>2]=s<<8;w=(c[C>>2]|0)+8|0;c[C>>2]=w;if((w|0)<32){y=s>>>16&255}else{break}}}c[C>>2]=32;c[D>>2]=0;q=(((c[t>>2]|0)-(c[B>>2]|0)<<3|0)/8|0)+53|0;i=h;return q|0}}while(0);yDb(b,24,2045624,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0}function Idb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((h|0)<=0){i=0;return i|0}j=(g|0)>0;k=g&1;l=(k|0)==0;m=1191992+k|0;n=b|0;o=b+4|0;p=b+12|0;q=b+20|0;r=b+8|0;s=e;e=0;t=0;a:while(1){if(j){u=0;v=c[o>>2]|0;w=c[p>>2]|0;while(1){if(((c[q>>2]|0)-32+v-(w-(c[r>>2]|0)<<3)|0)<56){i=-1;y=33;break a}z=a[s+u|0]&3;A=u;do{A=A+1|0;if((A|0)>=(g|0)){break}}while((a[s+A|0]&3|0)==(z|0));B=A-u|0;if((A|0)==(g|0)&(z|0)==0){C=B+k|0}else{C=(B|0)>255?255:B}do{if((C|0)<256){B=(d[1191992+C|0]|0)>>>1<<2|2;D=c[n>>2]|0;if((v|0)>(B|0)){E=v;F=D<<B|C;G=w}else{H=w;x=fe(C>>>((B-v|0)>>>0)|D<<v|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=(c[p>>2]|0)+4|0;c[p>>2]=H;E=v+32|0;F=C;G=H}I=G;J=E-B|0;K=F}else{B=c[n>>2]|0;if((v|0)>14){I=w;J=v-14|0;K=B<<14;break}else{H=w;x=fe(B<<v|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=(c[p>>2]|0)+4|0;c[p>>2]=H;I=H;J=v+18|0;K=0;break}}}while(0);c[n>>2]=K;c[o>>2]=J;if((J|0)>2){L=J-2|0;M=K<<2|z;N=I}else{A=I;x=fe(z>>>((2-J|0)>>>0)|K<<J|0)|0;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;A=(c[p>>2]|0)+4|0;c[p>>2]=A;L=J+30|0;M=z;N=A}c[n>>2]=M;c[o>>2]=L;A=C+u|0;if((A|0)<(g|0)){u=A;v=L;w=N}else{O=z;break}}}else{O=t}if(!((O|0)==0|l)){w=(d[m]|0)>>>1<<2|2;v=c[n>>2]|0;u=c[o>>2]|0;if((u|0)>(w|0)){P=u;Q=v<<w|k}else{A=fe(k>>>((w-u|0)>>>0)|v<<u|0)|0;v=c[p>>2]|0;x=A;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;P=u+32|0;Q=k}u=P-w|0;c[n>>2]=Q;c[o>>2]=u;if((u|0)>2){R=u-2|0;S=Q<<2}else{w=fe(Q<<u|0)|0;v=c[p>>2]|0;x=w;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;R=u+30|0;S=0}c[n>>2]=S;c[o>>2]=R}K_(b);u=e+1|0;if((u|0)<(h|0)){s=s+f|0;e=u;t=O}else{i=0;y=33;break}}if((y|0)==33){return i|0}return 0}function Jdb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;h=b;j=c[f+28>>2]|0;if((j|0)<100){k=-1094995529;i=g;return k|0}l=c[f+24>>2]|0;f=l;m=fe(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;f=l+4|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=117440512){yDb(a,16,2177792,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(j>>>0<m>>>0|m>>>0<100>>>0){yDb(a,16,2101568,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}f=l+8|0;o=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=fe(o|0)|0;p=l+12|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=fe(q|0)|0;r=l+16|0;s=a+120|0;c[s>>2]=fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;r=l+20|0;t=a+124|0;c[t>>2]=fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;r=l+24|0;u=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=fe(u|0)|0;v=l+28|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=fe(w|0)|0;x=l+32|0;y=fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0;x=l+36|0;z=fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0;x=l+40|0;A=fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0;x=l+44|0;B=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=fe(B|0)|0;C=l+48|0;D=fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=l+52|0;E=fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=l+56|0;F=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;C=fe(F|0)|0;G=l+60|0;H=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;G=fe(H|0)|0;I=l+64|0;J=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;I=fe(J|0)|0;K=l+76|0;L=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0;K=fe(L|0)|0;M=l+m|0;N=a;yDb(N,48,2045560,(n=i,i=i+40|0,c[n>>2]=f,c[n+8>>2]=p,c[n+16>>2]=y,c[n+24>>2]=z,c[n+32>>2]=A,n)|0);i=n;yDb(N,48,1999920,(n=i,i=i+48|0,c[n>>2]=E,c[n+8>>2]=K,c[n+16>>2]=x,c[n+24>>2]=v,c[n+32>>2]=D,c[n+40>>2]=r,n)|0);i=n;yDb(N,48,1963032,(n=i,i=i+24|0,c[n>>2]=C,c[n+8>>2]=G,c[n+16>>2]=I,n)|0);i=n;if(f>>>0>2>>>0){yDb(N,16,1934888,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if((q|0)==0|p>>>0>32>>>0){yDb(N,16,1911744,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if((u|0)!=0){DDb(N,1891264,(n=i,i=i+8|0,c[n>>2]=r,n)|0);i=n;k=-1163346256;i=g;return k|0}if(v>>>0>1>>>0){yDb(N,16,2348672,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(z>>>0>1>>>0){yDb(N,16,2328520,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(!((y|0)==32|(y|0)==16|(y|0)==8)){yDb(N,16,2304208,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(!((A|0)==32|(A|0)==16|(A|0)==8)){yDb(N,16,2286320,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if((B|0)==0|x>>>0>32>>>0){yDb(N,16,2270312,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(K>>>0>256>>>0){yDb(N,16,2254992,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}y=hDb(c[s>>2]|0,c[t>>2]|0,0,0)|0;if((y|0)<0){k=y;i=g;return k|0}y=(A-1+(ba(c[s>>2]|0,x)|0)&-A)>>>3;if(D>>>0<y>>>0){yDb(N,16,2240704,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}A=K*12|0;if((j-m|0)>>>0<((ba(c[t>>2]|0,D)|0)+A|0)>>>0){yDb(N,16,2228640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if((o|0)!=33554432){EDb(N,2216824,(n=i,i=i+8|0,c[n>>2]=f,n)|0);i=n;k=-1163346256;i=g;return k|0}f=a+140|0;c[f>>2]=-1;a:do{switch(E|0){case 2:case 3:{if((B|0)!=134217728){O=60;break a}c[f>>2]=11;P=M;break};case 4:case 5:{if(!((x|0)==32|(x|0)==24|(x|0)==16)){k=-1094995529;i=g;return k|0}o=(B|0)==268435456;do{if(o&(q|0)==251658240){s=(H|0)==-536674304;if((F|0)==8126464&s&(J|0)==520093696){c[f>>2]=(w|0)!=0?45:46;break}if(!((F|0)==520093696&s&(J|0)==8126464)){O=60;break a}c[f>>2]=(w|0)!=0?49:50}else{if(o&(q|0)==268435456){s=(H|0)==-536412160;if((F|0)==16252928&s&(J|0)==520093696){c[f>>2]=(w|0)!=0?43:44;break}if(!((F|0)==520093696&s&(J|0)==16252928)){O=60;break a}c[f>>2]=(w|0)!=0?47:48;break}if((x|0)==24){s=(H|0)==16711680;if((F|0)==65280&s&(J|0)==-16777216){c[f>>2]=(w|0)!=0?2:3;break}if(!((F|0)==-16777216&s&(J|0)==65280)){O=60;break a}c[f>>2]=(w|0)!=0?3:2;break}else if((x|0)==32){s=(H|0)==16711680;if((F|0)==65280&s&(J|0)==-16777216){c[f>>2]=(w|0)!=0?27:30;break}if(!((F|0)==-16777216&s&(J|0)==65280)){O=60;break a}c[f>>2]=(w|0)!=0?29:28;break}else{O=60;break a}}}while(0);P=l+(A+m)|0;break};case 0:case 1:{if(!((x|0)==8|(x|0)==1)){k=-1094995529;i=g;return k|0}if((p|0)==8){c[f>>2]=8;P=M;break a}else if((p|0)==1){c[f>>2]=9;P=M;break a}else{O=60;break a}break};default:{yDb(N,16,2207432,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}}}while(0);if((O|0)==60){DDb(N,2199248,(n=i,i=i+24|0,c[n>>2]=x,c[n+8>>2]=p,c[n+16>>2]=E,n)|0);i=n;k=-1163346256;i=g;return k|0}n=_$a(a,h,0)|0;if((n|0)<0){k=n;i=g;return k|0}c[b+84>>2]=1;c[b+88>>2]=1;do{if((c[f>>2]|0)==11){n=c[b+4>>2]|0;if((L|0)==0){Q=P;break}h=K>>>0>1>>>0?K*12|0:12;a=P;E=0;while(1){c[n+(E<<2)>>2]=(d[a+6|0]|0)<<8|(d[a+4|0]|0)<<16|(d[a+8|0]|0);p=E+1|0;if(p>>>0<K>>>0){a=a+12|0;E=p}else{break}}Q=P+h|0}else{Q=P}}while(0);if((c[t>>2]|0)>0){P=b+32|0;K=Q;Q=c[b>>2]|0;b=0;while(1){UGb(Q|0,K|0,y)|0;L=b+1|0;if((L|0)<(c[t>>2]|0)){K=K+D|0;Q=Q+(c[P>>2]|0)|0;b=L}else{break}}}c[e>>2]=1;k=j;i=g;return k|0}function Kdb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;g=i;h=c[b+140>>2]|0;j=bFb(h)|0;k=$Eb(j)|0;l=a[j+7|0]&1;switch(h|0){case 11:case 21:case 22:case 19:case 24:{m=k;n=8;o=8;p=256;q=3;r=l;s=0;t=0;u=0;v=0;break};case 8:{m=k;n=8;o=8;p=0;q=0;r=l;s=0;t=0;u=0;v=0;break};case 46:case 45:case 50:case 49:{j=(h-49|0)>>>0<2>>>0;m=k;n=16;o=16;p=0;q=4;r=l;s=j?31744:31;t=0;u=j?31:31744;v=992;break};case 2:{m=k;n=24;o=32;p=0;q=4;r=1;s=255;t=0;u=16711680;v=65280;break};case 9:{m=k;n=1;o=8;p=0;q=0;r=1;s=0;t=1;u=0;v=0;break};case 28:case 30:{w=l;y=3;break};case 3:{m=k;n=24;o=32;p=0;q=4;r=l;s=255;t=0;u=16711680;v=65280;break};case 44:case 43:case 48:case 47:{j=(h-47|0)>>>0<2>>>0;m=k;n=16;o=16;p=0;q=4;r=l;s=j?63488:31;t=0;u=j?31:63488;v=2016;break};case 29:case 27:{w=1;y=3;break};default:{yDb(b,16,2177760,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;z=-22;i=g;return z|0}}if((y|0)==3){y=(h-28|0)>>>0<2>>>0;m=24;n=32;o=32;p=0;q=4;r=w;s=y?16711680:255;t=0;u=y?255:16711680;v=65280}y=b+120|0;w=(o-1+(ba(c[y>>2]|0,n)|0)&-o)>>>3;h=p*12|0;j=b+124|0;l=(ba(w,c[j>>2]|0)|0)+(h|111)|0;k=r0a(b,d,l,(l|0)<0|0?-1:0)|0;if((k|0)<0){z=k;i=g;return z|0}k=c[d+24>>2]|0;c[e+84>>2]=1;c[e+88>>2]=1;l=k;x=1862270976;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+4|0;x=117440512;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+8|0;x=33554432;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+12|0;x=fe(m|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+16|0;x=fe(c[y>>2]|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+20|0;x=fe(c[j>>2]|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+24|0;x=0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+28|0;x=fe(r|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+32|0;x=536870912;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+36|0;x=fe(t|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+40|0;x=fe(o|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+44|0;x=fe(n|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+48|0;x=fe(w|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+52|0;x=fe(q|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+56|0;x=fe(u|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+60|0;x=fe(v|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+64|0;x=fe(s|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=k+68|0;x=134217728;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=fe(p|0)|0;s=k+72|0;x=l;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=k+76|0;x=l;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=k+80|0;x=fe(c[y>>2]|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=k+84|0;x=fe(c[j>>2]|0)|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=k+88|0;x=0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=k+92|0;x=0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=k+96|0;x=0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;UGb(k+100|0,2101552,11)|0;s=k+111|0;if((p|0)==0){A=s}else{y=e+4|0;l=h|111;h=s;s=0;while(1){v=c[(c[y>>2]|0)+(s<<2)>>2]|0;u=h;x=fe(s|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;u=h+4|0;x=de(v>>>16<<8&65535|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;u=h+6|0;x=de(v&65535&-256|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;u=h+8|0;x=de(v<<8&65535|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;a[h+10|0]=7;a[h+11|0]=0;u=s+1|0;if(u>>>0<p>>>0){h=h+12|0;s=u}else{break}}A=k+l|0}if((c[j>>2]|0)>0){l=e+32|0;k=A;A=0;s=c[e>>2]|0;while(1){UGb(k|0,s|0,w)|0;e=A+1|0;if((e|0)<(c[j>>2]|0)){k=k+w|0;A=e;s=s+(c[l>>2]|0)|0}else{break}}}l=d+36|0;c[l>>2]=c[l>>2]|1;c[f>>2]=1;z=0;i=g;return z|0}function Ldb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a+60|0;e=c[d>>2]|0;c[e>>2]=a;c[a+140>>2]=0;f=c[a+124>>2]|0;if((f|0)<8){yDb(a,16,2328488,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-22;i=b;return h|0}j=c[a+120>>2]|0;if((j&1|0)!=0){yDb(a,16,2304176,(g=i,i=i+8|0,c[g>>2]=j,g)|0);i=g;h=-22;i=b;return h|0}g=ba(j,f)|0;f=e+16|0;c[f>>2]=g;j=WDb(g)|0;c[e+8>>2]=j;if((j|0)==0){h=-12;i=b;return h|0}j=WDb((c[f>>2]|0)+130|0)|0;c[e+12>>2]=j;if((j|0)==0){j=c[d>>2]|0;JCb(j+4|0);$Db(j+8|0);$Db(j+12|0);h=-12;i=b;return h|0}j=ICb()|0;c[e+4>>2]=j;if((j|0)!=0){h=0;i=b;return h|0}j=c[d>>2]|0;JCb(j+4|0);$Db(j+8|0);$Db(j+12|0);h=-12;i=b;return h|0}function Mdb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;h=i;j=b+60|0;k=c[j>>2]|0;l=k+4|0;m=$$a(b,c[l>>2]|0)|0;if((m|0)<0){n=m;i=h;return n|0}m=c[g+24>>2]|0;o=g+28|0;g=c[o>>2]|0;if(!((g|0)>-1)){yDb(0,0,1911712,(p=i,i=i+24|0,c[p>>2]=1891248,c[p+8>>2]=2348648,c[p+16>>2]=135,p)|0);i=p;Cd();return 0}q=k+20|0;c[q>>2]=m;c[k+28>>2]=m;c[k+24>>2]=m+g;do{if((g|0)<4){r=6}else{c[q>>2]=m+4;k=m;s=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;if((s|0)==0){r=6;break}else if((s|0)!=1){yDb(b,16,2177736,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;n=-1094995529;i=h;return n|0}s=c[j>>2]|0;k=c[s+12>>2]|0;t=s+24|0;u=s+20|0;v=c[u>>2]|0;if(((c[t>>2]|0)-v|0)<4){w=0}else{c[u>>2]=v+4;x=v;w=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0}x=Odb(b,w)|0;if((x|0)!=0){n=x;i=h;return n|0}x=c[s+28>>2]|0;v=(c[t>>2]|0)-x|0;c[u>>2]=x+((v|0)<16?v:16);v=Pdb(s,k,c[s+16>>2]>>1)|0;if((v|0)!=0){yDb(b,16,2101528,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=v;i=h;return n|0}v=s+8|0;x=b+124|0;if((c[x>>2]|0)<=0){break}u=b+120|0;t=c[v>>2]|0;y=k;k=0;while(1){z=((d[y]|0)<<1)+(d[t]|0)&63;A=z&255;a[t]=A;B=y+1|0;if(((c[u>>2]|0)-1|0)>1){C=z;z=1;D=B;while(1){E=t+(z+1)|0;F=((d[D]|0)<<1)+(d[E]|0)&63;a[t+z|0]=(F+C|0)>>>1;G=F&255;a[E]=G;E=z+2|0;H=D+1|0;if((E|0)<((c[u>>2]|0)-1|0)){C=F;z=E;D=H}else{I=G;J=E;K=H;break}}}else{I=A;J=1;K=B}a[t+J|0]=I;L=c[u>>2]|0;D=k+1|0;M=c[x>>2]|0;if((D|0)<(M|0)){t=t+L|0;y=K;k=D}else{break}}k=s+4|0;if((M|0)<=0){break}y=c[k>>2]|0;t=c[y>>2]|0;D=c[v>>2]|0;z=0;C=L;H=y;y=M;while(1){if((C|0)>0){E=0;do{G=a[D+E|0]|0;a[t+E|0]=G<<2|(G&255)>>>3;E=E+1|0;N=c[u>>2]|0;}while((E|0)<(N|0));O=N;P=c[k>>2]|0;Q=c[x>>2]|0}else{O=C;P=H;Q=y}E=z+1|0;if((E|0)<(Q|0)){t=t+(c[P+32>>2]|0)|0;D=D+O|0;z=E;C=O;H=P;y=Q}else{break}}}}while(0);do{if((r|0)==6){Q=c[j>>2]|0;P=Q;O=Q+12|0;N=c[O>>2]|0;M=Q+24|0;L=Q+20|0;K=c[L>>2]|0;I=c[M>>2]|0;if((I-K|0)<4){R=0;S=K}else{J=K+4|0;c[L>>2]=J;w=K;R=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;S=J}if((I-S|0)<4){T=0}else{c[L>>2]=S+4;I=S;T=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0}I=Odb(b,R)|0;if((I|0)!=0){n=I;i=h;return n|0}I=c[M>>2]|0;J=Q+28|0;w=c[J>>2]|0;if(T>>>0<(I-w|0)>>>0){U=T;V=I;W=w}else{yDb(b,24,1934840,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;U=0;V=c[M>>2]|0;W=c[J>>2]|0}w=V-W|0;c[L>>2]=W+((w|0)<12?w:12);w=Q+16|0;I=Pdb(P,N,c[w>>2]>>1)|0;if((I|0)!=0){yDb(b,16,2101528,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=I;i=h;return n|0}I=Q+8|0;K=c[I>>2]|0;m=a[N]|0;q=m&255;a[K]=m<<1;m=N+1|0;N=b+120|0;if(((c[N>>2]|0)-1|0)>1){g=q;y=1;H=m;while(1){C=(d[H]|0)+g&31;a[K+y|0]=C+g;a[K+(y+1)|0]=C<<1;z=y+2|0;D=H+1|0;if((z|0)<((c[N>>2]|0)-1|0)){g=C;y=z;H=D}else{X=C;Y=z;Z=D;break}}}else{X=q;Y=1;Z=m}a[K+Y|0]=X<<1;H=b+124|0;y=c[H>>2]|0;if((y|0)>1){g=K+(c[N>>2]|0)|0;D=K;z=Z;C=1;while(1){t=((d[D]|0)>>>1)+(d[z]|0)&31;a[g]=t<<1;x=z+1|0;if(((c[N>>2]|0)-1|0)>1){k=t;u=1;v=x;while(1){s=u+1|0;E=((d[D+s|0]|0)>>>1)+(d[v]|0)&31;a[g+u|0]=E+k;a[g+s|0]=E<<1;s=u+2|0;B=v+1|0;if((s|0)<((c[N>>2]|0)-1|0)){k=E;u=s;v=B}else{_=E;$=s;aa=B;break}}}else{_=t;$=1;aa=x}a[g+$|0]=_<<1;v=C+1|0;u=c[H>>2]|0;if((v|0)<(u|0)){D=g;g=g+(c[N>>2]|0)|0;z=aa;C=v}else{ba=u;break}}}else{ba=y}if((U|0)==0){ca=ba}else{C=U+8|0;z=c[J>>2]|0;g=(c[M>>2]|0)-z|0;if((C|0)<0){da=0}else{da=(g|0)<(C|0)?g:C}c[L>>2]=z+da;z=Qdb(P,c[O>>2]|0,(c[w>>2]|0)/2|0)|0;do{if((z|0)>=0){C=((c[w>>2]|0)/2|0)-1|0;g=(z|0)>(C|0)?C:z;if((g|0)>0){ea=0}else{break}do{C=(c[I>>2]|0)+(ea<<1|1)|0;a[C]=(a[(c[O>>2]|0)+ea|0]<<1)+(a[C]|0)&63;ea=ea+1|0;}while((ea|0)<(g|0))}}while(0);ca=c[H>>2]|0}O=Q+4|0;if((ca|0)<=0){break}z=c[O>>2]|0;w=c[z>>2]|0;P=c[I>>2]|0;L=0;M=c[N>>2]|0;J=z;z=ca;while(1){if((M|0)>0){y=0;do{g=a[P+y|0]|0;a[w+y|0]=g<<2|(g&255)>>>3;y=y+1|0;fa=c[N>>2]|0;}while((y|0)<(fa|0));ga=fa;ha=c[O>>2]|0;ia=c[H>>2]|0}else{ga=M;ha=J;ia=z}y=L+1|0;if((y|0)<(ia|0)){w=w+(c[ha+32>>2]|0)|0;P=P+ga|0;L=y;M=ga;J=ha;z=ia}else{break}}}}while(0);ia=MCb(e,c[l>>2]|0)|0;if((ia|0)<0){n=ia;i=h;return n|0}c[f>>2]=1;n=c[o>>2]|0;i=h;return n|0}function Ndb(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+4|0);$Db(b+8|0);$Db(b+12|0);return 0}function Odb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;f=i;g=c[b+60>>2]|0;if((e|0)==0){h=0;i=f;return h|0}j=e+4|0;e=g+20|0;k=c[g+24>>2]|0;if(!(j>>>0<(k-(c[e>>2]|0)|0)>>>0)){yDb(b,16,2045528,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;h=-1094995529;i=f;return h|0}m=c[g+28>>2]|0;n=k-m|0;if((j|0)<0){o=0}else{o=(n|0)<(j|0)?n:j}j=m+o|0;c[e>>2]=j;if((k-j|0)<2){p=0;q=j}else{n=m+(o+2)|0;c[e>>2]=n;o=j;p=(d[o]|d[o+1|0]<<8)<<16>>16&65535;q=n}if((k-q|0)<2){r=0;s=q}else{n=q+2|0;c[e>>2]=n;o=q;r=(d[o]|d[o+1|0]<<8)<<16>>16&65535;s=n}n=r<<1;o=r+1|0;if(!(n>>>0<(k-s|0)>>>0)){yDb(b,16,1999888,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;h=-1094995529;i=f;return h|0}c[e>>2]=s+n;n=g+12|0;s=g+16|0;TGb(c[n>>2]|0,0,c[s>>2]|0)|0;e=Qdb(g,c[n>>2]|0,c[s>>2]|0)|0;if((e|0)<0){yDb(b,16,1963e3,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;h=e;i=f;return h|0}l=g+4|0;g=c[l>>2]|0;s=c[g+4>>2]|0;k=c[g+8>>2]|0;r=c[n>>2]|0;n=r+e|0;e=b+124|0;j=c[e>>2]|0;if((p|0)==0){p=j>>2;a:do{if((p|0)>0){m=b+120|0;t=n;u=0;v=r;w=k;x=s;y=s+(c[g+36>>2]|0)|0;z=k+(c[g+40>>2]|0)|0;A=c[m>>2]|0;B=g;C=j;b:while(1){if((A>>1|0)>0){D=0;E=v;F=A;while(1){if((t-E|0)<1){h=0;G=39;break b}H=E+1|0;I=a[E]|0;J=I&255;if(I<<24>>24==0){K=F}else{if(!(J>>>0<o>>>0)){h=-1094995529;G=39;break b}I=q+(J<<1)|0;J=(d[I]|d[I+1|0]<<8)<<16>>16&65535;I=J>>>3&248;L=(I>>>5|I)&255;I=D|1;a[y+I|0]=L;a[y+D|0]=L;a[x+I|0]=L;a[x+D|0]=L;L=(J>>>8&248|J>>>13)&255;a[z+I|0]=L;a[z+D|0]=L;a[w+I|0]=L;a[w+D|0]=L;K=c[m>>2]|0}L=D+2|0;if((L|0)<(K>>1|0)){D=L;E=H;F=K}else{break}}M=H;N=K;O=c[l>>2]|0;P=c[e>>2]|0}else{M=v;N=A;O=B;P=C}F=c[O+36>>2]<<1;E=x+F|0;D=c[O+40>>2]<<1;L=w+D|0;I=u+1|0;J=P>>2;if((I|0)<(J|0)){u=I;v=M;w=L;x=E;y=y+F|0;z=z+D|0;A=N;B=O;C=P}else{Q=L;R=E;S=P;T=J;U=O;break a}}if((G|0)==39){i=f;return h|0}}else{Q=k;R=s;S=j;T=p;U=g}}while(0);if((S&3|0)==0){h=0;i=f;return h|0}p=(S+1>>1)-(T<<1)|0;T=ba(c[U+36>>2]|0,p)|0;UGb(R|0,R+(-T|0)|0,T)|0;T=ba(c[(c[l>>2]|0)+40>>2]|0,p)|0;UGb(Q|0,Q+(-T|0)|0,T)|0;h=0;i=f;return h|0}else{c:do{if((j>>1|0)>0){T=b+120|0;Q=n;p=0;R=r;U=k;S=s;O=c[T>>2]|0;P=g;N=j;d:while(1){if((O>>1|0)>0){M=0;K=R;H=O;while(1){if((Q-K|0)<1){h=0;G=39;break d}V=K+1|0;C=a[K]|0;B=C&255;if(C<<24>>24==0){W=H}else{if(!(B>>>0<o>>>0)){h=-1094995529;G=39;break d}C=q+(B<<1)|0;B=(d[C]|d[C+1|0]<<8)<<16>>16&65535;C=B>>>3&248;a[S+M|0]=C>>>5|C;a[U+M|0]=B>>>8&248|B>>>13;W=c[T>>2]|0}B=M+1|0;if((B|0)<(W>>1|0)){M=B;K=V;H=W}else{break}}X=V;Y=W;Z=c[l>>2]|0;_=c[e>>2]|0}else{X=R;Y=O;Z=P;_=N}H=S+(c[Z+36>>2]|0)|0;K=U+(c[Z+40>>2]|0)|0;M=p+1|0;if((M|0)<(_>>1|0)){p=M;R=X;U=K;S=H;O=Y;P=Z;N=_}else{$=K;aa=H;ca=_;da=Z;break c}}if((G|0)==39){i=f;return h|0}}else{$=k;aa=s;ca=j;da=g}}while(0);if((ca&1|0)==0){h=0;i=f;return h|0}ca=b+120|0;UGb(aa|0,aa+(-(c[da+36>>2]|0)|0)|0,c[ca>>2]>>1)|0;UGb($|0,$+(-(c[(c[l>>2]|0)+40>>2]|0)|0)|0,c[ca>>2]>>1)|0;h=0;i=f;return h|0}return 0}function Pdb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=e+f|0;f=c[b+20>>2]|0;h=b+24|0;i=c[b+28>>2]|0;j=f;k=i;l=b+20|0;b=c[h>>2]|0;if((b-j|0)<1){m=0;n=f}else{o=f+1|0;c[l>>2]=o;m=d[f]|0;n=o}if((b-n|0)<1){p=0;q=n}else{o=n+1|0;c[l>>2]=o;p=d[n]|0;q=o}o=p+m|0;n=m<<1;m=b-q|0;f=m>>>0>n>>>0?n:m;m=q+f|0;c[l>>2]=m;if((b-m|0)<1){r=0}else{c[l>>2]=q+(f+1);r=d[m]|0}m=j-k-(p<<1)|0;j=b-k|0;k=e;e=r;r=o;a:while(1){f=k;q=128;n=r;while(1){s=q>>1;t=m+(n<<1)+((e&q|0)!=0)|0;if((t|0)<0){u=0}else{u=(j|0)<(t|0)?j:t}t=i+u|0;if((b-t|0)<1){v=0}else{v=d[t]|0}if((v|0)==(p|0)){w=f;x=19;break a}if(v>>>0<p>>>0){t=f+1|0;a[f]=v;if(t>>>0>g>>>0){w=t;x=19;break a}else{y=t;z=o}}else{y=f;z=v}if((s|0)==0){break}else{f=y;q=s;n=z}}n=c[l>>2]|0;if((c[h>>2]|0)==(n|0)){w=y;x=19;break}c[l>>2]=n+1;k=y;e=d[n]|0;r=z}if((x|0)==19){return((w|0)!=(g|0)?-1094995529:0)|0}return 0}function Qdb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=e+f|0;a:do{if((f|0)>0){h=b+20|0;i=b+24|0;j=e;k=g;l=e;while(1){m=c[h>>2]|0;n=c[i>>2]|0;if((n|0)==(m|0)){o=-1094995529;p=30;break}q=m+1|0;c[h>>2]=q;r=a[m]|0;s=r&255;if((r&255)>>>0<224>>>0){do{if((s&128|0)==0){if((n-q|0)<1){t=0;u=q}else{v=m+2|0;c[h>>2]=v;t=d[q]|0;u=v}w=t|s<<3&768;x=(s>>>2&7)+3|0;y=s&3;z=u}else{if((s&64|0)==0){v=n-q|0;do{if((v|0)<1){A=0;B=q;C=0}else{D=(d[q]|0)>>>6;if((v|0)<2){A=0;B=q;C=D;break}E=m+3|0;c[h>>2]=E;F=q;A=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&16383;B=E;C=D}}while(0);w=A;x=(s&63)+4|0;y=C;z=B;break}v=s&3;D=n;if((D-q|0)<2){G=0;H=q}else{E=m+3|0;c[h>>2]=E;F=q;G=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;H=E}if((D-H|0)<1){I=0;J=H}else{D=H+1|0;c[h>>2]=D;I=d[H]|0;J=D}D=(I|s<<6&768)+5|0;if((D+v|0)>(k-l|0)){K=l;L=j;break a}else{w=G|s<<12&65536;x=D;y=v;z=J}}}while(0);m=w+1|0;v=l+(x+y)|0;if(v>>>0>g>>>0){o=-1094995529;p=30;break}if((l-j+y|0)<(m|0)){o=-1094995529;p=30;break}D=n-z|0;E=D>>>0>y>>>0?y:D;UGb(l|0,z|0,E)|0;c[h>>2]=(c[h>>2]|0)+E;iEb(l+y|0,m,x);M=v}else{v=(r&255)>>>0>251>>>0;if(v){N=s&3}else{N=(s<<2&124)+4|0}if((k-l|0)<(N|0)){o=-1094995529;p=30;break}m=n-q|0;E=m>>>0>N>>>0?N:m;UGb(l|0,q|0,E)|0;c[h>>2]=(c[h>>2]|0)+E;E=l+N|0;if(v){K=E;L=j;break a}else{M=E}}if(M>>>0<g>>>0){l=M}else{K=M;L=j;break a}}if((p|0)==30){return o|0}}else{K=e;L=e}}while(0);o=K-L|0;return o|0}function Rdb(a){a=a|0;var b=0;b=i;c[a+140>>2]=7;c[a+796>>2]=12;if((c[a+120>>2]&7|0)==0){i=b;return 0}yDb(a,24,2101480,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function Sdb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=b+124|0;k=b+120|0;if(+(c[j>>2]|0)<+(c[f>>2]|0)*1.5*+(c[k>>2]|0)){yDb(b,16,2177704,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=g;return m|0}l=_$a(b,d,0)|0;if((l|0)<0){m=l;i=g;return m|0}c[d+84>>2]=1;c[d+88>>2]=1;l=c[f>>2]|0;if((l|0)>0){f=d+32|0;b=d;n=d+36|0;o=d+4|0;p=d+40|0;q=d+8|0;d=h;h=l;l=c[k>>2]|0;while(1){r=h-1|0;if((l|0)>0){s=ba(c[p>>2]|0,r)|0;t=ba(c[n>>2]|0,r)|0;u=d;v=(c[b>>2]|0)+(ba(c[f>>2]|0,r)|0)|0;w=(c[o>>2]|0)+t|0;t=(c[q>>2]|0)+s|0;s=0;while(1){a[w]=a[u]|0;a[v]=a[u+1|0]|0;a[t]=a[u+2|0]|0;a[v+1|0]=a[u+3|0]|0;a[w+1|0]=a[u+4|0]|0;a[v+2|0]=a[u+5|0]|0;a[t+1|0]=a[u+6|0]|0;a[v+3|0]=a[u+7|0]|0;a[v+4|0]=a[u+8|0]|0;a[v+5|0]=a[u+9|0]|0;a[v+6|0]=a[u+10|0]|0;x=u+12|0;a[v+7|0]=a[u+11|0]|0;y=s+8|0;z=c[k>>2]|0;if((y|0)<(z|0)){u=x;v=v+8|0;w=w+2|0;t=t+2|0;s=y}else{A=x;B=z;break}}}else{A=d;B=l}if((r|0)>0){d=A;h=r;l=B}else{break}}}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function Tdb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[a+120>>2]&7|0)!=0){yDb(a,16,2177656,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-1094995529;i=b;return e|0}f=ICb()|0;c[a+804>>2]=f;c[a+792>>2]=12;if((f|0)!=0){e=0;i=b;return e|0}yDb(a,16,2101448,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-12;i=b;return e|0}function Udb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0.0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=b+120|0;h=b+124|0;i=+(ba(c[h>>2]|0,c[g>>2]|0)|0)*1.5;j=r0a(b,d,~~+i>>>0,(E=+i,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0))|0;if((j|0)<0){k=j;return k|0}j=c[b+804>>2]|0;c[j+84>>2]=1;c[j+88>>2]=1;j=c[h>>2]|0;if((j|0)>0){h=e+32|0;b=e|0;l=e+36|0;m=e+4|0;n=e+40|0;o=e+8|0;e=c[d+24>>2]|0;p=j;j=c[g>>2]|0;while(1){q=p-1|0;if((j|0)>0){r=ba(c[n>>2]|0,q)|0;s=ba(c[l>>2]|0,q)|0;t=e;u=(c[b>>2]|0)+(ba(c[h>>2]|0,q)|0)|0;v=(c[m>>2]|0)+s|0;s=(c[o>>2]|0)+r|0;r=0;while(1){a[t]=a[v]|0;a[t+1|0]=a[u]|0;a[t+2|0]=a[s]|0;a[t+3|0]=a[u+1|0]|0;a[t+4|0]=a[v+1|0]|0;a[t+5|0]=a[u+2|0]|0;a[t+6|0]=a[s+1|0]|0;a[t+7|0]=a[u+3|0]|0;a[t+8|0]=a[u+4|0]|0;a[t+9|0]=a[u+5|0]|0;a[t+10|0]=a[u+6|0]|0;w=t+12|0;a[t+11|0]=a[u+7|0]|0;x=r+8|0;y=c[g>>2]|0;if((x|0)<(y|0)){t=w;u=u+8|0;v=v+2|0;s=s+2|0;r=x}else{z=w;A=y;break}}}else{z=e;A=j}if((q|0)>0){e=z;p=q;j=A}else{break}}}A=d+36|0;c[A>>2]=c[A>>2]|1;c[f>>2]=1;k=0;return k|0}function Vdb(a){a=a|0;$Db(a+804|0);return 0}function Wdb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=c[a+120>>2]|0;do{if((f&1|0)==0){g=c[a+124>>2]|0;if((g&1|0)!=0){break}h=a;if((hDb(f,g,0,h)|0)<0){break}if((c[a+100>>2]|0)<3){yDb(h,16,1962960,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}c[a+140>>2]=11;g=c[a+96>>2]|0;l=d[g]|0;c[e+8>>2]=l;m=d[g+1|0]|0;c[e+12>>2]=m;n=d[g+2|0]|0;c[e+16>>2]=n;do{if((m+l|0)<=256){if((l+n|0)>256){break}g=ICb()|0;c[e+4>>2]=g;k=(g|0)==0?-12:0;i=b;return k|0}}while(0);yDb(h,16,1934784,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}}while(0);yDb(a,16,1999856,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}function Xdb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;j=c[b+60>>2]|0;k=j+4|0;l=c[k>>2]|0;m=g+28|0;n=j+8|0;if((c[m>>2]|0)<(((c[n>>2]|0)*3|0)+4|0)){yDb(b,16,2177632,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}q=$$a(b,l)|0;if((q|0)<0){p=q;i=h;return p|0}if((c[b+428>>2]|0)==0){TGb(c[l+4>>2]|0,0,1024)|0}q=l|0;r=j+40|0;c[r>>2]=c[q>>2];s=c[q>>2]|0;q=j+36|0;c[q>>2]=s;t=g+24|0;g=(c[t>>2]|0)+4|0;u=j+28|0;c[u>>2]=g;v=j+32|0;c[v>>2]=(c[t>>2]|0)+(c[m>>2]|0);w=j+24|0;c[w>>2]=0;x=a[c[t>>2]|0]|0;y=x&255;if((x&255)>>>0>1>>>0){yDb(b,16,2101424,(o=i,i=i+8|0,c[o>>2]=y,o)|0);i=o;p=-1094995529;i=h;return p|0}x=c[j+12+(y<<2)>>2]|0;y=c[l+4>>2]|0;if((c[n>>2]|0)>0){z=0;A=g;do{g=d[A+1|0]<<10|d[A]<<18|d[A+2|0]<<2;c[y+(z+x<<2)>>2]=g|g>>>6&197379|-16777216;z=z+1|0;A=A+3|0;c[u>>2]=A;}while((z|0)<(c[n>>2]|0))}c[l+304>>2]=1;n=b+124|0;z=c[n>>2]|0;a:do{if((z|0)>0){A=b+120|0;x=l+32|0;y=0;g=c[A>>2]|0;B=s;C=z;b:while(1){if((g|0)>0){D=2;E=B;while(1){F=c[u>>2]|0;if((F-(c[t>>2]|0)|0)>=(c[m>>2]|0)){G=14;break b}H=c[w>>2]|0;if((H|0)==0){I=F+1|0;c[u>>2]=I;c[w>>2]=F;J=(d[F]|0)>>>4;K=F;L=I}else{I=a[H]&15;c[w>>2]=0;J=I;K=0;L=F}if(J<<24>>24==15){if((K|0)==0){c[u>>2]=L+1;c[w>>2]=L;M=(d[L]|0)>>>4}else{F=a[K]&15;c[w>>2]=0;M=F}F=M&255;I=c[x>>2]|0;H=(ba(a[676481+(F<<1)|0]|0,I)|0)+(a[676480+(F<<1)|0]|0)|0;F=E+H|0;if(F>>>0<(c[r>>2]|0)>>>0){G=26;break b}a[E]=a[F]|0;a[(c[q>>2]|0)+1|0]=a[E+(H+1)|0]|0;a[(c[q>>2]|0)+I|0]=a[E+(H+I)|0]|0;F=I+1|0;a[(c[q>>2]|0)+F|0]=a[E+(H+F)|0]|0}else{F=J&255;H=c[x>>2]|0;I=d[593467+(F<<2)|0]|0;if(((c[v>>2]|0)-L|0)<(I|0)){G=20;break b}a[E]=a[L]|0;a[(c[q>>2]|0)+1|0]=a[(c[u>>2]|0)+(d[593464+(F<<2)|0]|0)|0]|0;a[(c[q>>2]|0)+H|0]=a[(c[u>>2]|0)+(d[593465+(F<<2)|0]|0)|0]|0;a[(c[q>>2]|0)+(H+1)|0]=a[(c[u>>2]|0)+(d[593466+(F<<2)|0]|0)|0]|0;c[u>>2]=(c[u>>2]|0)+I}N=(c[q>>2]|0)+2|0;c[q>>2]=N;O=c[A>>2]|0;if((D|0)>=(O|0)){break}D=D+2|0;E=N}P=D;Q=O;R=N;S=c[n>>2]|0}else{P=0;Q=g;R=B;S=C}E=R+((c[x>>2]<<1)-P)|0;c[q>>2]=E;I=y+2|0;if((I|0)<(S|0)){y=I;g=Q;B=E;C=S}else{break a}}if((G|0)==14){yDb(b,16,2177632,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}else if((G|0)==20){yDb(c[j>>2]|0,16,2177632,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}else if((G|0)==26){yDb(c[j>>2]|0,16,2045496,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}}}while(0);o=MCb(e,c[k>>2]|0)|0;if((o|0)<0){p=o;i=h;return p|0}c[f>>2]=1;p=c[m>>2]|0;i=h;return p|0}function Ydb(a){a=a|0;JCb((c[a+60>>2]|0)+4|0);return 0}function Zdb(a){a=a|0;c[a+140>>2]=0;return 0}function _db(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=b+120|0;k=b+124|0;if((c[j>>2]|0)<(ba(((c[f>>2]|0)+1>>1)*6|0,(c[k>>2]|0)+1>>1)|0)){yDb(b,16,2177600,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=g;return m|0}l=_$a(b,d,0)|0;if((l|0)<0){m=l;i=g;return m|0}c[d+84>>2]=1;c[d+88>>2]=1;l=c[k>>2]|0;if((l+1>>1|0)>0){b=d+32|0;n=d+36|0;o=d+40|0;p=h;h=c[d>>2]|0;q=c[d+4>>2]|0;r=c[d+8>>2]|0;d=0;s=c[f>>2]|0;t=l;while(1){if((s+1>>1|0)>0){l=p;u=0;while(1){a[q+u|0]=a[l]^-128;a[r+u|0]=a[l+1|0]^-128;v=u<<1;a[h+v|0]=a[l+2|0]|0;w=v|1;a[h+w|0]=a[l+3|0]|0;a[h+((c[b>>2]|0)+v)|0]=a[l+4|0]|0;x=l+6|0;a[h+(w+(c[b>>2]|0))|0]=a[l+5|0]|0;w=u+1|0;y=c[f>>2]|0;if((w|0)<(y+1>>1|0)){l=x;u=w}else{break}}z=x;A=y;B=c[k>>2]|0}else{z=p;A=s;B=t}u=d+1|0;if((u|0)<(B+1>>1|0)){p=z;h=h+(c[b>>2]<<1)|0;q=q+(c[n>>2]|0)|0;r=r+(c[o>>2]|0)|0;d=u;s=A;t=B}else{break}}}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function $db(a){a=a|0;var b=0,d=0,e=0;b=i;d=ICb()|0;c[a+804>>2]=d;if((d|0)!=0){e=0;i=b;return e|0}yDb(a,16,2177568,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-12;i=b;return e|0}function aeb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=b+120|0;h=b+124|0;i=ba(((c[g>>2]|0)+1>>1)*6|0,(c[h>>2]|0)+1>>1)|0;j=r0a(b,d,i,(i|0)<0|0?-1:0)|0;if((j|0)<0){k=j;return k|0}j=c[d+24>>2]|0;i=c[b+804>>2]|0;c[i+84>>2]=1;c[i+88>>2]=1;i=c[h>>2]|0;if((i+1>>1|0)>0){b=e+32|0;l=e+36|0;m=e+40|0;n=j;j=c[e>>2]|0;o=c[e+4>>2]|0;p=c[e+8>>2]|0;e=0;q=c[g>>2]|0;r=i;while(1){if((q+1>>1|0)>0){i=n;s=0;while(1){a[i]=a[o+s|0]^-128;a[i+1|0]=a[p+s|0]^-128;t=s<<1;a[i+2|0]=a[j+t|0]|0;u=t|1;a[i+3|0]=a[j+u|0]|0;a[i+4|0]=a[j+((c[b>>2]|0)+t)|0]|0;v=i+6|0;a[i+5|0]=a[j+(u+(c[b>>2]|0))|0]|0;u=s+1|0;w=c[g>>2]|0;if((u|0)<(w+1>>1|0)){i=v;s=u}else{break}}x=v;y=w;z=c[h>>2]|0}else{x=n;y=q;z=r}s=e+1|0;if((s|0)<(z+1>>1|0)){n=x;j=j+(c[b>>2]<<1)|0;o=o+(c[l>>2]|0)|0;p=p+(c[m>>2]|0)|0;e=s;q=y;r=z}else{break}}}z=d+36|0;c[z>>2]=c[z>>2]|1;c[f>>2]=1;k=0;return k|0}function beb(a){a=a|0;$Db(a+804|0);return 0}function ceb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a+60|0;e=c[d>>2]|0;c[a+140>>2]=17;c[a+796>>2]=8;c[e+36>>2]=0;c[e+40>>2]=0;c[e+44>>2]=0;f=Qd(e+4|0,1999848,56)|0;if((f|0)!=0){yDb(a,16,1962920,(a=i,i=i+8|0,c[a>>2]=f,a)|0);i=a;g=-12;i=b;return g|0}a=ICb()|0;c[e>>2]=a;if((a|0)!=0){g=0;i=b;return g|0}a=c[d>>2]|0;JCb(a);he(a+4|0)|0;g=-12;i=b;return g|0}function deb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;h=c[b+60>>2]|0;j=d;k=h;l=c[k>>2]|0;m=h+4|0;n=m;o=c[l>>2]|0;p=f+36|0;do{if((c[p>>2]&1|0)==0){if((o|0)!=0){q=o+(ba((c[b+124>>2]|0)-1|0,c[l+32>>2]|0)|0)|0;c[d+84>>2]=0;c[d+88>>2]=2;r=q;break}yDb(b,16,2177528,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=g;return t|0}else{c[d+84>>2]=1;c[d+88>>2]=1;r=o}}while(0);o=bc(n|0)|0;if((o|0)!=0){yDb(b,16,2101392,(s=i,i=i+8|0,c[s>>2]=o,s)|0);i=s;t=-1094995529;i=g;return t|0}o=_$a(b,j,1)|0;if((o|0)<0){t=o;i=g;return t|0}c[m>>2]=c[f+24>>2];m=f+28|0;c[h+8>>2]=c[m>>2];f=b+124|0;o=c[f>>2]|0;q=d+32|0;a:do{if((o|0)>0){u=ba(o-1|0,c[q>>2]|0)|0;v=h+16|0;w=b+120|0;x=h+20|0;y=l+32|0;z=r;A=(c[d>>2]|0)+u|0;u=1;while(1){c[v>>2]=A;c[x>>2]=c[w>>2]<<1;B=$c(n|0,2)|0;if(B>>>0>1>>>0){break}do{if((c[p>>2]&1|0)==0){if((c[w>>2]<<1|0)>0){C=0}else{break}do{D=A+C|0;E=a[D]|0;a[D]=(a[z+C|0]&(-(E<<24>>24==0|0)&255))+E;C=C+1|0;}while((C|0)<(c[w>>2]<<1|0))}}while(0);if((u|0)>=(c[f>>2]|0)){break a}z=z+(-(c[y>>2]|0)|0)|0;A=A+(-(c[q>>2]|0)|0)|0;u=u+1|0}yDb(b,16,2045456,(s=i,i=i+8|0,c[s>>2]=B,s)|0);i=s;t=-1094995529;i=g;return t|0}}while(0);KCb(c[k>>2]|0);s=MCb(c[k>>2]|0,j)|0;if((s|0)<0){t=s;i=g;return t|0}c[e>>2]=1;t=c[m>>2]|0;i=g;return t|0}function eeb(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b);he(b+4|0)|0;return 0}function feb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;e=a+120|0;c[d+792>>2]=c[e>>2];f=a+124|0;c[d+796>>2]=c[f>>2];c[d+4>>2]=c[a+792>>2];g=d+836|0;h=g;TGb(g|0,0,56)|0;g=ba((c[e>>2]<<2)+1020|0,(c[f>>2]|0)+64|0)|0;c[d+8>>2]=g;do{if((g|0)!=0){f=cEb(g)|0;c[d+12>>2]=f;if((f|0)!=0){break}yDb(a,16,2286216,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-12;i=b;return k|0}}while(0);c[d+868>>2]=0;c[d+872>>2]=0;c[d+876>>2]=0;d=Qd(h|0,2270304,56)|0;if((d|0)==0){k=0;i=b;return k|0}yDb(a,16,2254968,(j=i,i=i+8|0,c[j>>2]=d,j)|0);i=j;k=-1313558101;i=b;return k|0}function geb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;j=e;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=g;n=d[k]|0;o=g+808|0;c[o>>2]=n;p=k+1|0;a:do{if((n&1|0)==0){if((c[g+892>>2]|0)!=0){q=l-1|0;r=p;break}yDb(b,16,1911672,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else{u=g+892|0;c[u>>2]=0;v=a[p]|0;w=v&255;y=a[k+2|0]|0;z=y&255;A=d[k+3|0]|0;B=g+804|0;c[B>>2]=A;C=d[k+4|0]|0;D=g+800|0;c[D>>2]=C;E=d[k+5|0]|0;F=g+816|0;c[F>>2]=E;G=d[k+6|0]|0;H=g+820|0;c[H>>2]=G;c[u>>2]=0;I=g+896|0;c[I>>2]=0;J=k+7|0;K=l-7|0;L=b;yDb(L,48,2177480,(s=i,i=i+56|0,c[s>>2]=n,c[s+8>>2]=w,c[s+16>>2]=z,c[s+24>>2]=A,c[s+32>>2]=C,c[s+40>>2]=E,c[s+48>>2]=G,s)|0);i=s;if(!(v<<24>>24==0&y<<24>>24==1)){DDb(L,2101368,(s=i,i=i+16|0,c[s>>2]=w,c[s+8>>2]=z,s)|0);i=s;t=-1163346256;i=h;return t|0}z=c[F>>2]|0;w=c[H>>2]|0;do{if((z|0)==0){M=w}else{if((w|0)==0){M=0;break}y=c[B>>2]|0;if(!(y>>>0<2>>>0)){DDb(L,1999824,(s=i,i=i+8|0,c[s>>2]=y,s)|0);i=s;t=-1163346256;i=h;return t|0}y=c[D>>2]|0;if((y|0)==5|(y|0)==6){c[g+4>>2]=16;c[I>>2]=2462;c[b+140>>2]=(y|0)==5?46:44;c[g+812>>2]=c[g+792>>2]<<1}else if((y|0)==4){c[g+4>>2]=8;c[I>>2]=2108;c[b+140>>2]=11;c[g+812>>2]=c[g+792>>2]}else if((y|0)==8){c[g+4>>2]=32;c[I>>2]=2320;c[b+140>>2]=298;c[g+812>>2]=c[g+792>>2]<<2}else{c[I>>2]=0;DDb(L,1962904,(s=i,i=i+8|0,c[s>>2]=y,s)|0);i=s;t=-1163346256;i=h;return t|0}y=bc(g+836|0)|0;if((y|0)!=0){yDb(L,16,1934752,(s=i,i=i+8|0,c[s>>2]=y,s)|0);i=s;t=-1313558101;i=h;return t|0}y=g+788|0;v=b+120|0;G=b+124|0;E=ba(c[G>>2]|0,c[v>>2]|0)|0;C=g+4|0;c[y>>2]=YDb(c[y>>2]|0,E,(c[C>>2]|0)/8|0)|0;E=g+784|0;A=ba(c[G>>2]|0,c[v>>2]|0)|0;N=YDb(c[E>>2]|0,A,(c[C>>2]|0)/8|0)|0;c[E>>2]=N;A=c[F>>2]|0;c[g+824>>2]=((c[g+792>>2]|0)-1+A|0)/(A|0)|0;A=c[H>>2]|0;c[g+828>>2]=((c[g+796>>2]|0)-1+A|0)/(A|0)|0;A=c[y>>2]|0;if((A|0)==0|(N|0)==0){t=-12;i=h;return t|0}else{N=ba(c[G>>2]|0,c[v>>2]|0)|0;TGb(A|0,0,ba(N,(c[C>>2]|0)/8|0)|0)|0;N=ba(c[G>>2]|0,c[v>>2]|0)|0;TGb(c[E>>2]|0,0,ba(N,(c[C>>2]|0)/8|0)|0)|0;c[u>>2]=1314;q=K;r=J;break a}}}while(0);DDb(L,2045432,(s=i,i=i+16|0,c[s>>2]=z,c[s+8>>2]=M,s)|0);i=s;t=-1163346256;i=h;return t|0}}while(0);M=g+892|0;n=_$a(b,j,0)|0;if((n|0)<0){t=n;i=h;return t|0}do{if((c[g+804>>2]|0)==0){if(!((c[g+8>>2]|0)>>>0<q>>>0)){UGb(c[g+12>>2]|0,r|0,q)|0;break}yDb(b,16,1891224,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else{n=g+836|0;j=g+856|0;c[j>>2]=0;c[g+844>>2]=0;c[n>>2]=r;c[g+840>>2]=q;c[g+848>>2]=c[g+12>>2];c[g+852>>2]=c[g+8>>2];k=$c(n|0,2)|0;if(!(k>>>0>1>>>0)){c[g+832>>2]=c[j>>2];break}yDb(b,16,2348624,(s=i,i=i+8|0,c[s>>2]=k,s)|0);i=s;t=-1094995529;i=h;return t|0}}while(0);q=e+84|0;do{if((c[o>>2]&1|0)==0){c[q>>2]=0;c[e+88>>2]=2;if((c[g+832>>2]|0)==0){break}re[c[g+896>>2]&4095](m)|0}else{c[q>>2]=1;c[e+88>>2]=1;re[c[M>>2]&4095](m)|0}}while(0);m=c[e>>2]|0;M=g+788|0;q=c[M>>2]|0;o=c[g+800>>2]|0;if((o|0)==4){r=e+4|0;k=0;while(1){j=k*3|0;n=(c[r>>2]|0)+(k<<2)|0;x=(d[g+(j+16)|0]|0)<<16|(d[g+(j+17)|0]|0)<<8|(d[g+(j+18)|0]|0)|-16777216;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+1|0;if((n|0)<256){k=n}else{O=35;break}}}else if((o|0)==5|(o|0)==6|(o|0)==8){O=35}else{yDb(b,16,2328456,(s=i,i=i+8|0,c[s>>2]=o,s)|0);i=s}if((O|0)==35){O=c[g+812>>2]|0;iDb(m,c[e+32>>2]|0,q,O,O,c[g+796>>2]|0)}O=g+784|0;g=c[O>>2]|0;c[O>>2]=c[M>>2];c[M>>2]=g;c[f>>2]=1;t=l;i=h;return t|0}function heb(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+12|0);he(b+836|0)|0;$Db(b+788|0);$Db(b+784|0);return 0}function ieb(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((c[a+800>>2]|0)==4){UGb(a+16|0,b|0,768)|0;d=b+768|0}else{d=b}b=ba(c[a+796>>2]|0,c[a+792>>2]|0)|0;UGb(c[a+788>>2]|0,d|0,ba(b,(c[a+4>>2]|0)/8|0)|0)|0;return 0}function jeb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;e=b+12|0;f=c[e>>2]|0;g=c[b+788>>2]|0;h=c[b+784>>2]|0;if((c[b+808>>2]&2|0)==0){j=f}else{k=0;l=f;while(1){m=b+16+k|0;a[m]=a[m]^a[l];m=k+1|0;if((m|0)<768){k=m;l=l+1|0}else{break}}j=f+768|0}f=j+((ba(c[b+824>>2]<<1,c[b+828>>2]|0)|0)+3&-4)|0;l=b+796|0;k=c[l>>2]|0;if((k|0)>0){m=b+820|0;n=b+792|0;o=b+816|0;p=0;q=h;h=0;r=g;g=f;s=k;k=c[m>>2]|0;t=c[n>>2]|0;while(1){u=s-p|0;v=(u|0)>(k|0)?k:u;if((t|0)>0){u=(v|0)>0;w=0;x=h;y=g;z=t;A=c[o>>2]|0;while(1){B=a[j+x|0]|0;C=B&1;D=a[j+(x+1)|0]>>1;E=x+2|0;F=z-w|0;G=(F|0)>(A|0)?A:F;F=r+w|0;H=(B>>1)+w|0;B=D+p|0;a:do{if(u){I=q+(H+(ba(D,z)|0))|0;if((G|0)>0){J=0;K=F;L=I}else{I=0;M=F;N=z;while(1){O=B+I|0;if((O|0)<0){P=21}else{if((O|0)<(c[l>>2]|0)){Q=N}else{P=21}}if((P|0)==21){P=0;TGb(M|0,0,G|0)|0;Q=c[n>>2]|0}O=I+1|0;if((O|0)<(v|0)){I=O;M=M+Q|0;N=Q}else{R=Q;break a}}}while(1){N=B+J|0;do{if((N|0)<0){P=17}else{if((N|0)<(c[l>>2]|0)){S=0}else{P=17;break}do{M=H+S|0;do{if((M|0)<0){P=15}else{if((M|0)>=(c[n>>2]|0)){P=15;break}a[K+S|0]=a[L+S|0]|0}}while(0);if((P|0)==15){P=0;a[K+S|0]=0}S=S+1|0;}while((S|0)<(G|0))}}while(0);if((P|0)==17){P=0;TGb(K|0,0,G|0)|0}N=c[n>>2]|0;M=J+1|0;if((M|0)<(v|0)){J=M;K=K+N|0;L=L+N|0}else{R=N;break}}}else{R=z}}while(0);if(u&(C|0)!=0&(G|0)>0){H=w-1-z|0;B=~A;D=(H|0)>(B|0)?H:B;B=0;H=y;N=F;while(1){M=0;I=H;while(1){O=N+M|0;a[O]=a[O]^a[I];O=M+1|0;if((O|0)<(G|0)){M=O;I=I+1|0}else{break}}I=H+~D|0;M=c[n>>2]|0;O=B+1|0;if((O|0)<(v|0)){B=O;H=I;N=N+M|0}else{T=I;U=M;break}}}else{T=y;U=R}N=c[o>>2]|0;H=N+w|0;if((H|0)<(U|0)){w=H;x=E;y=T;z=U;A=N}else{break}}V=E;W=T;X=U;Y=c[m>>2]|0;Z=c[l>>2]|0}else{V=h;W=g;X=t;Y=k;Z=s}A=ba(Y,X)|0;z=Y+p|0;if((z|0)<(Z|0)){p=z;q=q+A|0;h=V;r=r+A|0;g=W;s=Z;k=Y;t=X}else{_=W;break}}}else{_=f}f=_-(c[e>>2]|0)|0;e=c[b+832>>2]|0;if((f|0)==(e|0)){i=d;return 0}yDb(c[b>>2]|0,16,2304152,(b=i,i=i+16|0,c[b>>2]=f,c[b+8>>2]=e,b)|0);i=b;i=d;return 0}function keb(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;e=i;f=d+12|0;g=c[f>>2]|0;h=g+((ba(c[d+824>>2]<<1,c[d+828>>2]|0)|0)+3&-4)|0;j=d+796|0;k=c[j>>2]|0;if((k|0)>0){l=d+820|0;m=d+792|0;n=d+816|0;o=0;p=c[d+784>>2]|0;q=0;r=c[d+788>>2]|0;s=h;t=k;k=c[l>>2]|0;u=c[m>>2]|0;while(1){v=t-o|0;w=(v|0)>(k|0)?k:v;if((u|0)>0){v=(w|0)>0;x=0;y=q;z=s;A=u;B=c[n>>2]|0;while(1){C=a[g+y|0]|0;D=C&1;E=a[g+(y+1)|0]>>1;F=y+2|0;G=A-x|0;H=(G|0)>(B|0)?B:G;G=r+(x<<1)|0;I=(C>>1)+x|0;C=E+o|0;a:do{if(v){J=p+(I+(ba(E,A)|0)<<1)|0;K=H<<1;if((H|0)>0){L=0;M=G;N=J;O=A;P=A}else{J=0;Q=G;R=A;while(1){S=C+J|0;if((S|0)<0){T=17}else{if((S|0)<(c[j>>2]|0)){U=R}else{T=17}}if((T|0)==17){T=0;TGb(Q|0,0,K|0)|0;U=c[m>>2]|0}S=J+1|0;if((S|0)<(w|0)){J=S;Q=Q+(U<<1)|0;R=U}else{V=U;break a}}}while(1){R=C+L|0;do{if((R|0)<0){T=13}else{if((R|0)<(c[j>>2]|0)){W=0}else{T=13;break}while(1){Q=I+W|0;if((Q|0)>-1&(Q|0)<(O|0)){b[M+(W<<1)>>1]=b[N+(W<<1)>>1]|0}else{b[M+(W<<1)>>1]=0}Q=W+1|0;if((Q|0)<(H|0)){W=Q}else{X=O;Y=P;break}}}}while(0);if((T|0)==13){T=0;TGb(M|0,0,K|0)|0;R=c[m>>2]|0;X=R;Y=R}R=L+1|0;if((R|0)<(w|0)){L=R;M=M+(X<<1)|0;N=N+(X<<1)|0;O=X;P=Y}else{V=Y;break}}}else{V=A}}while(0);if((D|0)==0|v^1){Z=z}else{I=(H|0)>0;C=x-1-A|0;E=~B;K=((C|0)>(E|0)?C:E)*-2|0;E=0;C=z;R=G;while(1){if(I){Q=0;J=C;while(1){S=R+(Q<<1)|0;b[S>>1]=b[S>>1]^b[J>>1];S=Q+1|0;if((S|0)<(H|0)){Q=S;J=J+2|0}else{break}}_=C+(K-2)|0}else{_=C}J=E+1|0;if((J|0)<(w|0)){E=J;C=_;R=R+(V<<1)|0}else{Z=_;break}}}R=c[n>>2]|0;C=R+x|0;if((C|0)<(V|0)){x=C;y=F;z=Z;A=V;B=R}else{break}}$=F;aa=Z;ca=V;da=c[j>>2]|0;ea=c[l>>2]|0}else{$=q;aa=s;ca=u;da=t;ea=k}B=ba(ea,ca)|0;A=ea+o|0;if((A|0)<(da|0)){o=A;p=p+(B<<1)|0;q=$;r=r+(B<<1)|0;s=aa;t=da;k=ea;u=ca}else{break}}fa=aa;ga=c[f>>2]|0}else{fa=h;ga=g}g=fa-ga|0;ga=c[d+832>>2]|0;if((g|0)==(ga|0)){i=e;return 0}yDb(c[d>>2]|0,16,2304152,(d=i,i=i+16|0,c[d>>2]=g,c[d+8>>2]=ga,d)|0);i=d;i=e;return 0}function leb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;d=i;e=b+12|0;f=c[e>>2]|0;g=f+((ba(c[b+824>>2]<<1,c[b+828>>2]|0)|0)+3&-4)|0;h=b+796|0;j=c[h>>2]|0;if((j|0)>0){k=b+820|0;l=b+792|0;m=b+816|0;n=0;o=c[b+784>>2]|0;p=0;q=c[b+788>>2]|0;r=g;s=j;j=c[k>>2]|0;t=c[l>>2]|0;while(1){u=s-n|0;v=(u|0)>(j|0)?j:u;if((t|0)>0){u=(v|0)>0;w=0;x=p;y=r;z=t;A=c[m>>2]|0;while(1){B=a[f+x|0]|0;C=B&1;D=a[f+(x+1)|0]>>1;E=x+2|0;F=z-w|0;G=(F|0)>(A|0)?A:F;F=q+(w<<2)|0;H=(B>>1)+w|0;B=D+n|0;if(u){I=G<<2;J=(G|0)>0;K=0;L=F;M=o+(H+(ba(D,z)|0)<<2)|0;while(1){D=B+K|0;do{if((D|0)<0){N=10}else{if((D|0)>=(c[h>>2]|0)){N=10;break}if(J){O=0}else{break}do{P=H+O|0;do{if((P|0)<0){N=13}else{if((P|0)>=(c[l>>2]|0)){N=13;break}c[L+(O<<2)>>2]=c[M+(O<<2)>>2]}}while(0);if((N|0)==13){N=0;c[L+(O<<2)>>2]=0}O=O+1|0;}while((O|0)<(G|0))}}while(0);if((N|0)==10){N=0;TGb(L|0,0,I|0)|0}D=c[l>>2]|0;P=K+1|0;if((P|0)<(v|0)){K=P;L=L+(D<<2)|0;M=M+(D<<2)|0}else{Q=D;break}}}else{Q=z}if((C|0)==0|u^1){R=y;S=Q}else{M=(G|0)>0;L=w-1-z|0;K=~A;I=((L|0)>(K|0)?L:K)*-4|0;K=0;L=y;H=F;J=Q;while(1){if(M){B=0;D=L;while(1){P=H+(B<<2)|0;c[P>>2]=c[P>>2]^c[D>>2];P=B+1|0;if((P|0)<(G|0)){B=P;D=D+4|0}else{break}}T=L+(I-4)|0;U=c[l>>2]|0}else{T=L;U=J}D=K+1|0;if((D|0)<(v|0)){K=D;L=T;H=H+(U<<2)|0;J=U}else{R=T;S=U;break}}}J=c[m>>2]|0;H=J+w|0;if((H|0)<(S|0)){w=H;x=E;y=R;z=S;A=J}else{break}}V=E;W=R;X=S;Y=c[k>>2]|0;Z=c[h>>2]|0}else{V=p;W=r;X=t;Y=j;Z=s}A=ba(Y,X)|0;z=Y+n|0;if((z|0)<(Z|0)){n=z;o=o+(A<<2)|0;p=V;q=q+(A<<2)|0;r=W;s=Z;j=Y;t=X}else{break}}_=W;$=c[e>>2]|0}else{_=g;$=f}f=_-$|0;$=c[b+832>>2]|0;if((f|0)==($|0)){i=d;return 0}yDb(c[b>>2]|0,16,2304152,(b=i,i=i+16|0,c[b>>2]=f,c[b+8>>2]=$,b)|0);i=b;i=d;return 0}function meb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a+60|0;e=c[d>>2]|0;f=1;do{c[4311512+(f<<2)>>2]=~~(+(-f|0)*+$(+(f|0)*.00390625)*369.3299304675746);f=f+1|0;}while((f|0)<256);c[e>>2]=a;c[e+1824>>2]=0;c[e+1820>>2]=c[a+360>>2];f=e+4|0;c[f>>2]=8;g=c[a+276>>2]|0;if((g|0)>0){c[f>>2]=(g|0)>127?127:g}g=c[a+84>>2]|0;f=(g|0)>-1?g:9;if(f>>>0>9>>>0){yDb(a,16,2101320,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;j=-22;i=b;return j|0}g=e+1828|0;TGb(g|0,0,56)|0;k=a+120|0;l=c[k>>2]|0;m=a+124|0;n=c[m>>2]|0;o=(ba(n,l)|0)+1028+(ba(((l+15|0)/16|0)<<1,(n+15|0)/16|0)|0)|0;n=e+1816|0;c[n>>2]=o;l=WDb(o)|0;c[e+12>>2]=l;if((l|0)==0){yDb(a,16,2045368,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-12;i=b;return j|0}l=c[n>>2]|0;o=l+11+(l+7>>3)+(l+63>>6)|0;c[n>>2]=o;n=WDb(o)|0;c[e+8>>2]=n;if((n|0)==0){yDb(a,16,1999776,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-12;i=b;return j|0}n=(c[k>>2]|0)+15&-16;c[e+1812>>2]=n;k=WDb(ba(n,c[m>>2]|0)|0)|0;c[e+1808>>2]=k;if((k|0)==0){yDb(a,16,1962872,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-12;i=b;return j|0}c[e+1860>>2]=0;c[e+1864>>2]=0;c[e+1868>>2]=0;e=Sb(g|0,f|0,1934744,56)|0;if((e|0)!=0){yDb(a,16,1911648,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;j=-1;i=b;return j|0}h=ICb()|0;e=a+804|0;c[e>>2]=h;if((h|0)!=0){j=0;i=b;return j|0}h=c[d>>2]|0;$Db(h+8|0);$Db(h+12|0);Zc(h+1828|0)|0;$Db(h+1808|0);JCb(e);j=-12;i=b;return j|0}function neb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0;h=i;i=i+256|0;j=h|0;k=c[b+60>>2]|0;l=k+1824|0;m=c[l>>2]|0;n=(m|0)==0;o=n&1;p=m+1|0;c[l>>2]=p;if((p|0)==(c[k+1820>>2]|0)){c[l>>2]=0}l=c[b+804>>2]|0;c[l+88>>2]=n?1:2;c[l+84>>2]=o;l=f+4|0;p=c[l>>2]|0;do{if(n){m=p;q=f|0;r=c[q>>2]|0;s=k+1808|0;t=0;do{u=m+(t<<2)|0;v=t*3|0;a[k+(v+18)|0]=c[u>>2];a[k+(v+17)|0]=(c[u>>2]|0)>>>8;a[k+(v+16)|0]=(c[u>>2]|0)>>>16;t=t+1|0;}while((t|0)<256);t=k+12|0;UGb(c[t>>2]|0,k+16|0,768)|0;UGb(k+784|0,c[l>>2]|0,1024)|0;m=b+124|0;if((c[m>>2]|0)<=0){w=0;x=768;break}u=b+120|0;v=f+32|0;y=0;z=768;A=r;B=c[u>>2]|0;while(1){UGb((c[t>>2]|0)+z|0,A|0,B)|0;C=c[u>>2]|0;D=C+z|0;E=y+1|0;F=c[m>>2]|0;if((E|0)<(F|0)){y=E;z=D;A=A+(c[v>>2]|0)|0;B=C}else{G=D;H=s;I=q;J=0;K=F;L=59;break}}}else{q=k+784|0;s=(PGb(p,q,1024)|0)==0;B=p;v=f|0;A=c[v>>2]|0;z=k+1808|0;y=c[z>>2]|0;m=k+12|0;if(s){M=0;N=0}else{s=0;u=0;while(1){t=c[B+(s<<2)>>2]|0;r=t>>>8;F=t>>>16;D=s*3|0;C=k+(D+16)|0;a[(c[m>>2]|0)+u|0]=(d[C]|0)^F;E=k+(D+17)|0;a[(c[m>>2]|0)+(u+1)|0]=(d[E]|0)^r;O=k+(D+18)|0;a[(c[m>>2]|0)+(u+2)|0]=(d[O]|0)^t;a[C]=F;a[E]=r;a[O]=t;t=s+1|0;if((t|0)<256){s=t;u=u+3|0}else{break}}UGb(q|0,c[l>>2]|0,1024)|0;M=1;N=768}u=b+120|0;s=b+124|0;B=(c[m>>2]|0)+N|0;t=(ba((((c[u>>2]|0)+15|0)/16|0)<<1,((c[s>>2]|0)+15|0)/16|0)|0)+3&-4;TGb(B|0,0,t|0)|0;O=t+N|0;t=c[s>>2]|0;if((t|0)<=0){w=M;x=O;break}r=f+32|0;E=k+1812|0;F=k;C=j|0;D=k+4|0;P=O;O=y;Q=0;R=A;S=B;B=t;t=c[u>>2]|0;while(1){T=B-Q|0;U=(T|0)>16?16:T;if((t|0)>0){T=P;V=0;W=S;X=t;Y=-1;while(1){Z=X-V|0;_=(Z|0)>16?16:Z;Z=R+V|0;$=c[r>>2]|0;aa=c[E>>2]|0;ca=c[F>>2]|0;da=c[ca+120>>2]|0;ea=da-V|0;fa=(ea|0)<16?ea:16;ea=c[ca+124>>2]|0;ca=ea-Q|0;ga=(ca|0)<16?ca:16;TGb(C|0,0,256)|0;ca=(ga|0)>0&(fa|0)>0;if(ca){ha=O+V|0;ia=0;ja=Z;ka=0;while(1){la=0;ma=ka;do{na=(a[ha+la|0]^a[ja+la|0])&255;oa=j+na|0;a[oa]=(a[oa]|0)+1;ma=na|ma;la=la+1|0;}while((la|0)<(fa|0));la=ia+1|0;if((la|0)<(ga|0)){ha=ha+aa|0;ia=la;ja=ja+$|0;ka=ma}else{pa=ma;break}}}else{pa=0}ka=0;ja=1;do{ka=(c[4311512+((d[j+ja|0]|0)<<2)>>2]|0)+ka|0;ja=ja+1|0;}while((ja|0)<256);a:do{if((ka|0)==0){qa=0;ra=0;sa=pa}else{ja=c[D>>2]|0;ia=Q-ja|0;ha=(ia|0)>0?ia:0;ia=ja+Q|0;la=ea-ga|0;if((ha|0)<(((ia|0)>(la|0)?la:ia)|0)){ta=ha;ua=ka;va=0;wa=0;xa=pa}else{qa=0;ra=0;sa=pa;break}while(1){ha=V-ja|0;ia=(ha|0)>0?ha:0;ha=ja+V|0;na=da-fa|0;b:do{if((ia|0)<(((ha|0)>(na|0)?na:ha)|0)){oa=ta-Q|0;ya=ba(oa,aa)|0;if((ta|0)==(Q|0)){za=ua;Aa=ia;Ba=va;Ca=wa;Da=xa}else{Ea=ua;Fa=ia;Ga=va;Ha=wa;while(1){Ia=Fa-V|0;TGb(C|0,0,256)|0;if(ca){Ja=O+(Fa+ya)|0;Ka=0;La=Z;Ma=0;while(1){Na=0;Oa=Ma;do{Pa=(a[Ja+Na|0]^a[La+Na|0])&255;Qa=j+Pa|0;a[Qa]=(a[Qa]|0)+1;Oa=Pa|Oa;Na=Na+1|0;}while((Na|0)<(fa|0));Na=Ka+1|0;if((Na|0)<(ga|0)){Ja=Ja+aa|0;Ka=Na;La=La+$|0;Ma=Oa}else{Ra=Oa;break}}}else{Ra=0}Ma=0;La=1;do{Ma=(c[4311512+((d[j+La|0]|0)<<2)>>2]|0)+Ma|0;La=La+1|0;}while((La|0)<256);if((Ma|0)<(Ea|0)){if((Ma|0)==0){qa=oa;ra=Ia;sa=Ra;break a}else{Sa=Ma;Ta=oa;Ua=Ia}}else{Sa=Ea;Ta=Ga;Ua=Ha}La=Fa+1|0;Ka=ja+V|0;Ja=da-fa|0;if((La|0)<(((Ka|0)>(Ja|0)?Ja:Ka)|0)){Ea=Sa;Fa=La;Ga=Ta;Ha=Ua}else{Va=Sa;Wa=Ta;Xa=Ua;Ya=Ra;break b}}}while(1){do{if((Aa|0)==(V|0)){Za=za;_a=Ba;$a=Ca;ab=Da}else{Ha=Aa-V|0;TGb(C|0,0,256)|0;if(ca){Ga=O+(Aa+ya)|0;Fa=0;Ea=Z;La=0;while(1){Ka=0;Ja=La;do{Na=(a[Ga+Ka|0]^a[Ea+Ka|0])&255;Pa=j+Na|0;a[Pa]=(a[Pa]|0)+1;Ja=Na|Ja;Ka=Ka+1|0;}while((Ka|0)<(fa|0));Ka=Fa+1|0;if((Ka|0)<(ga|0)){Ga=Ga+aa|0;Fa=Ka;Ea=Ea+$|0;La=Ja}else{bb=Ja;break}}}else{bb=0}La=0;Ea=1;do{La=(c[4311512+((d[j+Ea|0]|0)<<2)>>2]|0)+La|0;Ea=Ea+1|0;}while((Ea|0)<256);if((La|0)>=(za|0)){Za=za;_a=Ba;$a=Ca;ab=bb;break}if((La|0)==0){qa=oa;ra=Ha;sa=bb;break a}else{Za=La;_a=oa;$a=Ha;ab=bb}}}while(0);Ia=Aa+1|0;Ma=ja+V|0;Ea=da-fa|0;if((Ia|0)<(((Ma|0)>(Ea|0)?Ea:Ma)|0)){za=Za;Aa=Ia;Ba=_a;Ca=$a;Da=ab}else{Va=Za;Wa=_a;Xa=$a;Ya=ab;break}}}else{Va=ua;Wa=va;Xa=wa;Ya=xa}}while(0);ia=ta+1|0;ha=ja+Q|0;if((ia|0)<(((ha|0)>(la|0)?la:ha)|0)){ta=ia;ua=Va;va=Wa;wa=Xa;xa=Ya}else{qa=Wa;ra=Xa;sa=Ya;break}}}}while(0);a[W]=ra<<1|(sa|0)!=0;a[W+1|0]=qa<<1;if((sa|0)==0|(U|0)<1){cb=T}else{fa=c[E>>2]|0;da=O+(ra+V+(ba(fa,qa)|0))|0;$=(_|0)>0;aa=Y-X|0;ga=(aa|0)>-17?~aa:16;aa=0;ca=T;ka=Z;ea=da;da=fa;while(1){if($){fa=0;la=ca;while(1){a[(c[m>>2]|0)+la|0]=a[ea+fa|0]^a[ka+fa|0];ja=fa+1|0;if((ja|0)<(_|0)){fa=ja;la=la+1|0}else{break}}db=ga+ca|0;eb=c[E>>2]|0}else{db=ca;eb=da}la=aa+1|0;if((la|0)<(U|0)){aa=la;ca=db;ka=ka+(c[r>>2]|0)|0;ea=ea+eb|0;da=eb}else{cb=db;break}}}da=V+16|0;fb=W+2|0;gb=c[u>>2]|0;if((da|0)>=(gb|0)){break}T=cb;V=da;W=fb;X=gb;Y=Y+16|0}hb=cb;ib=fb;jb=gb;kb=c[s>>2]|0}else{hb=P;ib=S;jb=t;kb=B}Y=Q+16|0;if((Y|0)<(kb|0)){P=hb;O=O+(c[E>>2]<<4)|0;Q=Y;R=R+(c[r>>2]<<4)|0;S=ib;B=kb;t=jb}else{G=hb;H=z;I=v;J=M;K=kb;L=59;break}}}}while(0);c:do{if((L|0)==59){kb=b+124|0;if((K|0)<=0){w=J;x=G;break}M=b+120|0;hb=k+1812|0;jb=f+32|0;ib=1;gb=c[H>>2]|0;fb=c[I>>2]|0;while(1){UGb(gb|0,fb|0,c[M>>2]|0)|0;if((ib|0)>=(c[kb>>2]|0)){w=J;x=G;break c}ib=ib+1|0;gb=gb+(c[hb>>2]|0)|0;fb=fb+(c[jb>>2]|0)|0}}}while(0);G=k+1828|0;J=G;if(n){bd(J|0)|0}c[G>>2]=c[k+12>>2];c[k+1832>>2]=x;c[k+1836>>2]=0;x=k+8|0;c[k+1840>>2]=c[x>>2];c[k+1844>>2]=c[k+1816>>2];G=k+1848|0;c[G>>2]=0;if((Yd(J|0,2)|0)!=0){yDb(b,16,2177456,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;lb=-1;i=h;return lb|0}J=(-o&6|1)+(c[G>>2]|0)|0;k=r0a(b,e,J,(J|0)<0|0?-1:0)|0;if((k|0)<0){lb=k;i=h;return lb|0}k=c[e+24>>2]|0;J=k+1|0;a[k]=(w?2:0)|n&1;if(n){a[J]=0;a[k+2|0]=1;a[k+3|0]=1;a[k+4|0]=4;a[k+5|0]=16;a[k+6|0]=16;mb=k+7|0}else{mb=J}UGb(mb|0,c[x>>2]|0,c[G>>2]|0)|0;G=e+36|0;c[G>>2]=c[G>>2]|o;c[g>>2]=1;lb=0;i=h;return lb|0}function oeb(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+8|0);$Db(b+12|0);Zc(b+1828|0)|0;$Db(b+1808|0);JCb(a+804|0);return 0}function peb(a){a=a|0;var b=0;b=i;c[a+140>>2]=56;c[a+796>>2]=10;if((c[a+52>>2]|0)!=1983000929){i=b;return 0}DDb(a,2045352,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function qeb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;j=c[a+120>>2]|0;k=e;l=g+24|0;m=c[l>>2]|0;n=j<<3;o=(n|0)/3|0;if((j|0)==1){yDb(a,16,2177432,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}r=c[g+28>>2]|0;s=c[a+124>>2]|0;do{if((c[a+52>>2]|0)==1983000880){if(((r|0)%(s|0)|0|0)!=0){t=o;break}u=(r|0)/(s|0)|0;t=(u*3|0|0)<(n|0)?o:u}else{t=o}}while(0);o=g+28|0;g=ba(s,t)|0;if((r|0)<(g|0)){yDb(a,16,2101280,(p=i,i=i+16|0,c[p>>2]=r,c[p+8>>2]=g,p)|0);i=p;q=-1094995529;i=h;return q|0}p=_$a(a,k,0)|0;if((p|0)<0){q=p;i=h;return q|0}c[e+88>>2]=1;c[e+84>>2]=1;p=c[e>>2]|0;k=c[e+4>>2]|0;g=c[e+8>>2]|0;r=(c[l>>2]|0)+t|0;l=g;s=k;n=p;u=c[a+124>>2]|0;if((u|0)>0){a=e+32|0;v=e+36|0;w=e+40|0;if((j&1|0)==0){j=r;e=m;x=l;y=s;z=n;A=1;while(1){B=j-1|0;C=j-2|0;D=e;E=x;F=y;G=z;while(1){H=D;I=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=D+4|0;b[F>>1]=I<<6;J=G+2|0;b[G>>1]=I>>>4&65535&-64;b[E>>1]=I>>>14&65535&-64;if(!(H>>>0<B>>>0)){K=13;break}I=H;H=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;I=D+8|0;b[J>>1]=H<<6;b[F+2>>1]=H>>>4&65535&-64;L=G+6|0;b[G+4>>1]=H>>>14&65535&-64;if(!(I>>>0<C>>>0)){K=15;break}H=I;I=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=D+12|0;b[E+2>>1]=I<<6;M=G+8|0;b[L>>1]=I>>>4&65535&-64;b[F+4>>1]=I>>>14&65535&-64;if(!(H>>>0<B>>>0)){K=17;break}I=H;H=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;N=D+16|0;b[M>>1]=H<<6;b[E+4>>1]=H>>>4&65535&-64;b[G+10>>1]=H>>>14&65535&-64;if(N>>>0<C>>>0){D=N;E=E+6|0;F=F+6|0;G=G+12|0}else{K=19;break}}if((K|0)==13){K=0;b[J>>1]=128;G=p+(ba(c[a>>2]|0,A)|0)|0;F=k+(ba(c[v>>2]|0,A)|0)|0;O=D+5|0;P=g+(ba(c[w>>2]|0,A)|0)|0;Q=F;R=G}else if((K|0)==15){K=0;b[L>>1]=128;G=p+(ba(c[a>>2]|0,A)|0)|0;F=k+(ba(c[v>>2]|0,A)|0)|0;O=D+10|0;P=g+(ba(c[w>>2]|0,A)|0)|0;Q=F;R=G}else if((K|0)==17){K=0;b[M>>1]=128;G=p+(ba(c[a>>2]|0,A)|0)|0;F=k+(ba(c[v>>2]|0,A)|0)|0;O=D+13|0;P=g+(ba(c[w>>2]|0,A)|0)|0;Q=F;R=G}else if((K|0)==19){K=0;G=p+(ba(c[a>>2]|0,A)|0)|0;F=k+(ba(c[v>>2]|0,A)|0)|0;O=N;P=g+(ba(c[w>>2]|0,A)|0)|0;Q=F;R=G}if((A|0)<(u|0)){j=j+t|0;e=O;x=P;y=Q;z=R;A=A+1|0}else{break}}}else{A=r;r=m;m=l;l=s;s=n;n=1;while(1){R=A-1|0;z=A-2|0;Q=r;y=m;P=l;x=s;while(1){O=Q;e=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=Q+4|0;b[P>>1]=e<<6;S=x+2|0;b[x>>1]=e>>>4&65535&-64;b[y>>1]=e>>>14&65535&-64;if(!(O>>>0<R>>>0)){K=23;break}e=O;O=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;T=Q+8|0;b[S>>1]=O<<6;b[P+2>>1]=O>>>4&65535&-64;b[x+4>>1]=O>>>14&65535&-64;if(!(T>>>0<z>>>0)){K=25;break}O=T;e=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=Q+12|0;b[y+2>>1]=e<<6;U=x+8|0;b[x+6>>1]=e>>>4&65535&-64;b[P+4>>1]=e>>>14&65535&-64;if(!(O>>>0<R>>>0)){K=27;break}e=O;O=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=Q+16|0;b[U>>1]=O<<6;b[y+4>>1]=O>>>4&65535&-64;V=x+12|0;b[x+10>>1]=O>>>14&65535&-64;if(e>>>0<z>>>0){Q=e;y=y+6|0;P=P+6|0;x=V}else{K=29;break}}if((K|0)==23){K=0;b[S>>1]=128;x=p+(ba(c[a>>2]|0,n)|0)|0;P=k+(ba(c[v>>2]|0,n)|0)|0;W=Q+5|0;X=g+(ba(c[w>>2]|0,n)|0)|0;Y=P;Z=x}else if((K|0)==25){K=0;x=p+(ba(c[a>>2]|0,n)|0)|0;P=k+(ba(c[v>>2]|0,n)|0)|0;W=T;X=g+(ba(c[w>>2]|0,n)|0)|0;Y=P;Z=x}else if((K|0)==27){K=0;b[U>>1]=128;x=p+(ba(c[a>>2]|0,n)|0)|0;P=k+(ba(c[v>>2]|0,n)|0)|0;W=Q+13|0;X=g+(ba(c[w>>2]|0,n)|0)|0;Y=P;Z=x}else if((K|0)==29){K=0;b[V>>1]=128;x=p+(ba(c[a>>2]|0,n)|0)|0;P=k+(ba(c[v>>2]|0,n)|0)|0;W=Q+18|0;X=g+(ba(c[w>>2]|0,n)|0)|0;Y=P;Z=x}if((n|0)<(u|0)){A=A+t|0;r=W;m=X;l=Y;s=Z;n=n+1|0}else{break}}}}c[f>>2]=1;q=c[o>>2]|0;i=h;return q|0}function reb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=a+60|0;f=c[e>>2]|0;do{if((c[a+100>>2]|0)==4){g=a+96|0;if((c[g>>2]|0)==0){break}h=a+120|0;j=c[h>>2]|0;do{if((j&15|0)==0){k=a+124|0;l=c[k>>2]|0;if((l&15|0)!=0){break}m=hDb(j,l,0,a)|0;if((m|0)<0){n=m;i=b;return n|0}m=f+1248|0;c[m>>2]=cEb(ba(c[h>>2]<<1,c[k>>2]|0)|0)|0;l=cEb(ba(c[h>>2]<<1,c[k>>2]|0)|0)|0;c[f+1252>>2]=l;if((c[m>>2]|0)==0|(l|0)==0){l=c[e>>2]|0;$Db(l+1248|0);$Db(l+1252|0);$Db(l+3136|0);c[l+3140>>2]=0;m=l+3148|0;k=0;do{$Db(m+(k<<4)+12|0);c[m+(k<<4)>>2]=0;k=k+1|0;}while((k|0)<100);Q_(l+2344|0);n=-12;i=b;return n|0}else{k=c[g>>2]|0;m=f+3144|0;c[m>>2]=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>16;Z3(f+4|0,a);c[f>>2]=a;k=0;do{c[8857180+(k*80|0)>>2]=5087536+(k<<9);c[8857188+(k*80|0)>>2]=32;N_(8857176+(k*80|0)|0,5,7,1680185+(k<<6)|0,2,1,1680184+(k<<6)|0,2,1,0,0,0,4)|0;c[8857200+(k*80|0)>>2]=5087664+(k<<9);c[8857208+(k*80|0)>>2]=32;N_(8857196+(k*80|0)|0,5,7,1680201+(k<<6)|0,2,1,1680200+(k<<6)|0,2,1,0,0,0,4)|0;c[8857220+(k*80|0)>>2]=5087792+(k<<9);c[8857228+(k*80|0)>>2]=32;N_(8857216+(k*80|0)|0,5,7,1680217+(k<<6)|0,2,1,1680216+(k<<6)|0,2,1,0,0,0,4)|0;c[8857240+(k*80|0)>>2]=5087920+(k<<9);c[8857248+(k*80|0)>>2]=32;N_(8857236+(k*80|0)|0,5,7,1680233+(k<<6)|0,2,1,1680232+(k<<6)|0,2,1,0,0,0,4)|0;k=k+1|0;}while((k|0)<2);c[a+140>>2]=(c[m>>2]|0)>2?44:50;n=0;i=b;return n|0}}}while(0);yDb(a,16,2027936,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=b;return n|0}}while(0);yDb(a,16,2032016,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=b;return n|0}function seb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0;j=i;i=i+5920|0;k=j|0;l=j+2048|0;m=j+2560|0;n=j+4608|0;o=j+4872|0;p=j+5904|0;q=c[h+24>>2]|0;r=c[h+28>>2]|0;h=c[e+60>>2]|0;s=h;t=f;if((r|0)<20){u=-1094995529;i=j;return u|0}v=e+120|0;if((c[v>>2]&15|0)!=0){yDb(0,0,2177400,(w=i,i=i+24|0,c[w>>2]=2101224,c[w+8>>2]=2045328,c[w+16>>2]=831,w)|0);i=w;Cd();return 0}x=e+124|0;if((c[x>>2]&15|0)!=0){yDb(0,0,2177400,(w=i,i=i+24|0,c[w>>2]=2101224,c[w+8>>2]=2045328,c[w+16>>2]=831,w)|0);i=w;Cd();return 0}y=q+4|0;z=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;if(r>>>0<(z+8|0)>>>0){yDb(c[h>>2]|0,16,1999752,(w=i,i=i+16|0,c[w>>2]=r,c[w+8>>2]=z,w)|0);i=w;u=-1094995529;i=j;return u|0}z=q;y=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;do{if((y|0)==1836213859){z=r-20|0;A=h+3144|0;B=c[A>>2]|0;if((B|0)<2){yDb(c[h>>2]|0,16,1934680,(w=i,i=i+8|0,c[w>>2]=B,w)|0);i=w;u=-1094995529;i=j;return u|0}B=q+12|0;C=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=q+16|0;D=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;if((D|z|0)<0){yDb(c[h>>2]|0,16,1911632,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=-1094995529;i=j;return u|0}B=h+3148|0;E=e+428|0;F=h;G=0;while(1){H=c[B+(G<<4)+8>>2]|0;do{if((H|0)!=0){if((H|0)>=(c[E>>2]|0)){break}yDb(c[F>>2]|0,16,1891200,(w=i,i=i+8|0,c[w>>2]=H,w)|0);i=w}}while(0);H=G+1|0;if((H|0)<100){G=H}else{I=-1;J=0;break}}while(1){if((c[B+(J<<4)+8>>2]|0)==(C|0)){K=19;break}G=(c[B+(J<<4)+4>>2]|0)==0?J:I;H=J+1|0;if((H|0)<100){I=G;J=H}else{L=G;K=20;break}}if((K|0)==19){if((J|0)>99){L=I;K=20}else{M=J}}if((K|0)==20){c[B+(L<<4)+8>>2]=C;M=L}G=B+(M<<4)+4|0;H=c[G>>2]|0;if(z>>>0>(-17-H|0)>>>0){u=-1094995529;i=j;return u|0}N=B+(M<<4)+12|0;O=jEb(c[N>>2]|0,B+(M<<4)|0,r-4+H|0)|0;c[N>>2]=O;if((O|0)==0){yDb(c[F>>2]|0,16,2348600,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=-12;i=j;return u|0}UGb(O+(c[G>>2]|0)|0,q+20|0,z)|0;O=(c[G>>2]|0)+z|0;c[G>>2]=O;if(O>>>0<D>>>0){u=r;i=j;return u|0}H=c[N>>2]|0;N=c[E>>2]|0;if((C|0)!=(N|0)){yDb(c[F>>2]|0,16,2328424,(w=i,i=i+16|0,c[w>>2]=C,c[w+8>>2]=N,w)|0);i=w}if((c[A>>2]|0)<2){u=-1094995529;i=j;return u|0}else{c[B+(M<<4)+8>>2]=0;c[G>>2]=0;P=H;Q=1836213872;R=O;break}}else{P=q+12|0;Q=y;R=r-12|0}}while(0);y=_$a(e,t,0)|0;if((y|0)<0){u=y;i=j;return u|0}a:do{if((Q|0)==1836213865){c[f+88>>2]=1;y=h;t=c[y>>2]|0;q=c[t+120>>2]|0;M=c[t+124>>2]|0;L=P;J=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;b:do{if(J>>>0>67108864>>>0){S=-1094995529}else{L=J+12|0;if(L>>>0>R>>>0){yDb(t,16,2113248,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;S=-1094995529;break}I=P+(J+4)|0;O=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24)<<2;I=P+L|0;if((O+L|0)!=(R|0)|O>>>0>67108864>>>0){yDb(t,16,2098984,(w=i,i=i+24|0,c[w>>2]=O,c[w+8>>2]=J,c[w+16>>2]=R,w)|0);i=w;S=-1094995529;break}O=n|0;L=o;TGb(k|0,0,2048)|0;H=P+R|0;TGb(m|0,-1|0,2048)|0;G=H;N=I;T=P+(J+13)|0;U=d[I]|0;while(1){V=N+2|0;W=d[T]|0;X=W-U|0;if((G-V|0)<(((X+1|0)>0?X+2|0:1)|0)){K=60;break}Y=N+3|0;Z=a[V]|0;_=Z&255;if((U|0)>(W|0)){$=V;aa=Y;ca=Z;da=_}else{Z=U;V=Y;Y=_;while(1){c[k+(Z<<2)>>2]=Y;_=Z+1|0;ea=a[V]|0;fa=ea&255;if((_|0)>(W|0)){break}else{Z=_;V=V+1|0;Y=fa}}$=N+(X+3)|0;aa=N+(X+4)|0;ca=ea;da=fa}if(ca<<24>>24==0){K=64;break}else{N=$;T=aa;U=da}}do{if((K|0)==60){yDb(t,16,2059648,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ga=0}else if((K|0)==64){c[k+1024>>2]=1;U=I;T=aa;while(1){if((T-U&3|0)==0){break}else{T=T+1|0}}if(T>>>0>H>>>0){yDb(t,16,2054600,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ga=0;break}else{ha=257}while(1){U=65536;X=65536;N=0;Y=0;V=0;while(1){Z=c[k+(V<<2)>>2]|0;if((Z|0)!=0&(Z|0)<(U|0)){W=(Z|0)<(X|0);ia=W?V:Y;ja=W?Y:V;ka=W?Z:X;la=W?X:Z}else{ia=Y;ja=N;ka=X;la=U}Z=V+1|0;if((Z|0)<(ha|0)){U=la;X=ka;N=ja;Y=ia;V=Z}else{break}}if((la|0)==65536){ma=0;break}c[k+(ha<<2)>>2]=ka+la;a[l+ia|0]=0;a[l+ja|0]=1;c[m+(ja<<2)>>2]=ha;c[m+(ia<<2)>>2]=ha;c[k+(ja<<2)>>2]=0;c[k+(ia<<2)>>2]=0;V=ha+1|0;if((V|0)<512){ha=V}else{ma=0;break}}do{V=m+(ma<<2)|0;Y=c[V>>2]|0;if((Y|0)==-1){na=0;oa=0}else{N=ma;X=0;U=0;Z=V;V=Y;while(1){pa=(d[l+N|0]<<X)+U|0;qa=X+1|0;if((qa|0)>31){yDb(c[y>>2]|0,16,2043744,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ra=c[Z>>2]|0}else{ra=V}Y=m+(ra<<2)|0;W=c[Y>>2]|0;if((W|0)==-1){break}else{N=ra;X=qa;U=pa;Z=Y;V=W}}na=qa&255;oa=pa}c[o+(ma<<2)>>2]=oa;a[n+ma|0]=na;ma=ma+1|0;}while((ma|0)<257);V=(N_(h+2344|0,9,257,O,1,1,L,4,4,0,0,0,0)|0)==0;ga=V?T:0}}while(0);if((ga|0)==0){yDb(c[y>>2]|0,16,2092704,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;S=-1094995529;break}if(ga>>>0>H>>>0){yDb(0,0,2177400,(w=i,i=i+24|0,c[w>>2]=2087448,c[w+8>>2]=2045328,c[w+16>>2]=788,w)|0);i=w;Cd();return 0}L=P+4|0;O=J<<3;I=O>>>0>2147483639>>>0|(L|0)==0;V=I?0:L;L=I?0:O;O=h+1276|0;c[O>>2]=V;I=h+1288|0;c[I>>2]=L;Z=h+1292|0;c[Z>>2]=L+8;c[h+1280>>2]=V+(L>>3);L=h+1284|0;c[L>>2]=0;V=G-ga|0;U=h+3136|0;X=U;O$a(U,h+3140|0,V);U=c[X>>2]|0;if((U|0)==0){S=-12;break}Xe[c[h+1100>>2]&4095](U,ga,V>>>2);U=c[X>>2]|0;X=V<<3;V=X>>>0>2147483639>>>0|(U|0)==0;N=V?0:U;U=V?0:X;X=h+1256|0;c[X>>2]=N;c[h+1268>>2]=U;V=U+8|0;W=h+1272|0;c[W>>2]=V;c[h+1260>>2]=N+(U>>3);U=h+1264|0;c[U>>2]=0;Y=h+2364|0;c[Y>>2]=0;do{if((M|0)>0){_=(q|0)>0;sa=h+44|0;ta=h+2368|0;ua=h+2348|0;va=h+1248|0;wa=h+2496|0;xa=h+2624|0;ya=h+2752|0;za=h+2880|0;Aa=h+3008|0;Ba=0;c:while(1){if(_){Ca=0;do{me[c[sa>>2]&511](ta);Da=0;do{Ea=s+2368+(Da<<7)|0;Fa=c[L>>2]|0;Ga=(c[I>>2]|0)-Fa|0;if((Ga|0)<2){K=92;break c}Ha=c[ua>>2]|0;Ia=c[U>>2]|0;Ja=c[W>>2]|0;Ka=c[X>>2]|0;La=Ka+(Ia>>>3)|0;Ma=(fe(d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0)|0)<<(Ia&7)>>>23;La=b[Ha+(Ma<<2)>>1]|0;Na=b[Ha+(Ma<<2)+2>>1]|0;Ma=Na<<16>>16;do{if(Na<<16>>16<0){Oa=Ia+9|0;Pa=Ja>>>0>Oa>>>0?Oa:Ja;Oa=Ka+(Pa>>>3)|0;Qa=((fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Pa&7)>>>((Ma+32|0)>>>0))+La|0;Oa=b[Ha+(Qa<<2)>>1]|0;Ra=b[Ha+(Qa<<2)+2>>1]|0;Qa=Ra<<16>>16;if(!(Ra<<16>>16<0)){Sa=Qa;Ta=Oa;Ua=Pa;break}Ra=Pa-Ma|0;Pa=Ja>>>0>Ra>>>0?Ra:Ja;Ra=Ka+(Pa>>>3)|0;Va=((fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Pa&7)>>>((Qa+32|0)>>>0))+Oa|0;Sa=b[Ha+(Va<<2)+2>>1]|0;Ta=b[Ha+(Va<<2)>>1]|0;Ua=Pa}else{Sa=Ma;Ta=La;Ua=Ia}}while(0);Ia=Sa+Ua|0;La=Ja>>>0>Ia>>>0?Ia:Ja;c[U>>2]=La;if(Ta>>>0>15>>>0){K=97;break c}if((Ta|0)==0){Wa=0;Xa=Fa}else{Ia=c[Z>>2]|0;Ma=(c[O>>2]|0)+(Fa>>>3)|0;Na=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Fa&7);Ma=(Na^-2147483648)>>31;Pa=Ta+Fa|0;Va=Ia>>>0>Pa>>>0?Pa:Ia;c[L>>2]=Va;Wa=((Ma^Na)>>>((32-Ta|0)>>>0)^Ma)-Ma<<4;Xa=Va}Va=(c[Y>>2]|0)+Wa&65535;b[Ea>>1]=Va;c[Y>>2]=Va<<16>>16;Va=1;Ma=La;La=Xa;d:while(1){Na=Va;Ia=Ma;while(1){Pa=Ka+(Ia>>>3)|0;Oa=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Ia&7)>>>23;Pa=b[Ha+(Oa<<2)>>1]|0;Qa=b[Ha+(Oa<<2)+2>>1]|0;Oa=Qa<<16>>16;do{if(Qa<<16>>16<0){Ra=Ia+9|0;Ya=Ja>>>0>Ra>>>0?Ra:Ja;Ra=Ka+(Ya>>>3)|0;Za=((fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Ya&7)>>>((Oa+32|0)>>>0))+Pa|0;Ra=b[Ha+(Za<<2)>>1]|0;_a=b[Ha+(Za<<2)+2>>1]|0;Za=_a<<16>>16;if(!(_a<<16>>16<0)){$a=Za;ab=Ra;bb=Ya;break}_a=Ya-Oa|0;Ya=Ja>>>0>_a>>>0?_a:Ja;_a=Ka+(Ya>>>3)|0;cb=((fe(d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0)|0)<<(Ya&7)>>>((Za+32|0)>>>0))+Ra|0;$a=b[Ha+(cb<<2)+2>>1]|0;ab=b[Ha+(cb<<2)>>1]|0;bb=Ya}else{$a=Oa;ab=Pa;bb=Ia}}while(0);Pa=$a+bb|0;db=Ja>>>0>Pa>>>0?Pa:Ja;c[U>>2]=db;if((ab|0)==0){break d}else if((ab|0)!=240){break}Na=Na+16|0;Ia=db}Ia=ab&15;if((Ia|0)==0){K=109;break c}Pa=c[Z>>2]|0;Oa=(c[O>>2]|0)+(La>>>3)|0;Qa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(La&7);Oa=(Qa^-2147483648)>>31;Ya=Ia+La|0;cb=Pa>>>0>Ya>>>0?Ya:Pa;c[L>>2]=cb;eb=(ab>>4)+Na|0;if((eb|0)>63){K=110;break}Pa=d[1075976+eb|0]|0;b[s+2368+(Da<<7)+(Pa<<1)>>1]=ba(d[1377472+Pa|0]|0,((Oa^Qa)>>>((32-Ia|0)>>>0)^Oa)-Oa|0)|0;Oa=eb+1|0;if((Oa|0)>63){break}else{Va=Oa;Ma=db;La=cb}}if((K|0)==110){K=0;yDb(c[y>>2]|0,16,2063376,(w=i,i=i+8|0,c[w>>2]=eb,w)|0);i=w}Da=Da+1|0;}while((Da|0)<6);Da=c[(c[y>>2]|0)+120>>2]|0;La=c[va>>2]|0;Ma=(ba(Da,Ba)|0)+Ca|0;b[ta>>1]=(b[ta>>1]|0)+8192;veb(ta);b[wa>>1]=(b[wa>>1]|0)+8192;veb(wa);b[xa>>1]=(b[xa>>1]|0)+8192;veb(xa);b[ya>>1]=(b[ya>>1]|0)+8192;veb(ya);if((c[(c[y>>2]|0)+88>>2]&8192|0)==0){veb(za);veb(Aa)}Va=Da+1|0;Ja=Da<<1;Ha=La+(Ma<<1)|0;Ma=0;while(1){La=Ma>>2<<1;Ka=Ma<<4&48;Ea=Ma<<3;Fa=Ha;cb=0;while(1){Oa=(cb>>2)+La|0;Ia=cb<<1&6|Ka;Qa=cb+Ea|0;Pa=b[s+2880+(Qa<<1)>>1]|0;Ya=b[s+3008+(Qa<<1)>>1]|0;Qa=Ya+Pa>>1;Ra=Pa<<1;Pa=b[s+2368+(Oa<<7)+(Ia<<1)>>1]|0;b[Fa>>1]=(Pa+Ya<<8&63488)+((Pa+Ra|0)>>>3)+(Pa-Qa<<3&2016);Pa=b[s+2368+(Oa<<7)+((Ia|1)<<1)>>1]|0;b[Fa+2>>1]=(Pa-Qa<<3&2016)+((Pa+Ra|0)>>>3)+(Pa+Ya<<8&63488);Pa=b[s+2368+(Oa<<7)+((Ia|8)<<1)>>1]|0;b[Fa+(Da<<1)>>1]=(Pa-Qa<<3&2016)+((Pa+Ra|0)>>>3)+(Pa+Ya<<8&63488);Pa=b[s+2368+(Oa<<7)+((Ia|9)<<1)>>1]|0;b[Fa+(Va<<1)>>1]=(Pa-Qa<<3&2016)+((Pa+Ra|0)>>>3)+(Pa+Ya<<8&63488);Ya=cb+1|0;if((Ya|0)<8){Fa=Fa+4|0;cb=Ya}else{break}}cb=Ma+1|0;if((cb|0)<8){Ha=Ha+(Ja<<1)|0;Ma=cb}else{break}}Ca=Ca+16|0;}while((Ca|0)<(q|0))}Ca=Ba+16|0;if((Ca|0)<(M|0)){Ba=Ca}else{K=121;break}}if((K|0)==92){yDb(c[y>>2]|0,16,2077120,(w=i,i=i+8|0,c[w>>2]=Ga,w)|0);i=w;S=-1;break b}else if((K|0)==97){yDb(c[y>>2]|0,16,2072384,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;S=-1094995529;break b}else if((K|0)==109){yDb(c[y>>2]|0,16,2067760,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;S=-1094995529;break b}else if((K|0)==121){fb=c[U>>2]|0;gb=c[W>>2]|0;hb=c[X>>2]|0;ib=ua;break}}else{fb=0;gb=V;hb=N;ib=h+2348|0}}while(0);N=c[ib>>2]|0;V=hb+(fb>>>3)|0;X=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(fb&7)>>>23;V=b[N+(X<<2)>>1]|0;W=b[N+(X<<2)+2>>1]|0;X=W<<16>>16;do{if(W<<16>>16<0){L=fb+9|0;O=gb>>>0>L>>>0?L:gb;L=hb+(O>>>3)|0;Z=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(O&7)>>>((X+32|0)>>>0))+V|0;L=b[N+(Z<<2)>>1]|0;Y=b[N+(Z<<2)+2>>1]|0;Z=Y<<16>>16;if(!(Y<<16>>16<0)){jb=Z;kb=L;lb=O;break}Y=O-X|0;O=gb>>>0>Y>>>0?Y:gb;Y=hb+(O>>>3)|0;I=((fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(O&7)>>>((Z+32|0)>>>0))+L|0;jb=b[N+(I<<2)+2>>1]|0;kb=b[N+(I<<2)>>1]|0;lb=O}else{jb=X;kb=V;lb=fb}}while(0);V=jb+lb|0;c[U>>2]=gb>>>0>V>>>0?V:gb;if((kb|0)==256){break a}yDb(c[y>>2]|0,16,2082832,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break a}}while(0);yDb(c[y>>2]|0,16,2240680,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=S;i=j;return u|0}else if((Q|0)==1836213872|(Q|0)==846358128){c[f+88>>2]=2;M=h;q=c[M>>2]|0;J=c[q+120>>2]|0;t=c[q+124>>2]|0;B=c[h+1248>>2]|0;A=c[h+1252>>2]|0;C=h+3144|0;do{if((c[C>>2]|0)>1){if(R>>>0<20>>>0){mb=-1094995529;break}F=P+8|0;E=P+12|0;D=P+16|0;nb=20;ob=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;pb=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;qb=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;K=132}else{F=P-4|0;D=(d[F]|d[F+1|0]<<8)<<16>>16&65535;F=P-2|0;E=(d[F]|d[F+1|0]<<8)<<16>>16&65535;nb=0;ob=E;pb=R-D-E|0;qb=D;K=132}}while(0);e:do{if((K|0)==132){do{if(!(qb>>>0>R>>>0|qb>>>0>268435454>>>0|pb>>>0>(R-qb|0)>>>0)){y=R-pb-qb|0;if(ob>>>0>y>>>0|nb>>>0>(y-ob|0)>>>0){break}y=h+3136|0;D=y;O$a(y,h+3140|0,qb);y=c[D>>2]|0;if((y|0)==0){mb=-12;break e}Xe[c[h+1100>>2]&4095](y,P+nb|0,qb>>>2);y=c[D>>2]|0;D=qb<<3;E=D>>>0>2147483639>>>0|(y|0)==0;F=E?0:y;y=E?0:D;c[h+1276>>2]=F;c[h+1288>>2]=y;c[h+1292>>2]=y+8;c[h+1280>>2]=F+(y>>3);c[h+1284>>2]=0;y=nb+qb|0;F=y+ob|0;D=P+y|0;if(!((R-y|0)>-1)){yDb(0,0,2177400,(w=i,i=i+24|0,c[w>>2]=2124920,c[w+8>>2]=2119360,c[w+16>>2]=135,w)|0);i=w;Cd();return 0}c[h+1308>>2]=D;c[h+1316>>2]=D;D=P+R|0;c[h+1312>>2]=D;y=P+F|0;if(!((R-F|0)>-1)){yDb(0,0,2177400,(w=i,i=i+24|0,c[w>>2]=2124920,c[w+8>>2]=2119360,c[w+16>>2]=135,w)|0);i=w;Cd();return 0}c[h+1296>>2]=y;c[h+1304>>2]=y;c[h+1300>>2]=D;D=J<<1;y=0;do{if((c[C>>2]|0)>1){c[s+1320+(y<<2)>>2]=((ba(a[643065+(y<<1)|0]|0,D)|0)/2|0)+(a[643064+(y<<1)|0]|0)}else{c[s+1320+(y<<2)>>2]=(y&15)-8+((ba((y>>4)-8|0,D)|0)/2|0)}y=y+1|0;}while((y|0)<256);if((t|0)<=0){break a}y=J<<3;D=B;ua=A;F=0;while(1){E=0;while(1){if((E|0)>=(J|0)){break}z=ueb(s,D+(E<<1)|0,ua+(E<<1)|0,3,3,J)|0;if((z|0)<0){mb=z;break e}else{E=E+8|0}}E=F+8|0;if((E|0)<(t|0)){D=D+(y<<1)|0;ua=ua+(y<<1)|0;F=E}else{break a}}}}while(0);yDb(q,16,2173896,(w=i,i=i+32|0,c[w>>2]=qb,c[w+8>>2]=pb,c[w+16>>2]=ob,c[w+24>>2]=qb-R+pb+ob,w)|0);i=w;mb=-1094995529}}while(0);yDb(c[M>>2]|0,16,2216792,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=mb;i=j;return u|0}else if((Q|0)==846358121){c[f+88>>2]=1;q=P-4|0;t=R+4|0;J=p;A=h;B=c[A>>2]|0;C=c[B+120>>2]|0;U=c[B+124>>2]|0;if((ba(C+15>>4<<3,U+15>>4)|0)>(t|0)){yDb(B,16,2113248,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;rb=-1094995529}else{B=c[h+1248>>2]|0;if(!((t|0)>-1)){yDb(0,0,2177400,(w=i,i=i+24|0,c[w>>2]=2124920,c[w+8>>2]=2119360,c[w+16>>2]=135,w)|0);i=w;Cd();return 0}if((U|0)<=0){break}F=(C|0)>0;y=(t|0)<8;t=p|0;ua=p+4|0;D=p+8|0;E=p+12|0;z=C<<4;V=q;q=B;B=0;while(1){if(F){if(y){break}else{sb=V;tb=q;ub=0}while(1){TGb(J|0,0,16)|0;X=sb;N=(d[X]|d[X+1|0]<<8)<<16>>16&65535;c[t>>2]=N;X=sb+2|0;W=(d[X]|d[X+1|0]<<8)<<16>>16&65535;c[ua>>2]=W;if((N&32768|0)!=0){yDb(c[A>>2]|0,16,2038992,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}if((W&32768|0)!=0){yDb(c[A>>2]|0,16,2035928,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}X=N<<1;O=N>>>10;I=W>>>10;c[D>>2]=(((((X&1984)+(W&992)|0)>>>0)/96|0)<<5)+(((((O<<1)+I|0)>>>0)/3|0)<<10)+((((X&62)+(W&31)|0)>>>0)/3|0);X=W<<1;c[E>>2]=(((((X&1984)+(N&992)|0)>>>0)/96|0)<<5)+(((((I<<1)+O|0)>>>0)/3|0)<<10)+((((X&62)+(N&31)|0)>>>0)/3|0);N=sb+4|0;X=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;N=0;do{O=N>>>2<<3;I=ba(N,C)|0;W=0;do{b[tb+(W+I<<1)>>1]=c[p+((X>>>(((W>>2<<1)+O|0)>>>0)&3)<<2)>>2];W=W+1|0;}while((W|0)<16);N=N+1|0;}while((N|0)<16);N=sb+8|0;X=tb+32|0;W=ub+16|0;if((W|0)<(C|0)){sb=N;tb=X;ub=W}else{vb=N;wb=X;xb=W;break}}}else{vb=V;wb=q;xb=0}W=B+16|0;if((W|0)<(U|0)){V=vb;q=wb+(z-xb<<1)|0;B=W}else{break a}}TGb(J|0,0,16)|0;rb=-1}yDb(c[A>>2]|0,16,2270280,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=rb;i=j;return u|0}else{B=e;if((Q|0)==1600417395){yDb(B,16,2199216,(w=i,i=i+8|0,c[w>>2]=r,w)|0);i=w;break}else{yDb(B,16,2190640,(w=i,i=i+8|0,c[w>>2]=r,w)|0);i=w;break}}}while(0);c[f+84>>2]=(c[f+88>>2]|0)==1;w=h+1248|0;Q=c[v>>2]<<1;iDb(c[f>>2]|0,c[f+32>>2]|0,c[w>>2]|0,Q,Q,c[x>>2]|0);x=h+1252|0;h=c[x>>2]|0;c[x>>2]=c[w>>2];c[w>>2]=h;c[g>>2]=1;u=r;i=j;return u|0}function teb(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;$Db(b+1248|0);$Db(b+1252|0);$Db(b+3136|0);c[b+3140>>2]=0;a=b+3148|0;d=0;do{$Db(a+(d<<4)+12|0);c[a+(d<<4)>>2]=0;d=d+1|0;}while((d|0)<100);Q_(b+2344|0);return 0}function ueb(a,f,g,h,j,k){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;l=i;m=a+3144|0;n=a+1284|0;o=a+1292|0;p=a+1276|0;q=a+1252|0;r=a|0;s=j;j=h;h=g;g=f;a:while(1){f=-1<<j;t=(j|0)>-1;u=s;v=h;w=g;while(1){x=1<<u;y=c[m>>2]|0;z=c[8857176+(((y|0)<2|0)*80|0)+((d[436048+(u<<2)+j|0]|0)*20|0)+4>>2]|0;A=c[n>>2]|0;B=c[o>>2]|0;C=(c[p>>2]|0)+(A>>>3)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(A&7)>>>27;C=b[z+(D<<2)>>1]|0;E=C<<16>>16;F=(b[z+(D<<2)+2>>1]|0)+A|0;c[n>>2]=B>>>0>F>>>0?F:B;G=c[q>>2]|0;H=c[r>>2]|0;if(!((C&65535)>>>0<7>>>0&t)){I=4;break a}J=G+((ba(1-x+(c[H+124>>2]|0)|0,k)|0)+f<<1)|0;if((E|0)==6){I=10;break a}else if((E|0)==2){break}else if((E|0)!=1){I=15;break a}C=u-1|0;B=ueb(a,w,v,j,C,k)|0;if((B|0)<0){K=B;I=59;break a}B=k<<C;u=C;v=v+(B<<1)|0;w=w+(B<<1)|0}f=j-1|0;t=ueb(a,w,v,f,u,k)|0;if((t|0)<0){K=t;I=59;break}t=1<<f;s=u;j=f;h=v+(t<<1)|0;g=w+(t<<1)|0}if((I|0)==4){yDb(0,0,2177400,(L=i,i=i+24|0,c[L>>2]=2164008,c[L+8>>2]=2045328,c[L+16>>2]=352,L)|0);i=L;Cd();return 0}else if((I|0)==10){g=a+1308|0;h=c[g>>2]|0;if(((c[a+1312>>2]|0)-h|0)>>>0<4>>>0){yDb(H,16,2157104,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}s=h+2|0;c[g>>2]=s;r=h;b[w>>1]=(d[r]|d[r+1|0]<<8)<<16>>16;c[g>>2]=h+4;h=s;s=(d[h]|d[h+1|0]<<8)<<16>>16;if((j|0)==0){b[w+(k<<1)>>1]=s;K=0;i=l;return K|0}else{b[w+2>>1]=s;K=0;i=l;return K|0}}else if((I|0)==15){do{if((E&3|0)==0){if((c[a+1300>>2]|0)!=(c[a+1296>>2]|0)){break}yDb(H,16,2150376,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}}while(0);do{if((E|0)==3){if((y|0)>1){K=0}else{M=0;N=1;O=v;break}i=l;return K|0}else if((E|0)==5){s=a+1308|0;h=c[s>>2]|0;g=(c[a+1312>>2]|0)-h|0;if(g>>>0<2>>>0){yDb(H,16,2157104,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}if(G>>>0>v>>>0|J>>>0<v>>>0){yDb(0,0,2177400,(L=i,i=i+24|0,c[L>>2]=2143408,c[L+8>>2]=2045328,c[L+16>>2]=404,L)|0);i=L;Cd();return 0}if((g|0)<2){M=0;N=0;O=v;break}c[s>>2]=h+2;s=h;M=(d[s]|d[s+1|0]<<8)<<16>>16&65535;N=0;O=v}else if((E|0)==0){s=a+1296|0;h=c[s>>2]|0;if(((c[a+1300>>2]|0)-h|0)<1){P=0}else{c[s>>2]=h+1;P=d[h]|0}M=0;N=1;O=v+(c[a+1320+(P<<2)>>2]<<1)|0}else if((E|0)==4){h=a+1296|0;s=c[h>>2]|0;if(((c[a+1300>>2]|0)-s|0)<1){Q=0}else{c[h>>2]=s+1;Q=d[s]|0}s=a+1308|0;h=c[s>>2]|0;g=(c[a+1312>>2]|0)-h|0;if(g>>>0<2>>>0){yDb(H,16,2157104,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}else{r=v+(c[a+1320+(Q<<2)>>2]<<1)|0;if((g|0)<2){M=0;N=1;O=r;break}c[s>>2]=h+2;s=h;M=(d[s]|d[s+1|0]<<8)<<16>>16&65535;N=1;O=r;break}}else{M=0;N=1;O=v}}while(0);if(G>>>0>O>>>0|O>>>0>J>>>0){yDb(H,16,2138032,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}H=M*65537|0;if((j|0)==0){if((x|0)<=0){K=0;i=l;return K|0}if((N|0)==0){M=H&65535;J=0;G=w;while(1){b[G>>1]=M;v=J+1|0;if((v|0)<(x|0)){J=v;G=G+(k<<1)|0}else{K=0;break}}i=l;return K|0}else{G=-N|0;J=0;M=O;v=w;while(1){b[v>>1]=(e[M>>1]&G)+H;Q=J+1|0;if((Q|0)<(x|0)){J=Q;M=M+(k<<1)|0;v=v+(k<<1)|0}else{K=0;break}}i=l;return K|0}}else if((j|0)==3){if((x|0)<=0){K=0;i=l;return K|0}v=(N|0)==0;M=-N|0;J=0;G=O;Q=w;while(1){a=G;c[Q>>2]=((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24)&M)+H;a=G+4|0;c[Q+4>>2]=((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24)&M)+H;a=G+8|0;c[Q+8>>2]=((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24)&M)+H;a=G+12|0;c[Q+12>>2]=((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24)&M)+H;if(v){R=G}else{R=G+(k<<1)|0}a=J+1|0;if((a|0)<(x|0)){J=a;G=R;Q=Q+(k<<1)|0}else{K=0;break}}i=l;return K|0}else if((j|0)==2){if((x|0)<=0){K=0;i=l;return K|0}Q=-N|0;if((N|0)==0){R=0;G=w;while(1){J=O;c[G>>2]=((d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24)&Q)+H;J=O+4|0;c[G+4>>2]=((d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24)&Q)+H;J=R+1|0;if((J|0)<(x|0)){R=J;G=G+(k<<1)|0}else{K=0;break}}i=l;return K|0}else{G=0;R=O;J=w;while(1){v=R;c[J>>2]=((d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24)&Q)+H;v=R+4|0;c[J+4>>2]=((d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24)&Q)+H;v=G+1|0;if((v|0)<(x|0)){G=v;R=R+(k<<1)|0;J=J+(k<<1)|0}else{K=0;break}}i=l;return K|0}}else if((j|0)==1){if((x|0)<=0){K=0;i=l;return K|0}if((N|0)==0){j=0;J=w;while(1){c[J>>2]=H;R=j+1|0;if((R|0)<(x|0)){j=R;J=J+(k<<1)|0}else{K=0;break}}i=l;return K|0}J=-N|0;N=0;j=O;O=w;while(1){w=j;c[O>>2]=((d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24)&J)+H;w=N+1|0;if((w|0)<(x|0)){N=w;j=j+(k<<1)|0;O=O+(k<<1)|0}else{K=0;break}}i=l;return K|0}else{yDb(0,0,2177400,(L=i,i=i+24|0,c[L>>2]=2131336,c[L+8>>2]=2045328,c[L+16>>2]=334,L)|0);i=L;Cd();return 0}}else if((I|0)==59){i=l;return K|0}return 0}function veb(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=i;i=i+256|0;e=d|0;f=0;while(1){g=b[a+(f<<1)>>1]|0;h=f+32|0;j=b[a+(h<<1)>>1]|0;k=j+g|0;l=g-j|0;j=f+16|0;g=b[a+(j<<1)>>1]|0;m=f+48|0;n=b[a+(m<<1)>>1]|0;o=n+g|0;p=(((g-n|0)*92682|0)>>16)-o|0;n=o+k|0;g=k-o|0;o=p+l|0;k=l-p|0;p=f+40|0;l=b[a+(p<<1)>>1]|0;q=f+24|0;r=b[a+(q<<1)>>1]|0;s=r+l|0;t=l-r|0;r=f+8|0;l=b[a+(r<<1)>>1]|0;u=f+56|0;v=b[a+(u<<1)>>1]|0;w=v+l|0;x=l-v|0;v=w+s|0;l=((x+t|0)*121095|0)>>16;y=((t*-171254|0)>>16)-v+l|0;t=(((w-s|0)*92682|0)>>16)-y|0;s=t+(((x*70936|0)>>16)-l)|0;c[e+(f<<2)>>2]=v+n;c[e+(u<<2)>>2]=n-v;c[e+(r<<2)>>2]=y+o;c[e+(m<<2)>>2]=o-y;c[e+(j<<2)>>2]=t+k;c[e+(p<<2)>>2]=k-t;c[e+(h<<2)>>2]=s+g;c[e+(q<<2)>>2]=g-s;s=f+1|0;if((s|0)<8){f=s}else{z=0;break}}do{f=c[e+(z<<2)>>2]|0;s=z|4;g=c[e+(s<<2)>>2]|0;q=g+f|0;h=f-g|0;g=z|2;f=c[e+(g<<2)>>2]|0;t=z|6;k=c[e+(t<<2)>>2]|0;p=k+f|0;j=(((f-k|0)*92682|0)>>16)-p|0;k=p+q|0;f=q-p|0;p=j+h|0;q=h-j|0;j=z|5;h=c[e+(j<<2)>>2]|0;y=z|3;o=c[e+(y<<2)>>2]|0;m=o+h|0;r=h-o|0;o=z|1;h=c[e+(o<<2)>>2]|0;v=z|7;n=c[e+(v<<2)>>2]|0;u=n+h|0;l=h-n|0;n=u+m|0;h=((l+r|0)*121095|0)>>16;x=((r*-171254|0)>>16)-n+h|0;r=(((u-m|0)*92682|0)>>16)-x|0;m=r+(((l*70936|0)>>16)-h)|0;b[a+(z<<1)>>1]=(n+k|0)>>>6;b[a+(v<<1)>>1]=(k-n|0)>>>6;b[a+(o<<1)>>1]=(x+p|0)>>>6;b[a+(t<<1)>>1]=(p-x|0)>>>6;b[a+(g<<1)>>1]=(r+q|0)>>>6;b[a+(j<<1)>>1]=(q-r|0)>>>6;b[a+(s<<1)>>1]=(m+f|0)>>>6;b[a+(y<<1)>>1]=(f-m|0)>>>6;z=z+8|0;}while((z|0)<64);i=d;return}function web(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[b+60>>2]|0;c[e>>2]=b;f=c[b+792>>2]|0;if((f|0)==24){c[b+140>>2]=Oe[c[b+152>>2]&1023](b,588320)|0;a[e+4|0]=3;a[e+5|0]=2;a[e+6|0]=1;a[e+7|0]=0}else if((f|0)==32){c[b+140>>2]=30;a[e+4|0]=4}else if((f|0)==8){c[b+140>>2]=11;a[e+4|0]=1;a[e+5|0]=0}else{yDb(b,16,2177296,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-1094995529;i=d;return h|0}if((c[b+140>>2]|0)!=30){h=0;i=d;return h|0}a[e+5|0]=2;a[e+6|0]=1;a[e+7|0]=0;a[e+8|0]=3;h=0;i=d;return h|0}function xeb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;i=c[h+24>>2]|0;j=c[h+28>>2]|0;k=c[e+60>>2]|0;l=c[e+124>>2]|0;m=a[k+4|0]|0;n=m&255;o=_$a(e,f,0)|0;if((o|0)<0){p=o;return p|0}o=l<<1;a:do{if(!(m<<24>>24==0)){q=i+(ba(n,o)|0)|0;r=f;s=f+32|0;t=i+j|0;if((l|0)==0){u=0;while(1){u=u+1|0;if(!(u>>>0<n>>>0)){break a}}}else{v=q;w=0}b:while(1){u=ba(w,o)|0;x=k+(w+5)|0;y=j-u|0;z=v;A=0;while(1){B=c[r>>2]|0;C=c[s>>2]|0;D=ba(C,A)|0;E=(d[x]|0)+D|0;D=A<<1;if(y>>>0<(D+2|0)>>>0){p=-1094995529;F=30;break b}G=b[i+(D+u)>>1]|0;c:do{if(G<<16>>16==0){H=z}else{D=B+(E+C)|0;I=z;J=(de(G|0)|0)&65535;K=B+E|0;while(1){if((t-I|0)<2){p=-1094995529;F=30;break b}L=I+1|0;M=a[I]|0;do{if(M<<24>>24>-1){N=M+1&255;O=N&255;P=J-1-O|0;if((D-K|0)>>>0<(ba(O,n)|0)>>>0){H=L;break c}if((t-L|0)<(O|0)){p=-1094995529;F=30;break b}if(N<<24>>24==0){Q=K;R=P;S=L;break}O=M&255;T=ba(n,O+1|0)|0;U=L;V=N;N=K;while(1){W=V-1&255;a[N]=a[U]|0;if(W<<24>>24==0){break}else{U=U+1|0;V=W;N=N+n|0}}Q=K+T|0;R=P;S=I+(O+2)|0}else{N=1-M&255;if((D-K|0)>>>0<(ba(N&255,n)|0)>>>0){H=L;break c}V=ba(n,(-M&255)+1|0)|0;U=N;N=K;while(1){W=U-1&255;a[N]=a[L]|0;if(W<<24>>24==0){break}else{U=W;N=N+n|0}}Q=K+V|0;R=J-2|0;S=I+2|0}}while(0);if((R|0)==0){H=S;break}else{I=S;J=R;K=Q}}}}while(0);E=A+1|0;if(E>>>0<l>>>0){z=H;A=E}else{break}}A=w+1|0;if(A>>>0<n>>>0){v=H;w=A}else{break a}}if((F|0)==30){return p|0}}}while(0);if((c[e+792>>2]|0)<9){e=HZ(h,0,0)|0;if((e|0)==0){X=k+12|0}else{c[f+304>>2]=1;h=k+12|0;UGb(h|0,e|0,1024)|0;X=h}UGb(c[f+4>>2]|0,X|0,1024)|0}c[g>>2]=1;p=j;return p|0}function yeb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+60>>2]|0;if(((c[a+416>>2]|0)-1|0)>>>0>1>>>0){yDb(a,16,1911496,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1094995529;i=b;return f|0}g=c[(c[a+12>>2]|0)+12>>2]|0;if((g|0)==86072){c[d+4>>2]=1071888}else if((g|0)==86071){c[d+4>>2]=1320736}else{yDb(a,16,1891088,(e=i,i=i+8|0,c[e>>2]=g,e)|0);i=e;f=-1094995529;i=b;return f|0}c[a+420>>2]=5;f=0;i=b;return f|0}function zeb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;j=c[b+60>>2]|0;k=e;l=j+8|0;m=l;n=l;o=c[n>>2]|0;if((o|0)!=0|(g|0)==0){p=o}else{o=g+28|0;q=c[o>>2]|0;r=b+416|0;s=c[r>>2]|0;t=(q|0)/(s|0)|0;u=t-2|0;if(((q|0)%(s|0)|0|0)==0){v=q;w=s}else{yDb(b,24,1999640,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;v=c[o>>2]|0;w=c[r>>2]|0}if((v|0)<(w*3|0|0)){yDb(b,16,1962776,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-22;i=h;return y|0}w=g+24|0;a[j]=a[(c[w>>2]|0)+1|0]^-128;if((c[r>>2]|0)==2){a[j+1|0]=a[(c[w>>2]|0)+(t+1)|0]^-128}c[j+20>>2]=0;c[j+16>>2]=u;v=WDb(u)|0;c[n>>2]=v;if((v|0)==0){y=-12;i=h;return y|0}do{if((c[r>>2]|0)==2){o=WDb(u)|0;c[j+12>>2]=o;if((o|0)!=0){z=c[n>>2]|0;break}$Db(l);y=-12;i=h;return y|0}else{z=v}}while(0);UGb(z|0,(c[w>>2]|0)+2|0,u)|0;if((c[r>>2]|0)==2){UGb(c[j+12>>2]|0,(c[w>>2]|0)+(t+2)|0,u)|0}p=c[n>>2]|0}if((p|0)==0){yDb(b,16,1934592,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-22;i=h;return y|0}x=j+20|0;p=(c[j+16>>2]|0)-(c[x>>2]|0)|0;n=(p|0)<2048?p:2048;if((n|0)<1){c[f>>2]=0;y=c[g+28>>2]|0;i=h;return y|0}c[e+76>>2]=n<<1;g=_$a(b,k,0)|0;if((g|0)<0){y=g;i=h;return y|0}g=b+416|0;a:do{if((c[g>>2]|0)>0){k=e;p=j+4|0;if((n|0)==0){u=0;while(1){u=u+1|0;if((u|0)>=(c[g>>2]|0)){break a}}}else{A=0}do{u=j+A|0;t=c[p>>2]|0;w=n;r=(c[m+(A<<2)>>2]|0)+(c[x>>2]|0)|0;z=a[u]|0;v=c[k+(A<<2)>>2]|0;while(1){l=w-1|0;o=d[r]|0;s=(a[t+(o&15)|0]|0)+(z&255)|0;if(s>>>0>255>>>0){B=-s>>31&255}else{B=s&255}a[v]=B;s=(a[t+(o>>>4)|0]|0)+(B&255)|0;if(s>>>0>255>>>0){C=-s>>31&255}else{C=s&255}a[v+1|0]=C;if((l|0)==0){break}else{w=l;r=r+1|0;z=C;v=v+2|0}}a[u]=C;A=A+1|0;}while((A|0)<(c[g>>2]|0))}}while(0);c[x>>2]=(c[x>>2]|0)+n;c[f>>2]=1;y=ba((((c[b+428>>2]|0)==0)<<1)+n|0,c[g>>2]|0)|0;i=h;return y|0}function Aeb(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+8|0);$Db(b+12|0);c[b+16>>2]=0;c[b+20>>2]=0;return 0}function Beb(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b+60|0;g=c[f>>2]|0;oDb(g,1);h=b+80|0;j=c[h>>2]|0;if((j|0)<1){c[g+260>>2]=4;k=4}else{l=(j|0)/118|0;c[h>>2]=l;c[g+260>>2]=l;k=l}l=b;h=g+260|0;yDb(l,32,1999600,(j=i,i=i+8|0,c[j>>2]=k,j)|0);i=j;c[g+268>>2]=0;k=(c[(c[b+12>>2]|0)+12>>2]|0)==145|0;c[g+264>>2]=k;m=g+316|0;c[m>>2]=k|4;k=g+284|0;n=0;do{o=c[679216+(n<<2)>>2]|0;c[k+(n<<2)>>2]=~~(+(d[1878880+(o*3|0)|0]|0|0)*.3+ +(d[1878881+(o*3|0)|0]|0|0)*.59+ +(d[1878882+(o*3|0)|0]|0|0)*.11);n=n+1|0;}while((n|0)<(c[m>>2]|0));m=WDb((c[h>>2]|0)*128e3|0)|0;c[g+272>>2]=m;do{if((m|0)!=0){n=WDb(32768)|0;c[g+280>>2]=n;if((n|0)==0){break}n=cEb((c[h>>2]|0)*4e3|0)|0;c[g+276>>2]=n;if((n|0)==0){break}n=cEb(256)|0;c[g+308>>2]=n;if((n|0)==0){break}n=WDb(4096)|0;c[g+304>>2]=n;if((n|0)==0){break}n=cEb(48)|0;c[b+96>>2]=n;if((n|0)==0){yDb(l,16,1934544,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;p=-12;i=e;return p|0}c[b+100>>2]=32;k=n;x=fe(c[h>>2]|0)|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=n+16|0;x=16777216;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=ICb()|0;n=b+804|0;c[n>>2]=k;if((k|0)==0){o=c[f>>2]|0;JCb(n);ZDb(c[o+272>>2]|0);ZDb(c[o+280>>2]|0);ZDb(c[o+304>>2]|0);ZDb(c[o+276>>2]|0);ZDb(c[o+308>>2]|0);p=-12;i=e;return p|0}c[k+88>>2]=1;c[k+84>>2]=1;k=b+52|0;if((c[k>>2]|0)==0){c[k>>2]=1832138337}k=g+320|0;c[k>>2]=0;c[k+4>>2]=-2147483648;p=0;i=e;return p|0}}while(0);yDb(l,16,1962736,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;p=-12;i=e;return p|0}function Ceb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;h=b+60|0;i=c[h>>2]|0;j=c[b+804>>2]|0;k=c[i+276>>2]|0;l=c[i+308>>2]|0;m=c[i+304>>2]|0;n=c[i+272>>2]|0;o=c[i+280>>2]|0;p=i+264|0;q=c[p>>2]<<8;r=b+124|0;s=c[r>>2]|0;t=(s|0)>200?25:s>>3;s=b+120|0;u=c[s>>2]|0;v=(u|0)>320?40:u>>3;u=ba(v,t)|0;do{if((f|0)==0){w=i+260|0;if((c[w>>2]|0)==0){y=0;return y|0}z=c[i+268>>2]|0;if((z|0)==0){A=0;B=0}else{A=z;B=z}c[w>>2]=B;C=A}else{w=i+268|0;z=c[w>>2]|0;D=c[i+260>>2]|0;if(!(z>>>0<D>>>0)){if((z|0)==(D|0)){C=D;break}else{y=0}return y|0}UGb(j|0,f|0,472)|0;c[j+88>>2]=1;c[j+84>>2]=1;D=c[s>>2]|0;z=c[r>>2]|0;E=(z|0)>200?200:z;z=(D|0)>320?320:D;D=c[j>>2]|0;F=j+32|0;G=n+(((c[w>>2]|0)*32e3|0)<<2)|0;H=-200;I=0;J=8;K=1;while(1){L=I-((J|0)>(K|0)?J:K)|0;M=H>>>0>L>>>0?H:L;L=I+8|0;N=0;O=G;P=319;Q=8;R=2;S=-1;while(1){T=P>>>1;U=~T;V=(((Q|0)>(R|0)?Q:R)+S|0)>>>1;W=~V;X=U>>>0>W>>>0?U:W;W=~T;T=~V;V=-(W>>>0>T>>>0?W:T)|0;T=N+8|0;W=I;U=O;while(1){if((W|0)<(E|0)){Y=N;Z=U;while(1){if((Y|0)<(z|0)){_=ba(c[F>>2]|0,W)|0;c[Z>>2]=((d[D+(_+(Y|1))|0]|0)+(d[D+(_+Y)|0]|0)|0)>>>1}_=Y+2|0;if((_|0)<(T|0)&(_|0)<320){Y=_;Z=Z+4|0}else{break}}}Z=W+1|0;if((Z|0)<(L|0)&(Z|0)<200){W=Z;U=U+(V<<2)|0}else{break}}$=O+((ba(M,X)|0)<<2)|0;if((T|0)<320){N=T;O=$;P=P-8|0;Q=Q+8|0;R=R+8|0;S=S-8|0}else{break}}if((L|0)<200){G=$;H=H+8|0;I=L;J=J+8|0;K=K+8|0}else{break}}c[w>>2]=(c[w>>2]|0)+1;K=i+320|0;if(!((c[K>>2]|0)==0&(c[K+4>>2]|0)==(-2147483648|0))){y=0;return y|0}J=f+136|0;I=c[J+4>>2]|0;c[K>>2]=c[J>>2];c[K+4>>2]=I;y=0;return y|0}}while(0);f=i+268|0;$=i+260|0;do{if((C|0)==0){aa=0;ca=55}else{j=(ba(C,u+q|0)|0)+4096|0;r=r0a(b,e,j,(j|0)<0|0?-1:0)|0;if((r|0)<0){y=r;return y|0}r=c[e+24>>2]|0;s=i;D8(n,32,(c[$>>2]|0)*1e3|0,o,256,50,k,s);E8(n,32,(c[$>>2]|0)*1e3|0,o,256,50,k,s);s=c[h>>2]|0;A=c[s+280>>2]|0;B=s+316|0;I=s+284|0;K=0;J=0;while(1){H=c[B>>2]|0;do{if((J|0)<(H-1|0)){G=J+1|0;if((K|0)!=(c[I+(G<<2)>>2]|0)){da=J;ea=H;break}D=I+(J<<2)|0;F=c[D>>2]|0;z=K-F|0;if((z|0)<0){da=G;ea=H;break}a[4599048+F|0]=0;if((z|0)>=1){F=1;do{a[4599048+(F+(c[D>>2]|0))|0]=(F*7|0|0)/(z|0)|0;F=F+1|0;}while((F|0)<=(z|0))}da=G;ea=c[B>>2]|0}else{da=J;ea=H}}while(0);if((da|0)>=(ea-1|0)){a[4599048+K|0]=0}a[4598792+K|0]=da;H=da+1|0;L=(c[B>>2]|0)-1|0;a[4598536+K|0]=(H|0)>(L|0)?L:H;H=K+1|0;if((H|0)<256){K=H;J=da}else{break}}J=s+296|0;K=s+288|0;B=s+264|0;I=0;w=A;H=m;while(1){L=0;z=0;F=0;while(1){D=L<<2;T=L<<1&6;X=T|1;E=0;S=0;R=0;Q=z;P=F;while(1){O=c[w+(S+D<<2)>>2]&255;N=a[4598792+O|0]|0;if((N&255)>>>0>2>>>0){fa=O+P-(c[J>>2]|0)|0}else{fa=P}if(N<<24>>24==0){ga=Q-O+(c[K>>2]|0)|0}else{ga=Q}M=d[4599048+O|0]|0;if((a[909120+(M<<5)+(T<<2)+S|0]|0)==0){ha=N}else{ha=a[4598536+O|0]|0}ia=(ha&3|R<<2)^3;if((a[909120+(M<<5)+(X<<2)+S|0]|0)==0){ja=N}else{ja=a[4598536+O|0]|0}ka=(ja&3|E<<2)^3;O=S+1|0;if((O|0)<4){E=ka;S=O;R=ia;Q=ga;P=fa}else{break}}a[H+L|0]=ia;a[H+(L+2048)|0]=ka;P=L+1|0;if((P|0)<8){L=P;z=ga;F=fa}else{break}}F=(fa|0)>0;do{if(F&(ga|0)>0){if((c[B>>2]|0)==0){ca=52;break}if((ga|0)>(fa|0)){z=0;do{L=c[J>>2]|0;P=w+(z<<2)|0;Q=c[P>>2]|0;c[P>>2]=(L|0)>(Q|0)?Q:L;z=z+1|0;}while((z|0)<32)}else{z=0;do{L=c[K>>2]|0;Q=w+(z<<2)|0;P=c[Q>>2]|0;c[Q>>2]=(L|0)>(P|0)?L:P;z=z+1|0;}while((z|0)<32)}la=H;ma=w;na=I-1|0}else{ca=52}}while(0);if((ca|0)==52){ca=0;a[l+I|0]=F&1;la=H+8|0;ma=w+128|0;na=I}z=na+1|0;if((z|0)<256){I=z;w=ma;H=la}else{break}}UGb(r|0,m|0,4096)|0;if((c[$>>2]|0)<=0){aa=j;ca=55;break}H=u+q|0;w=k;I=r+4096|0;K=j;J=0;while(1){if(!((t|0)<1|(v|0)<1)){B=0;do{A=ba(B,v)|0;s=0;do{z=s+A|0;a[I+z|0]=c[w+(z<<2)>>2];s=s+1|0;}while((s|0)<(v|0));B=B+1|0;}while((B|0)<(t|0))}B=K+u|0;if((c[p>>2]|0)==0){oa=B;pa=u}else{F=0;do{s=a[l+(c[w+(F+256<<2)>>2]|0)|0]<<1|a[l+(c[w+(F<<2)>>2]|0)|0]|a[l+(c[w+(F+512<<2)>>2]|0)|0]<<2;if((F|0)<232){qa=a[l+(c[w+(F+768<<2)>>2]|0)|0]<<3|s}else{qa=s}a[I+(F+u)|0]=qa<<2;F=F+1|0;}while((F|0)<256);oa=B+q|0;pa=H}F=J+1|0;if((F|0)<(c[$>>2]|0)){w=w+4e3|0;I=I+pa|0;K=oa;J=F}else{ra=oa;sa=H;break}}}}while(0);if((ca|0)==55){ra=aa;sa=u+q|0}q=fe(c[f>>2]|0)|0;u=b+96|0;b=(c[u>>2]|0)+4|0;x=q;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=(c[u>>2]|0)+8|0;x=1048576;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;b=fe(sa|0)|0;sa=(c[u>>2]|0)+12|0;x=b;a[sa]=x;x=x>>8;a[sa+1|0]=x;x=x>>8;a[sa+2|0]=x;x=x>>8;a[sa+3|0]=x;c[f>>2]=0;f=i+320|0;i=c[f>>2]|0;sa=c[f+4>>2]|0;b=e+16|0;c[b>>2]=i;c[b+4>>2]=sa;b=e+8|0;c[b>>2]=i;c[b+4>>2]=sa;c[f>>2]=0;c[f+4>>2]=-2147483648;c[e+28>>2]=ra;f=e+36|0;c[f>>2]=c[f>>2]|1;c[g>>2]=(ra|0)!=0;y=0;return y|0}function Deb(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(a+804|0);ZDb(c[b+272>>2]|0);ZDb(c[b+280>>2]|0);ZDb(c[b+304>>2]|0);ZDb(c[b+276>>2]|0);ZDb(c[b+308>>2]|0);return 0}function Eeb(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;c[k>>2]=g;c[l>>2]=h;g=c[a>>2]|0;n=g;o=g;p=g+84|0;q=c[p>>2]|0;a:do{if((q|0)>(h|0)){r=-100}else{s=g+88|0;t=g+48|0;u=g+96|0;v=g+44|0;w=g+4|0;x=q;y=h;while(1){if((x|0)==0){z=0;A=y}else{if((c[u>>2]|0)==0){break}else{z=x;A=y}}while(1){if((z|0)>=(A|0)){r=-100;break a}B=c[s>>2]|0;C=d[(c[k>>2]|0)+z|0]|0|(B<<8|0>>>24);D=c[s+4>>2]<<8|B>>>24|0;c[s>>2]=C;c[s+4>>2]=D;E=Pe[c[t>>2]&255](C,D,n,u,m)|0;if((E|0)!=0){break}z=z+1|0;A=c[l>>2]|0}if((E|0)<1){r=-100;break a}c[s>>2]=0;c[s+4>>2]=0;D=z+1-(c[v>>2]|0)|0;c[p>>2]=E;if((c[m>>2]|0)!=0){if(((c[w>>2]|0)+D|0)>=1){r=D;break a}}C=E+D|0;c[p>>2]=C;D=c[l>>2]|0;if((C|0)>(D|0)){r=-100;break a}else{x=C;y=D}}c[p>>2]=0;r=x}}while(0);if((WRa(o,r,k,l)|0)<0){o=c[p>>2]|0;E=c[l>>2]|0;c[p>>2]=o-((o|0)>(E|0)?E:o);c[e>>2]=0;c[f>>2]=0;F=c[l>>2]|0;i=j;return F|0}c[e>>2]=c[k>>2];c[f>>2]=c[l>>2];l=c[g+100>>2]|0;f=b+48|0;if((l|0)==0){G=c[f>>2]|0}else{c[f>>2]=l;G=l}if((G|0)!=86018){c[b+412>>2]=c[g+56>>2];G=c[b+440>>2]|0;if((G|0)==2){l=b+456|0;c[l>>2]=3;c[l+4>>2]=0}else if((G|0)==1){G=b+456|0;c[G>>2]=4;c[G+4>>2]=0}G=c[g+52>>2]|0;do{if((G|0)>1){l=b+456|0;f=c[l>>2]|0;k=c[l+4>>2]|0;if((f|0)==4&(k|0)==0){c[b+416>>2]=1;l=b+448|0;c[l>>2]=4;c[l+4>>2]=0;break}if(!((G|0)>2&((f|0)==3&(k|0)==0))){H=27;break}c[b+416>>2]=2;k=b+448|0;c[k>>2]=3;c[k+4>>2]=0}else{H=27}}while(0);if((H|0)==27){c[b+416>>2]=G;G=g+72|0;H=c[G+4>>2]|0;k=b+448|0;c[k>>2]=c[G>>2];c[k+4>>2]=H}c[a+304>>2]=c[g+64>>2];c[b+464>>2]=c[g+80>>2]}c[b+72>>2]=c[g+60>>2];F=r;i=j;return F|0}function Feb(a){a=a|0;var b=0;b=c[a>>2]|0;c[b+44>>2]=7;c[b+48>>2]=24;return 0}function Geb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;i=i+56|0;j=h|0;k=h+24|0;l=h+48|0;m=fe(a|0)|0;a=l|0;c[a>>2]=fe(b|0)|0;c[a+4>>2]=m;m=l+8|0;c[j>>2]=m-7;c[j+12>>2]=56;c[j+16>>2]=64;c[j+4>>2]=m;c[j+8>>2]=0;m=FX(j,k)|0;if((m|0)<0){n=0;i=h;return n|0}c[f>>2]=0;c[g>>2]=1;c[e+56>>2]=c[k>>2];c[e+52>>2]=d[1175888+(d[k+15|0]|0)|0]|0;c[e+64>>2]=c[k+4>>2];c[e+60>>2]=c[k+8>>2];n=m;i=h;return n|0}function Heb(b){b=b|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0;f=i;i=i+192|0;h=f|0;j=c[b+60>>2]|0;k=j;c[j+4>>2]=b;l=b+412|0;c[j+6512>>2]=c[l>>2];c[j+6772>>2]=54;c[j+6776>>2]=36;c[j+6780>>2]=488;c[j+6784>>2]=334;c[j+6788>>2]=350;c[b+420>>2]=8;m=c[b+100>>2]|0;do{if((m|0)>0){n=Neb(k,b,j+6504|0,c[b+96>>2]|0,m<<3,1)|0;if((n|0)<0){o=n;i=f;return o|0}else{p=b+416|0;break}}else{n=c[l>>2]|0;do{if((n|0)>92016){q=0}else{if((n|0)>75131){q=1;break}if((n|0)>55425){q=2;break}if((n|0)>46008){q=3;break}if((n|0)>37565){q=4;break}if((n|0)>27712){q=5;break}if((n|0)>23003){q=6;break}if((n|0)>18782){q=7;break}if((n|0)>13855){q=8;break}if((n|0)>11501){q=9;break}q=(n|0)>9390?10:11}}while(0);c[j+6508>>2]=q;n=b+416|0;c[j+6540>>2]=c[n>>2];c[j+6520>>2]=-1;c[j+6544>>2]=-1;r=0;while(1){if(!(r>>>0<8>>>0)){break}if((d[1175888+r|0]|0)==(c[n>>2]|0)){break}else{r=r+1|0}}s=(r|0)==8?0:r;c[j+6516>>2]=s;if((s|0)==0){p=n;break}t=h|0;u=s-1|0;if(u>>>0>6>>>0){yDb(b,16,2031968,(v=i,i=i+8|0,c[v>>2]=s,v)|0);i=v;if((c[b+696>>2]&8|0)==0){p=n;break}else{o=-1094995529}i=f;return o|0}w=a[190072+s|0]|0;UGb(h|0,1878592+(u*15|0)|0,w*3|0)|0;do{if((s|0)==7){if((c[b+680>>2]|0)>=1){break}yDb(b,32,2027768,(v=i,i=i+8|0,c[v>>2]=1,v)|0);i=v;a[h+8|0]=2}}while(0);Ueb(k,t,w,3,0)|0;p=n}}while(0);if((c[p>>2]|0)>64){yDb(b,16,2216760,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;o=-1094995529;i=f;return o|0}c[646365]=9201792;c[646367]=304;N_(2585456,8,e[638508]|0,c[319272]|0,1,1,c[319260]|0,2,2,0,0,0,4)|0;c[646370]=9200712;c[646372]=270;N_(2585476,8,e[638509]|0,c[319273]|0,1,1,c[319261]|0,2,2,0,0,0,4)|0;c[646375]=9198512;c[646377]=550;N_(2585496,8,e[638510]|0,c[319274]|0,1,1,c[319262]|0,2,2,0,0,0,4)|0;c[646380]=9197312;c[646382]=300;N_(2585516,8,e[638511]|0,c[319275]|0,1,1,c[319263]|0,2,2,0,0,0,4)|0;c[646385]=9196e3;c[646387]=328;N_(2585536,8,e[638512]|0,c[319276]|0,1,1,c[319264]|0,2,2,0,0,0,4)|0;c[646390]=9194824;c[646392]=294;N_(2585556,8,e[638513]|0,c[319277]|0,1,1,c[319265]|0,2,2,0,0,0,4)|0;c[646395]=9193600;c[646397]=306;N_(2585576,8,e[638514]|0,c[319278]|0,1,1,c[319266]|0,2,2,0,0,0,4)|0;c[646400]=9192528;c[646402]=268;N_(2585596,8,e[638515]|0,c[319279]|0,1,1,c[319267]|0,2,2,0,0,0,4)|0;c[646405]=9190488;c[646407]=510;N_(2585616,8,e[638516]|0,c[319280]|0,1,1,c[319268]|0,2,2,0,0,0,4)|0;c[646410]=9189024;c[646412]=366;N_(2585636,8,e[638517]|0,c[319281]|0,1,1,c[319269]|0,2,2,0,0,0,4)|0;c[646415]=9187176;c[646417]=462;N_(2585656,8,e[638518]|0,c[319282]|0,1,1,c[319270]|0,2,2,0,0,0,4)|0;ofb();iba(j+5376|0,b);fCb(j+5396|0,c[b+88>>2]&8388608);c[j+5432>>2]=523124044;Dfb();c[646421]=9185768;c[646423]=352;N_(2585680,7,121,1277624,1,1,1277136,4,4,0,0,0,4)|0;aLa(j+5120|0,11,1,2.9802322387695312e-8)|0;aLa(j+5248|0,10,1,5.960464477539063e-8)|0;aLa(j+5184|0,8,1,2.384185791015625e-7)|0;aLa(j+5312|0,11,0,-65536.0)|0;Slb(7996832,4.0,1024);Slb(7996320,6.0,128);VXa(10);VXa(9);VXa(7);if((c[2211057]|0)==0){x=0}else{o=0;i=f;return o|0}while(1){y=+(x|0);z=y*+S(+y,+.3333333333333333);g[8811464+(x<<2)>>2]=z;j=x+1|0;if((j|0)<8192){x=j}else{o=0;break}}i=f;return o|0}function Ieb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+40|0;j=h|0;k=h+32|0;l=b+60|0;m=c[l>>2]|0;n=c[g+24>>2]|0;o=c[g+28>>2]|0;HZ(g,1,h+24|0)|0;p=HZ(g,71,k)|0;q=m+5696|0;c[q>>2]=0;if((p|0)!=0&(c[k>>2]|0)>0){c[q>>2]=(d[p]|0)+1}p=c[m+5692>>2]|0;if((p|0)>-1){c[q>>2]=p}if((o|0)>268435454){r=-1094995529;i=h;return r|0}p=o<<3;q=p>>>0>2147483639>>>0|(n|0)==0;k=q?0:n;s=q?0:p;c[j>>2]=k;p=j+12|0;c[p>>2]=s;t=j+16|0;c[t>>2]=s+8;c[j+4>>2]=k+(s>>3);s=j+8|0;c[s>>2]=0;if(q){r=q?-1094995529:0;i=h;return r|0}q=c[m+6504>>2]|0;do{if((q|0)==17|(q|0)==19|(q|0)==23|(q|0)==39){m=c[l>>2]|0;k=m;u=m+6516|0;v=c[u>>2]|0;w=m+6504|0;x=c[w>>2]|0;if((x|0)==39|(x|0)==23){y=512}else{y=1024}z=m+8|0;c[z>>2]=e;A=Peb(b)|0;if((A|0)<0){r=A;i=h;return r|0}B=m+4|0;c[(c[B>>2]|0)+840>>2]=(c[w>>2]|0)-1;c[m+1004>>2]=0;if(v>>>0>7>>>0){DDb(b,1957112,(C=i,i=i+8|0,c[C>>2]=c[u>>2],C)|0);i=C;r=-1094995529;i=h;return r|0}u=a[190072+v|0]|0;m=v-1|0;v=(x|0)==39;x=A;A=0;while(1){if((A|0)>=(u|0)){D=24;break}E=d[1878592+(m*15|0)+(A*3|0)|0]|0;F=d[1878592+(m*15|0)+(A*3|0)+1|0]|0;w=Qeb(k,E,F)|0;if((w|0)==0){D=16;break}if(!v){G=c[t>>2]|0;H=(c[s>>2]|0)+4|0;c[s>>2]=G>>>0>H>>>0?H:G}if((E|0)==1){I=Seb(k,j,w)|0}else if((E|0)==0){I=Reb(k,w+160|0,j,0)|0}else if((E|0)==3){I=Reb(k,w+160|0,j,0)|0}else{I=x}if((I|0)<0){r=I;D=32;break}else{x=I;A=A+1|0}}if((D|0)==16){yDb(c[B>>2]|0,16,1911456,(C=i,i=i+16|0,c[C>>2]=E,c[C+8>>2]=F,C)|0);i=C;r=-1094995529;i=h;return r|0}else if((D|0)==24){Veb(k);A=c[z>>2]|0;c[A+76>>2]=y;c[A+344>>2]=c[b+412>>2];c[f>>2]=1;A=c[s>>2]|0;x=(c[p>>2]|0)-A|0;v=-A|0;m=(c[t>>2]|0)-A|0;if((x|0)<(v|0)){J=v}else{J=(m|0)<(x|0)?m:x}x=J+A|0;c[s>>2]=x;K=x;break}else if((D|0)==32){i=h;return r|0}}else{x=Oeb(b,e,f,j,g)|0;if((x|0)<0){r=x;i=h;return r|0}else{K=c[s>>2]|0;break}}}while(0);s=K+7>>3;K=s;while(1){if((K|0)>=(o|0)){r=o;D=32;break}if((a[n+K|0]|0)==0){K=K+1|0}else{r=s;D=32;break}}if((D|0)==32){i=h;return r|0}return 0}function Jeb(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;a=b+492|0;d=0;do{e=a+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){qfb(f+112352|0)}$Db(e);e=a+64+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){qfb(f+112352|0)}$Db(e);e=a+128+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){qfb(f+112352|0)}$Db(e);e=a+192+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){qfb(f+112352|0)}$Db(e);d=d+1|0;}while((d|0)<16);bLa(b+5120|0);bLa(b+5184|0);bLa(b+5248|0);bLa(b+5312|0);return 0}function Keb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=(c[a+60>>2]|0)+492|0;a=0;while(1){d=c[b+192+(a<<2)>>2]|0;if((d|0)!=0){TGb(d+9568|0,0,6144)|0;TGb(d+61760|0,0,6144)|0}d=a+1|0;if((d|0)<16){a=d}else{e=0;break}}while(1){a=c[b+128+(e<<2)>>2]|0;if((a|0)!=0){TGb(a+9568|0,0,6144)|0;TGb(a+61760|0,0,6144)|0}a=e+1|0;if((a|0)<16){e=a}else{f=0;break}}while(1){e=c[b+64+(f<<2)>>2]|0;if((e|0)!=0){TGb(e+9568|0,0,6144)|0;TGb(e+61760|0,0,6144)|0}e=f+1|0;if((e|0)<16){f=e}else{g=0;break}}do{f=c[b+(g<<2)>>2]|0;if((f|0)!=0){TGb(f+9568|0,0,6144)|0;TGb(f+61760|0,0,6144)|0}g=g+1|0;}while((g|0)<16);return}function Leb(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;d=Heb(a)|0;if((c[a+100>>2]|0)<=0){return d|0}c[b+6816>>2]=(d|0)==0;return d|0}function Meb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=i;i=i+24|0;h=g|0;j=c[a+60>>2]|0;k=j;l=c[f+24>>2]|0;m=f+28|0;n=c[m>>2]|0;o=n>>>0>268435455>>>0?-8:n<<3;p=o>>>0>2147483639>>>0|(l|0)==0;q=p?0:l;l=p?0:o;o=h|0;c[o>>2]=q;r=h+12|0;c[r>>2]=l;s=l+8|0;t=h+16|0;c[t>>2]=s;c[h+4>>2]=q+(l>>3);l=h+8|0;c[l>>2]=0;if(p){u=p?-1094995529:0;i=g;return u|0}p=q;v=fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;p=s>>>0>11>>>0?11:s;c[l>>2]=p;if((v&-2097152|0)!=1457520640){u=-1094995529;i=g;return u|0}v=q+(p>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(p&3)>>>19;v=p+13|0;p=s>>>0>v>>>0?v:s;c[l>>2]=p;v=w+3|0;if((v|0)>(n|0)){u=-1094995529;i=g;return u|0}n=q+(p>>>3)|0;w=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=p+1|0;x=s>>>0>n>>>0?n:s;c[l>>2]=x;a:do{if((w&-2147483648>>>((p&7)>>>0)|0)==0){n=q+(x>>>3)|0;y=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=x+1|0;c[l>>2]=s>>>0>n>>>0?n:s;n=j+6820|0;c[n>>2]=0;z=(y&-2147483648>>>((x&7)>>>0)|0)!=0;y=c[l>>2]|0;A=c[t>>2]|0;do{if(z){B=q+(y>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)>>>31;B=y+1|0;c[l>>2]=A>>>0>B>>>0?B:A;c[n>>2]=C;if((C|0)!=0){D=q;E=n;break a}C=c[l>>2]|0;B=c[t>>2]|0;F=q+(C>>>3)|0;G=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(C&7)>>>30;F=C+2|0;C=B>>>0>F>>>0?F:B;c[l>>2]=C;F=G<<3;G=F+8|0;if(G>>>0<26>>>0){H=G+C|0;G=B>>>0>H>>>0?H:B;c[l>>2]=G;I=G;J=B;break}else{G=C+16|0;C=(B>>>0>G>>>0?G:B)-8+F|0;F=B>>>0>C>>>0?C:B;c[l>>2]=F;I=F;J=B;break}}else{I=y;J=A}}while(0);A=I+1|0;y=(J>>>0>A>>>0?A:J)+6|0;A=J>>>0>y>>>0?y:J;c[l>>2]=A;y=q+(A>>>3)|0;B=fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=A+4|0;F=J>>>0>y>>>0?y:J;c[l>>2]=F;if((-268435456>>>((A&7)>>>0)&B|0)!=0){DDb(c[j+4>>2]|0,1975280,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-1163346256;i=g;return u|0}B=q+(F>>>3)|0;A=fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0;B=F+3|0;y=J>>>0>B>>>0?B:J;c[l>>2]=y;if((A&-536870912>>>((F&7)>>>0)|0)!=0){DDb(c[j+4>>2]|0,1973344,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-1163346256;i=g;return u|0}do{if(z){F=q+(y>>>3)|0;A=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(y&7)>>>30;F=y+2|0;B=J>>>0>F>>>0?F:J;c[l>>2]=B;F=A<<3;A=F+8|0;C=q+(B>>>3)|0;G=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7);if(A>>>0<26>>>0){C=A+B|0;c[l>>2]=J>>>0>C>>>0?C:J;L=G>>>((24-F|0)>>>0)}else{C=B+16|0;B=J>>>0>C>>>0?C:J;c[l>>2]=B;C=F-8|0;A=q+(B>>>3)|0;H=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(B&7)>>>((40-F|0)>>>0);F=C+B|0;c[l>>2]=J>>>0>F>>>0?F:J;L=H|G>>>16<<C}C=afb(k,h,L)|0;if((C|0)<0){u=C;i=g;return u|0}G=L-C|0;C=c[l>>2]|0;H=-C|0;F=c[t>>2]|0;B=F-C|0;if((G|0)<(H|0)){M=H}else{M=(B|0)<(G|0)?B:G}G=M+C|0;c[l>>2]=G;N=G;O=F}else{F=afb(k,h,0)|0;if((F|0)<0){u=F;i=g;return u|0}else{N=c[l>>2]|0;O=c[t>>2]|0;break}}}while(0);y=c[o>>2]|0;F=y+(N>>>3)|0;G=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(N&7)>>>29;F=N+3|0;c[l>>2]=O>>>0>F>>>0?F:O;c[j+6824>>2]=G;switch(G|0){case 0:{G=c[t>>2]|0;F=(c[l>>2]|0)+8|0;c[l>>2]=G>>>0>F>>>0?F:G;break};case 3:case 4:case 5:{G=c[t>>2]|0;F=(c[l>>2]|0)+6|0;c[l>>2]=G>>>0>F>>>0?F:G;break};case 1:{G=c[l>>2]|0;F=c[t>>2]|0;C=y+(G>>>3)|0;B=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(G&7)>>>23;C=G+9|0;c[l>>2]=F>>>0>C>>>0?C:F;c[j+6828>>2]=B;break};case 6:case 7:{B=c[t>>2]|0;F=(c[l>>2]|0)+1|0;c[l>>2]=B>>>0>F>>>0?F:B;break};default:{}}B=c[l>>2]|0;F=c[t>>2]|0;C=y+(B>>>3)|0;G=fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=B+1|0;H=F>>>0>C>>>0?C:F;c[l>>2]=H;b:do{if((G&-2147483648>>>((B&7)>>>0)|0)==0){P=H}else{if(!z){C=H;while(1){A=y+(C>>>3)|0;Q=fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0;A=C+1|0;R=(F>>>0>A>>>0?A:F)+8|0;A=F>>>0>R>>>0?R:F;c[l>>2]=A;if((Q&-2147483648>>>((C&7)>>>0)|0)==0){P=A;break b}else{C=A}}}C=y+(H>>>3)|0;A=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(H&7)>>>30;C=H+2|0;Q=F>>>0>C>>>0?C:F;c[l>>2]=Q;C=A<<3;A=C+8|0;if(A>>>0<26>>>0){R=A+Q|0;A=F>>>0>R>>>0?R:F;c[l>>2]=A;P=A;break}else{A=Q+16|0;Q=(F>>>0>A>>>0?A:F)-8+C|0;C=F>>>0>Q>>>0?Q:F;c[l>>2]=C;P=C;break}}}while(0);H=y+(P>>>3)|0;z=fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0;H=P+1|0;B=F>>>0>H>>>0?H:F;c[l>>2]=B;if((z&-2147483648>>>((P&7)>>>0)|0)==0){D=y;E=n;break}z=B+8|0;c[l>>2]=F>>>0>z>>>0?z:F;D=y;E=n}else{z=c[j+4>>2]|0;if((c[z+96>>2]|0)!=0){D=q;E=j+6820|0;break}yDb(z,48,1983464,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-11;i=g;return u|0}}while(0);do{if((c[E>>2]|0)==0){switch(c[j+6824>>2]|0){case 3:case 5:case 7:{q=c[t>>2]|0;P=(c[l>>2]|0)+2|0;c[l>>2]=q>>>0>P>>>0?P:q;S=0;break};case 0:{q=c[t>>2]|0;P=0;O=c[l>>2]|0;while(1){N=D+(O>>>3)|0;k=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(O&7)>>>24;N=O+8|0;M=q>>>0>N>>>0?N:q;c[l>>2]=M;N=k+P|0;if((k|0)==255){P=N;O=M}else{S=N;break}}break};case 1:{S=c[j+6828>>2]|0;break};default:{S=0}}O=S<<3;P=(c[r>>2]|0)-(c[l>>2]|0)|0;if((O|0)>(P|0)){yDb(c[j+4>>2]|0,16,1980608,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-1094995529;i=g;return u|0}if((O+256|0)>=(P|0)){break}yDb(c[j+4>>2]|0,16,1977840,(K=i,i=i+16|0,c[K>>2]=O,c[K+8>>2]=P,K)|0);i=K;u=-1094995529;i=g;return u|0}}while(0);r=j+6816|0;do{if((c[r>>2]|0)==0){S=a+96|0;t=c[S>>2]|0;if((t|0)==0){c[e>>2]=0;u=c[m>>2]|0;i=g;return u|0}E=j;P=j+6760|0;O=j+6504|0;if((c[P>>2]|0)==4){UGb(j+6240|0,O|0,264)|0;T=c[S>>2]|0}else{T=t}c[P>>2]=0;t=Neb(E,a,O,T,c[a+100>>2]<<3,1)|0;if((t|0)>=0){c[r>>2]=1;U=c[o>>2]|0;break}if((c[P>>2]|0)==4){u=t;i=g;return u|0}if((c[j+6496>>2]|0)==0){u=t;i=g;return u|0}UGb(O|0,j+6240|0,264)|0;O=c[j+4>>2]|0;c[O+416>>2]=c[j+6744>>2];S=j+6752|0;q=c[S+4>>2]|0;n=O+448|0;c[n>>2]=c[S>>2];c[n+4>>2]=q;Ueb(E,j+6548|0,c[j+6740>>2]|0,c[P>>2]|0,0)|0;u=t;i=g;return u|0}else{U=D}}while(0);D=c[l>>2]|0;l=U+(D>>>3)|0;if(((fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(D&7)&-1048576|0)==-1048576){yDb(c[j+4>>2]|0,16,1999520,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-1094995529;i=g;return u|0}else{K=Oeb(a,b,e,h,f)|0;u=(K|0)<0?K:v;i=g;return u|0}return 0}function Neb(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=i;i=i+216|0;l=k|0;m=k+192|0;n=h>>>0>2147483639>>>0|(g|0)==0;o=n?0:g;p=n?0:h;q=m|0;c[q>>2]=o;c[m+12>>2]=p;r=p+8|0;s=m+16|0;c[s>>2]=r;c[m+4>>2]=o+(p+7>>3);t=m+8|0;c[t>>2]=0;if(n){u=n?-1094995529:0;i=k;return u|0}n=QMa(f,g,h,j)|0;if((n|0)<0){u=-1094995529;i=k;return u|0}j=c[f+4>>2]|0;if((j|0)>12){yDb(e,16,1934512,(v=i,i=i+8|0,c[v>>2]=j,v)|0);i=v;u=-1094995529;i=k;return u|0}h=f|0;g=c[h>>2]|0;a:do{if((g|0)==23){if(!((j-3|0)>>>0>4>>>0)){w=(r|0)<(n|0)?r:n;c[t>>2]=w;x=w;y=10;break}yDb(e,16,2020984,(v=i,i=i+8|0,c[v>>2]=j,v)|0);i=v;u=-1094995529;i=k;return u|0}else{w=(r|0)<(n|0)?r:n;c[t>>2]=w;switch(g|0){case 39:{break};case 1:case 2:case 4:case 17:{x=w;y=10;break a;break};default:{EDb(e,2017144,(v=i,i=i+16|0,c[v>>2]=(c[f+16>>2]|0)==1?2013272:9203200,c[v+8>>2]=g,v)|0);i=v;u=-38;i=k;return u|0}}z=c[f+12>>2]|0;A=l|0;c[f+40>>2]=0;c[f+16>>2]=0;B=d[o+(w>>>3)|0]|0;C=((w|0)<(r|0))+w|0;c[t>>2]=C;if((B&128>>>((w&7)>>>0)|0)!=0){DDb(e,1998440,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1163346256;i=k;return u|0}w=o+(C>>>3)|0;B=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(C&7)>>>29;w=C+3|0;C=r>>>0>w>>>0?w:r;c[t>>2]=C;if((B|0)!=0){EDb(e,1994552,(v=i,i=i+8|0,c[v>>2]=B,v)|0);i=v;u=-1163346256;i=k;return u|0}B=d[o+(C>>>3)|0]|0;w=((C|0)<(r|0))+C|0;c[t>>2]=w;if((B&128>>>((C&7)>>>0)|0)!=0){EDb(e,1991192,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1163346256;i=k;return u|0}C=o+(w>>>3)|0;B=fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=w+4|0;D=r>>>0>C>>>0?C:r;c[t>>2]=D;b:do{if((B&-268435456>>>((w&7)>>>0)|0)!=0){C=D;while(1){E=o+(C>>>3)|0;F=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(C&7)>>>28;E=C+4|0;G=r>>>0>E>>>0?E:r;c[t>>2]=G;do{if((F|0)==15){E=o+(G>>>3)|0;H=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(G&7)>>>24;E=G+8|0;I=r>>>0>E>>>0?E:r;c[t>>2]=I;E=H+15|0;if((E|0)!=270){J=E;K=I;break}E=o+(I>>>3)|0;H=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(I&7)>>>16;E=I+16|0;I=r>>>0>E>>>0?E:r;c[t>>2]=I;J=H+270|0;K=I}else{J=F;K=G}}while(0);G=J<<3;if((p-K|0)<(G|4|0)){break}F=-K|0;I=r-K|0;if((G|0)<(F|0)){L=F}else{L=(I|0)<(G|0)?I:G}G=L+K|0;I=o+(G>>>3)|0;F=fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0;I=G+4|0;C=r>>>0>I>>>0?I:r;c[t>>2]=C;if((-268435456>>>((G&7)>>>0)&F|0)==0){break b}}yDb(c[b+4>>2]|0,16,2328312,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1094995529;i=k;return u|0}}while(0);D=l|0;w=z-1|0;if(w>>>0>6>>>0){yDb(e,16,2031968,(v=i,i=i+8|0,c[v>>2]=z,v)|0);i=v;u=-1094995529;i=k;return u|0}B=a[190072+z|0]|0;UGb(A|0,1878592+(w*15|0)|0,B*3|0)|0;do{if((z|0)==7){if((c[e+680>>2]|0)>=1){break}yDb(e,32,2027768,(v=i,i=i+8|0,c[v>>2]=1,v)|0);i=v;a[l+8|0]=2}}while(0);do{if((b|0)!=0){z=Ueb(b,D,B,3,0)|0;if((z|0)==0){break}if((z|0)<0){u=z}else{break a}i=k;return u|0}}while(0);B=c[t>>2]|0;D=c[s>>2]|0;z=(c[q>>2]|0)+(B>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7)>>>30;z=B+2|0;c[t>>2]=D>>>0>z>>>0?z:D;if((A|0)==0){break}EDb(e,1987728,(v=i,i=i+8|0,c[v>>2]=A,v)|0);i=v;u=-1163346256;i=k;return u|0}}while(0);c:do{if((y|0)==10){K=c[f+12>>2]|0;L=l|0;p=d[o+(x>>>3)|0]|0;J=((x|0)<(r|0))+x|0;c[t>>2]=J;if((p&128>>>((x&7)>>>0)|0)!=0){DDb(e,1998440,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1163346256;i=k;return u|0}p=((J|0)<(r|0))+J|0;if((d[o+(J>>>3)|0]&128>>>((J&7)>>>0)|0)==0){M=p}else{J=p+14|0;M=r>>>0>J>>>0?J:r}J=M&7;p=d[o+(M>>>3)|0]|0;n=((M|0)<(r|0))+M|0;c[t>>2]=n;if((g|0)==6|(g|0)==20){j=n+3|0;A=r>>>0>j>>>0?j:r;c[t>>2]=A;N=A}else{N=n}do{if((K|0)==0){n=N+4|0;c[t>>2]=r>>>0>n>>>0?n:r;n=Teb(e,f,l|0,m)|0;if((n|0)<0){u=n}else{O=n;break}i=k;return u|0}else{n=K-1|0;if(n>>>0>6>>>0){yDb(e,16,2031968,(v=i,i=i+8|0,c[v>>2]=K,v)|0);i=v;u=-1094995529;i=k;return u|0}A=a[190072+K|0]|0;UGb(L|0,1878592+(n*15|0)|0,A*3|0)|0;if((K|0)!=7){O=A;break}if((c[e+680>>2]|0)>=1){O=A;break}yDb(e,32,2027768,(v=i,i=i+8|0,c[v>>2]=1,v)|0);i=v;a[l+8|0]=2;O=A}}while(0);K=l|0;do{if((O|0)>0){L=0;A=0;do{n=a[l+(A*3|0)+2|0]|0;if(n<<24>>24==0){P=0}else{P=n<<24>>24!=5|0}L=(((a[l+(A*3|0)|0]|0)==1?2:1)&-P)+L|0;A=A+1|0;}while((A|0)<(O|0));if((L|0)<=1){y=29;break}c[f+40>>2]=0}else{y=29}}while(0);do{if((y|0)==29){if((c[f+16>>2]|0)!=1){break}A=f+40|0;if(!((c[A>>2]|0)==-1)){break}c[A>>2]=1}}while(0);do{if((b|0)!=0){A=Ueb(b,K,O,3,0)|0;if((A|0)==0){break}if((A|0)<0){u=A}else{break c}i=k;return u|0}}while(0);K=c[h>>2]|0;if((p&128>>>(J>>>0)|0)!=0){d:do{switch(K|0){case 17:case 19:case 20:case 23:{A=c[t>>2]|0;n=c[s>>2]|0;j=(c[q>>2]|0)+(A>>>3)|0;D=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(A&7)>>>29;j=A+3|0;A=n>>>0>j>>>0?j:n;c[t>>2]=A;if((D|0)==0){Q=A;R=n;break d}EDb(e,1994552,(v=i,i=i+8|0,c[v>>2]=D,v)|0);i=v;u=-1163346256;i=k;return u|0};case 22:{D=c[s>>2]|0;n=(c[t>>2]|0)+5|0;A=(D>>>0>n>>>0?n:D)+11|0;n=D>>>0>A>>>0?A:D;c[t>>2]=n;Q=n;R=D;break};default:{Q=c[t>>2]|0;R=c[s>>2]|0}}}while(0);J=Q+1|0;c[t>>2]=R>>>0>J>>>0?J:R}if(!((K|0)==17|(K|0)==19|(K|0)==20|(K|0)==23)){break}J=c[t>>2]|0;p=c[s>>2]|0;D=(c[q>>2]|0)+(J>>>3)|0;n=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(J&7)>>>30;D=J+2|0;c[t>>2]=p>>>0>D>>>0?D:p;if((n|0)==0){break}EDb(e,1987728,(v=i,i=i+8|0,c[v>>2]=n,v)|0);i=v;u=-1163346256;i=k;return u|0}}while(0);u=c[t>>2]|0;i=k;return u|0}function Oeb(e,f,h,j,k){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0.0,ua=0,va=0,wa=0,xa=0.0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0.0,Na=0,Oa=0,Pa=0.0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0.0,Va=0,Wa=0.0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0.0,nb=0,ob=0.0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0;l=i;i=i+688|0;m=l|0;n=l+256|0;o=l+264|0;p=l+272|0;q=l+296|0;r=l+488|0;s=l+680|0;t=c[e+60>>2]|0;u=t;v=t+8|0;c[v>>2]=f;w=j|0;y=j+8|0;z=c[y>>2]|0;A=(c[w>>2]|0)+(z>>>3)|0;a:do{if(((fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7)&-1048576|0)==-1048576){B=q|0;C=FX(j,p)|0;b:do{if((C|0)>0){D=t+6768|0;do{if((c[D>>2]|0)==0){if((a[p+16|0]|0)==1){break}EDb(c[t+4>>2]|0,2024288,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;c[D>>2]=1}}while(0);D=t+6760|0;if((c[D>>2]|0)==4){UGb(t+6240|0,t+6504|0,264)|0}c[D>>2]=0;F=p+15|0;G=a[F]|0;do{if(G<<24>>24==0){c[t+6516>>2]=0;if((c[t+5696>>2]|0)==0){break}if((c[t+6496>>2]|0)!=0){break}a[q+3|0]=0;a[B]=0;a[q+5|0]=1;a[q+2|0]=1;a[q+1|0]=0;a[q+4|0]=1;if((Ueb(u,q|0,2,2,0)|0)!=0){H=-7;break b}}else{I=G&255;c[t+6516>>2]=I;J=c[t+4>>2]|0;K=q|0;L=I-1|0;if(L>>>0>6>>>0){yDb(J,16,2031968,(E=i,i=i+8|0,c[E>>2]=I,E)|0);i=E;H=-1094995529;break b}M=a[190072+I|0]|0;UGb(B|0,1878592+(L*15|0)|0,M*3|0)|0;do{if(G<<24>>24==7){if((c[J+680>>2]|0)>=1){N=0;break}yDb(J,32,2027768,(E=i,i=i+8|0,c[E>>2]=1,E)|0);i=E;a[q+8|0]=2;N=c[D>>2]|0}else{N=0}}while(0);J=Ueb(u,K,M,N>>>0>2>>>0?N:2,0)|0;if((J|0)<0){H=J;break b}}}while(0);D=c[p>>2]|0;c[t+6512>>2]=D;c[t+6508>>2]=d[p+14|0]|0;c[t+6504>>2]=d[p+13|0]|0;do{if((c[t+6496>>2]|0)==4){if((c[t+6252>>2]|0)!=(d[F]|0)){O=21;break}if((c[t+6248>>2]|0)!=(D|0)){O=21}}else{O=21}}while(0);if((O|0)==21){c[t+6520>>2]=-1;c[t+6544>>2]=-1}if((a[p+12|0]|0)!=0){O=24;break}D=c[j+16>>2]|0;F=(c[y>>2]|0)+16|0;c[y>>2]=D>>>0>F>>>0?F:D;O=24}else{O=24}}while(0);do{if((O|0)==24){if((C|0)<0){H=C;break}B=c[t+6508>>2]|0;if((B|0)<=12){O=28;break a}yDb(c[t+4>>2]|0,16,1934512,(E=i,i=i+8|0,c[E>>2]=B,E)|0);i=E;P=-1094995529;break a}}while(0);yDb(e,16,1962696,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;P=H}else{O=28}}while(0);c:do{if((O|0)==28){H=Peb(e)|0;if((H|0)<0){P=H;break}p=t+6504|0;N=p;q=t+4|0;c[(c[q>>2]|0)+840>>2]=(c[p>>2]|0)-1;c[t+1004>>2]=0;z=j+16|0;A=j+12|0;C=t+6760|0;B=t+6240|0;D=r|0;F=t+6516|0;G=e;J=t+6520|0;L=t+6544|0;I=t+6548|0;Q=t+6740|0;R=t+488|0;T=t+412|0;U=t+416|0;V=t+16|0;W=m|0;X=0;Y=0;Z=0;_=0;$=7;aa=0;ba=H;H=c[y>>2]|0;d:while(1){ca=c[z>>2]|0;da=c[w>>2]|0;ea=da+(H>>>3)|0;fa=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(H&7);ga=fa>>>29;ea=H+3|0;ha=ca>>>0>ea>>>0?ea:ca;c[y>>2]=ha;if((ga|0)==7){O=158;break}ea=da+(ha>>>3)|0;ia=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ha&7)>>>28;ea=ha+4|0;c[y>>2]=ca>>>0>ea>>>0?ea:ca;if((fa|0)>-1){fa=Qeb(u,ga,ia)|0;if((fa|0)==0){O=33;break}else{ja=fa;ka=1024}}else{ja=Y;ka=aa}e:do{switch(ga|0){case 2:{fa=c[y>>2]|0;ca=c[w>>2]|0;ea=d[ca+(fa>>>3)|0]<<(fa&7)>>>7;ha=c[z>>2]|0;da=((fa|0)<(ha|0))+fa|0;c[y>>2]=da;fa=ja+104544|0;c[fa>>2]=ea<<1&2;ea=ca+(da>>>3)|0;la=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(da&7)>>>29;ea=da+3|0;c[y>>2]=ha>>>0>ea>>>0?ea:ha;ha=ja+104548|0;c[ha>>2]=la;la=0;ea=0;while(1){da=ea+1|0;ma=c[y>>2]|0;na=d[ca+(ma>>>3)|0]<<(ma&7);oa=c[z>>2]|0;pa=((ma|0)<(oa|0))+ma|0;c[y>>2]=pa;ma=na>>>7&1;c[ja+104552+(la<<2)>>2]=ma;na=ca+(pa>>>3)|0;qa=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(pa&7)>>>28;na=pa+4|0;c[y>>2]=oa>>>0>na>>>0?na:oa;c[ja+104584+(la<<2)>>2]=qa;if((ma|0)==0){c[ja+104616+(la<<2)>>2]=2;ra=da}else{ma=c[y>>2]|0;qa=c[z>>2]|0;oa=ca+(ma>>>3)|0;na=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ma&7)>>>30;oa=ma+2|0;c[y>>2]=qa>>>0>oa>>>0?oa:qa;c[ja+104616+(la<<2)>>2]=na;ra=(na|0)==3?ea+2|0:da}da=la+1|0;if((da|0)>(c[ha>>2]|0)){break}else{la=da;ea=ra}}ea=ja+160|0;la=c[y>>2]|0;ha=d[ca+(la>>>3)|0]|0;M=c[z>>2]|0;K=((la|0)<(M|0))+la|0;c[y>>2]=K;da=c[fa>>2]|0;if((ha&128>>>((la&7)>>>0)|0)==0){sa=da>>>0>1>>>0|0}else{sa=1}c[fa>>2]=sa+da;da=ca+(K>>>3)|0;la=fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0;da=K+1|0;ha=M>>>0>da>>>0?da:M;c[y>>2]=ha;da=ca+(ha>>>3)|0;na=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ha&7)>>>30;da=ha+2|0;c[y>>2]=M>>>0>da>>>0?da:M;ta=+g[1502704+(na<<2)>>2];na=Reb(u,ea,j,0)|0;if((na|0)!=0){P=na;break c}if((ra|0)<=0){ua=_;va=Z;wa=X;break e}na=ja+176|0;M=ea|0;ea=(la&-2147483648>>>((K&7)>>>0)|0)==0;K=0;while(1){la=c[fa>>2]|0;if((K|0)==0){xa=1.0;ya=0;za=1}else{da=c[y>>2]|0;if((la|0)==3){Aa=1;Ba=da;Ca=c[z>>2]|0;Da=c[w>>2]|0;O=51}else{ha=c[w>>2]|0;qa=d[ha+(da>>>3)|0]<<(da&7)>>>7;oa=c[z>>2]|0;ma=((da|0)<(oa|0))+da|0;c[y>>2]=ma;da=qa&1;if((da|0)==0){Ea=0;Fa=0}else{Aa=da;Ba=ma;Ca=oa;Da=ha;O=51}}if((O|0)==51){O=0;ha=c[646421]|0;oa=Da+(Ba>>>3)|0;ma=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(Ba&7)>>>25;oa=b[ha+(ma<<2)>>1]|0;da=b[ha+(ma<<2)+2>>1]|0;ma=da<<16>>16;do{if(da<<16>>16<0){qa=Ba+7|0;pa=Ca>>>0>qa>>>0?qa:Ca;qa=Da+(pa>>>3)|0;Ga=((fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(pa&7)>>>((ma+32|0)>>>0))+oa|0;qa=b[ha+(Ga<<2)>>1]|0;Ha=b[ha+(Ga<<2)+2>>1]|0;Ga=Ha<<16>>16;if(!(Ha<<16>>16<0)){Ia=Ga;Ja=qa;Ka=pa;break}Ha=pa-ma|0;pa=Ca>>>0>Ha>>>0?Ha:Ca;Ha=Da+(pa>>>3)|0;La=((fe(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(pa&7)>>>((Ga+32|0)>>>0))+qa|0;Ia=b[ha+(La<<2)+2>>1]|0;Ja=b[ha+(La<<2)>>1]|0;Ka=pa}else{Ia=ma;Ja=oa;Ka=Ba}}while(0);oa=Ia+Ka|0;c[y>>2]=Ca>>>0>oa>>>0?oa:Ca;Ea=Ja-60|0;Fa=Aa}xa=+S(+ta,+(+(-Ea|0)));ya=Ea;za=Fa}do{if((la|0)==3){g[ja+104648+(K*480|0)>>2]=xa}else{oa=c[na>>2]|0;if((oa|0)<=0){break}ma=(za|0)==0;ha=a[M]|0;da=0;pa=0;La=ya;Ma=xa;qa=ha;Ga=oa;oa=ha;while(1){if(qa<<24>>24==0){Na=pa;Oa=La;Pa=Ma;Qa=0;Ra=Ga;Sa=oa}else{ha=0;Ha=pa;Ta=La;Ua=Ma;Va=oa;while(1){if((c[ja+3332+(Ha<<2)>>2]|0)==0){Wa=Ua;Xa=Ta;Ya=Va}else{do{if(ma){Za=c[646421]|0;_a=c[y>>2]|0;$a=c[z>>2]|0;ab=c[w>>2]|0;bb=ab+(_a>>>3)|0;cb=(fe(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(_a&7)>>>25;bb=b[Za+(cb<<2)>>1]|0;db=b[Za+(cb<<2)+2>>1]|0;cb=db<<16>>16;do{if(db<<16>>16<0){eb=_a+7|0;fb=$a>>>0>eb>>>0?eb:$a;eb=ab+(fb>>>3)|0;gb=((fe(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(fb&7)>>>((cb+32|0)>>>0))+bb|0;eb=b[Za+(gb<<2)>>1]|0;hb=b[Za+(gb<<2)+2>>1]|0;gb=hb<<16>>16;if(!(hb<<16>>16<0)){ib=gb;jb=eb;kb=fb;break}hb=fb-cb|0;fb=$a>>>0>hb>>>0?hb:$a;hb=ab+(fb>>>3)|0;lb=((fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(fb&7)>>>((gb+32|0)>>>0))+eb|0;ib=b[Za+(lb<<2)+2>>1]|0;jb=b[Za+(lb<<2)>>1]|0;kb=fb}else{ib=cb;jb=bb;kb=_a}}while(0);_a=ib+kb|0;c[y>>2]=$a>>>0>_a>>>0?_a:$a;_a=jb-60|0;if((_a|0)==0){mb=Ua;nb=Ta;break}bb=_a+Ta|0;if(ea){ob=1.0;pb=bb}else{ob=+(1-(bb<<1&2)|0);pb=bb>>1}mb=ob*+S(+ta,+(+(-pb|0)));nb=bb}else{mb=Ua;nb=Ta}}while(0);g[ja+104648+(K*480|0)+(Ha<<2)>>2]=mb;Wa=mb;Xa=nb;Ya=a[M]|0}bb=ha+1|0;qb=Ha+1|0;if((bb|0)<(Ya&255|0)){ha=bb;Ha=qb;Ta=Xa;Ua=Wa;Va=Ya}else{break}}Na=qb;Oa=Xa;Pa=Wa;Qa=Ya;Ra=c[na>>2]|0;Sa=Ya}Va=da+1|0;if((Va|0)<(Ra|0)){da=Va;pa=Na;La=Oa;Ma=Pa;qa=Qa;Ga=Ra;oa=Sa}else{break}}}}while(0);la=K+1|0;if((la|0)<(ra|0)){K=la}else{ua=_;va=Z;wa=X;break}}break};case 6:{K=c[y>>2]|0;if((ia|0)==15){na=c[z>>2]|0;M=(c[w>>2]|0)+(K>>>3)|0;ea=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>24;M=K+8|0;fa=na>>>0>M>>>0?M:na;c[y>>2]=fa;rb=ea+14|0;sb=fa}else{rb=ia;sb=K}if(((c[A>>2]|0)-sb|0)<(rb<<3|0)){O=98;break d}if((rb|0)<=0){ua=_;va=Z;wa=X;break e}K=(Y|0)==0;fa=Y+112352|0;ea=rb;na=sb;while(1){M=c[z>>2]|0;ca=c[w>>2]|0;la=ca+(na>>>3)|0;oa=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(na&7)>>>28;la=na+4|0;Ga=M>>>0>la>>>0?la:M;c[y>>2]=Ga;do{if((oa|0)==11){la=d[ca+(Ga>>>3)|0]|0;qa=((Ga|0)<(M|0))+Ga|0;c[y>>2]=qa;if((la&128>>>((Ga&7)>>>0)|0)==0){tb=1;ub=qa;vb=M}else{la=ca+(qa>>>3)|0;La=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(qa&7)>>>28;la=qa+4|0;c[y>>2]=M>>>0>la>>>0?la:M;c[V>>2]=La;La=c[z>>2]|0;la=(c[y>>2]|0)+4|0;qa=La>>>0>la>>>0?la:La;c[y>>2]=qa;tb=2;ub=qa;vb=La}La=d[ca+(ub>>>3)|0]|0;qa=((ub|0)<(vb|0))+ub|0;c[y>>2]=qa;if((La&128>>>((ub&7)>>>0)|0)==0){wb=tb;xb=qa;yb=vb}else{qa=0;La=0;f:while(1){g:do{if((qa|0)<57){la=La;while(1){if((la|0)<7){zb=la;break g}pa=c[y>>2]|0;da=d[ca+(pa>>>3)|0]|0;ma=c[z>>2]|0;Va=((pa|0)<(ma|0))+pa|0;c[y>>2]=Va;if((da&128>>>((pa&7)>>>0)|0)==0){Ab=Va;Bb=ma;break f}else{la=0}}}else{if((La|0)<7){zb=La}else{O=125;break f}}}while(0);la=c[y>>2]|0;ma=d[ca+(la>>>3)|0]<<(la&7)>>>7;c[y>>2]=((la|0)<(c[z>>2]|0))+la;c[u+156+(qa<<2)>>2]=ma&1;qa=qa+1|0;La=zb+1|0}if((O|0)==125){O=0;Ab=c[y>>2]|0;Bb=c[z>>2]|0}wb=((qa|0)/7|0)+tb|0;xb=Ab;yb=Bb}La=d[ca+(xb>>>3)|0]|0;ma=((xb|0)<(yb|0))+xb|0;c[y>>2]=ma;if((La&128>>>((xb&7)>>>0)|0)==0){Cb=1;Db=wb;Eb=ma;Fb=yb}else{La=ca+(ma>>>3)|0;la=(fe(d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0)|0)<<(ma&7)>>>28;La=ma+4|0;c[y>>2]=yb>>>0>La>>>0?La:yb;c[T>>2]=la;la=c[y>>2]|0;La=c[z>>2]|0;ma=ca+(la>>>3)|0;Va=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7)>>>28;ma=la+4|0;c[y>>2]=La>>>0>ma>>>0?ma:La;c[U>>2]=Va;Va=c[T>>2]|0;La=Va+1|0;ma=wb+1|0;if((La|0)>0){la=0;do{pa=c[y>>2]|0;da=c[z>>2]|0;Ta=ca+(pa>>>3)|0;Ha=(fe(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(pa&7)>>>24;Ta=pa+8|0;c[y>>2]=da>>>0>Ta>>>0?Ta:da;c[u+420+(la<<2)>>2]=Ha;la=la+1|0;}while((la|0)<(La|0));Gb=wb+2+Va|0}else{Gb=ma}Cb=La;Db=Gb;Eb=c[y>>2]|0;Fb=c[z>>2]|0}la=d[ca+(Eb>>>3)|0]|0;qa=((Eb|0)<(Fb|0))+Eb|0;c[y>>2]=qa;if((la&128>>>((Eb&7)>>>0)|0)==0){Hb=Db;Ib=qa;Jb=Fb}else{la=ca+(qa>>>3)|0;Ha=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(qa&7)>>>25;la=qa+7|0;c[y>>2]=Fb>>>0>la>>>0?la:Fb;c[R>>2]=Ha;Ha=c[z>>2]|0;la=(c[y>>2]|0)+1|0;qa=Ha>>>0>la>>>0?la:Ha;c[y>>2]=qa;Hb=Db+1|0;Ib=qa;Jb=Ha}if((Cb|0)>0){Kb=0;Lb=Ib;Mb=Jb}else{Nb=Hb;break}while(1){Ha=d[ca+(Lb>>>3)|0]<<(Lb&7)>>>7;c[y>>2]=((Lb|0)<(Mb|0))+Lb;c[u+20+(Kb<<2)>>2]=Ha&1;Ha=c[y>>2]|0;qa=c[z>>2]|0;la=ca+(Ha>>>3)|0;da=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(Ha&7)>>>25;la=Ha+7|0;c[y>>2]=qa>>>0>la>>>0?la:qa;c[u+88+(Kb<<2)>>2]=da;da=Kb+1|0;if((da|0)>=(Cb|0)){break}Kb=da;Lb=c[y>>2]|0;Mb=c[z>>2]|0}Nb=Hb+Cb|0}else if((oa|0)==14){Ob=1;O=101}else if((oa|0)==13){Ob=0;O=101}else if((oa|0)==0){La=ea<<3;ma=La-4|0;do{if((ma|0)<69){Pb=ma}else{Va=Ga+13|0;da=M>>>0>Va>>>0?Va:M;c[y>>2]=da;Va=La-17|0;if((Va|0)>7){qa=~((La-25|0)>>>3);la=qa>>>0>4294967041>>>0;Ha=Va;Ta=0;pa=1;ha=da;while(1){da=ca+(ha>>>3)|0;bb=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ha&7)>>>24;da=ha+8|0;_a=M>>>0>da>>>0?da:M;c[y>>2]=_a;a[m+Ta|0]=bb;bb=Ha-8|0;da=pa+1|0;if(da>>>0<256>>>0&(bb|0)>7){Ha=bb;Ta=pa;pa=da;ha=_a}else{break}}ha=la?qa:-255;Qb=(ha<<3)+Va|0;Rb=-ha|0}else{Qb=Va;Rb=0}a[m+Rb|0]=0;ha=c[q>>2]|0;if((c[ha+688>>2]&1|0)!=0){yDb(ha,48,2240632,(E=i,i=i+8|0,c[E>>2]=W,E)|0);i=E}ha=xd(W|0,2228592,(E=i,i=i+16|0,c[E>>2]=n,c[E+8>>2]=o,E)|0)|0;i=E;if((ha|0)!=2){Pb=Qb;break}c[(c[(c[q>>2]|0)+64>>2]|0)+48>>2]=1024;Pb=Qb}}while(0);La=c[y>>2]|0;ma=-La|0;ha=(c[z>>2]|0)-La|0;if((Pb|0)<(ma|0)){Sb=ma}else{Sb=(ha|0)<(Pb|0)?ha:Pb}c[y>>2]=Sb+La;Nb=ea}else{La=(ea<<3)-4|0;ha=-Ga|0;ma=M-Ga|0;if((La|0)<(ha|0)){Tb=ha}else{Tb=(ma|0)<(La|0)?ma:La}c[y>>2]=Tb+Ga;Nb=ea}}while(0);h:do{if((O|0)==101){O=0;if(K){yDb(c[q>>2]|0,16,2286080,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;Nb=ea;break}Ga=c[J>>2]|0;if((Ga|0)==(-1|0)){O=107}else if((Ga|0)==0){yDb(c[q>>2]|0,16,2270152,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;Ga=(ea<<3)-4|0;M=c[y>>2]|0;ca=-M|0;oa=(c[z>>2]|0)-M|0;if((Ga|0)<(ca|0)){Ub=ca}else{Ub=(oa|0)<(Ga|0)?oa:Ga}c[y>>2]=Ub+M;Nb=ea;break}do{if((O|0)==107){O=0;if((c[C>>2]|0)!=4){break}yDb(c[q>>2]|0,16,2254856,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;M=(ea<<3)-4|0;Ga=c[y>>2]|0;oa=-Ga|0;ca=(c[z>>2]|0)-Ga|0;if((M|0)<(oa|0)){Vb=oa}else{Vb=(ca|0)<(M|0)?ca:M}c[y>>2]=Vb+Ga;Nb=ea;break h}}while(0);do{if((c[L>>2]|0)==-1){Ga=c[C>>2]|0;if(!(Ga>>>0<4>>>0)){O=115;break}M=c[q>>2]|0;if((c[M+416>>2]|0)!=1){O=115;break}c[J>>2]=1;c[L>>2]=1;c[M+840>>2]=28;Ueb(u,I,c[Q>>2]|0,Ga,1)|0}else{O=115}}while(0);if((O|0)==115){O=0;c[J>>2]=1;c[(c[q>>2]|0)+840>>2]=4}Nb=rfb(u,fa,j,Ob,ea,$)|0}}while(0);Ga=ea-Nb|0;if((Ga|0)<=0){ua=_;va=Z;wa=X;break e}ea=Ga;na=c[y>>2]|0}break};case 5:{if((c[C>>2]|0)==4){UGb(B|0,p|0,264)|0}c[C>>2]=0;na=Teb(e,N,D,j)|0;if((na|0)<0){P=na;break c}if((Z|0)!=0){yDb(G,16,1891e3,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;Wb=X;Xb=_;Yb=ba;O=155;break e}ea=Ueb(u,D,na,1,1)|0;if((ea|0)!=0){P=ea;break c}c[F>>2]=0;ua=_;va=1;wa=X;break};case 0:{Wb=X+1|0;Xb=1;Yb=Reb(u,ja+160|0,j,0)|0;O=155;break};case 4:{ea=c[y>>2]|0;na=c[w>>2]|0;fa=d[na+(ea>>>3)|0]|0;K=c[z>>2]|0;Ga=((ea|0)<(K|0))+ea|0;c[y>>2]=Ga;M=na+(Ga>>>3)|0;ca=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Ga&7)>>>24;M=Ga+8|0;Ga=K>>>0>M>>>0?M:K;c[y>>2]=Ga;if((ca|0)==255){M=na+(Ga>>>3)|0;na=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Ga&7)>>>24;M=Ga+8|0;oa=K>>>0>M>>>0?M:K;c[y>>2]=oa;Zb=na+255|0;_b=oa}else{Zb=ca;_b=Ga}do{if((fa&128>>>((ea&7)>>>0)|0)==0){$b=_b}else{Ga=-_b&7;if((Ga|0)==0){$b=_b;break}ca=Ga+_b|0;Ga=K>>>0>ca>>>0?ca:K;c[y>>2]=Ga;$b=Ga}}while(0);ea=Zb<<3;if(((c[A>>2]|0)-$b|0)<(ea|0)){O=82;break d}fa=-$b|0;Ga=K-$b|0;if((ea|0)<(fa|0)){ac=fa}else{ac=(Ga|0)<(ea|0)?Ga:ea}c[y>>2]=ac+$b;ua=_;va=Z;wa=X;break};case 3:{Wb=X;Xb=1;Yb=Reb(u,ja+160|0,j,0)|0;O=155;break};case 1:{Wb=X;Xb=1;Yb=Seb(u,j,ja)|0;O=155;break};default:{P=-558323010;break c}}}while(0);if((O|0)==155){O=0;if((Yb|0)==0){ua=Xb;va=Z;wa=Wb}else{P=Yb;break c}}ea=c[y>>2]|0;if(((c[A>>2]|0)-ea|0)<3){O=157;break}else{X=wa;Y=ja;Z=va;_=ua;$=ga;aa=ka;ba=0;H=ea}}if((O|0)==33){yDb(c[q>>2]|0,16,1911456,(E=i,i=i+16|0,c[E>>2]=ga,c[E+8>>2]=ia,E)|0);i=E;P=-1094995529;break}else if((O|0)==82){yDb(c[q>>2]|0,16,2157024,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;P=-1094995529;break}else if((O|0)==98){yDb(G,16,2348480,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;P=-1094995529;break}else if((O|0)==157){yDb(G,16,2328312,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;P=-1094995529;break}else if((O|0)==158){Veb(u);if((c[J>>2]|0)==1){bc=(c[t+6532>>2]|0)>(c[t+6512>>2]|0)|0}else{bc=0}H=aa<<bc;if(!((c[C>>2]|0)==0|(_|0)==0)){c[e+412>>2]=c[t+6512>>2]<<bc;c[e+424>>2]=H;c[C>>2]=4}do{if((bc|0)!=0){ba=HZ(k,70,s)|0;if(!((ba|0)!=0&(c[s>>2]|0)>3)){break}$=ba;x=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24)<<1;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x}}while(0);C=(H|0)!=0;_=C&1;c[h>>2]=_;aa=c[v>>2]|0;if(C){c[aa+76>>2]=H;c[aa+344>>2]=c[e+412>>2]}else{KCb(aa)}c[h>>2]=_;_=c[t+5696>>2]|0;if(!((_|0)!=0&(X|0)==2)){cc=0;i=l;return cc|0}aa=t+6752|0;if(!((c[aa>>2]|0)==3&(c[aa+4>>2]|0)==0)){cc=0;i=l;return cc|0}if((_|0)==1){c[f+4>>2]=c[f>>2];cc=0;i=l;return cc|0}else if((_|0)==2){c[f>>2]=c[f+4>>2];cc=0;i=l;return cc|0}else{cc=0;i=l;return cc|0}}}}while(0);f=t+6760|0;if((c[f>>2]|0)==4){cc=P;i=l;return cc|0}if((c[t+6496>>2]|0)==0){cc=P;i=l;return cc|0}UGb(t+6504|0,t+6240|0,264)|0;h=c[t+4>>2]|0;c[h+416>>2]=c[t+6744>>2];e=t+6752|0;v=c[e+4>>2]|0;s=h+448|0;c[s>>2]=c[e>>2];c[s+4>>2]=v;Ueb(u,t+6548|0,c[t+6740>>2]|0,c[f>>2]|0,0)|0;cc=P;i=l;return cc|0}function Peb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+60>>2]|0;d=b+492|0;e=0;while(1){f=c[d+(e<<2)>>2]|0;if((f|0)!=0){c[f+52320>>2]=f+15712;c[f+104512>>2]=f+67904}f=e+1|0;if((f|0)<16){e=f}else{g=0;break}}while(1){e=c[d+64+(g<<2)>>2]|0;if((e|0)!=0){c[e+52320>>2]=e+15712;c[e+104512>>2]=e+67904}e=g+1|0;if((e|0)<16){g=e}else{h=0;break}}while(1){g=c[d+128+(h<<2)>>2]|0;if((g|0)!=0){c[g+52320>>2]=g+15712;c[g+104512>>2]=g+67904}g=h+1|0;if((g|0)<16){h=g}else{i=0;break}}do{h=c[d+192+(i<<2)>>2]|0;if((h|0)!=0){c[h+52320>>2]=h+15712;c[h+104512>>2]=h+67904}i=i+1|0;}while((i|0)<16);i=b+8|0;KCb(c[i>>2]|0);d=a+416|0;if((c[d>>2]|0)==0){j=1;return j|0}h=c[i>>2]|0;c[h+76>>2]=2048;g=_$a(a,h,0)|0;if((g|0)<0){j=g;return j|0}g=c[d>>2]|0;if((g|0)<=0){j=0;return j|0}d=b+5436|0;b=0;while(1){h=c[d+(b<<2)>>2]|0;if((h|0)!=0){c[h+52160>>2]=c[(c[(c[i>>2]|0)+64>>2]|0)+(b<<2)>>2]}h=b+1|0;if((h|0)<(g|0)){b=h}else{j=0;break}}return j|0}function Qeb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+384|0;g=f|0;h=f+192|0;j=b+6516|0;k=c[j>>2]|0;if((k|0)==0){l=c[b+748+(d<<6)+(e<<2)>>2]|0;i=f;return l|0}m=b+1004|0;n=c[m>>2]|0;o=(d|0)==1;do{if((n|0)==0&o&(k|0)==1){p=b+6760|0;if((c[p>>2]|0)==4){UGb(b+6240|0,b+6504|0,264)|0}c[p>>2]=0;yDb(c[b+4>>2]|0,48,2038976,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=g|0;a[p]=a[1878607]|0;a[p+1|0]=a[1878608]|0;a[p+2|0]=a[1878609]|0;if((Ueb(b,g|0,1,2,1)|0)<0){l=0;i=f;return l|0}else{c[j>>2]=2;c[b+6544>>2]=0;r=c[m>>2]|0;s=2;break}}else{r=n;s=k}}while(0);k=(d|0)==0;a:do{if((r|d|0)==0&(s|0)==2){n=b+6760|0;if((c[n>>2]|0)==4){UGb(b+6240|0,b+6504|0,264)|0}c[n>>2]=0;yDb(c[b+4>>2]|0,48,2035904,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=h|0;a[n]=a[1878592]|0;a[n+1|0]=a[1878593]|0;a[n+2|0]=a[1878594]|0;if((Ueb(b,h|0,1,2,1)|0)<0){l=0;i=f;return l|0}c[j>>2]=1;if((c[b+6520>>2]|0)==0){break}c[b+6544>>2]=-1}else{b:do{switch(s|0){case 5:{t=c[m>>2]|0;u=5;v=22;break};case 1:{break a;break};case 7:{n=c[m>>2]|0;if(!((n|0)==3&o)){w=n;v=19;break b}c[m>>2]=4;n=c[b+564>>2]|0;c[b+812+(e<<2)>>2]=n;l=n;i=f;return l|0};case 3:case 2:{x=s;v=28;break};case 6:{w=c[m>>2]|0;v=19;break};case 4:{y=c[m>>2]|0;z=4;v=25;break};default:{l=0;i=f;return l|0}}}while(0);do{if((v|0)==19){n=a[190072+s|0]|0;if((w|0)!=(n-1|0)){t=w;u=s;v=22;break}if(!((d|0)==3|(d|0)==0)){t=w;u=s;v=22;break}c[m>>2]=n;n=c[b+684>>2]|0;c[b+748+(d<<6)+(e<<2)>>2]=n;l=n;i=f;return l|0}}while(0);do{if((v|0)==22){if(!((t|0)==2&o)){y=t;z=u;v=25;break}c[m>>2]=3;n=c[b+560>>2]|0;c[b+812+(e<<2)>>2]=n;l=n;i=f;return l|0}}while(0);do{if((v|0)==25){if((y|0)!=2){x=z;v=28;break}if(!((z|0)==4&k)){A=z;break}c[m>>2]=3;n=c[b+496>>2]|0;c[b+748+(e<<2)>>2]=n;l=n;i=f;return l|0}}while(0);do{if((v|0)==28){n=c[m>>2]|0;if(!((n|0)==((x|0)!=2|0)&o)){A=x;break}c[m>>2]=n+1;n=c[b+556>>2]|0;c[b+812+(e<<2)>>2]=n;l=n;i=f;return l|0}}while(0);if((A|0)==2){l=0}else{break}i=f;return l|0}}while(0);A=c[m>>2]|0;if((A|d|0)!=0){l=0;i=f;return l|0}c[m>>2]=A+1;A=c[b+492>>2]|0;c[b+748+(e<<2)>>2]=A;l=A;i=f;return l|0}function Reb(f,h,j,l){f=f|0;h=h|0;j=j|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0.0,Ib=0.0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0.0,sc=0.0,tc=0.0,uc=0.0;m=i;i=i+40|0;n=m|0;o=h+152|0;p=h|0;q=h+5312|0;r=f+6504|0;s=c[r>>2]|0;t=(s|0)==39;if((s|0)==17|(s|0)==19|(s|0)==23){u=1}else{u=t}s=n|0;c[s>>2]=0;v=j+8|0;w=c[v>>2]|0;x=j+16|0;y=c[x>>2]|0;z=j|0;A=(c[z>>2]|0)+(w>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(w&7)>>>24;A=w+8|0;c[v>>2]=y>>>0>A>>>0?A:y;y=(l|0)!=0;do{if(!y){if((Zeb(f,p,j)|0)<0){C=-1094995529}else{break}i=m;return C|0}}while(0);l=h+4|0;A=(c[l>>2]|0)==2?3:5;w=h+16|0;D=c[w>>2]|0;a:do{if((D|0)>0){E=h|0;F=32-A|0;G=j+12|0;H=(1<<A)-1|0;I=a[E]|0;J=0;K=0;L=I;M=D;N=I;b:while(1){if(L<<24>>24==0){O=J;P=0;S=M;T=N}else{I=c[z>>2]|0;U=J;V=0;while(1){W=c[v>>2]|0;X=c[x>>2]|0;Y=I+(W>>>3)|0;Z=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(W&7)>>>28;Y=W+4|0;W=X>>>0>Y>>>0?Y:X;c[v>>2]=W;if((Z|0)==12){_=14;break b}Y=c[G>>2]|0;$=V&255;aa=W;while(1){W=I+(aa>>>3)|0;ca=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(aa&7)>>>(F>>>0);W=aa+A|0;da=X>>>0>W>>>0?W:X;c[v>>2]=da;W=ca+($&255)|0;if((Y-da|0)<0){_=16;break b}ea=W&255;fa=a[E]|0;ga=fa&255;if(ea>>>0>ga>>>0){_=18;break b}if((ca|0)==(H|0)){$=W&255;aa=da}else{break}}if((V|0)<(ea|0)){aa=U;$=V;while(1){c[h+3172+(aa<<2)>>2]=Z;c[h+3684+(aa<<2)>>2]=ea;Y=$+1|0;if((Y|0)<(ea|0)){aa=aa+1|0;$=Y}else{break}}ha=U-V+ea|0;ia=ea;ja=a[E]|0}else{ha=U;ia=V;ja=fa}if((ia|0)<(ja&255|0)){U=ha;V=ia}else{break}}O=ha;P=ja;S=c[w>>2]|0;T=ja}V=K+1|0;if((V|0)<(S|0)){J=O;K=V;L=P;M=S;N=T}else{_=24;break}}if((_|0)==14){yDb(c[f+4>>2]|0,16,2059624,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}else if((_|0)==16){yDb(c[f+4>>2]|0,16,2054520,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}else if((_|0)==18){yDb(c[f+4>>2]|0,16,2043672,(ka=i,i=i+16|0,c[ka>>2]=ea,c[ka+8>>2]=ga,ka)|0);i=ka;C=-1094995529;i=m;return C|0}else if((_|0)==24){N=h+4164|0;if((S|0)<=0){la=N;break}M=f+4|0;L=0;K=0;J=0;H=B-90|0;F=B;G=1;V=T;U=T;c:while(1){d:do{if(V<<24>>24==0){ma=K;na=F;oa=H;pa=G;qa=J;ra=0;sa=U}else{I=0;$=K;aa=J;Z=H;Y=F;X=G;da=U;while(1){W=I;ca=$;ta=Z;ua=Y;va=X;wa=da;e:while(1){xa=W;ya=ca;za=ua;Aa=wa;f:while(1){Ba=xa;Ca=ya;Da=Aa;while(1){Ea=c[h+3684+(Ca<<2)>>2]|0;Fa=c[h+3172+(Ca<<2)>>2]|0;if((Fa|0)==13){break f}else if((Fa|0)==15|(Fa|0)==14){break e}else if((Fa|0)!=0){break}if((Ba|0)<(Ea|0)){TGb(h+4164+(Ca<<2)|0,0,Ea-Ba<<2|0)|0;Ga=Ea;Ha=Ca-Ba+Ea|0;Ia=a[E]|0}else{Ga=Ba;Ha=Ca;Ia=Da}if((Ga|0)<(Ia&255|0)){Ba=Ga;Ca=Ha;Da=Ia}else{ma=Ha;na=za;oa=ta;pa=va;qa=aa;ra=Ia;sa=Ia;break d}}if((Ba|0)<(Ea|0)){Fa=c[646421]|0;Ja=c[x>>2]|0;Ka=c[z>>2]|0;La=Ba;Ma=Ca;Na=za;Oa=c[v>>2]|0;do{Pa=Ka+(Oa>>>3)|0;Qa=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Oa&7)>>>25;Pa=b[Fa+(Qa<<2)>>1]|0;Ra=b[Fa+(Qa<<2)+2>>1]|0;Qa=Ra<<16>>16;do{if(Ra<<16>>16<0){Sa=Oa+7|0;Ta=Ja>>>0>Sa>>>0?Sa:Ja;Sa=Ka+(Ta>>>3)|0;Ua=((fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ta&7)>>>((Qa+32|0)>>>0))+Pa|0;Sa=b[Fa+(Ua<<2)>>1]|0;Va=b[Fa+(Ua<<2)+2>>1]|0;Ua=Va<<16>>16;if(!(Va<<16>>16<0)){Wa=Ua;Xa=Sa;Ya=Ta;break}Va=Ta-Qa|0;Ta=Ja>>>0>Va>>>0?Va:Ja;Va=Ka+(Ta>>>3)|0;Za=((fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)>>>((Ua+32|0)>>>0))+Sa|0;Wa=b[Fa+(Za<<2)+2>>1]|0;Xa=b[Fa+(Za<<2)>>1]|0;Ya=Ta}else{Wa=Qa;Xa=Pa;Ya=Oa}}while(0);Pa=Wa+Ya|0;Oa=Ja>>>0>Pa>>>0?Pa:Ja;c[v>>2]=Oa;Na=Na-60+Xa|0;if(Na>>>0>255>>>0){break c}g[h+4164+(Ma<<2)>>2]=-0.0- +g[7994608+(Na+100<<2)>>2];La=La+1|0;Ma=Ma+1|0;}while((La|0)<(Ea|0));_a=La;$a=Ma;ab=Na;bb=a[E]|0}else{_a=Ba;$a=Ca;ab=za;bb=Da}if((_a|0)<(bb&255|0)){xa=_a;ya=$a;za=ab;Aa=bb}else{ma=$a;na=ab;oa=ta;pa=va;qa=aa;ra=bb;sa=bb;break d}}if((Ba|0)<(Ea|0)){Aa=Ba;ya=Ca;xa=ta;Oa=va;while(1){Ja=Oa-1|0;if((Oa|0)>0){Fa=c[v>>2]|0;Ka=c[x>>2]|0;Pa=(c[z>>2]|0)+(Fa>>>3)|0;Qa=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Fa&7)>>>23;Pa=Fa+9|0;c[v>>2]=Ka>>>0>Pa>>>0?Pa:Ka;cb=Qa-256|0}else{Qa=c[646421]|0;Ka=c[v>>2]|0;Pa=c[x>>2]|0;Fa=c[z>>2]|0;Ra=Fa+(Ka>>>3)|0;Ta=(fe(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Ka&7)>>>25;Ra=b[Qa+(Ta<<2)>>1]|0;Za=b[Qa+(Ta<<2)+2>>1]|0;Ta=Za<<16>>16;do{if(Za<<16>>16<0){Sa=Ka+7|0;Ua=Pa>>>0>Sa>>>0?Sa:Pa;Sa=Fa+(Ua>>>3)|0;Va=((fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ua&7)>>>((Ta+32|0)>>>0))+Ra|0;Sa=b[Qa+(Va<<2)>>1]|0;db=b[Qa+(Va<<2)+2>>1]|0;Va=db<<16>>16;if(!(db<<16>>16<0)){eb=Va;fb=Sa;gb=Ua;break}db=Ua-Ta|0;Ua=Pa>>>0>db>>>0?db:Pa;db=Fa+(Ua>>>3)|0;hb=((fe(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(Ua&7)>>>((Va+32|0)>>>0))+Sa|0;eb=b[Qa+(hb<<2)+2>>1]|0;fb=b[Qa+(hb<<2)>>1]|0;gb=Ua}else{eb=Ta;fb=Ra;gb=Ka}}while(0);Ka=eb+gb|0;c[v>>2]=Pa>>>0>Ka>>>0?Ka:Pa;cb=fb-60|0}ib=cb+xa|0;if((ib|0)<-100){jb=-100}else{jb=(ib|0)>155?155:ib}if((ib|0)!=(jb|0)){DDb(c[M>>2]|0,2067656,(ka=i,i=i+16|0,c[ka>>2]=ib,c[ka+8>>2]=jb,ka)|0);i=ka}g[h+4164+(ya<<2)>>2]=-0.0- +g[7994608+(jb+200<<2)>>2];Ka=Aa+1|0;if((Ka|0)<(Ea|0)){Aa=Ka;ya=ya+1|0;xa=ib;Oa=Ja}else{break}}kb=Ea;lb=Ca-Ba+Ea|0;mb=ib;nb=Ba+va-Ea|0;ob=a[E]|0}else{kb=Ba;lb=Ca;mb=ta;nb=va;ob=Da}if((kb|0)<(ob&255|0)){W=kb;ca=lb;ta=mb;ua=za;va=nb;wa=ob}else{ma=lb;na=za;oa=mb;pa=nb;qa=aa;ra=ob;sa=ob;break d}}if((Ba|0)<(Ea|0)){wa=Ba;ua=Ca;ca=aa;while(1){W=c[646421]|0;Oa=c[v>>2]|0;xa=c[x>>2]|0;ya=c[z>>2]|0;Aa=ya+(Oa>>>3)|0;Ka=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Oa&7)>>>25;Aa=b[W+(Ka<<2)>>1]|0;Ra=b[W+(Ka<<2)+2>>1]|0;Ka=Ra<<16>>16;do{if(Ra<<16>>16<0){Ta=Oa+7|0;Qa=xa>>>0>Ta>>>0?Ta:xa;Ta=ya+(Qa>>>3)|0;Fa=((fe(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(Qa&7)>>>((Ka+32|0)>>>0))+Aa|0;Ta=b[W+(Fa<<2)>>1]|0;Za=b[W+(Fa<<2)+2>>1]|0;Fa=Za<<16>>16;if(!(Za<<16>>16<0)){pb=Fa;qb=Ta;rb=Qa;break}Za=Qa-Ka|0;Qa=xa>>>0>Za>>>0?Za:xa;Za=ya+(Qa>>>3)|0;Ma=((fe(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(Qa&7)>>>((Fa+32|0)>>>0))+Ta|0;pb=b[W+(Ma<<2)+2>>1]|0;qb=b[W+(Ma<<2)>>1]|0;rb=Qa}else{pb=Ka;qb=Aa;rb=Oa}}while(0);Oa=pb+rb|0;c[v>>2]=xa>>>0>Oa>>>0?Oa:xa;tb=ca-60+qb|0;if((tb|0)<-155){ub=-155}else{ub=(tb|0)>100?100:tb}if((tb|0)!=(ub|0)){DDb(c[M>>2]|0,2072264,(ka=i,i=i+16|0,c[ka>>2]=tb,c[ka+8>>2]=ub,ka)|0);i=ka}g[h+4164+(ua<<2)>>2]=+g[7994608+(200-ub<<2)>>2];Oa=wa+1|0;if((Oa|0)>=(Ea|0)){break}wa=Oa;ua=ua+1|0;ca=tb}vb=Ea;wb=Ca-Ba+Ea|0;xb=tb;yb=a[E]|0}else{vb=Ba;wb=Ca;xb=aa;yb=Da}if((vb|0)<(yb&255|0)){I=vb;$=wb;aa=xb;Z=ta;Y=za;X=va;da=yb}else{ma=wb;na=za;oa=ta;pa=va;qa=xb;ra=yb;sa=yb;break}}}}while(0);da=L+1|0;if((da|0)<(c[w>>2]|0)){L=da;K=ma;J=qa;H=oa;F=na;G=pa;V=ra;U=sa}else{la=N;break a}}yDb(c[M>>2]|0,16,2063344,(ka=i,i=i+8|0,c[ka>>2]=Na,ka)|0);i=ka;C=-1094995529;i=m;return C|0}}else{la=h+4164|0}}while(0);Na=c[v>>2]|0;g:do{if(t){zb=0;Ab=Na}else{sa=c[z>>2]|0;ra=d[sa+(Na>>>3)|0]<<(Na&7)>>>7;pa=c[x>>2]|0;na=((Na|0)<(pa|0))+Na|0;c[v>>2]=na;oa=ra&1;if((oa|0)==0){zb=0;Ab=na;break}if((c[l>>2]|0)==2){yDb(c[f+4>>2]|0,16,2098904,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}ra=c[h+76>>2]|0;qa=c[h+84>>2]|0;ma=sa+(na>>>3)|0;yb=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(na&7)>>>30;ma=na+2|0;na=pa>>>0>ma>>>0?ma:pa;c[v>>2]=na;ma=yb+1|0;c[s>>2]=ma;yb=sa+(na>>>3)|0;xb=(fe(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(na&7)>>>26;yb=na+6|0;na=pa>>>0>yb>>>0?yb:pa;c[v>>2]=na;h:do{if((xb|0)<(qa|0)){yb=e[ra+(xb<<1)>>1]|0;za=sa+(na>>>3)|0;wb=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(na&7)>>>27;za=na+5|0;vb=pa>>>0>za>>>0?za:pa;c[v>>2]=vb;za=wb+yb|0;c[n+8>>2]=za;yb=e[ra+(qa<<1)>>1]|0;if((za|0)>=(yb|0)){break}wb=sa+(vb>>>3)|0;Da=(fe(d[wb]|d[wb+1|0]<<8|d[wb+2|0]<<16|d[wb+3|0]<<24|0)|0)<<(vb&7)>>>28;wb=vb+4|0;vb=pa>>>0>wb>>>0?wb:pa;c[v>>2]=vb;c[n+24>>2]=Da;if(ma>>>0>1>>>0){Bb=1;Cb=vb;Db=za}else{zb=oa;Ab=vb;break g}while(1){vb=sa+(Cb>>>3)|0;za=(fe(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(Cb&7)>>>27;vb=Cb+5|0;Da=pa>>>0>vb>>>0?vb:pa;c[v>>2]=Da;vb=za+Db|0;c[n+8+(Bb<<2)>>2]=vb;if((vb|0)>=(yb|0)){break h}za=sa+(Da>>>3)|0;wb=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Da&7)>>>28;za=Da+4|0;Da=pa>>>0>za>>>0?za:pa;c[v>>2]=Da;c[n+24+(Bb<<2)>>2]=wb;wb=Bb+1|0;if((wb|0)<(c[s>>2]|0)){Bb=wb;Cb=Da;Db=vb}else{zb=oa;Ab=Da;break g}}}}while(0);yDb(c[f+4>>2]|0,16,2092672,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}}while(0);Db=d[(c[z>>2]|0)+(Ab>>>3)|0]<<(Ab&7)>>>7;c[v>>2]=((Ab|0)<(c[x>>2]|0))+Ab;Ab=Db&1;Db=o|0;c[Db>>2]=Ab;do{if(!((Ab|0)==0|u)){if(($eb(f,o,j,p)|0)<0){C=-1094995529}else{break}i=m;return C|0}}while(0);do{if(!t){Ab=c[v>>2]|0;Cb=d[(c[z>>2]|0)+(Ab>>>3)|0]|0;c[v>>2]=((Ab|0)<(c[x>>2]|0))+Ab;if((Cb&128>>>((Ab&7)>>>0)|0)==0){break}DDb(c[f+4>>2]|0,2087440,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1163346256;i=m;return C|0}}while(0);do{if(!((c[Db>>2]|0)==0|u^1)){if(($eb(f,o,j,p)|0)<0){C=-1094995529}else{break}i=m;return C|0}}while(0);p=h+88|0;j=c[p>>2]|0;o=1024/(j|0)|0;u=c[h+76>>2]|0;if((j|0)>0){j=h|0;Db=0;do{t=e[u+(d[j]<<1)>>1]|0;TGb(h+5312+(t+(Db<<7)<<2)|0,0,o-t<<2|0)|0;Db=Db+1|0;}while((Db|0)<(c[p>>2]|0))}p=c[w>>2]|0;i:do{if((p|0)>0){Db=h|0;o=f+5404|0;j=f+5428|0;t=f+5432|0;Ab=0;Cb=0;Bb=q;l=a[Db]|0;Na=p;j:while(1){oa=a[h+20+Cb|0]|0;pa=oa&255;if(l<<24>>24==0){Eb=Ab;Fb=0;Gb=Na}else{sa=oa<<24>>24==0;oa=Ab;ma=0;do{qa=(c[h+3172+(oa<<2)>>2]|0)-1|0;ra=e[u+(ma<<1)>>1]|0;na=Bb+(ra<<2)|0;ma=ma+1|0;xb=(e[u+(ma<<1)>>1]|0)-ra|0;k:do{if(qa>>>0>12>>>0){if(sa){break}ra=xb<<2;M=0;yb=na;while(1){TGb(yb|0,0,ra|0)|0;Da=M+1|0;if(Da>>>0<pa>>>0){M=Da;yb=yb+512|0}else{break}}}else{if((qa|0)==12){if(sa){break}yb=(xb|0)>0;M=la+(oa<<2)|0;ra=0;va=na;while(1){if(yb){ta=0;Da=c[t>>2]|0;do{Da=(ba(Da,1664525)|0)+1013904223|0;g[va+(ta<<2)>>2]=+(Da|0);ta=ta+1|0;}while((ta|0)<(xb|0));c[t>>2]=Da}Hb=+we[c[j>>2]&7](va,va,xb);Ib=+g[M>>2]/+R(Hb);te[c[o>>2]&7](va,va,Ib,xb);ta=ra+1|0;if(ta>>>0<pa>>>0){ra=ta;va=va+512|0}else{break k}}}va=c[1286120+(qa<<2)>>2]|0;ra=c[1286168+(qa<<2)>>2]|0;M=c[2585460+(qa*20|0)>>2]|0;yb=c[v>>2]|0;ta=c[x>>2]|0;l:do{switch(qa>>>1|0){case 1:{if(sa){Jb=yb;break l}xa=la+(oa<<2)|0;vb=c[z>>2]|0;wb=yb;za=1;Ca=na;while(1){Ba=wb;tb=Ca;Ea=xb;while(1){ub=vb+(Ba>>>3)|0;qb=(fe(d[ub]|d[ub+1|0]<<8|d[ub+2|0]<<16|d[ub+3|0]<<24|0)|0)<<(Ba&7);ub=qb>>>24;rb=b[M+(ub<<2)>>1]|0;pb=b[M+(ub<<2)+2>>1]|0;ub=pb<<16>>16;if(pb<<16>>16<0){pb=Ba+8|0;ob=ta>>>0>pb>>>0?pb:ta;pb=vb+(ob>>>3)|0;nb=(fe(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(ob&7);pb=(nb>>>((ub+32|0)>>>0))+rb|0;Kb=ob;Lb=nb;Mb=b[M+(pb<<2)+2>>1]|0;Nb=b[M+(pb<<2)>>1]|0}else{Kb=Ba;Lb=qb;Mb=ub;Nb=rb}rb=Kb+Mb|0;ub=e[ra+(Nb<<1)>>1]|0;qb=ub>>>8&15;pb=(qb|0)!=0?Lb<<Mb:0;nb=qb+(ta>>>0>rb>>>0?rb:ta)|0;Ob=ta>>>0>nb>>>0?nb:ta;nb=(g[k>>2]=+g[xa>>2],c[k>>2]|0);g[tb>>2]=+g[va+((ub&3)<<2)>>2]*(c[k>>2]=pb&-2147483648^nb,+g[k>>2]);rb=pb<<(ub>>>12&1);g[tb+4>>2]=+g[va+((ub>>>2&3)<<2)>>2]*(c[k>>2]=rb&-2147483648^nb,+g[k>>2]);pb=rb<<(ub>>>13&1);g[tb+8>>2]=+g[va+((ub>>>4&3)<<2)>>2]*(c[k>>2]=pb&-2147483648^nb,+g[k>>2]);g[tb+12>>2]=+g[va+((ub>>>6&3)<<2)>>2]*(c[k>>2]=pb<<(ub>>>14&1)&-2147483648^nb,+g[k>>2]);nb=Ea-4|0;if((nb|0)==0){break}else{Ba=Ob;tb=tb+16|0;Ea=nb}}if(!(za>>>0<pa>>>0)){Jb=Ob;break l}wb=Ob;za=za+1|0;Ca=Ca+512|0}break};case 2:{if(sa){Jb=yb;break l}Ca=la+(oa<<2)|0;za=c[z>>2]|0;wb=yb;xa=1;vb=na;while(1){Da=wb;Ea=xb;tb=vb;while(1){Ba=za+(Da>>>3)|0;Ja=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Da&7)>>>24;Ba=b[M+(Ja<<2)>>1]|0;Pa=b[M+(Ja<<2)+2>>1]|0;Ja=Pa<<16>>16;if(Pa<<16>>16<0){Pa=Da+8|0;nb=ta>>>0>Pa>>>0?Pa:ta;Pa=za+(nb>>>3)|0;ub=((fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(nb&7)>>>((Ja+32|0)>>>0))+Ba|0;Pb=nb;Qb=b[M+(ub<<2)+2>>1]|0;Rb=b[M+(ub<<2)>>1]|0}else{Pb=Da;Qb=Ja;Rb=Ba}Ba=Pb+Qb|0;Sb=ta>>>0>Ba>>>0?Ba:ta;Ba=e[ra+(Rb<<1)>>1]|0;Ib=+g[Ca>>2];g[tb>>2]=Ib*+g[va+((Ba&15)<<2)>>2];g[tb+4>>2]=Ib*+g[va+((Ba>>>4&15)<<2)>>2];Ba=Ea-2|0;if((Ba|0)==0){break}else{Da=Sb;Ea=Ba;tb=tb+8|0}}if(!(xa>>>0<pa>>>0)){Jb=Sb;break l}wb=Sb;xa=xa+1|0;vb=vb+512|0}break};case 3:case 4:{if(sa){Jb=yb;break l}vb=la+(oa<<2)|0;xa=c[z>>2]|0;wb=yb;Ca=1;za=na;while(1){tb=wb;Ea=xb;Da=za;while(1){Ba=xa+(tb>>>3)|0;Ja=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(tb&7);Ba=Ja>>>24;ub=b[M+(Ba<<2)>>1]|0;nb=b[M+(Ba<<2)+2>>1]|0;Ba=nb<<16>>16;if(nb<<16>>16<0){nb=tb+8|0;Pa=ta>>>0>nb>>>0?nb:ta;nb=xa+(Pa>>>3)|0;pb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Pa&7);nb=(pb>>>((Ba+32|0)>>>0))+ub|0;Tb=b[M+(nb<<2)+2>>1]|0;Ub=Pa;Vb=pb;Wb=b[M+(nb<<2)>>1]|0}else{Tb=Ba;Ub=tb;Vb=Ja;Wb=ub}ub=Tb+Ub|0;Ja=e[ra+(Wb<<1)>>1]|0;Ba=Ja>>>8&15;if((Ba|0)==0){Xb=0}else{Xb=Vb<<Tb>>>((32-Ba|0)>>>0)<<(Ja>>>12)}nb=Ba+(ta>>>0>ub>>>0?ub:ta)|0;Yb=ta>>>0>nb>>>0?nb:ta;nb=(g[k>>2]=+g[vb>>2],c[k>>2]|0);g[Da>>2]=+g[va+((Ja&15)<<2)>>2]*(c[k>>2]=nb^Xb>>>1<<31,+g[k>>2]);g[Da+4>>2]=+g[va+((Ja>>>4&15)<<2)>>2]*(c[k>>2]=nb^Xb<<31,+g[k>>2]);nb=Ea-2|0;if((nb|0)==0){break}else{tb=Yb;Ea=nb;Da=Da+8|0}}if(!(Ca>>>0<pa>>>0)){Jb=Yb;break l}wb=Yb;Ca=Ca+1|0;za=za+512|0}break};case 0:{if(sa){Jb=yb;break l}za=la+(oa<<2)|0;Ca=c[z>>2]|0;wb=yb;vb=1;xa=na;while(1){Da=wb;Ea=xa;tb=xb;while(1){nb=Ca+(Da>>>3)|0;Ja=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Da&7)>>>24;nb=b[M+(Ja<<2)>>1]|0;ub=b[M+(Ja<<2)+2>>1]|0;Ja=ub<<16>>16;if(ub<<16>>16<0){ub=Da+8|0;Ba=ta>>>0>ub>>>0?ub:ta;ub=Ca+(Ba>>>3)|0;pb=((fe(d[ub]|d[ub+1|0]<<8|d[ub+2|0]<<16|d[ub+3|0]<<24|0)|0)<<(Ba&7)>>>((Ja+32|0)>>>0))+nb|0;Zb=Ba;_b=b[M+(pb<<2)>>1]|0;$b=b[M+(pb<<2)+2>>1]|0}else{Zb=Da;_b=nb;$b=Ja}Ja=Zb+$b|0;ac=ta>>>0>Ja>>>0?Ja:ta;Ja=e[ra+(_b<<1)>>1]|0;Ib=+g[za>>2];g[Ea>>2]=Ib*+g[va+((Ja&3)<<2)>>2];g[Ea+4>>2]=Ib*+g[va+((Ja>>>2&3)<<2)>>2];g[Ea+8>>2]=Ib*+g[va+((Ja>>>4&3)<<2)>>2];g[Ea+12>>2]=Ib*+g[va+((Ja>>>6&3)<<2)>>2];Ja=tb-4|0;if((Ja|0)==0){break}else{Da=ac;Ea=Ea+16|0;tb=Ja}}if(!(vb>>>0<pa>>>0)){Jb=ac;break l}wb=ac;vb=vb+1|0;xa=xa+512|0}break};default:{if(sa){Jb=yb;break l}xa=la+(oa<<2)|0;vb=yb;wb=1;za=na;while(1){Ca=c[z>>2]|0;tb=xb;Ea=za;Da=vb;while(1){Ja=Ca+(Da>>>3)|0;nb=(fe(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Da&7);Ja=nb>>>24;pb=b[M+(Ja<<2)>>1]|0;Ba=b[M+(Ja<<2)+2>>1]|0;Ja=Ba<<16>>16;if(Ba<<16>>16<0){Ba=Da+8|0;ub=ta>>>0>Ba>>>0?Ba:ta;Ba=Ca+(ub>>>3)|0;Pa=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(ub&7);Ba=(Pa>>>((Ja+32|0)>>>0))+pb|0;bc=b[M+(Ba<<2)+2>>1]|0;cc=b[M+(Ba<<2)>>1]|0;dc=ub;ec=Pa}else{bc=Ja;cc=pb;dc=Da;ec=nb}nb=bc+dc|0;pb=ta>>>0>nb>>>0?nb:ta;if((cc|0)==0){c[Ea>>2]=0;c[Ea+4>>2]=0;fc=pb}else{nb=e[ra+(cc<<1)>>1]|0;Ja=nb>>>12;Pa=nb>>>8;ub=32-Ja|0;Ba=ec<<bc>>>(ub>>>0)<<ub;ub=Ja+pb|0;pb=ta>>>0>ub>>>0?ub:ta;if((Pa&1|0)==0){ub=c[va+((nb&15)<<2)>>2]|0;c[Ea>>2]=ub|Ba&-2147483648;gc=Ba<<((ub|0)!=0);hc=pb}else{ub=Ca+(pb>>>3)|0;Ja=(fe(d[ub]|d[ub+1|0]<<8|d[ub+2|0]<<16|d[ub+3|0]<<24|0)|0)<<(pb&7);ub=~Ja;rb=Ja>>>0<4294901760>>>0;qb=rb?ub>>>16:ub;ub=rb?16:0;if((qb&65280|0)==0){ic=ub;jc=qb}else{ic=ub|8;jc=qb>>>8}qb=31-ic-(d[1191992+jc|0]|0)|0;if(qb>>>0>8>>>0){break j}ub=qb+1|0;rb=ub+pb|0;pb=qb+4|0;ob=(ta>>>0>rb>>>0?rb:ta)+pb|0;c[Ea>>2]=c[8811464+((Ja<<ub>>>((28-qb|0)>>>0))+(1<<pb)<<2)>>2]|Ba&-2147483648;gc=Ba<<1;hc=ta>>>0>ob>>>0?ob:ta}ob=Ea+4|0;if((Pa&2|0)==0){kc=hc;lc=c[va+((nb>>>4&15)<<2)>>2]|gc&-2147483648}else{nb=Ca+(hc>>>3)|0;Pa=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(hc&7);nb=~Pa;Ba=Pa>>>0<4294901760>>>0;pb=Ba?nb>>>16:nb;nb=Ba?16:0;if((pb&65280|0)==0){mc=nb;nc=pb}else{mc=nb|8;nc=pb>>>8}pb=31-mc-(d[1191992+nc|0]|0)|0;if(pb>>>0>8>>>0){break j}nb=pb+1|0;Ba=nb+hc|0;qb=pb+4|0;ub=(ta>>>0>Ba>>>0?Ba:ta)+qb|0;kc=ta>>>0>ub>>>0?ub:ta;lc=c[8811464+((Pa<<nb>>>((28-pb|0)>>>0))+(1<<qb)<<2)>>2]|gc&-2147483648}c[ob>>2]=lc;fc=kc}ob=tb-2|0;if((ob|0)==0){break}else{tb=ob;Ea=Ea+8|0;Da=fc}}te[c[o>>2]&7](za,za,+g[xa>>2],xb);if(!(wb>>>0<pa>>>0)){Jb=fc;break l}vb=fc;wb=wb+1|0;za=za+512|0}}}}while(0);c[v>>2]=Jb}}while(0);oa=oa+1|0;oc=a[Db]|0;}while((ma|0)<(oc&255|0));Eb=oa;Fb=oc;Gb=c[w>>2]|0}ma=Cb+1|0;if((ma|0)<(Gb|0)){Ab=Eb;Cb=ma;Bb=Bb+(pa<<7<<2)|0;l=Fb;Na=Gb}else{break i}}yDb(c[f+4>>2]|0,16,2082792,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}}while(0);do{if((zb|0)!=0){ka=c[s>>2]|0;if((ka|0)>0){pc=0;qc=0}else{break}while(1){Gb=c[n+8+(qc<<2)>>2]|0;Fb=h+5312+(Gb<<2)|0;Ib=+g[Fb>>2];Eb=pc;while(1){w=Eb+1|0;if((e[u+(w<<1)>>1]|0)>(Gb|0)){break}else{Eb=w}}do{if((c[h+3172+(Eb<<2)>>2]|0)!=13){Gb=la+(Eb<<2)|0;Hb=+g[Gb>>2];if(!(Hb!=0.0)){break}rc=+(-(c[n+24+(qc<<2)>>2]|0)|0);if(Ib!=0.0){sc=Ib/Hb;Hb=sc/+R(+R(+Q(+sc)));if(sc>0.0){tc=-0.0-rc}else{tc=rc}uc=Hb+tc}else{uc=rc}rc=uc*+sb(+(+Q(+uc)));g[Fb>>2]=rc*+g[Gb>>2]}}while(0);Fb=qc+1|0;if((Fb|0)<(ka|0)){pc=Eb;qc=Fb}else{break}}}}while(0);if((c[r>>2]|0)!=1|y){C=0;i=m;return C|0}_eb(f,h);C=0;i=m;return C|0}function Seb(f,h,j){f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0.0,aa=0;k=i;l=f+6504|0;if((c[l>>2]|0)==39){m=1;n=3}else{o=h+8|0;p=c[o>>2]|0;q=d[(c[h>>2]|0)+(p>>>3)|0]<<(p&7);c[o>>2]=((p|0)<(c[h+16>>2]|0))+p;p=q&128;q=p>>>7;if((p|0)==0){r=0;s=0;t=q}else{m=q;n=3}}a:do{if((n|0)==3){q=j+160|0;if((Zeb(f,q,h)|0)!=0){u=-1094995529;i=k;return u|0}p=a[j+52364|0]|0;o=j+52352|0;UGb(o|0,q|0,152)|0;a[j+52365|0]=p;b:do{if((c[j+52448>>2]|0)!=0){if((c[l>>2]|0)==1){break}p=h+8|0;q=c[p>>2]|0;v=h+16|0;w=c[v>>2]|0;x=h|0;y=(c[x>>2]|0)+(q>>>3)|0;z=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>31;y=q+1|0;c[p>>2]=w>>>0>y>>>0?y:w;w=z&255;a[j+52380|0]=w;if(w<<24>>24==0){break}w=a[o]|0;z=c[p>>2]|0;y=c[v>>2]|0;q=c[x>>2]|0;A=q+(z>>>3)|0;B=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7)>>>21;A=z+11|0;z=y>>>0>A>>>0?A:y;c[p>>2]=z;b[j+52382>>1]=B;B=q+(z>>>3)|0;A=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7)>>>29;B=z+3|0;z=y>>>0>B>>>0?B:y;c[p>>2]=z;g[j+52384>>2]=+g[688368+(A<<2)>>2];A=(w&255)>>>0>40>>>0?40:w&255;if((A|0)==0){break}else{C=0;D=z;E=q;F=y}while(1){y=d[E+(D>>>3)|0]<<(D&7)>>>7;c[p>>2]=((D|0)<(F|0))+D;a[j+52388+C|0]=y&1;y=C+1|0;if((y|0)>=(A|0)){break b}C=y;D=c[p>>2]|0;E=c[x>>2]|0;F=c[v>>2]|0}}}while(0);o=h+8|0;v=c[o>>2]|0;x=h+16|0;p=c[x>>2]|0;A=h|0;y=c[A>>2]|0;q=y+(v>>>3)|0;z=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(v&7)>>>30;q=v+2|0;v=p>>>0>q>>>0?q:p;c[o>>2]=v;if((z|0)==0){r=0;s=1;t=m;break}else if((z|0)==3){yDb(c[f+4>>2]|0,16,2150344,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=k;return u|0}if((z|0)==2){TGb(j+8|0,1,ba(d[j+160|0]|0,c[j+176>>2]|0)|0)|0;r=2;s=1;t=m;break}else if((z|0)!=1){r=z;s=1;t=m;break}z=j+176|0;q=j+160|0;if((ba(d[q]|0,c[z>>2]|0)|0)>0){G=0;H=v;I=y;J=p}else{r=1;s=1;t=m;break}while(1){p=d[I+(H>>>3)|0]<<(H&7)>>>7;c[o>>2]=((H|0)<(J|0))+H;a[j+8+G|0]=p&1;p=G+1|0;if((p|0)>=(ba(d[q]|0,c[z>>2]|0)|0)){r=1;s=1;t=m;break a}G=p;H=c[o>>2]|0;I=c[A>>2]|0;J=c[x>>2]|0}}}while(0);J=j+160|0;I=Reb(f,J,h,t)|0;if((I|0)!=0){u=I;i=k;return u|0}I=j+52352|0;H=Reb(f,I,h,t)|0;if((H|0)!=0){u=H;i=k;return u|0}do{if(s){do{if((r|0)!=0){H=c[j+236>>2]|0;t=j+176|0;h=c[t>>2]|0;if((h|0)<=0){break}G=j+160|0;m=f+5424|0;F=a[G]|0;E=j+57664|0;D=0;C=0;n=j+5472|0;x=F;A=h;h=F;while(1){F=j+180+D|0;if(x<<24>>24==0){K=C;L=0;M=A;N=h}else{o=0;z=C;q=h;while(1){do{if((a[j+8+z|0]|0)==0){O=q}else{if(!((c[j+3332+(z<<2)>>2]|0)>>>0<13>>>0)){O=q;break}if(!((c[j+55524+(z<<2)>>2]|0)>>>0<13>>>0)){O=q;break}if((a[F]|0)==0){O=q;break}p=H+(o<<1)|0;y=H+(o+1<<1)|0;v=0;do{w=e[p>>1]|0;B=w+(v<<7)|0;Xe[c[m>>2]&4095](n+(B<<2)|0,E+(B<<2)|0,(e[y>>1]|0)-w|0);v=v+1|0;}while((v|0)<(d[F]|0));O=a[G]|0}}while(0);v=o+1|0;P=z+1|0;if((v|0)<(O&255|0)){o=v;z=P;q=O}else{break}}K=P;L=O;M=c[t>>2]|0;N=O}q=d[F]<<7;z=D+1|0;if((z|0)<(M|0)){E=E+(q<<2)|0;D=z;C=K;n=n+(q<<2)|0;x=L;A=M;h=N}else{break}}}}while(0);if((c[l>>2]|0)!=1){break}_eb(f,J);_eb(f,I)}}while(0);I=c[j+52428>>2]|0;J=j+52368|0;l=c[J>>2]|0;if((l|0)<=0){u=0;i=k;return u|0}N=j+52352|0;M=(r|0)==0;r=f+5404|0;f=a[N]|0;L=0;K=0;O=j+57664|0;P=j+5472|0;s=f;h=l;l=f;while(1){f=j+52372+K|0;if(s<<24>>24==0){Q=L;R=0;S=h;T=l}else{A=0;x=L;n=l;while(1){C=c[j+55524+(x<<2)>>2]|0;D=c[j+56036+(x<<2)>>2]|0;do{if((C-14|0)>>>0<2>>>0){if((A|0)<(D|0)){U=A;V=x;W=C}else{X=x;Y=A;Z=n;break}while(1){E=(W<<1)-29|0;if(M){_=E}else{_=ba(1-(d[j+8+V|0]<<1)|0,E)|0}$=+(_|0)*+g[j+56516+(V<<2)>>2];if((a[f]|0)==0){aa=U+1|0}else{E=I+(U<<1)|0;t=U+1|0;G=I+(t<<1)|0;m=0;while(1){H=e[E>>1]|0;q=H+(m<<7)|0;te[c[r>>2]&7](O+(q<<2)|0,P+(q<<2)|0,$,(e[G>>1]|0)-H|0);H=m+1|0;if((H|0)<(d[f]|0)){m=H}else{aa=t;break}}}t=V+1|0;if((aa|0)>=(D|0)){break}U=aa;V=t;W=c[j+55524+(t<<2)>>2]|0}X=x-A+D|0;Y=D;Z=a[N]|0}else{X=x-A+D|0;Y=D;Z=n}}while(0);if((Y|0)<(Z&255|0)){A=Y;x=X;n=Z}else{break}}Q=X;R=Z;S=c[J>>2]|0;T=Z}n=d[f]<<7;x=K+1|0;if((x|0)<(S|0)){L=Q;K=x;O=O+(n<<2)|0;P=P+(n<<2)|0;s=R;h=S;l=T}else{u=0;break}}i=k;return u|0}function Teb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;j=g+8|0;k=g+16|0;l=c[k>>2]|0;m=(c[j>>2]|0)+2|0;n=l>>>0>m>>>0?m:l;c[j>>2]=n;m=g|0;o=c[m>>2]|0;p=o+(n>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(n&7)>>>28;p=n+4|0;n=l>>>0>p>>>0?p:l;c[j>>2]=n;if((c[e+4>>2]|0)==(q|0)){r=n;s=l;t=o}else{yDb(b,24,2207320,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;r=c[j>>2]|0;s=c[k>>2]|0;t=c[m>>2]|0}o=t+(r>>>3)|0;l=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>28;o=r+4|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;n=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>28;o=r+4|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;q=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>28;o=r+4|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;e=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>30;o=r+2|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>29;o=r+3|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;v=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>28;o=r+4|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=((r|0)<(s|0))+r|0;if(((d[t+(r>>>3)|0]|0)&128>>>((r&7)>>>0)|0)==0){w=o}else{r=o+4|0;w=s>>>0>r>>>0?r:s}c[j>>2]=w;r=((w|0)<(s|0))+w|0;if(((d[t+(w>>>3)|0]|0)&128>>>((w&7)>>>0)|0)==0){x=r}else{w=r+4|0;x=s>>>0>w>>>0?w:s}c[j>>2]=x;w=((x|0)<(s|0))+x|0;if(((d[t+(x>>>3)|0]|0)&128>>>((x&7)>>>0)|0)==0){y=w}else{x=w+3|0;y=s>>>0>x>>>0?x:s}c[j>>2]=y;x=g+12|0;g=n+l|0;w=q+g|0;r=e+w|0;if(((c[x>>2]|0)-y|0)<(p+r+v<<2|0)){yDb(b,16,2199152,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;z=-1;i=h;return z|0}a:do{if((l|0)!=0){o=f;A=l;B=y;C=t;D=s;while(1){E=A-1|0;F=(d[C+(B>>>3)|0]|0)<<(B&7)>>>7;c[j>>2]=((B|0)<(D|0))+B;a[o|0]=F&1;F=c[j>>2]|0;G=c[k>>2]|0;H=(c[m>>2]|0)+(F>>>3)|0;I=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>28;H=F+4|0;c[j>>2]=G>>>0>H>>>0?H:G;a[o+1|0]=I;a[o+2|0]=1;if((E|0)==0){break a}o=o+3|0;A=E;B=c[j>>2]|0;C=c[m>>2]|0;D=c[k>>2]|0}}}while(0);b:do{if((n|0)!=0){s=f+(l*3|0)|0;t=n;while(1){y=t-1|0;D=c[j>>2]|0;C=(d[(c[m>>2]|0)+(D>>>3)|0]|0)<<(D&7)>>>7;c[j>>2]=((D|0)<(c[k>>2]|0))+D;a[s|0]=C&1;C=c[j>>2]|0;D=c[k>>2]|0;B=(c[m>>2]|0)+(C>>>3)|0;A=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>28;B=C+4|0;c[j>>2]=D>>>0>B>>>0?B:D;a[s+1|0]=A;a[s+2|0]=2;if((y|0)==0){break b}s=s+3|0;t=y}}}while(0);c:do{if((q|0)!=0){n=f+(g*3|0)|0;l=q;while(1){t=l-1|0;s=c[j>>2]|0;y=(d[(c[m>>2]|0)+(s>>>3)|0]|0)<<(s&7)>>>7;c[j>>2]=((s|0)<(c[k>>2]|0))+s;a[n|0]=y&1;y=c[j>>2]|0;s=c[k>>2]|0;A=(c[m>>2]|0)+(y>>>3)|0;D=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7)>>>28;A=y+4|0;c[j>>2]=s>>>0>A>>>0?A:s;a[n+1|0]=D;a[n+2|0]=3;if((t|0)==0){break c}n=n+3|0;l=t}}}while(0);if((e|0)!=0){q=f+(w*3|0)|0;w=e;while(1){e=w-1|0;a[q|0]=3;g=c[j>>2]|0;l=c[k>>2]|0;n=(c[m>>2]|0)+(g>>>3)|0;t=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(g&7)>>>28;n=g+4|0;c[j>>2]=l>>>0>n>>>0?n:l;a[q+1|0]=t;a[q+2|0]=4;if((e|0)==0){break}else{q=q+3|0;w=e}}}w=p<<2;p=c[j>>2]|0;q=-p|0;e=c[k>>2]|0;t=e-p|0;if((w|0)<(q|0)){J=q}else{J=(t|0)<(w|0)?t:w}w=J+p|0;c[j>>2]=w;if((v|0)==0){K=w}else{p=f+(r*3|0)|0;f=v;J=w;w=e;while(1){e=f-1|0;t=J+1|0;c[j>>2]=w>>>0>t>>>0?t:w;a[p|0]=2;t=c[j>>2]|0;q=c[k>>2]|0;l=(c[m>>2]|0)+(t>>>3)|0;n=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(t&7)>>>28;l=t+4|0;c[j>>2]=q>>>0>l>>>0?l:q;a[p+1|0]=n;a[p+2|0]=5;if((e|0)==0){break}p=p+3|0;f=e;J=c[j>>2]|0;w=c[k>>2]|0}K=c[j>>2]|0}w=-K&7;J=c[k>>2]|0;if((w|0)==0){L=K}else{k=w+K|0;K=J>>>0>k>>>0?k:J;c[j>>2]=K;L=K}K=(c[m>>2]|0)+(L>>>3)|0;m=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(L&7)>>>24;K=L+8|0;L=J>>>0>K>>>0?K:J;c[j>>2]=L;K=m<<3;if(((c[x>>2]|0)-L|0)<(K|0)){yDb(b,16,2199152,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;z=-1094995529;i=h;return z|0}u=-L|0;b=J-L|0;if((K|0)<(u|0)){M=u}else{M=(b|0)<(K|0)?b:K}c[j>>2]=M+L;z=v+r|0;i=h;return z|0}function Ueb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;j=i;i=i+1096|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=b+4|0;p=c[o>>2]|0;q=b+6548|0;if((q|0)!=(e|0)){UGb(q|0,e|0,f*3|0)|0;c[b+6740>>2]=f}q=p+456|0;a:do{if((c[q>>2]|0)==0&(c[q+4>>2]|0)==(-2147483648|0)){r=0;s=0}else{t=n;u=j+1048|0;v=j+1056|0;w=j+1064|0;x=j+1072|0;y=j+1080|0;TGb(t|0,0,1024)|0;if(f>>>0>64>>>0){r=0;s=0;break}if((f|0)>0){z=0;A=0;B=0;C=0;while(1){if((a[e+(C*3|0)+2|0]|0)!=1){D=z;E=A;F=B;G=C;break}if((a[e+(C*3|0)|0]|0)==1){if(!((B|0)==0|(A|0)==0)){r=0;s=0;break a}H=0;I=1;J=z+2|0}else{H=B^1;I=A;J=z+1|0}K=C+1|0;if((K|0)<(f|0)){z=J;A=I;B=H;C=K}else{D=J;E=I;F=H;G=K;break}}if((F|0)!=0&(E|0)!=0|(D|0)<0){r=0;s=0;break}else{L=D;M=G}}else{L=0;M=0}if((M|0)<(f|0)){C=0;B=0;A=M;while(1){if((a[e+(A*3|0)+2|0]|0)!=2){N=C;O=B;P=A;break}if((a[e+(A*3|0)|0]|0)==1){if((B|0)!=0){r=0;s=0;break a}Q=0;R=C+2|0}else{Q=B^1;R=C+1|0}z=A+1|0;if((z|0)<(f|0)){C=R;B=Q;A=z}else{N=R;O=Q;P=z;break}}if((O|0)!=0|(N|0)<0){r=0;s=0;break}else{S=N;T=P}}else{S=0;T=M}if((T|0)<(f|0)){A=0;B=0;C=T;while(1){if((a[e+(C*3|0)+2|0]|0)!=3){U=A;break}if((a[e+(C*3|0)|0]|0)==1){if((B|0)!=0){r=0;s=0;break a}V=0;W=A+2|0}else{V=B^1;W=A+1|0}z=C+1|0;if((z|0)<(f|0)){A=W;B=V;C=z}else{U=W;break}}if((U|0)<0){r=0;s=0;break}else{X=U}}else{X=0}if((L&1|0)==0){Y=L;Z=0}else{C=a[e+1|0]|0;B=n|0;c[B>>2]=4;c[B+4>>2]=0;a[n+8|0]=0;a[n+9|0]=C;a[n+10|0]=1;C=t+11|0;a[C]=a[u]|0;a[C+1|0]=a[u+1|0]|0;a[C+2|0]=a[u+2|0]|0;a[C+3|0]=a[u+3|0]|0;a[C+4|0]=a[u+4|0]|0;Y=L-1|0;Z=1}if((Y|0)>3){C=k|0;B=l|0;A=m|0;z=n+(Z<<4)|0;K=a[e+(Z*3|0)+1|0]|0;_=z|0;if((a[e+(Z*3|0)|0]|0)==1){c[_>>2]=192;c[_+4>>2]=0;a[n+(Z<<4)+8|0]=1;a[n+(Z<<4)+9|0]=K;a[n+(Z<<4)+10|0]=1;$=z+11|0;a[$]=a[C]|0;a[$+1|0]=a[C+1|0]|0;a[$+2|0]=a[C+2|0]|0;a[$+3|0]=a[C+3|0]|0;a[$+4|0]=a[C+4|0]|0;aa=1}else{c[_>>2]=64;c[_+4>>2]=0;a[n+(Z<<4)+8|0]=0;a[n+(Z<<4)+9|0]=K;a[n+(Z<<4)+10|0]=1;K=z+11|0;a[K]=a[B]|0;a[K+1|0]=a[B+1|0]|0;a[K+2|0]=a[B+2|0]|0;a[K+3|0]=a[B+3|0]|0;a[K+4|0]=a[B+4|0]|0;B=Z+1|0;K=n+(B<<4)|0;z=a[e+(B*3|0)+1|0]|0;_=K|0;c[_>>2]=128;c[_+4>>2]=0;a[n+(B<<4)+8|0]=0;a[n+(B<<4)+9|0]=z;a[n+(B<<4)+10|0]=1;B=K+11|0;a[B]=a[A]|0;a[B+1|0]=a[A+1|0]|0;a[B+2|0]=a[A+2|0]|0;a[B+3|0]=a[A+3|0]|0;a[B+4|0]=a[A+4|0]|0;aa=2}ba=Y-2|0;ca=aa+Z|0}else{ba=Y;ca=Z}do{if((ba|0)>1){A=k|0;B=l|0;K=m|0;z=n+(ca<<4)|0;_=a[e+(ca*3|0)+1|0]|0;C=z|0;if((a[e+(ca*3|0)|0]|0)==1){c[C>>2]=3;c[C+4>>2]=0;a[n+(ca<<4)+8|0]=1;a[n+(ca<<4)+9|0]=_;a[n+(ca<<4)+10|0]=1;$=z+11|0;a[$]=a[A]|0;a[$+1|0]=a[A+1|0]|0;a[$+2|0]=a[A+2|0]|0;a[$+3|0]=a[A+3|0]|0;a[$+4|0]=a[A+4|0]|0;da=1}else{c[C>>2]=1;c[C+4>>2]=0;a[n+(ca<<4)+8|0]=0;a[n+(ca<<4)+9|0]=_;a[n+(ca<<4)+10|0]=1;_=z+11|0;a[_]=a[B]|0;a[_+1|0]=a[B+1|0]|0;a[_+2|0]=a[B+2|0]|0;a[_+3|0]=a[B+3|0]|0;a[_+4|0]=a[B+4|0]|0;_=ca+1|0;z=n+(_<<4)|0;C=a[e+(_*3|0)+1|0]|0;$=z|0;c[$>>2]=2;c[$+4>>2]=0;a[n+(_<<4)+8|0]=0;a[n+(_<<4)+9|0]=C;a[n+(_<<4)+10|0]=1;_=z+11|0;a[_]=a[K]|0;a[_+1|0]=a[K+1|0]|0;a[_+2|0]=a[K+2|0]|0;a[_+3|0]=a[K+3|0]|0;a[_+4|0]=a[K+4|0]|0;da=2}_=da+ca|0;z=ba-2|0;if((z|0)>1){ea=_;fa=z}else{ga=_;break}while(1){_=(a[e+(ea*3|0)|0]|0)==1;z=n+(ea<<4)|0;C=a[e+(ea*3|0)+1|0]|0;$=z|0;c[$>>2]=-1;c[$+4>>2]=-1;$=n+(ea<<4)+8|0;if(_){a[$]=1;a[n+(ea<<4)+9|0]=C;a[n+(ea<<4)+10|0]=1;_=z+11|0;a[_]=a[A]|0;a[_+1|0]=a[A+1|0]|0;a[_+2|0]=a[A+2|0]|0;a[_+3|0]=a[A+3|0]|0;a[_+4|0]=a[A+4|0]|0;ha=1}else{a[$]=0;a[n+(ea<<4)+9|0]=C;a[n+(ea<<4)+10|0]=1;C=z+11|0;a[C]=a[B]|0;a[C+1|0]=a[B+1|0]|0;a[C+2|0]=a[B+2|0]|0;a[C+3|0]=a[B+3|0]|0;a[C+4|0]=a[B+4|0]|0;C=ea+1|0;z=n+(C<<4)|0;$=a[e+(C*3|0)+1|0]|0;_=z|0;c[_>>2]=-1;c[_+4>>2]=-1;a[n+(C<<4)+8|0]=0;a[n+(C<<4)+9|0]=$;a[n+(C<<4)+10|0]=1;C=z+11|0;a[C]=a[K]|0;a[C+1|0]=a[K+1|0]|0;a[C+2|0]=a[K+2|0]|0;a[C+3|0]=a[K+3|0]|0;a[C+4|0]=a[K+4|0]|0;ha=2}C=ha+ea|0;z=fa-2|0;if((z|0)>1){ea=C;fa=z}else{ga=C;break}}}else{ga=ca}}while(0);do{if((S|0)>1){u=k|0;t=l|0;K=m|0;B=n+(ga<<4)|0;A=a[e+(ga*3|0)+1|0]|0;C=B|0;if((a[e+(ga*3|0)|0]|0)==1){c[C>>2]=1536;c[C+4>>2]=0;a[n+(ga<<4)+8|0]=1;a[n+(ga<<4)+9|0]=A;a[n+(ga<<4)+10|0]=1;z=B+11|0;a[z]=a[u]|0;a[z+1|0]=a[u+1|0]|0;a[z+2|0]=a[u+2|0]|0;a[z+3|0]=a[u+3|0]|0;a[z+4|0]=a[u+4|0]|0;ia=1}else{c[C>>2]=512;c[C+4>>2]=0;a[n+(ga<<4)+8|0]=0;a[n+(ga<<4)+9|0]=A;a[n+(ga<<4)+10|0]=1;A=B+11|0;a[A]=a[t]|0;a[A+1|0]=a[t+1|0]|0;a[A+2|0]=a[t+2|0]|0;a[A+3|0]=a[t+3|0]|0;a[A+4|0]=a[t+4|0]|0;A=ga+1|0;B=n+(A<<4)|0;C=a[e+(A*3|0)+1|0]|0;z=B|0;c[z>>2]=1024;c[z+4>>2]=0;a[n+(A<<4)+8|0]=0;a[n+(A<<4)+9|0]=C;a[n+(A<<4)+10|0]=1;A=B+11|0;a[A]=a[K]|0;a[A+1|0]=a[K+1|0]|0;a[A+2|0]=a[K+2|0]|0;a[A+3|0]=a[K+3|0]|0;a[A+4|0]=a[K+4|0]|0;ia=2}A=ia+ga|0;B=S-2|0;if((B|0)>1){ja=A;ka=B}else{la=A;break}while(1){A=(a[e+(ja*3|0)|0]|0)==1;B=n+(ja<<4)|0;C=a[e+(ja*3|0)+1|0]|0;z=B|0;c[z>>2]=-1;c[z+4>>2]=-1;z=n+(ja<<4)+8|0;if(A){a[z]=1;a[n+(ja<<4)+9|0]=C;a[n+(ja<<4)+10|0]=2;A=B+11|0;a[A]=a[u]|0;a[A+1|0]=a[u+1|0]|0;a[A+2|0]=a[u+2|0]|0;a[A+3|0]=a[u+3|0]|0;a[A+4|0]=a[u+4|0]|0;ma=1}else{a[z]=0;a[n+(ja<<4)+9|0]=C;a[n+(ja<<4)+10|0]=2;C=B+11|0;a[C]=a[t]|0;a[C+1|0]=a[t+1|0]|0;a[C+2|0]=a[t+2|0]|0;a[C+3|0]=a[t+3|0]|0;a[C+4|0]=a[t+4|0]|0;C=ja+1|0;B=n+(C<<4)|0;z=a[e+(C*3|0)+1|0]|0;A=B|0;c[A>>2]=-1;c[A+4>>2]=-1;a[n+(C<<4)+8|0]=0;a[n+(C<<4)+9|0]=z;a[n+(C<<4)+10|0]=2;C=B+11|0;a[C]=a[K]|0;a[C+1|0]=a[K+1|0]|0;a[C+2|0]=a[K+2|0]|0;a[C+3|0]=a[K+3|0]|0;a[C+4|0]=a[K+4|0]|0;ma=2}C=ma+ja|0;B=ka-2|0;if((B|0)>1){ja=C;ka=B}else{la=C;break}}}else{la=ga}}while(0);if((X|0)>3){K=k|0;t=l|0;u=m|0;C=X-4|0;B=la;z=X;do{A=(a[e+(B*3|0)|0]|0)==1;$=n+(B<<4)|0;_=a[e+(B*3|0)+1|0]|0;na=$|0;c[na>>2]=-1;c[na+4>>2]=-1;na=n+(B<<4)+8|0;if(A){a[na]=1;a[n+(B<<4)+9|0]=_;a[n+(B<<4)+10|0]=3;A=$+11|0;a[A]=a[K]|0;a[A+1|0]=a[K+1|0]|0;a[A+2|0]=a[K+2|0]|0;a[A+3|0]=a[K+3|0]|0;a[A+4|0]=a[K+4|0]|0;oa=1}else{a[na]=0;a[n+(B<<4)+9|0]=_;a[n+(B<<4)+10|0]=3;_=$+11|0;a[_]=a[t]|0;a[_+1|0]=a[t+1|0]|0;a[_+2|0]=a[t+2|0]|0;a[_+3|0]=a[t+3|0]|0;a[_+4|0]=a[t+4|0]|0;_=B+1|0;$=n+(_<<4)|0;na=a[e+(_*3|0)+1|0]|0;A=$|0;c[A>>2]=-1;c[A+4>>2]=-1;a[n+(_<<4)+8|0]=0;a[n+(_<<4)+9|0]=na;a[n+(_<<4)+10|0]=3;_=$+11|0;a[_]=a[u]|0;a[_+1|0]=a[u+1|0]|0;a[_+2|0]=a[u+2|0]|0;a[_+3|0]=a[u+3|0]|0;a[_+4|0]=a[u+4|0]|0;oa=2}B=oa+B|0;z=z-2|0;}while((z|0)>3);pa=B;qa=X-2-(C&-2)|0}else{pa=la;qa=X}if((qa|0)>1){z=k|0;u=l|0;t=m|0;K=n+(pa<<4)|0;_=a[e+(pa*3|0)+1|0]|0;$=K|0;if((a[e+(pa*3|0)|0]|0)==1){c[$>>2]=48;c[$+4>>2]=0;a[n+(pa<<4)+8|0]=1;a[n+(pa<<4)+9|0]=_;a[n+(pa<<4)+10|0]=3;na=K+11|0;a[na]=a[z]|0;a[na+1|0]=a[z+1|0]|0;a[na+2|0]=a[z+2|0]|0;a[na+3|0]=a[z+3|0]|0;a[na+4|0]=a[z+4|0]|0;ra=1}else{c[$>>2]=16;c[$+4>>2]=0;a[n+(pa<<4)+8|0]=0;a[n+(pa<<4)+9|0]=_;a[n+(pa<<4)+10|0]=3;_=K+11|0;a[_]=a[u]|0;a[_+1|0]=a[u+1|0]|0;a[_+2|0]=a[u+2|0]|0;a[_+3|0]=a[u+3|0]|0;a[_+4|0]=a[u+4|0]|0;u=pa+1|0;_=n+(u<<4)|0;K=a[e+(u*3|0)+1|0]|0;$=_|0;c[$>>2]=32;c[$+4>>2]=0;a[n+(u<<4)+8|0]=0;a[n+(u<<4)+9|0]=K;a[n+(u<<4)+10|0]=3;u=_+11|0;a[u]=a[t]|0;a[u+1|0]=a[t+1|0]|0;a[u+2|0]=a[t+2|0]|0;a[u+3|0]=a[t+3|0]|0;a[u+4|0]=a[t+4|0]|0;ra=2}sa=qa-2|0;ta=ra+pa|0}else{sa=qa;ta=pa}if((sa|0)==0){ua=ta}else{t=n+(ta<<4)|0;u=a[e+(ta*3|0)+1|0]|0;_=t|0;c[_>>2]=256;c[_+4>>2]=0;a[n+(ta<<4)+8|0]=0;a[n+(ta<<4)+9|0]=u;a[n+(ta<<4)+10|0]=3;u=t+11|0;a[u]=a[v]|0;a[u+1|0]=a[v+1|0]|0;a[u+2|0]=a[v+2|0]|0;a[u+3|0]=a[v+3|0]|0;a[u+4|0]=a[v+4|0]|0;ua=ta+1|0}do{if((ua|0)<(f|0)){if((a[e+(ua*3|0)+2|0]|0)!=4){va=ua;break}u=n+(ua<<4)|0;t=a[e+(ua*3|0)+1|0]|0;_=u|0;c[_>>2]=8;c[_+4>>2]=0;a[n+(ua<<4)+8|0]=3;a[n+(ua<<4)+9|0]=t;a[n+(ua<<4)+10|0]=4;t=u+11|0;a[t]=a[w]|0;a[t+1|0]=a[w+1|0]|0;a[t+2|0]=a[w+2|0]|0;a[t+3|0]=a[w+3|0]|0;a[t+4|0]=a[w+4|0]|0;va=ua+1|0}else{va=ua}}while(0);b:do{if((va|0)<(f|0)){w=va;while(1){if((a[e+(w*3|0)+2|0]|0)!=4){wa=w;break b}v=n+(w<<4)|0;C=a[e+(w*3|0)+1|0]|0;B=v|0;c[B>>2]=-1;c[B+4>>2]=-1;a[n+(w<<4)+8|0]=3;a[n+(w<<4)+9|0]=C;a[n+(w<<4)+10|0]=4;C=v+11|0;a[C]=a[x]|0;a[C+1|0]=a[x+1|0]|0;a[C+2|0]=a[x+2|0]|0;a[C+3|0]=a[x+3|0]|0;a[C+4|0]=a[x+4|0]|0;C=w+1|0;if((C|0)<(f|0)){w=C}else{wa=C;break}}}else{wa=va}}while(0);x=wa;while(1){if((x|0)>1){xa=1;ya=0}else{break}while(1){w=xa-1|0;C=n+(w<<4)|0;v=c[C+4>>2]|0;B=n+(xa<<4)|0;t=B|0;u=c[t+4>>2]|0;if(v>>>0>u>>>0|v>>>0==u>>>0&(c[C>>2]|0)>>>0>(c[t>>2]|0)>>>0){t=B;c[y>>2]=c[t>>2];c[y+4>>2]=c[t+4>>2];c[y+8>>2]=c[t+8>>2];c[y+12>>2]=c[t+12>>2];B=n+(w<<4)|0;c[t>>2]=c[B>>2];c[t+4>>2]=c[B+4>>2];c[t+8>>2]=c[B+8>>2];c[t+12>>2]=c[B+12>>2];c[B>>2]=c[y>>2];c[B+4>>2]=c[y+4>>2];c[B+8>>2]=c[y+8>>2];c[B+12>>2]=c[y+12>>2];za=xa}else{za=ya}B=xa+1|0;if((B|0)<(x|0)){xa=B;ya=za}else{break}}if((za|0)>0){x=za}else{break}}if((wa|0)>0){Aa=0;Ba=0;Ca=0}else{r=0;s=0;break}while(1){a[e+(Aa*3|0)|0]=a[n+(Aa<<4)+8|0]|0;a[e+(Aa*3|0)+1|0]=a[n+(Aa<<4)+9|0]|0;a[e+(Aa*3|0)+2|0]=a[n+(Aa<<4)+10|0]|0;x=n+(Aa<<4)|0;y=c[x>>2]|0;B=c[x+4>>2]|0;x=(y|0)==(-1|0)&(B|0)==(-1|0);t=(x?0:y)|Ca;y=(x?0:B)|Ba;B=Aa+1|0;if((B|0)<(wa|0)){Aa=B;Ba=y;Ca=t}else{r=y;s=t;break}}}}while(0);do{if((f|0)>0){Ca=b+6544|0;Ba=0;Aa=0;c:while(1){wa=a[e+(Aa*3|0)|0]|0;if((Ba|0)>63){Da=-1094995529;Ea=110;break}n=b+492+((wa&255)<<6)+(d[e+(Aa*3|0)+1|0]<<2)|0;za=c[n>>2]|0;ya=(za|0)!=0;do{if((a[e+(Aa*3|0)+2|0]|0)==0){if(ya){qfb(za+112352|0)}$Db(n);Fa=Ba}else{if(!ya){xa=cEb(456160)|0;c[n>>2]=xa;if((xa|0)==0){Da=-12;Ea=110;break c}pfb(b,xa+112352|0)}if(wa<<24>>24==2){Fa=Ba;break}xa=wa<<24>>24==1;do{if(xa){Ga=1}else{if(!(wa<<24>>24==0)){Ga=0;break}Ga=(c[Ca>>2]|0)==1|0}}while(0);if((Ba|0)>=(64-Ga|0)){Ea=94;break c}va=Ba+1|0;c[b+5436+(Ba<<2)>>2]=(c[n>>2]|0)+160;if(!xa){if(!(wa<<24>>24==0)){Fa=va;break}if((c[Ca>>2]|0)!=1){Fa=va;break}}c[b+5436+(va<<2)>>2]=(c[n>>2]|0)+52352;Fa=Ba+2|0}}while(0);n=Aa+1|0;if((n|0)<(f|0)){Ba=Fa;Aa=n}else{Ea=103;break}}if((Ea|0)==94){yDb(c[o>>2]|0,16,2216760,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Da=-1094995529;i=j;return Da|0}else if((Ea|0)==103){if(!((c[Ca>>2]|0)==1&(Fa|0)==2)){Ha=r;Ia=s;Ja=Fa;break}Aa=(s|0)==4&(r|0)==0;Ha=Aa?0:0;Ia=Aa?3:0;Ja=Fa;break}else if((Ea|0)==110){i=j;return Da|0}}else{Ha=r;Ia=s;Ja=0}}while(0);UGb(b+748|0,b+492|0,256)|0;if(!((Ia|0)==0&(Ha|0)==0)){s=p+448|0;c[s>>2]=Ia;c[s+4>>2]=Ha}s=b+6752|0;c[s>>2]=Ia;c[s+4>>2]=Ha;c[b+6744>>2]=Ja;c[p+416>>2]=Ja;c[b+6760>>2]=g;do{if((h|0)!=0){g=Peb(c[o>>2]|0)|0;if((g|0)<0){Da=g}else{break}i=j;return Da|0}}while(0);Da=0;i=j;return Da|0}function Veb(b){b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=b+6504|0;e=c[d>>2]|0;if((e|0)==23){f=242}else if((e|0)==39){f=200}else{f=c[b+6772>>2]|0}e=b+6776|0;h=b+6788|0;i=b+6520|0;j=b+6780|0;k=3;while(1){l=(k|0)<2;m=(k|0)==1;n=(k|0)==2;o=(k|0)<3;p=0;do{q=c[b+492+(k<<6)+(p<<2)>>2]|0;do{if((q|0)!=0){if(l){r=q+52352|0;s=q+160|0;t=0;do{u=c[b+620+(t<<2)>>2]|0;do{if((u|0)!=0){if((c[u+104544>>2]|0)!=0){break}v=u+104548|0;if((c[v>>2]|0)<0){break}else{w=0;x=0}while(1){do{if((c[u+104552+(w<<2)>>2]|0)==(k|0)){if((c[u+104584+(w<<2)>>2]|0)!=(p|0)){y=17;break}z=u+104616+(w<<2)|0;if((c[z>>2]|0)==1){A=x}else{Yeb(b,s,u,x);B=c[z>>2]|0;z=((B|0)!=0)+x|0;if((B|0)==2){C=z;break}else{A=z}}Yeb(b,r,u,A);C=A+1|0}else{y=17}}while(0);if((y|0)==17){y=0;C=((c[u+104616+(w<<2)>>2]|0)==3?2:1)+x|0}z=w+1|0;if((z|0)>(c[v>>2]|0)){break}else{w=z;x=C}}}}while(0);t=t+1|0;}while((t|0)<16)}do{if((c[d>>2]|0)==4){if((c[q+256>>2]|0)==0){break}if((a[q+188|0]|0)!=0){ne[c[e>>2]&1023](b,q+160|0)}if(!((a[q+52380|0]|0)!=0&m)){break}ne[c[e>>2]&1023](b,q+52352|0)}}while(0);t=q+160|0;r=t|0;s=q+312|0;if((c[s>>2]|0)!=0){cf[c[j>>2]&1023](q+5472|0,s,t|0,1)}t=q+52352|0;s=q+52504|0;if((c[s>>2]|0)!=0){cf[c[j>>2]&1023](q+57664|0,s,t|0,1)}if(l){s=q+160|0;u=0;do{v=c[b+620+(u<<2)>>2]|0;do{if((v|0)!=0){if((c[v+104544>>2]|0)!=1){break}z=v+104548|0;if((c[z>>2]|0)<0){break}else{D=0;E=0}while(1){do{if((c[v+104552+(D<<2)>>2]|0)==(k|0)){if((c[v+104584+(D<<2)>>2]|0)!=(p|0)){y=40;break}B=v+104616+(D<<2)|0;if((c[B>>2]|0)==1){F=E}else{Yeb(b,s,v,E);G=c[B>>2]|0;B=((G|0)!=0)+E|0;if((G|0)==2){H=B;break}else{F=B}}Yeb(b,t,v,F);H=F+1|0}else{y=40}}while(0);if((y|0)==40){y=0;H=((c[v+104616+(D<<2)>>2]|0)==3?2:1)+E|0}B=D+1|0;if((B|0)>(c[z>>2]|0)){break}else{D=B;E=H}}}}while(0);u=u+1|0;}while((u|0)<16)}if(n){if((c[q+104544>>2]|0)==3){y=45}}else{y=45}if((y|0)==45){y=0;ne[f&1023](b,r);if((c[d>>2]|0)==4){ne[c[h>>2]&1023](b,r)}do{if(m){ne[f&1023](b,t);if((c[d>>2]|0)!=4){break}ne[c[h>>2]&1023](b,t)}}while(0);if((c[i>>2]|0)>0){sfb(b,q+112352|0,k,c[q+52320>>2]|0,c[q+104512>>2]|0)}if(!o){break}}t=q+104512|0;r=q+52320|0;u=0;do{s=c[b+620+(u<<2)>>2]|0;do{if((s|0)!=0){if((c[s+104544>>2]|0)!=3){break}v=c[s+104548>>2]|0;if((v|0)<0){break}z=s+52320|0;B=0;G=0;while(1){do{if((c[s+104552+(B<<2)>>2]|0)==(k|0)){if((c[s+104584+(B<<2)>>2]|0)!=(p|0)){y=67;break}I=c[s+104616+(B<<2)>>2]|0;if((I|0)==1){J=G;K=c[z>>2]|0;L=c[i>>2]|0}else{M=+g[s+104648+(G*480|0)>>2];N=c[z>>2]|0;O=c[r>>2]|0;P=c[i>>2]|0;Q=1024<<((P|0)==1);if((Q|0)>0){R=0;do{S=O+(R<<2)|0;g[S>>2]=+g[S>>2]+M*+g[N+(R<<2)>>2];R=R+1|0;}while((R|0)<(Q|0))}Q=((I|0)!=0)+G|0;if((I|0)==2){T=Q;break}else{J=Q;K=N;L=P}}Q=J+1|0;M=+g[s+104648+(J*480|0)>>2];R=c[t>>2]|0;O=1024<<((L|0)==1);if((O|0)>0){U=0}else{T=Q;break}while(1){S=R+(U<<2)|0;g[S>>2]=+g[S>>2]+M*+g[K+(U<<2)>>2];S=U+1|0;if((S|0)<(O|0)){U=S}else{T=Q;break}}}else{y=67}}while(0);if((y|0)==67){y=0;T=((c[s+104616+(B<<2)>>2]|0)==3?2:1)+G|0}Q=B+1|0;if((Q|0)>(v|0)){break}else{B=Q;G=T}}}}while(0);u=u+1|0;}while((u|0)<16)}}while(0);p=p+1|0;}while((p|0)<16);if((k|0)>0){k=k-1|0}else{break}}return}function Web(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[d+52160>>2]|0;f=d+9408|0;g=b+1024|0;Xe[c[b+5164>>2]&4095](b+5248|0,g,d+5312|0);if((a[d+13|0]|0)==0){le[c[b+5412>>2]&1023](e,f,g,5434024,256);h=f;i=b+2048|0;j=i;UGb(h|0,j|0,1024)|0;return}else{k=f;UGb(e|0,k|0,768)|0;le[c[b+5412>>2]&1023](e+768|0,d+10176|0,g,5461800,64);UGb(e+1280|0,b+1280|0,768)|0;h=k;i=b+2048|0;j=i;UGb(h|0,j|0,1024)|0;return}}function Xeb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,i=0.0,j=0,k=0,l=0,m=0;d=c[b+52160>>2]|0;e=b+9408|0;f=0;do{h=b+5312+(f<<2)|0;i=+g[h>>2];j=b+5312+(511-f<<2)|0;g[h>>2]=-0.0- +g[j>>2];g[j>>2]=i;j=b+5312+((f|1)<<2)|0;i=-0.0- +g[j>>2];h=b+5312+(510-f<<2)|0;g[j>>2]=+g[h>>2];g[h>>2]=i;f=f+2|0;}while((f|0)<256);f=a+1024|0;Xe[c[a+5164>>2]&4095](a+5248|0,f,b+5312|0);h=0;while(1){j=a+1024+(h<<2)|0;g[j>>2]=-0.0- +g[j>>2];j=h+2|0;if((j|0)<512){h=j}else{k=128;break}}while(1){h=k-128|0;g[d+(h<<2)>>2]=+g[a+1024+(255-k<<2)>>2]*+g[1278144+(h<<2)>>2]+ +g[b+9408+(k+256<<2)>>2]*+g[1278144+(k+384<<2)>>2]+ +g[1278144+(k+896<<2)>>2]*(-0.0- +g[b+9408+(767-k<<2)>>2])+ +g[1278144+(k+1408<<2)>>2]*(-0.0- +g[b+9408+(k+1280<<2)>>2]);h=k+1|0;if((h|0)<256){k=h}else{l=0;break}}while(1){k=l+128|0;g[d+(k<<2)>>2]=+g[a+1024+(l<<2)>>2]*+g[1278144+(k<<2)>>2]+ +g[1278144+(l+640<<2)>>2]*(-0.0- +g[b+9408+(511-l<<2)>>2])+ +g[1278144+(l+1152<<2)>>2]*(-0.0- +g[b+9408+(l+512<<2)>>2])+ +g[b+9408+(1535-l<<2)>>2]*+g[1278144+(l+1664<<2)>>2];k=l+1|0;if((k|0)<256){l=k}else{m=0;break}}do{l=m+384|0;g[d+(l<<2)>>2]=+g[a+1024+(m+256<<2)>>2]*+g[1278144+(l<<2)>>2]+ +g[1278144+(m+896<<2)>>2]*(-0.0- +g[b+9408+(255-m<<2)>>2])+ +g[1278144+(m+1408<<2)>>2]*(-0.0- +g[b+9408+(m+768<<2)>>2]);m=m+1|0;}while((m|0)<128);m=e;VGb(b+11456|0,m|0,4096)|0;UGb(m|0,f|0,2048)|0;return}function Yeb(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;k=i;l=c[h+236>>2]|0;if((c[e+6504>>2]|0)==4){yDb(c[e+4>>2]|0,16,2303944,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=k;return}e=c[h+176>>2]|0;if((e|0)<=0){i=k;return}m=h+160|0;n=a[m]|0;o=h+5472|0;p=0;q=0;r=f+5312|0;f=n;s=n;while(1){n=h+180+p|0;if(f<<24>>24==0){t=q;u=0;v=s}else{w=0;x=q;y=s;while(1){do{if((c[h+3332+(x<<2)>>2]|0)==0){z=y}else{A=+g[h+104648+(j*480|0)+(x<<2)>>2];B=a[n]|0;if(B<<24>>24==0){z=y;break}C=b[l+(w<<1)>>1]|0;D=b[l+(w+1<<1)>>1]|0;E=0;F=B;while(1){if((C&65535)>>>0<(D&65535)>>>0){B=E<<7;G=D&65535;H=C&65535;do{I=H+B|0;J=r+(I<<2)|0;g[J>>2]=+g[J>>2]+A*+g[o+(I<<2)>>2];H=H+1|0;}while((H|0)<(G|0));K=a[n]|0}else{K=F}G=E+1|0;if((G|0)<(K&255|0)){E=G;F=K}else{break}}z=a[m]|0}}while(0);F=w+1|0;E=x+1|0;if((F|0)<(z&255|0)){w=F;x=E;y=z}else{t=E;u=z;v=z;break}}}y=(d[n]|0)<<7;x=p+1|0;if((x|0)<(e|0)){o=o+(y<<2)|0;p=x;q=t;r=r+(y<<2)|0;f=u;s=v}else{break}}i=k;return}function Zeb(e,f,h){e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;j=i;k=c[e+6504>>2]|0;l=(k|0)!=39;do{if(l){m=h+8|0;n=c[m>>2]|0;o=h|0;p=c[o>>2]|0;q=d[p+(n>>>3)|0]|0;r=h+16|0;s=c[r>>2]|0;t=((n|0)<(s|0))+n|0;c[m>>2]=t;if((q&128>>>((n&7)>>>0)|0)!=0){yDb(c[e+4>>2]|0,16,2143384,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1094995529;i=j;return v|0}n=f+4|0;c[f+8>>2]=c[n>>2];q=p+(t>>>3)|0;p=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(t&7)>>>30;q=t+2|0;c[m>>2]=s>>>0>q>>>0?q:s;c[n>>2]=p;if((k|0)!=23|(p|0)==0){s=f+12|0;a[f+13|0]=a[s]|0;q=c[m>>2]|0;t=(d[(c[o>>2]|0)+(q>>>3)|0]|0)<<(q&7)>>>7;c[m>>2]=((q|0)<(c[r>>2]|0))+q;a[s]=t&1;w=p;x=m;y=r;z=o;break}yDb(c[e+4>>2]|0,16,2137952,(u=i,i=i+8|0,c[u>>2]=p,u)|0);i=u;c[n>>2]=0;v=-1094995529;i=j;return v|0}else{w=c[f+4>>2]|0;x=h+8|0;y=h+16|0;z=h|0}}while(0);h=f+16|0;c[h>>2]=1;a[f+20|0]=1;n=c[x>>2]|0;p=c[y>>2]|0;o=(c[z>>2]|0)+(n>>>3)|0;r=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(n&7);a:do{if((w|0)==2){o=n+4|0;c[x>>2]=p>>>0>o>>>0?o:p;a[f|0]=r>>>28;o=0;do{m=c[x>>2]|0;t=d[(c[z>>2]|0)+(m>>>3)|0]|0;c[x>>2]=((m|0)<(c[y>>2]|0))+m;s=c[h>>2]|0;if((t&128>>>((m&7)>>>0)|0)==0){c[h>>2]=s+1;a[f+20+s|0]=1}else{m=s-1+(f+20)|0;a[m]=(a[m]|0)+1}o=o+1|0;}while((o|0)<7);c[f+88>>2]=8;o=e+6508|0;m=c[o>>2]|0;c[f+76>>2]=c[1130296+(m<<2)>>2];c[f+84>>2]=d[1277856+m|0]|0;c[f+92>>2]=d[1110584+(c[o>>2]|0)|0]|0;c[f+96>>2]=0;A=35}else{o=n+6|0;c[x>>2]=p>>>0>o>>>0?o:p;o=f|0;a[o]=r>>>26;c[f+88>>2]=1;m=e+6508|0;s=c[m>>2]|0;do{if((k|0)==39|(k|0)==23){t=c[1130240+(s<<2)>>2]|0;c[f+76>>2]=t;q=a[1277840+s|0]|0;c[f+84>>2]=q&255;c[f+92>>2]=d[1110568+(c[m>>2]|0)|0]|0;if(q<<24>>24==0|(t|0)==0){v=-558323010}else{break}i=j;return v|0}else{c[f+76>>2]=c[1130352+(s<<2)>>2];c[f+84>>2]=d[1277872+s|0]|0;c[f+92>>2]=d[1110600+(c[m>>2]|0)|0]|0}}while(0);if(l){s=c[x>>2]|0;t=(d[(c[z>>2]|0)+(s>>>3)|0]|0)<<(s&7)>>>7;c[x>>2]=((s|0)<(c[y>>2]|0))+s;s=t&1;c[f+96>>2]=s;c[f+104>>2]=0;B=s}else{B=c[f+96>>2]|0}if((B|0)==0){A=35;break}if((k|0)==1){s=c[x>>2]|0;t=c[z>>2]|0;q=d[t+(s>>>3)|0]|0;C=c[y>>2]|0;D=((s|0)<(C|0))+s|0;c[x>>2]=D;do{if((q&128>>>((s&7)>>>0)|0)!=0){E=t+(D>>>3)|0;F=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>27;E=D+5|0;c[x>>2]=C>>>0>E>>>0?E:C;c[f+104>>2]=F;if(!((F|0)==31|(F|0)==0)){break}yDb(c[e+4>>2]|0,16,2113184,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break a}}while(0);C=a[o]|0;D=a[1277776+(c[m>>2]|0)|0]|0;if(((C&255)>>>0>(D&255)>>>0?D:C)<<24>>24==0){A=35;break}else{G=0;H=t}while(1){C=c[x>>2]|0;D=(d[H+(C>>>3)|0]|0)<<(C&7)>>>7;c[x>>2]=((C|0)<(c[y>>2]|0))+C;a[f+108+G|0]=D&1;D=G+1|0;C=a[o]|0;s=a[1277776+(c[m>>2]|0)|0]|0;if((D|0)>=(((C&255)>>>0>(s&255)>>>0?s:C)&255|0)){A=35;break a}G=D;H=c[z>>2]|0}}else if((k|0)==23){yDb(c[e+4>>2]|0,16,2124880,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1163346256;i=j;return v|0}else if((k|0)==17|(k|0)==2){yDb(c[e+4>>2]|0,16,2131296,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break}else{m=c[x>>2]|0;t=c[y>>2]|0;D=(c[z>>2]|0)+(m>>>3)|0;C=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(m&7)>>>31;D=m+1|0;c[x>>2]=t>>>0>D>>>0?D:t;t=C&255;a[f+28|0]=t;if(t<<24>>24==0){A=35;break}t=a[o]|0;C=c[x>>2]|0;D=c[y>>2]|0;m=c[z>>2]|0;s=m+(C>>>3)|0;q=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(C&7)>>>21;s=C+11|0;C=D>>>0>s>>>0?s:D;c[x>>2]=C;b[f+30>>1]=q;q=m+(C>>>3)|0;s=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(C&7)>>>29;q=C+3|0;C=D>>>0>q>>>0?q:D;c[x>>2]=C;g[f+32>>2]=+g[688368+(s<<2)>>2];s=(t&255)>>>0>40>>>0?40:t&255;if((s|0)==0){A=35;break}else{I=0;J=C;K=m;L=D}while(1){D=(d[K+(J>>>3)|0]|0)<<(J&7)>>>7;c[x>>2]=((J|0)<(L|0))+J;a[f+36+I|0]=D&1;D=I+1|0;if((D|0)>=(s|0)){A=35;break a}I=D;J=c[x>>2]|0;K=c[z>>2]|0;L=c[y>>2]|0}}}}while(0);do{if((A|0)==35){y=d[f|0]|0;L=c[f+84>>2]|0;if((y|0)>(L|0)){yDb(c[e+4>>2]|0,16,2119296,(u=i,i=i+16|0,c[u>>2]=y,c[u+8>>2]=L,u)|0);i=u;break}else{v=0;i=j;return v|0}}}while(0);a[f|0]=0;v=-1094995529;i=j;return v|0}function _eb(d,f){d=d|0;f=f|0;var h=0,i=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0.0,v=0,w=0.0,x=0,y=0.0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0,K=0;h=f+100|0;if((c[h>>2]|0)==0){i=0;do{g[f+36032+(i*24|0)+16>>2]=0.0;g[f+36032+(i*24|0)+20>>2]=0.0;g[f+36032+(i*24|0)>>2]=0.0;g[f+36032+(i*24|0)+4>>2]=0.0;g[f+36032+(i*24|0)+8>>2]=1.0;g[f+36032+(i*24|0)+12>>2]=1.0;i=i+1|0;}while((i|0)<672);c[h>>2]=1}if((c[f+4>>2]|0)==2){h=0;do{g[f+36032+(h*24|0)+16>>2]=0.0;g[f+36032+(h*24|0)+20>>2]=0.0;g[f+36032+(h*24|0)>>2]=0.0;g[f+36032+(h*24|0)+4>>2]=0.0;g[f+36032+(h*24|0)+8>>2]=1.0;g[f+36032+(h*24|0)+12>>2]=1.0;h=h+1|0;}while((h|0)<672);return}h=a[1277776+(c[d+6508>>2]|0)|0]|0;if(!(h<<24>>24==0)){d=f+76|0;i=f+96|0;j=0;l=c[d>>2]|0;while(1){m=b[l+(j<<1)>>1]|0;n=j+1|0;if((m&65535)>>>0<(e[l+(n<<1)>>1]|0)>>>0){o=f+108+j|0;p=m&65535;while(1){m=f+5312+(p<<2)|0;if((c[i>>2]|0)==0){q=0}else{q=(a[o]|0)!=0|0}r=f+36032+(p*24|0)+16|0;s=+g[r>>2];t=f+36032+(p*24|0)+20|0;u=+g[t>>2];v=f+36032+(p*24|0)|0;w=+g[v>>2];x=f+36032+(p*24|0)+4|0;y=+g[x>>2];z=f+36032+(p*24|0)+8|0;A=+g[z>>2];B=f+36032+(p*24|0)+12|0;C=+g[B>>2];if(A>1.0){D=(g[k>>2]=.953125/A,c[k>>2]|0);E=w*(c[k>>2]=D+32767+(D&1)&-65536,+g[k>>2])}else{E=0.0}if(C>1.0){D=(g[k>>2]=.953125/C,c[k>>2]|0);F=y*(c[k>>2]=D+32767+(D&1)&-65536,+g[k>>2])}else{F=0.0}G=s*E;if((q|0)==0){H=+g[m>>2]}else{I=(c[k>>2]=(g[k>>2]=G+u*F,c[k>>2]|0)+32768&-65536,+g[k>>2])+ +g[m>>2];g[m>>2]=I;H=I}I=H-G;g[x>>2]=(c[k>>2]=(g[k>>2]=y*.90625+u*I,c[k>>2]|0)&-65536,+g[k>>2]);g[B>>2]=(c[k>>2]=(g[k>>2]=C*.90625+(u*u+I*I)*.5,c[k>>2]|0)&-65536,+g[k>>2]);g[v>>2]=(c[k>>2]=(g[k>>2]=w*.90625+s*H,c[k>>2]|0)&-65536,+g[k>>2]);g[z>>2]=(c[k>>2]=(g[k>>2]=A*.90625+(s*s+H*H)*.5,c[k>>2]|0)&-65536,+g[k>>2]);g[t>>2]=(c[k>>2]=(g[k>>2]=(s-E*H)*.953125,c[k>>2]|0)&-65536,+g[k>>2]);g[r>>2]=(c[k>>2]=(g[k>>2]=H*.953125,c[k>>2]|0)&-65536,+g[k>>2]);r=p+1|0;t=c[d>>2]|0;if((r|0)<(e[t+(n<<1)>>1]|0)){p=r}else{J=t;break}}}else{J=l}if((n|0)<(h&255|0)){j=n;l=J}else{break}}}J=c[f+104>>2]|0;if((J|0)==0){return}l=J-1|0;if((l|0)<672){K=l}else{return}do{g[f+36032+(K*24|0)+16>>2]=0.0;g[f+36032+(K*24|0)+20>>2]=0.0;g[f+36032+(K*24|0)>>2]=0.0;g[f+36032+(K*24|0)+4>>2]=0.0;g[f+36032+(K*24|0)+8>>2]=1.0;g[f+36032+(K*24|0)+12>>2]=1.0;K=K+30|0;}while((K|0)<672);return}function $eb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;j=(c[f+4>>2]|0)==2;k=j&1;if(j){l=7}else{l=(c[a+6504>>2]|0)==1?20:12}j=f+88|0;if((c[j>>2]|0)<=0){m=0;i=h;return m|0}f=2-k|0;n=e+8|0;o=e+16|0;p=32-f|0;q=k<<1;k=6-q|0;r=32-k|0;s=5-q|0;q=32-s|0;t=c[e>>2]|0;e=0;a:while(1){u=c[n>>2]|0;v=c[o>>2]|0;w=t+(u>>>3)|0;x=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>(p>>>0);w=u+f|0;c[n>>2]=v>>>0>w>>>0?w:v;v=b+4+(e<<2)|0;c[v>>2]=x;b:do{if((x|0)!=0){w=c[n>>2]|0;u=(d[t+(w>>>3)|0]|0)<<(w&7)>>>7;y=c[o>>2]|0;z=((w|0)<(y|0))+w|0;c[n>>2]=z;w=u&1;if((c[v>>2]|0)<=0){break}u=w+3|0;A=0;B=z;z=y;while(1){y=t+(B>>>3)|0;C=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(B&7)>>>(r>>>0);y=B+k|0;c[n>>2]=z>>>0>y>>>0?y:z;c[b+36+(e<<4)+(A<<2)>>2]=C;C=c[n>>2]|0;y=c[o>>2]|0;D=t+(C>>>3)|0;E=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>>(q>>>0);D=C+s|0;c[n>>2]=y>>>0>D>>>0?D:y;F=b+292+(e<<4)+(A<<2)|0;c[F>>2]=E;if((E|0)>(l|0)){break a}do{if((E|0)!=0){y=c[n>>2]|0;D=(d[t+(y>>>3)|0]|0)<<(y&7)>>>7;c[n>>2]=((y|0)<(c[o>>2]|0))+y;c[b+164+(e<<4)+(A<<2)>>2]=D&1;D=c[n>>2]|0;y=(d[t+(D>>>3)|0]|0)<<(D&7)>>>7;C=c[o>>2]|0;G=((D|0)<(C|0))+D|0;c[n>>2]=G;D=y&1;y=u-D|0;if((c[F>>2]|0)<=0){break}H=32-y|0;I=c[186208+((D<<1|w)<<2)>>2]|0;D=0;J=G;do{G=t+(J>>>3)|0;K=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(J&7)>>>(H>>>0);G=J+y|0;J=C>>>0>G>>>0?G:C;c[n>>2]=J;g[b+420+(e*320|0)+(A*80|0)+(D<<2)>>2]=+g[I+(K<<2)>>2];D=D+1|0;}while((D|0)<(c[F>>2]|0))}}while(0);D=A+1|0;if((D|0)>=(c[v>>2]|0)){break b}A=D;B=c[n>>2]|0;z=c[o>>2]|0}}}while(0);v=e+1|0;if((v|0)<(c[j>>2]|0)){e=v}else{m=0;L=17;break}}if((L|0)==17){i=h;return m|0}yDb(c[a+4>>2]|0,16,2077064,(a=i,i=i+16|0,c[a>>2]=E,c[a+8>>2]=l,a)|0);i=a;c[F>>2]=0;m=-1094995529;i=h;return m|0}function afb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+48|0;f=e|0;g=c[a+4>>2]|0;TGb(f|0,0,44)|0;h=b+8|0;j=c[h>>2]|0;k=(c[b+12>>2]|0)-j|0;if((d|0)==0){l=k;m=0}else{l=(k|0)<(d|0)?k:d;m=1}if((j&7|0)!=0){DDb(g,1970392,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1163346256;i=e;return o|0}if((l|0)<1){o=-1094995529;i=e;return o|0}d=b|0;k=(j|0)/8|0;j=Neb(0,g,f,(c[d>>2]|0)+k|0,l,m)|0;if((j|0)<0){o=-1094995529;i=e;return o|0}m=a+6816|0;do{if((c[m>>2]|0)==0){yDb(g,48,1959232,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=12}else{if((c[a+6512>>2]|0)==(c[f+8>>2]|0)){if((c[a+6516>>2]|0)==(c[f+12>>2]|0)){break}}yDb(g,32,1961592,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=12}}while(0);if((p|0)==12){c[m>>2]=0;m=(j+7|0)/8|0;p=g+100|0;n=g+96|0;f=c[n>>2]|0;do{if((c[p>>2]|0)<(m|0)){ZDb(f);a=WDb(m+16|0)|0;c[n>>2]=a;if((a|0)==0){o=-12}else{q=a;break}i=e;return o|0}else{q=f}}while(0);c[p>>2]=m;UGb(q|0,(c[d>>2]|0)+k|0,m)|0;TGb((c[g+96>>2]|0)+m|0,0,16)|0}m=c[h>>2]|0;g=-m|0;k=(c[b+16>>2]|0)-m|0;if((j|0)<(g|0)){r=g}else{r=(k|0)<(j|0)?k:j}c[h>>2]=r+m;o=j;i=e;return o|0}function bfb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[d+52160>>2]|0;f=d+9408|0;g=(a[d+12|0]|0)!=0?7996320:5461800;h=(a[d+13|0]|0)!=0;i=h?7996832:5462312;j=h?7996320:5461800;h=b+1024|0;k=b+5728|0;l=d+4|0;if((c[l>>2]|0)==2){m=b+5184|0;n=b+5228|0;Xe[c[n>>2]&4095](m,h,d+5312|0);Xe[c[n>>2]&4095](m,b+1536|0,d+5824|0);Xe[c[n>>2]&4095](m,b+2048|0,d+6336|0);Xe[c[n>>2]&4095](m,b+2560|0,d+6848|0);Xe[c[n>>2]&4095](m,b+3072|0,d+7360|0);Xe[c[n>>2]&4095](m,b+3584|0,d+7872|0);Xe[c[n>>2]&4095](m,b+4096|0,d+8384|0);Xe[c[n>>2]&4095](m,b+4608|0,d+8896|0)}else{Xe[c[b+5164>>2]&4095](b+5120|0,h,d+5312|0)}m=c[d+8>>2]|0;do{if((m|0)==0|(m|0)==3){if(!((c[l>>2]|0)>>>0<2>>>0)){o=7;break}le[c[b+5412>>2]&1023](e,f,h,i,512)}else{o=7}}while(0);do{if((o|0)==7){UGb(e|0,f|0,1792)|0;i=(c[l>>2]|0)==2;m=b+5412|0;le[c[m>>2]&1023](e+1792|0,d+11200|0,h,j,64);if(i){le[c[m>>2]&1023](e+2304|0,b+1280|0,b+1536|0,g,64);le[c[m>>2]&1023](e+2816|0,b+1792|0,b+2048|0,g,64);le[c[m>>2]&1023](e+3328|0,b+2304|0,b+2560|0,g,64);le[c[m>>2]&1023](k,b+2816|0,b+3072|0,g,64);UGb(e+3840|0,k|0,256)|0;break}else{UGb(e+2304|0,b+1280|0,1792)|0;break}}}while(0);e=c[l>>2]|0;if((e|0)==2){UGb(f|0,b+5984|0,256)|0;l=b+5412|0;le[c[l>>2]&1023](d+9664|0,b+3328|0,b+3584|0,g,64);le[c[l>>2]&1023](d+10176|0,b+3840|0,b+4096|0,g,64);le[c[l>>2]&1023](d+10688|0,b+4352|0,b+4608|0,g,64);UGb(d+11200|0,b+4864|0,256)|0;return}g=f;f=b+3072|0;if((e|0)==1){UGb(g|0,f|0,1792)|0;UGb(d+11200|0,b+4864|0,256)|0;return}else{UGb(g|0,f|0,2048)|0;return}}function cfb(d,e){d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=e|0;h=c[e+76>>2]|0;if((c[e+4>>2]|0)==2){return}i=c[e+52160>>2]|0;j=d+1024|0;k=b[e+30>>1]|0;if(k<<16>>16<1024){l=((k&65535)<<16)+67108864|0;if((l|0)>0){m=l>>16;n=4}else{o=0}}else{m=2048;n=4}if((n|0)==4){n=e+32|0;l=0;while(1){g[i+(l<<2)>>2]=+g[e+23744+(l+2048-(k<<16>>16)<<2)>>2]*+g[n>>2];p=l+1|0;if((p|0)<(m|0)){l=p}else{o=m;break}}}TGb(i+(o<<2)|0,0,2048-o<<2|0)|0;cf[c[d+6784>>2]&1023](d,j,i,f);i=e+152|0;if((c[i>>2]|0)!=0){cf[c[d+6780>>2]&1023](j,i,f,0)}f=e|0;i=a[f]|0;if(i<<24>>24==0){return}else{q=0;r=i}while(1){do{if((a[e+36+q|0]|0)==0){s=r;t=q+1|0}else{i=b[h+(q<<1)>>1]|0;j=q+1|0;o=b[h+(j<<1)>>1]|0;if(!((i&65535)>>>0<(o&65535)>>>0)){s=r;t=j;break}m=o&65535;o=i&65535;do{i=e+5312+(o<<2)|0;g[i>>2]=+g[d+1024+(o<<2)>>2]+ +g[i>>2];o=o+1|0;}while((o|0)<(m|0));s=a[f]|0;t=j}}while(0);if((t|0)<(((s&255)>>>0>40>>>0?40:s&255)|0)){q=t;r=s}else{break}}return}function dfb(a,b,f,h){a=a|0;b=b|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0;j=i;i=i+168|0;k=j|0;l=j+80|0;m=c[f+92>>2]|0;n=d[f|0]|0;o=(m|0)>(n|0)?n:m;m=f+88|0;n=c[m>>2]|0;if((n|0)<=0){i=j;return}p=f+84|0;q=f+76|0;f=(h|0)==0;h=l|0;r=0;s=n;while(1){n=b+4+(r<<2)|0;t=c[n>>2]|0;if((t|0)>0){u=r<<7;v=c[p>>2]|0;w=0;x=t;while(1){t=v-(c[b+36+(r<<4)+(w<<2)>>2]|0)|0;y=(t|0)<0?0:t;t=c[b+292+(r<<4)+(w<<2)>>2]|0;a:do{if((t|0)==0){z=x}else{A=(t|0)>0;if(A){B=0;while(1){C=-0.0- +g[b+420+(r*320|0)+(w*80|0)+(B<<2)>>2];g[k+(B<<2)>>2]=C;D=B+1|0;E=D>>1;if((E|0)>0){F=B-1|0;G=0;do{H=k+(G<<2)|0;I=+g[H>>2];J=k+(F-G<<2)|0;K=+g[J>>2];g[H>>2]=I+K*C;g[J>>2]=K+I*C;G=G+1|0;}while((G|0)<(E|0))}if((D|0)<(t|0)){B=D}else{break}}}B=c[q>>2]|0;E=e[B+(((y|0)>(o|0)?o:y)<<1)>>1]|0;G=e[B+(((v|0)>(o|0)?o:v)<<1)>>1]|0;B=G-E|0;if((B|0)<1){z=x;break}F=(c[b+164+(r<<4)+(w<<2)>>2]|0)==0;J=F?1:-1;H=(F?E:G-1|0)+u|0;G=(B|0)>0;if(!f){if(G){L=0;M=H}else{z=x;break}while(1){E=(L|0)>(t|0)?t:L;if((E|0)>=1){F=a+(M<<2)|0;N=1;C=+g[F>>2];do{I=+g[a+(M-(ba(N,J)|0)<<2)>>2];C=C-I*+g[k+(N-1<<2)>>2];g[F>>2]=C;N=N+1|0;}while((N|0)<=(E|0))}E=L+1|0;if((E|0)<(B|0)){L=E;M=M+J|0}else{z=x;break a}}}if(G){O=0;P=H}else{z=x;break}while(1){E=a+(P<<2)|0;C=+g[E>>2];g[h>>2]=C;N=(O|0)>(t|0)?t:O;if((N|0)>=1){F=1;I=C;do{I=I+ +g[l+(F<<2)>>2]*+g[k+(F-1<<2)>>2];F=F+1|0;}while((F|0)<=(N|0));g[E>>2]=I}if(A){N=t;while(1){F=N-1|0;g[l+(N<<2)>>2]=+g[l+(F<<2)>>2];if((F|0)>0){N=F}else{break}}}N=O+1|0;if((N|0)<(B|0)){O=N;P=P+J|0}else{break}}z=c[n>>2]|0}}while(0);t=w+1|0;if((t|0)<(z|0)){v=y;w=t;x=z}else{break}}Q=c[m>>2]|0}else{Q=s}x=r+1|0;if((x|0)<(Q|0)){r=x;s=Q}else{break}}i=j;return}function efb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=(a[f+12|0]|0)!=0;h=(a[f+13|0]|0)!=0;i=f+4|0;if((c[i>>2]|0)==3){TGb(e|0,0,1792)|0;f=e+1792|0;cf[c[b+5396>>2]&1023](f,f,h?7996320:5461800,128)}else{cf[c[b+5396>>2]&1023](e,e,h?7996832:5462312,1024)}h=c[b+5420>>2]|0;f=e+4096|0;if((c[i>>2]|0)==1){i=e+5888|0;cf[h&1023](i,i,g?7996320:5461800,128);TGb(e+6400|0,0,1792)|0;j=b+5312|0;k=b+5360|0;l=c[k>>2]|0;Xe[l&4095](j,d,e);return}else{cf[h&1023](f,f,g?7996832:5462312,1024);j=b+5312|0;k=b+5360|0;l=c[k>>2]|0;Xe[l&4095](j,d,e);return}}function ffb(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0;e=d+5312|0;f=(a[d+12|0]|0)!=0;h=f?7996832:5462312;i=f?7996320:5461800;f=c[d+4>>2]|0;if((f|0)==1){j=e;UGb(j|0,b+3072|0,1792)|0;TGb(d+7616|0,0,1792)|0;cf[c[b+5420>>2]&1023](d+7104|0,b+4864|0,i+256|0,64);k=0;while(1){g[d+5312+(k+512<<2)>>2]=+g[b+1024+(1023-k<<2)>>2]*+g[i+(63-k<<2)>>2];l=k+1|0;if((l|0)<64){k=l}else{m=j;break}}}else if((f|0)==2){f=e;UGb(f|0,d+9408|0,2048)|0;TGb(d+7616|0,0,1792)|0;cf[c[b+5420>>2]&1023](d+7104|0,b+4864|0,i+256|0,64);j=0;while(1){g[d+5312+(j+512<<2)>>2]=+g[b+1024+(1023-j<<2)>>2]*+g[i+(63-j<<2)>>2];k=j+1|0;if((k|0)<64){j=k}else{m=f;break}}}else{cf[c[b+5420>>2]&1023](e,b+3072|0,h+2048|0,512);f=0;do{g[d+5312+(f+512<<2)>>2]=+g[b+1024+(1023-f<<2)>>2]*+g[h+(511-f<<2)>>2];f=f+1|0;}while((f|0)<512);m=e}e=d+27840|0;UGb(d+23744|0,e|0,4096)|0;UGb(e|0,c[d+52160>>2]|0,4096)|0;UGb(d+31936|0,m|0,4096)|0;return}function gfb(b){b=b|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0;e=i;i=i+24|0;f=e|0;h=e+8|0;j=e+16|0;k=b+60|0;l=c[k>>2]|0;m=l;c[b+424>>2]=1024;n=b+412|0;o=0;while(1){if((o|0)>=16){break}if((c[n>>2]|0)==(c[1743568+(o<<2)>>2]|0)){break}else{o=o+1|0}}p=c[b+416>>2]|0;q=l+228|0;c[q>>2]=p;if((o|0)==16){yDb(b,16,1962656,(r=i,i=i+8|0,c[r>>2]=c[n>>2],r)|0);i=r;s=-22;i=e;return s|0}if((p|0)>6){yDb(b,16,1934464,(r=i,i=i+8|0,c[r>>2]=p,r)|0);i=r;s=-22;i=e;return s|0}t=c[b+840>>2]|0;if(!((t|0)==(-99|0)|(t|0)==1)){yDb(b,16,1911424,(r=i,i=i+8|0,c[r>>2]=t,r)|0);i=r;s=-22;i=e;return s|0}if(+(c[b+72>>2]|0)*1024.0/+(c[n>>2]|0)>+(p*6144|0|0)){yDb(b,16,1890944,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=e;return s|0}c[l+224>>2]=o;n=l+232|0;c[n>>2]=1878808+((p-1|0)*5|0);fCb(l+164|0,c[b+88>>2]&8388608);Slb(7996832,4.0,1024);Slb(7996320,6.0,128);VXa(10);VXa(7);p=aLa(l+36|0,11,0,32768.0)|0;a:do{if((p|0)==0){t=aLa(l+100|0,8,0,32768.0)|0;if((t|0)!=0){u=t;break}t=cEb((c[q>>2]|0)*12288|0)|0;v=l+4832|0;c[v>>2]=t;do{if((t|0)==0){if(((c[q>>2]|0)*12288|0|0)==0){break}yDb(b,16,2348432,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;u=-12;break a}}while(0);t=cEb((d[c[n>>2]|0]|0)*456160|0)|0;c[l+236>>2]=t;do{if((t|0)==0){if(((d[c[n>>2]|0]|0)*456160|0|0)==0){break}yDb(b,16,2348432,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;u=-12;break a}}while(0);t=cEb(21)|0;w=b+96|0;c[w>>2]=t;if((t|0)==0){yDb(b,16,2348432,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;u=-12;break}if((c[q>>2]|0)>0){y=0;do{c[m+200+(y<<2)>>2]=(c[v>>2]|0)+((y*3072|0)<<2);y=y+1|0;}while((y|0)<(c[q>>2]|0));z=c[w>>2]|0}else{z=t}c[b+100>>2]=5;y=c[k>>2]|0;v=z;x=fe((c[y+224>>2]<<4|c[y+228>>2])<<19|268457701|0)|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;a[z+4|0]=0;v=f|0;c[v>>2]=c[403568+(o<<2)>>2];c[f+4>>2]=c[403176+(o<<2)>>2];y=j|0;c[y>>2]=d[1277872+o|0]|0;c[j+4>>2]=d[1277856+o|0]|0;A=c[n>>2]|0;B=a[A]|0;if(B<<24>>24==0){C=B&255}else{B=0;D=A;while(1){A=B+1|0;a[h+B|0]=(a[D+A|0]|0)==1|0;E=c[n>>2]|0;F=d[E]|0;if((A|0)<(F|0)){B=A;D=E}else{C=F;break}}}D=Xmb(l+240|0,b,2,v,y,C,h|0)|0;if((D|0)!=0){u=D;break}c[l+284>>2]=_mb(b)|0;c[l+288>>2]=1286008+(c[l+8>>2]<<4);D=c[b+80>>2]|0;if((D|0)==0){G=120.0}else{G=+(D|0)}g[l+300>>2]=G;Dfb();D=0;do{H=+g[7994608+(D<<2)>>2];g[7992896+(D<<2)>>2]=+R(H*+R(H));D=D+1|0;}while((D|0)<428);c[b+116>>2]=1024;Qhb(b,l+304|0);s=0;i=e;return s|0}else{u=p}}while(0);p=c[k>>2]|0;bLa(p+36|0);bLa(p+100|0);Zmb(p+240|0);k=c[p+284>>2]|0;if((k|0)!=0){anb(k)}$Db(p+4832|0);$Db(p+236|0);Rhb(p+304|0);s=u;i=e;return s|0}function hfb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0.0,Ja=0.0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0;j=i;i=i+416|0;k=j|0;l=j+16|0;m=j+352|0;n=j+408|0;o=c[b+60>>2]|0;p=o;q=o+200|0;r=o+296|0;if((c[r>>2]|0)==2){s=0;i=j;return s|0}t=(f|0)!=0;do{if(t){u=Shb(o+304|0,f)|0;if((u|0)<0){s=u;i=j;return s|0}else{v=(c[f+76>>2]|0)+2048|0;break}}else{v=2048}}while(0);u=o+228|0;w=c[u>>2]|0;y=w-1|0;if((w|0)>0){z=f+64|0;A=f+76|0;f=3072-v<<2;if(t){B=0;while(1){C=p+200+(B<<2)|0;D=c[C>>2]|0;UGb(D+4096|0,D+8192|0,4096)|0;UGb((c[C>>2]|0)+8192|0,c[(c[z>>2]|0)+(d[1878768+(y*6|0)+B|0]<<2)>>2]|0,c[A>>2]<<2)|0;TGb((c[C>>2]|0)+(v<<2)|0,0,f|0)|0;C=B+1|0;D=c[u>>2]|0;if((C|0)<(D|0)){B=C}else{E=D;break}}}else{B=0;while(1){A=p+200+(B<<2)|0;y=c[A>>2]|0;UGb(y+4096|0,y+8192|0,4096)|0;TGb((c[A>>2]|0)+(v<<2)|0,0,f|0)|0;A=B+1|0;y=c[u>>2]|0;if((A|0)<(y|0)){B=A}else{E=y;break}}}}else{E=w}w=c[o+284>>2]|0;if((w|0)!=0){$mb(w,q,E)}E=b+428|0;if((c[E>>2]|0)==0){s=0;i=j;return s|0}w=o+232|0;B=c[w>>2]|0;if((a[B]|0)!=0){f=o+236|0;v=o+224|0;y=o+260|0;A=o+164|0;z=o+100|0;D=o+148|0;C=o+36|0;F=o+84|0;G=o+264|0;H=o+240|0;I=o+244|0;J=m;K=0;L=0;M=B;while(1){B=L+1|0;N=a[M+B|0]|0;O=N<<24>>24==1?2:1;P=c[f>>2]|0;Q=N<<24>>24==3;N=0;do{R=P+(L*456160|0)+160+(N*52192|0)|0;S=N+K|0;T=c[q+(S<<2)>>2]|0;U=T+4096|0;V=l+(S*56|0)|0;if(Q){W=V|0;c[W>>2]=0;X=l+(S*56|0)+12|0;c[X>>2]=0;Y=l+(S*56|0)+16|0;c[Y>>2]=1;c[l+(S*56|0)+20>>2]=1;c[P+(L*456160|0)+160+(N*52192|0)+84>>2]=(c[v>>2]|0)>7?1:3;Z=P+(L*456160|0)+160+(N*52192|0)+4|0;_=W;$=X;aa=Y}else{Y=P+(L*456160|0)+160+(N*52192|0)+4|0;Se[c[(c[I>>2]|0)+8>>2]&511](m,H,U,t?T+6144|0:0,S,c[Y>>2]|0);UGb(V|0,J|0,56)|0;Z=Y;_=V|0;$=l+(S*56|0)+12|0;aa=l+(S*56|0)+16|0}c[P+(L*456160|0)+160+(N*52192|0)+8>>2]=c[Z>>2];V=c[_>>2]|0;c[Z>>2]=V;Y=P+(L*456160|0)+160+(N*52192|0)+12|0;a[P+(L*456160|0)+160+(N*52192|0)+13|0]=a[Y]|0;a[Y]=c[$>>2];Y=c[aa>>2]|0;X=P+(L*456160|0)+160+(N*52192|0)+88|0;c[X>>2]=Y;W=(Y|0)==8|0;c[P+(L*456160|0)+160+(N*52192|0)+80>>2]=c[(c[y>>2]|0)+(W<<2)>>2];if(Q){ca=P+(L*456160|0)+160+(N*52192|0)+84|0;da=ca;ea=ca}else{da=(c[G>>2]|0)+(W<<2)|0;ea=P+(L*456160|0)+160+(N*52192|0)+84|0}c[ea>>2]=c[da>>2];if((Y|0)>0){Y=0;do{a[P+(L*456160|0)+160+(N*52192|0)+20+Y|0]=c[l+(S*56|0)+20+(Y<<2)>>2];Y=Y+1|0;}while((Y|0)<(c[X>>2]|0));fa=c[Z>>2]|0}else{fa=V}Xe[c[1793192+(fa<<2)>>2]&4095](A,R,T);if((c[Z>>2]|0)==2){Xe[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+5312|0,P+(L*456160|0)+160+(N*52192|0)+15552|0);Xe[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+5824|0,P+(L*456160|0)+160+(N*52192|0)+16576|0);Xe[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+6336|0,P+(L*456160|0)+160+(N*52192|0)+17600|0);Xe[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+6848|0,P+(L*456160|0)+160+(N*52192|0)+18624|0);Xe[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+7360|0,P+(L*456160|0)+160+(N*52192|0)+19648|0);Xe[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+7872|0,P+(L*456160|0)+160+(N*52192|0)+20672|0);Xe[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+8384|0,P+(L*456160|0)+160+(N*52192|0)+21696|0);Xe[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+8896|0,P+(L*456160|0)+160+(N*52192|0)+22720|0)}else{Xe[c[F>>2]&4095](C,P+(L*456160|0)+160+(N*52192|0)+5312|0,P+(L*456160|0)+160+(N*52192|0)+15552|0)}UGb(T|0,U|0,4096)|0;N=N+1|0;}while((N|0)<(O|0));N=c[w>>2]|0;if((B|0)<(d[N]|0)){K=O+K|0;L=B;M=N}else{break}}}M=c[u>>2]<<13;L=r0a(b,e,M,(M|0)<0|0?-1:0)|0;if((L|0)<0){s=L;i=j;return s|0}L=o+12|0;M=e+24|0;K=e+28|0;C=o+32|0;F=o+20|0;z=o+28|0;D=o+24|0;Z=o+16|0;A=L;fa=b+88|0;da=L;L=k;ea=b+72|0;G=b+412|0;y=o+300|0;aa=o+236|0;$=o+240|0;_=o+244|0;J=n|0;H=o+292|0;m=o+288|0;I=o+4|0;a:while(1){v=c[K>>2]|0;q=(v|0)<0;f=q?0:c[M>>2]|0;N=q?0:v;c[C>>2]=N<<3;c[F>>2]=f;c[z>>2]=f+N;c[D>>2]=f;c[Z>>2]=32;c[A>>2]=0;do{if((c[E>>2]&255|0)==1){if((c[fa>>2]&8388608|0)!=0){ga=32;ha=0;break}c[A>>2]=454672;c[Z>>2]=13;K_(da);f=0;N=c[A>>2]|0;v=c[Z>>2]|0;while(1){q=a[2176984+f|0]|0;if((v|0)>8){ia=v-8|0;ja=q|N<<8}else{P=fe(q>>>((8-v|0)>>>0)|N<<v|0)|0;Q=c[D>>2]|0;x=P;a[Q]=x;x=x>>8;a[Q+1|0]=x;x=x>>8;a[Q+2|0]=x;x=x>>8;a[Q+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;ia=v+24|0;ja=q}c[A>>2]=ja;c[Z>>2]=ia;q=f+1|0;if((q|0)<13){f=q;N=ja;v=ia}else{break}}if((ia|0)>7){ka=ia-7|0;la=ja<<7}else{v=fe(ja<<ia|0)|0;N=c[D>>2]|0;x=v;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;ka=ia+25|0;la=0}c[A>>2]=la;c[Z>>2]=ka;ga=ka;ha=la}else{ga=32;ha=0}}while(0);TGb(L|0,0,16)|0;B=c[w>>2]|0;if((a[B]|0)==0){ma=ga}else{O=0;N=0;v=B;B=ha;f=ga;while(1){U=l+(O*56|0)|0;T=N+1|0;R=a[v+T|0]|0;V=R&255;q=R<<24>>24==1;R=q?2:1;Q=c[aa>>2]|0;P=Q+(N*456160|0)|0;if((f|0)>3){na=f-3|0;oa=B<<3|V}else{X=fe(V>>>((3-f|0)>>>0)|B<<f|0)|0;Y=c[D>>2]|0;x=X;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;na=f+29|0;oa=V}c[A>>2]=oa;c[Z>>2]=na;Y=k+(V<<2)|0;V=c[Y>>2]|0;c[Y>>2]=V+1;if((na|0)>4){pa=na-4|0;qa=oa<<4|V}else{Y=fe(V>>>((4-na|0)>>>0)|oa<<na|0)|0;X=c[D>>2]|0;x=Y;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;pa=na+28|0;qa=V}c[A>>2]=qa;c[Z>>2]=pa;V=0;do{c[n+(V<<2)>>2]=Q+(N*456160|0)+160+(V*52192|0)+5312;V=V+1|0;}while((V|0)<(R|0));cf[c[(c[_>>2]|0)+12>>2]&1023]($,O,J,U);V=0;do{c[H>>2]=V+O;Ve[c[c[m>>2]>>2]&15](b,p,Q+(N*456160|0)+160+(V*52192|0)|0,+g[y>>2]);V=V+1|0;}while((V|0)<(R|0));V=P|0;c[V>>2]=0;b:do{if(q){X=O+1|0;if((c[U>>2]|0)!=(c[l+(X*56|0)>>2]|0)){break}if((c[l+(O*56|0)+12>>2]|0)!=(c[l+(X*56|0)+12>>2]|0)){break}c[V>>2]=1;Y=c[l+(O*56|0)+16>>2]|0;S=0;while(1){if((S|0)>=(Y|0)){break b}if((c[l+(O*56|0)+20+(S<<2)>>2]|0)==(c[l+(X*56|0)+20+(S<<2)>>2]|0)){S=S+1|0}else{break}}c[V>>2]=0}}while(0);c[H>>2]=O;U=c[I>>2]|0;do{if((U|0)==0){ra=0}else{if((c[V>>2]|0)==0){ra=0;break}if((U|0)<=0){S=c[(c[m>>2]|0)+12>>2]|0;if((S|0)==0){ra=0;break}$e[S&3](p,P,+g[y>>2]);ra=0;break}S=Q+(N*456160|0)+248|0;X=c[S>>2]|0;if((X|0)<=0){ra=0;break}Y=Q+(N*456160|0)+244|0;W=0;ca=c[Y>>2]|0;sa=X;while(1){if((ca|0)>0){X=W<<4;ta=0;do{a[ta+X+(Q+(N*456160|0)+8)|0]=1;ta=ta+1|0;ua=c[Y>>2]|0;}while((ta|0)<(ua|0));va=ua;wa=c[S>>2]|0}else{va=ca;wa=sa}ta=(d[Q+(N*456160|0)+180+W|0]|0)+W|0;if((ta|0)<(wa|0)){W=ta;ca=va;sa=wa}else{ra=0;break}}}}while(0);do{c[Q+(N*456160|0)+160+(ra*52192|0)+3132>>2]=0;P=Q+(N*456160|0)+160+(ra*52192|0)+88|0;U=c[P>>2]|0;if((U<<4|0)>0){sa=Q+(N*456160|0)+160+(ra*52192|0)+84|0;ca=(ra|0)==0;W=Q+(N*456160|0)+160+(ra*52192|0)+80|0;S=0;Y=0;ta=0;X=c[sa>>2]|0;while(1){c:do{if((X|0)>0){if(ca){xa=0;ya=S;za=X}else{Aa=0;Ba=S;while(1){Ca=(d[(c[W>>2]|0)+Aa|0]|0)+Ba|0;Da=Aa+1|0;if((Da|0)<(X|0)){Aa=Da;Ba=Ca}else{Ea=Ca;Fa=X;break c}}}while(1){do{if((c[V>>2]|0)==0){Ga=za}else{if((a[xa+ta+(Q+(N*456160|0)+8)|0]|0)==0){Ga=za;break}if((a[(c[W>>2]|0)+xa|0]|0)==0){Ga=za;break}else{Ha=0}do{Ba=Ha+ya|0;Aa=Q+(N*456160|0)+5472+(Ba<<2)|0;Ca=Q+(N*456160|0)+57664+(Ba<<2)|0;Ia=+g[Ca>>2];Ja=(+g[Aa>>2]+Ia)*.5;g[Aa>>2]=Ja;g[Ca>>2]=Ja-Ia;Ha=Ha+1|0;}while((Ha|0)<(d[(c[W>>2]|0)+xa|0]|0));Ga=c[sa>>2]|0}}while(0);Ca=(d[(c[W>>2]|0)+xa|0]|0)+ya|0;Aa=xa+1|0;if((Aa|0)<(Ga|0)){xa=Aa;ya=Ca;za=Ga}else{Ea=Ca;Fa=Ga;break}}}else{Ea=S;Fa=X}}while(0);Ca=ta-1|0;Aa=Fa;while(1){if((Aa|0)<=0){break}if((a[Ca+Aa+(Q+(N*456160|0)+160+(ra*52192|0)+5156)|0]|0)==0){break}else{Aa=Aa-1|0}}Ka=(Y|0)>(Aa|0)?Y:Aa;Ca=ta+16|0;La=c[P>>2]|0;if((Ca|0)<(La<<4|0)){S=Ea;Y=Ka;ta=Ca;X=Fa}else{break}}Ma=Ka&255;Na=La}else{Ma=0;Na=U}X=Q+(N*456160|0)+160+(ra*52192|0)|0;a[X]=Ma;if((Na|0)>0){ta=0;Y=Ma;S=Na;while(1){W=Q+(N*456160|0)+160+(ra*52192|0)+20+ta|0;if(Y<<24>>24==0){Oa=0;Pa=S}else{sa=ta<<4;ca=0;do{Ca=(d[W]|0)+ta|0;Ba=ta;while(1){if((Ba|0)>=(Ca|0)){Qa=1;break}if((a[(Ba<<4)+ca+(Q+(N*456160|0)+160+(ra*52192|0)+5156)|0]|0)==0){Qa=0;break}else{Ba=Ba+1|0}}a[ca+sa+(Q+(N*456160|0)+160+(ra*52192|0)+5156)|0]=Qa;ca=ca+1|0;Ra=a[X]|0;}while((ca|0)<(Ra&255|0));Oa=Ra;Pa=c[P>>2]|0}ca=(d[W]|0)+ta|0;if((ca|0)<(Pa|0)){ta=ca;Y=Oa;S=Pa}else{break}}}ra=ra+1|0;}while((ra|0)<(R|0));do{if(q){S=c[V>>2]|0;d:do{if((S|0)!=0){Y=Q+(N*456160|0)+160|0;ta=a[Y]|0;P=Q+(N*456160|0)+52352|0;X=a[P]|0;U=(ta&255)>>>0>(X&255)>>>0?ta:X;a[Y]=U;a[P]=U;P=c[Q+(N*456160|0)+248>>2]|0;Y=P<<4;do{if(!((Y|0)<1|U<<24>>24==0)){X=U&255;ta=0;ca=0;while(1){sa=0;Sa=ca;do{Sa=((a[sa+ta+(Q+(N*456160|0)+8)|0]|0)!=0)+Sa|0;sa=sa+1|0;}while((sa|0)<(X|0));sa=ta+16|0;if((sa|0)<(Y|0)){ta=sa;ca=Sa}else{break}}if((Sa|0)==0){break}ca=(Sa|0)<(ba(X,P)|0);c[Q+(N*456160|0)+4>>2]=ca?1:2;break d}}while(0);c[Q+(N*456160|0)+4>>2]=0}}while(0);P=c[A>>2]|0;Y=c[Z>>2]|0;if((Y|0)>1){Ta=Y-1|0;Ua=P<<1|S}else{U=fe(S>>>((1-Y|0)>>>0)|P<<Y|0)|0;P=c[D>>2]|0;x=U;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;Ta=Y+31|0;Ua=S}c[A>>2]=Ua;c[Z>>2]=Ta;if((c[V>>2]|0)==0){Va=0;break}jfb(p,Q+(N*456160|0)+160|0);Y=Q+(N*456160|0)+4|0;P=c[Y>>2]|0;U=c[A>>2]|0;W=c[Z>>2]|0;if((W|0)>2){Wa=W-2|0;Xa=U<<2|P}else{ca=fe(P>>>((2-W|0)>>>0)|U<<W|0)|0;U=c[D>>2]|0;x=ca;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;Wa=W+30|0;Xa=P}c[A>>2]=Xa;c[Z>>2]=Wa;if((c[Y>>2]|0)!=1){Va=0;break}Y=Q+(N*456160|0)+248|0;P=c[Y>>2]|0;if((P|0)<=0){Va=0;break}W=Q+(N*456160|0)+160|0;U=0;ca=a[W]|0;ta=P;P=Xa;sa=Wa;while(1){if(ca<<24>>24==0){Ya=0;Za=ta;_a=P;$a=sa}else{Aa=U<<4;Ba=0;Ca=P;Da=sa;while(1){ab=d[Ba+Aa+(Q+(N*456160|0)+8)|0]|0;if((Da|0)>1){bb=Da-1|0;cb=ab|Ca<<1}else{db=fe(ab>>>((1-Da|0)>>>0)|Ca<<Da|0)|0;eb=c[D>>2]|0;x=db;a[eb]=x;x=x>>8;a[eb+1|0]=x;x=x>>8;a[eb+2|0]=x;x=x>>8;a[eb+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;bb=Da+31|0;cb=ab}c[A>>2]=cb;c[Z>>2]=bb;ab=Ba+1|0;fb=a[W]|0;if((ab|0)<(fb&255|0)){Ba=ab;Ca=cb;Da=bb}else{break}}Ya=fb;Za=c[Y>>2]|0;_a=cb;$a=bb}Da=(d[Q+(N*456160|0)+180+U|0]|0)+U|0;if((Da|0)<(Za|0)){U=Da;ca=Ya;ta=Za;P=_a;sa=$a}else{Va=0;break}}}else{Va=0}}while(0);do{c[H>>2]=Va+O;q=Q+(N*456160|0)+160+(Va*52192|0)|0;sa=c[V>>2]|0;P=Q+(N*456160|0)+160+(Va*52192|0)+4644|0;ta=c[P>>2]|0;ca=c[A>>2]|0;U=c[Z>>2]|0;if((U|0)>8){gb=U-8|0;hb=ca<<8|ta}else{Y=fe(ta>>>((8-U|0)>>>0)|ca<<U|0)|0;ca=c[D>>2]|0;x=Y;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;gb=U+24|0;hb=ta}c[A>>2]=hb;c[Z>>2]=gb;if((sa|0)==0){jfb(p,q|0)}sa=Q+(N*456160|0)+160+(Va*52192|0)+88|0;do{if((c[sa>>2]|0)>0){ta=0;do{U=Q+(N*456160|0)+160+(Va*52192|0)+20+ta|0;pe[c[(c[m>>2]|0)+4>>2]&7](p,q,ta,d[U]|0,+g[y>>2]);ta=(d[U]|0)+ta|0;ib=c[sa>>2]|0;}while((ta|0)<(ib|0));if((ib|0)<=0){break}ta=q|0;U=a[ta]|0;ca=c[P>>2]|0;Y=0;W=U;S=ib;Da=U;while(1){if(W<<24>>24==0){jb=ca;kb=0;lb=S;mb=Da}else{U=Y<<4;Ca=ca;Ba=0;Aa=Da;while(1){ab=Ba+U|0;if((a[Q+(N*456160|0)+160+(Va*52192|0)+5156+ab|0]|0)==0){eb=c[Q+(N*456160|0)+160+(Va*52192|0)+4644+(ab<<2)>>2]|0;ab=eb-Ca+60|0;if(!(ab>>>0<121>>>0)){nb=139;break a}db=d[1277624+ab|0]|0;ob=c[1277136+(ab<<2)>>2]|0;ab=c[A>>2]|0;pb=c[Z>>2]|0;if((pb|0)>(db|0)){qb=pb-db|0;rb=ab<<db|ob}else{sb=fe(ob>>>((db-pb|0)>>>0)|ab<<pb|0)|0;ab=c[D>>2]|0;x=sb;a[ab]=x;x=x>>8;a[ab+1|0]=x;x=x>>8;a[ab+2|0]=x;x=x>>8;a[ab+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;qb=32-db+pb|0;rb=ob}c[A>>2]=rb;c[Z>>2]=qb;tb=eb;ub=a[ta]|0}else{tb=Ca;ub=Aa}eb=Ba+1|0;if((eb|0)<(ub&255|0)){Ca=tb;Ba=eb;Aa=ub}else{break}}jb=tb;kb=ub;lb=c[sa>>2]|0;mb=ub}Aa=(d[Q+(N*456160|0)+160+(Va*52192|0)+20+Y|0]|0)+Y|0;if((Aa|0)<(lb|0)){ca=jb;Y=Aa;W=kb;S=lb;Da=mb}else{break}}}}while(0);P=Q+(N*456160|0)+160+(Va*52192|0)+3132|0;Da=(c[P>>2]|0)!=0|0;S=c[A>>2]|0;W=c[Z>>2]|0;if((W|0)>1){vb=W-1|0;wb=S<<1|Da}else{Y=fe(Da>>>((1-W|0)>>>0)|S<<W|0)|0;S=c[D>>2]|0;x=Y;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;vb=W+31|0;wb=Da}c[A>>2]=wb;c[Z>>2]=vb;Da=c[P>>2]|0;do{if((Da|0)==0){xb=wb;yb=vb}else{W=Da-1|0;if((vb|0)>2){zb=vb-2|0;Ab=W|wb<<2}else{S=fe(W>>>((2-vb|0)>>>0)|wb<<vb|0)|0;Y=c[D>>2]|0;x=S;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;zb=vb+30|0;Ab=W}c[A>>2]=Ab;c[Z>>2]=zb;W=c[Q+(N*456160|0)+160+(Va*52192|0)+3136>>2]|0;if((zb|0)>6){Bb=zb-6|0;Cb=W|Ab<<6}else{Y=fe(W>>>((6-zb|0)>>>0)|Ab<<zb|0)|0;S=c[D>>2]|0;x=Y;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;Bb=zb+26|0;Cb=W}c[A>>2]=Cb;c[Z>>2]=Bb;if((c[P>>2]|0)>0){Db=0;Eb=Cb;Fb=Bb}else{xb=Cb;yb=Bb;break}while(1){W=c[Q+(N*456160|0)+160+(Va*52192|0)+3140+(Db<<2)>>2]|0;if((Fb|0)>5){Gb=Fb-5|0;Hb=W|Eb<<5}else{S=fe(W>>>((5-Fb|0)>>>0)|Eb<<Fb|0)|0;Y=c[D>>2]|0;x=S;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;Gb=Fb+27|0;Hb=W}c[A>>2]=Hb;c[Z>>2]=Gb;W=c[Q+(N*456160|0)+160+(Va*52192|0)+3156+(Db<<2)>>2]|0;if((Gb|0)>4){Ib=Gb-4|0;Jb=W|Hb<<4}else{Y=fe(W>>>((4-Gb|0)>>>0)|Hb<<Gb|0)|0;S=c[D>>2]|0;x=Y;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;Ib=Gb+28|0;Jb=W}c[A>>2]=Jb;c[Z>>2]=Ib;W=Db+1|0;if((W|0)<(c[P>>2]|0)){Db=W;Eb=Jb;Fb=Ib}else{xb=Jb;yb=Ib;break}}}}while(0);if((yb|0)>1){Kb=yb-1|0;Lb=xb<<1}else{P=fe(xb<<yb|0)|0;Da=c[D>>2]|0;x=P;a[Da]=x;x=x>>8;a[Da+1|0]=x;x=x>>8;a[Da+2|0]=x;x=x>>8;a[Da+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;Kb=yb+31|0;Lb=0}c[A>>2]=Lb;c[Z>>2]=Kb;if((Kb|0)>1){Mb=Kb-1|0;Nb=Lb<<1}else{Da=fe(Lb<<Kb|0)|0;P=c[D>>2]|0;x=Da;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;Mb=Kb+31|0;Nb=0}c[A>>2]=Nb;c[Z>>2]=Mb;P=c[sa>>2]|0;if((P|0)>0){Da=q|0;W=Q+(N*456160|0)+160+(Va*52192|0)+80|0;S=a[Da]|0;Y=0;ca=S;ta=P;P=S;while(1){if(ca<<24>>24==0){Ob=0;Pb=ta;Qb=P;Rb=Q+(N*456160|0)+160+(Va*52192|0)+20+Y|0}else{S=Y<<4;Aa=Q+(N*456160|0)+160+(Va*52192|0)+20+Y|0;Ba=0;Ca=0;U=P;while(1){X=Ca+S|0;do{if((a[Q+(N*456160|0)+160+(Va*52192|0)+5156+X|0]|0)==0){if((a[Aa]|0)==0){Sb=U;break}eb=Q+(N*456160|0)+160+(Va*52192|0)+4644+(X<<2)|0;ob=Q+(N*456160|0)+160+(Va*52192|0)+3172+(X<<2)|0;pb=Y;do{Me[c[(c[m>>2]|0)+8>>2]&3](p,da,Q+(N*456160|0)+160+(Va*52192|0)+5312+((pb<<7)+Ba<<2)|0,d[(c[W>>2]|0)+Ca|0]|0,c[eb>>2]|0,c[ob>>2]|0,+g[y>>2]);pb=pb+1|0;}while((pb|0)<((d[Aa]|0)+Y|0));Sb=a[Da]|0}else{Sb=U}}while(0);X=Ca+1|0;if((X|0)<(Sb&255|0)){Ba=(d[(c[W>>2]|0)+Ca|0]|0)+Ba|0;Ca=X;U=Sb}else{break}}Ob=Sb;Pb=c[sa>>2]|0;Qb=Sb;Rb=Aa}U=(d[Rb]|0)+Y|0;if((U|0)<(Pb|0)){Y=U;ca=Ob;ta=Pb;P=Qb}else{break}}}Va=Va+1|0;}while((Va|0)<(R|0));Q=c[w>>2]|0;if((T|0)>=(d[Q]|0)){break}O=R+O|0;N=T;v=Q;B=c[A>>2]|0;f=c[Z>>2]|0}ma=c[Z>>2]|0}Tb=c[D>>2]|0;Ub=(Tb-(c[F>>2]|0)<<3)+(32-ma)|0;Vb=c[u>>2]|0;if((Ub|0)<=((Vb*6144|0)-3|0)){break}g[y>>2]=+(c[ea>>2]|0)*1024.0/+(c[G>>2]|0)/+(Ub|0)*+g[y>>2]}if((nb|0)==139){yDb(0,0,2100848,(nb=i,i=i+24|0,c[nb>>2]=2045168,c[nb+8>>2]=1999464,c[nb+16>>2]=387,nb)|0);i=nb;Cd();return 0}c[o+276>>2]=(Ub|0)/(Vb|0)|0;Vb=c[A>>2]|0;if((ma|0)>3){Wb=ma-3|0;Xb=Vb<<3|7;Yb=Tb}else{Ub=Tb;x=fe(7>>>((3-ma|0)>>>0)|Vb<<ma|0)|0;a[Ub]=x;x=x>>8;a[Ub+1|0]=x;x=x>>8;a[Ub+2|0]=x;x=x>>8;a[Ub+3|0]=x;Ub=(c[D>>2]|0)+4|0;c[D>>2]=Ub;Wb=ma+29|0;Xb=7;Yb=Ub}c[A>>2]=Xb;c[Z>>2]=Wb;if((Wb|0)<32){Ub=Xb<<Wb;c[A>>2]=Ub;Wb=Ub>>>24&255;Ub=Yb;while(1){c[D>>2]=Ub+1;a[Ub]=Wb;Xb=c[A>>2]|0;c[A>>2]=Xb<<8;ma=(c[Z>>2]|0)+8|0;c[Z>>2]=ma;if((ma|0)>=32){break}Wb=Xb>>>16&255;Ub=c[D>>2]|0}Zb=c[D>>2]|0}else{Zb=Yb}c[Z>>2]=32;c[A>>2]=0;A=Zb-(c[F>>2]|0)<<3;c[b+664>>2]=A;if((c[fa>>2]&2|0)==0){Ia=+(c[ea>>2]|0)*1024.0/+(c[G>>2]|0)/+(A|0)*+g[y>>2];g[y>>2]=Ia>65536.0?65536.0:Ia}if(!t){c[r>>2]=(c[r>>2]|0)+1}Thb(o+304|0,c[b+424>>2]|0,e+8|0,e+48|0);c[K>>2]=32-(c[Z>>2]|0)+((c[D>>2]|0)-(c[F>>2]|0)<<3)>>3;c[h>>2]=1;s=0;i=j;return s|0}function ifb(a){a=a|0;var b=0;b=c[a+60>>2]|0;bLa(b+36|0);bLa(b+100|0);Zmb(b+240|0);a=c[b+284>>2]|0;if((a|0)!=0){anb(a)}$Db(b+4832|0);$Db(b+236|0);Rhb(b+304|0);return 0}function jfb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;f=b+12|0;g=c[f>>2]|0;h=b+16|0;i=c[h>>2]|0;if((i|0)>1){j=i-1|0;k=g<<1}else{l=fe(g<<i|0)|0;g=b+24|0;m=c[g>>2]|0;x=l;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;j=i+31|0;k=0}c[f>>2]=k;c[h>>2]=j;i=e+4|0;g=c[i>>2]|0;if((j|0)>2){n=j-2|0;o=k<<2|g}else{m=fe(k<<j|g>>>((2-j|0)>>>0)|0)|0;k=b+24|0;l=c[k>>2]|0;x=m;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[k>>2]=(c[k>>2]|0)+4;n=j+30|0;o=g}c[f>>2]=o;c[h>>2]=n;g=d[e+12|0]|0;if((n|0)>1){p=n-1|0;q=o<<1|g}else{j=fe(g>>>((1-n|0)>>>0)|o<<n|0)|0;o=b+24|0;k=c[o>>2]|0;x=j;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;p=n+31|0;q=g}c[f>>2]=q;c[h>>2]=p;g=d[e|0]|0;if((c[i>>2]|0)!=2){if((p|0)>6){r=p-6|0;s=q<<6|g}else{i=fe(g>>>((6-p|0)>>>0)|q<<p|0)|0;n=b+24|0;o=c[n>>2]|0;x=i;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;r=p+26|0;s=g}c[f>>2]=s;c[h>>2]=r;if((r|0)>1){t=r-1|0;u=s<<1}else{n=fe(s<<r|0)|0;s=b+24|0;o=c[s>>2]|0;x=n;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;t=r+31|0;u=0}c[f>>2]=u;c[h>>2]=t;return}if((p|0)>4){v=p-4|0;w=q<<4|g;y=b+24|0}else{t=fe(g>>>((4-p|0)>>>0)|q<<p|0)|0;q=b+24|0;b=c[q>>2]|0;x=t;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;v=p+28|0;w=g;y=q}c[f>>2]=w;c[h>>2]=v;q=1;g=w;w=v;while(1){v=(a[e+20+q|0]|0)==0|0;if((w|0)>1){z=w-1|0;A=g<<1|v}else{p=fe(v>>>((1-w|0)>>>0)|g<<w|0)|0;b=c[y>>2]|0;x=p;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;z=w+31|0;A=v}c[f>>2]=A;c[h>>2]=z;v=q+1|0;if((v|0)<8){q=v;g=A;w=z}else{break}}return}function kfb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=(a[d+13|0]|0)!=0?7996832:5462312;cf[c[b>>2]&1023](d+15552|0,e,(a[d+12|0]|0)!=0?7996832:5462312,1024);cf[c[b+24>>2]&1023](d+19648|0,e+4096|0,f,1024);return}function lfb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=(a[d+12|0]|0)!=0?7996320:5461800;cf[c[b>>2]&1023](d+15552|0,e,(a[d+13|0]|0)!=0?7996832:5462312,1024);UGb(d+19648|0,e+4096|0,1792)|0;cf[c[b+24>>2]&1023](d+21440|0,e+5888|0,f,128);TGb(d+21952|0,0,1792)|0;return}function mfb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=(a[d+12|0]|0)!=0?7996320:5461800;g=(a[d+13|0]|0)!=0?7996320:5461800;h=b|0;i=b+24|0;cf[c[h>>2]&1023](d+15552|0,e+1792|0,f,128);b=e+2304|0;cf[c[i>>2]&1023](d+16064|0,b,f,128);cf[c[h>>2]&1023](d+16576|0,b,g,128);b=e+2816|0;cf[c[i>>2]&1023](d+17088|0,b,f,128);cf[c[h>>2]&1023](d+17600|0,b,g,128);b=e+3328|0;cf[c[i>>2]&1023](d+18112|0,b,f,128);cf[c[h>>2]&1023](d+18624|0,b,g,128);b=e+3840|0;cf[c[i>>2]&1023](d+19136|0,b,f,128);cf[c[h>>2]&1023](d+19648|0,b,g,128);b=e+4352|0;cf[c[i>>2]&1023](d+20160|0,b,f,128);cf[c[h>>2]&1023](d+20672|0,b,g,128);b=e+4864|0;cf[c[i>>2]&1023](d+21184|0,b,f,128);cf[c[h>>2]&1023](d+21696|0,b,g,128);b=e+5376|0;cf[c[i>>2]&1023](d+22208|0,b,f,128);cf[c[h>>2]&1023](d+22720|0,b,g,128);cf[c[i>>2]&1023](d+23232|0,e+5888|0,f,128);return}function nfb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=(a[d+12|0]|0)!=0?7996832:5462312;g=(a[d+13|0]|0)!=0?7996320:5461800;TGb(d+15552|0,0,1792)|0;cf[c[b>>2]&1023](d+17344|0,e+1792|0,g,128);UGb(d+17856|0,e+2304|0,1792)|0;cf[c[b+24>>2]&1023](d+19648|0,e+4096|0,f,1024);return}function ofb(){var a=0;c[646427]=7988504;c[646429]=1098;N_(2585704,9,121,399600,1,1,399112,4,4,0,0,0,4)|0;c[646432]=7984136;c[646434]=1092;N_(2585724,9,121,1319640,1,1,1319152,4,4,0,0,0,4)|0;c[646437]=7981064;c[646439]=768;N_(2585744,9,49,398736,1,1,398536,4,4,0,0,0,4)|0;c[646442]=7976960;c[646444]=1026;N_(2585764,9,49,1318776,1,1,1318576,4,4,0,0,0,4)|0;c[646447]=7972728;c[646449]=1058;N_(2585784,9,63,399048,1,1,398792,4,4,0,0,0,4)|0;c[646452]=7968520;c[646454]=1052;N_(2585804,9,63,1319088,1,1,1318832,4,4,0,0,0,4)|0;c[646457]=7966344;c[646459]=544;N_(2585824,9,25,398504,1,1,398448,2,2,0,0,0,4)|0;c[646462]=7964168;c[646464]=544;N_(2585844,9,25,1318544,1,1,1318488,2,2,0,0,0,4)|0;c[646467]=7961800;c[646469]=592;N_(2585864,9,63,398384,1,1,398256,2,2,0,0,0,4)|0;c[646472]=7959752;c[646474]=512;N_(2585884,9,25,398224,1,1,398192,1,1,0,0,0,4)|0;a=1;do{g[48e4+(a+320<<2)>>2]=+g[48e4+(320-a<<2)>>2];a=a+1|0;}while((a|0)<320);g[120384]=-0.0- +g[120384];g[120512]=-0.0- +g[120512];a=0;do{g[4313232+(a<<2)>>2]=+g[48e4+(a<<1<<2)>>2];a=a+1|0;}while((a|0)<320);xpb();return}function pfb(a,b){a=a|0;b=b|0;if((c[b+343668>>2]|0)!=0){return}a=b+68|0;c[b+64>>2]=c[a>>2];c[b+4>>2]=0;c[a>>2]=32;c[b+76>>2]=0;c[b+102312>>2]=-1;c[b+14664>>2]=-1;TGb(b+12|0,-1|0,6)|0;c[b+14656>>2]=1152;c[b+102304>>2]=1152;aLa(b+343648|0,7,1,4.76837158203125e-7)|0;aLa(b+343584|0,7,1,-65536.0)|0;ypb(b+175392|0);qob(b+343712|0);c[b+343768>>2]=112;c[b+343772>>2]=200;c[b+343776>>2]=26;c[b+343780>>2]=4;return}function qfb(a){a=a|0;bLa(a+343648|0);bLa(a+343584|0);return}function rfb(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0.0,W=0.0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0.0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0;m=i;i=i+272|0;n=m|0;o=m+32|0;p=m+136|0;q=m+248|0;r=q;s=h;c[r>>2]=c[s>>2];c[r+4>>2]=c[s+4>>2];c[r+8>>2]=c[s+8>>2];c[r+12>>2]=c[s+12>>2];c[r+16>>2]=c[s+16>>2];s=(k<<3)-4|0;r=h+8|0;t=c[r>>2]|0;u=-t|0;v=(c[h+16>>2]|0)-t|0;if((s|0)<(u|0)){w=u}else{w=(v|0)<(s|0)?v:s}c[r>>2]=w+t;t=g+8|0;c[t>>2]=0;w=g|0;if((c[w>>2]|0)==0){c[w>>2]=c[f+6512>>2]<<1}r=f+6532|0;if((c[r>>2]|0)==0){c[r>>2]=c[f+6512>>2]<<1}r=q+8|0;s=c[r>>2]|0;v=c[q+16>>2]|0;if((j|0)==0){y=1;z=s}else{j=s+10|0;s=v>>>0>j>>>0?j:v;c[r>>2]=s;y=11;z=s}s=g+68|0;c[g+64>>2]=c[s>>2];r=g+76|0;c[g+72>>2]=c[r>>2];c[g+80>>2]=1;j=q+8|0;u=q|0;h=c[u>>2]|0;A=d[h+(z>>>3)|0]|0;B=q+16|0;C=((z|0)<(v|0))+z|0;c[j>>2]=C;if((A&128>>>((z&7)>>>0)|0)==0){D=y}else{z=m+240|0;A=g+24|0;E=c[A>>2]|0;c[g+4>>2]=1;F=g+12|0;a[z]=a[F]|0;a[z+1|0]=a[F+1|0]|0;a[z+2|0]=a[F+2|0]|0;a[z+3|0]=a[F+3|0]|0;a[z+4|0]=a[F+4|0]|0;a[z+5|0]=a[F+5|0]|0;G=d[h+(C>>>3)|0]<<(C&7)>>>7;H=((C|0)<(v|0))+C|0;c[j>>2]=H;c[g+20>>2]=G&1;G=h+(H>>>3)|0;I=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>28;G=H+4|0;H=v>>>0>G>>>0?G:v;c[j>>2]=H;a[F]=I;I=h+(H>>>3)|0;G=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(H&7)>>>28;I=H+4|0;H=v>>>0>I>>>0?I:v;c[j>>2]=H;a[g+13|0]=G;G=h+(H>>>3)|0;I=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>29;G=H+3|0;a[g+14|0]=I;I=(v>>>0>G>>>0?G:v)+2|0;G=v>>>0>I>>>0?I:v;c[j>>2]=G;I=d[h+(G>>>3)|0]|0;H=((G|0)<(v|0))+G|0;c[j>>2]=H;J=d[h+(H>>>3)|0]|0;K=((H|0)<(v|0))+H|0;c[j>>2]=K;if((128>>>((G&7)>>>0)&I|0)==0){a[g+15|0]=2;a[g+16|0]=1;a[g+17|0]=2;L=K}else{I=h+(K>>>3)|0;G=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(K&7)>>>30;I=K+2|0;K=v>>>0>I>>>0?I:v;c[j>>2]=K;a[g+15|0]=G;G=d[h+(K>>>3)|0]<<(K&7)>>>7;I=((K|0)<(v|0))+K|0;c[j>>2]=I;a[g+16|0]=G&1;G=h+(I>>>3)|0;K=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(I&7)>>>30;G=I+2|0;I=v>>>0>G>>>0?G:v;c[j>>2]=I;a[g+17|0]=K;L=I}if((PGb(z,F,6)|0)!=0){c[t>>2]=1}if((128>>>((H&7)>>>0)&J|0)==0){c[A>>2]=2;c[g+28>>2]=2;c[g+32>>2]=1;c[g+36>>2]=1;M=2;N=L}else{J=h+(L>>>3)|0;H=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7)>>>30;J=L+2|0;L=v>>>0>J>>>0?J:v;c[j>>2]=L;c[A>>2]=H;A=h+(L>>>3)|0;J=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(L&7)>>>30;A=L+2|0;L=v>>>0>A>>>0?A:v;c[j>>2]=L;c[g+28>>2]=J;J=d[h+(L>>>3)|0]<<(L&7)>>>7;A=((L|0)<(v|0))+L|0;c[j>>2]=A;c[g+32>>2]=J&1;J=d[h+(A>>>3)|0]<<(A&7)>>>7;h=((A|0)<(v|0))+A|0;c[j>>2]=h;c[g+36>>2]=J&1;M=H;N=h}do{if((M|0)==(E|0)){O=N}else{if((c[t>>2]|0)!=0){O=N;break}Bfb(g);O=c[j>>2]|0}}while(0);D=y-C+O|0}a:do{if((c[t>>2]|0)!=0){O=n;C=o;y=c[w>>2]|0;if((y|0)<32e3){P=3e3}else{P=(y|0)<64e3?4e3:5e3}if((y|0)==88200|(y|0)==96e3|(y|0)==128e3|(y|0)==176400|(y|0)==192e3){Q=482640;R=32}else if((y|0)==32e3){Q=482608;R=32}else if((y|0)==22050){Q=482576;R=32}else if((y|0)==44100|(y|0)==48e3|(y|0)==64e3){Q=482624;R=32}else if((y|0)==24e3){Q=482592;R=32}else if((y|0)==16e3){Q=482560;R=32}else{yDb(c[f+4>>2]|0,16,2143304,(T=i,i=i+8|0,c[T>>2]=y,T)|0);i=T;U=g+12|0}b:do{if((R|0)==32){N=y>>1;E=(((P<<8)+N|0)>>>0)/(y>>>0)|0;M=g+12|0;h=(a[Q+(d[M]|0)|0]|0)+((((P<<7)+N|0)>>>0)/(y>>>0)|0)|0;N=g+44|0;c[N>>2]=h;H=g+13|0;J=a[H]|0;A=J&255;do{if((J&255)>>>0<14>>>0){v=g+52|0;c[v>>2]=E;V=+(E|0);W=+S(+(64.0/V),+.07692307978868484);X=V*W;L=Gc(+X)|0;b[n>>1]=L-E;V=W*X;F=Gc(+V)|0;b[n+2>>1]=F-L;X=W*V;L=Gc(+X)|0;b[n+4>>1]=L-F;V=W*X;F=Gc(+V)|0;b[n+6>>1]=F-L;X=W*V;L=Gc(+X)|0;b[n+8>>1]=L-F;V=W*X;F=Gc(+V)|0;b[n+10>>1]=F-L;X=W*V;L=Gc(+X)|0;b[n+12>>1]=L-F;V=W*X;F=Gc(+V)|0;b[n+14>>1]=F-L;X=W*V;L=Gc(+X)|0;b[n+16>>1]=L-F;V=W*X;F=Gc(+V)|0;b[n+18>>1]=F-L;X=W*V;L=Gc(+X)|0;b[n+20>>1]=L-F;F=Gc(+(W*X))|0;b[n+22>>1]=F-L;b[n+24>>1]=64-F;Yc(O|0,13,2,98);F=a[H]|0;L=c[v>>2]|0;if(F<<24>>24==0){Y=L}else{z=F&255;F=0;I=L;do{I=(b[n+(F<<1)>>1]|0)+I|0;F=F+1|0;}while((F|0)<(z|0));c[v>>2]=I;Y=I}Z=Y;_=c[w>>2]|0}else{if((J<<24>>24|0)==15){z=h*3|0;c[g+52>>2]=z;Z=z;_=y;break}else if((J<<24>>24|0)==14){z=h<<1;c[g+52>>2]=z;Z=z;_=y;break}else{yDb(c[f+4>>2]|0,16,2137864,(T=i,i=i+8|0,c[T>>2]=A,T)|0);i=T;U=M;break b}}}while(0);A=g+52|0;h=Z>>>0<64>>>0?Z:64;c[A>>2]=h;do{if((_|0)<32001){$=48}else{if((_|0)==44100){$=35;break}if((_|0)>47999){$=32;break}yDb(0,0,2131232,(T=i,i=i+24|0,c[T>>2]=2124808,c[T+8>>2]=2119248,c[T+16>>2]=403,T)|0);i=T;Cd();return 0}}while(0);J=c[N>>2]|0;H=h-J|0;if(H>>>0>$>>>0){yDb(c[f+4>>2]|0,16,2113104,(T=i,i=i+8|0,c[T>>2]=H,T)|0);i=T;U=M;break}E=a[g+15|0]|0;do{if(E<<24>>24==0){z=(d[g+16|0]|0)+1|0;F=((z&2)+H|0)>>>(z>>>0)<<1;L=g+84|0;c[L>>2]=F;K=c[f+4>>2]|0;G=d[g+14|0]|0;if((F|0)<1){yDb(K,16,2082744,(T=i,i=i+8|0,c[T>>2]=F,T)|0);i=T;U=M;break b}if((G|0)>=(F|0)){yDb(K,16,2076984,(T=i,i=i+8|0,c[T>>2]=G,T)|0);i=T;U=M;break b}if((F|0)==0){aa=h;ca=J;da=0}else{F=z&65535;G=1;do{b[g+262896+(G<<1)>>1]=F;G=G+1|0;ea=c[L>>2]|0;}while(!(G>>>0>ea>>>0));aa=c[A>>2]|0;ca=c[N>>2]|0;da=ea}G=aa-ca|0;F=ba(da,z)|0;I=G-F|0;do{if((I|0)<0){v=g+262898|0;b[v>>1]=(b[v>>1]|0)-1;v=g+262900|0;b[v>>1]=(b[v>>1]|0)-((I|0)<-1);fa=ca&65535;ga=da}else{if((G|0)==(F|0)){fa=ca&65535;ga=da;break}v=g+262896+(da<<1)|0;b[v>>1]=(b[v>>1]|0)+1;fa=c[N>>2]&65535;ga=c[L>>2]|0}}while(0);b[g+262896>>1]=fa;if((ga|0)==0){ha=0;break}else{ia=1;ja=fa}while(1){F=g+262896+(ia<<1)|0;G=(b[F>>1]|0)+ja&65535;b[F>>1]=G;F=ia+1|0;I=c[L>>2]|0;if(F>>>0>I>>>0){ha=I;break}else{ia=F;ja=G}}}else{if((h*49|0)>>>0>(J*110|0)>>>0){L=J<<1;c[g+48>>2]=L;ka=1;la=L}else{c[g+48>>2]=h;ka=0;la=h}X=+(7-(E&255)|0);L=g+48|0;G=Gc(+(X*+gc(+(+(la>>>0>>>0)/+(J>>>0>>>0)))))|0;F=G<<1;if((F|0)<1){yDb(c[f+4>>2]|0,16,2098864,(T=i,i=i+8|0,c[T>>2]=F,T)|0);i=T;U=M;break b}I=o|0;b[I>>1]=0;z=o+2|0;v=c[N>>2]|0;K=c[L>>2]|0;W=+(v|0);V=+S(+(+(K|0)/W),+(1.0/+(F|0)));ma=F-1|0;if((ma|0)>0){na=v;oa=0;pa=W;while(1){W=V*pa;qa=Gc(+W)|0;ra=oa+1|0;b[o+(ra<<1)>>1]=qa-na;if((ra|0)<(ma|0)){na=qa;oa=ra;pa=W}else{sa=qa;break}}}else{sa=v}oa=o+(F<<1)|0;b[oa>>1]=K-sa;Yc(z|0,F|0,2,98);na=b[oa>>1]|0;oa=c[N>>2]&65535;b[I>>1]=oa;ma=1;qa=oa;while(1){oa=o+(ma<<1)|0;ta=b[oa>>1]|0;if(ta<<16>>16<1){R=72;break}ra=ta+qa&65535;b[oa>>1]=ra;oa=ma+1|0;if((oa|0)>(F|0)){break}else{ma=oa;qa=ra}}if((R|0)==72){yDb(c[f+4>>2]|0,16,2092616,(T=i,i=i+16|0,c[T>>2]=ma,c[T+8>>2]=ta<<16>>16,T)|0);i=T;U=M;break b}if((ka|0)==0){c[g+84>>2]=F;qa=d[g+14|0]|0;if((qa|0)<(F|0)){UGb(g+262896|0,C|0,G<<2|2)|0;ha=F;break}else{yDb(c[f+4>>2]|0,16,2076984,(T=i,i=i+8|0,c[T>>2]=qa,T)|0);i=T;U=M;break b}}pa=X*((a[g+16|0]|0)!=0?.7692307829856873:1.0);qa=Gc(+(pa*+gc(+(+((c[A>>2]|0)>>>0>>>0)/+((c[L>>2]|0)>>>0>>>0)))))|0;I=qa<<1;z=p|0;K=p+2|0;v=c[L>>2]|0;ra=c[A>>2]|0;pa=+(v|0);V=+S(+(+(ra|0)/pa),+(1.0/+(I|0)));oa=I-1|0;if((oa|0)>0){ua=v;va=0;W=pa;while(1){pa=V*W;wa=Gc(+pa)|0;xa=va+1|0;b[p+(xa<<1)>>1]=wa-ua;if((xa|0)<(oa|0)){ua=wa;va=xa;W=pa}else{ya=wa;break}}}else{ya=v}va=p+(I<<1)|0;b[va>>1]=ra-ya;ua=b[K>>1]|0;if((I|0)>1){oa=1;G=ua;while(1){ma=oa+1|0;wa=b[p+(ma<<1)>>1]|0;xa=(wa|0)>(G|0)?G:wa;if((ma|0)<(I|0)){oa=ma;G=xa}else{za=xa;break}}}else{za=ua}G=K;if((za|0)<(na|0)){Yc(G|0,I|0,2,98);oa=b[K>>1]|0;ra=oa<<16>>16;v=na-ra|0;xa=b[va>>1]|0;ma=(xa<<16>>16)-ra>>1;ra=(v|0)>(ma|0)?ma:v;b[K>>1]=ra+(oa&65535);b[va>>1]=(xa&65535)-ra}Yc(G|0,I|0,2,98);ra=c[L>>2]&65535;b[z>>1]=ra;c:do{if((I|0)>=1){xa=1;oa=ra;while(1){v=p+(xa<<1)|0;Aa=b[v>>1]|0;if(Aa<<16>>16<1){break}ma=Aa+oa&65535;b[v>>1]=ma;v=xa+1|0;if((v|0)>(I|0)){break c}else{xa=v;oa=ma}}yDb(c[f+4>>2]|0,16,2087392,(T=i,i=i+16|0,c[T>>2]=xa,c[T+8>>2]=Aa<<16>>16,T)|0);i=T;U=M;break b}}while(0);ra=I+F|0;z=g+84|0;c[z>>2]=ra;L=c[f+4>>2]|0;va=d[g+14|0]|0;if((ra|0)<1){yDb(L,16,2082744,(T=i,i=i+8|0,c[T>>2]=ra,T)|0);i=T;U=M;break b}if((va|0)<(ra|0)){ra=F|1;UGb(g+262896|0,C|0,ra<<1)|0;UGb(g+262896+(ra<<1)|0,G|0,qa<<2)|0;ha=c[z>>2]|0;break}else{yDb(L,16,2076984,(T=i,i=i+8|0,c[T>>2]=va,T)|0);i=T;U=M;break b}}}while(0);J=g+84|0;E=d[g+14|0]|0;h=ha-E|0;c[g+262884>>2]=h;H=(h+1|0)>>>1;va=g+262880|0;c[va>>2]=H;L=g+263044|0;UGb(L|0,g+262896+(E<<1)|0,(h<<1)+2|0)|0;E=b[g+263044+(h<<1)>>1]|0;z=E&65535;ra=b[L>>1]|0;L=ra&65535;c[r>>2]=z-L;c[s>>2]=L;if((E&65535)>>>0>64>>>0){yDb(c[f+4>>2]|0,16,2173800,(T=i,i=i+8|0,c[T>>2]=z,T)|0);i=T;U=M;break}if((ra&65535)>>>0>32>>>0){yDb(c[f+4>>2]|0,16,2163936,(T=i,i=i+8|0,c[T>>2]=L,T)|0);i=T;U=M;break}z=g+262994|0;b[z>>1]=ra;ra=h&1;if((H|0)==0){Ba=L}else{L=1;do{b[g+262994+(L<<1)>>1]=b[g+263044+((L<<1)-ra<<1)>>1]|0;L=L+1|0;}while(!(L>>>0>(c[va>>2]|0)>>>0));Ba=c[s>>2]|0}L=g+17|0;W=+(d[L]|0);do{if((Gc(+(W*+gc(+(+((c[A>>2]|0)>>>0>>>0)/+(Ba>>>0>>>0)))))|0)<1){ra=g+262888|0;c[ra>>2]=1;Ca=ra}else{V=+(d[L]|0);ra=Gc(+(V*+gc(+(+((c[A>>2]|0)>>>0>>>0)/+((c[s>>2]|0)>>>0>>>0)))))|0;H=g+262888|0;c[H>>2]=ra;if(!(ra>>>0>5>>>0)){Ca=H;break}yDb(c[f+4>>2]|0,16,2156960,(T=i,i=i+8|0,c[T>>2]=ra,T)|0);i=T;U=M;break b}}while(0);b[g+263142>>1]=b[z>>1]|0;A=c[Ca>>2]|0;if((A|0)!=0){L=1;ra=0;H=A;do{ra=((((c[va>>2]|0)-ra|0)>>>0)/((H+1-L|0)>>>0)|0)+ra|0;b[g+263142+(L<<1)>>1]=b[g+262994+(ra<<1)>>1]|0;L=L+1|0;H=c[Ca>>2]|0;}while(!(L>>>0>H>>>0))}H=c[N>>2]|0;L=c[s>>2]|0;ra=c[w>>2]|0;va=((ra>>1)+2048e3|0)/(ra|0)|0;ra=g+263216|0;c[ra>>2]=0;if(va>>>0<((c[r>>2]|0)+L|0)>>>0){z=0;while(1){if((e[g+262896+(z<<1)>>1]|0)<(va|0)){z=z+1|0}else{Da=L;Ea=H;Fa=0;Ga=z;Ha=0;Ia=H;break}}}else{Da=L;Ea=H;Fa=0;Ga=c[J>>2]|0;Ha=0;Ia=H}while(1){z=Ia-1+Ea|0;va=0;A=Fa;h=Ga;while(1){if((h|0)!=(Ga|0)){if(!(A>>>0>(z-va|0)>>>0)){break}}E=e[g+262896+(h<<1)>>1]|0;va=E+Ia&1;A=E;h=h-1|0}if(Ha>>>0>5>>>0){R=124;break}h=A-Da|0;a[g+263220+Ha|0]=(h|0)>0?h&255:0;h=c[ra>>2]|0;a[g+263226+h|0]=(c[N>>2]|0)-va-(d[g+263220+h|0]|0);h=c[ra>>2]|0;if((a[g+263220+h|0]|0)==0){Ja=Da;Ka=c[s>>2]|0;La=h}else{z=h+1|0;c[ra>>2]=z;Ja=A;Ka=A;La=z}if(((e[g+262896+(Ga<<1)>>1]|0)-A|0)<3){Ma=c[J>>2]|0}else{Ma=Ga}if((A|0)==((c[r>>2]|0)+(c[s>>2]|0)|0)){break}Da=Ja;Ea=Ka;Fa=A;Ga=Ma;Ha=La;Ia=c[N>>2]|0}if((R|0)==124){yDb(c[f+4>>2]|0,16,2150264,(T=i,i=i+8|0,c[T>>2]=Ha,T)|0);i=T;U=M;break}do{if(La>>>0>1>>>0){N=La-1|0;if(!((d[g+263220+N|0]|0)>>>0<3>>>0)){break}c[ra>>2]=N}}while(0);Bfb(g);c[g+87736>>2]=0;c[g+175384>>2]=0;break a}}while(0);yDb(c[f+4>>2]|0,16,2190536,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;c[g+4>>2]=0;c[s>>2]=32;c[r>>2]=0;c[g+102312>>2]=-1;c[g+14664>>2]=-1;TGb(U|0,-1|0,6)|0}}while(0);U=g+4|0;if((c[U>>2]|0)==0){Na=D}else{La=c[j>>2]|0;do{if((l|0)==1){Ha=c[u>>2]|0;Ia=c[B>>2]|0;Ma=((La|0)<(Ia|0))+La|0;if((d[Ha+(La>>>3)|0]&128>>>((La&7)>>>0)|0)==0){Oa=Ma}else{Ga=Ma+8|0;Oa=Ia>>>0>Ga>>>0?Ga:Ia}c[j>>2]=Oa;Ga=d[Ha+(Oa>>>3)|0]<<(Oa&7)>>>7;c[j>>2]=((Oa|0)<(Ia|0))+Oa;Ia=Ga&1;c[g+40>>2]=Ia;Ga=g+96|0;Ha=(yfb(f,g,q,Ga)|0)!=0;do{if((Ia|0)==0){if(Ha){R=193;break}Ma=g+87744|0;if((yfb(f,g,q,Ma)|0)!=0){R=193;break}Fa=c[g+104>>2]|0;if((Fa|0)>0){Ka=c[u>>2]|0;Ea=c[B>>2]|0;Ja=0;Da=c[j>>2]|0;do{w=d[Ka+(Da>>>3)|0]<<(Da&7)>>>7;Da=((Da|0)<(Ea|0))+Da|0;c[j>>2]=Da;a[g+120+Ja|0]=w&1;Ja=Ja+1|0;}while((Ja|0)<(Fa|0))}Fa=c[g+116>>2]|0;if((Fa|0)>0){Ja=c[u>>2]|0;Da=c[B>>2]|0;Ea=0;Ka=c[j>>2]|0;do{w=d[Ja+(Ka>>>3)|0]<<(Ka&7)>>>7;Ka=((Ka|0)<(Da|0))+Ka|0;c[j>>2]=Ka;a[g+125+Ea|0]=w&1;Ea=Ea+1|0;}while((Ea|0)<(Fa|0))}Fa=c[g+87752>>2]|0;if((Fa|0)>0){Ea=c[u>>2]|0;Ka=c[B>>2]|0;Da=0;Ja=c[j>>2]|0;do{w=d[Ea+(Ja>>>3)|0]<<(Ja&7)>>>7;Ja=((Ja|0)<(Ka|0))+Ja|0;c[j>>2]=Ja;a[g+87768+Da|0]=w&1;Da=Da+1|0;}while((Da|0)<(Fa|0))}Fa=c[g+87764>>2]|0;if((Fa|0)>0){Da=c[u>>2]|0;Ja=c[B>>2]|0;Ka=0;Ea=c[j>>2]|0;do{w=d[Da+(Ea>>>3)|0]<<(Ea&7)>>>7;Ea=((Ea|0)<(Ja|0))+Ea|0;c[j>>2]=Ea;a[g+87773+Ka|0]=w&1;Ka=Ka+1|0;}while((Ka|0)<(Fa|0))}Fa=g+132|0;Ka=g+127|0;a[Fa]=a[Ka]|0;a[Fa+1|0]=a[Ka+1|0]|0;a[Fa+2|0]=a[Ka+2|0]|0;a[Fa+3|0]=a[Ka+3|0]|0;a[Fa+4|0]=a[Ka+4|0]|0;Ka=g+262888|0;do{if((c[Ka>>2]|0)==0){Fa=g+87780|0;Ea=g+87775|0;a[Fa]=a[Ea]|0;a[Fa+1|0]=a[Ea+1|0]|0;a[Fa+2|0]=a[Ea+2|0]|0;a[Fa+3|0]=a[Ea+3|0]|0;a[Fa+4|0]=a[Ea+4|0]|0}else{Ea=c[B>>2]|0;Fa=c[u>>2]|0;Ja=0;Da=c[j>>2]|0;do{w=Fa+(Da>>>3)|0;Ca=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(Da&7)>>>30;w=Da+2|0;Da=Ea>>>0>w>>>0?w:Ea;c[j>>2]=Da;a[g+127+Ja|0]=Ca;Ja=Ja+1|0;Pa=c[Ka>>2]|0;}while(Ja>>>0<Pa>>>0);Ja=g+87780|0;A=g+87775|0;a[Ja]=a[A]|0;a[Ja+1|0]=a[A+1|0]|0;a[Ja+2|0]=a[A+2|0]|0;a[Ja+3|0]=a[A+3|0]|0;a[Ja+4|0]=a[A+4|0]|0;if((Pa|0)==0){break}else{Qa=0;Ra=Da}do{A=Fa+(Ra>>>3)|0;Ja=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(Ra&7)>>>30;A=Ra+2|0;Ra=Ea>>>0>A>>>0?A:Ea;c[j>>2]=Ra;a[g+87775+Qa|0]=Ja;Qa=Qa+1|0;}while(Qa>>>0<(c[Ka>>2]|0)>>>0)}}while(0);zfb(g,q,Ga,0);zfb(g,q,Ma,1);Afb(g,q,Ga,0);Afb(g,q,Ma,1)}else{if(Ha){R=193;break}Ka=g+87744|0;Ea=g+87752|0;Fa=c[Ea>>2]|0;a[g+87756|0]=a[g+87756+Fa|0]|0;a[g+175380|0]=a[g+175372+Fa|0]|0;Da=g+102312|0;c[g+102308>>2]=-((c[Da>>2]|0)!=(Fa|0)|0);Fa=g+87757|0;Ja=g+109|0;a[Fa]=a[Ja]|0;a[Fa+1|0]=a[Ja+1|0]|0;a[Fa+2|0]=a[Ja+2|0]|0;a[Fa+3|0]=a[Ja+3|0]|0;a[Fa+4|0]=a[Ja+4|0]|0;a[Fa+5|0]=a[Ja+5|0]|0;Ja=g+87724|0;Fa=g+175372|0;A=Ja|0;va=Ja+4|0;Ja=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;va=Fa|0;x=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;va=Fa+4|0;x=Ja;a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;va=g+175381|0;Ja=g+87733|0;a[va]=a[Ja]|0;a[va+1|0]=a[Ja+1|0]|0;a[va+2|0]=a[Ja+2|0]|0;Ja=c[g+104>>2]|0;c[Ea>>2]=Ja;c[g+87836>>2]=c[g+188>>2];va=g+116|0;Fa=c[va>>2]|0;A=g+87764|0;c[A>>2]=Fa;c[Ka>>2]=c[Ga>>2];c[Da>>2]=c[g+14664>>2];if((Ja|0)>0){Da=c[u>>2]|0;Ca=c[B>>2]|0;w=0;Ba=c[j>>2]|0;do{ha=d[Da+(Ba>>>3)|0]<<(Ba&7)>>>7;Ba=((Ba|0)<(Ca|0))+Ba|0;c[j>>2]=Ba;a[g+120+w|0]=ha&1;w=w+1|0;}while((w|0)<(Ja|0));Sa=c[va>>2]|0}else{Sa=Fa}if((Sa|0)>0){Ja=c[u>>2]|0;w=c[B>>2]|0;Ba=0;Ca=c[j>>2]|0;do{Da=d[Ja+(Ca>>>3)|0]<<(Ca&7)>>>7;Ca=((Ca|0)<(w|0))+Ca|0;c[j>>2]=Ca;a[g+125+Ba|0]=Da&1;Ba=Ba+1|0;}while((Ba|0)<(Sa|0))}Ba=c[Ea>>2]|0;if((Ba|0)>0){Ca=c[u>>2]|0;w=c[B>>2]|0;Ja=0;Fa=c[j>>2]|0;do{va=d[Ca+(Fa>>>3)|0]<<(Fa&7)>>>7;Fa=((Fa|0)<(w|0))+Fa|0;c[j>>2]=Fa;a[g+87768+Ja|0]=va&1;Ja=Ja+1|0;}while((Ja|0)<(Ba|0))}Ba=c[A>>2]|0;if((Ba|0)>0){Ja=c[u>>2]|0;Fa=c[B>>2]|0;w=0;Ca=c[j>>2]|0;do{Ea=d[Ja+(Ca>>>3)|0]<<(Ca&7)>>>7;Ca=((Ca|0)<(Fa|0))+Ca|0;c[j>>2]=Ca;a[g+87773+w|0]=Ea&1;w=w+1|0;}while((w|0)<(Ba|0))}Ba=g+132|0;w=g+127|0;a[Ba]=a[w]|0;a[Ba+1|0]=a[w+1|0]|0;a[Ba+2|0]=a[w+2|0]|0;a[Ba+3|0]=a[w+3|0]|0;a[Ba+4|0]=a[w+4|0]|0;Ba=g+262888|0;if((c[Ba>>2]|0)!=0){Ca=c[B>>2]|0;Fa=c[u>>2]|0;Ja=0;A=c[j>>2]|0;do{Ea=Fa+(A>>>3)|0;va=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(A&7)>>>30;Ea=A+2|0;A=Ca>>>0>Ea>>>0?Ea:Ca;c[j>>2]=A;a[g+127+Ja|0]=va;Ja=Ja+1|0;}while(Ja>>>0<(c[Ba>>2]|0)>>>0)}Ba=g+87780|0;Ja=g+87775|0;a[Ba]=a[Ja]|0;a[Ba+1|0]=a[Ja+1|0]|0;a[Ba+2|0]=a[Ja+2|0]|0;a[Ba+3|0]=a[Ja+3|0]|0;a[Ba+4|0]=a[Ja+4|0]|0;a[Ja]=a[w]|0;a[Ja+1|0]=a[w+1|0]|0;a[Ja+2|0]=a[w+2|0]|0;a[Ja+3|0]=a[w+3|0]|0;a[Ja+4|0]=a[w+4|0]|0;zfb(g,q,Ga,0);Afb(g,q,Ga,0);zfb(g,q,Ka,1);Afb(g,q,Ka,1)}}while(0);if((R|0)==193){c[U>>2]=0;c[s>>2]=32;c[r>>2]=0;c[g+102312>>2]=-1;c[g+14664>>2]=-1;TGb(g+12|0,-1|0,6)|0;break}Ga=c[j>>2]|0;Ha=c[u>>2]|0;Ia=d[Ha+(Ga>>>3)|0]<<(Ga&7)>>>7;Ja=c[B>>2]|0;Ba=((Ga|0)<(Ja|0))+Ga|0;c[j>>2]=Ba;Ga=Ia&1;c[g+100>>2]=Ga;do{if((Ga|0)==0){Ta=Ba}else{Ia=c[g+262884>>2]|0;if((Ia|0)>0){Ua=0;Va=Ba}else{Ta=Ba;break}while(1){A=d[Ha+(Va>>>3)|0]<<(Va&7)>>>7;Ca=((Va|0)<(Ja|0))+Va|0;c[j>>2]=Ca;a[g+137+Ua|0]=A&1;A=Ua+1|0;if((A|0)<(Ia|0)){Ua=A;Va=Ca}else{Ta=Ca;break}}}}while(0);Ba=d[Ha+(Ta>>>3)|0]<<(Ta&7)>>>7;Ga=((Ta|0)<(Ja|0))+Ta|0;c[j>>2]=Ga;Ia=Ba&1;c[g+87748>>2]=Ia;if((Ia|0)==0){Wa=Ga;Xa=Ha;Ya=Ja;R=195;break}Ia=c[g+262884>>2]|0;if((Ia|0)>0){Za=0;_a=Ga}else{Wa=Ga;Xa=Ha;Ya=Ja;R=195;break}while(1){Ga=d[Ha+(_a>>>3)|0]<<(_a&7)>>>7;Ba=((_a|0)<(Ja|0))+_a|0;c[j>>2]=Ba;a[g+87785+Za|0]=Ga&1;Ga=Za+1|0;if((Ga|0)<(Ia|0)){Za=Ga;_a=Ba}else{Wa=Ba;Xa=Ha;Ya=Ja;R=195;break}}}else if((l|0)==2|(l|0)==0){Ja=c[B>>2]|0;Ha=((La|0)<(Ja|0))+La|0;if((d[(c[u>>2]|0)+(La>>>3)|0]&128>>>((La&7)>>>0)|0)==0){$a=Ha}else{Ia=Ha+4|0;$a=Ja>>>0>Ia>>>0?Ia:Ja}c[j>>2]=$a;Ja=g+96|0;if((yfb(f,g,q,Ja)|0)!=0){c[U>>2]=0;c[s>>2]=32;c[r>>2]=0;c[g+102312>>2]=-1;c[g+14664>>2]=-1;TGb(g+12|0,-1|0,6)|0;break}Ia=c[g+104>>2]|0;if((Ia|0)>0){Ha=c[u>>2]|0;Ba=c[B>>2]|0;Ga=0;Ka=c[j>>2]|0;do{w=d[Ha+(Ka>>>3)|0]<<(Ka&7)>>>7;Ka=((Ka|0)<(Ba|0))+Ka|0;c[j>>2]=Ka;a[g+120+Ga|0]=w&1;Ga=Ga+1|0;}while((Ga|0)<(Ia|0))}Ia=c[g+116>>2]|0;if((Ia|0)>0){Ga=c[u>>2]|0;Ka=c[B>>2]|0;Ba=0;Ha=c[j>>2]|0;do{w=d[Ga+(Ha>>>3)|0]<<(Ha&7)>>>7;Ha=((Ha|0)<(Ka|0))+Ha|0;c[j>>2]=Ha;a[g+125+Ba|0]=w&1;Ba=Ba+1|0;}while((Ba|0)<(Ia|0))}Ia=g+132|0;Ba=g+127|0;a[Ia]=a[Ba]|0;a[Ia+1|0]=a[Ba+1|0]|0;a[Ia+2|0]=a[Ba+2|0]|0;a[Ia+3|0]=a[Ba+3|0]|0;a[Ia+4|0]=a[Ba+4|0]|0;Ba=g+262888|0;if((c[Ba>>2]|0)!=0){Ia=c[B>>2]|0;Ha=c[u>>2]|0;Ka=0;Ga=c[j>>2]|0;do{w=Ha+(Ga>>>3)|0;Ca=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(Ga&7)>>>30;w=Ga+2|0;Ga=Ia>>>0>w>>>0?w:Ia;c[j>>2]=Ga;a[g+127+Ka|0]=Ca;Ka=Ka+1|0;}while(Ka>>>0<(c[Ba>>2]|0)>>>0)}zfb(g,q,Ja,0);Afb(g,q,Ja,0);Ba=c[j>>2]|0;Ka=c[u>>2]|0;Ga=d[Ka+(Ba>>>3)|0]<<(Ba&7)>>>7;Ia=c[B>>2]|0;Ha=((Ba|0)<(Ia|0))+Ba|0;c[j>>2]=Ha;Ba=Ga&1;c[g+100>>2]=Ba;if((Ba|0)==0){Wa=Ha;Xa=Ka;Ya=Ia;R=195;break}Ba=c[g+262884>>2]|0;if((Ba|0)>0){ab=0;bb=Ha}else{Wa=Ha;Xa=Ka;Ya=Ia;R=195;break}while(1){Ha=d[Ka+(bb>>>3)|0]<<(bb&7)>>>7;Ga=((bb|0)<(Ia|0))+bb|0;c[j>>2]=Ga;a[g+137+ab|0]=Ha&1;Ha=ab+1|0;if((Ha|0)<(Ba|0)){ab=Ha;bb=Ga}else{Wa=Ga;Xa=Ka;Ya=Ia;R=195;break}}}else{yDb(c[f+4>>2]|0,16,2285984,(T=i,i=i+8|0,c[T>>2]=l,T)|0);i=T;c[U>>2]=0;c[s>>2]=32;c[r>>2]=0;c[g+102312>>2]=-1;c[g+14664>>2]=-1;TGb(g+12|0,-1|0,6)|0}}while(0);d:do{if((R|0)==195){r=d[Xa+(Wa>>>3)|0]|0;s=((Wa|0)<(Ya|0))+Wa|0;c[j>>2]=s;if((r&128>>>((Wa&7)>>>0)|0)==0){break}r=Xa+(s>>>3)|0;U=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>28;r=s+4|0;s=Ya>>>0>r>>>0?r:Ya;c[j>>2]=s;if((U|0)==15){r=Xa+(s>>>3)|0;l=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>24;r=s+8|0;bb=Ya>>>0>r>>>0?r:Ya;c[j>>2]=bb;cb=l+15|0;db=bb}else{cb=U;db=s}s=cb<<3;e:do{if((s|0)>7){U=f+4|0;bb=f+6544|0;l=g+175392|0;r=s;ab=db;$a=Ya;_a=Xa;while(1){eb=r-2|0;Za=_a+(ab>>>3)|0;Ta=(fe(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(ab&7)>>>30;Za=ab+2|0;fb=$a>>>0>Za>>>0?Za:$a;c[j>>2]=fb;if((Ta|0)==0){R=207;break}else if((Ta|0)!=2){R=209;break}gb=c[U>>2]|0;if((c[bb>>2]|0)==0){R=202;break}Ta=eb-(upb(gb,q,l,eb)|0)|0;c[(c[U>>2]|0)+840>>2]=28;if((Ta|0)<=7){hb=Ta;break e}r=Ta;ab=c[j>>2]|0;$a=c[B>>2]|0;_a=c[u>>2]|0}do{if((R|0)==202){yDb(gb,16,2254744,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;ab=c[j>>2]|0;l=-ab|0;bb=(c[B>>2]|0)-ab|0;if((eb|0)<(l|0)){ib=l}else{ib=(bb|0)<(eb|0)?bb:eb}c[j>>2]=ib+ab;break d}else if((R|0)==207){if((eb|0)>16){R=209;break}ab=_a+(fb>>>3)|0;if(((fe(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(fb&7)>>>((34-r|0)>>>0)|0)==0){jb=fb;kb=$a}else{R=209}}}while(0);if((R|0)==209){DDb(c[U>>2]|0,2240592,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;jb=c[j>>2]|0;kb=c[B>>2]|0}$a=-jb|0;r=kb-jb|0;if((eb|0)<($a|0)){lb=$a}else{lb=(r|0)<(eb|0)?r:eb}c[j>>2]=lb+jb;break d}else{hb=s}}while(0);if((hb|0)<0){yDb(c[f+4>>2]|0,16,2270104,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T}if((hb|0)<=0){break}s=c[B>>2]|0;r=(c[j>>2]|0)+hb|0;c[j>>2]=s>>>0>r>>>0?r:s}}while(0);Na=D-La+(c[j>>2]|0)|0}j=(Na+4+(4-Na&7)|0)>>>3;if(!(j>>>0>k>>>0)){i=m;return k|0}yDb(c[f+4>>2]|0,16,2191480,(T=i,i=i+16|0,c[T>>2]=k,c[T+8>>2]=j,T)|0);i=T;i=m;return k|0}function sfb(f,h,j,k,l){f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0,E=0,F=0,G=0,H=0.0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0.0,qb=0.0,rb=0.0,sb=0,tb=0,ub=0,vb=0,wb=0.0,xb=0.0,yb=0.0,zb=0,Ab=0;m=i;n=(c[f+6532>>2]|0)<(c[h>>2]|0)|0;o=(j|0)==1;j=o?2:1;p=h+80|0;if((c[p>>2]|0)==0){c[h+64>>2]=c[h+68>>2];c[h+72>>2]=c[h+76>>2]}else{c[p>>2]=0}p=h+4|0;a:do{if((c[p>>2]|0)!=0){do{if(o){if((c[h+40>>2]|0)==0){break}q=(c[h+188>>2]|0)!=0;r=q?1.0:.5;s=q?12.0:24.0;q=h+104|0;t=c[q>>2]|0;if((t|0)!=0){u=1;v=t;while(1){t=h+108+u|0;if((c[h+262880+(d[t]<<2)>>2]|0)==0){w=v}else{x=0;do{y=h+86512+(u*192|0)+(x<<2)|0;z=+Wc(+(r*+g[y>>2]+7.0));A=h+174160+(u*192|0)+(x<<2)|0;B=+Wc(+(r*(s- +g[A>>2])));if(z>1.0e20){yDb(0,16,2303768,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;D=1.0}else{D=z}z=D/(B+1.0);g[y>>2]=z;g[A>>2]=B*z;x=x+1|0;}while(x>>>0<(c[h+262880+(d[t]<<2)>>2]|0)>>>0);w=c[q>>2]|0}t=u+1|0;if(t>>>0>w>>>0){break}else{u=t;v=w}}}v=h+116|0;u=c[v>>2]|0;if((u|0)==0){break a}q=h+262888|0;t=1;x=c[q>>2]|0;A=u;while(1){if((x|0)==0){E=0;F=A}else{u=0;do{y=h+87664+(t*20|0)+(u<<2)|0;s=+Wc(+(6.0- +g[y>>2]+1.0));G=h+175312+(t*20|0)+(u<<2)|0;r=+Wc(+(12.0- +g[G>>2]));if(s>1.0e20){yDb(0,16,2303768,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;H=1.0}else{H=s}s=H/(r+1.0);g[y>>2]=s;g[G>>2]=r*s;u=u+1|0;I=c[q>>2]|0;}while(u>>>0<I>>>0);E=I;F=c[v>>2]|0}u=t+1|0;if(u>>>0>F>>>0){break a}else{t=u;x=E;A=F}}}}while(0);A=h+262888|0;x=0;do{s=(c[h+96+(x*87648|0)+92>>2]|0)!=0?1.0:.5;t=h+96+(x*87648|0)+8|0;v=c[t>>2]|0;if((v|0)!=0){q=1;u=v;while(1){v=h+96+(x*87648|0)+12+q|0;if((c[h+262880+(d[v]<<2)>>2]|0)==0){J=u}else{G=0;do{y=h+96+(x*87648|0)+86416+(q*192|0)+(G<<2)|0;r=+Wc(+(s*+g[y>>2]+6.0));g[y>>2]=r;if(r>1.0e20){yDb(0,16,2303768,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;g[y>>2]=1.0}G=G+1|0;}while(G>>>0<(c[h+262880+(d[v]<<2)>>2]|0)>>>0);J=c[t>>2]|0}v=q+1|0;if(v>>>0>J>>>0){break}else{q=v;u=J}}}u=h+96+(x*87648|0)+20|0;q=c[u>>2]|0;if((q|0)!=0){t=1;v=c[A>>2]|0;G=q;while(1){if((v|0)==0){K=0;L=G}else{q=0;do{y=h+96+(x*87648|0)+87568+(t*20|0)+(q<<2)|0;g[y>>2]=+Wc(+(6.0- +g[y>>2]));q=q+1|0;M=c[A>>2]|0;}while(q>>>0<M>>>0);K=M;L=c[u>>2]|0}q=t+1|0;if(q>>>0>L>>>0){break}else{t=q;v=K;G=L}}}x=x+1|0;}while((x|0)<(j|0))}}while(0);L=h+343584|0;K=h+343712|0;M=h+342304|0;J=f+5420|0;F=K|0;E=h+343724|0;I=h+343628|0;w=h+342560|0;o=h+343728|0;x=h+343768|0;A=h+263232|0;G=h+343776|0;v=h+343780|0;t=h+332864|0;u=h+333376|0;q=h+44|0;y=h+262888|0;N=h+273472|0;O=h+68|0;P=h+263216|0;Q=h+76|0;S=h+32|0;T=h+263044|0;U=h+262994|0;V=h+343716|0;W=h+343772|0;X=h+262892|0;Y=h+28|0;Z=h+262884|0;_=h+263142|0;$=f+4|0;aa=h+102312|0;ca=h+14664|0;da=h+12|0;ea=h+343744|0;fa=0;do{ga=h+96+(fa*87648|0)+9312|0;ha=h+96+(fa*87648|0)+30976|0;ia=c[ha>>2]|0;UGb(ga|0,h+96+(fa*87648|0)+13408|0,1152)|0;UGb(h+96+(fa*87648|0)+10464|0,((fa|0)!=0?l:k)|0,4096)|0;ja=ga;ga=0;while(1){cf[c[J>>2]&1023](M,4313232,ja,320);me[c[F>>2]&511](M);me[c[E>>2]&511](M);Xe[c[I>>2]&4095](L,M,w);ne[c[o>>2]&1023](h+96+(fa*87648|0)+14592+(ia<<13)+(ga<<8)|0,M);ka=ga+1|0;if((ka|0)<32){ja=ja+128|0;ga=ka}else{break}}ga=h+96+(fa*87648|0)|0;Pe[c[x>>2]&255](f,h,A,h+96+(fa*87648|0)+14592|0,c[ha>>2]|0)|0;c[ha>>2]=c[ha>>2]^1;b:do{if((c[p>>2]|0)!=0){le[c[v>>2]&1023](K,t,u,A,c[q>>2]|0);ja=c[y>>2]|0;if((ja|0)!=0){ia=0;do{ka=d[h+96+(fa*87648|0)+31+ia|0]|0;if(((d[h+96+(fa*87648|0)+36+ia|0]|0)+ka|0)==1){la=.6000000238418579}else{la=+g[482712+(ka<<2)>>2]}ka=h+96+(fa*87648|0)+14572+(ia<<2)|0;H=+g[ka>>2];if(la<H){ma=la*.75+H*.25}else{ma=la*.90625+H*.09375}g[ka>>2]=ma<.015625?0.0:ma;ia=ia+1|0;}while(ia>>>0<ja>>>0)}ja=h+96+(fa*87648|0)+87628|0;ia=c[O>>2]|0;ka=c[P>>2]|0;do{if((ka|0)==0){na=ia;oa=ia;pa=61}else{qa=(c[h+96+(fa*87648|0)+8>>2]|0)+(h+96+(fa*87648|0)+87628)|0;ra=0;sa=0;ta=ia;ua=ka;c:while(1){va=h+263220+ra|0;if((a[va]|0)==0){wa=sa;xa=ta;ya=ua}else{za=h+263226+ra|0;Aa=0;Ba=sa;Ca=ta;while(1){Da=(d[za]|0)+Aa|0;Ea=c[y>>2]|0;Fa=Ba;while(1){if(Fa>>>0>Ea>>>0){break}if((Ca|0)<(e[h+263142+(Fa<<1)>>1]|0)){break}else{Fa=Fa+1|0}}Ga=Fa-1|0;if((Ga|0)<0){pa=56;break c}We[c[ea>>2]&7](h+273472+(Ca*320|0)+16|0,h+263232+(Da*320|0)+16|0,h+332864+(Da<<3)|0,h+333376+(Da<<3)|0,+g[h+96+(fa*87648|0)+14572+(Ga<<2)>>2],d[ja]<<1,d[qa]<<1);Ea=Aa+1|0;Ha=Ca+1|0;if((Ea|0)<(d[va]|0)){Aa=Ea;Ba=Ga;Ca=Ha}else{break}}wa=Ga;xa=Ha;ya=c[P>>2]|0}Ba=ra+1|0;if(Ba>>>0<ya>>>0){ra=Ba;sa=wa;ta=xa;ua=ya}else{pa=60;break}}if((pa|0)==56){pa=0;yDb(c[$>>2]|0,16,2328240,(C=i,i=i+8|0,c[C>>2]=Ca,C)|0);i=C;break}else if((pa|0)==60){pa=0;na=xa;oa=c[O>>2]|0;pa=61;break}}}while(0);do{if((pa|0)==61){pa=0;ja=(c[Q>>2]|0)+oa|0;if(!(na>>>0<ja>>>0)){break}TGb(h+273472+(na*320|0)|0,0,(ja-na|0)*320|0|0)|0}}while(0);ja=h+96+(fa*87648|0)+14564|0;TGb(h+96+(fa*87648|0)+86080|0,0,336)|0;ka=h+96+(fa*87648|0)+8|0;d:do{if((c[ka>>2]|0)==0){Ia=0}else{ia=h+96+(fa*87648|0)+20|0;ua=h+96+(fa*87648|0)+87638|0;ta=h+96+(fa*87648|0)+4|0;sa=h+96+(fa*87648|0)+14568|0;ra=0;while(1){qa=ra+1|0;Ba=a[h+96+(fa*87648|0)+12+qa|0]|0;Aa=c[h+262880+((Ba&255)<<2)>>2]|0;va=Ba<<24>>24==0?U:T;Ba=b[va>>1]|0;if((c[O>>2]|0)!=(Ba&65535|0)){break}za=(Aa|0)==0;if(!za){Ea=0;Ja=Ba;while(1){Ba=Ea+1|0;Ka=b[va+(Ba<<1)>>1]|0;if((Ja&65535)>>>0<(Ka&65535)>>>0){La=h+96+(fa*87648|0)+86416+(qa*192|0)+(Ea<<2)|0;Ma=Ka&65535;Na=Ja&65535;do{g[h+333888+(ra*192|0)+(Na-(c[O>>2]|0)<<2)>>2]=+g[La>>2];Na=Na+1|0;}while((Na|0)<(Ma|0))}if(Ba>>>0<Aa>>>0){Ea=Ba;Ja=Ka}else{break}}}if((c[ia>>2]|0)>>>0>1>>>0){Oa=(d[h+96+(fa*87648|0)+87628+ra|0]|0)>>>0>=(d[ua]|0)>>>0?2:1}else{Oa=1}Ja=c[y>>2]|0;if((Ja|0)!=0){Ea=0;Ma=b[_>>1]|0;Na=Ja;while(1){Ja=Ea+1|0;La=h+263142+(Ja<<1)|0;Da=b[La>>1]|0;if((Ma&65535)>>>0<(Da&65535)>>>0){Fa=h+96+(fa*87648|0)+87568+(Oa*20|0)+(Ea<<2)|0;Pa=Ma&65535;do{g[h+335232+(ra*192|0)+(Pa-(c[O>>2]|0)<<2)>>2]=+g[Fa>>2];Pa=Pa+1|0;Qa=b[La>>1]|0;}while((Pa|0)<(Qa&65535|0));Ra=Qa;Sa=c[y>>2]|0}else{Ra=Da;Sa=Na}if(Ja>>>0<Sa>>>0){Ea=Ja;Ma=Ra;Na=Sa}else{break}}}Na=c[Z>>2]|0;if((Na|0)!=0){Ma=0;Ea=Na;while(1){if((c[ta>>2]|0)==0){Ta=Ea;Ua=Ma+1|0}else{Na=Ma+1|0;Pa=((e[h+263044+(Na<<1)>>1]|0)+(e[h+263044+(Ma<<1)>>1]|0)|0)>>>1;La=c[O>>2]|0;if((ra|0)<(c[sa>>2]|0)){Va=(a[Pa-La+(h+96+(fa*87648|0)+86032)|0]|0)==1|0}else{Va=1}a[Pa-La+(h+96+(fa*87648|0)+86032+(qa*48|0))|0]=a[h+96+(fa*87648|0)+41+Ma|0]&(-Va&255);Ta=c[Z>>2]|0;Ua=Na}if(Ua>>>0<Ta>>>0){Ma=Ua;Ea=Ta}else{break}}}if(!za){Ea=0;do{Ma=e[va+(Ea<<1)>>1]|0;Ea=Ea+1|0;Na=e[va+(Ea<<1)>>1]|0;La=c[O>>2]|0;Pa=Ma;while(1){if((Pa|0)>=(Na|0)){Wa=0;break}if((a[Pa-La+(h+96+(fa*87648|0)+86032+(qa*48|0))|0]|0)==0){Pa=Pa+1|0}else{Wa=1;break}}TGb(Ma-La+(h+336576+(ra*48|0))|0,Wa|0,Na-Ma|0)|0;}while(Ea>>>0<Aa>>>0)}Aa=c[ka>>2]|0;if(qa>>>0<Aa>>>0){ra=qa}else{Ia=Aa;break d}}yDb(c[$>>2]|0,16,2348352,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[p>>2]=0;c[O>>2]=32;c[Q>>2]=0;c[aa>>2]=-1;c[ca>>2]=-1;TGb(da|0,-1|0,6)|0;break b}}while(0);UGb(h+96+(fa*87648|0)+86032|0,h+96+(fa*87648|0)+86032+(Ia*48|0)|0,48)|0;ra=c[O>>2]|0;sa=(Ia|0)==0;do{if((c[S>>2]|0)==0){if(sa){break}else{Xa=0;Ya=Ia}while(1){ta=Xa+1|0;ua=d[h+96+(fa*87648|0)+87628+ta|0]|0;ia=d[h+96+(fa*87648|0)+87628+Xa|0]|0;Aa=ua-ia<<1;Ea=ia<<1;ia=Ea+2|0;va=h+96+(fa*87648|0)+12+ta|0;za=a[va]|0;Pa=za<<24>>24==0?U:T;if((c[h+262880+((za&255)<<2)>>2]|0)==0){Za=Ya}else{za=(ua<<1)-Ea|0;Ea=0;ua=b[Pa>>1]|0;while(1){Ja=Ea+1|0;Da=Pa+(Ja<<1)|0;Fa=b[Da>>1]|0;Ka=Pa+(Ea<<1)|0;Ba=ua&65535;_a=ba(Aa,(Fa&65535)-Ba|0)|0;if((ua&65535)>>>0<(Fa&65535)>>>0){$a=Ba;H=0.0;do{H=H+ +De[c[V>>2]&3](h+273472+($a*320|0)+(ia<<3)|0,za);$a=$a+1|0;ab=b[Da>>1]|0;}while(($a|0)<(ab&65535|0));bb=H;cb=b[Ka>>1]|0;db=ab}else{bb=0.0;cb=ua;db=Fa}D=bb/+(_a|0);if((cb&65535)>>>0<(db&65535)>>>0){$a=db&65535;Da=cb&65535;do{g[h+336912+(Xa*192|0)+(Da-ra<<2)>>2]=D;Da=Da+1|0;}while((Da|0)<($a|0))}if(Ja>>>0<(c[h+262880+(d[va]<<2)>>2]|0)>>>0){Ea=Ja;ua=db}else{break}}Za=c[ka>>2]|0}if(ta>>>0<Za>>>0){Xa=ta;Ya=Za}else{eb=Za;pa=114;break}}}else{if(sa){break}ua=0;Ea=c[Q>>2]|0;va=Ia;while(1){za=ua+1|0;ia=d[h+96+(fa*87648|0)+87628+za|0]|0;Aa=d[h+96+(fa*87648|0)+87628+ua|0]|0;D=.5/+(ia-Aa|0);Pa=Aa<<1;Aa=Pa+2|0;if((Ea|0)==0){fb=0;gb=va}else{qa=(ia<<1)-Pa|0;Pa=0;do{g[h+336912+(ua*192|0)+(Pa<<2)>>2]=D*+De[c[V>>2]&3](h+273472+((Pa+ra|0)*320|0)+(Aa<<3)|0,qa);Pa=Pa+1|0;hb=c[Q>>2]|0;}while(Pa>>>0<hb>>>0);fb=hb;gb=c[ka>>2]|0}if(za>>>0<gb>>>0){ua=za;Ea=fb;va=gb}else{eb=gb;pa=114;break}}}}while(0);do{if((pa|0)==114){pa=0;if((eb|0)==0){break}ka=c[h+96+(fa*87648|0)+14568>>2]|0;ra=0;while(1){if((ra|0)==(ka|0)){ib=0}else{ib=(ra|0)!=(c[ja>>2]|0)}if((c[X>>2]|0)==0){jb=ra+1|0}else{sa=ra+1|0;D=+(ib&1|0);va=0;Ea=c[O>>2]|0;while(1){ua=h+263154+(va<<1)|0;Pa=b[ua>>1]|0;qa=(Pa&65535)-Ea|0;Aa=va+1|0;ta=h+263154+(Aa<<1)|0;ia=b[ta>>1]|0;if(qa>>>0<((ia&65535)-Ea|0)>>>0){$a=qa;do{H=+g[h+333888+(ra*192|0)+($a<<2)>>2];s=+g[h+335232+(ra*192|0)+($a<<2)>>2];r=s+1.0;z=H/r;g[h+338256+(ra*192|0)+($a<<2)>>2]=+R(s*z);g[h+339600+(ra*192|0)+($a<<2)>>2]=+R(z*+(d[h+96+(fa*87648|0)+86032+(sa*48|0)+$a|0]|0));if((a[h+336576+(ra*48|0)+$a|0]|0)==0){g[h+340944+(ra*192|0)+($a<<2)>>2]=+R(H/((D*s+1.0)*(+g[h+336912+(ra*192|0)+($a<<2)>>2]+1.0)))}else{g[h+340944+(ra*192|0)+($a<<2)>>2]=+R(H*s/(r*(+g[h+336912+(ra*192|0)+($a<<2)>>2]+1.0)))}$a=$a+1|0;kb=b[ta>>1]|0;lb=c[O>>2]|0;}while($a>>>0<((kb&65535)-lb|0)>>>0);mb=lb;nb=b[ua>>1]|0;ob=kb}else{mb=Ea;nb=Pa;ob=ia}$a=(nb&65535)-mb|0;Ja=ob&65535;qa=Ja-mb|0;Da=$a>>>0<qa>>>0;if(Da){_a=$a;r=0.0;s=0.0;do{s=s+ +g[h+333888+(ra*192|0)+(_a<<2)>>2];r=r+ +g[h+336912+(ra*192|0)+(_a<<2)>>2];_a=_a+1|0;}while(_a>>>0<qa>>>0);pb=r+1.1920928955078125e-7;qb=s+1.1920928955078125e-7}else{pb=1.1920928955078125e-7;qb=1.1920928955078125e-7}H=+g[482696+(c[Y>>2]<<2)>>2]*+R(qb/pb);z=H<1.0e5?H:1.0e5;if(Da){qa=$a;do{_a=h+338256+(ra*192|0)+(qa<<2)|0;H=+g[_a>>2];ia=h+340944+(ra*192|0)+(qa<<2)|0;B=+g[ia>>2];rb=z*H/B;g[_a>>2]=H>rb?rb:H;g[ia>>2]=B>z?z:B;qa=qa+1|0;sb=c[O>>2]|0;}while(qa>>>0<(Ja-sb|0)>>>0);tb=sb;ub=b[ua>>1]|0;vb=b[ta>>1]|0}else{tb=mb;ub=nb;vb=ob}Ja=(ub&65535)-tb|0;qa=vb&65535;$a=qa-tb|0;Da=Ja>>>0<$a>>>0;if(Da){if(ib){ia=Ja;z=0.0;s=0.0;while(1){r=s+ +g[h+333888+(ra*192|0)+(ia<<2)>>2];B=+g[h+340944+(ra*192|0)+(ia<<2)>>2];H=+g[h+339600+(ra*192|0)+(ia<<2)>>2];rb=+g[h+338256+(ra*192|0)+(ia<<2)>>2];wb=z+(B*+g[h+336912+(ra*192|0)+(ia<<2)>>2]*B+H*H+rb*rb*+(H==0.0|0));_a=ia+1|0;if(_a>>>0<$a>>>0){ia=_a;z=wb;s=r}else{xb=wb;yb=r;break}}}else{ia=Ja;s=0.0;z=0.0;while(1){r=z+ +g[h+333888+(ra*192|0)+(ia<<2)>>2];wb=+g[h+340944+(ra*192|0)+(ia<<2)>>2];H=+g[h+339600+(ra*192|0)+(ia<<2)>>2];rb=+g[h+338256+(ra*192|0)+(ia<<2)>>2];B=s+(wb*+g[h+336912+(ra*192|0)+(ia<<2)>>2]*wb+H*H+rb*rb*0.0);ta=ia+1|0;if(ta>>>0<$a>>>0){ia=ta;s=B;z=r}else{xb=B;yb=r;break}}}}else{xb=0.0;yb=0.0}z=+R((yb+1.1920928955078125e-7)/(xb+1.1920928955078125e-7));s=z<1.5848932266235352?z:1.5848932266235352;if(Da){ia=Ja;while(1){$a=h+340944+(ra*192|0)+(ia<<2)|0;g[$a>>2]=s*+g[$a>>2];$a=h+338256+(ra*192|0)+(ia<<2)|0;g[$a>>2]=s*+g[$a>>2];$a=h+339600+(ra*192|0)+(ia<<2)|0;g[$a>>2]=s*+g[$a>>2];$a=ia+1|0;ta=c[O>>2]|0;if($a>>>0<(qa-ta|0)>>>0){ia=$a}else{zb=ta;break}}}else{zb=tb}if(Aa>>>0<(c[X>>2]|0)>>>0){va=Aa;Ea=zb}else{jb=sa;break}}}if(jb>>>0<eb>>>0){ra=jb}else{break}}}}while(0);le[c[W>>2]&1023](h+96+(fa*87648|0)+30992+((c[ha>>2]|0)*19456|0)|0,N,h,ga,ja)}}while(0);ga=c[ha>>2]|0;oe[c[G>>2]&63](h,h+293952+(fa*19456|0)|0,h+96+(fa*87648|0)+30992+((1-ga|0)*19456|0)|0,h+96+(fa*87648|0)+30992+(ga*19456|0)|0,A,fa)|0;fa=fa+1|0;}while((fa|0)<(j|0));do{if((c[f+6544>>2]|0)==1){fa=h+175392|0;if((c[fa>>2]|0)==0){UGb(h+313408|0,h+293952|0,19456)|0;Ab=2;break}else{vpb(c[$>>2]|0,fa,h+293952|0,h+313408|0,(c[Q>>2]|0)+(c[O>>2]|0)|0)|0;Ab=2;break}}else{Ab=j}}while(0);j=h+343648|0;O=f+5396|0;f=h+342304|0;tfb(j,K,O,k,h+293952|0,f,h+192|0,h+14656|0,n);if((Ab|0)!=2){i=m;return}tfb(j,K,O,l,h+313408|0,f,h+87840|0,h+102304|0,n);i=m;return}function tfb(a,b,d,e,f,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=(k|0)!=0;m=l?4313232:48e4;n=128>>>(k>>>0);o=1152>>>(k>>>0);p=2304-o|0;q=i+(p<<2)|0;r=i;s=o<<2;o=d|0;t=64>>>(k>>>0);u=d+20|0;d=192>>>(k>>>0);v=m+(t<<2)|0;w=256>>>(k>>>0);x=m+(n<<2)|0;y=448>>>(k>>>0);z=m+(d<<2)|0;A=512>>>(k>>>0);B=m+(w<<2)|0;C=704>>>(k>>>0);D=m+(320>>>(k>>>0)<<2)|0;E=768>>>(k>>>0);F=m+(384>>>(k>>>0)<<2)|0;G=960>>>(k>>>0);H=m+(y<<2)|0;I=1024>>>(k>>>0);J=m+(A<<2)|0;K=1216>>>(k>>>0);L=m+(576>>>(k>>>0)<<2)|0;k=b+8|0;M=a+44|0;N=h|0;O=h+256|0;h=b+24|0;P=b+20|0;if(l){Q=0;R=e}else{l=0;b=e;while(1){e=c[j>>2]|0;if((e|0)<(n|0)){UGb(q|0,r|0,s)|0;S=p}else{S=e}e=S-n|0;c[j>>2]=e;T=i+(e<<2)|0;U=f+9728+(l<<8)|0;me[c[k>>2]&511](U);Xe[c[M>>2]&4095](a,N,f+(l<<8)|0);Xe[c[M>>2]&4095](a,O,U);Xe[c[h>>2]&4095](T,O,N);cf[c[o>>2]&1023](b,T,m,t);le[c[u>>2]&1023](b,i+(e+d<<2)|0,v,b,t);le[c[u>>2]&1023](b,i+(e+w<<2)|0,x,b,t);le[c[u>>2]&1023](b,i+(e+y<<2)|0,z,b,t);le[c[u>>2]&1023](b,i+(e+A<<2)|0,B,b,t);le[c[u>>2]&1023](b,i+(e+C<<2)|0,D,b,t);le[c[u>>2]&1023](b,i+(e+E<<2)|0,F,b,t);le[c[u>>2]&1023](b,i+(e+G<<2)|0,H,b,t);le[c[u>>2]&1023](b,i+(e+I<<2)|0,J,b,t);le[c[u>>2]&1023](b,i+(e+K<<2)|0,L,b,t);e=l+1|0;if((e|0)<32){l=e;b=b+(t<<2)|0}else{break}}return}while(1){b=c[j>>2]|0;if((b|0)<(n|0)){UGb(q|0,r|0,s)|0;V=p}else{V=b}b=V-n|0;c[j>>2]=b;l=i+(b<<2)|0;O=0;do{h=f+(Q<<8)+(O<<2)|0;g[h>>2]=-0.0- +g[h>>2];g[f+(Q<<8)+(O+32<<2)>>2]=+g[f+9728+(Q<<8)+(31-O<<2)>>2];O=O+1|0;}while((O|0)<32);Xe[c[M>>2]&4095](a,N,f+(Q<<8)|0);ne[c[P>>2]&1023](l,N);cf[c[o>>2]&1023](R,l,m,t);le[c[u>>2]&1023](R,i+(b+d<<2)|0,v,R,t);le[c[u>>2]&1023](R,i+(b+w<<2)|0,x,R,t);le[c[u>>2]&1023](R,i+(b+y<<2)|0,z,R,t);le[c[u>>2]&1023](R,i+(b+A<<2)|0,B,R,t);le[c[u>>2]&1023](R,i+(b+C<<2)|0,D,R,t);le[c[u>>2]&1023](R,i+(b+E<<2)|0,F,R,t);le[c[u>>2]&1023](R,i+(b+G<<2)|0,H,R,t);le[c[u>>2]&1023](R,i+(b+I<<2)|0,J,R,t);le[c[u>>2]&1023](R,i+(b+K<<2)|0,L,R,t);O=Q+1|0;if((O|0)<32){Q=O;R=R+(t<<2)|0}else{break}}return}function ufb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0;TGb(d|0,0,10240)|0;a=c[b+68>>2]|0;if((a|0)!=0){h=0;do{i=8;do{j=i-8|0;g[d+(h*320|0)+(i<<3)>>2]=+g[e+(f<<13)+(j<<8)+(h<<3)>>2];g[d+(h*320|0)+(i<<3)+4>>2]=+g[e+(f<<13)+(j<<8)+(h<<3)+4>>2];i=i+1|0;}while((i|0)<40);h=h+1|0;}while(h>>>0<a>>>0)}a=1-f|0;f=c[b+64>>2]|0;if((f|0)==0){return 0}else{k=0}do{g[d+(k*320|0)>>2]=+g[e+(a<<13)+6144+(k<<3)>>2];g[d+(k*320|0)+4>>2]=+g[e+(a<<13)+6144+(k<<3)+4>>2];g[d+(k*320|0)+8>>2]=+g[e+(a<<13)+6400+(k<<3)>>2];g[d+(k*320|0)+12>>2]=+g[e+(a<<13)+6400+(k<<3)+4>>2];g[d+(k*320|0)+16>>2]=+g[e+(a<<13)+6656+(k<<3)>>2];g[d+(k*320|0)+20>>2]=+g[e+(a<<13)+6656+(k<<3)+4>>2];g[d+(k*320|0)+24>>2]=+g[e+(a<<13)+6912+(k<<3)>>2];g[d+(k*320|0)+28>>2]=+g[e+(a<<13)+6912+(k<<3)+4>>2];g[d+(k*320|0)+32>>2]=+g[e+(a<<13)+7168+(k<<3)>>2];g[d+(k*320|0)+36>>2]=+g[e+(a<<13)+7168+(k<<3)+4>>2];g[d+(k*320|0)+40>>2]=+g[e+(a<<13)+7424+(k<<3)>>2];g[d+(k*320|0)+44>>2]=+g[e+(a<<13)+7424+(k<<3)+4>>2];g[d+(k*320|0)+48>>2]=+g[e+(a<<13)+7680+(k<<3)>>2];g[d+(k*320|0)+52>>2]=+g[e+(a<<13)+7680+(k<<3)+4>>2];g[d+(k*320|0)+56>>2]=+g[e+(a<<13)+7936+(k<<3)>>2];g[d+(k*320|0)+60>>2]=+g[e+(a<<13)+7936+(k<<3)+4>>2];k=k+1|0;}while(k>>>0<f>>>0);return 0}function vfb(b,e,f,h,j){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0.0,aa=0,ba=0.0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;k=i;i=i+384|0;l=k|0;m=k+192|0;n=(c[f+36>>2]|0)==0;o=(n&1)<<2;p=c[f+68>>2]|0;q=c[f+76>>2]|0;r=h+87640|0;s=c[r>>2]|0;t=h+87644|0;u=c[t>>2]|0;do{if((c[f+8>>2]|0)==0){if(!n){break}v=h+87628|0;w=h+87636|0;UGb(h+69904+(((d[v]|0)<<1)*192|0)|0,h+69904+(((d[w]|0)<<1)*192|0)|0,768)|0;UGb(h+77968+(((d[v]|0)<<1)*192|0)|0,h+77968+(((d[w]|0)<<1)*192|0)|0,768)|0}else{if(!n){break}w=h+87628|0;v=f+340944|0;x=q<<2;y=f+338256|0;z=0;do{UGb(h+69904+((((d[w]|0)<<1)+z|0)*192|0)|0,v|0,x)|0;UGb(h+77968+((((d[w]|0)<<1)+z|0)*192|0)|0,y|0,x)|0;z=z+1|0;}while((z|0)<(o|0))}}while(0);z=h+8|0;x=c[z>>2]|0;if((x|0)==0){A=u;B=s;c[r>>2]=B;c[t>>2]=A;i=k;return}y=q<<2;w=0;v=a[h+87628|0]|0;C=x;while(1){x=(v&255)<<1;D=w+1|0;E=h+87628+D|0;F=a[E]|0;if(x>>>0<(F&255)<<1>>>0){G=f+340944+(w*192|0)|0;H=f+338256+(w*192|0)|0;I=x;do{x=I+o|0;UGb(h+69904+(x*192|0)|0,G|0,y)|0;UGb(h+77968+(x*192|0)|0,H|0,y)|0;I=I+1|0;J=a[E]|0;}while((I|0)<((J&255)<<1|0));K=J;L=c[z>>2]|0}else{K=F;L=C}if(D>>>0<L>>>0){w=D;v=K;C=L}else{break}}if((L|0)==0){A=u;B=s;c[r>>2]=B;c[t>>2]=A;i=k;return}C=l|0;K=m|0;v=j+4|0;w=(q|0)>0;J=f+343748|0;y=e+(p*320|0)|0;e=p&1;I=(q|0)>1;E=(q&1|0)==0;H=u;u=s;s=0;G=a[h+87628|0]|0;x=L;while(1){L=(G&255)<<1;M=s+1|0;N=h+87628+M|0;O=a[N]|0;if(L>>>0<(O&255)<<1>>>0){P=f+339600+(s*192|0)|0;Q=H;R=u;S=L;do{do{if(n){if((s|0)==(c[j>>2]|0)){T=28;break}if((s|0)==(c[v>>2]|0)){T=28;break}if(!w){U=K;V=C;break}L=S+o|0;W=0;while(1){X=l+(W<<2)|0;g[X>>2]=0.0;Y=m+(W<<2)|0;g[Y>>2]=0.0;Z=0;_=0.0;$=0.0;do{aa=L-Z|0;ba=+g[482672+(Z<<2)>>2];_=_+ +g[h+69904+(aa*192|0)+(W<<2)>>2]*ba;$=$+ +g[h+77968+(aa*192|0)+(W<<2)>>2]*ba;Z=Z+1|0;}while((Z|0)<=(o|0));g[X>>2]=_;g[Y>>2]=$;Z=W+1|0;if((Z|0)<(q|0)){W=Z}else{U=K;V=C;break}}}else{T=28}}while(0);if((T|0)==28){T=0;U=h+77968+(S*192|0)|0;V=h+69904+((S+o|0)*192|0)|0}W=b+(S<<9)+(p<<3)|0;le[c[J>>2]&1023](W,y,V,q,S+2|0);do{if((s|0)==(c[j>>2]|0)){T=32}else{if((s|0)==(c[v>>2]|0)){T=32;break}Se[c[f+343752+(Q<<2)>>2]&511](W,P,U,R,p,q)}}while(0);do{if((T|0)==32){T=0;W=Q&1;L=1-(Q+e&2)|0;if(I){ba=+(L|0);ca=+((L^-W)+W|0);Z=0;aa=1;while(1){da=Z<<1|W;ea=b+(S<<9)+(p<<3)+(da<<2)|0;g[ea>>2]=+g[ea>>2]+ba*+g[f+339600+(s*192|0)+(Z<<2)>>2];ea=b+(S<<9)+(p<<3)+((da|2)<<2)|0;g[ea>>2]=+g[ea>>2]+ca*+g[f+339600+(s*192|0)+(aa<<2)>>2];ea=Z+2|0;da=ea|1;if((da|0)<(q|0)){Z=ea;aa=da}else{fa=ea;break}}}else{fa=0}if(E){break}aa=b+(S<<9)+(p<<3)+((fa<<1|W)<<2)|0;g[aa>>2]=+g[aa>>2]+ +(L|0)*+g[f+339600+(s*192|0)+(fa<<2)>>2]}}while(0);R=R+q&511;Q=Q+1&3;S=S+1|0;ga=a[N]|0;}while((S|0)<((ga&255)<<1|0));ha=Q;ia=R;ja=ga;ka=c[z>>2]|0}else{ha=H;ia=u;ja=O;ka=x}if(M>>>0<ka>>>0){H=ha;u=ia;s=M;G=ja;x=ka}else{A=ha;B=ia;break}}c[r>>2]=B;c[t>>2]=A;i=k;return}function wfb(a,b,e,f,h,i){a=a|0;b=b|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=((d[a+96+(i*87648|0)+87636|0]|0)<<1)-32|0;i=(j|0)>0;k=i?j:0;TGb(b|0,0,19456)|0;j=c[a+64>>2]|0;if((j|0)==0){l=0;m=0}else{n=j>>>0>1>>>0;o=0;do{if(i){p=0;do{q=p+2|0;g[b+(p<<8)+(o<<2)>>2]=+g[h+(o*320|0)+(q<<3)>>2];g[b+9728+(p<<8)+(o<<2)>>2]=+g[h+(o*320|0)+(q<<3)+4>>2];p=p+1|0;}while((p|0)<(k|0))}o=o+1|0;}while(o>>>0<j>>>0);l=n?j:1;m=j}j=(c[a+72>>2]|0)+m|0;if(l>>>0<j>>>0){m=l;do{if(i){l=0;do{n=l+32|0;g[b+(l<<8)+(m<<2)>>2]=+g[e+(n<<9)+(m<<3)>>2];g[b+9728+(l<<8)+(m<<2)>>2]=+g[e+(n<<9)+(m<<3)+4>>2];l=l+1|0;}while((l|0)<(k|0))}m=m+1|0;}while(m>>>0<j>>>0)}j=c[a+68>>2]|0;do{if((j|0)==0){r=0}else{m=j>>>0>1>>>0;if((k|0)<38){s=0}else{r=m?j:1;break}do{e=k;do{i=e+2|0;g[b+(e<<8)+(s<<2)>>2]=+g[h+(s*320|0)+(i<<3)>>2];g[b+9728+(e<<8)+(s<<2)>>2]=+g[h+(s*320|0)+(i<<3)+4>>2];e=e+1|0;}while((e|0)<38);s=s+1|0;}while(s>>>0<j>>>0);r=m?j:1}}while(0);s=(c[a+76>>2]|0)+j|0;if(r>>>0<s>>>0&(k|0)<32){t=r}else{return 0}do{r=k;do{g[b+(r<<8)+(t<<2)>>2]=+g[f+(r<<9)+(t<<3)>>2];g[b+9728+(r<<8)+(t<<2)>>2]=+g[f+(r<<9)+(t<<3)+4>>2];r=r+1|0;}while((r|0)<32);t=t+1|0;}while(t>>>0<s>>>0);return 0}



function pna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))))))))))))))+8>>4;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function qna(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+8|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+16|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+24|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+8<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+12<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;return}function rna(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a;h=f>>1;f=h<<1;i=h*3|0;j=h<<2;k=(e[g+(-h<<1)>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=k;l=k+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=l;k=l+(c[d+32>>2]|0)|0;b[g+(i-h<<1)>>1]=k;b[g+(j-h<<1)>>1]=k+(c[d+48>>2]|0);k=1-h|0;h=(e[g+(k<<1)>>1]|0)+(c[d+4>>2]|0)|0;b[a+2>>1]=h;l=h+(c[d+20>>2]|0)|0;b[g+(k+f<<1)>>1]=l;h=l+(c[d+36>>2]|0)|0;b[g+(k+i<<1)>>1]=h;b[g+(k+j<<1)>>1]=h+(c[d+52>>2]|0);h=k+1|0;l=(e[g+(h<<1)>>1]|0)+(c[d+8>>2]|0)|0;b[a+4>>1]=l;m=l+(c[d+24>>2]|0)|0;b[g+(h+f<<1)>>1]=m;l=m+(c[d+40>>2]|0)|0;b[g+(h+i<<1)>>1]=l;b[g+(h+j<<1)>>1]=l+(c[d+56>>2]|0);l=k+2|0;k=(e[g+(l<<1)>>1]|0)+(c[d+12>>2]|0)|0;b[a+6>>1]=k;a=k+(c[d+28>>2]|0)|0;b[g+(l+f<<1)>>1]=a;f=a+(c[d+44>>2]|0)|0;b[g+(l+i<<1)>>1]=f;b[g+(l+j<<1)>>1]=f+(c[d+60>>2]|0);TGb(d|0,0,64)|0;return}function sna(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=a;h=f>>1;f=(e[a-2>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=f;i=f+(c[d+4>>2]|0)|0;b[a+2>>1]=i;f=i+(c[d+8>>2]|0)|0;b[a+4>>1]=f;b[a+6>>1]=f+(c[d+12>>2]|0);f=(e[g+(h-1<<1)>>1]|0)+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=f;a=f+(c[d+20>>2]|0)|0;b[g+(h+1<<1)>>1]=a;f=a+(c[d+24>>2]|0)|0;b[g+(h+2<<1)>>1]=f;b[g+(h+3<<1)>>1]=f+(c[d+28>>2]|0);f=h<<1;a=(e[g+(f-1<<1)>>1]|0)+(c[d+32>>2]|0)|0;b[g+(f<<1)>>1]=a;i=a+(c[d+36>>2]|0)|0;b[g+((f|1)<<1)>>1]=i;a=i+(c[d+40>>2]|0)|0;b[g+(f+2<<1)>>1]=a;b[g+(f+3<<1)>>1]=a+(c[d+44>>2]|0);a=f+h|0;h=(e[g+(a-1<<1)>>1]|0)+(c[d+48>>2]|0)|0;b[g+(a<<1)>>1]=h;f=h+(c[d+52>>2]|0)|0;b[g+(a+1<<1)>>1]=f;h=f+(c[d+56>>2]|0)|0;b[g+(a+2<<1)>>1]=h;b[g+(a+3<<1)>>1]=h+(c[d+60>>2]|0);TGb(d|0,0,64)|0;return}function tna(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=g<<1;h=g*3|0;i=g<<2;j=g*5|0;k=g*6|0;l=g*7|0;m=g<<3;n=0;o=a+(-g<<1)|0;a=d;while(1){p=(e[o>>1]|0)+(c[a>>2]|0)|0;b[o+(g<<1)>>1]=p;q=p+(c[a+32>>2]|0)|0;b[o+(f<<1)>>1]=q;p=q+(c[a+64>>2]|0)|0;b[o+(h<<1)>>1]=p;q=p+(c[a+96>>2]|0)|0;b[o+(i<<1)>>1]=q;p=q+(c[a+128>>2]|0)|0;b[o+(j<<1)>>1]=p;q=p+(c[a+160>>2]|0)|0;b[o+(k<<1)>>1]=q;p=q+(c[a+192>>2]|0)|0;b[o+(l<<1)>>1]=p;b[o+(m<<1)>>1]=p+(c[a+224>>2]|0);p=n+1|0;if((p|0)<8){n=p;o=o+2|0;a=a+4|0}else{break}}TGb(d|0,0,256)|0;return}function una(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=f>>1;f=0;h=a;a=d;while(1){i=(e[h-2>>1]|0)+(c[a>>2]|0)|0;b[h>>1]=i;j=i+(c[a+4>>2]|0)|0;b[h+2>>1]=j;i=j+(c[a+8>>2]|0)|0;b[h+4>>1]=i;j=i+(c[a+12>>2]|0)|0;b[h+6>>1]=j;i=j+(c[a+16>>2]|0)|0;b[h+8>>1]=i;j=i+(c[a+20>>2]|0)|0;b[h+10>>1]=j;i=j+(c[a+24>>2]|0)|0;b[h+12>>1]=i;b[h+14>>1]=i+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}TGb(d|0,0,256)|0;return}function vna(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;rna(a+(c[b>>2]|0)|0,d,e);rna(a+(c[b+4>>2]|0)|0,d+64|0,e);rna(a+(c[b+8>>2]|0)|0,d+128|0,e);rna(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function wna(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;sna(a+(c[b>>2]|0)|0,d,e);sna(a+(c[b+4>>2]|0)|0,d+64|0,e);sna(a+(c[b+8>>2]|0)|0,d+128|0,e);sna(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function xna(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;rna(a+(c[b>>2]|0)|0,d,e);rna(a+(c[b+4>>2]|0)|0,d+64|0,e);rna(a+(c[b+8>>2]|0)|0,d+128|0,e);rna(a+(c[b+12>>2]|0)|0,d+192|0,e);rna(a+(c[b+32>>2]|0)|0,d+256|0,e);rna(a+(c[b+36>>2]|0)|0,d+320|0,e);rna(a+(c[b+40>>2]|0)|0,d+384|0,e);rna(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function yna(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;sna(a+(c[b>>2]|0)|0,d,e);sna(a+(c[b+4>>2]|0)|0,d+64|0,e);sna(a+(c[b+8>>2]|0)|0,d+128|0,e);sna(a+(c[b+12>>2]|0)|0,d+192|0,e);sna(a+(c[b+32>>2]|0)|0,d+256|0,e);sna(a+(c[b+36>>2]|0)|0,d+320|0,e);sna(a+(c[b+40>>2]|0)|0,d+384|0,e);sna(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function zna(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{rna(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Ana(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{sna(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Bna(a,b,d){a=a|0;b=b|0;d=d|0;b=c[a+(-d|0)>>2]|0;c[a>>2]=b;c[a+d>>2]=b;c[a+(d<<1)>>2]=b;c[a+(d*3|0)>>2]=b;return}function Cna(a,b,e){a=a|0;b=b|0;e=e|0;c[a>>2]=ba(d[a-1|0]|0,16843009)|0;c[a+e>>2]=ba(d[a+(e-1)|0]|0,16843009)|0;b=e<<1;c[a+b>>2]=ba(d[a+(b-1)|0]|0,16843009)|0;b=e*3|0;c[a+b>>2]=ba(d[a+(b-1)|0]|0,16843009)|0;return}function Dna(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;b=e<<1;f=e*3|0;g=ba((d[a+(-e|0)|0]|0)+4+(d[a+(1-e)|0]|0)+(d[a+(2-e)|0]|0)+(d[a+(3-e)|0]|0)+(d[a-1|0]|0)+(d[a+(e-1)|0]|0)+(d[a+(b-1)|0]|0)+(d[a+(f-1)|0]|0)>>3,16843009)|0;c[a>>2]=g;c[a+e>>2]=g;c[a+b>>2]=g;c[a+f>>2]=g;return}function Ena(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d[b+(1-e)|0]|0;g=d[b+(2-e)|0]|0;h=d[b+(3-e)|0]|0;i=d[c]|0;j=d[c+1|0]|0;k=d[c+2|0]|0;l=d[c+3|0]|0;a[b]=((d[b+(-e|0)|0]|0)+2+g+(f<<1)|0)>>>2;c=(f+2+h+(g<<1)|0)>>>2&255;a[b+e|0]=c;a[b+1|0]=c;c=(g+2+i+(h<<1)|0)>>>2&255;g=e<<1;a[b+g|0]=c;a[b+(e+1)|0]=c;a[b+2|0]=c;c=(h+2+j+(i<<1)|0)>>>2&255;h=e*3|0;a[b+h|0]=c;a[b+(g|1)|0]=c;a[b+(e+2)|0]=c;a[b+3|0]=c;c=(i+2+k+(j<<1)|0)>>>2&255;a[b+(h+1)|0]=c;a[b+(g+2)|0]=c;a[b+(e+3)|0]=c;c=(j+2+l+(k<<1)|0)>>>2&255;a[b+(h+2)|0]=c;a[b+(g+3)|0]=c;a[b+(h+3)|0]=(k+2+(l*3|0)|0)>>>2;return}function Fna(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=d[b+~e|0]|0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b+(3-e)|0]|0;j=d[b-1|0]|0;k=d[b+(e-1)|0]|0;l=e<<1;m=d[b+(l-1)|0]|0;n=e*3|0;a[b+n|0]=(k+2+(m<<1)+(d[b+(n-1)|0]|0)|0)>>>2;o=(j+2+(k<<1)+m|0)>>>2&255;a[b+(n+1)|0]=o;a[b+l|0]=o;o=c+2|0;m=(o+(j<<1)+k|0)>>>2&255;a[b+(n+2)|0]=m;a[b+(l|1)|0]=m;a[b+e|0]=m;m=((c<<1)+2+f+j|0)>>>2&255;a[b+(n+3)|0]=m;a[b+(l+2)|0]=m;a[b+(e+1)|0]=m;a[b]=m;m=(o+(f<<1)+g|0)>>>2&255;a[b+(l+3)|0]=m;a[b+(e+2)|0]=m;a[b+1|0]=m;m=(f+2+(g<<1)+h|0)>>>2&255;a[b+(e+3)|0]=m;a[b+2|0]=m;a[b+3|0]=(g+2+(h<<1)+i|0)>>>2;return}function Gna(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=d[b+~e|0]|0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b+(3-e)|0]|0;j=d[b-1|0]|0;k=d[b+(e-1)|0]|0;l=e<<1;m=d[b+(l-1)|0]|0;n=e*3|0;o=(c+1+f|0)>>>1&255;a[b+(l|1)|0]=o;a[b]=o;o=(f+1+g|0)>>>1&255;a[b+(l+2)|0]=o;a[b+1|0]=o;o=(g+1+h|0)>>>1&255;a[b+(l+3)|0]=o;a[b+2|0]=o;a[b+3|0]=(h+1+i|0)>>>1;o=((c<<1)+2+f+j|0)>>>2&255;a[b+(n+1)|0]=o;a[b+e|0]=o;o=c+2|0;c=(o+(f<<1)+g|0)>>>2&255;a[b+(n+2)|0]=c;a[b+(e+1)|0]=c;c=(f+2+(g<<1)+h|0)>>>2&255;a[b+(n+3)|0]=c;a[b+(e+2)|0]=c;a[b+(e+3)|0]=(g+2+(h<<1)+i|0)>>>2;a[b+l|0]=(o+(j<<1)+k|0)>>>2;a[b+n|0]=(j+2+(k<<1)+m|0)>>>2;return}function Hna(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=d[b+~e|0]|0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b-1|0]|0;j=d[b+(e-1)|0]|0;k=e<<1;l=d[b+(k-1)|0]|0;m=e*3|0;n=d[b+(m-1)|0]|0;o=(c+1+i|0)>>>1&255;a[b+(e+2)|0]=o;a[b]=o;o=((c<<1)+2+f+i|0)>>>2&255;a[b+(e+3)|0]=o;a[b+1|0]=o;o=c+2|0;a[b+2|0]=(o+(f<<1)+g|0)>>>2;a[b+3|0]=(f+2+(g<<1)+h|0)>>>2;h=(i+1+j|0)>>>1&255;a[b+(k+2)|0]=h;a[b+e|0]=h;h=(o+(i<<1)+j|0)>>>2&255;a[b+(k+3)|0]=h;a[b+(e+1)|0]=h;h=(j+1+l|0)>>>1&255;a[b+(m+2)|0]=h;a[b+k|0]=h;h=(i+2+(j<<1)+l|0)>>>2&255;a[b+(m+3)|0]=h;a[b+(k|1)|0]=h;a[b+m|0]=(l+1+n|0)>>>1;a[b+(m+1)|0]=(j+2+(l<<1)+n|0)>>>2;return}function Ina(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b+(3-e)|0]|0;j=d[c]|0;k=d[c+1|0]|0;l=d[c+2|0]|0;a[b]=(f+1+g|0)>>>1;c=(g+1+h|0)>>>1&255;m=e<<1;a[b+m|0]=c;a[b+1|0]=c;c=(h+1+i|0)>>>1&255;a[b+(m|1)|0]=c;a[b+2|0]=c;c=(i+1+j|0)>>>1&255;a[b+(m+2)|0]=c;a[b+3|0]=c;a[b+(m+3)|0]=(j+1+k|0)>>>1;a[b+e|0]=(f+2+(g<<1)+h|0)>>>2;f=(g+2+(h<<1)+i|0)>>>2&255;g=e*3|0;a[b+g|0]=f;a[b+(e+1)|0]=f;f=(h+2+(i<<1)+j|0)>>>2&255;a[b+(g+1)|0]=f;a[b+(e+2)|0]=f;f=(i+2+(j<<1)+k|0)>>>2&255;a[b+(g+2)|0]=f;a[b+(e+3)|0]=f;a[b+(g+3)|0]=(j+2+(k<<1)+l|0)>>>2;return}function Jna(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;c=d[b-1|0]|0;f=d[b+(e-1)|0]|0;g=e<<1;h=d[b+(g-1)|0]|0;i=e*3|0;j=a[b+(i-1)|0]|0;k=j&255;a[b]=(c+1+f|0)>>>1;a[b+1|0]=(c+2+(f<<1)+h|0)>>>2;c=(f+1+h|0)>>>1&255;a[b+e|0]=c;a[b+2|0]=c;c=(f+2+(h<<1)+k|0)>>>2&255;a[b+(e+1)|0]=c;a[b+3|0]=c;c=(h+1+k|0)>>>1&255;a[b+g|0]=c;a[b+(e+2)|0]=c;c=(h+2+k+(k<<1)|0)>>>2&255;a[b+(g|1)|0]=c;a[b+(e+3)|0]=c;a[b+(i+3)|0]=j;a[b+(i+2)|0]=j;a[b+(g+2)|0]=j;a[b+i|0]=j;a[b+(i+1)|0]=j;a[b+(g+3)|0]=j;return}function Kna(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;b=e<<1;f=e*3|0;g=ba(((d[a-1|0]|0)+2+(d[a+(e-1)|0]|0)+(d[a+(b-1)|0]|0)+(d[a+(f-1)|0]|0)|0)>>>2,16843009)|0;c[a>>2]=g;c[a+e>>2]=g;c[a+b>>2]=g;c[a+f>>2]=g;return}function Lna(a,b,e){a=a|0;b=b|0;e=e|0;b=ba(((d[a+(-e|0)|0]|0)+2+(d[a+(1-e)|0]|0)+(d[a+(2-e)|0]|0)+(d[a+(3-e)|0]|0)|0)>>>2,16843009)|0;c[a>>2]=b;c[a+e>>2]=b;c[a+(e<<1)>>2]=b;c[a+(e*3|0)>>2]=b;return}function Mna(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=-2139062144;c[a+d>>2]=-2139062144;c[a+(d<<1)>>2]=-2139062144;c[a+(d*3|0)>>2]=-2139062144;return}function Nna(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=2139062143;c[a+d>>2]=2139062143;c[a+(d<<1)>>2]=2139062143;c[a+(d*3|0)>>2]=2139062143;return}function Ona(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=-2122219135;c[a+d>>2]=-2122219135;c[a+(d<<1)>>2]=-2122219135;c[a+(d*3|0)>>2]=-2122219135;return}function Pna(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=-g|0;i=d[b+h|0]|0;j=d[b+(1-g)|0]|0;k=d[b+(2-g)|0]|0;l=d[b+(3-g)|0]|0;m=d[b+(4-g)|0]|0;n=d[b+(5-g)|0]|0;o=d[b+(6-g)|0]|0;p=a[b+(7-g)|0]|0;q=p&255;if((f|0)==0){r=p}else{r=a[b+(8-g)|0]|0}a[b]=((d[b+((e|0)==0?h:~g)|0]|0)+2+(i<<1)+j|0)>>>2;a[b+1|0]=(i+2+(j<<1)+k|0)>>>2;a[b+2|0]=(j+2+(k<<1)+l|0)>>>2;a[b+3|0]=(k+2+(l<<1)+m|0)>>>2;k=b+4|0;a[k]=(l+2+(m<<1)+n|0)>>>2;a[b+5|0]=(m+2+(n<<1)+o|0)>>>2;a[b+6|0]=(n+2+(o<<1)+q|0)>>>2;a[b+7|0]=((r&255)+2+(q<<1)+o|0)>>>2;o=c[b>>2]|0;q=c[k>>2]|0;c[b+g>>2]=o;c[b+(g+4)>>2]=q;k=g<<1;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g*3|0;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g<<2;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g*5|0;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g*6|0;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g*7|0;c[b+k>>2]=o;c[b+(k+4)>>2]=q;return}function Qna(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((b|0)==0){b=a-1|0;g=b;h=b}else{g=a+~f|0;h=a-1|0}b=d[h]|0;h=d[a+(f-1)|0]|0;e=f<<1;i=d[a+(e-1)|0]|0;j=f*3|0;k=d[a+(j-1)|0]|0;l=f<<2;m=d[a+(l-1)|0]|0;n=f*5|0;o=d[a+(n-1)|0]|0;p=f*6|0;q=d[a+(p-1)|0]|0;r=f*7|0;s=d[a+(r-1)|0]|0;t=ba(((d[g]|0)+2+(b<<1)+h|0)>>>2,16843009)|0;c[a>>2]=t;c[a+4>>2]=t;t=ba((b+2+(h<<1)+i|0)>>>2,16843009)|0;c[a+f>>2]=t;c[a+(f+4)>>2]=t;t=ba((h+2+(i<<1)+k|0)>>>2,16843009)|0;c[a+e>>2]=t;c[a+(e+4)>>2]=t;t=ba((i+2+(k<<1)+m|0)>>>2,16843009)|0;c[a+j>>2]=t;c[a+(j+4)>>2]=t;t=ba((k+2+(m<<1)+o|0)>>>2,16843009)|0;c[a+l>>2]=t;c[a+(l+4)>>2]=t;t=ba((m+2+(o<<1)+q|0)>>>2,16843009)|0;c[a+n>>2]=t;c[a+(n+4)>>2]=t;t=ba((o+2+(q<<1)+s|0)>>>2,16843009)|0;c[a+p>>2]=t;c[a+(p+4)>>2]=t;t=ba((q+2+(s*3|0)|0)>>>2,16843009)|0;c[a+r>>2]=t;c[a+(r+4)>>2]=t;return}function Rna(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=(e|0)!=0;if(h){e=~g;i=b+e|0;j=b-1|0;k=e}else{e=b-1|0;i=e;j=e;k=~g}e=d[j]|0;j=d[b+(g-1)|0]|0;l=d[b+((g<<1)-1)|0]|0;m=d[b+((g*3|0)-1)|0]|0;n=d[b+((g<<2)-1)|0]|0;o=d[b+((g*5|0)-1)|0]|0;p=d[b+((g*6|0)-1)|0]|0;q=d[b+((g*7|0)-1)|0]|0;r=-g|0;s=d[b+r|0]|0;t=d[b+(1-g)|0]|0;u=d[b+(2-g)|0]|0;v=d[b+(3-g)|0]|0;w=d[b+(4-g)|0]|0;x=d[b+(5-g)|0]|0;y=d[b+(6-g)|0]|0;z=a[b+(7-g)|0]|0;A=z&255;if((f|0)==0){B=z}else{B=a[b+(8-g)|0]|0}z=ba((((d[i]|0)+2+(e<<1)+j|0)>>>2)+8+((e+2+(j<<1)+l|0)>>>2)+((j+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q*3|0)|0)>>>2)+(((d[b+(h?k:r)|0]|0)+2+(s<<1)+t|0)>>>2)+((s+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+A|0)>>>2)+(((B&255)+2+(A<<1)+y|0)>>>2)>>4,16843009)|0;c[b>>2]=z;c[b+4>>2]=z;c[b+g>>2]=z;c[b+(g+4)>>2]=z;y=g<<1;c[b+y>>2]=z;c[b+(y+4)>>2]=z;A=y+g|0;c[b+A>>2]=z;c[b+(A+4)>>2]=z;y=A+g|0;c[b+y>>2]=z;c[b+(y+4)>>2]=z;A=y+g|0;c[b+A>>2]=z;c[b+(A+4)>>2]=z;y=A+g|0;c[b+y>>2]=z;c[b+(y+4)>>2]=z;A=y+g|0;c[b+A>>2]=z;c[b+(A+4)>>2]=z;return}function Sna(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=-f|0;h=d[b+g|0]|0;i=d[b+(1-f)|0]|0;j=d[b+(2-f)|0]|0;k=(h+2+(i<<1)+j|0)>>>2;l=d[b+(3-f)|0]|0;m=(i+2+(j<<1)+l|0)>>>2;n=d[b+(4-f)|0]|0;o=(j+2+(l<<1)+n|0)>>>2;j=d[b+(5-f)|0]|0;p=(l+2+(n<<1)+j|0)>>>2;l=d[b+(6-f)|0]|0;q=(n+2+(j<<1)+l|0)>>>2;n=a[b+(7-f)|0]|0;r=n&255;s=(j+2+(l<<1)+r|0)>>>2;if((e|0)==0){t=r;u=r;v=r;w=r;x=r;y=r;z=r;A=r;B=(n&255)+2+(r<<1)|0}else{n=d[b+(8-f)|0]|0;e=d[b+(9-f)|0]|0;j=d[b+(10-f)|0]|0;C=d[b+(11-f)|0]|0;D=d[b+(12-f)|0]|0;E=d[b+(13-f)|0]|0;F=d[b+(14-f)|0]|0;G=d[b+(15-f)|0]|0;t=(F+2+(G*3|0)|0)>>>2;u=(E+2+(F<<1)+G|0)>>>2;v=(D+2+(E<<1)+F|0)>>>2;w=(C+2+(D<<1)+E|0)>>>2;x=(j+2+(C<<1)+D|0)>>>2;y=(e+2+(j<<1)+C|0)>>>2;z=(n+2+(e<<1)+j|0)>>>2;A=(r+2+(n<<1)+e|0)>>>2;B=(d[b+(8-f)|0]|0)+2+(r<<1)|0}r=(B+l|0)>>>2;a[b]=((((d[b+((c|0)==0?g:~f)|0]|0)+2+(h<<1)+i|0)>>>2)+2+(k<<1)+m|0)>>>2;i=(k+2+(m<<1)+o|0)>>>2&255;a[b+1|0]=i;a[b+f|0]=i;i=(m+2+(o<<1)+p|0)>>>2&255;a[b+2|0]=i;a[b+(f+1)|0]=i;m=f<<1;a[b+m|0]=i;i=(o+2+(p<<1)+q|0)>>>2&255;a[b+3|0]=i;a[b+(f+2)|0]=i;a[b+(m|1)|0]=i;o=f*3|0;a[b+o|0]=i;i=(p+2+(q<<1)+s|0)>>>2&255;a[b+4|0]=i;a[b+(f+3)|0]=i;a[b+(m+2)|0]=i;a[b+(o+1)|0]=i;p=f<<2;a[b+p|0]=i;i=(q+2+(s<<1)+r|0)>>>2&255;a[b+5|0]=i;a[b+(f+4)|0]=i;a[b+(m+3)|0]=i;a[b+(o+2)|0]=i;a[b+(p|1)|0]=i;q=f*5|0;a[b+q|0]=i;i=(s+2+(r<<1)+A|0)>>>2&255;a[b+6|0]=i;a[b+(f+5)|0]=i;a[b+(m+4)|0]=i;a[b+(o+3)|0]=i;a[b+(p|2)|0]=i;a[b+(q+1)|0]=i;s=f*6|0;a[b+s|0]=i;i=(r+2+(A<<1)+z|0)>>>2&255;a[b+7|0]=i;a[b+(f+6)|0]=i;a[b+(m+5)|0]=i;a[b+(o+4)|0]=i;a[b+(p|3)|0]=i;a[b+(q+2)|0]=i;a[b+(s|1)|0]=i;r=f*7|0;a[b+r|0]=i;i=(A+2+(z<<1)+y|0)>>>2&255;a[b+(f+7)|0]=i;a[b+(m+6)|0]=i;a[b+(o+5)|0]=i;a[b+(p+4)|0]=i;a[b+(q+3)|0]=i;a[b+(s+2)|0]=i;a[b+(r+1)|0]=i;i=(z+2+(y<<1)+x|0)>>>2&255;a[b+(m+7)|0]=i;a[b+(o+6)|0]=i;a[b+(p+5)|0]=i;a[b+(q+4)|0]=i;a[b+(s+3)|0]=i;a[b+(r+2)|0]=i;i=(y+2+(x<<1)+w|0)>>>2&255;a[b+(o+7)|0]=i;a[b+(p+6)|0]=i;a[b+(q+5)|0]=i;a[b+(s+4)|0]=i;a[b+(r+3)|0]=i;i=(x+2+(w<<1)+v|0)>>>2&255;a[b+(p+7)|0]=i;a[b+(q+6)|0]=i;a[b+(s+5)|0]=i;a[b+(r+4)|0]=i;i=(w+2+(v<<1)+u|0)>>>2&255;a[b+(q+7)|0]=i;a[b+(s+6)|0]=i;a[b+(r+5)|0]=i;i=(v+2+(u<<1)+t|0)>>>2&255;a[b+(s+7)|0]=i;a[b+(r+6)|0]=i;a[b+(r+7)|0]=(u+2+(t*3|0)|0)>>>2;return}function Tna(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=(c|0)!=0;c=-f|0;h=~f;i=d[b+c|0]|0;j=d[b+(1-f)|0]|0;k=((d[b+(g?h:c)|0]|0)+2+(i<<1)+j|0)>>>2;c=d[b+(2-f)|0]|0;l=(i+2+(j<<1)+c|0)>>>2;m=d[b+(3-f)|0]|0;n=(j+2+(c<<1)+m|0)>>>2;j=d[b+(4-f)|0]|0;o=(c+2+(m<<1)+j|0)>>>2;c=d[b+(5-f)|0]|0;p=(m+2+(j<<1)+c|0)>>>2;m=d[b+(6-f)|0]|0;q=(j+2+(c<<1)+m|0)>>>2;j=a[b+(7-f)|0]|0;r=j&255;s=(c+2+(m<<1)+r|0)>>>2;if((e|0)==0){t=j}else{t=a[b+(8-f)|0]|0}if(g){g=b+h|0;u=g;v=b-1|0;w=g}else{g=b-1|0;u=g;v=g;w=b+h|0}h=d[v]|0;v=d[b+(f-1)|0]|0;g=((d[u]|0)+2+(h<<1)+v|0)>>>2;u=f<<1;j=d[b+(u-1)|0]|0;e=h+2|0;h=(e+(v<<1)+j|0)>>>2;c=f*3|0;x=d[b+(c-1)|0]|0;y=(v+2+(j<<1)+x|0)>>>2;v=f<<2;z=d[b+(v-1)|0]|0;A=(j+2+(x<<1)+z|0)>>>2;j=f*5|0;B=d[b+(j-1)|0]|0;C=(x+2+(z<<1)+B|0)>>>2;x=f*6|0;D=d[b+(x-1)|0]|0;E=(z+2+(B<<1)+D|0)>>>2;z=f*7|0;F=d[b+(z-1)|0]|0;G=(B+2+(D<<1)+F|0)>>>2;B=(e+((d[w]|0)<<1)+i|0)>>>2;a[b+z|0]=(E+2+((D+2+(F*3|0)|0)>>>2)+(G<<1)|0)>>>2;F=(C+2+(E<<1)+G|0)>>>2&255;a[b+(z+1)|0]=F;a[b+x|0]=F;F=(A+2+(C<<1)+E|0)>>>2&255;a[b+(z+2)|0]=F;a[b+(x|1)|0]=F;a[b+j|0]=F;F=(y+2+(A<<1)+C|0)>>>2&255;a[b+(z+3)|0]=F;a[b+(x+2)|0]=F;a[b+(j+1)|0]=F;a[b+v|0]=F;F=(h+2+(y<<1)+A|0)>>>2&255;a[b+(z+4)|0]=F;a[b+(x+3)|0]=F;a[b+(j+2)|0]=F;a[b+(v|1)|0]=F;a[b+c|0]=F;F=(g+2+(h<<1)+y|0)>>>2&255;a[b+(z+5)|0]=F;a[b+(x+4)|0]=F;a[b+(j+3)|0]=F;a[b+(v|2)|0]=F;a[b+(c+1)|0]=F;a[b+u|0]=F;F=((g<<1)+2+h+B|0)>>>2&255;a[b+(z+6)|0]=F;a[b+(x+5)|0]=F;a[b+(j+4)|0]=F;a[b+(v|3)|0]=F;a[b+(c+2)|0]=F;a[b+(u|1)|0]=F;a[b+f|0]=F;F=k+2|0;h=(F+g+(B<<1)|0)>>>2&255;a[b+(z+7)|0]=h;a[b+(x+6)|0]=h;a[b+(j+5)|0]=h;a[b+(v+4)|0]=h;a[b+(c+3)|0]=h;a[b+(u+2)|0]=h;a[b+(f+1)|0]=h;a[b]=h;h=((k<<1)+2+l+B|0)>>>2&255;a[b+(x+7)|0]=h;a[b+(j+6)|0]=h;a[b+(v+5)|0]=h;a[b+(c+4)|0]=h;a[b+(u+3)|0]=h;a[b+(f+2)|0]=h;a[b+1|0]=h;h=(F+(l<<1)+n|0)>>>2&255;a[b+(j+7)|0]=h;a[b+(v+6)|0]=h;a[b+(c+5)|0]=h;a[b+(u+4)|0]=h;a[b+(f+3)|0]=h;a[b+2|0]=h;h=(l+2+(n<<1)+o|0)>>>2&255;a[b+(v+7)|0]=h;a[b+(c+6)|0]=h;a[b+(u+5)|0]=h;a[b+(f+4)|0]=h;a[b+3|0]=h;h=(n+2+(o<<1)+p|0)>>>2&255;a[b+(c+7)|0]=h;a[b+(u+6)|0]=h;a[b+(f+5)|0]=h;a[b+4|0]=h;h=(o+2+(p<<1)+q|0)>>>2&255;a[b+(u+7)|0]=h;a[b+(f+6)|0]=h;a[b+5|0]=h;h=(p+2+(q<<1)+s|0)>>>2&255;a[b+(f+7)|0]=h;a[b+6|0]=h;a[b+7|0]=(q+2+(s<<1)+(((t&255)+2+(r<<1)+m|0)>>>2)|0)>>>2;return}function Una(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=(c|0)!=0;c=-f|0;h=~f;i=d[b+c|0]|0;j=d[b+(1-f)|0]|0;k=((d[b+(g?h:c)|0]|0)+2+(i<<1)+j|0)>>>2;c=d[b+(2-f)|0]|0;l=(i+2+(j<<1)+c|0)>>>2;m=d[b+(3-f)|0]|0;n=(j+2+(c<<1)+m|0)>>>2;j=d[b+(4-f)|0]|0;o=(c+2+(m<<1)+j|0)>>>2;c=d[b+(5-f)|0]|0;p=(m+2+(j<<1)+c|0)>>>2;m=d[b+(6-f)|0]|0;q=(j+2+(c<<1)+m|0)>>>2;j=a[b+(7-f)|0]|0;r=j&255;s=(c+2+(m<<1)+r|0)>>>2;if((e|0)==0){t=j}else{t=a[b+(8-f)|0]|0}j=((t&255)+2+(r<<1)+m|0)>>>2;if(g){g=b+h|0;u=g;v=b-1|0;w=g}else{g=b-1|0;u=g;v=g;w=b+h|0}h=d[v]|0;v=d[b+(f-1)|0]|0;g=((d[u]|0)+2+(h<<1)+v|0)>>>2;u=f<<1;m=d[b+(u-1)|0]|0;r=h+2|0;h=(r+(v<<1)+m|0)>>>2;t=f*3|0;e=d[b+(t-1)|0]|0;c=(v+2+(m<<1)+e|0)>>>2;v=f<<2;x=d[b+(v-1)|0]|0;y=(m+2+(e<<1)+x|0)>>>2;m=f*5|0;z=d[b+(m-1)|0]|0;A=(e+2+(x<<1)+z|0)>>>2;e=f*6|0;B=d[b+(e-1)|0]|0;C=(x+2+(z<<1)+B|0)>>>2;x=f*7|0;D=(z+2+(B<<1)+(d[b+(x-1)|0]|0)|0)>>>2;B=(r+((d[w]|0)<<1)+i|0)>>>2;a[b+e|0]=(y+2+(A<<1)+C|0)>>>2;a[b+x|0]=(A+2+(C<<1)+D|0)>>>2;D=(h+2+(c<<1)+y|0)>>>2&255;a[b+(e|1)|0]=D;a[b+v|0]=D;D=(c+2+(y<<1)+A|0)>>>2&255;a[b+(x+1)|0]=D;a[b+m|0]=D;D=((g<<1)+2+h+B|0)>>>2&255;a[b+(e+2)|0]=D;a[b+(v|1)|0]=D;a[b+u|0]=D;D=(g+2+(h<<1)+c|0)>>>2&255;a[b+(x+2)|0]=D;a[b+(m+1)|0]=D;a[b+t|0]=D;D=k+2|0;c=(D+g+(B<<1)|0)>>>2&255;a[b+(x+3)|0]=c;a[b+(m+2)|0]=c;a[b+(t+1)|0]=c;a[b+f|0]=c;c=k+1|0;g=(c+B|0)>>>1&255;a[b+(e+3)|0]=g;a[b+(v|2)|0]=g;a[b+(u|1)|0]=g;a[b]=g;g=((k<<1)+2+l+B|0)>>>2&255;a[b+(x+4)|0]=g;a[b+(m+3)|0]=g;a[b+(t+2)|0]=g;a[b+(f+1)|0]=g;g=(c+l|0)>>>1&255;a[b+(e+4)|0]=g;a[b+(v|3)|0]=g;a[b+(u+2)|0]=g;a[b+1|0]=g;g=(D+(l<<1)+n|0)>>>2&255;a[b+(x+5)|0]=g;a[b+(m+4)|0]=g;a[b+(t+3)|0]=g;a[b+(f+2)|0]=g;g=(l+1+n|0)>>>1&255;a[b+(e+5)|0]=g;a[b+(v+4)|0]=g;a[b+(u+3)|0]=g;a[b+2|0]=g;g=(l+2+(n<<1)+o|0)>>>2&255;a[b+(x+6)|0]=g;a[b+(m+5)|0]=g;a[b+(t+4)|0]=g;a[b+(f+3)|0]=g;g=(n+1+o|0)>>>1&255;a[b+(e+6)|0]=g;a[b+(v+5)|0]=g;a[b+(u+4)|0]=g;a[b+3|0]=g;g=(n+2+(o<<1)+p|0)>>>2&255;a[b+(x+7)|0]=g;a[b+(m+6)|0]=g;a[b+(t+5)|0]=g;a[b+(f+4)|0]=g;g=(o+1+p|0)>>>1&255;a[b+(e+7)|0]=g;a[b+(v+6)|0]=g;a[b+(u+5)|0]=g;a[b+4|0]=g;g=(o+2+(p<<1)+q|0)>>>2&255;a[b+(m+7)|0]=g;a[b+(t+6)|0]=g;a[b+(f+5)|0]=g;g=(p+1+q|0)>>>1&255;a[b+(v+7)|0]=g;a[b+(u+6)|0]=g;a[b+5|0]=g;g=(p+2+(q<<1)+s|0)>>>2&255;a[b+(t+7)|0]=g;a[b+(f+6)|0]=g;g=(q+1+s|0)>>>1&255;a[b+(u+7)|0]=g;a[b+6|0]=g;a[b+(f+7)|0]=(q+2+(s<<1)+j|0)>>>2;a[b+7|0]=(s+1+j|0)>>>1;return}function Vna(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=(c|0)!=0;c=-f|0;g=~f;h=d[b+c|0]|0;i=d[b+(1-f)|0]|0;j=((d[b+(e?g:c)|0]|0)+2+(h<<1)+i|0)>>>2;c=d[b+(2-f)|0]|0;k=(h+2+(i<<1)+c|0)>>>2;l=d[b+(3-f)|0]|0;m=(i+2+(c<<1)+l|0)>>>2;i=d[b+(4-f)|0]|0;n=(c+2+(l<<1)+i|0)>>>2;c=d[b+(5-f)|0]|0;o=(l+2+(i<<1)+c|0)>>>2;l=d[b+(6-f)|0]|0;p=(i+2+(c<<1)+l|0)>>>2;i=(c+2+(l<<1)+(d[b+(7-f)|0]|0)|0)>>>2;if(e){e=b+g|0;q=e;r=b-1|0;s=e}else{e=b-1|0;q=e;r=e;s=b+g|0}g=d[r]|0;r=d[b+(f-1)|0]|0;e=((d[q]|0)+2+(g<<1)+r|0)>>>2;q=f<<1;l=d[b+(q-1)|0]|0;c=g+2|0;g=(c+(r<<1)+l|0)>>>2;t=f*3|0;u=d[b+(t-1)|0]|0;v=(r+2+(l<<1)+u|0)>>>2;r=f<<2;w=d[b+(r-1)|0]|0;x=(l+2+(u<<1)+w|0)>>>2;l=f*5|0;y=d[b+(l-1)|0]|0;z=(u+2+(w<<1)+y|0)>>>2;u=f*6|0;A=d[b+(u-1)|0]|0;B=(w+2+(y<<1)+A|0)>>>2;w=f*7|0;C=d[b+(w-1)|0]|0;D=(y+2+(A<<1)+C|0)>>>2;y=(A+2+(C*3|0)|0)>>>2;C=(c+((d[s]|0)<<1)+h|0)>>>2;a[b+w|0]=(y+1+D|0)>>>1;a[b+(w+1)|0]=(B+2+y+(D<<1)|0)>>>2;y=(B+1+D|0)>>>1&255;a[b+(w+2)|0]=y;a[b+u|0]=y;y=(z+2+(B<<1)+D|0)>>>2&255;a[b+(w+3)|0]=y;a[b+(u|1)|0]=y;y=(z+1+B|0)>>>1&255;a[b+(w+4)|0]=y;a[b+(u+2)|0]=y;a[b+l|0]=y;y=(x+2+(z<<1)+B|0)>>>2&255;a[b+(w+5)|0]=y;a[b+(u+3)|0]=y;a[b+(l+1)|0]=y;y=(x+1+z|0)>>>1&255;a[b+(w+6)|0]=y;a[b+(u+4)|0]=y;a[b+(l+2)|0]=y;a[b+r|0]=y;y=(v+2+(x<<1)+z|0)>>>2&255;a[b+(w+7)|0]=y;a[b+(u+5)|0]=y;a[b+(l+3)|0]=y;a[b+(r|1)|0]=y;y=(v+1+x|0)>>>1&255;a[b+(u+6)|0]=y;a[b+(l+4)|0]=y;a[b+(r|2)|0]=y;a[b+t|0]=y;y=(g+2+(v<<1)+x|0)>>>2&255;a[b+(u+7)|0]=y;a[b+(l+5)|0]=y;a[b+(r|3)|0]=y;a[b+(t+1)|0]=y;y=(g+1+v|0)>>>1&255;a[b+(l+6)|0]=y;a[b+(r+4)|0]=y;a[b+(t+2)|0]=y;a[b+q|0]=y;y=(e+2+(g<<1)+v|0)>>>2&255;a[b+(l+7)|0]=y;a[b+(r+5)|0]=y;a[b+(t+3)|0]=y;a[b+(q|1)|0]=y;y=e+1|0;l=(y+g|0)>>>1&255;a[b+(r+6)|0]=l;a[b+(t+4)|0]=l;a[b+(q+2)|0]=l;a[b+f|0]=l;l=((e<<1)+2+g+C|0)>>>2&255;a[b+(r+7)|0]=l;a[b+(t+5)|0]=l;a[b+(q+3)|0]=l;a[b+(f+1)|0]=l;l=(y+C|0)>>>1&255;a[b+(t+6)|0]=l;a[b+(q+4)|0]=l;a[b+(f+2)|0]=l;a[b]=l;l=j+2|0;y=(l+e+(C<<1)|0)>>>2&255;a[b+(t+7)|0]=y;a[b+(q+5)|0]=y;a[b+(f+3)|0]=y;a[b+1|0]=y;y=((j<<1)+2+k+C|0)>>>2&255;a[b+(q+6)|0]=y;a[b+(f+4)|0]=y;a[b+2|0]=y;y=(l+(k<<1)+m|0)>>>2&255;a[b+(q+7)|0]=y;a[b+(f+5)|0]=y;a[b+3|0]=y;y=(k+2+(m<<1)+n|0)>>>2&255;a[b+(f+6)|0]=y;a[b+4|0]=y;y=(m+2+(n<<1)+o|0)>>>2&255;a[b+(f+7)|0]=y;a[b+5|0]=y;a[b+6|0]=(n+2+(o<<1)+p|0)>>>2;a[b+7|0]=(o+2+(p<<1)+i|0)>>>2;return}function Wna(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=-f|0;h=d[b+g|0]|0;i=d[b+(1-f)|0]|0;j=((d[b+((c|0)==0?g:~f)|0]|0)+2+(h<<1)+i|0)>>>2;g=d[b+(2-f)|0]|0;c=(h+2+(i<<1)+g|0)>>>2;h=d[b+(3-f)|0]|0;k=(i+2+(g<<1)+h|0)>>>2;i=d[b+(4-f)|0]|0;l=(g+2+(h<<1)+i|0)>>>2;g=d[b+(5-f)|0]|0;m=(h+2+(i<<1)+g|0)>>>2;h=d[b+(6-f)|0]|0;n=(i+2+(g<<1)+h|0)>>>2;i=a[b+(7-f)|0]|0;o=i&255;p=(g+2+(h<<1)+o|0)>>>2;if((e|0)==0){q=o;r=o;s=o;t=o;u=o;v=(i&255)+2+(o<<1)|0}else{i=d[b+(8-f)|0]|0;e=d[b+(9-f)|0]|0;g=d[b+(10-f)|0]|0;w=d[b+(11-f)|0]|0;x=d[b+(12-f)|0]|0;q=(w+2+(x<<1)+(d[b+(13-f)|0]|0)|0)>>>2;r=(g+2+(w<<1)+x|0)>>>2;s=(e+2+(g<<1)+w|0)>>>2;t=(i+2+(e<<1)+g|0)>>>2;u=(o+2+(i<<1)+e|0)>>>2;v=(d[b+(8-f)|0]|0)+2+(o<<1)|0}o=(v+h|0)>>>2;a[b]=(j+1+c|0)>>>1;a[b+f|0]=(j+2+(c<<1)+k|0)>>>2;j=(c+1+k|0)>>>1&255;a[b+1|0]=j;h=f<<1;a[b+h|0]=j;j=(c+2+(k<<1)+l|0)>>>2&255;a[b+(f+1)|0]=j;c=f*3|0;a[b+c|0]=j;j=(k+1+l|0)>>>1&255;a[b+2|0]=j;a[b+(h|1)|0]=j;v=f<<2;a[b+v|0]=j;j=(k+2+(l<<1)+m|0)>>>2&255;a[b+(f+2)|0]=j;a[b+(c+1)|0]=j;k=f*5|0;a[b+k|0]=j;j=(l+1+m|0)>>>1&255;a[b+3|0]=j;a[b+(h+2)|0]=j;a[b+(v|1)|0]=j;e=f*6|0;a[b+e|0]=j;j=(l+2+(m<<1)+n|0)>>>2&255;a[b+(f+3)|0]=j;a[b+(c+2)|0]=j;a[b+(k+1)|0]=j;l=f*7|0;a[b+l|0]=j;j=(m+1+n|0)>>>1&255;a[b+4|0]=j;a[b+(h+3)|0]=j;a[b+(v|2)|0]=j;a[b+(e|1)|0]=j;j=(m+2+(n<<1)+p|0)>>>2&255;a[b+(f+4)|0]=j;a[b+(c+3)|0]=j;a[b+(k+2)|0]=j;a[b+(l+1)|0]=j;j=(n+1+p|0)>>>1&255;a[b+5|0]=j;a[b+(h+4)|0]=j;a[b+(v|3)|0]=j;a[b+(e+2)|0]=j;j=(n+2+(p<<1)+o|0)>>>2&255;a[b+(f+5)|0]=j;a[b+(c+4)|0]=j;a[b+(k+3)|0]=j;a[b+(l+2)|0]=j;j=(p+1+o|0)>>>1&255;a[b+6|0]=j;a[b+(h+5)|0]=j;a[b+(v+4)|0]=j;a[b+(e+3)|0]=j;j=(p+2+(o<<1)+u|0)>>>2&255;a[b+(f+6)|0]=j;a[b+(c+5)|0]=j;a[b+(k+4)|0]=j;a[b+(l+3)|0]=j;j=(o+1+u|0)>>>1&255;a[b+7|0]=j;a[b+(h+6)|0]=j;a[b+(v+5)|0]=j;a[b+(e+4)|0]=j;j=(o+2+(u<<1)+t|0)>>>2&255;a[b+(f+7)|0]=j;a[b+(c+6)|0]=j;a[b+(k+5)|0]=j;a[b+(l+4)|0]=j;j=(u+1+t|0)>>>1&255;a[b+(h+7)|0]=j;a[b+(v+6)|0]=j;a[b+(e+5)|0]=j;j=(u+2+(t<<1)+s|0)>>>2&255;a[b+(c+7)|0]=j;a[b+(k+6)|0]=j;a[b+(l+5)|0]=j;j=(t+1+s|0)>>>1&255;a[b+(v+7)|0]=j;a[b+(e+6)|0]=j;j=(t+2+(s<<1)+r|0)>>>2&255;a[b+(k+7)|0]=j;a[b+(l+6)|0]=j;a[b+(e+7)|0]=(s+1+r|0)>>>1;a[b+(l+7)|0]=(s+2+(r<<1)+q|0)>>>2;return}function Xna(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c|0)==0){c=b-1|0;g=c;h=c}else{g=b+~f|0;h=b-1|0}c=d[h]|0;h=d[b+(f-1)|0]|0;e=((d[g]|0)+2+(c<<1)+h|0)>>>2;g=f<<1;i=d[b+(g-1)|0]|0;j=(c+2+(h<<1)+i|0)>>>2;c=f*3|0;k=d[b+(c-1)|0]|0;l=(h+2+(i<<1)+k|0)>>>2;h=f<<2;m=d[b+(h-1)|0]|0;n=(i+2+(k<<1)+m|0)>>>2;i=f*5|0;o=d[b+(i-1)|0]|0;p=(k+2+(m<<1)+o|0)>>>2;k=f*6|0;q=d[b+(k-1)|0]|0;r=(m+2+(o<<1)+q|0)>>>2;m=f*7|0;s=d[b+(m-1)|0]|0;t=(o+2+(q<<1)+s|0)>>>2;o=(q+2+(s*3|0)|0)>>>2;a[b]=(e+1+j|0)>>>1;a[b+1|0]=(e+2+(j<<1)+l|0)>>>2;e=(j+1+l|0)>>>1&255;a[b+2|0]=e;a[b+f|0]=e;e=(j+2+(l<<1)+n|0)>>>2&255;a[b+3|0]=e;a[b+(f+1)|0]=e;e=(l+1+n|0)>>>1&255;a[b+4|0]=e;a[b+(f+2)|0]=e;a[b+g|0]=e;e=(l+2+(n<<1)+p|0)>>>2&255;a[b+5|0]=e;a[b+(f+3)|0]=e;a[b+(g|1)|0]=e;e=(n+1+p|0)>>>1&255;a[b+6|0]=e;a[b+(f+4)|0]=e;a[b+(g+2)|0]=e;a[b+c|0]=e;e=(n+2+(p<<1)+r|0)>>>2&255;a[b+7|0]=e;a[b+(f+5)|0]=e;a[b+(g+3)|0]=e;a[b+(c+1)|0]=e;e=(p+1+r|0)>>>1&255;a[b+(f+6)|0]=e;a[b+(g+4)|0]=e;a[b+(c+2)|0]=e;a[b+h|0]=e;e=(p+2+(r<<1)+t|0)>>>2&255;a[b+(f+7)|0]=e;a[b+(g+5)|0]=e;a[b+(c+3)|0]=e;a[b+(h|1)|0]=e;e=(r+1+t|0)>>>1&255;a[b+(g+6)|0]=e;a[b+(c+4)|0]=e;a[b+(h|2)|0]=e;a[b+i|0]=e;e=(r+2+o+(t<<1)|0)>>>2&255;a[b+(g+7)|0]=e;a[b+(c+5)|0]=e;a[b+(h|3)|0]=e;a[b+(i+1)|0]=e;e=(o+1+t|0)>>>1&255;a[b+(c+6)|0]=e;a[b+(h+4)|0]=e;a[b+(i+2)|0]=e;a[b+k|0]=e;e=(t+2+(o*3|0)|0)>>>2&255;a[b+(c+7)|0]=e;a[b+(h+5)|0]=e;a[b+(i+3)|0]=e;a[b+(k|1)|0]=e;e=o&255;a[b+(m+7)|0]=e;a[b+(k+7)|0]=e;a[b+(i+7)|0]=e;a[b+(h+7)|0]=e;a[b+(m+6)|0]=e;a[b+(k+6)|0]=e;a[b+(i+6)|0]=e;a[b+(h+6)|0]=e;a[b+(m+5)|0]=e;a[b+(k+5)|0]=e;a[b+(i+5)|0]=e;a[b+(m+4)|0]=e;a[b+(k+4)|0]=e;a[b+(i+4)|0]=e;a[b+(m+3)|0]=e;a[b+(k+3)|0]=e;a[b+(m+2)|0]=e;a[b+(k+2)|0]=e;a[b+(m+1)|0]=e;a[b+m|0]=e;return}function Yna(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((b|0)==0){b=a-1|0;g=b;h=b}else{g=a+~f|0;h=a-1|0}b=d[h]|0;h=d[a+(f-1)|0]|0;e=d[a+((f<<1)-1)|0]|0;i=d[a+((f*3|0)-1)|0]|0;j=d[a+((f<<2)-1)|0]|0;k=d[a+((f*5|0)-1)|0]|0;l=d[a+((f*6|0)-1)|0]|0;m=d[a+((f*7|0)-1)|0]|0;n=ba((((d[g]|0)+2+(b<<1)+h|0)>>>2)+4+((b+2+(h<<1)+e|0)>>>2)+((h+2+(e<<1)+i|0)>>>2)+((e+2+(i<<1)+j|0)>>>2)+((i+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m*3|0)|0)>>>2)>>3,16843009)|0;c[a>>2]=n;c[a+4>>2]=n;c[a+f>>2]=n;c[a+(f+4)>>2]=n;m=f<<1;c[a+m>>2]=n;c[a+(m+4)>>2]=n;l=m+f|0;c[a+l>>2]=n;c[a+(l+4)>>2]=n;m=l+f|0;c[a+m>>2]=n;c[a+(m+4)>>2]=n;l=m+f|0;c[a+l>>2]=n;c[a+(l+4)>>2]=n;m=l+f|0;c[a+m>>2]=n;c[a+(m+4)>>2]=n;l=m+f|0;c[a+l>>2]=n;c[a+(l+4)>>2]=n;return}function Zna(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=-g|0;i=d[b+h|0]|0;j=d[b+(1-g)|0]|0;k=d[b+(2-g)|0]|0;l=d[b+(3-g)|0]|0;m=d[b+(4-g)|0]|0;n=d[b+(5-g)|0]|0;o=d[b+(6-g)|0]|0;p=a[b+(7-g)|0]|0;q=p&255;if((f|0)==0){r=p}else{r=a[b+(8-g)|0]|0}p=ba((((d[b+((e|0)==0?h:~g)|0]|0)+2+(i<<1)+j|0)>>>2)+4+((i+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+q|0)>>>2)+(((r&255)+2+(q<<1)+o|0)>>>2)>>3,16843009)|0;c[b>>2]=p;c[b+4>>2]=p;c[b+g>>2]=p;c[b+(g+4)>>2]=p;o=g<<1;c[b+o>>2]=p;c[b+(o+4)>>2]=p;q=o+g|0;c[b+q>>2]=p;c[b+(q+4)>>2]=p;o=q+g|0;c[b+o>>2]=p;c[b+(o+4)>>2]=p;q=o+g|0;c[b+q>>2]=p;c[b+(q+4)>>2]=p;o=q+g|0;c[b+o>>2]=p;c[b+(o+4)>>2]=p;q=o+g|0;c[b+q>>2]=p;c[b+(q+4)>>2]=p;return}function _na(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;d=e<<1;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;b=d+e|0;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;d=b+e|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;b=d+e|0;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;d=b+e|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;b=d+e|0;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;return}function $na(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+(-b|0)>>2]|0;e=c[a+(4-b)>>2]|0;c[a>>2]=d;c[a+4>>2]=e;c[a+b>>2]=d;c[a+(b+4)>>2]=e;f=b<<1;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*3|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b<<2;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*5|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*6|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*7|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;return}function aoa(a,b){a=a|0;b=b|0;var e=0,f=0;e=ba(d[a-1|0]|0,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;e=ba(d[a+(b-1)|0]|0,16843009)|0;c[a+b>>2]=e;c[a+(b+4)>>2]=e;e=b<<1;f=ba(d[a+(e-1)|0]|0,16843009)|0;c[a+e>>2]=f;c[a+(e+4)>>2]=f;f=b*3|0;e=ba(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;e=b<<2;f=ba(d[a+(e-1)|0]|0,16843009)|0;c[a+e>>2]=f;c[a+(e+4)>>2]=f;f=b*5|0;e=ba(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;e=b*6|0;f=ba(d[a+(e-1)|0]|0,16843009)|0;c[a+e>>2]=f;c[a+(e+4)>>2]=f;f=b*7|0;b=ba(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=b;c[a+(f+4)>>2]=b;return}function boa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+(-b|0)>>2]|0;e=c[a+(4-b)>>2]|0;c[a>>2]=d;c[a+4>>2]=e;c[a+b>>2]=d;c[a+(b+4)>>2]=e;f=b<<1;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*3|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b<<2;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*5|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*6|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*7|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b<<3;c[a+f>>2]=d;c[a+(f|4)>>2]=e;f=b*9|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*10|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*11|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*12|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*13|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*14|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*15|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;return}function coa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=0;do{f=ba(e,b)|0;g=ba(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=g;c[a+(f+4)>>2]=g;e=e+1|0;}while((e|0)<16);return}function doa(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=3-c|0;f=(c<<2)-1|0;g=f-(c<<1)|0;h=f+c|0;i=g-c|0;j=h+c|0;k=i-c|0;l=d[b+(j+c)|0]|0;m=((((d[b+(e+4)|0]|0)-(d[b+(e-4)|0]|0)<<2)+((((d[b+(e+3)|0]|0)-(d[b+(e-3)|0]|0)|0)*3|0)+(((d[b+(e+2)|0]|0)-(d[b+(e-2)|0]|0)<<1)+((d[b+(e+1)|0]|0)-(d[b+(e-1)|0]|0))))|0)*17|0)+16>>5;e=(((l-(d[b+(k-c)|0]|0)<<2)+((((d[b+j|0]|0)-(d[b+k|0]|0)|0)*3|0)+(((d[b+h|0]|0)-(d[b+i|0]|0)<<1)+((d[b+f|0]|0)-(d[b+g|0]|0))))|0)*17|0)+16>>5;g=m<<1;f=m*3|0;i=m<<2;h=m*5|0;k=m*6|0;j=m*7|0;n=b;o=((e+m|0)*-3|0)+16+((d[b+(8-c-1)|0]|0)+l<<4)|0;l=8;while(1){b=o>>5;if(b>>>0>255>>>0){p=-b>>31&255}else{p=b&255}a[n]=p;b=o+m>>5;if(b>>>0>255>>>0){q=-b>>31&255}else{q=b&255}a[n+1|0]=q;b=o+g>>5;if(b>>>0>255>>>0){r=-b>>31&255}else{r=b&255}a[n+2|0]=r;b=o+f>>5;if(b>>>0>255>>>0){s=-b>>31&255}else{s=b&255}a[n+3|0]=s;b=o+i>>5;if(b>>>0>255>>>0){t=-b>>31&255}else{t=b&255}a[n+4|0]=t;b=o+h>>5;if(b>>>0>255>>>0){u=-b>>31&255}else{u=b&255}a[n+5|0]=u;b=o+k>>5;if(b>>>0>255>>>0){v=-b>>31&255}else{v=b&255}a[n+6|0]=v;b=o+j>>5;if(b>>>0>255>>>0){w=-b>>31&255}else{w=b&255}a[n+7|0]=w;b=l-1|0;if((b|0)>0){n=n+c|0;o=o+e|0;l=b}else{break}}return}function eoa(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=3-c|0;f=(c<<3)-1|0;g=f-(c<<1)|0;h=f+c|0;i=g-c|0;j=h+c|0;k=i-c|0;l=(c*11|0)-1+c|0;m=(c*3|0)-1-c|0;n=l+c|0;o=m-c|0;p=n+c|0;q=o-c|0;r=a[b+(p+c)|0]|0;s=((((d[b+(e+4)|0]|0)-(d[b+(e-4)|0]|0)<<2)+((((d[b+(e+3)|0]|0)-(d[b+(e-3)|0]|0)|0)*3|0)+(((d[b+(e+2)|0]|0)-(d[b+(e-2)|0]|0)<<1)+((d[b+(e+1)|0]|0)-(d[b+(e-1)|0]|0))))|0)*17|0)+16>>5;e=((((r&255)-(d[b+(q-c)|0]|0)<<3)+((((d[b+p|0]|0)-(d[b+q|0]|0)|0)*7|0)+((((d[b+n|0]|0)-(d[b+o|0]|0)|0)*6|0)+((((d[b+l|0]|0)-(d[b+m|0]|0)|0)*5|0)+(((d[b+(j+c)|0]|0)-(d[b+(k-c)|0]|0)<<2)+((((d[b+j|0]|0)-(d[b+k|0]|0)|0)*3|0)+(((d[b+h|0]|0)-(d[b+i|0]|0)<<1)+((d[b+f|0]|0)-(d[b+g|0]|0))))))))|0)*5|0)+32>>6;g=s*3|0;f=s<<1;i=s<<2;h=s*5|0;k=s*6|0;j=s*7|0;m=b;l=16-g+(e*-7|0)+((d[b+(7-c)|0]|0)+(r&255)<<4)|0;r=16;while(1){b=l>>5;if(b>>>0>255>>>0){t=-b>>31&255}else{t=b&255}a[m]=t;b=l+s>>5;if(b>>>0>255>>>0){u=-b>>31&255}else{u=b&255}a[m+1|0]=u;b=l+f>>5;if(b>>>0>255>>>0){v=-b>>31&255}else{v=b&255}a[m+2|0]=v;b=l+g>>5;if(b>>>0>255>>>0){w=-b>>31&255}else{w=b&255}a[m+3|0]=w;b=l+i>>5;if(b>>>0>255>>>0){x=-b>>31&255}else{x=b&255}a[m+4|0]=x;b=l+h>>5;if(b>>>0>255>>>0){y=-b>>31&255}else{y=b&255}a[m+5|0]=y;b=l+k>>5;if(b>>>0>255>>>0){z=-b>>31&255}else{z=b&255}a[m+6|0]=z;b=l+j>>5;if(b>>>0>255>>>0){A=-b>>31&255}else{A=b&255}a[m+7|0]=A;b=r-1|0;if((b|0)>0){m=m+c|0;l=l+e|0;r=b}else{break}}return}function foa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b<<2;f=b*5|0;g=b<<1;h=b*6|0;i=b*3|0;j=(d[a+(7-b)|0]|0)+((d[a+(6-b)|0]|0)+((d[a+(5-b)|0]|0)+(d[a+(4-b)|0]|0)))|0;k=b*7|0;l=(d[a+(k-1)|0]|0)+((d[a+(h-1)|0]|0)+((d[a+(f-1)|0]|0)+(d[a+(e-1)|0]|0)))|0;m=ba((d[a+(i-1)|0]|0)+((d[a+(g-1)|0]|0)+((d[a+(b-1)|0]|0)+((d[a-1|0]|0)+(d[a+(-b|0)|0]|0))+(d[a+(1-b)|0]|0))+(d[a+(2-b)|0]|0))+(d[a+(3-b)|0]|0)+4>>3,16843009)|0;n=ba((j+2|0)>>>2,16843009)|0;c[a>>2]=m;c[a+4>>2]=n;c[a+b>>2]=m;c[a+(b+4)>>2]=n;c[a+g>>2]=m;c[a+(g+4)>>2]=n;c[a+i>>2]=m;c[a+(i+4)>>2]=n;n=ba((l+2|0)>>>2,16843009)|0;i=ba(l+4+j>>3,16843009)|0;c[a+e>>2]=n;c[a+(e+4)>>2]=i;c[a+f>>2]=n;c[a+(f+4)>>2]=i;c[a+h>>2]=n;c[a+(h+4)>>2]=i;c[a+k>>2]=n;c[a+(k+4)>>2]=i;return}function goa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b<<2;f=b*5|0;g=b<<1;h=b*6|0;i=b*3|0;j=b*7|0;k=ba(((d[a+(i-1)|0]|0)+((d[a+(g-1)|0]|0)+((d[a+(b-1)|0]|0)+(d[a-1|0]|0)))+2|0)>>>2,16843009)|0;l=((d[a+(j-1)|0]|0)+((d[a+(h-1)|0]|0)+((d[a+(f-1)|0]|0)+(d[a+(e-1)|0]|0)))+2|0)>>>2;c[a>>2]=k;c[a+4>>2]=k;c[a+b>>2]=k;c[a+(b+4)>>2]=k;c[a+g>>2]=k;c[a+(g+4)>>2]=k;c[a+i>>2]=k;c[a+(i+4)>>2]=k;k=ba(l,16843009)|0;c[a+e>>2]=k;c[a+(e+4)>>2]=k;c[a+f>>2]=k;c[a+(f+4)>>2]=k;c[a+h>>2]=k;c[a+(h+4)>>2]=k;c[a+j>>2]=k;c[a+(j+4)>>2]=k;return}function hoa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=4-b|0;f=ba(((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+(d[a+(-b|0)|0]|0)))+2|0)>>>2,16843009)|0;g=ba(((d[a+(e+3)|0]|0)+((d[a+(e+2)|0]|0)+((d[a+(e+1)|0]|0)+(d[a+e|0]|0)))+2|0)>>>2,16843009)|0;c[a>>2]=f;c[a+4>>2]=g;c[a+b>>2]=f;c[a+(b+4)>>2]=g;e=b<<1;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*3|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b<<2;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*5|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*6|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*7|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;return}function ioa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;hoa(a,b);e=b<<1;f=b*3|0;g=ba((d[a+(-b|0)|0]|0)+4+(d[a+(1-b)|0]|0)+(d[a+(2-b)|0]|0)+(d[a+(3-b)|0]|0)+(d[a-1|0]|0)+(d[a+(b-1)|0]|0)+(d[a+(e-1)|0]|0)+(d[a+(f-1)|0]|0)>>3,16843009)|0;c[a>>2]=g;c[a+b>>2]=g;c[a+e>>2]=g;c[a+f>>2]=g;return}function joa(a,b){a=a|0;b=b|0;var e=0;foa(a,b);e=ba(((d[a+(-b|0)|0]|0)+2+(d[a+(1-b)|0]|0)+(d[a+(2-b)|0]|0)+(d[a+(3-b)|0]|0)|0)>>>2,16843009)|0;c[a>>2]=e;c[a+b>>2]=e;c[a+(b<<1)>>2]=e;c[a+(b*3|0)>>2]=e;return}function koa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;goa(a,b);d=b<<2;c[a+d>>2]=-2139062144;c[a+(d+b)>>2]=-2139062144;e=b<<1;c[a+(d+e)>>2]=-2139062144;f=b*3|0;c[a+(d+f)>>2]=-2139062144;g=d+4|0;c[a+g>>2]=-2139062144;c[a+(g+b)>>2]=-2139062144;c[a+(g+e)>>2]=-2139062144;c[a+(g+f)>>2]=-2139062144;return}function loa(a,b){a=a|0;b=b|0;var d=0,e=0;goa(a,b);c[a>>2]=-2139062144;c[a+b>>2]=-2139062144;d=b<<1;c[a+d>>2]=-2139062144;e=b*3|0;c[a+e>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;return}function moa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=0;f=0;g=0;h=0;i=0;j=0;do{k=d[a+((ba(j,b)|0)-1)|0]|0;i=k+i+(d[a+(j-b)|0]|0)|0;k=j+4|0;h=(d[a+(k-b)|0]|0)+h|0;g=(d[a+((ba(k,b)|0)-1)|0]|0)+g|0;f=(d[a+((ba(j+8|0,b)|0)-1)|0]|0)+f|0;e=(d[a+((ba(j+12|0,b)|0)-1)|0]|0)+e|0;j=j+1|0;}while((j|0)<4);j=ba(i+4>>3,16843009)|0;i=ba(h+2>>2,16843009)|0;c[a>>2]=j;c[a+4>>2]=i;c[a+b>>2]=j;c[a+(b+4)>>2]=i;k=b<<1;c[a+k>>2]=j;c[a+(k+4)>>2]=i;k=b*3|0;c[a+k>>2]=j;c[a+(k+4)>>2]=i;i=ba(g+2>>2,16843009)|0;k=ba(g+4+h>>3,16843009)|0;g=ba(f+2>>2,16843009)|0;j=ba(f+4+h>>3,16843009)|0;f=ba(e+2>>2,16843009)|0;l=ba(e+4+h>>3,16843009)|0;h=b<<2;c[a+h>>2]=i;c[a+(h+4)>>2]=k;h=b*5|0;c[a+h>>2]=i;c[a+(h+4)>>2]=k;h=b*6|0;c[a+h>>2]=i;c[a+(h+4)>>2]=k;h=b*7|0;c[a+h>>2]=i;c[a+(h+4)>>2]=k;k=b<<3;c[a+k>>2]=g;c[a+(k|4)>>2]=j;k=b*9|0;c[a+k>>2]=g;c[a+(k+4)>>2]=j;k=b*10|0;c[a+k>>2]=g;c[a+(k+4)>>2]=j;k=b*11|0;c[a+k>>2]=g;c[a+(k+4)>>2]=j;j=b*12|0;c[a+j>>2]=f;c[a+(j+4)>>2]=l;j=b*13|0;c[a+j>>2]=f;c[a+(j+4)>>2]=l;j=b*14|0;c[a+j>>2]=f;c[a+(j+4)>>2]=l;j=b*15|0;c[a+j>>2]=f;c[a+(j+4)>>2]=l;return}function noa(a,b){a=a|0;b=b|0;goa(a,b);goa(a+(b<<3)|0,b);return}function ooa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=4-b|0;f=ba(((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+(d[a+(-b|0)|0]|0)))+2|0)>>>2,16843009)|0;g=ba(((d[a+(e+3)|0]|0)+((d[a+(e+2)|0]|0)+((d[a+(e+1)|0]|0)+(d[a+e|0]|0)))+2|0)>>>2,16843009)|0;c[a>>2]=f;c[a+4>>2]=g;c[a+b>>2]=f;c[a+(b+4)>>2]=g;e=b<<1;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*3|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b<<2;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*5|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*6|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*7|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b<<3;c[a+e>>2]=f;c[a+(e|4)>>2]=g;e=b*9|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*10|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*11|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*12|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*13|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*14|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*15|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;return}function poa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;ooa(a,b);e=b<<1;f=b*3|0;g=ba((d[a+(-b|0)|0]|0)+4+(d[a+(1-b)|0]|0)+(d[a+(2-b)|0]|0)+(d[a+(3-b)|0]|0)+(d[a-1|0]|0)+(d[a+(b-1)|0]|0)+(d[a+(e-1)|0]|0)+(d[a+(f-1)|0]|0)>>3,16843009)|0;c[a>>2]=g;c[a+b>>2]=g;c[a+e>>2]=g;c[a+f>>2]=g;return}function qoa(a,b){a=a|0;b=b|0;var e=0;moa(a,b);e=ba(((d[a+(-b|0)|0]|0)+2+(d[a+(1-b)|0]|0)+(d[a+(2-b)|0]|0)+(d[a+(3-b)|0]|0)|0)>>>2,16843009)|0;c[a>>2]=e;c[a+b>>2]=e;c[a+(b<<1)>>2]=e;c[a+(b*3|0)>>2]=e;return}function roa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;goa(a,b);goa(a+(b<<3)|0,b);d=b<<2;c[a+d>>2]=-2139062144;c[a+(d+b)>>2]=-2139062144;e=b<<1;c[a+(d+e)>>2]=-2139062144;f=b*3|0;c[a+(d+f)>>2]=-2139062144;g=d+4|0;c[a+g>>2]=-2139062144;c[a+(g+b)>>2]=-2139062144;c[a+(g+e)>>2]=-2139062144;c[a+(g+f)>>2]=-2139062144;return}function soa(a,b){a=a|0;b=b|0;var d=0,e=0;goa(a,b);goa(a+(b<<3)|0,b);c[a>>2]=-2139062144;c[a+b>>2]=-2139062144;d=b<<1;c[a+d>>2]=-2139062144;e=b*3|0;c[a+e>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;return}function toa(a,b){a=a|0;b=b|0;var d=0;c[a>>2]=2139062143;c[a+4>>2]=2139062143;c[a+b>>2]=2139062143;c[a+(b+4)>>2]=2139062143;d=b<<1;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b*3|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b<<2;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b*5|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b*6|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b*7|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;return}function uoa(a,b){a=a|0;b=b|0;var d=0;c[a>>2]=-2122219135;c[a+4>>2]=-2122219135;c[a+b>>2]=-2122219135;c[a+(b+4)>>2]=-2122219135;d=b<<1;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b*3|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b<<2;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b*5|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b*6|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b*7|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;return}function voa(a,b){a=a|0;b=b|0;var d=0;c[a>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;d=b<<1;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b*3|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b<<2;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b*5|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b*6|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b*7|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;return}function woa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[a>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+b>>2]=-2139062144;d=b+4|0;c[a+d>>2]=-2139062144;e=b<<1;c[a+e>>2]=-2139062144;f=e+4|0;c[a+f>>2]=-2139062144;g=b*3|0;c[a+g>>2]=-2139062144;h=g+4|0;c[a+h>>2]=-2139062144;i=b<<2;c[a+i>>2]=-2139062144;j=i+4|0;c[a+j>>2]=-2139062144;k=b*5|0;c[a+k>>2]=-2139062144;l=k+4|0;c[a+l>>2]=-2139062144;m=b*6|0;c[a+m>>2]=-2139062144;n=m+4|0;c[a+n>>2]=-2139062144;o=b*7|0;c[a+o>>2]=-2139062144;p=o+4|0;c[a+p>>2]=-2139062144;q=b<<3;c[a+q>>2]=-2139062144;c[a+(q|4)>>2]=-2139062144;c[a+(q+b)>>2]=-2139062144;c[a+(q+d)>>2]=-2139062144;c[a+(q+e)>>2]=-2139062144;c[a+(f+q)>>2]=-2139062144;c[a+(q+g)>>2]=-2139062144;c[a+(h+q)>>2]=-2139062144;c[a+(q+i)>>2]=-2139062144;c[a+(j+q)>>2]=-2139062144;c[a+(q+k)>>2]=-2139062144;c[a+(l+q)>>2]=-2139062144;c[a+(q+m)>>2]=-2139062144;c[a+(n+q)>>2]=-2139062144;c[a+(q+o)>>2]=-2139062144;c[a+(p+q)>>2]=-2139062144;return}function xoa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=ba((d[a+(15-b)|0]|0)+((d[a+(14-b)|0]|0)+((d[a+(13-b)|0]|0)+((d[a+(12-b)|0]|0)+((d[a+(11-b)|0]|0)+((d[a+(10-b)|0]|0)+((d[a+(9-b)|0]|0)+((d[a+(8-b)|0]|0)+((d[a+(7-b)|0]|0)+((d[a+(6-b)|0]|0)+((d[a+(5-b)|0]|0)+((d[a+(4-b)|0]|0)+((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+((d[a+(-b|0)|0]|0)+((d[a+((b*15|0)-1)|0]|0)+((d[a+((b*14|0)-1)|0]|0)+((d[a+((b*13|0)-1)|0]|0)+((d[a+((b*12|0)-1)|0]|0)+((d[a+((b*11|0)-1)|0]|0)+((d[a+((b*10|0)-1)|0]|0)+((d[a+((b*9|0)-1)|0]|0)+((d[a+((b<<3)-1)|0]|0)+((d[a+((b*7|0)-1)|0]|0)+((d[a+((b*6|0)-1)|0]|0)+((d[a+((b*5|0)-1)|0]|0)+((d[a+((b<<2)-1)|0]|0)+((d[a+((b*3|0)-1)|0]|0)+((d[a+((b<<1)-1)|0]|0)+((d[a+(b-1)|0]|0)+(d[a-1|0]|0)))))))))))))))))))))))))))))))+16>>5,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+8>>2]=e;c[a+12>>2]=e;c[a+b>>2]=e;c[a+(b+4)>>2]=e;c[a+(b+8)>>2]=e;c[a+(b+12)>>2]=e;f=b<<1;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;return}function yoa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+(-b|0)>>2]|0;e=c[a+(4-b)>>2]|0;f=c[a+(8-b)>>2]|0;g=c[a+(12-b)>>2]|0;h=0;do{i=ba(h,b)|0;c[a+i>>2]=d;c[a+(i+4)>>2]=e;c[a+(i+8)>>2]=f;c[a+(i+12)>>2]=g;h=h+1|0;}while((h|0)<16);return}function zoa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=0;do{f=ba(e,b)|0;g=ba(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=g;c[a+(f+4)>>2]=g;c[a+(f+8)>>2]=g;c[a+(f+12)>>2]=g;e=e+1|0;}while((e|0)<16);return}function Aoa(a,b){a=a|0;b=b|0;var d=0,e=0;TGb(a|0,127,16)|0;c[a+b>>2]=2139062143;c[a+(b+4)>>2]=2139062143;c[a+(b+8)>>2]=2139062143;c[a+(b+12)>>2]=2139062143;d=b<<1;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;return}function Boa(a,b){a=a|0;b=b|0;var d=0,e=0;TGb(a|0,-127|0,16)|0;c[a+b>>2]=-2122219135;c[a+(b+4)>>2]=-2122219135;c[a+(b+8)>>2]=-2122219135;c[a+(b+12)>>2]=-2122219135;d=b<<1;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;return}function Coa(a,b){a=a|0;b=b|0;Qoa(a,b,0,0);return}function Doa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=ba((d[a+((b*15|0)-1)|0]|0)+((d[a+((b*14|0)-1)|0]|0)+((d[a+((b*13|0)-1)|0]|0)+((d[a+((b*12|0)-1)|0]|0)+((d[a+((b*11|0)-1)|0]|0)+((d[a+((b*10|0)-1)|0]|0)+((d[a+((b*9|0)-1)|0]|0)+((d[a+((b<<3)-1)|0]|0)+((d[a+((b*7|0)-1)|0]|0)+((d[a+((b*6|0)-1)|0]|0)+((d[a+((b*5|0)-1)|0]|0)+((d[a+((b<<2)-1)|0]|0)+((d[a+((b*3|0)-1)|0]|0)+((d[a+((b<<1)-1)|0]|0)+((d[a+(b-1)|0]|0)+(d[a-1|0]|0)))))))))))))))+8>>4,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+8>>2]=e;c[a+12>>2]=e;c[a+b>>2]=e;c[a+(b+4)>>2]=e;c[a+(b+8)>>2]=e;c[a+(b+12)>>2]=e;f=b<<1;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;return}function Eoa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=ba((d[a+(15-b)|0]|0)+((d[a+(14-b)|0]|0)+((d[a+(13-b)|0]|0)+((d[a+(12-b)|0]|0)+((d[a+(11-b)|0]|0)+((d[a+(10-b)|0]|0)+((d[a+(9-b)|0]|0)+((d[a+(8-b)|0]|0)+((d[a+(7-b)|0]|0)+((d[a+(6-b)|0]|0)+((d[a+(5-b)|0]|0)+((d[a+(4-b)|0]|0)+((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+(d[a+(-b|0)|0]|0)))))))))))))))+8>>4,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+8>>2]=e;c[a+12>>2]=e;c[a+b>>2]=e;c[a+(b+4)>>2]=e;c[a+(b+8)>>2]=e;c[a+(b+12)>>2]=e;f=b<<1;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;return}function Foa(a,b){a=a|0;b=b|0;var d=0,e=0;TGb(a|0,-128|0,16)|0;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;c[a+(b+8)>>2]=-2139062144;c[a+(b+12)>>2]=-2139062144;d=b<<1;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;return}function Goa(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=e<<1;g=e*3|0;h=e<<2;i=(b[d>>1]&255)+(a[c+(-e|0)|0]|0)&255;a[c]=i;j=i+(b[d+8>>1]&255)&255;a[c+e|0]=j;i=j+(b[d+16>>1]&255)&255;a[c+(g-e)|0]=i;a[c+(h-e)|0]=i+(b[d+24>>1]&255);i=1-e|0;e=(b[d+2>>1]&255)+(a[c+i|0]|0)&255;a[c+1|0]=e;j=e+(b[d+10>>1]&255)&255;a[c+(i+f)|0]=j;e=j+(b[d+18>>1]&255)&255;a[c+(i+g)|0]=e;a[c+(i+h)|0]=e+(b[d+26>>1]&255);e=i+1|0;j=(b[d+4>>1]&255)+(a[c+e|0]|0)&255;a[c+2|0]=j;k=j+(b[d+12>>1]&255)&255;a[c+(e+f)|0]=k;j=k+(b[d+20>>1]&255)&255;a[c+(e+g)|0]=j;a[c+(e+h)|0]=j+(b[d+28>>1]&255);j=i+2|0;i=(b[d+6>>1]&255)+(a[c+j|0]|0)&255;a[c+3|0]=i;e=i+(b[d+14>>1]&255)&255;a[c+(j+f)|0]=e;f=e+(b[d+22>>1]&255)&255;a[c+(j+g)|0]=f;a[c+(j+h)|0]=f+(b[d+30>>1]&255);TGb(d|0,0,32)|0;return}function Hoa(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=(b[d>>1]&255)+(a[c-1|0]|0)&255;a[c]=f;g=f+(b[d+2>>1]&255)&255;a[c+1|0]=g;f=g+(b[d+4>>1]&255)&255;a[c+2|0]=f;a[c+3|0]=f+(b[d+6>>1]&255);f=(b[d+8>>1]&255)+(a[c+(e-1)|0]|0)&255;a[c+e|0]=f;g=f+(b[d+10>>1]&255)&255;a[c+(e+1)|0]=g;f=g+(b[d+12>>1]&255)&255;a[c+(e+2)|0]=f;a[c+(e+3)|0]=f+(b[d+14>>1]&255);f=e<<1;g=(b[d+16>>1]&255)+(a[c+(f-1)|0]|0)&255;a[c+f|0]=g;h=g+(b[d+18>>1]&255)&255;a[c+(f|1)|0]=h;g=h+(b[d+20>>1]&255)&255;a[c+(f+2)|0]=g;a[c+(f+3)|0]=g+(b[d+22>>1]&255);g=f+e|0;e=(b[d+24>>1]&255)+(a[c+(g-1)|0]|0)&255;a[c+g|0]=e;f=e+(b[d+26>>1]&255)&255;a[c+(g+1)|0]=f;e=f+(b[d+28>>1]&255)&255;a[c+(g+2)|0]=e;a[c+(g+3)|0]=e+(b[d+30>>1]&255);TGb(d|0,0,32)|0;return}function Ioa(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=e<<1;g=e*3|0;h=e<<2;i=e*5|0;j=e*6|0;k=e*7|0;l=e<<3;m=0;n=c+(-e|0)|0;c=d;while(1){o=(b[c>>1]&255)+(a[n]|0)&255;a[n+e|0]=o;p=o+(b[c+16>>1]&255)&255;a[n+f|0]=p;o=p+(b[c+32>>1]&255)&255;a[n+g|0]=o;p=o+(b[c+48>>1]&255)&255;a[n+h|0]=p;o=p+(b[c+64>>1]&255)&255;a[n+i|0]=o;p=o+(b[c+80>>1]&255)&255;a[n+j|0]=p;o=p+(b[c+96>>1]&255)&255;a[n+k|0]=o;a[n+l|0]=o+(b[c+112>>1]&255);o=m+1|0;if((o|0)<8){m=o;n=n+1|0;c=c+2|0}else{break}}TGb(d|0,0,128)|0;return}function Joa(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=0;g=c;c=d;while(1){h=(b[c>>1]&255)+(a[g-1|0]|0)&255;a[g]=h;i=h+(b[c+2>>1]&255)&255;a[g+1|0]=i;h=i+(b[c+4>>1]&255)&255;a[g+2|0]=h;i=h+(b[c+6>>1]&255)&255;a[g+3|0]=i;h=i+(b[c+8>>1]&255)&255;a[g+4|0]=h;i=h+(b[c+10>>1]&255)&255;a[g+5|0]=i;h=i+(b[c+12>>1]&255)&255;a[g+6|0]=h;a[g+7|0]=h+(b[c+14>>1]&255);h=f+1|0;if((h|0)<8){f=h;g=g+e|0;c=c+16|0}else{break}}TGb(d|0,0,128)|0;return}function Koa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Goa(a+(c[b>>2]|0)|0,d,e);Goa(a+(c[b+4>>2]|0)|0,d+32|0,e);Goa(a+(c[b+8>>2]|0)|0,d+64|0,e);Goa(a+(c[b+12>>2]|0)|0,d+96|0,e);return}function Loa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Hoa(a+(c[b>>2]|0)|0,d,e);Hoa(a+(c[b+4>>2]|0)|0,d+32|0,e);Hoa(a+(c[b+8>>2]|0)|0,d+64|0,e);Hoa(a+(c[b+12>>2]|0)|0,d+96|0,e);return}function Moa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Goa(a+(c[b>>2]|0)|0,d,e);Goa(a+(c[b+4>>2]|0)|0,d+32|0,e);Goa(a+(c[b+8>>2]|0)|0,d+64|0,e);Goa(a+(c[b+12>>2]|0)|0,d+96|0,e);Goa(a+(c[b+32>>2]|0)|0,d+128|0,e);Goa(a+(c[b+36>>2]|0)|0,d+160|0,e);Goa(a+(c[b+40>>2]|0)|0,d+192|0,e);Goa(a+(c[b+44>>2]|0)|0,d+224|0,e);return}function Noa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Hoa(a+(c[b>>2]|0)|0,d,e);Hoa(a+(c[b+4>>2]|0)|0,d+32|0,e);Hoa(a+(c[b+8>>2]|0)|0,d+64|0,e);Hoa(a+(c[b+12>>2]|0)|0,d+96|0,e);Hoa(a+(c[b+32>>2]|0)|0,d+128|0,e);Hoa(a+(c[b+36>>2]|0)|0,d+160|0,e);Hoa(a+(c[b+40>>2]|0)|0,d+192|0,e);Hoa(a+(c[b+44>>2]|0)|0,d+224|0,e);return}function Ooa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Goa(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<4<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Poa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Hoa(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<4<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Qoa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=-c|0;h=7-c|0;i=(c<<3)-1|0;j=b+i|0;k=b+(i-(c<<1))|0;i=b+((c*15|0)-1)|0;l=2;m=j;n=k;o=(d[b+(h+1)|0]|0)-(d[b+(h-1)|0]|0)|0;p=(d[j]|0)-(d[k]|0)|0;do{m=m+c|0;n=n+g|0;o=(ba((d[b+(l+h)|0]|0)-(d[b+(h-l)|0]|0)|0,l)|0)+o|0;p=(ba((d[m]|0)-(d[n]|0)|0,l)|0)+p|0;l=l+1|0;}while((l|0)<9);do{if((e|0)==0){if((f|0)==0){q=(p*5|0)+32>>6;r=(o*5|0)+32>>6;break}else{q=(p>>2)+p>>4;r=(o>>2)+o>>4;break}}else{q=(((o|0)/4|0)*5|0|0)/16|0;r=(((p|0)/4|0)*5|0|0)/16|0}}while(0);p=r<<1;o=r*3|0;f=r<<2;e=((q+r|0)*-7|0)+16+((d[b+(16-c-1)|0]|0)+(d[i]|0)<<4)|0;i=b;b=16;while(1){l=-16;n=e;while(1){m=n>>5;if(m>>>0>255>>>0){s=-m>>31&255}else{s=m&255}a[i+(l+16)|0]=s;m=n+r>>5;if(m>>>0>255>>>0){t=-m>>31&255}else{t=m&255}a[i+(l+17)|0]=t;m=n+p>>5;if(m>>>0>255>>>0){u=-m>>31&255}else{u=m&255}a[i+(l+18)|0]=u;m=n+o>>5;if(m>>>0>255>>>0){v=-m>>31&255}else{v=m&255}a[i+(l+19)|0]=v;m=l+4|0;if((m|0)<0){l=m;n=n+f|0}else{break}}n=b-1|0;if((n|0)>0){e=e+q|0;i=i+c|0;b=n}else{break}}return}function Roa(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;l=d[b+(-g|0)|0]|0;m=d[b+(1-g)|0]|0;n=d[b+(2-g)|0]|0;o=d[b+(3-g)|0]|0;p=c&255;c=e&255;e=m<<1;a[b]=(h+4+j+e+(l+i<<1)|0)>>>3;h=(m+1+n|0)>>>1&255;q=g<<1;a[b+q|0]=h;a[b+1|0]=h;h=(n+1+o|0)>>>1&255;a[b+(q|1)|0]=h;a[b+2|0]=h;h=p+1|0;r=(h+o|0)>>>1&255;a[b+(q+2)|0]=r;a[b+3|0]=r;a[b+(q+3)|0]=(h+c|0)>>>1;a[b+g|0]=(i+4+(j<<1)+k+l+e+n|0)>>>3;e=(m+2+(n<<1)+o|0)>>>2&255;m=g*3|0;a[b+m|0]=e;a[b+(g+1)|0]=e;e=p+2|0;l=(e+n+(o<<1)|0)>>>2&255;a[b+(m+1)|0]=l;a[b+(g+2)|0]=l;l=((p<<1)+2+c+o|0)>>>2&255;a[b+(m+2)|0]=l;a[b+(g+3)|0]=l;a[b+(m+3)|0]=(e+(c<<1)+(f&255)|0)>>>2;return}function Soa(a,b){a=a|0;b=b|0;if((b|0)==12){c[a>>2]=1498;c[a+4>>2]=1072;c[a+8>>2]=1916;c[a+12>>2]=1986;c[a+16>>2]=680;c[a+20>>2]=1310;c[a+24>>2]=1514;c[a+28>>2]=550;c[a+32>>2]=460;c[a+36>>2]=606;c[a+40>>2]=1728;c[a+44>>2]=1958;c[a+48>>2]=1484;c[a+52>>2]=2308;c[a+56>>2]=310;c[a+60>>2]=1448;c[a+64>>2]=730;c[a+68>>2]=1042;c[a+72>>2]=1954;c[a+76>>2]=974;c[a+80>>2]=4;c[a+84>>2]=50;c[a+88>>2]=128;c[a+92>>2]=540;c[a+96>>2]=832;c[a+100>>2]=1314;c[a+104>>2]=922;c[a+108>>2]=116;c[a+112>>2]=2118;c[a+116>>2]=2266;c[a+120>>2]=2326;c[a+124>>2]=774;c[a+128>>2]=858;c[a+132>>2]=1928;c[a+136>>2]=1830;c[a+140>>2]=370;c[a+144>>2]=372;c[a+148>>2]=68;c[a+152>>2]=1742;c[a+156>>2]=2236;c[a+160>>2]=576;c[a+164>>2]=1672;c[a+168>>2]=36;c[a+172>>2]=818;c[a+176>>2]=1662;c[a+180>>2]=1282;c[a+184>>2]=1418;c[a+188>>2]=2186;c[a+192>>2]=1094;c[a+196>>2]=1278;c[a+200>>2]=1782;c[a+204>>2]=1364;c[a+208>>2]=1262;c[a+212>>2]=608;c[a+216>>2]=60;c[a+220>>2]=92;c[a+224>>2]=110;c[a+228>>2]=1652;c[a+232>>2]=1152;c[a+236>>2]=1612;c[a+240>>2]=2042;c[a+244>>2]=804;c[a+248>>2]=2164;c[a+252>>2]=2318;c[a+256>>2]=2290;c[a+260>>2]=548;c[a+264>>2]=784;c[a+268>>2]=432;c[a+272>>2]=2160;c[a+276>>2]=2136;c[a+280>>2]=2056;c[a+284>>2]=2098;c[a+288>>2]=2268;c[a+292>>2]=768;c[a+296>>2]=512;c[a+300>>2]=984;c[a+304>>2]=1476;c[a+308>>2]=364;c[a+312>>2]=400;c[a+316>>2]=2364;c[a+320>>2]=558;c[a+324>>2]=572;c[a+328>>2]=830;c[a+332>>2]=2138;c[a+336>>2]=1066;c[a+340>>2]=1020;c[a+344>>2]=1852;c[a+348>>2]=1856;c[a+352>>2]=1452;c[a+356>>2]=982;c[a+360>>2]=1864;c[a+364>>2]=1934;c[a+368>>2]=1884;c[a+372>>2]=1386;c[a+376>>2]=1036;c[a+380>>2]=1438;c[a+384>>2]=2296;c[a+388>>2]=1206;c[a+392>>2]=2320;c[a+396>>2]=716;c[a+400>>2]=1318;c[a+404>>2]=836;c[a+408>>2]=244;c[a+412>>2]=850;c[a+416>>2]=802;c[a+420>>2]=8;c[a+424>>2]=1182;c[a+428>>2]=1244;c[a+432>>2]=1290;c[a+436>>2]=1848;c[a+440>>2]=2166;c[a+444>>2]=1286;return}else if((b|0)==14){c[a>>2]=2092;c[a+4>>2]=1656;c[a+8>>2]=1320;c[a+12>>2]=1370;c[a+16>>2]=100;c[a+20>>2]=734;c[a+24>>2]=2106;c[a+28>>2]=1136;c[a+32>>2]=2298;c[a+36>>2]=20;c[a+40>>2]=1666;c[a+44>>2]=182;c[a+48>>2]=2090;c[a+52>>2]=528;c[a+56>>2]=2076;c[a+60>>2]=1162;c[a+64>>2]=1298;c[a+68>>2]=1334;c[a+72>>2]=1326;c[a+76>>2]=382;c[a+80>>2]=2084;c[a+84>>2]=2132;c[a+88>>2]=704;c[a+92>>2]=1134;c[a+96>>2]=542;c[a+100>>2]=1024;c[a+104>>2]=1508;c[a+108>>2]=726;c[a+112>>2]=1246;c[a+116>>2]=470;c[a+120>>2]=1718;c[a+124>>2]=1080;c[a+128>>2]=1432;c[a+132>>2]=178;c[a+136>>2]=1214;c[a+140>>2]=2168;c[a+144>>2]=106;c[a+148>>2]=1850;c[a+152>>2]=1412;c[a+156>>2]=166;c[a+160>>2]=312;c[a+164>>2]=196;c[a+168>>2]=626;c[a+172>>2]=1420;c[a+176>>2]=84;c[a+180>>2]=1900;c[a+184>>2]=816;c[a+188>>2]=1568;c[a+192>>2]=500;c[a+196>>2]=706;c[a+200>>2]=1622;c[a+204>>2]=478;c[a+208>>2]=1866;c[a+212>>2]=1190;c[a+216>>2]=2152;c[a+220>>2]=2174;c[a+224>>2]=722;c[a+228>>2]=2248;c[a+232>>2]=866;c[a+236>>2]=1324;c[a+240>>2]=526;c[a+244>>2]=266;c[a+248>>2]=90;c[a+252>>2]=520;c[a+256>>2]=1680;c[a+260>>2]=2338;c[a+264>>2]=1382;c[a+268>>2]=1056;c[a+272>>2]=74;c[a+276>>2]=1810;c[a+280>>2]=1148;c[a+284>>2]=1496;c[a+288>>2]=2172;c[a+292>>2]=1362;c[a+296>>2]=2306;c[a+300>>2]=134;c[a+304>>2]=888;c[a+308>>2]=2158;c[a+312>>2]=998;c[a+316>>2]=570;c[a+320>>2]=1664;c[a+324>>2]=1166;c[a+328>>2]=282;c[a+332>>2]=962;c[a+336>>2]=1394;c[a+340>>2]=1354;c[a+344>>2]=70;c[a+348>>2]=80;c[a+352>>2]=538;c[a+356>>2]=96;c[a+360>>2]=82;c[a+364>>2]=186;c[a+368>>2]=104;c[a+372>>2]=2292;c[a+376>>2]=422;c[a+380>>2]=834;c[a+384>>2]=476;c[a+388>>2]=1826;c[a+392>>2]=1050;c[a+396>>2]=142;c[a+400>>2]=738;c[a+404>>2]=586;c[a+408>>2]=464;c[a+412>>2]=1772;c[a+416>>2]=504;c[a+420>>2]=1786;c[a+424>>2]=1288;c[a+428>>2]=1860;c[a+432>>2]=1874;c[a+436>>2]=88;c[a+440>>2]=1574;c[a+444>>2]=124;return}else if((b|0)==10){c[a>>2]=902;c[a+4>>2]=448;c[a+8>>2]=154;c[a+12>>2]=202;c[a+16>>2]=1242;c[a+20>>2]=1920;c[a+24>>2]=918;c[a+28>>2]=2336;c[a+32>>2]=1084;c[a+36>>2]=1186;c[a+40>>2]=1402;c[a+44>>2]=1346;c[a+48>>2]=896;c[a+52>>2]=1726;c[a+56>>2]=880;c[a+60>>2]=2030;c[a+64>>2]=148;c[a+68>>2]=424;c[a+72>>2]=188;c[a+76>>2]=1584;c[a+80>>2]=1180;c[a+84>>2]=1436;c[a+88>>2]=1888;c[a+92>>2]=2354;c[a+96>>2]=1424;c[a+100>>2]=1922;c[a+104>>2]=332;c[a+108>>2]=1744;c[a+112>>2]=1526;c[a+116>>2]=1658;c[a+120>>2]=536;c[a+124>>2]=1372;c[a+128>>2]=296;c[a+132>>2]=1322;c[a+136>>2]=978;c[a+140>>2]=964;c[a+144>>2]=956;c[a+148>>2]=652;c[a+152>>2]=1138;c[a+156>>2]=1628;c[a+160>>2]=1456;c[a+164>>2]=2278;c[a+168>>2]=1822;c[a+172>>2]=264;c[a+176>>2]=1250;c[a+180>>2]=708;c[a+184>>2]=2316;c[a+188>>2]=384;c[a+192>>2]=1688;c[a+196>>2]=1898;c[a+200>>2]=402;c[a+204>>2]=770;c[a+208>>2]=668;c[a+212>>2]=24;c[a+216>>2]=648;c[a+220>>2]=672;c[a+224>>2]=1876;c[a+228>>2]=1060;c[a+232>>2]=1752;c[a+236>>2]=2208;c[a+240>>2]=1722;c[a+244>>2]=1408;c[a+248>>2]=2294;c[a+252>>2]=1724;c[a+256>>2]=798;c[a+260>>2]=1142;c[a+264>>2]=232;c[a+268>>2]=2244;c[a+272>>2]=1566;c[a+276>>2]=1558;c[a+280>>2]=2352;c[a+284>>2]=328;c[a+288>>2]=990;c[a+292>>2]=204;c[a+296>>2]=1108;c[a+300>>2]=62;c[a+304>>2]=634;c[a+308>>2]=958;c[a+312>>2]=2194;c[a+316>>2]=1092;c[a+320>>2]=2344;c[a+324>>2]=2366;c[a+328>>2]=1422;c[a+332>>2]=192;c[a+336>>2]=1642;c[a+340>>2]=1616;c[a+344>>2]=1232;c[a+348>>2]=1266;c[a+352>>2]=2028;c[a+356>>2]=1592;c[a+360>>2]=1248;c[a+364>>2]=1338;c[a+368>>2]=1270;c[a+372>>2]=788;c[a+376>>2]=1610;c[a+380>>2]=2024;c[a+384>>2]=1682;c[a+388>>2]=632;c[a+392>>2]=970;c[a+396>>2]=1098;c[a+400>>2]=1906;c[a+404>>2]=2210;c[a+408>>2]=1994;c[a+412>>2]=306;c[a+416>>2]=1388;c[a+420>>2]=590;c[a+424>>2]=602;c[a+428>>2]=656;c[a+432>>2]=720;c[a+436>>2]=1228;c[a+440>>2]=2304;c[a+444>>2]=326;return}else if((b|0)==9){c[a>>2]=356;c[a+4>>2]=1556;c[a+8>>2]=1596;c[a+12>>2]=1268;c[a+16>>2]=1930;c[a+20>>2]=2004;c[a+24>>2]=386;c[a+28>>2]=662;c[a+32>>2]=578;c[a+36>>2]=1780;c[a+40>>2]=1984;c[a+44>>2]=1224;c[a+48>>2]=808;c[a+52>>2]=2324;c[a+56>>2]=176;c[a+60>>2]=1766;c[a+64>>2]=750;c[a+68>>2]=2370;c[a+72>>2]=740;c[a+76>>2]=1124;c[a+80>>2]=1236;c[a+84>>2]=842;c[a+88>>2]=146;c[a+92>>2]=2074;c[a+96>>2]=1594;c[a+100>>2]=1204;c[a+104>>2]=1638;c[a+108>>2]=840;c[a+112>>2]=1264;c[a+116>>2]=1122;c[a+120>>2]=378;c[a+124>>2]=1702;c[a+128>>2]=102;c[a+132>>2]=598;c[a+136>>2]=640;c[a+140>>2]=1454;c[a+144>>2]=610;c[a+148>>2]=1794;c[a+152>>2]=1374;c[a+156>>2]=948;c[a+160>>2]=160;c[a+164>>2]=556;c[a+168>>2]=952;c[a+172>>2]=502;c[a+176>>2]=1914;c[a+180>>2]=484;c[a+184>>2]=2156;c[a+188>>2]=1058;c[a+192>>2]=1032;c[a+196>>2]=1800;c[a+200>>2]=162;c[a+204>>2]=618;c[a+208>>2]=212;c[a+212>>2]=2150;c[a+216>>2]=248;c[a+220>>2]=936;c[a+224>>2]=2262;c[a+228>>2]=1468;c[a+232>>2]=2226;c[a+236>>2]=600;c[a+240>>2]=1716;c[a+244>>2]=1808;c[a+248>>2]=1366;c[a+252>>2]=120;c[a+256>>2]=46;c[a+260>>2]=1974;c[a+264>>2]=886;c[a+268>>2]=756;c[a+272>>2]=532;c[a+276>>2]=844;c[a+280>>2]=2016;c[a+284>>2]=1316;c[a+288>>2]=2100;c[a+292>>2]=1294;c[a+296>>2]=898;c[a+300>>2]=1996;c[a+304>>2]=392;c[a+308>>2]=138;c[a+312>>2]=2026;c[a+316>>2]=206;c[a+320>>2]=462;c[a+324>>2]=1734;c[a+328>>2]=1e3;c[a+332>>2]=2192;c[a+336>>2]=2046;c[a+340>>2]=86;c[a+344>>2]=518;c[a+348>>2]=938;c[a+352>>2]=1704;c[a+356>>2]=2086;c[a+360>>2]=78;c[a+364>>2]=1202;c[a+368>>2]=1678;c[a+372>>2]=122;c[a+376>>2]=334;c[a+380>>2]=592;c[a+384>>2]=64;c[a+388>>2]=676;c[a+392>>2]=1606;c[a+396>>2]=1936;c[a+400>>2]=1634;c[a+404>>2]=748;c[a+408>>2]=1548;c[a+412>>2]=1964;c[a+416>>2]=2200;c[a+420>>2]=1980;c[a+424>>2]=1086;c[a+428>>2]=2220;c[a+432>>2]=628;c[a+436>>2]=776;c[a+440>>2]=2322;c[a+444>>2]=1608;return}else{c[a>>2]=1258;c[a+4>>2]=1778;c[a+8>>2]=172;c[a+12>>2]=1624;c[a+16>>2]=986;c[a+20>>2]=906;c[a+24>>2]=1858;c[a+28>>2]=354;c[a+32>>2]=954;c[a+36>>2]=2274;c[a+40>>2]=488;c[a+44>>2]=22;c[a+48>>2]=2272;c[a+52>>2]=2008;c[a+56>>2]=434;c[a+60>>2]=324;c[a+64>>2]=2202;c[a+68>>2]=912;c[a+72>>2]=1054;c[a+76>>2]=2060;c[a+80>>2]=2180;c[a+84>>2]=2310;c[a+88>>2]=2162;c[a+92>>2]=1144;c[a+96>>2]=1932;c[a+100>>2]=894;c[a+104>>2]=1982;c[a+108>>2]=1768;c[a+112>>2]=940;c[a+116>>2]=1472;c[a+120>>2]=1312;c[a+124>>2]=786;c[a+128>>2]=1226;c[a+132>>2]=1522;c[a+136>>2]=2104;c[a+140>>2]=14;c[a+144>>2]=1536;c[a+148>>2]=854;c[a+152>>2]=1038;c[a+156>>2]=42;c[a+160>>2]=440;c[a+164>>2]=272;c[a+168>>2]=48;c[a+172>>2]=230;c[a+176>>2]=1576;c[a+180>>2]=510;c[a+184>>2]=992;c[a+188>>2]=190;c[a+192>>2]=420;c[a+196>>2]=1450;c[a+200>>2]=442;c[a+204>>2]=316;c[a+208>>2]=1088;c[a+212>>2]=114;c[a+216>>2]=2258;c[a+220>>2]=1254;c[a+224>>2]=1340;c[a+228>>2]=1140;c[a+232>>2]=1300;c[a+236>>2]=1524;c[a+240>>2]=1378;c[a+244>>2]=2122;c[a+248>>2]=2280;c[a+252>>2]=1552;c[a+256>>2]=1482;c[a+260>>2]=480;c[a+264>>2]=1756;c[a+268>>2]=1668;c[a+272>>2]=1458;c[a+276>>2]=428;c[a+280>>2]=552;c[a+284>>2]=1640;c[a+288>>2]=54;c[a+292>>2]=2222;c[a+296>>2]=2360;c[a+300>>2]=1654;c[a+304>>2]=1444;c[a+308>>2]=1562;c[a+312>>2]=1696;c[a+316>>2]=1944;c[a+320>>2]=1404;c[a+324>>2]=2066;c[a+328>>2]=678;c[a+332>>2]=1260;c[a+336>>2]=1120;c[a+340>>2]=988;c[a+344>>2]=2e3;c[a+348>>2]=616;c[a+352>>2]=1390;c[a+356>>2]=44;c[a+360>>2]=980;c[a+364>>2]=1550;c[a+368>>2]=772;c[a+372>>2]=2154;c[a+376>>2]=736;c[a+380>>2]=294;c[a+384>>2]=2110;c[a+388>>2]=724;c[a+392>>2]=580;c[a+396>>2]=2250;c[a+400>>2]=1010;c[a+404>>2]=404;c[a+408>>2]=1868;c[a+412>>2]=466;c[a+416>>2]=582;c[a+420>>2]=1046;c[a+424>>2]=2006;c[a+428>>2]=198;c[a+432>>2]=1790;c[a+436>>2]=1690;c[a+440>>2]=304;c[a+444>>2]=1590;return}}function Toa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e+4|0;g=b+f|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=e<<1;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;h=b+g|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+8|0;c[a+8>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+12|0;c[a+12>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=e+8|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=e+12|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;e=b+g|0;c[a+g>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=g+4|0;g=b+e|0;c[a+e>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;return}function Uoa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;iAa(g|0,b,16,e);iAa(g+8|0,b+8|0,16,e);h=e<<3;iAa(g+128|0,b+h|0,16,e);iAa(g+136|0,b+(h+8)|0,16,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ba(o,e)|0;n=h+8|0;k=b+n|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=o<<4;j=g+(k|8)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+n>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+12|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(k|12)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+l>>2]=(k|m)-((k^m)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function Voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;iAa(a,b,c,c);iAa(a+8|0,b+8|0,c,c);d=c<<3;iAa(a+d|0,b+d|0,c,c);e=d+8|0;iAa(a+e|0,b+e|0,c,c);return}function Woa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;iAa(g|0,b,16,e);iAa(g+8|0,b+8|0,16,e);h=e<<3;iAa(g+128|0,b+h|0,16,e);iAa(g+136|0,b+(h+8)|0,16,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ba(o,e)|0;n=b+(h+9)|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o<<4;j=g+(n|8)|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(h+8)>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(n|12)|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+(h+12)>>2]=(n|l)-((n^l)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function Xoa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+592|0;h=g|0;j=g+336|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=e;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+4|0;m=e+4|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+8|0;n=e+8|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+12|0;m=e+12|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+1|0;if((m|0)<21){k=k+f|0;e=e+16|0;l=m}else{break}}jAa(j|0,h+32|0,16,16);jAa(j+8|0,h+40|0,16,16);jAa(j+128|0,h+160|0,16,16);jAa(j+136|0,h+168|0,16,16);l=0;while(1){e=l<<4;k=h+(e+32)|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+e|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(l,f)|0;c[b+k>>2]=(n|m)-((n^m)>>>1&2139062143);m=e|4;e=h+(m+32)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+m|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(k+4)>>2]=(m|n)-((m^n)>>>1&2139062143);n=l+1|0;if((n|0)<16){l=n}else{o=0;break}}do{l=o<<4;n=l|8;m=h+(n+32)|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+n|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(o,f)|0;c[b+(m+8)>>2]=(n|k)-((n^k)>>>1&2139062143);k=l|12;l=h+(k+32)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+k|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(m+12)>>2]=(k|n)-((k^n)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=g;return}function Yoa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;iAa(j|0,e,16,f);iAa(j+8|0,e+8|0,16,f);l=f<<3;iAa(j+128|0,e+l|0,16,f);iAa(j+136|0,e+(l+8)|0,16,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=e;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+4|0;n=e+4|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+8|0;o=e+8|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+12|0;n=e+12|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+1|0;if((n|0)<21){l=l+f|0;e=e+16|0;m=n}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=0;while(1){m=h<<4;e=j+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(h,f)|0;c[b+e>>2]=(n|l)-((n^l)>>>1&2139062143);l=m|4;m=j+l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[b+(e+4)>>2]=(l|n)-((l^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{p=0;break}}do{h=p<<4;n=h|8;l=j+n|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+n|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(p,f)|0;c[b+(l+8)>>2]=(n|e)-((n^e)>>>1&2139062143);e=h|12;h=j+e|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(l+12)>>2]=(e|n)-((e^n)>>>1&2139062143);p=p+1|0;}while((p|0)<16);i=g;return}function Zoa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+1184|0;g=f|0;h=f+672|0;j=f+928|0;iAa(h|0,b,16,e);k=b+8|0;iAa(h+8|0,k,16,e);l=e<<3;m=b+l|0;iAa(h+128|0,m,16,e);n=b+(l+8)|0;iAa(h+136|0,n,16,e);l=g|0;kAa(j|0,l,b,16,16,e);b=g+16|0;kAa(j+8|0,b,k,16,16,e);kAa(j+128|0,l,m,16,16,e);kAa(j+136|0,b,n,16,16,e);n=0;while(1){b=n<<4;m=h+b|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+b|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(n,e)|0;c[a+m>>2]=(k|l)-((k^l)>>>1&2139062143);l=b|4;b=h+l|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(m+4)>>2]=(l|k)-((l^k)>>>1&2139062143);k=n+1|0;if((k|0)<16){n=k}else{o=0;break}}do{n=o<<4;k=n|8;l=h+k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+k|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(o,e)|0;c[a+(l+8)>>2]=(k|m)-((k^m)>>>1&2139062143);m=n|12;n=h+m|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+m|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[a+(l+12)>>2]=(m|k)-((m^k)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function _oa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;iAa(j|0,e,16,f);iAa(j+8|0,e+8|0,16,f);l=f<<3;iAa(j+128|0,e+l|0,16,f);iAa(j+136|0,e+(l+8)|0,16,f);l=e+(-(f<<1)|1)|0;e=h|0;m=0;while(1){n=l;o=e;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+4|0;n=e+4|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+8|0;o=e+8|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+12|0;n=e+12|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+1|0;if((n|0)<21){l=l+f|0;e=e+16|0;m=n}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=0;while(1){m=h<<4;e=j+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(h,f)|0;c[b+e>>2]=(n|l)-((n^l)>>>1&2139062143);l=m|4;m=j+l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[b+(e+4)>>2]=(l|n)-((l^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{p=0;break}}do{h=p<<4;n=h|8;l=j+n|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+n|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(p,f)|0;c[b+(l+8)>>2]=(n|e)-((n^e)>>>1&2139062143);e=h|12;h=j+e|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(l+12)>>2]=(e|n)-((e^n)>>>1&2139062143);p=p+1|0;}while((p|0)<16);i=g;return}function $oa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+336|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=c;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+4|0;k=c+4|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+8|0;l=c+8|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+12|0;k=c+12|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=j+1|0;if((k|0)<21){h=h+e|0;c=c+16|0;j=k}else{break}}jAa(b,g+32|0,e,16);jAa(b+8|0,g+40|0,e,16);j=e<<3;jAa(b+j|0,g+160|0,e,16);jAa(b+(j+8)|0,g+168|0,e,16);i=f;return}function apa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1520|0;h=g|0;j=g+336|0;k=g+1008|0;l=g+1264|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=n;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+4|0;p=n+4|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+8|0;q=n+8|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+12|0;p=n+12|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+1|0;if((p|0)<21){m=m+f|0;n=n+16|0;o=p}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=j|0;kAa(l|0,h,e,16,16,f);o=j+16|0;kAa(l+8|0,o,e+8|0,16,16,f);j=f<<3;kAa(l+128|0,h,e+j|0,16,16,f);kAa(l+136|0,o,e+(j+8)|0,16,16,f);j=0;while(1){e=j<<4;o=k+e|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+e|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(j,f)|0;c[b+o>>2]=(n|h)-((n^h)>>>1&2139062143);h=e|4;e=k+h|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+4)>>2]=(h|n)-((h^n)>>>1&2139062143);n=j+1|0;if((n|0)<16){j=n}else{r=0;break}}do{j=r<<4;n=j|8;h=k+n|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+n|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(r,f)|0;c[b+(h+8)>>2]=(n|o)-((n^o)>>>1&2139062143);o=j|12;j=k+o|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[b+(h+12)>>2]=(o|n)-((o^n)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function bpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+672|0;e=d|0;f=e|0;kAa(a,f,b,c,16,c);g=e+16|0;kAa(a+8|0,g,b+8|0,c,16,c);e=c<<3;kAa(a+e|0,f,b+e|0,c,16,c);f=e+8|0;kAa(a+f|0,g,b+f|0,c,16,c);i=d;return}function cpa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1520|0;h=g|0;j=g+336|0;k=g+1008|0;l=g+1264|0;m=e+(-(f<<1)|1)|0;n=h|0;o=0;while(1){p=m;q=n;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+4|0;p=n+4|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+8|0;q=n+8|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+12|0;p=n+12|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+1|0;if((p|0)<21){m=m+f|0;n=n+16|0;o=p}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=j|0;kAa(l|0,h,e,16,16,f);o=j+16|0;kAa(l+8|0,o,e+8|0,16,16,f);j=f<<3;kAa(l+128|0,h,e+j|0,16,16,f);kAa(l+136|0,o,e+(j+8)|0,16,16,f);j=0;while(1){e=j<<4;o=k+e|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+e|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(j,f)|0;c[b+o>>2]=(n|h)-((n^h)>>>1&2139062143);h=e|4;e=k+h|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+4)>>2]=(h|n)-((h^n)>>>1&2139062143);n=j+1|0;if((n|0)<16){j=n}else{r=0;break}}do{j=r<<4;n=j|8;h=k+n|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+n|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ba(r,f)|0;c[b+(h+8)>>2]=(n|o)-((n^o)>>>1&2139062143);o=j|12;j=k+o|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[b+(h+12)>>2]=(o|n)-((o^n)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function dpa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+592|0;h=g|0;j=g+336|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=e;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+4|0;m=e+4|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+8|0;n=e+8|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+12|0;m=e+12|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+1|0;if((m|0)<21){k=k+f|0;e=e+16|0;l=m}else{break}}jAa(j|0,h+32|0,16,16);jAa(j+8|0,h+40|0,16,16);jAa(j+128|0,h+160|0,16,16);jAa(j+136|0,h+168|0,16,16);l=0;while(1){e=l<<4;k=h+(e+48)|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+e|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(l,f)|0;c[b+k>>2]=(n|m)-((n^m)>>>1&2139062143);m=e|4;e=h+(m+48)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+m|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(k+4)>>2]=(m|n)-((m^n)>>>1&2139062143);n=l+1|0;if((n|0)<16){l=n}else{o=0;break}}do{l=o<<4;n=l|8;m=h+(n+48)|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+n|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(o,f)|0;c[b+(m+8)>>2]=(n|k)-((n^k)>>>1&2139062143);k=l|12;l=h+(k+48)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+k|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(m+12)>>2]=(k|n)-((k^n)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=g;return}function epa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;iAa(j|0,e+f|0,16,f);l=f+8|0;iAa(j+8|0,e+l|0,16,f);m=f<<3;iAa(j+128|0,e+(m+f)|0,16,f);iAa(j+136|0,e+(l+m)|0,16,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=e;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+4|0;n=e+4|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+8|0;o=e+8|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+12|0;n=e+12|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+1|0;if((n|0)<21){m=m+f|0;e=e+16|0;l=n}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=0;while(1){l=h<<4;e=j+l|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+l|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(h,f)|0;c[b+e>>2]=(n|m)-((n^m)>>>1&2139062143);m=l|4;l=j+m|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(e+4)>>2]=(m|n)-((m^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{p=0;break}}do{h=p<<4;n=h|8;m=j+n|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(p,f)|0;c[b+(m+8)>>2]=(n|e)-((n^e)>>>1&2139062143);e=h|12;h=j+e|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(m+12)>>2]=(e|n)-((e^n)>>>1&2139062143);p=p+1|0;}while((p|0)<16);i=g;return}function fpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+1184|0;g=f|0;h=f+672|0;j=f+928|0;iAa(h|0,b+e|0,16,e);iAa(h+8|0,b+(e+8)|0,16,e);k=e<<3;iAa(h+128|0,b+(k+e)|0,16,e);l=k+8|0;iAa(h+136|0,b+(l+e)|0,16,e);m=g|0;kAa(j|0,m,b,16,16,e);n=g+16|0;kAa(j+8|0,n,b+8|0,16,16,e);kAa(j+128|0,m,b+k|0,16,16,e);kAa(j+136|0,n,b+l|0,16,16,e);l=0;while(1){b=l<<4;n=h+b|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+b|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(l,e)|0;c[a+n>>2]=(m|k)-((m^k)>>>1&2139062143);k=b|4;b=h+k|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+k|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(n+4)>>2]=(k|m)-((k^m)>>>1&2139062143);m=l+1|0;if((m|0)<16){l=m}else{o=0;break}}do{l=o<<4;m=l|8;k=h+m|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+m|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(o,e)|0;c[a+(k+8)>>2]=(m|n)-((m^n)>>>1&2139062143);n=l|12;l=h+n|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+n|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(k+12)>>2]=(n|m)-((n^m)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function gpa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;iAa(j|0,e+f|0,16,f);l=f+8|0;iAa(j+8|0,e+l|0,16,f);m=f<<3;iAa(j+128|0,e+(m+f)|0,16,f);iAa(j+136|0,e+(l+m)|0,16,f);m=e+(-(f<<1)|1)|0;e=h|0;l=0;while(1){n=m;o=e;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+4|0;n=e+4|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+8|0;o=e+8|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+12|0;n=e+12|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+1|0;if((n|0)<21){m=m+f|0;e=e+16|0;l=n}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=0;while(1){l=h<<4;e=j+l|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+l|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(h,f)|0;c[b+e>>2]=(n|m)-((n^m)>>>1&2139062143);m=l|4;l=j+m|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(e+4)>>2]=(m|n)-((m^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{p=0;break}}do{h=p<<4;n=h|8;m=j+n|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(p,f)|0;c[b+(m+8)>>2]=(n|e)-((n^e)>>>1&2139062143);e=h|12;h=j+e|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(m+12)>>2]=(e|n)-((e^n)>>>1&2139062143);p=p+1|0;}while((p|0)<16);i=g;return}function hpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(e+4)|0;c[a+(e+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=e<<1;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;e=b+g|0;c[a+h>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=b+(g+4)|0;c[a+(h+4)>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function ipa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;iAa(g|0,b,8,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function jpa(a,b,c){a=a|0;b=b|0;c=c|0;iAa(a,b,c,c);return}function kpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;iAa(g|0,b,8,e);h=0;do{j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function lpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=g+16|0;k=j;l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=4-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e-l)|0;c[g+8>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4-l)|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+4|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;j=b+(n-l)|0;c[g+32>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+36>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+48>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+52>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+64>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+68>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+80>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+84>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+96>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+100>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;jAa(h|0,k,8,8);j=0;do{g=j<<3;n=c[k+g>>2]|0;m=h+g|0;b=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,e)|0;c[a+m>>2]=(b|n)-((b^n)>>>1&2139062143);n=g|4;g=c[k+n>>2]|0;b=h+n|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(m+4)>>2]=(n|g)-((n^g)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function mpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;iAa(h|0,b,8,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=4-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e-l)|0;c[g+8>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4-l)|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+4|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;jAa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(k,e)|0;c[a+g>>2]=(m|n)-((m^n)>>>1&2139062143);n=o|4;o=h+n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+n|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[a+(g+4)>>2]=(n|m)-((n^m)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function npa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+336|0;g=f+208|0;h=f+272|0;iAa(g|0,b,8,e);kAa(h|0,f|0,b,8,8,e);b=0;do{j=b<<3;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(b,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=j|4;j=g+l|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+l|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function opa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;iAa(h|0,b,8,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+4|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+e)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4+m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+4+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(m+o)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(o+4+m)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;jAa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(k,e)|0;c[a+g>>2]=(n|l)-((n^l)>>>1&2139062143);l=o|4;o=h+l|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+l|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[a+(g+4)>>2]=(l|n)-((l^n)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function ppa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+104|0;g=f|0;h=g+16|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=4-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e-j)|0;c[g+8>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e+4-j)|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+4|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e+4)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+32>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+36>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+48>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+52>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+64>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+68>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+80>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+84>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+96>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+100>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;jAa(a,h,e,8);i=f;return}function qpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+208|0;j=i;i=i+64|0;k=i;i=i+64|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=4-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e-m)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4-m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+4|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+36>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+40>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+44>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+48>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+52>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+56>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+60>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+64>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+68>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+76>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+80>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+84>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+88>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+92>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+96>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+100>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;jAa(j|0,l,8,8);kAa(k|0,h|0,b,8,8,e);b=0;do{h=b<<3;l=j+h|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+h|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(b,e)|0;c[a+l>>2]=(g|p)-((g^p)>>>1&2139062143);p=h|4;h=j+p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+(l+4)>>2]=(p|g)-((p^g)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function rpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+208|0;kAa(a,d|0,b,c,8,c);i=d;return}function spa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+208|0;j=i;i=i+64|0;k=i;i=i+64|0;l=g+16|0;m=e<<1;n=-m|1;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+4|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+e)|0;c[g+8>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+4+n)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+m)|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(m+4+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(n+p)|0;c[g+24>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(p+4+n)|0;c[g+28>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+36>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+40>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+44>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+48>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+52>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+56>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+60>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+64>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+68>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+72>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+76>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+80>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+84>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+88>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+92>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+96>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+100>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;jAa(j|0,l,8,8);kAa(k|0,h|0,b,8,8,e);b=0;do{h=b<<3;l=j+h|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+h|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(b,e)|0;c[a+l>>2]=(g|p)-((g^p)>>>1&2139062143);p=h|4;h=j+p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+(l+4)>>2]=(p|g)-((p^g)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function tpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=4-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(e-k)|0;c[g+8>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(e+4-k)|0;c[g+12>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+4|0;c[g+20>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+24|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;jAa(h|0,j,8,8);j=m;m=0;do{o=m<<3;g=c[j+o>>2]|0;n=h+o|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(m,e)|0;c[a+n>>2]=(l|g)-((l^g)>>>1&2139062143);g=o|4;o=c[j+g>>2]|0;l=h+g|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(n+4)>>2]=(g|o)-((g^o)>>>1&2139062143);m=m+1|0;}while((m|0)<8);i=f;return}function upa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;l=b+e|0;iAa(h|0,l,8,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=4-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e-m)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4-m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+4|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+32>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+36>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+40>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+44>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+48>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+52>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+56>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+60>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+64>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+68>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+76>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+80>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+84>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+88>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+92>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+96>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+100>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;jAa(j|0,k,8,8);k=0;do{l=k<<3;g=h+l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+l|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(k,e)|0;c[a+g>>2]=(n|o)-((n^o)>>>1&2139062143);o=l|4;l=h+o|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+o|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(g+4)>>2]=(o|n)-((o^n)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function vpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+336|0;g=f+208|0;h=f+272|0;iAa(g|0,b+e|0,8,e);kAa(h|0,f|0,b,8,8,e);b=0;do{j=b<<3;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(b,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=j|4;j=g+l|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+l|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function wpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;iAa(h|0,b+e|0,8,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+4|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+e)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4+m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+4+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(m+o)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(o+4+m)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;jAa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(k,e)|0;c[a+g>>2]=(n|l)-((n^l)>>>1&2139062143);l=o|4;o=h+l|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+l|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[a+(g+4)>>2]=(l|n)-((l^n)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function xpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=b+f|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;e=b+g|0;c[a+g>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function ypa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+16|0;g=f|0;fAa(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2139062143);j=b+e|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|h)-((j^h)>>>1&2139062143);h=e<<1;j=b+h|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+8>>2]|0;c[a+h>>2]=(j|k)-((j^k)>>>1&2139062143);k=e*3|0;e=b+k|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=c[g+12>>2]|0;c[a+k>>2]=(e|b)-((e^b)>>>1&2139062143);i=f;return}function zpa(a,b,c){a=a|0;b=b|0;c=c|0;fAa(a,b,c,c);return}function Apa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+16|0;g=f|0;fAa(g,b,4,e);h=b+1|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2139062143);j=b+(e+1)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|h)-((j^h)>>>1&2139062143);h=e<<1;j=b+(h|1)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+8>>2]|0;c[a+h>>2]=(j|k)-((j^k)>>>1&2139062143);k=e*3|0;e=b+(k+1)|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=c[g+12>>2]|0;c[a+k>>2]=(e|b)-((e^b)>>>1&2139062143);i=f;return}function Bpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=g+20|0;q=o+e|0;o=b+(q-k)|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=q+e|0;q=b+(o-k)|0;c[g+24>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=o+e|0;o=b+(q-k)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+q)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;gAa(h,j,4);o=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|o)-((j^o)>>>1&2139062143);o=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|o)-((m^o)>>>1&2139062143);o=c[n>>2]|0;n=c[h+8>>2]|0;c[a+k>>2]=(n|o)-((n^o)>>>1&2139062143);o=c[p>>2]|0;p=c[h+12>>2]|0;c[a+(e*3|0)>>2]=(p|o)-((p^o)>>>1&2139062143);i=f;return}function Cpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;fAa(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+32>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;gAa(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2139062143);k=c[h+4>>2]|0;n=c[j+4>>2]|0;c[a+e>>2]=(n|k)-((n^k)>>>1&2139062143);k=c[h+8>>2]|0;n=c[j+8>>2]|0;c[a+l>>2]=(n|k)-((n^k)>>>1&2139062143);k=c[h+12>>2]|0;h=c[j+12>>2]|0;c[a+(e*3|0)>>2]=(h|k)-((h^k)>>>1&2139062143);i=f;return}function Dpa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+88|0;f=e+72|0;g=i;i=i+16|0;fAa(f,b,4,d);hAa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+4>>2]|0;h=c[g+4>>2]|0;c[a+d>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+8>>2]|0;h=c[g+8>>2]|0;c[a+(d<<1)>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+12>>2]|0;f=c[g+12>>2]|0;c[a+(d*3|0)>>2]=(f|b)-((f^b)>>>1&2139062143);i=e;return}function Epa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;fAa(h,b,4,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;p=b+(m+o)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+28>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;gAa(j,k,4);k=c[h>>2]|0;p=c[j>>2]|0;c[a>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+4>>2]|0;p=c[j+4>>2]|0;c[a+e>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+8>>2]|0;p=c[j+8>>2]|0;c[a+l>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+12>>2]|0;h=c[j+12>>2]|0;c[a+(e*3|0)>>2]=(h|k)-((h^k)>>>1&2139062143);i=f;return}function Fpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+40|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+24>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+32>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;gAa(a,h,e);i=f;return}function Gpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+72|0;j=i;i=i+16|0;k=i;i=i+16|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;gAa(j,l,4);hAa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+4>>2]|0;h=c[k+4>>2]|0;c[a+e>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+8>>2]|0;h=c[k+8>>2]|0;c[a+m>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+12>>2]|0;j=c[k+12>>2]|0;c[a+(e*3|0)>>2]=(j|b)-((j^b)>>>1&2139062143);i=f;return}function Hpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+72|0;hAa(a,d|0,b,c,c);i=d;return}function Ipa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+40|0;g=f|0;h=i;i=i+72|0;j=i;i=i+16|0;k=i;i=i+16|0;l=g+8|0;m=e<<1;n=-m|1;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+m)|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;q=b+(n+p)|0;c[g+12>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=p+e|0;p=b+(q+n)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=q+e|0;q=b+(p+n)|0;c[g+20>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=p+e|0;p=b+(q+n)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=q+e|0;q=b+(p+n)|0;c[g+28>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=b+(o+p)|0;c[g+32>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;gAa(j,l,4);hAa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+4>>2]|0;h=c[k+4>>2]|0;c[a+e>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+8>>2]|0;h=c[k+8>>2]|0;c[a+m>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+12>>2]|0;j=c[k+12>>2]|0;c[a+(e*3|0)>>2]=(j|b)-((j^b)>>>1&2139062143);i=f;return}function Jpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=g+20|0;q=o+e|0;o=b+(q-k)|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=g+24|0;r=q+e|0;q=b+(r-k)|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=r+e|0;r=b+(q-k)|0;c[g+28>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;r=b+(l+q)|0;c[g+32>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;gAa(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2139062143);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2139062143);j=c[p>>2]|0;p=c[h+8>>2]|0;c[a+k>>2]=(p|j)-((p^j)>>>1&2139062143);j=c[o>>2]|0;o=c[h+12>>2]|0;c[a+(e*3|0)>>2]=(o|j)-((o^j)>>>1&2139062143);i=f;return}function Kpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;l=b+e|0;fAa(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;gAa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2139062143);k=c[h+4>>2]|0;o=c[j+4>>2]|0;c[a+e>>2]=(o|k)-((o^k)>>>1&2139062143);k=c[h+8>>2]|0;o=c[j+8>>2]|0;c[a+m>>2]=(o|k)-((o^k)>>>1&2139062143);k=c[h+12>>2]|0;h=c[j+12>>2]|0;c[a+(e*3|0)>>2]=(h|k)-((h^k)>>>1&2139062143);i=f;return}function Lpa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+88|0;f=e+72|0;g=i;i=i+16|0;fAa(f,b+d|0,4,d);hAa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+4>>2]|0;h=c[g+4>>2]|0;c[a+d>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+8>>2]|0;h=c[g+8>>2]|0;c[a+(d<<1)>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+12>>2]|0;f=c[g+12>>2]|0;c[a+(d*3|0)>>2]=(f|b)-((f^b)>>>1&2139062143);i=e;return}function Mpa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;fAa(h,b+e|0,4,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;p=b+(m+o)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+28>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;gAa(j,k,4);k=c[h>>2]|0;p=c[j>>2]|0;c[a>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+4>>2]|0;p=c[j+4>>2]|0;c[a+e>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+8>>2]|0;p=c[j+8>>2]|0;c[a+l>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+12>>2]|0;h=c[j+12>>2]|0;c[a+(e*3|0)>>2]=(h|k)-((h^k)>>>1&2139062143);i=f;return}function Npa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0;f=c;b[a>>1]=(d[f]|d[f+1|0]<<8)<<16>>16;f=c+e|0;b[a+e>>1]=(d[f]|d[f+1|0]<<8)<<16>>16;return}function Opa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;oAa(g,c,2,e);h=c;j=(d[h]|d[h+1|0]<<8)<<16>>16;h=b[g>>1]|0;b[a>>1]=(h|j)-(((h^j)&65535)>>>1&32639);j=c+e|0;c=(d[j]|d[j+1|0]<<8)<<16>>16;j=b[g+2>>1]|0;b[a+e>>1]=(j|c)-(((j^c)&65535)>>>1&32639);i=f;return}function Ppa(a,b,c){a=a|0;b=b|0;c=c|0;oAa(a,b,c,c);return}function Qpa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;oAa(g,c,2,e);h=c+1|0;j=(d[h]|d[h+1|0]<<8)<<16>>16;h=b[g>>1]|0;b[a>>1]=(h|j)-(((h^j)&65535)>>>1&32639);j=c+(e+1)|0;c=(d[j]|d[j+1|0]<<8)<<16>>16;j=b[g+2>>1]|0;b[a+e>>1]=(j|c)-(((j^c)&65535)>>>1&32639);i=f;return}function Rpa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=g+4|0;k=e<<1;l=c+(-k|0)|0;b[g>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=e-k|0;m=c+l|0;b[g+2>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=c;b[j>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=g+6|0;n=c+e|0;b[m>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=k+e+e|0;o=c+(n-k)|0;b[g+8>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=n+e|0;n=c+(o-k)|0;b[g+10>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=c+(l+o)|0;b[g+12>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;pAa(h,j,2);n=b[j>>1]|0;j=b[h>>1]|0;b[a>>1]=(j|n)-(((j^n)&65535)>>>1&32639);n=b[m>>1]|0;m=b[h+2>>1]|0;b[a+e>>1]=(m|n)-(((m^n)&65535)>>>1&32639);i=f;return}function Spa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=g+4|0;oAa(h,c,2,e);l=e<<1;m=c+(-l|0)|0;b[g>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=e-l|0;n=c+m|0;b[g+2>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=c;b[k>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=c+e|0;b[g+6>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=l+e+e|0;o=c+(n-l)|0;b[g+8>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=n+e|0;n=c+(o-l)|0;b[g+10>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=c+(m+o)|0;b[g+12>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;pAa(j,k,2);k=b[h>>1]|0;n=b[j>>1]|0;b[a>>1]=(n|k)-(((n^k)&65535)>>>1&32639);k=b[h+2>>1]|0;h=b[j+2>>1]|0;b[a+e>>1]=(h|k)-(((h^k)&65535)>>>1&32639);i=f;return}function Tpa(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+40|0;f=e+32|0;g=i;i=i+4|0;i=i+7&-8;oAa(f,c,2,d);qAa(g,e|0,c,2,d);c=b[f>>1]|0;h=b[g>>1]|0;b[a>>1]=(h|c)-(((h^c)&65535)>>>1&32639);c=b[f+2>>1]|0;f=b[g+2>>1]|0;b[a+d>>1]=(f|c)-(((f^c)&65535)>>>1&32639);i=e;return}function Upa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=g+4|0;oAa(h,c,2,e);l=e<<1;m=-l|1;n=c+m|0;b[g>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=m+e|0;o=c+n|0;b[g+2>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(m+l)|0;b[k>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l+e|0;l=c+(m+o)|0;b[g+6>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=o+e|0;o=c+(l+m)|0;b[g+8>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l+e|0;l=c+(o+m)|0;b[g+10>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c+(n+o)|0;b[g+12>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;pAa(j,k,2);k=b[h>>1]|0;l=b[j>>1]|0;b[a>>1]=(l|k)-(((l^k)&65535)>>>1&32639);k=b[h+2>>1]|0;h=b[j+2>>1]|0;b[a+e>>1]=(h|k)-(((h^k)&65535)>>>1&32639);i=f;return}function Vpa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f|0;h=g+4|0;j=e<<1;k=c+(-j|0)|0;b[g>>1]=(d[k]|d[k+1|0]<<8)<<16>>16;k=e-j|0;l=c+k|0;b[g+2>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c;b[h>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c+e|0;b[g+6>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=j+e+e|0;m=c+(l-j)|0;b[g+8>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=l+e|0;l=c+(m-j)|0;b[g+10>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c+(k+m)|0;b[g+12>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;pAa(a,h,e);i=f;return}function Wpa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f|0;h=i;i=i+28|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=i;i=i+4|0;i=i+7&-8;l=g+4|0;m=e<<1;n=c+(-m|0)|0;b[g>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=e-m|0;o=c+n|0;b[g+2>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c;b[l>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+e|0;b[g+6>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=m+e+e|0;p=c+(o-m)|0;b[g+8>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=o+e|0;o=c+(p-m)|0;b[g+10>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(n+p)|0;b[g+12>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;pAa(j,l,2);qAa(k,h|0,c,2,e);c=b[j>>1]|0;h=b[k>>1]|0;b[a>>1]=(h|c)-(((h^c)&65535)>>>1&32639);c=b[j+2>>1]|0;j=b[k+2>>1]|0;b[a+e>>1]=(j|c)-(((j^c)&65535)>>>1&32639);i=f;return}function Xpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+32|0;qAa(a,d|0,b,c,c);i=d;return}function Ypa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f|0;h=i;i=i+28|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=i;i=i+4|0;i=i+7&-8;l=g+4|0;m=e<<1;n=-m|1;o=c+n|0;b[g>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=n+e|0;p=c+o|0;b[g+2>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=c+(n+m)|0;b[l>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=m+e|0;m=c+(n+p)|0;b[g+6>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=p+e|0;p=c+(m+n)|0;b[g+8>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=m+e|0;m=c+(p+n)|0;b[g+10>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=c+(o+p)|0;b[g+12>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;pAa(j,l,2);qAa(k,h|0,c,2,e);c=b[j>>1]|0;h=b[k>>1]|0;b[a>>1]=(h|c)-(((h^c)&65535)>>>1&32639);c=b[j+2>>1]|0;j=b[k+2>>1]|0;b[a+e>>1]=(j|c)-(((j^c)&65535)>>>1&32639);i=f;return}function Zpa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=g+4|0;k=e<<1;l=c+(-k|0)|0;b[g>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=e-k|0;m=c+l|0;b[g+2>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=c;b[j>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=g+6|0;n=c+e|0;b[m>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=g+8|0;o=k+e+e|0;p=c+(o-k)|0;b[n>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=o+e|0;o=c+(p-k)|0;b[g+10>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(l+p)|0;b[g+12>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;pAa(h,j,2);j=b[m>>1]|0;m=b[h>>1]|0;b[a>>1]=(m|j)-(((m^j)&65535)>>>1&32639);j=b[n>>1]|0;n=b[h+2>>1]|0;b[a+e>>1]=(n|j)-(((n^j)&65535)>>>1&32639);i=f;return}function _pa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=g+4|0;l=c+e|0;oAa(h,l,2,e);m=e<<1;n=c+(-m|0)|0;b[g>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=e-m|0;o=c+n|0;b[g+2>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c;b[k>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l;b[g+6>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=m+e+e|0;l=c+(o-m)|0;b[g+8>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=o+e|0;o=c+(l-m)|0;b[g+10>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(n+l)|0;b[g+12>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;pAa(j,k,2);k=b[h>>1]|0;o=b[j>>1]|0;b[a>>1]=(o|k)-(((o^k)&65535)>>>1&32639);k=b[h+2>>1]|0;h=b[j+2>>1]|0;b[a+e>>1]=(h|k)-(((h^k)&65535)>>>1&32639);i=f;return}function $pa(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+40|0;f=e+32|0;g=i;i=i+4|0;i=i+7&-8;oAa(f,c+d|0,2,d);qAa(g,e|0,c,2,d);c=b[f>>1]|0;h=b[g>>1]|0;b[a>>1]=(h|c)-(((h^c)&65535)>>>1&32639);c=b[f+2>>1]|0;f=b[g+2>>1]|0;b[a+d>>1]=(f|c)-(((f^c)&65535)>>>1&32639);i=e;return}function aqa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=g+4|0;oAa(h,c+e|0,2,e);l=e<<1;m=-l|1;n=c+m|0;b[g>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=m+e|0;o=c+n|0;b[g+2>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(m+l)|0;b[k>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l+e|0;l=c+(m+o)|0;b[g+6>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=o+e|0;o=c+(l+m)|0;b[g+8>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l+e|0;l=c+(o+m)|0;b[g+10>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c+(n+o)|0;b[g+12>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;pAa(j,k,2);k=b[h>>1]|0;l=b[j>>1]|0;b[a>>1]=(l|k)-(((l^k)&65535)>>>1&32639);k=b[h+2>>1]|0;h=b[j+2>>1]|0;b[a+e>>1]=(h|k)-(((h^k)&65535)>>>1&32639);i=f;return}function bqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=f;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[i>>2]=(l|j)-((l^j)>>>1&2139062143);j=g+4|0;l=c[j>>2]|0;i=f+4|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[j>>2]=(k|l)-((k^l)>>>1&2139062143);l=h+1|0;if((l|0)<16){f=f+e|0;g=g+e|0;h=l}else{break}}h=b+8|0;b=a+8|0;a=0;while(1){g=b;f=c[g>>2]|0;l=h;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[g>>2]=(k|f)-((k^f)>>>1&2139062143);f=b+4|0;k=c[f>>2]|0;g=h+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[f>>2]=(l|k)-((l^k)>>>1&2139062143);k=a+1|0;if((k|0)<16){h=h+e|0;b=b+e|0;a=k}else{break}}return}function cqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f|0;iAa(g|0,b,16,e);iAa(g+8|0,b+8|0,16,e);h=e<<3;iAa(g+128|0,b+h|0,16,e);iAa(g+136|0,b+(h+8)|0,16,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=j+4|0;j=b+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+o|0;o=c[j>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[j>>2]=(m|o)-((m^o)>>>1&2139062143);o=h+1|0;if((o|0)<16){h=o}else{q=0;break}}do{h=ba(q,e)|0;o=h+8|0;m=b+o|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q<<4;p=g+(m|8)|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+o|0;o=c[p>>2]|0;l=(k|j)-((k^j)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=h+12|0;h=b+o|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(m|12)|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+o|0;o=c[h>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[h>>2]=(p|o)-((p^o)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function dqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;nAa(a,b,c,c);nAa(a+8|0,b+8|0,c,c);d=c<<3;nAa(a+d|0,b+d|0,c,c);e=d+8|0;nAa(a+e|0,b+e|0,c,c);return}function eqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f|0;iAa(g|0,b,16,e);iAa(g+8|0,b+8|0,16,e);h=e<<3;iAa(g+128|0,b+h|0,16,e);iAa(g+136|0,b+(h+8)|0,16,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=b+(j+5)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+(k|4)|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(j+4)|0;j=c[o>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[o>>2]=(m|j)-((m^j)>>>1&2139062143);j=h+1|0;if((j|0)<16){h=j}else{q=0;break}}do{h=ba(q,e)|0;j=b+(h+9)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=q<<4;o=g+(j|8)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(h+8)|0;k=c[o>>2]|0;l=(p|m)-((p^m)>>>1&2139062143)|0;c[o>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(j|12)|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+(h+12)|0;h=c[k>>2]|0;o=(j|l)-((j^l)>>>1&2139062143)|0;c[k>>2]=(o|h)-((o^h)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function fqa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+592|0;h=g|0;j=g+336|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=e;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+4|0;m=e+4|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+8|0;n=e+8|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+12|0;m=e+12|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+1|0;if((m|0)<21){k=k+f|0;e=e+16|0;l=m}else{break}}jAa(j|0,h+32|0,16,16);jAa(j+8|0,h+40|0,16,16);jAa(j+128|0,h+160|0,16,16);jAa(j+136|0,h+168|0,16,16);l=0;while(1){e=l<<4;k=h+(e+32)|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+e|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(l,f)|0;o=b+k|0;p=c[o>>2]|0;q=(n|m)-((n^m)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=e|4;e=h+(p+32)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(k+4)|0;k=c[e>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[e>>2]=(o|k)-((o^k)>>>1&2139062143);k=l+1|0;if((k|0)<16){l=k}else{r=0;break}}do{l=r<<4;k=h+(l+40)|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+(l|8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(r,f)|0;q=b+(k+8)|0;p=c[q>>2]|0;m=(e|o)-((e^o)>>>1&2139062143)|0;c[q>>2]=(m|p)-((m^p)>>>1&2139062143);p=h+((l|4)+40)|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+(l|12)|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(k+12)|0;k=c[p>>2]|0;q=(l|m)-((l^m)>>>1&2139062143)|0;c[p>>2]=(q|k)-((q^k)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function gqa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;iAa(j|0,e,16,f);iAa(j+8|0,e+8|0,16,f);l=f<<3;iAa(j+128|0,e+l|0,16,f);iAa(j+136|0,e+(l+8)|0,16,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=e;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+4|0;n=e+4|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+8|0;o=e+8|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+12|0;n=e+12|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+1|0;if((n|0)<21){l=l+f|0;e=e+16|0;m=n}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=0;while(1){m=h<<4;e=j+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(h,f)|0;o=b+e|0;p=c[o>>2]|0;q=(n|l)-((n^l)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=m|4;m=j+p|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(e+4)|0;e=c[m>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[m>>2]=(o|e)-((o^e)>>>1&2139062143);e=h+1|0;if((e|0)<16){h=e}else{r=0;break}}do{h=r<<4;e=h|8;o=j+e|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+e|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(r,f)|0;q=b+(o+8)|0;p=c[q>>2]|0;l=(e|m)-((e^m)>>>1&2139062143)|0;c[q>>2]=(l|p)-((l^p)>>>1&2139062143);p=h|12;h=j+p|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(o+12)|0;o=c[h>>2]|0;q=(p|l)-((p^l)>>>1&2139062143)|0;c[h>>2]=(q|o)-((q^o)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function hqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+1184|0;g=f|0;h=f+672|0;j=f+928|0;iAa(h|0,b,16,e);k=b+8|0;iAa(h+8|0,k,16,e);l=e<<3;m=b+l|0;iAa(h+128|0,m,16,e);n=b+(l+8)|0;iAa(h+136|0,n,16,e);l=g|0;kAa(j|0,l,b,16,16,e);b=g+16|0;kAa(j+8|0,b,k,16,16,e);kAa(j+128|0,l,m,16,16,e);kAa(j+136|0,b,n,16,16,e);n=0;while(1){b=n<<4;m=h+b|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+b|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(n,e)|0;g=a+m|0;o=c[g>>2]|0;p=(k|l)-((k^l)>>>1&2139062143)|0;c[g>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=h+o|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(m+4)|0;m=c[b>>2]|0;g=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(g|m)-((g^m)>>>1&2139062143);m=n+1|0;if((m|0)<16){n=m}else{q=0;break}}do{n=q<<4;m=n|8;g=h+m|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(q,e)|0;p=a+(g+8)|0;o=c[p>>2]|0;l=(m|b)-((m^b)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=n|12;n=h+o|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+o|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(g+12)|0;g=c[n>>2]|0;p=(o|l)-((o^l)>>>1&2139062143)|0;c[n>>2]=(p|g)-((p^g)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function iqa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;iAa(j|0,e,16,f);iAa(j+8|0,e+8|0,16,f);l=f<<3;iAa(j+128|0,e+l|0,16,f);iAa(j+136|0,e+(l+8)|0,16,f);l=e+(-(f<<1)|1)|0;e=h|0;m=0;while(1){n=l;o=e;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+4|0;n=e+4|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+8|0;o=e+8|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+12|0;n=e+12|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+1|0;if((n|0)<21){l=l+f|0;e=e+16|0;m=n}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=0;while(1){m=h<<4;e=j+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(h,f)|0;o=b+e|0;p=c[o>>2]|0;q=(n|l)-((n^l)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=m|4;m=j+p|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(e+4)|0;e=c[m>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[m>>2]=(o|e)-((o^e)>>>1&2139062143);e=h+1|0;if((e|0)<16){h=e}else{r=0;break}}do{h=r<<4;e=h|8;o=j+e|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+e|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(r,f)|0;q=b+(o+8)|0;p=c[q>>2]|0;l=(e|m)-((e^m)>>>1&2139062143)|0;c[q>>2]=(l|p)-((l^p)>>>1&2139062143);p=h|12;h=j+p|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(o+12)|0;o=c[h>>2]|0;q=(p|l)-((p^l)>>>1&2139062143)|0;c[h>>2]=(q|o)-((q^o)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function jqa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+336|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=c;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+4|0;k=c+4|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+8|0;l=c+8|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+12|0;k=c+12|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=j+1|0;if((k|0)<21){h=h+e|0;c=c+16|0;j=k}else{break}}mAa(b,g+32|0,e,16);mAa(b+8|0,g+40|0,e,16);j=e<<3;mAa(b+j|0,g+160|0,e,16);mAa(b+(j+8)|0,g+168|0,e,16);i=f;return}function kqa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1520|0;h=g|0;j=g+336|0;k=g+1008|0;l=g+1264|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=n;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+4|0;p=n+4|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+8|0;q=n+8|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+12|0;p=n+12|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+1|0;if((p|0)<21){m=m+f|0;n=n+16|0;o=p}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=j|0;kAa(l|0,h,e,16,16,f);o=j+16|0;kAa(l+8|0,o,e+8|0,16,16,f);j=f<<3;kAa(l+128|0,h,e+j|0,16,16,f);kAa(l+136|0,o,e+(j+8)|0,16,16,f);j=0;while(1){e=j<<4;o=k+e|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+e|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(j,f)|0;m=b+o|0;p=c[m>>2]|0;q=(n|h)-((n^h)>>>1&2139062143)|0;c[m>>2]=(q|p)-((q^p)>>>1&2139062143);p=e|4;e=k+p|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(o+4)|0;o=c[e>>2]|0;m=(p|q)-((p^q)>>>1&2139062143)|0;c[e>>2]=(m|o)-((m^o)>>>1&2139062143);o=j+1|0;if((o|0)<16){j=o}else{r=0;break}}do{j=r<<4;o=j|8;m=k+o|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+o|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(r,f)|0;q=b+(m+8)|0;p=c[q>>2]|0;h=(o|e)-((o^e)>>>1&2139062143)|0;c[q>>2]=(h|p)-((h^p)>>>1&2139062143);p=j|12;j=k+p|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+p|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(m+12)|0;m=c[j>>2]|0;q=(p|h)-((p^h)>>>1&2139062143)|0;c[j>>2]=(q|m)-((q^m)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function lqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+672|0;e=d|0;f=e|0;lAa(a,f,b,c,16,c);g=e+16|0;lAa(a+8|0,g,b+8|0,c,16,c);e=c<<3;lAa(a+e|0,f,b+e|0,c,16,c);f=e+8|0;lAa(a+f|0,g,b+f|0,c,16,c);i=d;return}function mqa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1520|0;h=g|0;j=g+336|0;k=g+1008|0;l=g+1264|0;m=e+(-(f<<1)|1)|0;n=h|0;o=0;while(1){p=m;q=n;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+4|0;p=n+4|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+8|0;q=n+8|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+12|0;p=n+12|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+1|0;if((p|0)<21){m=m+f|0;n=n+16|0;o=p}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=j|0;kAa(l|0,h,e,16,16,f);o=j+16|0;kAa(l+8|0,o,e+8|0,16,16,f);j=f<<3;kAa(l+128|0,h,e+j|0,16,16,f);kAa(l+136|0,o,e+(j+8)|0,16,16,f);j=0;while(1){e=j<<4;o=k+e|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+e|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(j,f)|0;m=b+o|0;p=c[m>>2]|0;q=(n|h)-((n^h)>>>1&2139062143)|0;c[m>>2]=(q|p)-((q^p)>>>1&2139062143);p=e|4;e=k+p|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(o+4)|0;o=c[e>>2]|0;m=(p|q)-((p^q)>>>1&2139062143)|0;c[e>>2]=(m|o)-((m^o)>>>1&2139062143);o=j+1|0;if((o|0)<16){j=o}else{r=0;break}}do{j=r<<4;o=j|8;m=k+o|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+o|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(r,f)|0;q=b+(m+8)|0;p=c[q>>2]|0;h=(o|e)-((o^e)>>>1&2139062143)|0;c[q>>2]=(h|p)-((h^p)>>>1&2139062143);p=j|12;j=k+p|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+p|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(m+12)|0;m=c[j>>2]|0;q=(p|h)-((p^h)>>>1&2139062143)|0;c[j>>2]=(q|m)-((q^m)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function nqa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+592|0;h=g|0;j=g+336|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=e;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+4|0;m=e+4|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+8|0;n=e+8|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+12|0;m=e+12|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+1|0;if((m|0)<21){k=k+f|0;e=e+16|0;l=m}else{break}}jAa(j|0,h+32|0,16,16);jAa(j+8|0,h+40|0,16,16);jAa(j+128|0,h+160|0,16,16);jAa(j+136|0,h+168|0,16,16);l=0;while(1){e=l<<4;k=h+(e+48)|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+e|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(l,f)|0;o=b+k|0;p=c[o>>2]|0;q=(n|m)-((n^m)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=e|4;e=h+(p+48)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(k+4)|0;k=c[e>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[e>>2]=(o|k)-((o^k)>>>1&2139062143);k=l+1|0;if((k|0)<16){l=k}else{r=0;break}}do{l=r<<4;k=h+(l+56)|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+(l|8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(r,f)|0;q=b+(k+8)|0;p=c[q>>2]|0;m=(e|o)-((e^o)>>>1&2139062143)|0;c[q>>2]=(m|p)-((m^p)>>>1&2139062143);p=h+((l|4)+56)|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+(l|12)|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(k+12)|0;k=c[p>>2]|0;q=(l|m)-((l^m)>>>1&2139062143)|0;c[p>>2]=(q|k)-((q^k)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function oqa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;iAa(j|0,e+f|0,16,f);l=f+8|0;iAa(j+8|0,e+l|0,16,f);m=f<<3;iAa(j+128|0,e+(m+f)|0,16,f);iAa(j+136|0,e+(l+m)|0,16,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=e;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+4|0;n=e+4|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+8|0;o=e+8|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+12|0;n=e+12|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+1|0;if((n|0)<21){m=m+f|0;e=e+16|0;l=n}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=0;while(1){l=h<<4;e=j+l|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+l|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(h,f)|0;o=b+e|0;p=c[o>>2]|0;q=(n|m)-((n^m)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=l|4;l=j+p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(e+4)|0;e=c[l>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[l>>2]=(o|e)-((o^e)>>>1&2139062143);e=h+1|0;if((e|0)<16){h=e}else{r=0;break}}do{h=r<<4;e=h|8;o=j+e|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+e|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(r,f)|0;q=b+(o+8)|0;p=c[q>>2]|0;m=(e|l)-((e^l)>>>1&2139062143)|0;c[q>>2]=(m|p)-((m^p)>>>1&2139062143);p=h|12;h=j+p|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(o+12)|0;o=c[h>>2]|0;q=(p|m)-((p^m)>>>1&2139062143)|0;c[h>>2]=(q|o)-((q^o)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function pqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+1184|0;g=f|0;h=f+672|0;j=f+928|0;iAa(h|0,b+e|0,16,e);iAa(h+8|0,b+(e+8)|0,16,e);k=e<<3;iAa(h+128|0,b+(k+e)|0,16,e);l=k+8|0;iAa(h+136|0,b+(l+e)|0,16,e);m=g|0;kAa(j|0,m,b,16,16,e);n=g+16|0;kAa(j+8|0,n,b+8|0,16,16,e);kAa(j+128|0,m,b+k|0,16,16,e);kAa(j+136|0,n,b+l|0,16,16,e);l=0;while(1){b=l<<4;n=h+b|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+b|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(l,e)|0;g=a+n|0;o=c[g>>2]|0;p=(m|k)-((m^k)>>>1&2139062143)|0;c[g>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=h+o|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(n+4)|0;n=c[b>>2]|0;g=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(g|n)-((g^n)>>>1&2139062143);n=l+1|0;if((n|0)<16){l=n}else{q=0;break}}do{l=q<<4;n=l|8;g=h+n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+n|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(q,e)|0;p=a+(g+8)|0;o=c[p>>2]|0;k=(n|b)-((n^b)>>>1&2139062143)|0;c[p>>2]=(k|o)-((k^o)>>>1&2139062143);o=l|12;l=h+o|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+o|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(g+12)|0;g=c[l>>2]|0;p=(o|k)-((o^k)>>>1&2139062143)|0;c[l>>2]=(p|g)-((p^g)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function qqa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;iAa(j|0,e+f|0,16,f);l=f+8|0;iAa(j+8|0,e+l|0,16,f);m=f<<3;iAa(j+128|0,e+(m+f)|0,16,f);iAa(j+136|0,e+(l+m)|0,16,f);m=e+(-(f<<1)|1)|0;e=h|0;l=0;while(1){n=m;o=e;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+4|0;n=e+4|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+8|0;o=e+8|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+12|0;n=e+12|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+1|0;if((n|0)<21){m=m+f|0;e=e+16|0;l=n}else{break}}jAa(k|0,h+32|0,16,16);jAa(k+8|0,h+40|0,16,16);jAa(k+128|0,h+160|0,16,16);jAa(k+136|0,h+168|0,16,16);h=0;while(1){l=h<<4;e=j+l|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+l|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ba(h,f)|0;o=b+e|0;p=c[o>>2]|0;q=(n|m)-((n^m)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=l|4;l=j+p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(e+4)|0;e=c[l>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[l>>2]=(o|e)-((o^e)>>>1&2139062143);e=h+1|0;if((e|0)<16){h=e}else{r=0;break}}do{h=r<<4;e=h|8;o=j+e|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+e|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(r,f)|0;q=b+(o+8)|0;p=c[q>>2]|0;m=(e|l)-((e^l)>>>1&2139062143)|0;c[q>>2]=(m|p)-((m^p)>>>1&2139062143);p=h|12;h=j+p|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(o+12)|0;o=c[h>>2]|0;q=(p|m)-((p^m)>>>1&2139062143)|0;c[h>>2]=(q|o)-((q^o)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function rqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=f;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[g>>2]=(j|h)-((j^h)>>>1&2139062143);h=b+4|0;j=c[h>>2]|0;g=f+4|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[h>>2]=(i|j)-((i^j)>>>1&2139062143);j=a+1|0;if((j|0)<8){f=f+e|0;b=b+e|0;a=j}else{break}}return}function sqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;iAa(g|0,b,8,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=j+4|0;j=b+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+o|0;o=c[j>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[j>>2]=(m|o)-((m^o)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function tqa(a,b,c){a=a|0;b=b|0;c=c|0;nAa(a,b,c,c);return}function uqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;iAa(g|0,b,8,e);h=0;do{j=ba(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=b+(j+5)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+(k|4)|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(j+4)|0;j=c[o>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[o>>2]=(m|j)-((m^j)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function vqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=g+16|0;k=j;l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=4-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e-l)|0;c[g+8>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4-l)|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+4|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;j=b+(n-l)|0;c[g+32>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+36>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+48>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+52>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+64>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+68>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+80>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+84>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+96>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+100>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;jAa(h|0,k,8,8);j=0;do{g=j<<3;n=c[k+g>>2]|0;m=h+g|0;b=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,e)|0;l=a+m|0;o=c[l>>2]|0;p=(b|n)-((b^n)>>>1&2139062143)|0;c[l>>2]=(p|o)-((p^o)>>>1&2139062143);o=g|4;g=c[k+o>>2]|0;p=h+o|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(m+4)|0;m=c[p>>2]|0;l=(o|g)-((o^g)>>>1&2139062143)|0;c[p>>2]=(l|m)-((l^m)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function wqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;iAa(h|0,b,8,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=4-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e-l)|0;c[g+8>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4-l)|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+4|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;jAa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(k,e)|0;b=a+g|0;l=c[b>>2]|0;p=(m|n)-((m^n)>>>1&2139062143)|0;c[b>>2]=(p|l)-((p^l)>>>1&2139062143);l=o|4;o=h+l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+l|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(g+4)|0;g=c[o>>2]|0;b=(l|p)-((l^p)>>>1&2139062143)|0;c[o>>2]=(b|g)-((b^g)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function xqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+336|0;g=f+208|0;h=f+272|0;iAa(g|0,b,8,e);kAa(h|0,f|0,b,8,8,e);b=0;do{j=b<<3;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(b,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=j|4;j=g+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+(k+4)|0;k=c[j>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[j>>2]=(n|k)-((n^k)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function yqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;iAa(h|0,b,8,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+4|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+e)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4+m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+4+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(m+o)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(o+4+m)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;jAa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(k,e)|0;b=a+g|0;m=c[b>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[b>>2]=(p|m)-((p^m)>>>1&2139062143);m=o|4;o=h+m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(g+4)|0;g=c[o>>2]|0;b=(m|p)-((m^p)>>>1&2139062143)|0;c[o>>2]=(b|g)-((b^g)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function zqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+104|0;g=f|0;h=g+16|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=4-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e-j)|0;c[g+8>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e+4-j)|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+4|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e+4)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+32>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+36>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+48>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+52>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+64>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+68>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+80>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+84>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+96>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+100>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;mAa(a,h,e,8);i=f;return}function Aqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+208|0;j=i;i=i+64|0;k=i;i=i+64|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=4-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e-m)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4-m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+4|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+36>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+40>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+44>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+48>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+52>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+56>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+60>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+64>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+68>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+76>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+80>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+84>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+88>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+92>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+96>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+100>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;jAa(j|0,l,8,8);kAa(k|0,h|0,b,8,8,e);b=0;do{h=b<<3;l=j+h|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+h|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(b,e)|0;o=a+l|0;n=c[o>>2]|0;m=(g|p)-((g^p)>>>1&2139062143)|0;c[o>>2]=(m|n)-((m^n)>>>1&2139062143);n=h|4;h=j+n|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(l+4)|0;l=c[h>>2]|0;o=(n|m)-((n^m)>>>1&2139062143)|0;c[h>>2]=(o|l)-((o^l)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function Bqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+208|0;lAa(a,d|0,b,c,8,c);i=d;return}function Cqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+208|0;j=i;i=i+64|0;k=i;i=i+64|0;l=g+16|0;m=e<<1;n=-m|1;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+4|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+e)|0;c[g+8>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+4+n)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+m)|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(m+4+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(n+p)|0;c[g+24>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(p+4+n)|0;c[g+28>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+36>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+40>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+44>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+48>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+52>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+56>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+60>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+64>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+68>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+72>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+76>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+80>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+84>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+88>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+92>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+96>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+100>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;jAa(j|0,l,8,8);kAa(k|0,h|0,b,8,8,e);b=0;do{h=b<<3;l=j+h|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+h|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ba(b,e)|0;m=a+l|0;o=c[m>>2]|0;n=(g|p)-((g^p)>>>1&2139062143)|0;c[m>>2]=(n|o)-((n^o)>>>1&2139062143);o=h|4;h=j+o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+o|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(l+4)|0;l=c[h>>2]|0;m=(o|n)-((o^n)>>>1&2139062143)|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function Dqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=4-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(e-k)|0;c[g+8>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(e+4-k)|0;c[g+12>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+4|0;c[g+20>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+24|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;jAa(h|0,j,8,8);j=m;m=0;do{o=m<<3;g=c[j+o>>2]|0;n=h+o|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(m,e)|0;b=a+n|0;k=c[b>>2]|0;p=(l|g)-((l^g)>>>1&2139062143)|0;c[b>>2]=(p|k)-((p^k)>>>1&2139062143);k=o|4;o=c[j+k>>2]|0;p=h+k|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+4)|0;n=c[p>>2]|0;b=(k|o)-((k^o)>>>1&2139062143)|0;c[p>>2]=(b|n)-((b^n)>>>1&2139062143);m=m+1|0;}while((m|0)<8);i=f;return}function Eqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;l=b+e|0;iAa(h|0,l,8,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=4-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e-m)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4-m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+4|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+32>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+36>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+40>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+44>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+48>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+52>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+56>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+60>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+64>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+68>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+76>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+80>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+84>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+88>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+92>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+96>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+100>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;jAa(j|0,k,8,8);k=0;do{l=k<<3;g=h+l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+l|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(k,e)|0;b=a+g|0;m=c[b>>2]|0;p=(n|o)-((n^o)>>>1&2139062143)|0;c[b>>2]=(p|m)-((p^m)>>>1&2139062143);m=l|4;l=h+m|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(g+4)|0;g=c[l>>2]|0;b=(m|p)-((m^p)>>>1&2139062143)|0;c[l>>2]=(b|g)-((b^g)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function Fqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+336|0;g=f+208|0;h=f+272|0;iAa(g|0,b+e|0,8,e);kAa(h|0,f|0,b,8,8,e);b=0;do{j=b<<3;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ba(b,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=j|4;j=g+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+(k+4)|0;k=c[j>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[j>>2]=(n|k)-((n^k)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function Gqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;iAa(h|0,b+e|0,8,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+4|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+e)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4+m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+4+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(m+o)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(o+4+m)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;jAa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(k,e)|0;b=a+g|0;m=c[b>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[b>>2]=(p|m)-((p^m)>>>1&2139062143);m=o|4;o=h+m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(g+4)|0;g=c[o>>2]|0;b=(m|p)-((m^p)>>>1&2139062143)|0;c[o>>2]=(b|g)-((b^g)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function Hqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=a;g=c[f>>2]|0;h=b;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[f>>2]=(i|g)-((i^g)>>>1&2139062143);g=a+e|0;i=c[g>>2]|0;f=b+e|0;h=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[g>>2]=(h|i)-((h^i)>>>1&2139062143);i=e<<1;h=a+i|0;g=c[h>>2]|0;f=b+i|0;j=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[h>>2]=(j|g)-((j^g)>>>1&2139062143);g=i+e|0;e=a+g|0;a=c[e>>2]|0;i=b+g|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[e>>2]=(g|a)-((g^a)>>>1&2139062143);return}function Iqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f|0;fAa(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;k=a;l=c[k>>2]|0;m=(h|j)-((h^j)>>>1&2139062143)|0;c[k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b+e|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=c[g+4>>2]|0;k=a+e|0;j=c[k>>2]|0;h=(l|m)-((l^m)>>>1&2139062143)|0;c[k>>2]=(h|j)-((h^j)>>>1&2139062143);j=e<<1;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g+8>>2]|0;m=a+j|0;j=c[m>>2]|0;l=(h|k)-((h^k)>>>1&2139062143)|0;c[m>>2]=(l|j)-((l^j)>>>1&2139062143);j=e*3|0;e=b+j|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=c[g+12>>2]|0;g=a+j|0;j=c[g>>2]|0;a=(e|b)-((e^b)>>>1&2139062143)|0;c[g>>2]=(a|j)-((a^j)>>>1&2139062143);i=f;return}function Jqa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=0;g=b;b=c;while(1){c=b+1|0;h=b-1|0;i=b+2|0;j=b+3|0;k=(((d[c]|0)+(d[b]|0)|0)*20|0)+16+(d[b-2|0]|0)+(((d[i]|0)+(d[h]|0)|0)*-5|0)+(d[j]|0)>>5;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[g]=((d[g]|0)+1+(l&255)|0)>>>1;k=g+1|0;m=b+4|0;n=(((d[i]|0)+(d[c]|0)|0)*20|0)+16+(d[h]|0)+(((d[j]|0)+(d[b]|0)|0)*-5|0)+(d[m]|0)>>5;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[k]=((d[k]|0)+1+(o&255)|0)>>>1;k=g+2|0;n=b+5|0;h=(((d[j]|0)+(d[i]|0)|0)*20|0)+16+(d[b]|0)+(((d[m]|0)+(d[c]|0)|0)*-5|0)+(d[n]|0)>>5;if(h>>>0>255>>>0){p=-h>>31&255}else{p=h&255}a[k]=((d[k]|0)+1+(p&255)|0)>>>1;k=g+3|0;h=(((d[m]|0)+(d[j]|0)|0)*20|0)+16+(d[c]|0)+(((d[n]|0)+(d[i]|0)|0)*-5|0)+(d[b+6|0]|0)>>5;if(h>>>0>255>>>0){q=-h>>31&255}else{q=h&255}a[k]=((d[k]|0)+1+(q&255)|0)>>>1;k=f+1|0;if((k|0)<4){f=k;g=g+e|0;b=b+e|0}else{break}}return}function Kqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f|0;fAa(g,b,4,e);h=b+1|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;k=a;l=c[k>>2]|0;m=(h|j)-((h^j)>>>1&2139062143)|0;c[k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b+(e+1)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=c[g+4>>2]|0;k=a+e|0;j=c[k>>2]|0;h=(l|m)-((l^m)>>>1&2139062143)|0;c[k>>2]=(h|j)-((h^j)>>>1&2139062143);j=e<<1;h=b+(j|1)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g+8>>2]|0;m=a+j|0;j=c[m>>2]|0;l=(h|k)-((h^k)>>>1&2139062143)|0;c[m>>2]=(l|j)-((l^j)>>>1&2139062143);j=e*3|0;e=b+(j+1)|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=c[g+12>>2]|0;g=a+j|0;j=c[g>>2]|0;a=(e|b)-((e^b)>>>1&2139062143)|0;c[g>>2]=(a|j)-((a^j)>>>1&2139062143);i=f;return}function Lqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=g+20|0;q=o+e|0;o=b+(q-k)|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=q+e|0;q=b+(o-k)|0;c[g+24>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=o+e|0;o=b+(q-k)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+q)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;gAa(h,j,4);o=c[j>>2]|0;j=c[h>>2]|0;g=a;q=c[g>>2]|0;l=(j|o)-((j^o)>>>1&2139062143)|0;c[g>>2]=(l|q)-((l^q)>>>1&2139062143);q=c[m>>2]|0;m=c[h+4>>2]|0;l=a+e|0;g=c[l>>2]|0;o=(m|q)-((m^q)>>>1&2139062143)|0;c[l>>2]=(o|g)-((o^g)>>>1&2139062143);g=c[n>>2]|0;n=c[h+8>>2]|0;o=a+k|0;k=c[o>>2]|0;l=(n|g)-((n^g)>>>1&2139062143)|0;c[o>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[p>>2]|0;p=c[h+12>>2]|0;h=a+(e*3|0)|0;e=c[h>>2]|0;a=(p|k)-((p^k)>>>1&2139062143)|0;c[h>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function Mqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;fAa(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+32>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;gAa(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;g=a;o=c[g>>2]|0;m=(n|k)-((n^k)>>>1&2139062143)|0;c[g>>2]=(m|o)-((m^o)>>>1&2139062143);o=c[h+4>>2]|0;m=c[j+4>>2]|0;g=a+e|0;k=c[g>>2]|0;n=(m|o)-((m^o)>>>1&2139062143)|0;c[g>>2]=(n|k)-((n^k)>>>1&2139062143);k=c[h+8>>2]|0;n=c[j+8>>2]|0;g=a+l|0;l=c[g>>2]|0;o=(n|k)-((n^k)>>>1&2139062143)|0;c[g>>2]=(o|l)-((o^l)>>>1&2139062143);l=c[h+12>>2]|0;h=c[j+12>>2]|0;j=a+(e*3|0)|0;e=c[j>>2]|0;a=(h|l)-((h^l)>>>1&2139062143)|0;c[j>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function Nqa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+88|0;f=e+72|0;g=i;i=i+16|0;fAa(f,b,4,d);hAa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;j=a;k=c[j>>2]|0;l=(h|b)-((h^b)>>>1&2139062143)|0;c[j>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[f+4>>2]|0;l=c[g+4>>2]|0;j=a+d|0;b=c[j>>2]|0;h=(l|k)-((l^k)>>>1&2139062143)|0;c[j>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+8>>2]|0;h=c[g+8>>2]|0;j=a+(d<<1)|0;k=c[j>>2]|0;l=(h|b)-((h^b)>>>1&2139062143)|0;c[j>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[f+12>>2]|0;f=c[g+12>>2]|0;g=a+(d*3|0)|0;d=c[g>>2]|0;a=(f|k)-((f^k)>>>1&2139062143)|0;c[g>>2]=(a|d)-((a^d)>>>1&2139062143);i=e;return}function Oqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;fAa(h,b,4,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;p=b+(m+o)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+28>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;gAa(j,k,4);k=c[h>>2]|0;p=c[j>>2]|0;g=a;o=c[g>>2]|0;n=(p|k)-((p^k)>>>1&2139062143)|0;c[g>>2]=(n|o)-((n^o)>>>1&2139062143);o=c[h+4>>2]|0;n=c[j+4>>2]|0;g=a+e|0;k=c[g>>2]|0;p=(n|o)-((n^o)>>>1&2139062143)|0;c[g>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+8>>2]|0;p=c[j+8>>2]|0;g=a+l|0;l=c[g>>2]|0;o=(p|k)-((p^k)>>>1&2139062143)|0;c[g>>2]=(o|l)-((o^l)>>>1&2139062143);l=c[h+12>>2]|0;h=c[j+12>>2]|0;j=a+(e*3|0)|0;e=c[j>>2]|0;a=(h|l)-((h^l)>>>1&2139062143)|0;c[j>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function Pqa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+40|0;h=g|0;j=h+8|0;k=f<<1;l=e+(-k|0)|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=f-k|0;m=e+l|0;c[h+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[j>>2]=n;m=e+f|0;c[h+12>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=k+f+f|0;o=e+(m-k)|0;c[h+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+f|0;m=e+(o-k)|0;c[h+20>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=o+f|0;o=e+(m-k)|0;c[h+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+f|0;m=e+(o-k)|0;c[h+28>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e+(l+o)|0;c[h+32>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=f*3|0;h=j;j=b;b=1;o=n&255;while(1){n=d[h-4|0]|0;l=o&255;e=d[h+4|0]|0;p=d[h+8|0]|0;q=d[h+12|0]|0;r=d[h+16|0]|0;s=d[h+20|0]|0;t=d[h+24|0]|0;u=(d[h-8|0]|0)+16+((e+l|0)*20|0)+q+((p+n|0)*-5|0)>>5;if(u>>>0>255>>>0){v=-u>>31&255}else{v=u&255}a[j]=((d[j]|0)+1+(v&255)|0)>>>1;u=j+f|0;w=n+16+((p+e|0)*20|0)+r+((q+l|0)*-5|0)>>5;if(w>>>0>255>>>0){x=-w>>31&255}else{x=w&255}a[u]=((d[u]|0)+1+(x&255)|0)>>>1;u=j+k|0;w=l+16+((q+p|0)*20|0)+s+((r+e|0)*-5|0)>>5;if(w>>>0>255>>>0){y=-w>>31&255}else{y=w&255}a[u]=((d[u]|0)+1+(y&255)|0)>>>1;u=j+m|0;w=e+16+((r+q|0)*20|0)+t+((s+p|0)*-5|0)>>5;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[u]=((d[u]|0)+1+(z&255)|0)>>>1;u=h+1|0;if((b|0)>=4){break}h=u;j=j+1|0;b=b+1|0;o=a[u]|0}i=g;return}function Qqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+72|0;j=i;i=i+16|0;k=i;i=i+16|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;gAa(j,l,4);hAa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;l=a;o=c[l>>2]|0;g=(h|b)-((h^b)>>>1&2139062143)|0;c[l>>2]=(g|o)-((g^o)>>>1&2139062143);o=c[j+4>>2]|0;g=c[k+4>>2]|0;l=a+e|0;b=c[l>>2]|0;h=(g|o)-((g^o)>>>1&2139062143)|0;c[l>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+8>>2]|0;h=c[k+8>>2]|0;l=a+m|0;m=c[l>>2]|0;o=(h|b)-((h^b)>>>1&2139062143)|0;c[l>>2]=(o|m)-((o^m)>>>1&2139062143);m=c[j+12>>2]|0;j=c[k+12>>2]|0;k=a+(e*3|0)|0;e=c[k>>2]|0;a=(j|m)-((j^m)>>>1&2139062143)|0;c[k>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function Rqa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+72|0;h=g|0;j=f<<1;k=e+(-j|0)|0;e=0;l=h|0;while(1){m=d[k]|0;n=d[k+1|0]|0;o=d[k-1|0]|0;p=d[k+2|0]|0;q=d[k+3|0]|0;b[l>>1]=(((d[k-2|0]|0)+((n+m&65535)*20&65535)&65535)+((p+o&65535)*-5&65535)&65535)+q;r=d[k+4|0]|0;b[l+2>>1]=((o+((p+n&65535)*20&65535)&65535)+((q+m&65535)*-5&65535)&65535)+r;o=d[k+5|0]|0;b[l+4>>1]=((m+((q+p&65535)*20&65535)&65535)+((r+n&65535)*-5&65535)&65535)+o;b[l+6>>1]=((n+((r+q&65535)*20&65535)&65535)+((o+p&65535)*-5&65535)&65535)+(d[k+6|0]|0);p=e+1|0;if((p|0)<9){k=k+f|0;e=p;l=l+8|0}else{break}}l=f*3|0;e=c;c=0;k=h+16|0;while(1){h=b[k-8>>1]|0;p=b[k>>1]|0;o=b[k+8>>1]|0;q=b[k+16>>1]|0;r=b[k+24>>1]|0;n=b[k+32>>1]|0;m=b[k+40>>1]|0;s=b[k+48>>1]|0;t=(b[k-16>>1]|0)+512+((o+p|0)*20|0)+r+((q+h|0)*-5|0)>>10;if(t>>>0>255>>>0){u=-t>>31&255}else{u=t&255}a[e]=((d[e]|0)+1+(u&255)|0)>>>1;t=e+f|0;v=h+512+((q+o|0)*20|0)+n+((r+p|0)*-5|0)>>10;if(v>>>0>255>>>0){w=-v>>31&255}else{w=v&255}a[t]=((d[t]|0)+1+(w&255)|0)>>>1;t=e+j|0;v=p+512+((r+q|0)*20|0)+m+((n+o|0)*-5|0)>>10;if(v>>>0>255>>>0){x=-v>>31&255}else{x=v&255}a[t]=((d[t]|0)+1+(x&255)|0)>>>1;t=e+l|0;v=o+512+((n+r|0)*20|0)+s+((m+q|0)*-5|0)>>10;if(v>>>0>255>>>0){y=-v>>31&255}else{y=v&255}a[t]=((d[t]|0)+1+(y&255)|0)>>>1;t=c+1|0;if((t|0)<4){e=e+1|0;c=t;k=k+2|0}else{break}}i=g;return}function Sqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+40|0;g=f|0;h=i;i=i+72|0;j=i;i=i+16|0;k=i;i=i+16|0;l=g+8|0;m=e<<1;n=-m|1;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+m)|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;q=b+(n+p)|0;c[g+12>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=p+e|0;p=b+(q+n)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=q+e|0;q=b+(p+n)|0;c[g+20>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=p+e|0;p=b+(q+n)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=q+e|0;q=b+(p+n)|0;c[g+28>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=b+(o+p)|0;c[g+32>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;gAa(j,l,4);hAa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;l=a;q=c[l>>2]|0;g=(h|b)-((h^b)>>>1&2139062143)|0;c[l>>2]=(g|q)-((g^q)>>>1&2139062143);q=c[j+4>>2]|0;g=c[k+4>>2]|0;l=a+e|0;b=c[l>>2]|0;h=(g|q)-((g^q)>>>1&2139062143)|0;c[l>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+8>>2]|0;h=c[k+8>>2]|0;l=a+m|0;m=c[l>>2]|0;q=(h|b)-((h^b)>>>1&2139062143)|0;c[l>>2]=(q|m)-((q^m)>>>1&2139062143);m=c[j+12>>2]|0;j=c[k+12>>2]|0;k=a+(e*3|0)|0;e=c[k>>2]|0;a=(j|m)-((j^m)>>>1&2139062143)|0;c[k>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function Tqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=g+20|0;q=o+e|0;o=b+(q-k)|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=g+24|0;r=q+e|0;q=b+(r-k)|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=r+e|0;r=b+(q-k)|0;c[g+28>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;r=b+(l+q)|0;c[g+32>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;gAa(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;r=a;g=c[r>>2]|0;q=(m|j)-((m^j)>>>1&2139062143)|0;c[r>>2]=(q|g)-((q^g)>>>1&2139062143);g=c[n>>2]|0;n=c[h+4>>2]|0;q=a+e|0;r=c[q>>2]|0;j=(n|g)-((n^g)>>>1&2139062143)|0;c[q>>2]=(j|r)-((j^r)>>>1&2139062143);r=c[p>>2]|0;p=c[h+8>>2]|0;j=a+k|0;k=c[j>>2]|0;q=(p|r)-((p^r)>>>1&2139062143)|0;c[j>>2]=(q|k)-((q^k)>>>1&2139062143);k=c[o>>2]|0;o=c[h+12>>2]|0;h=a+(e*3|0)|0;e=c[h>>2]|0;a=(o|k)-((o^k)>>>1&2139062143)|0;c[h>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function Uqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;l=b+e|0;fAa(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;gAa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;g=a;l=c[g>>2]|0;n=(o|k)-((o^k)>>>1&2139062143)|0;c[g>>2]=(n|l)-((n^l)>>>1&2139062143);l=c[h+4>>2]|0;n=c[j+4>>2]|0;g=a+e|0;k=c[g>>2]|0;o=(n|l)-((n^l)>>>1&2139062143)|0;c[g>>2]=(o|k)-((o^k)>>>1&2139062143);k=c[h+8>>2]|0;o=c[j+8>>2]|0;g=a+m|0;m=c[g>>2]|0;l=(o|k)-((o^k)>>>1&2139062143)|0;c[g>>2]=(l|m)-((l^m)>>>1&2139062143);m=c[h+12>>2]|0;h=c[j+12>>2]|0;j=a+(e*3|0)|0;e=c[j>>2]|0;a=(h|m)-((h^m)>>>1&2139062143)|0;c[j>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function Vqa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+88|0;f=e+72|0;g=i;i=i+16|0;fAa(f,b+d|0,4,d);hAa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;j=a;k=c[j>>2]|0;l=(h|b)-((h^b)>>>1&2139062143)|0;c[j>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[f+4>>2]|0;l=c[g+4>>2]|0;j=a+d|0;b=c[j>>2]|0;h=(l|k)-((l^k)>>>1&2139062143)|0;c[j>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+8>>2]|0;h=c[g+8>>2]|0;j=a+(d<<1)|0;k=c[j>>2]|0;l=(h|b)-((h^b)>>>1&2139062143)|0;c[j>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[f+12>>2]|0;f=c[g+12>>2]|0;g=a+(d*3|0)|0;d=c[g>>2]|0;a=(f|k)-((f^k)>>>1&2139062143)|0;c[g>>2]=(a|d)-((a^d)>>>1&2139062143);i=e;return}function Wqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;fAa(h,b+e|0,4,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;p=b+(m+o)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+28>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;gAa(j,k,4);k=c[h>>2]|0;p=c[j>>2]|0;g=a;o=c[g>>2]|0;n=(p|k)-((p^k)>>>1&2139062143)|0;c[g>>2]=(n|o)-((n^o)>>>1&2139062143);o=c[h+4>>2]|0;n=c[j+4>>2]|0;g=a+e|0;k=c[g>>2]|0;p=(n|o)-((n^o)>>>1&2139062143)|0;c[g>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+8>>2]|0;p=c[j+8>>2]|0;g=a+l|0;l=c[g>>2]|0;o=(p|k)-((p^k)>>>1&2139062143)|0;c[g>>2]=(o|l)-((o^l)>>>1&2139062143);l=c[h+12>>2]|0;h=c[j+12>>2]|0;j=a+(e*3|0)|0;e=c[j>>2]|0;a=(h|l)-((h^l)>>>1&2139062143)|0;c[j>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function Xqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=e+8|0;h=b+f|0;g=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=h;h=e<<1;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;j=b+g|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+g|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=b+16|0;h=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+16|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=j;j=b+24|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+24|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=e+16|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=e+24|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;e=b+h|0;f=e|0;g=e+4|0;e=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+h|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=e;e=h+8|0;h=b+e|0;b=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[g+4>>2]=h;return}function Yqa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;Yza(g|0,b,32,e);Yza(g+16|0,b+16|0,32,e);h=e<<3;Yza(g+256|0,b+h|0,32,e);Yza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=ZGb(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ba(r,e)|0;l=h+16|0;k=b+l|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r<<5;p=g+(o|16)|0;j=p|0;q=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p+4|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p^k;n=ZGb(q|m,p|k,((q^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+l|0;c[j>>2]=n;c[j+4>>2]=F;j=h+24|0;h=b+j|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+(o|24)|0;o=n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^h;q=ZGb(m|l,n|h,((m^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;r=r+1|0;}while((r|0)<16);i=f;return}function Zqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Yza(a,b,c,c);Yza(a+16|0,b+16|0,c,c);d=c<<3;Yza(a+d|0,b+d|0,c,c);e=d+16|0;Yza(a+e|0,b+e|0,c,c);return}function _qa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;Yza(g|0,b,32,e);Yza(g+16|0,b+16|0,32,e);h=e<<3;Yza(g+256|0,b+h|0,32,e);Yza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=ZGb(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ba(r,e)|0;l=b+(h+18)|0;k=l|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=l+4|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=r<<5;m=g+(k|16)|0;p=m|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^l;q=ZGb(o|j,m|l,((o^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(h+16)|0;c[p>>2]=q;c[p+4>>2]=F;p=b+(h+26)|0;q=p|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(k|24)|0;k=q|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q^p;l=ZGb(o|j,q|p,((o^j)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(h+24)|0;c[k>>2]=l;c[k+4>>2]=F;r=r+1|0;}while((r|0)<16);i=f;return}function $qa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Zza(j|0,h+64|0,32,32);Zza(j+16|0,h+80|0,32,32);Zza(j+256|0,h+320|0,32,32);Zza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=ZGb(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=F;m=e|8;e=h+(m+64)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=ZGb(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+64)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=ZGb(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=F;n=l|24;l=h+(n+64)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=ZGb(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function ara(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Yza(j|0,e,32,f);Yza(j+16|0,e+16|0,32,f);l=f<<3;Yza(j+256|0,e+l|0,32,f);Yza(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=ZGb(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=ZGb(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=ZGb(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=F;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=ZGb(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function bra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;Yza(h|0,b,32,e);k=b+16|0;Yza(h+16|0,k,32,e);l=e<<3;m=b+l|0;Yza(h+256|0,m,32,e);n=b+(l+16)|0;Yza(h+272|0,n,32,e);l=g|0;_za(j|0,l,b,32,32,e);b=g+16|0;_za(j+16|0,b,k,32,32,e);_za(j+256|0,l,m,32,32,e);_za(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l^m;p=ZGb(o|k,l|m,((o^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ba(n,e)|0;k=a+g|0;c[k>>2]=p;c[k+4>>2]=F;k=b|8;b=h+k|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+k|0;k=p|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p+4|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p^b;l=ZGb(m|o,p|b,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(g+8)|0;c[k>>2]=l;c[k+4>>2]=F;k=n+1|0;if((k|0)<16){n=k}else{q=0;break}}do{n=q<<5;k=n|16;l=h+k|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+k|0;k=g|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^l;b=ZGb(m|o,g|l,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=ba(q,e)|0;o=a+(k+16)|0;c[o>>2]=b;c[o+4>>2]=F;o=n|24;n=h+o|0;b=n|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=n+4|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^n;g=ZGb(l|m,b|n,((l^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(k+24)|0;c[o>>2]=g;c[o+4>>2]=F;q=q+1|0;}while((q|0)<16);i=f;return}function cra(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Yza(j|0,e,32,f);Yza(j+16|0,e+16|0,32,f);l=f<<3;Yza(j+256|0,e+l|0,32,f);Yza(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=ZGb(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=ZGb(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=ZGb(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=F;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=ZGb(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function dra(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+4|0;x=l;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}Zza(b,g+64|0,e,32);Zza(b+16|0,g+80|0,e,32);j=e<<3;Zza(b+j|0,g+320|0,e,32);Zza(b+(j+16)|0,g+336|0,e,32);i=f;return}function era(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=j|0;_za(l|0,h,e,32,32,f);o=j+16|0;_za(l+16|0,o,e+16|0,32,32,f);j=f<<3;_za(l+256|0,h,e+j|0,32,32,f);_za(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=ZGb(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=F;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=ZGb(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=F;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=ZGb(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=F;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=ZGb(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=F;t=t+1|0;}while((t|0)<16);i=g;return}function fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+1344|0;e=d|0;f=e|0;_za(a,f,b,c,32,c);g=e+16|0;_za(a+16|0,g,b+16|0,c,32,c);e=c<<3;_za(a+e|0,f,b+e|0,c,32,c);f=e+16|0;_za(a+f|0,g,b+f|0,c,32,c);i=d;return}function gra(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=j|0;_za(l|0,h,e,32,32,f);o=j+16|0;_za(l+16|0,o,e+16|0,32,32,f);j=f<<3;_za(l+256|0,h,e+j|0,32,32,f);_za(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=ZGb(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=F;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=ZGb(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=F;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=ZGb(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=F;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=ZGb(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=F;t=t+1|0;}while((t|0)<16);i=g;return}function hra(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Zza(j|0,h+64|0,32,32);Zza(j+16|0,h+80|0,32,32);Zza(j+256|0,h+320|0,32,32);Zza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=ZGb(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=F;m=e|8;e=h+(m+96)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=ZGb(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+96)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=ZGb(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=F;n=l|24;l=h+(n+96)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=ZGb(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function ira(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Yza(j|0,e+f|0,32,f);l=f+16|0;Yza(j+16|0,e+l|0,32,f);m=f<<3;Yza(j+256|0,e+(m+f)|0,32,f);Yza(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=ZGb(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=ZGb(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=ZGb(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=F;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=ZGb(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function jra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;Yza(h|0,b+e|0,32,e);Yza(h+16|0,b+(e+16)|0,32,e);k=e<<3;Yza(h+256|0,b+(k+e)|0,32,e);l=k+16|0;Yza(h+272|0,b+(l+e)|0,32,e);m=g|0;_za(j|0,m,b,32,32,e);n=g+16|0;_za(j+16|0,n,b+16|0,32,32,e);_za(j+256|0,m,b+k|0,32,32,e);_za(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k^n;p=ZGb(o|m,k|n,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ba(l,e)|0;m=a+g|0;c[m>>2]=p;c[m+4>>2]=F;m=b|8;b=h+m|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+m|0;m=p|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^b;k=ZGb(n|o,p|b,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(g+8)|0;c[m>>2]=k;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{q=0;break}}do{l=q<<5;m=l|16;k=h+m|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=g|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+4|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g^k;b=ZGb(n|o,g|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(q,e)|0;o=a+(m+16)|0;c[o>>2]=b;c[o+4>>2]=F;o=l|24;l=h+o|0;b=l|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=l+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^l;g=ZGb(k|n,b|l,((k^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(m+24)|0;c[o>>2]=g;c[o+4>>2]=F;q=q+1|0;}while((q|0)<16);i=f;return}function kra(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Yza(j|0,e+f|0,32,f);l=f+16|0;Yza(j+16|0,e+l|0,32,f);m=f<<3;Yza(j+256|0,e+(m+f)|0,32,f);Yza(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=ZGb(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=ZGb(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=ZGb(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=F;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=ZGb(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function lra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+(e+8)|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+(e+8)|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=e<<1;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=b+(g+8)|0;j=f|0;i=f+4|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(h+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=f;f=g+e|0;g=h+e|0;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;e=b+g|0;f=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=e;e=b+(g+8)|0;g=e|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(h+8)|0;c[b>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[b+4>>2]=e;return}function mra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;Yza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=ZGb(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function nra(a,b,c){a=a|0;b=b|0;c=c|0;Yza(a,b,c,c);return}function ora(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;Yza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=ZGb(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function pra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;Zza(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k^b;h=ZGb(m|g,k|b,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(p,e)|0;g=a+o|0;c[g>>2]=h;c[g+4>>2]=F;g=n|8;n=l+g|0;h=c[n>>2]|0;m=c[n+4>>2]|0;n=j+g|0;g=n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^m;k=ZGb(b|h,n|m,((b^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(o+8)|0;c[g>>2]=k;c[g+4>>2]=F;p=p+1|0;}while((p|0)<8);i=f;return}function qra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Yza(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;Zza(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o^n;m=ZGb(h|g,o|n,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=m;c[g+4>>2]=F;g=p|8;p=j+g|0;m=p|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+g|0;g=m|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m+4|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m^p;o=ZGb(n|h,m|p,((n^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=o;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function rra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;Yza(g|0,b,16,e);_za(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=ZGb(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=F;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=ZGb(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function sra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Yza(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Zza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=ZGb(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=ZGb(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function tra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;Zza(a,j,e,16);i=f;return}function ura(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;Zza(k|0,m,16,16);_za(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q^m;h=ZGb(g|o,q|m,((g^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=ba(b,e)|0;o=a+p|0;c[o>>2]=h;c[o+4>>2]=F;o=j|8;j=k+o|0;h=j|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+o|0;o=h|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h^j;q=ZGb(m|g,h|j,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(p+8)|0;c[o>>2]=q;c[o+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function vra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+416|0;_za(a,d|0,b,c,16,c);i=d;return}function wra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;Zza(k|0,m,16,16);_za(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h^m;n=ZGb(g|p,h|m,((g^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(b,e)|0;p=a+q|0;c[p>>2]=n;c[p+4>>2]=F;p=j|8;j=k+p|0;n=j|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^j;h=ZGb(m|g,n|j,((m^g)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(q+8)|0;c[p>>2]=h;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function xra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;Zza(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^g;l=ZGb(h|p,m|g,((h^p)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(o,e)|0;p=a+b|0;c[p>>2]=l;c[p+4>>2]=F;p=n|8;n=k+p|0;l=c[n>>2]|0;h=c[n+4>>2]|0;n=j+p|0;p=n|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^h;m=ZGb(g|l,n|h,((g^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(b+8)|0;c[p>>2]=m;c[p+4>>2]=F;o=o+1|0;}while((o|0)<8);i=f;return}function yra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;Yza(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;Zza(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^o;n=ZGb(h|g,m|o,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=q|8;q=j+g|0;n=q|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^q;m=ZGb(o|h,n|q,((o^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=m;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function zra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;Yza(g|0,b+e|0,16,e);_za(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=ZGb(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=F;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=ZGb(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Ara(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Yza(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Zza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=ZGb(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=ZGb(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Bra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+e|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=b+f|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=f+e|0;e=b+g|0;b=e|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[f+4>>2]=e;return}function Cra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;Vza(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=ZGb(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=F;h=b+e|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=ZGb(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=F;n=e<<1;m=b+n|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=ZGb(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=F;l=e*3|0;e=b+l|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=ZGb(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=F;i=f;return}function Dra(a,b,c){a=a|0;b=b|0;c=c|0;Vza(a,b,c,c);return}function Era(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;Vza(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=ZGb(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=F;h=b+(e+2)|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=ZGb(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=F;n=e<<1;m=b+(n+2)|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=ZGb(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=F;l=e*3|0;e=b+(l+2)|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=ZGb(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=F;i=f;return}function Fra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;Wza(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=p^s;h=ZGb(l|g,p|s,((l^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=h;c[k+4>>2]=F;k=c[o>>2]|0;h=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;l=c[o+4>>2]|0;o=l^h;s=ZGb(g|k,l|h,((g^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+e|0;c[o>>2]=s;c[o+4>>2]=F;o=c[n>>2]|0;s=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;g=c[n+4>>2]|0;n=g^s;h=ZGb(k|o,g|s,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+m|0;c[n>>2]=h;c[n+4>>2]=F;n=c[q>>2]|0;h=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;m=c[q+4>>2]|0;q=m^h;o=ZGb(j|n,m|h,((j^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+(e*3|0)|0;c[q>>2]=o;c[q+4>>2]=F;i=f;return}function Gra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Vza(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;Wza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=r^g;q=ZGb(k|n,r|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=q;c[m+4>>2]=F;m=j+8|0;q=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;r=ZGb(k|q,g|n,((k^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^q;g=ZGb(k|r,n|q,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=r;c[m+4>>2]=F;i=f;return}function Hra(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;Vza(f,b,8,d);Xza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=ZGb(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=F;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=ZGb(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=F;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=ZGb(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=ZGb(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=F;i=e;return}function Ira(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Vza(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Wza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=ZGb(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=F;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=F;i=f;return}function Jra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+72|0;g=f|0;h=g|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=g+8|0;h=e-k|0;m=b+h|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=m;m=b;l=m|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=m;m=g+24|0;l=b+e|0;n=l|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=l;l=g+32|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=n;n=g+40|0;l=m+e|0;m=b+(l-k)|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;m=g+48|0;n=l+e|0;l=b+(n-k)|0;o=l|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=l;l=g+56|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[l+4>>2]=n;n=g+64|0;g=b+(h+m)|0;m=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=g;Wza(a,j,e);i=f;return}function Kra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Wza(k,o,8);Xza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=ZGb(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=F;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=ZGb(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=F;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=ZGb(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=ZGb(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=F;i=f;return}function Lra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+144|0;Xza(a,d|0,b,c,c);i=d;return}function Mra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;Wza(k,o,8);Xza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=ZGb(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=F;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=ZGb(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=F;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=ZGb(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=ZGb(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=F;i=f;return}function Nra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;Wza(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=s^g;t=ZGb(o|l,s|g,((o^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=t;c[k+4>>2]=F;k=c[n>>2]|0;t=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^t;g=ZGb(l|k,o|t,((l^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=g;c[n+4>>2]=F;n=c[q>>2]|0;g=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;l=c[q+4>>2]|0;q=l^g;t=ZGb(k|n,l|g,((k^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+m|0;c[q>>2]=t;c[q+4>>2]=F;q=c[p>>2]|0;t=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;m=c[p+4>>2]|0;p=m^t;n=ZGb(j|q,m|t,((j^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(e*3|0)|0;c[p>>2]=n;c[p+4>>2]=F;i=f;return}function Ora(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;Vza(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;Wza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=ZGb(k|n,o|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;o=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=o;c[m+4>>2]=F;m=j+16|0;o=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|o,n|r,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+p|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;p=c[m+4>>2]|0;m=p^g;o=ZGb(l|j,p|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=o;c[m+4>>2]=F;i=f;return}function Pra(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;Vza(f,b+d|0,8,d);Xza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=ZGb(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=F;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=ZGb(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=F;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=ZGb(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=ZGb(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=F;i=e;return}function Qra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Vza(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Wza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=ZGb(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=F;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=F;i=f;return}function Rra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;return}function Sra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;cAa(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+e|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function Tra(a,b,c){a=a|0;b=b|0;c=c|0;cAa(a,b,c,c);return}function Ura(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;cAa(g,b,4,e);h=b+2|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+(e+2)|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function Vra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;dAa(h,j,4);n=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|n)-((j^n)>>>1&2147450879);n=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|n)-((m^n)>>>1&2147450879);i=f;return}function Wra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;cAa(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;dAa(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function Xra(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+64|0;f=e+56|0;g=i;i=i+8|0;cAa(f,b,4,d);eAa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function Yra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;cAa(h,b,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;dAa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function Zra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+32|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;dAa(a,h,e);i=f;return}function _ra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+56|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;dAa(j,l,4);eAa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function $ra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+56|0;eAa(a,d|0,b,c,c);i=d;return}function asa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+56|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=2-m|0;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+2|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+2)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e+e|0;m=b+(p+n)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;dAa(j,l,4);eAa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function bsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-k)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;dAa(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2147450879);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2147450879);i=f;return}function csa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;l=b+e|0;cAa(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;dAa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function dsa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+64|0;f=e+56|0;g=i;i=i+8|0;cAa(f,b+d|0,4,d);eAa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function esa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;cAa(h,b+e|0,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;dAa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function fsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=c[i+4>>2]|0;l=f;m=l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l^k;o=ZGb(n|j,l|k,((n^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[i>>2]=o;c[i+4>>2]=F;i=g+8|0;o=c[i>>2]|0;m=c[i+4>>2]|0;j=f+8|0;n=j|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j^m;l=ZGb(k|o,j|m,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[i>>2]=l;c[i+4>>2]=F;i=h+1|0;if((i|0)<16){f=f+e|0;g=g+e|0;h=i}else{break}}h=b+16|0;b=a+16|0;a=0;while(1){g=b;f=c[g>>2]|0;i=c[g+4>>2]|0;l=h;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^i;k=ZGb(o|f,l|i,((o^f)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[g>>2]=k;c[g+4>>2]=F;g=b+8|0;k=c[g>>2]|0;n=c[g+4>>2]|0;f=h+8|0;o=f|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f+4|0;f=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f^n;l=ZGb(i|k,f|n,((i^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[g>>2]=l;c[g+4>>2]=F;g=a+1|0;if((g|0)<16){h=h+e|0;b=b+e|0;a=g}else{break}}return}function gsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;Yza(g|0,b,32,e);Yza(g+16|0,b+16|0,32,e);h=e<<3;Yza(g+256|0,b+h|0,32,e);Yza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=ZGb(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ba(u,e)|0;l=h+16|0;q=b+l|0;m=q|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=u<<5;s=g+(m|16)|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+l|0;l=c[t>>2]|0;j=c[t+4>>2]|0;p=s^q;k=ZGb(r|o,s|q,((r^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;o=p^j;r=ZGb(k|l,p|j,((k^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;t=h+24|0;h=b+t|0;r=h|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+(m|24)|0;m=r|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r+4|0;r=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+t|0;t=c[m>>2]|0;k=c[m+4>>2]|0;j=r^h;p=ZGb(l|o,r|h,((l^o)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;o=j^k;l=ZGb(p|t,j|k,((p^t)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function hsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;bAa(a,b,c,c);bAa(a+16|0,b+16|0,c,c);d=c<<3;bAa(a+d|0,b+d|0,c,c);e=d+16|0;bAa(a+e|0,b+e|0,c,c);return}function isa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;Yza(g|0,b,32,e);Yza(g+16|0,b+16|0,32,e);h=e<<3;Yza(g+256|0,b+h|0,32,e);Yza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=ZGb(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ba(u,e)|0;l=b+(h+18)|0;q=l|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=u<<5;j=g+(q|16)|0;s=j|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=a+(h+16)|0;r=c[s>>2]|0;o=c[s+4>>2]|0;p=j^l;k=ZGb(t|m,j|l,((t^m)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;m=p^o;t=ZGb(k|r,p|o,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[s>>2]=t;c[s+4>>2]=F;s=b+(h+26)|0;t=s|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=g+(q|24)|0;q=t|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=t+4|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=a+(h+24)|0;h=c[q>>2]|0;k=c[q+4>>2]|0;o=t^s;p=ZGb(r|m,t|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;m=o^k;r=ZGb(p|h,o|k,((p^h)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function jsa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Zza(j|0,h+64|0,32,32);Zza(j+16|0,h+80|0,32,32);Zza(j+256|0,h+320|0,32,32);Zza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=ZGb(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;m=t^s;n=ZGb(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=F;q=e|8;e=h+(q+64)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=ZGb(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^u;r=ZGb(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+80)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=ZGb(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=F;m=n^e;t=ZGb(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h+((l|8)+80)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=ZGb(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^k;s=ZGb(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function ksa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Yza(j|0,e,32,f);Yza(j+16|0,e+16|0,32,f);l=f<<3;Yza(j+256|0,e+l|0,32,f);Yza(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=ZGb(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=ZGb(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^m;t=ZGb(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^e;s=ZGb(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function lsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;Yza(h|0,b,32,e);k=b+16|0;Yza(h+16|0,k,32,e);l=e<<3;m=b+l|0;Yza(h+256|0,m,32,e);n=b+(l+16)|0;Yza(h+272|0,n,32,e);l=g|0;_za(j|0,l,b,32,32,e);b=g+16|0;_za(j+16|0,b,k,32,32,e);_za(j+256|0,l,m,32,32,e);_za(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(n,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^m;t=ZGb(o|k,l|m,((o^k)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;k=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=b|8;b=h+p|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=ZGb(q|k,o|b,((q^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;k=r^t;q=ZGb(s|g,r|t,((s^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;p=n+1|0;if((p|0)<16){n=p}else{u=0;break}}do{n=u<<5;p=n|16;q=h+p|0;k=q|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+p|0;p=k|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=k^q;m=ZGb(s|g,k|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;g=o^b;s=ZGb(m|r,o|b,((m^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=F;t=n|24;n=h+t|0;s=n|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;m=c[t+4>>2]|0;b=s^n;o=ZGb(r|g,s|n,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;g=b^m;r=ZGb(o|p,b|m,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function msa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Yza(j|0,e,32,f);Yza(j+16|0,e+16|0,32,f);l=f<<3;Yza(j+256|0,e+l|0,32,f);Yza(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=ZGb(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=ZGb(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^m;t=ZGb(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^e;s=ZGb(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function nsa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+4|0;x=l;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}aAa(b,g+64|0,e,32);aAa(b+16|0,g+80|0,e,32);j=e<<3;aAa(b+j|0,g+320|0,e,32);aAa(b+(j+16)|0,g+336|0,e,32);i=f;return}function osa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=j|0;_za(l|0,h,e,32,32,f);o=j+16|0;_za(l+16|0,o,e+16|0,32,32,f);j=f<<3;_za(l+256|0,h,e+j|0,32,32,f);_za(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=ZGb(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;n=t^q;s=ZGb(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=F;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=ZGb(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=F;n=q^u;r=ZGb(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=F;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=ZGb(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^e;t=ZGb(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=ZGb(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^o;q=ZGb(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function psa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+1344|0;e=d|0;f=e|0;$za(a,f,b,c,32,c);g=e+16|0;$za(a+16|0,g,b+16|0,c,32,c);e=c<<3;$za(a+e|0,f,b+e|0,c,32,c);f=e+16|0;$za(a+f|0,g,b+f|0,c,32,c);i=d;return}function qsa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=j|0;_za(l|0,h,e,32,32,f);o=j+16|0;_za(l+16|0,o,e+16|0,32,32,f);j=f<<3;_za(l+256|0,h,e+j|0,32,32,f);_za(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=ZGb(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;n=t^q;s=ZGb(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=F;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=ZGb(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=F;n=q^u;r=ZGb(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=F;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=ZGb(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^e;t=ZGb(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=ZGb(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^o;q=ZGb(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function rsa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Zza(j|0,h+64|0,32,32);Zza(j+16|0,h+80|0,32,32);Zza(j+256|0,h+320|0,32,32);Zza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=ZGb(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;m=t^s;n=ZGb(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=F;q=e|8;e=h+(q+96)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=ZGb(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^u;r=ZGb(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+112)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=ZGb(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=F;m=n^e;t=ZGb(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h+((l|8)+112)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=ZGb(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^k;s=ZGb(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function ssa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Yza(j|0,e+f|0,32,f);l=f+16|0;Yza(j+16|0,e+l|0,32,f);m=f<<3;Yza(j+256|0,e+(m+f)|0,32,f);Yza(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=ZGb(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=ZGb(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^l;t=ZGb(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=F;n=l^e;s=ZGb(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function tsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;Yza(h|0,b+e|0,32,e);Yza(h+16|0,b+(e+16)|0,32,e);k=e<<3;Yza(h+256|0,b+(k+e)|0,32,e);l=k+16|0;Yza(h+272|0,b+(l+e)|0,32,e);m=g|0;_za(j|0,m,b,32,32,e);n=g+16|0;_za(j+16|0,n,b+16|0,32,32,e);_za(j+256|0,m,b+k|0,32,32,e);_za(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(l,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=k^n;t=ZGb(o|m,k|n,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=b|8;b=h+p|0;o=b|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=ZGb(q|m,o|b,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|g,r|t,((s^g)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;p=l+1|0;if((p|0)<16){l=p}else{u=0;break}}do{l=u<<5;p=l|16;q=h+p|0;m=q|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+p|0;p=m|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=m^q;n=ZGb(s|g,m|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;g=o^b;s=ZGb(n|r,o|b,((n^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=F;t=l|24;l=h+t|0;s=l|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+4|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;n=c[t+4>>2]|0;b=s^l;o=ZGb(r|g,s|l,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;g=b^n;r=ZGb(o|p,b|n,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function usa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Yza(j|0,e+f|0,32,f);l=f+16|0;Yza(j+16|0,e+l|0,32,f);m=f<<3;Yza(j+256|0,e+(m+f)|0,32,f);Yza(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Zza(k|0,h+64|0,32,32);Zza(k+16|0,h+80|0,32,32);Zza(k+256|0,h+320|0,32,32);Zza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=ZGb(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=ZGb(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^l;t=ZGb(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=F;n=l^e;s=ZGb(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function vsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;j=f;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j^i;m=ZGb(l|h,j|i,((l^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[g>>2]=m;c[g+4>>2]=F;g=b+8|0;m=c[g>>2]|0;k=c[g+4>>2]|0;h=f+8|0;l=h|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h^k;j=ZGb(i|m,h|k,((i^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[g>>2]=j;c[g+4>>2]=F;g=a+1|0;if((g|0)<8){f=f+e|0;b=b+e|0;a=g}else{break}}return}function wsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;Yza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=ZGb(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function xsa(a,b,c){a=a|0;b=b|0;c=c|0;bAa(a,b,c,c);return}function ysa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;Yza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=ZGb(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function zsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;Zza(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(p,e)|0;h=a+o|0;q=c[h>>2]|0;r=c[h+4>>2]|0;s=k^b;t=ZGb(m|g,k|b,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[h>>2]=m;c[h+4>>2]=F;h=n|8;n=l+h|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=j+h|0;h=n|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(o+8)|0;o=c[h>>2]|0;t=c[h+4>>2]|0;r=n^g;s=ZGb(q|m,n|g,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[h>>2]=q;c[h+4>>2]=F;p=p+1|0;}while((p|0)<8);i=f;return}function Asa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Yza(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;Zza(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;m=a+b|0;q=c[m>>2]|0;r=c[m+4>>2]|0;s=o^n;t=ZGb(h|g,o|n,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;h=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=p|8;p=j+m|0;h=p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+m|0;m=h|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+(b+8)|0;b=c[m>>2]|0;t=c[m+4>>2]|0;r=h^p;s=ZGb(q|g,h|p,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Bsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;Yza(g|0,b,16,e);_za(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=ZGb(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=ZGb(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Csa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Yza(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Zza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=ZGb(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=ZGb(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Dsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;aAa(a,j,e,16);i=f;return}function Esa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;Zza(k|0,m,16,16);_za(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(b,e)|0;h=a+p|0;n=c[h>>2]|0;r=c[h+4>>2]|0;s=q^m;t=ZGb(g|o,q|m,((g^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;o=s^r;g=ZGb(t|n,s|r,((t^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=g;c[h+4>>2]=F;h=j|8;j=k+h|0;g=j|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+h|0;h=g|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(p+8)|0;p=c[h>>2]|0;t=c[h+4>>2]|0;r=g^j;s=ZGb(n|o,g|j,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;o=r^t;n=ZGb(s|p,r|t,((s^p)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=n;c[h+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Fsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+416|0;$za(a,d|0,b,c,16,c);i=d;return}function Gsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;Zza(k|0,m,16,16);_za(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=ba(b,e)|0;n=a+q|0;o=c[n>>2]|0;r=c[n+4>>2]|0;s=h^m;t=ZGb(g|p,h|m,((g^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;p=s^r;g=ZGb(t|o,s|r,((t^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=j|8;j=k+n|0;g=j|0;p=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+n|0;n=g|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+4|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(q+8)|0;q=c[n>>2]|0;t=c[n+4>>2]|0;r=g^j;s=ZGb(o|p,g|j,((o^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;p=r^t;o=ZGb(s|q,r|t,((s^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=o;c[n+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Hsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;Zza(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(o,e)|0;l=a+b|0;q=c[l>>2]|0;r=c[l+4>>2]|0;s=m^g;t=ZGb(h|p,m|g,((h^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;p=s^r;h=ZGb(t|q,s|r,((t^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[l>>2]=h;c[l+4>>2]=F;l=n|8;n=k+l|0;h=c[n>>2]|0;p=c[n+4>>2]|0;n=j+l|0;l=n|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(b+8)|0;b=c[l>>2]|0;t=c[l+4>>2]|0;r=n^p;s=ZGb(q|h,n|p,((q^h)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;h=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;o=o+1|0;}while((o|0)<8);i=f;return}function Isa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;Yza(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;Zza(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;p=c[n>>2]|0;r=c[n+4>>2]|0;s=m^o;t=ZGb(h|g,m|o,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;h=ZGb(t|p,s|r,((t^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=h;c[n+4>>2]=F;n=q|8;q=j+n|0;h=q|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=h^q;s=ZGb(p|g,h|q,((p^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;p=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=p;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Jsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;Yza(g|0,b+e|0,16,e);_za(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=ZGb(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=ZGb(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Ksa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Yza(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Zza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=ZGb(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=ZGb(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Lsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=c[f>>2]|0;h=c[f+4>>2]|0;i=b;j=i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i+4|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i^h;l=ZGb(k|g,i|h,((k^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[f>>2]=l;c[f+4>>2]=F;f=a+e|0;l=c[f>>2]|0;j=c[f+4>>2]|0;g=b+e|0;k=g|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^j;i=ZGb(h|l,g|j,((h^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[f>>2]=i;c[f+4>>2]=F;f=e<<1;i=a+f|0;k=c[i>>2]|0;l=c[i+4>>2]|0;h=b+f|0;j=h|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h^l;m=ZGb(g|k,h|l,((g^k)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[i>>2]=m;c[i+4>>2]=F;i=f+e|0;e=a+i|0;a=c[e>>2]|0;f=c[e+4>>2]|0;m=b+i|0;i=m|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m^f;j=ZGb(b|a,m|f,((b^a)>>>1|i<<31)&2147450879,(i>>>1|0<<31)&2147450879)|0;c[e>>2]=j;c[e+4>>2]=F;return}function Msa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;Vza(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=ZGb(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;l=p^o;k=ZGb(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=F;h=b+e|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=ZGb(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^p;n=ZGb(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=F;k=e<<1;n=b+k|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=ZGb(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;o=h^j;m=ZGb(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=F;l=e*3|0;e=b+l|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=ZGb(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;m=k^a;g=ZGb(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=F;i=f;return}function Nsa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d>>1;d=0;g=a;a=c;while(1){c=a+2|0;h=a-2|0;i=a+4|0;j=a+6|0;k=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[i>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<512>>>0){l=k}else{l=-k>>31&511}b[g>>1]=((e[g>>1]|0)+1+l|0)>>>1;k=g+2|0;m=a+8|0;n=(((e[i>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[h>>1]|0)+(((e[j>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[m>>1]|0)>>5;if(n>>>0<512>>>0){o=n}else{o=-n>>31&511}b[k>>1]=((e[k>>1]|0)+1+o|0)>>>1;k=g+4|0;n=a+10|0;h=(((e[j>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[m>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(h>>>0<512>>>0){p=h}else{p=-h>>31&511}b[k>>1]=((e[k>>1]|0)+1+p|0)>>>1;k=g+6|0;h=(((e[m>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(h>>>0<512>>>0){q=h}else{q=-h>>31&511}b[k>>1]=((e[k>>1]|0)+1+q|0)>>>1;k=d+1|0;if((k|0)<4){d=k;g=g+(f<<1)|0;a=a+(f<<1)|0}else{break}}return}function Osa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;Vza(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=ZGb(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;l=p^o;k=ZGb(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=F;h=b+(e+2)|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=ZGb(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^p;n=ZGb(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=F;k=e<<1;n=b+(k+2)|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=ZGb(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;o=h^j;m=ZGb(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=F;l=e*3|0;e=b+(l+2)|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=ZGb(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;m=k^a;g=ZGb(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=F;i=f;return}function Psa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;Wza(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=a;h=c[k>>2]|0;b=c[k+4>>2]|0;r=p^s;t=ZGb(l|g,p|s,((l^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^b;l=ZGb(t|h,r|b,((t^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[k>>2]=l;c[k+4>>2]=F;k=c[o>>2]|0;l=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;h=c[o+4>>2]|0;o=a+e|0;t=c[o>>2]|0;b=c[o+4>>2]|0;r=h^l;s=ZGb(g|k,h|l,((g^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;k=r^b;g=ZGb(s|t,r|b,((s^t)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[o>>2]=g;c[o+4>>2]=F;o=c[n>>2]|0;g=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=a+m|0;m=c[n>>2]|0;s=c[n+4>>2]|0;b=t^g;r=ZGb(k|o,t|g,((k^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;o=b^s;k=ZGb(r|m,b|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[n>>2]=k;c[n+4>>2]=F;n=c[q>>2]|0;k=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;o=c[q+4>>2]|0;q=a+(e*3|0)|0;e=c[q>>2]|0;a=c[q+4>>2]|0;m=o^k;r=ZGb(j|n,o|k,((j^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^a;j=ZGb(r|e,m|a,((r^e)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=j;c[q+4>>2]=F;i=f;return}function Qsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Vza(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;Wza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=a;q=c[m>>2]|0;h=c[m+4>>2]|0;b=r^g;p=ZGb(k|n,r|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(p|q,b|h,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;q=c[m>>2]|0;p=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=p^n;r=ZGb(q|k,p|n,((q^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;q=ZGb(r|h,g|b,((r^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=F;m=j+16|0;q=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;r=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=r^k;n=ZGb(h|q,r|k,((h^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;q=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;q=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=q^h;n=ZGb(l|j,q|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function Rsa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;Vza(f,b,8,d);Xza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=ZGb(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;b=o^n;g=ZGb(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=F;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=ZGb(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;g=k^o;m=ZGb(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=F;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=ZGb(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;m=b^k;n=ZGb(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=ZGb(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;f=o^a;h=ZGb(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=F;i=e;return}function Ssa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Vza(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Wza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=ZGb(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=ZGb(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function Tsa(a,f,g){a=a|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+72|0;j=h|0;k=j|0;l=j+16|0;m=g<<1;n=f+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=n;n=j+8|0;k=g-m|0;o=f+k|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=f;n=o|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=p;c[l+4>>2]=o;o=j+24|0;n=f+g|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=n;n=j+32|0;o=m+g+g|0;q=f+(o-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=j+40|0;n=o+g|0;o=f+(n-m)|0;r=o|0;s=o+4|0;o=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=o;o=j+48|0;q=n+g|0;n=f+(q-m)|0;r=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=n;n=j+56|0;o=q+g|0;q=f+(o-m)|0;m=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=q;q=j+64|0;j=f+(k+o)|0;o=j|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=j;j=g>>1;g=j<<1;q=j*3|0;o=l;l=a;a=1;k=p&65535;while(1){p=e[o-8>>1]|0;f=k&65535;n=e[o+8>>1]|0;m=e[o+16>>1]|0;r=e[o+24>>1]|0;s=e[o+32>>1]|0;t=e[o+40>>1]|0;u=e[o+48>>1]|0;v=(e[o-16>>1]|0)+16+((n+f|0)*20|0)+r+((m+p|0)*-5|0)>>5;if(v>>>0<512>>>0){w=v}else{w=-v>>31&511}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;v=l+(j<<1)|0;x=p+16+((m+n|0)*20|0)+s+((r+f|0)*-5|0)>>5;if(x>>>0<512>>>0){y=x}else{y=-x>>31&511}b[v>>1]=((e[v>>1]|0)+1+y|0)>>>1;v=l+(g<<1)|0;x=f+16+((r+m|0)*20|0)+t+((s+n|0)*-5|0)>>5;if(x>>>0<512>>>0){z=x}else{z=-x>>31&511}b[v>>1]=((e[v>>1]|0)+1+z|0)>>>1;v=l+(q<<1)|0;x=n+16+((s+r|0)*20|0)+u+((t+m|0)*-5|0)>>5;if(x>>>0<512>>>0){A=x}else{A=-x>>31&511}b[v>>1]=((e[v>>1]|0)+1+A|0)>>>1;v=o+2|0;if((a|0)>=4){break}o=v;l=l+2|0;a=a+1|0;k=b[v>>1]|0}i=h;return}function Usa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Wza(k,o,8);Xza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;s=c[n+4>>2]|0;r=o^j;h=ZGb(l|b,o|j,((l^b)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;b=r^s;l=ZGb(h|g,r|s,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;s=c[n>>2]|0;r=c[n+4>>2]|0;j=h^b;o=ZGb(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^r;g=ZGb(o|s,j|r,((o^s)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;s=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;r=c[n+4>>2]|0;j=o^l;b=ZGb(s|g,o|l,((s^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;g=j^r;s=ZGb(b|p,j|r,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=s;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;s=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^s;b=ZGb(m|k,g|s,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;k=p^a;m=ZGb(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;i=f;return}function Vsa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+144|0;g=f|0;h=d>>1;d=h<<1;j=c+(-d<<1)|0;c=0;k=g|0;while(1){l=b[j>>1]|0;m=b[j+2>>1]|0;n=b[j-2>>1]|0;o=b[j+4>>1]|0;p=b[j+6>>1]|0;b[k>>1]=(((b[j-4>>1]|0)+((m+l&65535)*20&65535)&65535)+((o+n&65535)*-5&65535)&65535)+p;q=b[j+8>>1]|0;b[k+2>>1]=((n+((o+m&65535)*20&65535)&65535)+((p+l&65535)*-5&65535)&65535)+q;n=b[j+10>>1]|0;b[k+4>>1]=((l+((p+o&65535)*20&65535)&65535)+((q+m&65535)*-5&65535)&65535)+n;b[k+6>>1]=((m+((q+p&65535)*20&65535)&65535)+((n+o&65535)*-5&65535)&65535)+(b[j+12>>1]|0);o=c+1|0;if((o|0)<9){j=j+(h<<1)|0;c=o;k=k+16|0}else{break}}k=h*3|0;c=a;a=0;j=g+32|0;while(1){g=b[j-16>>1]|0;o=b[j>>1]|0;n=b[j+16>>1]|0;p=b[j+32>>1]|0;q=b[j+48>>1]|0;m=b[j+64>>1]|0;l=b[j+80>>1]|0;r=b[j+96>>1]|0;s=(b[j-32>>1]|0)+512+((n+o|0)*20|0)+q+((p+g|0)*-5|0)>>10;if(s>>>0<512>>>0){t=s}else{t=-s>>31&511}b[c>>1]=((e[c>>1]|0)+1+t|0)>>>1;s=c+(h<<1)|0;u=g+512+((p+n|0)*20|0)+m+((q+o|0)*-5|0)>>10;if(u>>>0<512>>>0){v=u}else{v=-u>>31&511}b[s>>1]=((e[s>>1]|0)+1+v|0)>>>1;s=c+(d<<1)|0;u=o+512+((q+p|0)*20|0)+l+((m+n|0)*-5|0)>>10;if(u>>>0<512>>>0){w=u}else{w=-u>>31&511}b[s>>1]=((e[s>>1]|0)+1+w|0)>>>1;s=c+(k<<1)|0;u=n+512+((m+q|0)*20|0)+r+((l+p|0)*-5|0)>>10;if(u>>>0<512>>>0){x=u}else{x=-u>>31&511}b[s>>1]=((e[s>>1]|0)+1+x|0)>>>1;s=a+1|0;if((s|0)<4){c=c+2|0;a=s;j=j+2|0}else{break}}i=f;return}function Wsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;Wza(k,o,8);Xza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;t=c[n+4>>2]|0;s=o^j;h=ZGb(l|b,o|j,((l^b)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;b=s^t;l=ZGb(h|g,s|t,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;t=c[n>>2]|0;s=c[n+4>>2]|0;j=h^b;o=ZGb(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^s;g=ZGb(o|t,j|s,((o^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;t=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;s=c[n+4>>2]|0;j=o^l;b=ZGb(t|g,o|l,((t^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;g=j^s;t=ZGb(b|p,j|s,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=t;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^t;b=ZGb(m|k,g|t,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;k=p^a;m=ZGb(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;i=f;return}function Xsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;Wza(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=a;t=c[k>>2]|0;h=c[k+4>>2]|0;b=s^g;r=ZGb(o|l,s|g,((o^l)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;l=b^h;o=ZGb(r|t,b|h,((r^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=o;c[k+4>>2]=F;k=c[n>>2]|0;o=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;t=c[n+4>>2]|0;n=a+e|0;r=c[n>>2]|0;h=c[n+4>>2]|0;b=t^o;g=ZGb(l|k,t|o,((l^k)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;k=b^h;l=ZGb(g|r,b|h,((g^r)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=c[q>>2]|0;l=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;r=c[q+4>>2]|0;q=a+m|0;m=c[q>>2]|0;g=c[q+4>>2]|0;h=r^l;b=ZGb(k|n,r|l,((k^n)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;n=h^g;k=ZGb(b|m,h|g,((b^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=k;c[q+4>>2]=F;q=c[p>>2]|0;k=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;n=c[p+4>>2]|0;p=a+(e*3|0)|0;e=c[p>>2]|0;a=c[p+4>>2]|0;m=n^k;b=ZGb(j|q,n|k,((j^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;q=m^a;j=ZGb(b|e,m|a,((b^e)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[p>>2]=j;c[p+4>>2]=F;i=f;return}function Ysa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;Vza(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;Wza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=o^g;q=ZGb(k|n,o|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;o=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(o|h,g|b,((o^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;o=c[m+4>>2]|0;m=a+p|0;p=c[m>>2]|0;b=c[m+4>>2]|0;g=o^k;n=ZGb(h|r,o|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|p,g|b,((n^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;p=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;j=p^a;l=ZGb(n|e,p|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function Zsa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;Vza(f,b+d|0,8,d);Xza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=ZGb(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;b=o^n;g=ZGb(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=F;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=ZGb(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;g=k^o;m=ZGb(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=F;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=ZGb(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;m=b^k;n=ZGb(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=ZGb(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;f=o^a;h=ZGb(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=F;i=e;return}function _sa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Vza(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Wza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=ZGb(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=ZGb(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function $sa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=e+8|0;h=b+f|0;g=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=h;h=e<<1;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;j=b+g|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+g|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=b+16|0;h=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+16|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=j;j=b+24|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+24|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=e+16|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=e+24|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;e=b+h|0;f=e|0;g=e+4|0;e=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+h|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=e;e=h+8|0;h=b+e|0;b=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[g+4>>2]=h;return}function ata(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;Mza(g|0,b,32,e);Mza(g+16|0,b+16|0,32,e);h=e<<3;Mza(g+256|0,b+h|0,32,e);Mza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=ZGb(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ba(r,e)|0;l=h+16|0;k=b+l|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r<<5;p=g+(o|16)|0;j=p|0;q=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p+4|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p^k;n=ZGb(q|m,p|k,((q^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+l|0;c[j>>2]=n;c[j+4>>2]=F;j=h+24|0;h=b+j|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+(o|24)|0;o=n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^h;q=ZGb(m|l,n|h,((m^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;r=r+1|0;}while((r|0)<16);i=f;return}function bta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Mza(a,b,c,c);Mza(a+16|0,b+16|0,c,c);d=c<<3;Mza(a+d|0,b+d|0,c,c);e=d+16|0;Mza(a+e|0,b+e|0,c,c);return}function cta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;Mza(g|0,b,32,e);Mza(g+16|0,b+16|0,32,e);h=e<<3;Mza(g+256|0,b+h|0,32,e);Mza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=ZGb(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ba(r,e)|0;l=b+(h+18)|0;k=l|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=l+4|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=r<<5;m=g+(k|16)|0;p=m|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^l;q=ZGb(o|j,m|l,((o^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(h+16)|0;c[p>>2]=q;c[p+4>>2]=F;p=b+(h+26)|0;q=p|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(k|24)|0;k=q|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q^p;l=ZGb(o|j,q|p,((o^j)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(h+24)|0;c[k>>2]=l;c[k+4>>2]=F;r=r+1|0;}while((r|0)<16);i=f;return}function dta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Nza(j|0,h+64|0,32,32);Nza(j+16|0,h+80|0,32,32);Nza(j+256|0,h+320|0,32,32);Nza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=ZGb(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=F;m=e|8;e=h+(m+64)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=ZGb(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+64)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=ZGb(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=F;n=l|24;l=h+(n+64)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=ZGb(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function eta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Mza(j|0,e,32,f);Mza(j+16|0,e+16|0,32,f);l=f<<3;Mza(j+256|0,e+l|0,32,f);Mza(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=ZGb(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=ZGb(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=ZGb(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=F;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=ZGb(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function fta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;Mza(h|0,b,32,e);k=b+16|0;Mza(h+16|0,k,32,e);l=e<<3;m=b+l|0;Mza(h+256|0,m,32,e);n=b+(l+16)|0;Mza(h+272|0,n,32,e);l=g|0;Oza(j|0,l,b,32,32,e);b=g+16|0;Oza(j+16|0,b,k,32,32,e);Oza(j+256|0,l,m,32,32,e);Oza(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l^m;p=ZGb(o|k,l|m,((o^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ba(n,e)|0;k=a+g|0;c[k>>2]=p;c[k+4>>2]=F;k=b|8;b=h+k|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+k|0;k=p|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p+4|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p^b;l=ZGb(m|o,p|b,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(g+8)|0;c[k>>2]=l;c[k+4>>2]=F;k=n+1|0;if((k|0)<16){n=k}else{q=0;break}}do{n=q<<5;k=n|16;l=h+k|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+k|0;k=g|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^l;b=ZGb(m|o,g|l,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=ba(q,e)|0;o=a+(k+16)|0;c[o>>2]=b;c[o+4>>2]=F;o=n|24;n=h+o|0;b=n|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=n+4|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^n;g=ZGb(l|m,b|n,((l^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(k+24)|0;c[o>>2]=g;c[o+4>>2]=F;q=q+1|0;}while((q|0)<16);i=f;return}function gta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Mza(j|0,e,32,f);Mza(j+16|0,e+16|0,32,f);l=f<<3;Mza(j+256|0,e+l|0,32,f);Mza(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=ZGb(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=ZGb(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=ZGb(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=F;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=ZGb(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function hta(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+4|0;x=l;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}Nza(b,g+64|0,e,32);Nza(b+16|0,g+80|0,e,32);j=e<<3;Nza(b+j|0,g+320|0,e,32);Nza(b+(j+16)|0,g+336|0,e,32);i=f;return}function ita(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=j|0;Oza(l|0,h,e,32,32,f);o=j+16|0;Oza(l+16|0,o,e+16|0,32,32,f);j=f<<3;Oza(l+256|0,h,e+j|0,32,32,f);Oza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=ZGb(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=F;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=ZGb(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=F;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=ZGb(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=F;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=ZGb(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=F;t=t+1|0;}while((t|0)<16);i=g;return}function jta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+1344|0;e=d|0;f=e|0;Oza(a,f,b,c,32,c);g=e+16|0;Oza(a+16|0,g,b+16|0,c,32,c);e=c<<3;Oza(a+e|0,f,b+e|0,c,32,c);f=e+16|0;Oza(a+f|0,g,b+f|0,c,32,c);i=d;return}function kta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=j|0;Oza(l|0,h,e,32,32,f);o=j+16|0;Oza(l+16|0,o,e+16|0,32,32,f);j=f<<3;Oza(l+256|0,h,e+j|0,32,32,f);Oza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=ZGb(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=F;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=ZGb(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=F;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=ZGb(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=F;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=ZGb(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=F;t=t+1|0;}while((t|0)<16);i=g;return}function lta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Nza(j|0,h+64|0,32,32);Nza(j+16|0,h+80|0,32,32);Nza(j+256|0,h+320|0,32,32);Nza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=ZGb(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=F;m=e|8;e=h+(m+96)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=ZGb(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+96)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=ZGb(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=F;n=l|24;l=h+(n+96)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=ZGb(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function mta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Mza(j|0,e+f|0,32,f);l=f+16|0;Mza(j+16|0,e+l|0,32,f);m=f<<3;Mza(j+256|0,e+(m+f)|0,32,f);Mza(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=ZGb(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=ZGb(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=ZGb(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=F;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=ZGb(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function nta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;Mza(h|0,b+e|0,32,e);Mza(h+16|0,b+(e+16)|0,32,e);k=e<<3;Mza(h+256|0,b+(k+e)|0,32,e);l=k+16|0;Mza(h+272|0,b+(l+e)|0,32,e);m=g|0;Oza(j|0,m,b,32,32,e);n=g+16|0;Oza(j+16|0,n,b+16|0,32,32,e);Oza(j+256|0,m,b+k|0,32,32,e);Oza(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k^n;p=ZGb(o|m,k|n,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ba(l,e)|0;m=a+g|0;c[m>>2]=p;c[m+4>>2]=F;m=b|8;b=h+m|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+m|0;m=p|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^b;k=ZGb(n|o,p|b,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(g+8)|0;c[m>>2]=k;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{q=0;break}}do{l=q<<5;m=l|16;k=h+m|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=g|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+4|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g^k;b=ZGb(n|o,g|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(q,e)|0;o=a+(m+16)|0;c[o>>2]=b;c[o+4>>2]=F;o=l|24;l=h+o|0;b=l|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=l+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^l;g=ZGb(k|n,b|l,((k^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(m+24)|0;c[o>>2]=g;c[o+4>>2]=F;q=q+1|0;}while((q|0)<16);i=f;return}function ota(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Mza(j|0,e+f|0,32,f);l=f+16|0;Mza(j+16|0,e+l|0,32,f);m=f<<3;Mza(j+256|0,e+(m+f)|0,32,f);Mza(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=ZGb(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=ZGb(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=ZGb(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=F;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=ZGb(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function pta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+(e+8)|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+(e+8)|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=e<<1;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=b+(g+8)|0;j=f|0;i=f+4|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(h+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=f;f=g+e|0;g=h+e|0;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;e=b+g|0;f=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=e;e=b+(g+8)|0;g=e|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(h+8)|0;c[b>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[b+4>>2]=e;return}function qta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;Mza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=ZGb(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function rta(a,b,c){a=a|0;b=b|0;c=c|0;Mza(a,b,c,c);return}function sta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;Mza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=ZGb(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function tta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;Nza(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k^b;h=ZGb(m|g,k|b,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(p,e)|0;g=a+o|0;c[g>>2]=h;c[g+4>>2]=F;g=n|8;n=l+g|0;h=c[n>>2]|0;m=c[n+4>>2]|0;n=j+g|0;g=n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^m;k=ZGb(b|h,n|m,((b^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(o+8)|0;c[g>>2]=k;c[g+4>>2]=F;p=p+1|0;}while((p|0)<8);i=f;return}function uta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Mza(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;Nza(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o^n;m=ZGb(h|g,o|n,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=m;c[g+4>>2]=F;g=p|8;p=j+g|0;m=p|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+g|0;g=m|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m+4|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m^p;o=ZGb(n|h,m|p,((n^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=o;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function vta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;Mza(g|0,b,16,e);Oza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=ZGb(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=F;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=ZGb(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function wta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Mza(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Nza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=ZGb(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=ZGb(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function xta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;Nza(a,j,e,16);i=f;return}function yta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;Nza(k|0,m,16,16);Oza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q^m;h=ZGb(g|o,q|m,((g^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=ba(b,e)|0;o=a+p|0;c[o>>2]=h;c[o+4>>2]=F;o=j|8;j=k+o|0;h=j|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+o|0;o=h|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h^j;q=ZGb(m|g,h|j,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(p+8)|0;c[o>>2]=q;c[o+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function zta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+416|0;Oza(a,d|0,b,c,16,c);i=d;return}function Ata(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;Nza(k|0,m,16,16);Oza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h^m;n=ZGb(g|p,h|m,((g^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(b,e)|0;p=a+q|0;c[p>>2]=n;c[p+4>>2]=F;p=j|8;j=k+p|0;n=j|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^j;h=ZGb(m|g,n|j,((m^g)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(q+8)|0;c[p>>2]=h;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Bta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;Nza(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^g;l=ZGb(h|p,m|g,((h^p)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(o,e)|0;p=a+b|0;c[p>>2]=l;c[p+4>>2]=F;p=n|8;n=k+p|0;l=c[n>>2]|0;h=c[n+4>>2]|0;n=j+p|0;p=n|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^h;m=ZGb(g|l,n|h,((g^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(b+8)|0;c[p>>2]=m;c[p+4>>2]=F;o=o+1|0;}while((o|0)<8);i=f;return}function Cta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;Mza(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;Nza(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^o;n=ZGb(h|g,m|o,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=q|8;q=j+g|0;n=q|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^q;m=ZGb(o|h,n|q,((o^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=m;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Dta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;Mza(g|0,b+e|0,16,e);Oza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=ZGb(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=F;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=ZGb(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Eta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Mza(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Nza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=ZGb(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=ZGb(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Fta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+e|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=b+f|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=f+e|0;e=b+g|0;b=e|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[f+4>>2]=e;return}function Gta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;Jza(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=ZGb(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=F;h=b+e|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=ZGb(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=F;n=e<<1;m=b+n|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=ZGb(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=F;l=e*3|0;e=b+l|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=ZGb(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=F;i=f;return}function Hta(a,b,c){a=a|0;b=b|0;c=c|0;Jza(a,b,c,c);return}function Ita(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;Jza(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=ZGb(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=F;h=b+(e+2)|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=ZGb(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=F;n=e<<1;m=b+(n+2)|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=ZGb(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=F;l=e*3|0;e=b+(l+2)|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=ZGb(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=F;i=f;return}function Jta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;Kza(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=p^s;h=ZGb(l|g,p|s,((l^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=h;c[k+4>>2]=F;k=c[o>>2]|0;h=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;l=c[o+4>>2]|0;o=l^h;s=ZGb(g|k,l|h,((g^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+e|0;c[o>>2]=s;c[o+4>>2]=F;o=c[n>>2]|0;s=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;g=c[n+4>>2]|0;n=g^s;h=ZGb(k|o,g|s,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+m|0;c[n>>2]=h;c[n+4>>2]=F;n=c[q>>2]|0;h=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;m=c[q+4>>2]|0;q=m^h;o=ZGb(j|n,m|h,((j^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+(e*3|0)|0;c[q>>2]=o;c[q+4>>2]=F;i=f;return}function Kta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Jza(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;Kza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=r^g;q=ZGb(k|n,r|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=q;c[m+4>>2]=F;m=j+8|0;q=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;r=ZGb(k|q,g|n,((k^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^q;g=ZGb(k|r,n|q,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=r;c[m+4>>2]=F;i=f;return}function Lta(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;Jza(f,b,8,d);Lza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=ZGb(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=F;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=ZGb(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=F;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=ZGb(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=ZGb(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=F;i=e;return}function Mta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Jza(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Kza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=ZGb(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=F;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=F;i=f;return}function Nta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+72|0;g=f|0;h=g|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=g+8|0;h=e-k|0;m=b+h|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=m;m=b;l=m|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=m;m=g+24|0;l=b+e|0;n=l|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=l;l=g+32|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=n;n=g+40|0;l=m+e|0;m=b+(l-k)|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;m=g+48|0;n=l+e|0;l=b+(n-k)|0;o=l|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=l;l=g+56|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[l+4>>2]=n;n=g+64|0;g=b+(h+m)|0;m=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=g;Kza(a,j,e);i=f;return}function Ota(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Kza(k,o,8);Lza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=ZGb(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=F;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=ZGb(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=F;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=ZGb(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=ZGb(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=F;i=f;return}function Pta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+144|0;Lza(a,d|0,b,c,c);i=d;return}function Qta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;Kza(k,o,8);Lza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=ZGb(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=F;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=ZGb(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=F;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=ZGb(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=ZGb(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=F;i=f;return}function Rta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;Kza(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=s^g;t=ZGb(o|l,s|g,((o^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=t;c[k+4>>2]=F;k=c[n>>2]|0;t=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^t;g=ZGb(l|k,o|t,((l^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=g;c[n+4>>2]=F;n=c[q>>2]|0;g=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;l=c[q+4>>2]|0;q=l^g;t=ZGb(k|n,l|g,((k^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+m|0;c[q>>2]=t;c[q+4>>2]=F;q=c[p>>2]|0;t=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;m=c[p+4>>2]|0;p=m^t;n=ZGb(j|q,m|t,((j^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(e*3|0)|0;c[p>>2]=n;c[p+4>>2]=F;i=f;return}function Sta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;Jza(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;Kza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=ZGb(k|n,o|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;o=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=o;c[m+4>>2]=F;m=j+16|0;o=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|o,n|r,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+p|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;p=c[m+4>>2]|0;m=p^g;o=ZGb(l|j,p|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=o;c[m+4>>2]=F;i=f;return}function Tta(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;Jza(f,b+d|0,8,d);Lza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=ZGb(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=F;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=ZGb(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=F;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=ZGb(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=ZGb(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=F;i=e;return}function Uta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Jza(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Kza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=ZGb(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=F;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=F;i=f;return}function Vta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;return}function Wta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;Sza(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+e|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function Xta(a,b,c){a=a|0;b=b|0;c=c|0;Sza(a,b,c,c);return}function Yta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;Sza(g,b,4,e);h=b+2|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+(e+2)|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function Zta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;Tza(h,j,4);n=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|n)-((j^n)>>>1&2147450879);n=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|n)-((m^n)>>>1&2147450879);i=f;return}function _ta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;Sza(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;Tza(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function $ta(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+64|0;f=e+56|0;g=i;i=i+8|0;Sza(f,b,4,d);Uza(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function aua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;Sza(h,b,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Tza(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function bua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+32|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;Tza(a,h,e);i=f;return}function cua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+56|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Tza(j,l,4);Uza(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function dua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+56|0;Uza(a,d|0,b,c,c);i=d;return}function eua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+56|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=2-m|0;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+2|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+2)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e+e|0;m=b+(p+n)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;Tza(j,l,4);Uza(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function fua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-k)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Tza(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2147450879);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2147450879);i=f;return}function gua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;l=b+e|0;Sza(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Tza(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function hua(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+64|0;f=e+56|0;g=i;i=i+8|0;Sza(f,b+d|0,4,d);Uza(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function iua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;Sza(h,b+e|0,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Tza(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function jua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=c[i+4>>2]|0;l=f;m=l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l^k;o=ZGb(n|j,l|k,((n^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[i>>2]=o;c[i+4>>2]=F;i=g+8|0;o=c[i>>2]|0;m=c[i+4>>2]|0;j=f+8|0;n=j|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j^m;l=ZGb(k|o,j|m,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[i>>2]=l;c[i+4>>2]=F;i=h+1|0;if((i|0)<16){f=f+e|0;g=g+e|0;h=i}else{break}}h=b+16|0;b=a+16|0;a=0;while(1){g=b;f=c[g>>2]|0;i=c[g+4>>2]|0;l=h;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^i;k=ZGb(o|f,l|i,((o^f)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[g>>2]=k;c[g+4>>2]=F;g=b+8|0;k=c[g>>2]|0;n=c[g+4>>2]|0;f=h+8|0;o=f|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f+4|0;f=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f^n;l=ZGb(i|k,f|n,((i^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[g>>2]=l;c[g+4>>2]=F;g=a+1|0;if((g|0)<16){h=h+e|0;b=b+e|0;a=g}else{break}}return}function kua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;Mza(g|0,b,32,e);Mza(g+16|0,b+16|0,32,e);h=e<<3;Mza(g+256|0,b+h|0,32,e);Mza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=ZGb(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ba(u,e)|0;l=h+16|0;q=b+l|0;m=q|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=u<<5;s=g+(m|16)|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+l|0;l=c[t>>2]|0;j=c[t+4>>2]|0;p=s^q;k=ZGb(r|o,s|q,((r^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;o=p^j;r=ZGb(k|l,p|j,((k^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;t=h+24|0;h=b+t|0;r=h|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+(m|24)|0;m=r|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r+4|0;r=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+t|0;t=c[m>>2]|0;k=c[m+4>>2]|0;j=r^h;p=ZGb(l|o,r|h,((l^o)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;o=j^k;l=ZGb(p|t,j|k,((p^t)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function lua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Rza(a,b,c,c);Rza(a+16|0,b+16|0,c,c);d=c<<3;Rza(a+d|0,b+d|0,c,c);e=d+16|0;Rza(a+e|0,b+e|0,c,c);return}function mua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;Mza(g|0,b,32,e);Mza(g+16|0,b+16|0,32,e);h=e<<3;Mza(g+256|0,b+h|0,32,e);Mza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=ZGb(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ba(u,e)|0;l=b+(h+18)|0;q=l|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=u<<5;j=g+(q|16)|0;s=j|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=a+(h+16)|0;r=c[s>>2]|0;o=c[s+4>>2]|0;p=j^l;k=ZGb(t|m,j|l,((t^m)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;m=p^o;t=ZGb(k|r,p|o,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[s>>2]=t;c[s+4>>2]=F;s=b+(h+26)|0;t=s|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=g+(q|24)|0;q=t|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=t+4|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=a+(h+24)|0;h=c[q>>2]|0;k=c[q+4>>2]|0;o=t^s;p=ZGb(r|m,t|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;m=o^k;r=ZGb(p|h,o|k,((p^h)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function nua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Nza(j|0,h+64|0,32,32);Nza(j+16|0,h+80|0,32,32);Nza(j+256|0,h+320|0,32,32);Nza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=ZGb(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;m=t^s;n=ZGb(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=F;q=e|8;e=h+(q+64)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=ZGb(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^u;r=ZGb(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+80)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=ZGb(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=F;m=n^e;t=ZGb(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h+((l|8)+80)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=ZGb(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^k;s=ZGb(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function oua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Mza(j|0,e,32,f);Mza(j+16|0,e+16|0,32,f);l=f<<3;Mza(j+256|0,e+l|0,32,f);Mza(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=ZGb(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=ZGb(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^m;t=ZGb(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^e;s=ZGb(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function pua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;Mza(h|0,b,32,e);k=b+16|0;Mza(h+16|0,k,32,e);l=e<<3;m=b+l|0;Mza(h+256|0,m,32,e);n=b+(l+16)|0;Mza(h+272|0,n,32,e);l=g|0;Oza(j|0,l,b,32,32,e);b=g+16|0;Oza(j+16|0,b,k,32,32,e);Oza(j+256|0,l,m,32,32,e);Oza(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(n,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^m;t=ZGb(o|k,l|m,((o^k)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;k=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=b|8;b=h+p|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=ZGb(q|k,o|b,((q^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;k=r^t;q=ZGb(s|g,r|t,((s^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;p=n+1|0;if((p|0)<16){n=p}else{u=0;break}}do{n=u<<5;p=n|16;q=h+p|0;k=q|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+p|0;p=k|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=k^q;m=ZGb(s|g,k|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;g=o^b;s=ZGb(m|r,o|b,((m^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=F;t=n|24;n=h+t|0;s=n|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;m=c[t+4>>2]|0;b=s^n;o=ZGb(r|g,s|n,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;g=b^m;r=ZGb(o|p,b|m,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function qua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Mza(j|0,e,32,f);Mza(j+16|0,e+16|0,32,f);l=f<<3;Mza(j+256|0,e+l|0,32,f);Mza(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=ZGb(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=ZGb(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^m;t=ZGb(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^e;s=ZGb(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function rua(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+4|0;x=l;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}Qza(b,g+64|0,e,32);Qza(b+16|0,g+80|0,e,32);j=e<<3;Qza(b+j|0,g+320|0,e,32);Qza(b+(j+16)|0,g+336|0,e,32);i=f;return}function sua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=j|0;Oza(l|0,h,e,32,32,f);o=j+16|0;Oza(l+16|0,o,e+16|0,32,32,f);j=f<<3;Oza(l+256|0,h,e+j|0,32,32,f);Oza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=ZGb(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;n=t^q;s=ZGb(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=F;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=ZGb(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=F;n=q^u;r=ZGb(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=F;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=ZGb(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^e;t=ZGb(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=ZGb(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^o;q=ZGb(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function tua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+1344|0;e=d|0;f=e|0;Pza(a,f,b,c,32,c);g=e+16|0;Pza(a+16|0,g,b+16|0,c,32,c);e=c<<3;Pza(a+e|0,f,b+e|0,c,32,c);f=e+16|0;Pza(a+f|0,g,b+f|0,c,32,c);i=d;return}function uua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=j|0;Oza(l|0,h,e,32,32,f);o=j+16|0;Oza(l+16|0,o,e+16|0,32,32,f);j=f<<3;Oza(l+256|0,h,e+j|0,32,32,f);Oza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=ZGb(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;n=t^q;s=ZGb(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=F;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=ZGb(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=F;n=q^u;r=ZGb(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=F;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=ZGb(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^e;t=ZGb(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=ZGb(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^o;q=ZGb(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function vua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Nza(j|0,h+64|0,32,32);Nza(j+16|0,h+80|0,32,32);Nza(j+256|0,h+320|0,32,32);Nza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=ZGb(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;m=t^s;n=ZGb(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=F;q=e|8;e=h+(q+96)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=ZGb(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^u;r=ZGb(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+112)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=ZGb(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=F;m=n^e;t=ZGb(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h+((l|8)+112)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=ZGb(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^k;s=ZGb(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function wua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Mza(j|0,e+f|0,32,f);l=f+16|0;Mza(j+16|0,e+l|0,32,f);m=f<<3;Mza(j+256|0,e+(m+f)|0,32,f);Mza(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=ZGb(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=ZGb(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^l;t=ZGb(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=F;n=l^e;s=ZGb(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function xua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;Mza(h|0,b+e|0,32,e);Mza(h+16|0,b+(e+16)|0,32,e);k=e<<3;Mza(h+256|0,b+(k+e)|0,32,e);l=k+16|0;Mza(h+272|0,b+(l+e)|0,32,e);m=g|0;Oza(j|0,m,b,32,32,e);n=g+16|0;Oza(j+16|0,n,b+16|0,32,32,e);Oza(j+256|0,m,b+k|0,32,32,e);Oza(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(l,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=k^n;t=ZGb(o|m,k|n,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=b|8;b=h+p|0;o=b|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=ZGb(q|m,o|b,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|g,r|t,((s^g)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;p=l+1|0;if((p|0)<16){l=p}else{u=0;break}}do{l=u<<5;p=l|16;q=h+p|0;m=q|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+p|0;p=m|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=m^q;n=ZGb(s|g,m|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;g=o^b;s=ZGb(n|r,o|b,((n^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=F;t=l|24;l=h+t|0;s=l|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+4|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;n=c[t+4>>2]|0;b=s^l;o=ZGb(r|g,s|l,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;g=b^n;r=ZGb(o|p,b|n,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function yua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Mza(j|0,e+f|0,32,f);l=f+16|0;Mza(j+16|0,e+l|0,32,f);m=f<<3;Mza(j+256|0,e+(m+f)|0,32,f);Mza(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Nza(k|0,h+64|0,32,32);Nza(k+16|0,h+80|0,32,32);Nza(k+256|0,h+320|0,32,32);Nza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=ZGb(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=ZGb(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^l;t=ZGb(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=F;n=l^e;s=ZGb(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function zua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;j=f;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j^i;m=ZGb(l|h,j|i,((l^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[g>>2]=m;c[g+4>>2]=F;g=b+8|0;m=c[g>>2]|0;k=c[g+4>>2]|0;h=f+8|0;l=h|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h^k;j=ZGb(i|m,h|k,((i^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[g>>2]=j;c[g+4>>2]=F;g=a+1|0;if((g|0)<8){f=f+e|0;b=b+e|0;a=g}else{break}}return}function Aua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;Mza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=ZGb(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function Bua(a,b,c){a=a|0;b=b|0;c=c|0;Rza(a,b,c,c);return}function Cua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;Mza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=ZGb(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function Dua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;Nza(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(p,e)|0;h=a+o|0;q=c[h>>2]|0;r=c[h+4>>2]|0;s=k^b;t=ZGb(m|g,k|b,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[h>>2]=m;c[h+4>>2]=F;h=n|8;n=l+h|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=j+h|0;h=n|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(o+8)|0;o=c[h>>2]|0;t=c[h+4>>2]|0;r=n^g;s=ZGb(q|m,n|g,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[h>>2]=q;c[h+4>>2]=F;p=p+1|0;}while((p|0)<8);i=f;return}function Eua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Mza(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;Nza(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;m=a+b|0;q=c[m>>2]|0;r=c[m+4>>2]|0;s=o^n;t=ZGb(h|g,o|n,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;h=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=p|8;p=j+m|0;h=p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+m|0;m=h|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+(b+8)|0;b=c[m>>2]|0;t=c[m+4>>2]|0;r=h^p;s=ZGb(q|g,h|p,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Fua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;Mza(g|0,b,16,e);Oza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=ZGb(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=ZGb(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Gua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Mza(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Nza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=ZGb(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=ZGb(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Hua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;Qza(a,j,e,16);i=f;return}function Iua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;Nza(k|0,m,16,16);Oza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(b,e)|0;h=a+p|0;n=c[h>>2]|0;r=c[h+4>>2]|0;s=q^m;t=ZGb(g|o,q|m,((g^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;o=s^r;g=ZGb(t|n,s|r,((t^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=g;c[h+4>>2]=F;h=j|8;j=k+h|0;g=j|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+h|0;h=g|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(p+8)|0;p=c[h>>2]|0;t=c[h+4>>2]|0;r=g^j;s=ZGb(n|o,g|j,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;o=r^t;n=ZGb(s|p,r|t,((s^p)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=n;c[h+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Jua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+416|0;Pza(a,d|0,b,c,16,c);i=d;return}function Kua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;Nza(k|0,m,16,16);Oza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=ba(b,e)|0;n=a+q|0;o=c[n>>2]|0;r=c[n+4>>2]|0;s=h^m;t=ZGb(g|p,h|m,((g^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;p=s^r;g=ZGb(t|o,s|r,((t^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=j|8;j=k+n|0;g=j|0;p=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+n|0;n=g|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+4|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(q+8)|0;q=c[n>>2]|0;t=c[n+4>>2]|0;r=g^j;s=ZGb(o|p,g|j,((o^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;p=r^t;o=ZGb(s|q,r|t,((s^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=o;c[n+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Lua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;Nza(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(o,e)|0;l=a+b|0;q=c[l>>2]|0;r=c[l+4>>2]|0;s=m^g;t=ZGb(h|p,m|g,((h^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;p=s^r;h=ZGb(t|q,s|r,((t^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[l>>2]=h;c[l+4>>2]=F;l=n|8;n=k+l|0;h=c[n>>2]|0;p=c[n+4>>2]|0;n=j+l|0;l=n|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(b+8)|0;b=c[l>>2]|0;t=c[l+4>>2]|0;r=n^p;s=ZGb(q|h,n|p,((q^h)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;h=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;o=o+1|0;}while((o|0)<8);i=f;return}function Mua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;Mza(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;Nza(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;p=c[n>>2]|0;r=c[n+4>>2]|0;s=m^o;t=ZGb(h|g,m|o,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;h=ZGb(t|p,s|r,((t^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=h;c[n+4>>2]=F;n=q|8;q=j+n|0;h=q|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=h^q;s=ZGb(p|g,h|q,((p^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;p=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=p;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Nua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;Mza(g|0,b+e|0,16,e);Oza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=ZGb(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=ZGb(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Oua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Mza(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Nza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=ZGb(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=ZGb(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Pua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=c[f>>2]|0;h=c[f+4>>2]|0;i=b;j=i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i+4|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i^h;l=ZGb(k|g,i|h,((k^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[f>>2]=l;c[f+4>>2]=F;f=a+e|0;l=c[f>>2]|0;j=c[f+4>>2]|0;g=b+e|0;k=g|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^j;i=ZGb(h|l,g|j,((h^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[f>>2]=i;c[f+4>>2]=F;f=e<<1;i=a+f|0;k=c[i>>2]|0;l=c[i+4>>2]|0;h=b+f|0;j=h|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h^l;m=ZGb(g|k,h|l,((g^k)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[i>>2]=m;c[i+4>>2]=F;i=f+e|0;e=a+i|0;a=c[e>>2]|0;f=c[e+4>>2]|0;m=b+i|0;i=m|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m^f;j=ZGb(b|a,m|f,((b^a)>>>1|i<<31)&2147450879,(i>>>1|0<<31)&2147450879)|0;c[e>>2]=j;c[e+4>>2]=F;return}function Qua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;Jza(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=ZGb(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;l=p^o;k=ZGb(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=F;h=b+e|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=ZGb(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^p;n=ZGb(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=F;k=e<<1;n=b+k|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=ZGb(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;o=h^j;m=ZGb(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=F;l=e*3|0;e=b+l|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=ZGb(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;m=k^a;g=ZGb(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=F;i=f;return}function Rua(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d>>1;d=0;g=a;a=c;while(1){c=a+2|0;h=a-2|0;i=a+4|0;j=a+6|0;k=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[i>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<1024>>>0){l=k}else{l=-k>>31&1023}b[g>>1]=((e[g>>1]|0)+1+l|0)>>>1;k=g+2|0;m=a+8|0;n=(((e[i>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[h>>1]|0)+(((e[j>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[m>>1]|0)>>5;if(n>>>0<1024>>>0){o=n}else{o=-n>>31&1023}b[k>>1]=((e[k>>1]|0)+1+o|0)>>>1;k=g+4|0;n=a+10|0;h=(((e[j>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[m>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(h>>>0<1024>>>0){p=h}else{p=-h>>31&1023}b[k>>1]=((e[k>>1]|0)+1+p|0)>>>1;k=g+6|0;h=(((e[m>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(h>>>0<1024>>>0){q=h}else{q=-h>>31&1023}b[k>>1]=((e[k>>1]|0)+1+q|0)>>>1;k=d+1|0;if((k|0)<4){d=k;g=g+(f<<1)|0;a=a+(f<<1)|0}else{break}}return}function Sua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;Jza(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=ZGb(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;l=p^o;k=ZGb(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=F;h=b+(e+2)|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=ZGb(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^p;n=ZGb(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=F;k=e<<1;n=b+(k+2)|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=ZGb(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;o=h^j;m=ZGb(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=F;l=e*3|0;e=b+(l+2)|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=ZGb(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;m=k^a;g=ZGb(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=F;i=f;return}function Tua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;Kza(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=a;h=c[k>>2]|0;b=c[k+4>>2]|0;r=p^s;t=ZGb(l|g,p|s,((l^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^b;l=ZGb(t|h,r|b,((t^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[k>>2]=l;c[k+4>>2]=F;k=c[o>>2]|0;l=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;h=c[o+4>>2]|0;o=a+e|0;t=c[o>>2]|0;b=c[o+4>>2]|0;r=h^l;s=ZGb(g|k,h|l,((g^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;k=r^b;g=ZGb(s|t,r|b,((s^t)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[o>>2]=g;c[o+4>>2]=F;o=c[n>>2]|0;g=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=a+m|0;m=c[n>>2]|0;s=c[n+4>>2]|0;b=t^g;r=ZGb(k|o,t|g,((k^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;o=b^s;k=ZGb(r|m,b|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[n>>2]=k;c[n+4>>2]=F;n=c[q>>2]|0;k=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;o=c[q+4>>2]|0;q=a+(e*3|0)|0;e=c[q>>2]|0;a=c[q+4>>2]|0;m=o^k;r=ZGb(j|n,o|k,((j^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^a;j=ZGb(r|e,m|a,((r^e)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=j;c[q+4>>2]=F;i=f;return}function Uua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Jza(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;Kza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=a;q=c[m>>2]|0;h=c[m+4>>2]|0;b=r^g;p=ZGb(k|n,r|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(p|q,b|h,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;q=c[m>>2]|0;p=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=p^n;r=ZGb(q|k,p|n,((q^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;q=ZGb(r|h,g|b,((r^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=F;m=j+16|0;q=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;r=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=r^k;n=ZGb(h|q,r|k,((h^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;q=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;q=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=q^h;n=ZGb(l|j,q|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function Vua(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;Jza(f,b,8,d);Lza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=ZGb(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;b=o^n;g=ZGb(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=F;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=ZGb(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;g=k^o;m=ZGb(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=F;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=ZGb(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;m=b^k;n=ZGb(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=ZGb(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;f=o^a;h=ZGb(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=F;i=e;return}function Wua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Jza(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Kza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=ZGb(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=ZGb(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function Xua(a,f,g){a=a|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+72|0;j=h|0;k=j|0;l=j+16|0;m=g<<1;n=f+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=n;n=j+8|0;k=g-m|0;o=f+k|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=f;n=o|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=p;c[l+4>>2]=o;o=j+24|0;n=f+g|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=n;n=j+32|0;o=m+g+g|0;q=f+(o-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=j+40|0;n=o+g|0;o=f+(n-m)|0;r=o|0;s=o+4|0;o=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=o;o=j+48|0;q=n+g|0;n=f+(q-m)|0;r=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=n;n=j+56|0;o=q+g|0;q=f+(o-m)|0;m=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=q;q=j+64|0;j=f+(k+o)|0;o=j|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=j;j=g>>1;g=j<<1;q=j*3|0;o=l;l=a;a=1;k=p&65535;while(1){p=e[o-8>>1]|0;f=k&65535;n=e[o+8>>1]|0;m=e[o+16>>1]|0;r=e[o+24>>1]|0;s=e[o+32>>1]|0;t=e[o+40>>1]|0;u=e[o+48>>1]|0;v=(e[o-16>>1]|0)+16+((n+f|0)*20|0)+r+((m+p|0)*-5|0)>>5;if(v>>>0<1024>>>0){w=v}else{w=-v>>31&1023}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;v=l+(j<<1)|0;x=p+16+((m+n|0)*20|0)+s+((r+f|0)*-5|0)>>5;if(x>>>0<1024>>>0){y=x}else{y=-x>>31&1023}b[v>>1]=((e[v>>1]|0)+1+y|0)>>>1;v=l+(g<<1)|0;x=f+16+((r+m|0)*20|0)+t+((s+n|0)*-5|0)>>5;if(x>>>0<1024>>>0){z=x}else{z=-x>>31&1023}b[v>>1]=((e[v>>1]|0)+1+z|0)>>>1;v=l+(q<<1)|0;x=n+16+((s+r|0)*20|0)+u+((t+m|0)*-5|0)>>5;if(x>>>0<1024>>>0){A=x}else{A=-x>>31&1023}b[v>>1]=((e[v>>1]|0)+1+A|0)>>>1;v=o+2|0;if((a|0)>=4){break}o=v;l=l+2|0;a=a+1|0;k=b[v>>1]|0}i=h;return}function Yua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Kza(k,o,8);Lza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;s=c[n+4>>2]|0;r=o^j;h=ZGb(l|b,o|j,((l^b)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;b=r^s;l=ZGb(h|g,r|s,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;s=c[n>>2]|0;r=c[n+4>>2]|0;j=h^b;o=ZGb(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^r;g=ZGb(o|s,j|r,((o^s)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;s=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;r=c[n+4>>2]|0;j=o^l;b=ZGb(s|g,o|l,((s^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;g=j^r;s=ZGb(b|p,j|r,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=s;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;s=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^s;b=ZGb(m|k,g|s,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;k=p^a;m=ZGb(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;i=f;return}function Zua(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+144|0;g=f|0;h=d>>1;d=h<<1;j=c+(-d<<1)|0;c=0;k=g|0;while(1){l=b[j>>1]|0;m=b[j+2>>1]|0;n=b[j-2>>1]|0;o=b[j+4>>1]|0;p=b[j+6>>1]|0;b[k>>1]=(((((m+l&65535)*20&65535)-10230&65535)+(b[j-4>>1]|0)&65535)+((o+n&65535)*-5&65535)&65535)+p;q=b[j+8>>1]|0;b[k+2>>1]=(((((o+m&65535)*20&65535)-10230&65535)+n&65535)+((p+l&65535)*-5&65535)&65535)+q;n=b[j+10>>1]|0;b[k+4>>1]=(((((p+o&65535)*20&65535)-10230&65535)+l&65535)+((q+m&65535)*-5&65535)&65535)+n;b[k+6>>1]=(((((q+p&65535)*20&65535)-10230&65535)+m&65535)+((n+o&65535)*-5&65535)&65535)+(b[j+12>>1]|0);o=c+1|0;if((o|0)<9){j=j+(h<<1)|0;c=o;k=k+16|0}else{break}}k=h*3|0;c=a;a=0;j=g+32|0;while(1){g=b[j-16>>1]|0;o=b[j>>1]|0;n=o+10230|0;m=b[j+16>>1]|0;p=m+10230|0;q=(b[j+32>>1]|0)+10230|0;l=(b[j+48>>1]|0)+10230|0;r=(b[j+64>>1]|0)+10230|0;s=(b[j+80>>1]|0)+10230|0;t=b[j+96>>1]|0;u=(b[j-32>>1]|0)+10742+((p+n|0)*20|0)+l+((g+10230+q|0)*-5|0)>>10;if(u>>>0<1024>>>0){v=u}else{v=-u>>31&1023}b[c>>1]=((e[c>>1]|0)+1+v|0)>>>1;u=c+(h<<1)|0;w=g+10742+((q+p|0)*20|0)+r+((l+n|0)*-5|0)>>10;if(w>>>0<1024>>>0){x=w}else{x=-w>>31&1023}b[u>>1]=((e[u>>1]|0)+1+x|0)>>>1;u=c+(d<<1)|0;w=o+10742+((l+q|0)*20|0)+s+((r+p|0)*-5|0)>>10;if(w>>>0<1024>>>0){y=w}else{y=-w>>31&1023}b[u>>1]=((e[u>>1]|0)+1+y|0)>>>1;u=c+(k<<1)|0;w=m+20972+t+((r+l|0)*20|0)+((s+q|0)*-5|0)>>10;if(w>>>0<1024>>>0){z=w}else{z=-w>>31&1023}b[u>>1]=((e[u>>1]|0)+1+z|0)>>>1;u=a+1|0;if((u|0)<4){c=c+2|0;a=u;j=j+2|0}else{break}}i=f;return}function _ua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;Kza(k,o,8);Lza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;t=c[n+4>>2]|0;s=o^j;h=ZGb(l|b,o|j,((l^b)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;b=s^t;l=ZGb(h|g,s|t,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;t=c[n>>2]|0;s=c[n+4>>2]|0;j=h^b;o=ZGb(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^s;g=ZGb(o|t,j|s,((o^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;t=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;s=c[n+4>>2]|0;j=o^l;b=ZGb(t|g,o|l,((t^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;g=j^s;t=ZGb(b|p,j|s,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=t;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^t;b=ZGb(m|k,g|t,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;k=p^a;m=ZGb(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;i=f;return}function $ua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;Kza(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=a;t=c[k>>2]|0;h=c[k+4>>2]|0;b=s^g;r=ZGb(o|l,s|g,((o^l)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;l=b^h;o=ZGb(r|t,b|h,((r^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=o;c[k+4>>2]=F;k=c[n>>2]|0;o=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;t=c[n+4>>2]|0;n=a+e|0;r=c[n>>2]|0;h=c[n+4>>2]|0;b=t^o;g=ZGb(l|k,t|o,((l^k)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;k=b^h;l=ZGb(g|r,b|h,((g^r)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=c[q>>2]|0;l=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;r=c[q+4>>2]|0;q=a+m|0;m=c[q>>2]|0;g=c[q+4>>2]|0;h=r^l;b=ZGb(k|n,r|l,((k^n)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;n=h^g;k=ZGb(b|m,h|g,((b^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=k;c[q+4>>2]=F;q=c[p>>2]|0;k=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;n=c[p+4>>2]|0;p=a+(e*3|0)|0;e=c[p>>2]|0;a=c[p+4>>2]|0;m=n^k;b=ZGb(j|q,n|k,((j^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;q=m^a;j=ZGb(b|e,m|a,((b^e)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[p>>2]=j;c[p+4>>2]=F;i=f;return}function ava(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;Jza(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;Kza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=o^g;q=ZGb(k|n,o|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;o=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(o|h,g|b,((o^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;o=c[m+4>>2]|0;m=a+p|0;p=c[m>>2]|0;b=c[m+4>>2]|0;g=o^k;n=ZGb(h|r,o|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|p,g|b,((n^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;p=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;j=p^a;l=ZGb(n|e,p|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function bva(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;Jza(f,b+d|0,8,d);Lza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=ZGb(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;b=o^n;g=ZGb(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=F;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=ZGb(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;g=k^o;m=ZGb(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=F;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=ZGb(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;m=b^k;n=ZGb(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=ZGb(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;f=o^a;h=ZGb(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=F;i=e;return}function cva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;Jza(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;Kza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=ZGb(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=ZGb(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function dva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=e+8|0;h=b+f|0;g=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=h;h=e<<1;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;j=b+g|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+g|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=b+16|0;h=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+16|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=j;j=b+24|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+24|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=e+16|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=e+24|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;e=b+h|0;f=e|0;g=e+4|0;e=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+h|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=e;e=h+8|0;h=b+e|0;b=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[g+4>>2]=h;return}function eva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;Aza(g|0,b,32,e);Aza(g+16|0,b+16|0,32,e);h=e<<3;Aza(g+256|0,b+h|0,32,e);Aza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=ZGb(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ba(r,e)|0;l=h+16|0;k=b+l|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r<<5;p=g+(o|16)|0;j=p|0;q=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p+4|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p^k;n=ZGb(q|m,p|k,((q^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+l|0;c[j>>2]=n;c[j+4>>2]=F;j=h+24|0;h=b+j|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+(o|24)|0;o=n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^h;q=ZGb(m|l,n|h,((m^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;r=r+1|0;}while((r|0)<16);i=f;return}function fva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Aza(a,b,c,c);Aza(a+16|0,b+16|0,c,c);d=c<<3;Aza(a+d|0,b+d|0,c,c);e=d+16|0;Aza(a+e|0,b+e|0,c,c);return}function gva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;Aza(g|0,b,32,e);Aza(g+16|0,b+16|0,32,e);h=e<<3;Aza(g+256|0,b+h|0,32,e);Aza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=ZGb(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ba(r,e)|0;l=b+(h+18)|0;k=l|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=l+4|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=r<<5;m=g+(k|16)|0;p=m|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^l;q=ZGb(o|j,m|l,((o^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(h+16)|0;c[p>>2]=q;c[p+4>>2]=F;p=b+(h+26)|0;q=p|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(k|24)|0;k=q|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q^p;l=ZGb(o|j,q|p,((o^j)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(h+24)|0;c[k>>2]=l;c[k+4>>2]=F;r=r+1|0;}while((r|0)<16);i=f;return}function hva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Bza(j|0,h+64|0,32,32);Bza(j+16|0,h+80|0,32,32);Bza(j+256|0,h+320|0,32,32);Bza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=ZGb(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=F;m=e|8;e=h+(m+64)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=ZGb(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+64)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=ZGb(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=F;n=l|24;l=h+(n+64)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=ZGb(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function iva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Aza(j|0,e,32,f);Aza(j+16|0,e+16|0,32,f);l=f<<3;Aza(j+256|0,e+l|0,32,f);Aza(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=ZGb(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=ZGb(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=ZGb(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=F;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=ZGb(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function jva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;Aza(h|0,b,32,e);k=b+16|0;Aza(h+16|0,k,32,e);l=e<<3;m=b+l|0;Aza(h+256|0,m,32,e);n=b+(l+16)|0;Aza(h+272|0,n,32,e);l=g|0;Cza(j|0,l,b,32,32,e);b=g+32|0;Cza(j+16|0,b,k,32,32,e);Cza(j+256|0,l,m,32,32,e);Cza(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l^m;p=ZGb(o|k,l|m,((o^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ba(n,e)|0;k=a+g|0;c[k>>2]=p;c[k+4>>2]=F;k=b|8;b=h+k|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+k|0;k=p|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p+4|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p^b;l=ZGb(m|o,p|b,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(g+8)|0;c[k>>2]=l;c[k+4>>2]=F;k=n+1|0;if((k|0)<16){n=k}else{q=0;break}}do{n=q<<5;k=n|16;l=h+k|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+k|0;k=g|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^l;b=ZGb(m|o,g|l,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=ba(q,e)|0;o=a+(k+16)|0;c[o>>2]=b;c[o+4>>2]=F;o=n|24;n=h+o|0;b=n|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=n+4|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^n;g=ZGb(l|m,b|n,((l^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(k+24)|0;c[o>>2]=g;c[o+4>>2]=F;q=q+1|0;}while((q|0)<16);i=f;return}function kva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Aza(j|0,e,32,f);Aza(j+16|0,e+16|0,32,f);l=f<<3;Aza(j+256|0,e+l|0,32,f);Aza(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=ZGb(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=ZGb(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=ZGb(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=F;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=ZGb(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function lva(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+4|0;x=l;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}Bza(b,g+64|0,e,32);Bza(b+16|0,g+80|0,e,32);j=e<<3;Bza(b+j|0,g+320|0,e,32);Bza(b+(j+16)|0,g+336|0,e,32);i=f;return}function mva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=j|0;Cza(l|0,h,e,32,32,f);o=j+32|0;Cza(l+16|0,o,e+16|0,32,32,f);j=f<<3;Cza(l+256|0,h,e+j|0,32,32,f);Cza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=ZGb(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=F;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=ZGb(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=F;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=ZGb(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=F;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=ZGb(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=F;t=t+1|0;}while((t|0)<16);i=g;return}function nva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+2688|0;e=d|0;f=e|0;Cza(a,f,b,c,32,c);g=e+32|0;Cza(a+16|0,g,b+16|0,c,32,c);e=c<<3;Cza(a+e|0,f,b+e|0,c,32,c);f=e+16|0;Cza(a+f|0,g,b+f|0,c,32,c);i=d;return}function ova(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=j|0;Cza(l|0,h,e,32,32,f);o=j+32|0;Cza(l+16|0,o,e+16|0,32,32,f);j=f<<3;Cza(l+256|0,h,e+j|0,32,32,f);Cza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=ZGb(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=F;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=ZGb(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=F;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=ZGb(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=F;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=ZGb(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=F;t=t+1|0;}while((t|0)<16);i=g;return}function pva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Bza(j|0,h+64|0,32,32);Bza(j+16|0,h+80|0,32,32);Bza(j+256|0,h+320|0,32,32);Bza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=ZGb(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=F;m=e|8;e=h+(m+96)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=ZGb(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+96)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=ZGb(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=F;n=l|24;l=h+(n+96)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=ZGb(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function qva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Aza(j|0,e+f|0,32,f);l=f+16|0;Aza(j+16|0,e+l|0,32,f);m=f<<3;Aza(j+256|0,e+(m+f)|0,32,f);Aza(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=ZGb(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=ZGb(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=ZGb(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=F;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=ZGb(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function rva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;Aza(h|0,b+e|0,32,e);Aza(h+16|0,b+(e+16)|0,32,e);k=e<<3;Aza(h+256|0,b+(k+e)|0,32,e);l=k+16|0;Aza(h+272|0,b+(l+e)|0,32,e);m=g|0;Cza(j|0,m,b,32,32,e);n=g+32|0;Cza(j+16|0,n,b+16|0,32,32,e);Cza(j+256|0,m,b+k|0,32,32,e);Cza(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k^n;p=ZGb(o|m,k|n,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ba(l,e)|0;m=a+g|0;c[m>>2]=p;c[m+4>>2]=F;m=b|8;b=h+m|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+m|0;m=p|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^b;k=ZGb(n|o,p|b,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(g+8)|0;c[m>>2]=k;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{q=0;break}}do{l=q<<5;m=l|16;k=h+m|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=g|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+4|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g^k;b=ZGb(n|o,g|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(q,e)|0;o=a+(m+16)|0;c[o>>2]=b;c[o+4>>2]=F;o=l|24;l=h+o|0;b=l|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=l+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^l;g=ZGb(k|n,b|l,((k^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(m+24)|0;c[o>>2]=g;c[o+4>>2]=F;q=q+1|0;}while((q|0)<16);i=f;return}function sva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Aza(j|0,e+f|0,32,f);l=f+16|0;Aza(j+16|0,e+l|0,32,f);m=f<<3;Aza(j+256|0,e+(m+f)|0,32,f);Aza(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=ZGb(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=ZGb(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=ZGb(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=F;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=ZGb(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function tva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+(e+8)|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+(e+8)|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=e<<1;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=b+(g+8)|0;j=f|0;i=f+4|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(h+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=f;f=g+e|0;g=h+e|0;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;e=b+g|0;f=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=e;e=b+(g+8)|0;g=e|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(h+8)|0;c[b>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[b+4>>2]=e;return}function uva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;Aza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=ZGb(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function vva(a,b,c){a=a|0;b=b|0;c=c|0;Aza(a,b,c,c);return}function wva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;Aza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=ZGb(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function xva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;Bza(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k^b;h=ZGb(m|g,k|b,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(p,e)|0;g=a+o|0;c[g>>2]=h;c[g+4>>2]=F;g=n|8;n=l+g|0;h=c[n>>2]|0;m=c[n+4>>2]|0;n=j+g|0;g=n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^m;k=ZGb(b|h,n|m,((b^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(o+8)|0;c[g>>2]=k;c[g+4>>2]=F;p=p+1|0;}while((p|0)<8);i=f;return}function yva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Aza(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;Bza(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o^n;m=ZGb(h|g,o|n,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=m;c[g+4>>2]=F;g=p|8;p=j+g|0;m=p|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+g|0;g=m|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m+4|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m^p;o=ZGb(n|h,m|p,((n^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=o;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function zva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;Aza(g|0,b,16,e);Cza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=ZGb(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=F;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=ZGb(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Ava(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Aza(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Bza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=ZGb(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=ZGb(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Bva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;Bza(a,j,e,16);i=f;return}function Cva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;Bza(k|0,m,16,16);Cza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q^m;h=ZGb(g|o,q|m,((g^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=ba(b,e)|0;o=a+p|0;c[o>>2]=h;c[o+4>>2]=F;o=j|8;j=k+o|0;h=j|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+o|0;o=h|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h^j;q=ZGb(m|g,h|j,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(p+8)|0;c[o>>2]=q;c[o+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Dva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+832|0;Cza(a,d|0,b,c,16,c);i=d;return}function Eva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;Bza(k|0,m,16,16);Cza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h^m;n=ZGb(g|p,h|m,((g^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(b,e)|0;p=a+q|0;c[p>>2]=n;c[p+4>>2]=F;p=j|8;j=k+p|0;n=j|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^j;h=ZGb(m|g,n|j,((m^g)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(q+8)|0;c[p>>2]=h;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Fva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;Bza(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^g;l=ZGb(h|p,m|g,((h^p)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(o,e)|0;p=a+b|0;c[p>>2]=l;c[p+4>>2]=F;p=n|8;n=k+p|0;l=c[n>>2]|0;h=c[n+4>>2]|0;n=j+p|0;p=n|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^h;m=ZGb(g|l,n|h,((g^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(b+8)|0;c[p>>2]=m;c[p+4>>2]=F;o=o+1|0;}while((o|0)<8);i=f;return}function Gva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;Aza(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;Bza(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^o;n=ZGb(h|g,m|o,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=q|8;q=j+g|0;n=q|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^q;m=ZGb(o|h,n|q,((o^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=m;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Hva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;Aza(g|0,b+e|0,16,e);Cza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=ZGb(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=F;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=ZGb(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Iva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Aza(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Bza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=ZGb(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=ZGb(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Jva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+e|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=b+f|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=f+e|0;e=b+g|0;b=e|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[f+4>>2]=e;return}function Kva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;xza(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=ZGb(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=F;h=b+e|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=ZGb(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=F;n=e<<1;m=b+n|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=ZGb(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=F;l=e*3|0;e=b+l|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=ZGb(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=F;i=f;return}function Lva(a,b,c){a=a|0;b=b|0;c=c|0;xza(a,b,c,c);return}function Mva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;xza(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=ZGb(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=F;h=b+(e+2)|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=ZGb(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=F;n=e<<1;m=b+(n+2)|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=ZGb(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=F;l=e*3|0;e=b+(l+2)|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=ZGb(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=F;i=f;return}function Nva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;yza(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=p^s;h=ZGb(l|g,p|s,((l^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=h;c[k+4>>2]=F;k=c[o>>2]|0;h=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;l=c[o+4>>2]|0;o=l^h;s=ZGb(g|k,l|h,((g^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+e|0;c[o>>2]=s;c[o+4>>2]=F;o=c[n>>2]|0;s=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;g=c[n+4>>2]|0;n=g^s;h=ZGb(k|o,g|s,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+m|0;c[n>>2]=h;c[n+4>>2]=F;n=c[q>>2]|0;h=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;m=c[q+4>>2]|0;q=m^h;o=ZGb(j|n,m|h,((j^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+(e*3|0)|0;c[q>>2]=o;c[q+4>>2]=F;i=f;return}function Ova(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;xza(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;yza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=r^g;q=ZGb(k|n,r|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=q;c[m+4>>2]=F;m=j+8|0;q=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;r=ZGb(k|q,g|n,((k^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^q;g=ZGb(k|r,n|q,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=r;c[m+4>>2]=F;i=f;return}function Pva(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;xza(f,b,8,d);zza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=ZGb(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=F;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=ZGb(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=F;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=ZGb(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=ZGb(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=F;i=e;return}function Qva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;xza(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;yza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=ZGb(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=F;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=F;i=f;return}function Rva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+72|0;g=f|0;h=g|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=g+8|0;h=e-k|0;m=b+h|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=m;m=b;l=m|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=m;m=g+24|0;l=b+e|0;n=l|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=l;l=g+32|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=n;n=g+40|0;l=m+e|0;m=b+(l-k)|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;m=g+48|0;n=l+e|0;l=b+(n-k)|0;o=l|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=l;l=g+56|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[l+4>>2]=n;n=g+64|0;g=b+(h+m)|0;m=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=g;yza(a,j,e);i=f;return}function Sva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;yza(k,o,8);zza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=ZGb(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=F;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=ZGb(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=F;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=ZGb(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=ZGb(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=F;i=f;return}function Tva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+288|0;zza(a,d|0,b,c,c);i=d;return}function Uva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;yza(k,o,8);zza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=ZGb(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=F;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=ZGb(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=F;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=ZGb(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=ZGb(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=F;i=f;return}function Vva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;yza(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=s^g;t=ZGb(o|l,s|g,((o^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=t;c[k+4>>2]=F;k=c[n>>2]|0;t=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^t;g=ZGb(l|k,o|t,((l^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=g;c[n+4>>2]=F;n=c[q>>2]|0;g=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;l=c[q+4>>2]|0;q=l^g;t=ZGb(k|n,l|g,((k^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+m|0;c[q>>2]=t;c[q+4>>2]=F;q=c[p>>2]|0;t=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;m=c[p+4>>2]|0;p=m^t;n=ZGb(j|q,m|t,((j^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(e*3|0)|0;c[p>>2]=n;c[p+4>>2]=F;i=f;return}function Wva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;xza(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;yza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=ZGb(k|n,o|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;o=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=o;c[m+4>>2]=F;m=j+16|0;o=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|o,n|r,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+p|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;p=c[m+4>>2]|0;m=p^g;o=ZGb(l|j,p|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=o;c[m+4>>2]=F;i=f;return}function Xva(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;xza(f,b+d|0,8,d);zza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=ZGb(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=F;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=ZGb(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=F;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=ZGb(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=ZGb(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=F;i=e;return}function Yva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;xza(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;yza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=ZGb(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=F;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=F;i=f;return}function Zva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;return}function _va(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;Gza(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+e|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function $va(a,b,c){a=a|0;b=b|0;c=c|0;Gza(a,b,c,c);return}function awa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;Gza(g,b,4,e);h=b+2|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+(e+2)|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function bwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;Hza(h,j,4);n=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|n)-((j^n)>>>1&2147450879);n=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|n)-((m^n)>>>1&2147450879);i=f;return}function cwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;Gza(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;Hza(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function dwa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+120|0;f=e+112|0;g=i;i=i+8|0;Gza(f,b,4,d);Iza(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function ewa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;Gza(h,b,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Hza(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function fwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+32|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;Hza(a,h,e);i=f;return}function gwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+112|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Hza(j,l,4);Iza(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function hwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+112|0;Iza(a,d|0,b,c,c);i=d;return}function iwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+112|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=2-m|0;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+2|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+2)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e+e|0;m=b+(p+n)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;Hza(j,l,4);Iza(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function jwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-k)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Hza(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2147450879);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2147450879);i=f;return}function kwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;l=b+e|0;Gza(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Hza(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function lwa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+120|0;f=e+112|0;g=i;i=i+8|0;Gza(f,b+d|0,4,d);Iza(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function mwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;Gza(h,b+e|0,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;Hza(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function nwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=c[i+4>>2]|0;l=f;m=l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l^k;o=ZGb(n|j,l|k,((n^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[i>>2]=o;c[i+4>>2]=F;i=g+8|0;o=c[i>>2]|0;m=c[i+4>>2]|0;j=f+8|0;n=j|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j^m;l=ZGb(k|o,j|m,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[i>>2]=l;c[i+4>>2]=F;i=h+1|0;if((i|0)<16){f=f+e|0;g=g+e|0;h=i}else{break}}h=b+16|0;b=a+16|0;a=0;while(1){g=b;f=c[g>>2]|0;i=c[g+4>>2]|0;l=h;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^i;k=ZGb(o|f,l|i,((o^f)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[g>>2]=k;c[g+4>>2]=F;g=b+8|0;k=c[g>>2]|0;n=c[g+4>>2]|0;f=h+8|0;o=f|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f+4|0;f=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f^n;l=ZGb(i|k,f|n,((i^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[g>>2]=l;c[g+4>>2]=F;g=a+1|0;if((g|0)<16){h=h+e|0;b=b+e|0;a=g}else{break}}return}function owa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;Aza(g|0,b,32,e);Aza(g+16|0,b+16|0,32,e);h=e<<3;Aza(g+256|0,b+h|0,32,e);Aza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=ZGb(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ba(u,e)|0;l=h+16|0;q=b+l|0;m=q|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=u<<5;s=g+(m|16)|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+l|0;l=c[t>>2]|0;j=c[t+4>>2]|0;p=s^q;k=ZGb(r|o,s|q,((r^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;o=p^j;r=ZGb(k|l,p|j,((k^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;t=h+24|0;h=b+t|0;r=h|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+(m|24)|0;m=r|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r+4|0;r=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+t|0;t=c[m>>2]|0;k=c[m+4>>2]|0;j=r^h;p=ZGb(l|o,r|h,((l^o)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;o=j^k;l=ZGb(p|t,j|k,((p^t)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function pwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Fza(a,b,c,c);Fza(a+16|0,b+16|0,c,c);d=c<<3;Fza(a+d|0,b+d|0,c,c);e=d+16|0;Fza(a+e|0,b+e|0,c,c);return}function qwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;Aza(g|0,b,32,e);Aza(g+16|0,b+16|0,32,e);h=e<<3;Aza(g+256|0,b+h|0,32,e);Aza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=ZGb(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ba(u,e)|0;l=b+(h+18)|0;q=l|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=u<<5;j=g+(q|16)|0;s=j|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=a+(h+16)|0;r=c[s>>2]|0;o=c[s+4>>2]|0;p=j^l;k=ZGb(t|m,j|l,((t^m)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;m=p^o;t=ZGb(k|r,p|o,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[s>>2]=t;c[s+4>>2]=F;s=b+(h+26)|0;t=s|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=g+(q|24)|0;q=t|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=t+4|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=a+(h+24)|0;h=c[q>>2]|0;k=c[q+4>>2]|0;o=t^s;p=ZGb(r|m,t|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;m=o^k;r=ZGb(p|h,o|k,((p^h)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function rwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Bza(j|0,h+64|0,32,32);Bza(j+16|0,h+80|0,32,32);Bza(j+256|0,h+320|0,32,32);Bza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=ZGb(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;m=t^s;n=ZGb(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=F;q=e|8;e=h+(q+64)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=ZGb(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^u;r=ZGb(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+80)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=ZGb(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=F;m=n^e;t=ZGb(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h+((l|8)+80)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=ZGb(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^k;s=ZGb(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function swa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Aza(j|0,e,32,f);Aza(j+16|0,e+16|0,32,f);l=f<<3;Aza(j+256|0,e+l|0,32,f);Aza(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=ZGb(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=ZGb(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^m;t=ZGb(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^e;s=ZGb(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function twa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;Aza(h|0,b,32,e);k=b+16|0;Aza(h+16|0,k,32,e);l=e<<3;m=b+l|0;Aza(h+256|0,m,32,e);n=b+(l+16)|0;Aza(h+272|0,n,32,e);l=g|0;Cza(j|0,l,b,32,32,e);b=g+32|0;Cza(j+16|0,b,k,32,32,e);Cza(j+256|0,l,m,32,32,e);Cza(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(n,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^m;t=ZGb(o|k,l|m,((o^k)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;k=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=b|8;b=h+p|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=ZGb(q|k,o|b,((q^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;k=r^t;q=ZGb(s|g,r|t,((s^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;p=n+1|0;if((p|0)<16){n=p}else{u=0;break}}do{n=u<<5;p=n|16;q=h+p|0;k=q|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+p|0;p=k|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=k^q;m=ZGb(s|g,k|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;g=o^b;s=ZGb(m|r,o|b,((m^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=F;t=n|24;n=h+t|0;s=n|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;m=c[t+4>>2]|0;b=s^n;o=ZGb(r|g,s|n,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;g=b^m;r=ZGb(o|p,b|m,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function uwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Aza(j|0,e,32,f);Aza(j+16|0,e+16|0,32,f);l=f<<3;Aza(j+256|0,e+l|0,32,f);Aza(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=ZGb(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=ZGb(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^m;t=ZGb(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^e;s=ZGb(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function vwa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+4|0;x=l;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}Eza(b,g+64|0,e,32);Eza(b+16|0,g+80|0,e,32);j=e<<3;Eza(b+j|0,g+320|0,e,32);Eza(b+(j+16)|0,g+336|0,e,32);i=f;return}function wwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=j|0;Cza(l|0,h,e,32,32,f);o=j+32|0;Cza(l+16|0,o,e+16|0,32,32,f);j=f<<3;Cza(l+256|0,h,e+j|0,32,32,f);Cza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=ZGb(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;n=t^q;s=ZGb(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=F;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=ZGb(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=F;n=q^u;r=ZGb(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=F;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=ZGb(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^e;t=ZGb(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=ZGb(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^o;q=ZGb(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function xwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+2688|0;e=d|0;f=e|0;Dza(a,f,b,c,32,c);g=e+32|0;Dza(a+16|0,g,b+16|0,c,32,c);e=c<<3;Dza(a+e|0,f,b+e|0,c,32,c);f=e+16|0;Dza(a+f|0,g,b+f|0,c,32,c);i=d;return}function ywa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=j|0;Cza(l|0,h,e,32,32,f);o=j+32|0;Cza(l+16|0,o,e+16|0,32,32,f);j=f<<3;Cza(l+256|0,h,e+j|0,32,32,f);Cza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=ZGb(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;n=t^q;s=ZGb(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=F;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=ZGb(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=F;n=q^u;r=ZGb(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=F;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=ZGb(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^e;t=ZGb(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=ZGb(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^o;q=ZGb(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function zwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}Bza(j|0,h+64|0,32,32);Bza(j+16|0,h+80|0,32,32);Bza(j+256|0,h+320|0,32,32);Bza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=ZGb(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;m=t^s;n=ZGb(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=F;q=e|8;e=h+(q+96)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=ZGb(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^u;r=ZGb(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+112)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=ZGb(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=F;m=n^e;t=ZGb(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h+((l|8)+112)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=ZGb(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^k;s=ZGb(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function Awa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Aza(j|0,e+f|0,32,f);l=f+16|0;Aza(j+16|0,e+l|0,32,f);m=f<<3;Aza(j+256|0,e+(m+f)|0,32,f);Aza(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=ZGb(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=ZGb(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^l;t=ZGb(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=F;n=l^e;s=ZGb(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function Bwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;Aza(h|0,b+e|0,32,e);Aza(h+16|0,b+(e+16)|0,32,e);k=e<<3;Aza(h+256|0,b+(k+e)|0,32,e);l=k+16|0;Aza(h+272|0,b+(l+e)|0,32,e);m=g|0;Cza(j|0,m,b,32,32,e);n=g+32|0;Cza(j+16|0,n,b+16|0,32,32,e);Cza(j+256|0,m,b+k|0,32,32,e);Cza(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(l,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=k^n;t=ZGb(o|m,k|n,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=b|8;b=h+p|0;o=b|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=ZGb(q|m,o|b,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|g,r|t,((s^g)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;p=l+1|0;if((p|0)<16){l=p}else{u=0;break}}do{l=u<<5;p=l|16;q=h+p|0;m=q|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+p|0;p=m|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=m^q;n=ZGb(s|g,m|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;g=o^b;s=ZGb(n|r,o|b,((n^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=F;t=l|24;l=h+t|0;s=l|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+4|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;n=c[t+4>>2]|0;b=s^l;o=ZGb(r|g,s|l,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;g=b^n;r=ZGb(o|p,b|n,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function Cwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;Aza(j|0,e+f|0,32,f);l=f+16|0;Aza(j+16|0,e+l|0,32,f);m=f<<3;Aza(j+256|0,e+(m+f)|0,32,f);Aza(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}Bza(k|0,h+64|0,32,32);Bza(k+16|0,h+80|0,32,32);Bza(k+256|0,h+320|0,32,32);Bza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=ZGb(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=ZGb(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^l;t=ZGb(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=F;n=l^e;s=ZGb(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function Dwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;j=f;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j^i;m=ZGb(l|h,j|i,((l^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[g>>2]=m;c[g+4>>2]=F;g=b+8|0;m=c[g>>2]|0;k=c[g+4>>2]|0;h=f+8|0;l=h|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h^k;j=ZGb(i|m,h|k,((i^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[g>>2]=j;c[g+4>>2]=F;g=a+1|0;if((g|0)<8){f=f+e|0;b=b+e|0;a=g}else{break}}return}function Ewa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;Aza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=ZGb(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function Fwa(a,b,c){a=a|0;b=b|0;c=c|0;Fza(a,b,c,c);return}function Gwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;Aza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=ZGb(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function Hwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;Bza(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(p,e)|0;h=a+o|0;q=c[h>>2]|0;r=c[h+4>>2]|0;s=k^b;t=ZGb(m|g,k|b,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[h>>2]=m;c[h+4>>2]=F;h=n|8;n=l+h|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=j+h|0;h=n|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(o+8)|0;o=c[h>>2]|0;t=c[h+4>>2]|0;r=n^g;s=ZGb(q|m,n|g,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[h>>2]=q;c[h+4>>2]=F;p=p+1|0;}while((p|0)<8);i=f;return}function Iwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Aza(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;Bza(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;m=a+b|0;q=c[m>>2]|0;r=c[m+4>>2]|0;s=o^n;t=ZGb(h|g,o|n,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;h=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=p|8;p=j+m|0;h=p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+m|0;m=h|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+(b+8)|0;b=c[m>>2]|0;t=c[m+4>>2]|0;r=h^p;s=ZGb(q|g,h|p,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Jwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;Aza(g|0,b,16,e);Cza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=ZGb(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=ZGb(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Kwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Aza(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Bza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=ZGb(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=ZGb(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Lwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;Eza(a,j,e,16);i=f;return}function Mwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;Bza(k|0,m,16,16);Cza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(b,e)|0;h=a+p|0;n=c[h>>2]|0;r=c[h+4>>2]|0;s=q^m;t=ZGb(g|o,q|m,((g^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;o=s^r;g=ZGb(t|n,s|r,((t^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=g;c[h+4>>2]=F;h=j|8;j=k+h|0;g=j|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+h|0;h=g|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(p+8)|0;p=c[h>>2]|0;t=c[h+4>>2]|0;r=g^j;s=ZGb(n|o,g|j,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;o=r^t;n=ZGb(s|p,r|t,((s^p)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=n;c[h+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Nwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+832|0;Dza(a,d|0,b,c,16,c);i=d;return}function Owa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;Bza(k|0,m,16,16);Cza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=ba(b,e)|0;n=a+q|0;o=c[n>>2]|0;r=c[n+4>>2]|0;s=h^m;t=ZGb(g|p,h|m,((g^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;p=s^r;g=ZGb(t|o,s|r,((t^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=j|8;j=k+n|0;g=j|0;p=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+n|0;n=g|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+4|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(q+8)|0;q=c[n>>2]|0;t=c[n+4>>2]|0;r=g^j;s=ZGb(o|p,g|j,((o^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;p=r^t;o=ZGb(s|q,r|t,((s^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=o;c[n+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Pwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;Bza(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(o,e)|0;l=a+b|0;q=c[l>>2]|0;r=c[l+4>>2]|0;s=m^g;t=ZGb(h|p,m|g,((h^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;p=s^r;h=ZGb(t|q,s|r,((t^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[l>>2]=h;c[l+4>>2]=F;l=n|8;n=k+l|0;h=c[n>>2]|0;p=c[n+4>>2]|0;n=j+l|0;l=n|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(b+8)|0;b=c[l>>2]|0;t=c[l+4>>2]|0;r=n^p;s=ZGb(q|h,n|p,((q^h)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;h=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;o=o+1|0;}while((o|0)<8);i=f;return}function Qwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;Aza(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;Bza(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;p=c[n>>2]|0;r=c[n+4>>2]|0;s=m^o;t=ZGb(h|g,m|o,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;h=ZGb(t|p,s|r,((t^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=h;c[n+4>>2]=F;n=q|8;q=j+n|0;h=q|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=h^q;s=ZGb(p|g,h|q,((p^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;p=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=p;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Rwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;Aza(g|0,b+e|0,16,e);Cza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=ZGb(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=ZGb(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Swa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;Aza(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;Bza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=ZGb(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=ZGb(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Twa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=c[f>>2]|0;h=c[f+4>>2]|0;i=b;j=i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i+4|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i^h;l=ZGb(k|g,i|h,((k^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[f>>2]=l;c[f+4>>2]=F;f=a+e|0;l=c[f>>2]|0;j=c[f+4>>2]|0;g=b+e|0;k=g|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^j;i=ZGb(h|l,g|j,((h^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[f>>2]=i;c[f+4>>2]=F;f=e<<1;i=a+f|0;k=c[i>>2]|0;l=c[i+4>>2]|0;h=b+f|0;j=h|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h^l;m=ZGb(g|k,h|l,((g^k)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[i>>2]=m;c[i+4>>2]=F;i=f+e|0;e=a+i|0;a=c[e>>2]|0;f=c[e+4>>2]|0;m=b+i|0;i=m|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m^f;j=ZGb(b|a,m|f,((b^a)>>>1|i<<31)&2147450879,(i>>>1|0<<31)&2147450879)|0;c[e>>2]=j;c[e+4>>2]=F;return}function Uwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;xza(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=ZGb(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;l=p^o;k=ZGb(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=F;h=b+e|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=ZGb(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^p;n=ZGb(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=F;k=e<<1;n=b+k|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=ZGb(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;o=h^j;m=ZGb(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=F;l=e*3|0;e=b+l|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=ZGb(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;m=k^a;g=ZGb(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=F;i=f;return}function Vwa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d>>1;d=0;g=a;a=c;while(1){c=a+2|0;h=a-2|0;i=a+4|0;j=a+6|0;k=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[i>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<4096>>>0){l=k}else{l=-k>>31&4095}b[g>>1]=((e[g>>1]|0)+1+l|0)>>>1;k=g+2|0;m=a+8|0;n=(((e[i>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[h>>1]|0)+(((e[j>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[m>>1]|0)>>5;if(n>>>0<4096>>>0){o=n}else{o=-n>>31&4095}b[k>>1]=((e[k>>1]|0)+1+o|0)>>>1;k=g+4|0;n=a+10|0;h=(((e[j>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[m>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(h>>>0<4096>>>0){p=h}else{p=-h>>31&4095}b[k>>1]=((e[k>>1]|0)+1+p|0)>>>1;k=g+6|0;h=(((e[m>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(h>>>0<4096>>>0){q=h}else{q=-h>>31&4095}b[k>>1]=((e[k>>1]|0)+1+q|0)>>>1;k=d+1|0;if((k|0)<4){d=k;g=g+(f<<1)|0;a=a+(f<<1)|0}else{break}}return}function Wwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;xza(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=ZGb(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;l=p^o;k=ZGb(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=F;h=b+(e+2)|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=ZGb(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^p;n=ZGb(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=F;k=e<<1;n=b+(k+2)|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=ZGb(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;o=h^j;m=ZGb(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=F;l=e*3|0;e=b+(l+2)|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=ZGb(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;m=k^a;g=ZGb(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=F;i=f;return}function Xwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;yza(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=a;h=c[k>>2]|0;b=c[k+4>>2]|0;r=p^s;t=ZGb(l|g,p|s,((l^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^b;l=ZGb(t|h,r|b,((t^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[k>>2]=l;c[k+4>>2]=F;k=c[o>>2]|0;l=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;h=c[o+4>>2]|0;o=a+e|0;t=c[o>>2]|0;b=c[o+4>>2]|0;r=h^l;s=ZGb(g|k,h|l,((g^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;k=r^b;g=ZGb(s|t,r|b,((s^t)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[o>>2]=g;c[o+4>>2]=F;o=c[n>>2]|0;g=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=a+m|0;m=c[n>>2]|0;s=c[n+4>>2]|0;b=t^g;r=ZGb(k|o,t|g,((k^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;o=b^s;k=ZGb(r|m,b|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[n>>2]=k;c[n+4>>2]=F;n=c[q>>2]|0;k=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;o=c[q+4>>2]|0;q=a+(e*3|0)|0;e=c[q>>2]|0;a=c[q+4>>2]|0;m=o^k;r=ZGb(j|n,o|k,((j^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^a;j=ZGb(r|e,m|a,((r^e)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=j;c[q+4>>2]=F;i=f;return}function Ywa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;xza(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;yza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=a;q=c[m>>2]|0;h=c[m+4>>2]|0;b=r^g;p=ZGb(k|n,r|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(p|q,b|h,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;q=c[m>>2]|0;p=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=p^n;r=ZGb(q|k,p|n,((q^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;q=ZGb(r|h,g|b,((r^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=F;m=j+16|0;q=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;r=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=r^k;n=ZGb(h|q,r|k,((h^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;q=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;q=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=q^h;n=ZGb(l|j,q|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function Zwa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;xza(f,b,8,d);zza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=ZGb(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;b=o^n;g=ZGb(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=F;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=ZGb(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;g=k^o;m=ZGb(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=F;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=ZGb(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;m=b^k;n=ZGb(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=ZGb(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;f=o^a;h=ZGb(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=F;i=e;return}function _wa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;xza(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;yza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=ZGb(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=ZGb(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function $wa(a,f,g){a=a|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+72|0;j=h|0;k=j|0;l=j+16|0;m=g<<1;n=f+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=n;n=j+8|0;k=g-m|0;o=f+k|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=f;n=o|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=p;c[l+4>>2]=o;o=j+24|0;n=f+g|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=n;n=j+32|0;o=m+g+g|0;q=f+(o-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=j+40|0;n=o+g|0;o=f+(n-m)|0;r=o|0;s=o+4|0;o=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=o;o=j+48|0;q=n+g|0;n=f+(q-m)|0;r=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=n;n=j+56|0;o=q+g|0;q=f+(o-m)|0;m=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=q;q=j+64|0;j=f+(k+o)|0;o=j|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=j;j=g>>1;g=j<<1;q=j*3|0;o=l;l=a;a=1;k=p&65535;while(1){p=e[o-8>>1]|0;f=k&65535;n=e[o+8>>1]|0;m=e[o+16>>1]|0;r=e[o+24>>1]|0;s=e[o+32>>1]|0;t=e[o+40>>1]|0;u=e[o+48>>1]|0;v=(e[o-16>>1]|0)+16+((n+f|0)*20|0)+r+((m+p|0)*-5|0)>>5;if(v>>>0<4096>>>0){w=v}else{w=-v>>31&4095}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;v=l+(j<<1)|0;x=p+16+((m+n|0)*20|0)+s+((r+f|0)*-5|0)>>5;if(x>>>0<4096>>>0){y=x}else{y=-x>>31&4095}b[v>>1]=((e[v>>1]|0)+1+y|0)>>>1;v=l+(g<<1)|0;x=f+16+((r+m|0)*20|0)+t+((s+n|0)*-5|0)>>5;if(x>>>0<4096>>>0){z=x}else{z=-x>>31&4095}b[v>>1]=((e[v>>1]|0)+1+z|0)>>>1;v=l+(q<<1)|0;x=n+16+((s+r|0)*20|0)+u+((t+m|0)*-5|0)>>5;if(x>>>0<4096>>>0){A=x}else{A=-x>>31&4095}b[v>>1]=((e[v>>1]|0)+1+A|0)>>>1;v=o+2|0;if((a|0)>=4){break}o=v;l=l+2|0;a=a+1|0;k=b[v>>1]|0}i=h;return}function axa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;yza(k,o,8);zza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;s=c[n+4>>2]|0;r=o^j;h=ZGb(l|b,o|j,((l^b)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;b=r^s;l=ZGb(h|g,r|s,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;s=c[n>>2]|0;r=c[n+4>>2]|0;j=h^b;o=ZGb(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^r;g=ZGb(o|s,j|r,((o^s)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;s=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;r=c[n+4>>2]|0;j=o^l;b=ZGb(s|g,o|l,((s^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;g=j^r;s=ZGb(b|p,j|r,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=s;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;s=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^s;b=ZGb(m|k,g|s,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;k=p^a;m=ZGb(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;i=f;return}function bxa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+288|0;h=g|0;j=f>>1;f=j<<1;k=d+(-f<<1)|0;d=0;l=h|0;while(1){m=e[k>>1]|0;n=e[k+2>>1]|0;o=e[k-2>>1]|0;p=e[k+4>>1]|0;q=e[k+6>>1]|0;c[l>>2]=(e[k-4>>1]|0)+((n+m|0)*20|0)+((p+o|0)*-5|0)+q;r=e[k+8>>1]|0;c[l+4>>2]=((p+n|0)*20|0)+o+r+((q+m|0)*-5|0);o=e[k+10>>1]|0;c[l+8>>2]=((q+p|0)*20|0)+m+o+((r+n|0)*-5|0);c[l+12>>2]=((r+q|0)*20|0)+n+(e[k+12>>1]|0)+((o+p|0)*-5|0);p=d+1|0;if((p|0)<9){k=k+(j<<1)|0;d=p;l=l+32|0}else{break}}l=j*3|0;d=a;a=0;k=h+64|0;while(1){h=c[k-32>>2]|0;p=c[k>>2]|0;o=c[k+32>>2]|0;n=c[k+64>>2]|0;q=c[k+96>>2]|0;r=c[k+128>>2]|0;m=c[k+160>>2]|0;s=c[k+192>>2]|0;t=(c[k-64>>2]|0)+512+((o+p|0)*20|0)+q+((n+h|0)*-5|0)>>10;if(t>>>0<4096>>>0){u=t}else{u=-t>>31&4095}b[d>>1]=((e[d>>1]|0)+1+u|0)>>>1;t=d+(j<<1)|0;v=h+512+((n+o|0)*20|0)+r+((q+p|0)*-5|0)>>10;if(v>>>0<4096>>>0){w=v}else{w=-v>>31&4095}b[t>>1]=((e[t>>1]|0)+1+w|0)>>>1;t=d+(f<<1)|0;v=p+512+((q+n|0)*20|0)+m+((r+o|0)*-5|0)>>10;if(v>>>0<4096>>>0){x=v}else{x=-v>>31&4095}b[t>>1]=((e[t>>1]|0)+1+x|0)>>>1;t=d+(l<<1)|0;v=o+512+((r+q|0)*20|0)+s+((m+n|0)*-5|0)>>10;if(v>>>0<4096>>>0){y=v}else{y=-v>>31&4095}b[t>>1]=((e[t>>1]|0)+1+y|0)>>>1;t=a+1|0;if((t|0)<4){d=d+2|0;a=t;k=k+4|0}else{break}}i=g;return}function cxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;yza(k,o,8);zza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;t=c[n+4>>2]|0;s=o^j;h=ZGb(l|b,o|j,((l^b)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;b=s^t;l=ZGb(h|g,s|t,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;t=c[n>>2]|0;s=c[n+4>>2]|0;j=h^b;o=ZGb(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^s;g=ZGb(o|t,j|s,((o^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;t=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;s=c[n+4>>2]|0;j=o^l;b=ZGb(t|g,o|l,((t^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;g=j^s;t=ZGb(b|p,j|s,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=t;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^t;b=ZGb(m|k,g|t,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;k=p^a;m=ZGb(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;i=f;return}function dxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;yza(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=a;t=c[k>>2]|0;h=c[k+4>>2]|0;b=s^g;r=ZGb(o|l,s|g,((o^l)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;l=b^h;o=ZGb(r|t,b|h,((r^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=o;c[k+4>>2]=F;k=c[n>>2]|0;o=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;t=c[n+4>>2]|0;n=a+e|0;r=c[n>>2]|0;h=c[n+4>>2]|0;b=t^o;g=ZGb(l|k,t|o,((l^k)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;k=b^h;l=ZGb(g|r,b|h,((g^r)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=F;n=c[q>>2]|0;l=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;r=c[q+4>>2]|0;q=a+m|0;m=c[q>>2]|0;g=c[q+4>>2]|0;h=r^l;b=ZGb(k|n,r|l,((k^n)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;n=h^g;k=ZGb(b|m,h|g,((b^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=k;c[q+4>>2]=F;q=c[p>>2]|0;k=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;n=c[p+4>>2]|0;p=a+(e*3|0)|0;e=c[p>>2]|0;a=c[p+4>>2]|0;m=n^k;b=ZGb(j|q,n|k,((j^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;q=m^a;j=ZGb(b|e,m|a,((b^e)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[p>>2]=j;c[p+4>>2]=F;i=f;return}function exa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;xza(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;yza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=o^g;q=ZGb(k|n,o|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;o=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(o|h,g|b,((o^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;o=c[m+4>>2]|0;m=a+p|0;p=c[m>>2]|0;b=c[m+4>>2]|0;g=o^k;n=ZGb(h|r,o|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|p,g|b,((n^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;p=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;j=p^a;l=ZGb(n|e,p|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function fxa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;xza(f,b+d|0,8,d);zza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=ZGb(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;b=o^n;g=ZGb(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=F;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=ZGb(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;g=k^o;m=ZGb(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=F;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=ZGb(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;m=b^k;n=ZGb(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=ZGb(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;f=o^a;h=ZGb(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=F;i=e;return}function gxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;xza(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;yza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=ZGb(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=ZGb(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;r=ZGb(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=ZGb(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;r=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=ZGb(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function hxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=e+8|0;h=b+f|0;g=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=h;h=e<<1;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;j=b+g|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+g|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=b+16|0;h=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+16|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=j;j=b+24|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+24|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=e+16|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=e+24|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;e=b+h|0;f=e|0;g=e+4|0;e=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+h|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=e;e=h+8|0;h=b+e|0;b=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[g+4>>2]=h;return}function ixa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;oza(g|0,b,32,e);oza(g+16|0,b+16|0,32,e);h=e<<3;oza(g+256|0,b+h|0,32,e);oza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=ZGb(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ba(r,e)|0;l=h+16|0;k=b+l|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r<<5;p=g+(o|16)|0;j=p|0;q=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p+4|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p^k;n=ZGb(q|m,p|k,((q^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+l|0;c[j>>2]=n;c[j+4>>2]=F;j=h+24|0;h=b+j|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+(o|24)|0;o=n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^h;q=ZGb(m|l,n|h,((m^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;r=r+1|0;}while((r|0)<16);i=f;return}function jxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;oza(a,b,c,c);oza(a+16|0,b+16|0,c,c);d=c<<3;oza(a+d|0,b+d|0,c,c);e=d+16|0;oza(a+e|0,b+e|0,c,c);return}function kxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;oza(g|0,b,32,e);oza(g+16|0,b+16|0,32,e);h=e<<3;oza(g+256|0,b+h|0,32,e);oza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=ZGb(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ba(r,e)|0;l=b+(h+18)|0;k=l|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=l+4|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=r<<5;m=g+(k|16)|0;p=m|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^l;q=ZGb(o|j,m|l,((o^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(h+16)|0;c[p>>2]=q;c[p+4>>2]=F;p=b+(h+26)|0;q=p|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(k|24)|0;k=q|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q^p;l=ZGb(o|j,q|p,((o^j)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(h+24)|0;c[k>>2]=l;c[k+4>>2]=F;r=r+1|0;}while((r|0)<16);i=f;return}function lxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}pza(j|0,h+64|0,32,32);pza(j+16|0,h+80|0,32,32);pza(j+256|0,h+320|0,32,32);pza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=ZGb(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=F;m=e|8;e=h+(m+64)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=ZGb(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+64)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=ZGb(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=F;n=l|24;l=h+(n+64)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=ZGb(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function mxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;oza(j|0,e,32,f);oza(j+16|0,e+16|0,32,f);l=f<<3;oza(j+256|0,e+l|0,32,f);oza(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=ZGb(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=ZGb(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=ZGb(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=F;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=ZGb(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function nxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;oza(h|0,b,32,e);k=b+16|0;oza(h+16|0,k,32,e);l=e<<3;m=b+l|0;oza(h+256|0,m,32,e);n=b+(l+16)|0;oza(h+272|0,n,32,e);l=g|0;qza(j|0,l,b,32,32,e);b=g+32|0;qza(j+16|0,b,k,32,32,e);qza(j+256|0,l,m,32,32,e);qza(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l^m;p=ZGb(o|k,l|m,((o^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ba(n,e)|0;k=a+g|0;c[k>>2]=p;c[k+4>>2]=F;k=b|8;b=h+k|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+k|0;k=p|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p+4|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p^b;l=ZGb(m|o,p|b,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(g+8)|0;c[k>>2]=l;c[k+4>>2]=F;k=n+1|0;if((k|0)<16){n=k}else{q=0;break}}do{n=q<<5;k=n|16;l=h+k|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+k|0;k=g|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^l;b=ZGb(m|o,g|l,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=ba(q,e)|0;o=a+(k+16)|0;c[o>>2]=b;c[o+4>>2]=F;o=n|24;n=h+o|0;b=n|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=n+4|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^n;g=ZGb(l|m,b|n,((l^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(k+24)|0;c[o>>2]=g;c[o+4>>2]=F;q=q+1|0;}while((q|0)<16);i=f;return}function oxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;oza(j|0,e,32,f);oza(j+16|0,e+16|0,32,f);l=f<<3;oza(j+256|0,e+l|0,32,f);oza(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=ZGb(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=ZGb(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=ZGb(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=F;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=ZGb(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function pxa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+4|0;x=l;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}pza(b,g+64|0,e,32);pza(b+16|0,g+80|0,e,32);j=e<<3;pza(b+j|0,g+320|0,e,32);pza(b+(j+16)|0,g+336|0,e,32);i=f;return}function qxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=j|0;qza(l|0,h,e,32,32,f);o=j+32|0;qza(l+16|0,o,e+16|0,32,32,f);j=f<<3;qza(l+256|0,h,e+j|0,32,32,f);qza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=ZGb(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=F;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=ZGb(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=F;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=ZGb(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=F;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=ZGb(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=F;t=t+1|0;}while((t|0)<16);i=g;return}function rxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+2688|0;e=d|0;f=e|0;qza(a,f,b,c,32,c);g=e+32|0;qza(a+16|0,g,b+16|0,c,32,c);e=c<<3;qza(a+e|0,f,b+e|0,c,32,c);f=e+16|0;qza(a+f|0,g,b+f|0,c,32,c);i=d;return}function sxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=j|0;qza(l|0,h,e,32,32,f);o=j+32|0;qza(l+16|0,o,e+16|0,32,32,f);j=f<<3;qza(l+256|0,h,e+j|0,32,32,f);qza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=ZGb(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=F;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=ZGb(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=F;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=ZGb(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=F;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=ZGb(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=F;t=t+1|0;}while((t|0)<16);i=g;return}function txa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}pza(j|0,h+64|0,32,32);pza(j+16|0,h+80|0,32,32);pza(j+256|0,h+320|0,32,32);pza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=ZGb(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=F;m=e|8;e=h+(m+96)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=ZGb(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+96)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=ZGb(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=F;n=l|24;l=h+(n+96)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=ZGb(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function uxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;oza(j|0,e+f|0,32,f);l=f+16|0;oza(j+16|0,e+l|0,32,f);m=f<<3;oza(j+256|0,e+(m+f)|0,32,f);oza(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=ZGb(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=ZGb(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=ZGb(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=F;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=ZGb(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function vxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;oza(h|0,b+e|0,32,e);oza(h+16|0,b+(e+16)|0,32,e);k=e<<3;oza(h+256|0,b+(k+e)|0,32,e);l=k+16|0;oza(h+272|0,b+(l+e)|0,32,e);m=g|0;qza(j|0,m,b,32,32,e);n=g+32|0;qza(j+16|0,n,b+16|0,32,32,e);qza(j+256|0,m,b+k|0,32,32,e);qza(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k^n;p=ZGb(o|m,k|n,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ba(l,e)|0;m=a+g|0;c[m>>2]=p;c[m+4>>2]=F;m=b|8;b=h+m|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+m|0;m=p|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^b;k=ZGb(n|o,p|b,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(g+8)|0;c[m>>2]=k;c[m+4>>2]=F;m=l+1|0;if((m|0)<16){l=m}else{q=0;break}}do{l=q<<5;m=l|16;k=h+m|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=g|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+4|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g^k;b=ZGb(n|o,g|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ba(q,e)|0;o=a+(m+16)|0;c[o>>2]=b;c[o+4>>2]=F;o=l|24;l=h+o|0;b=l|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=l+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^l;g=ZGb(k|n,b|l,((k^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(m+24)|0;c[o>>2]=g;c[o+4>>2]=F;q=q+1|0;}while((q|0)<16);i=f;return}function wxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;oza(j|0,e+f|0,32,f);l=f+16|0;oza(j+16|0,e+l|0,32,f);m=f<<3;oza(j+256|0,e+(m+f)|0,32,f);oza(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=ZGb(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=F;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=ZGb(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=F;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=ZGb(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=F;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=ZGb(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=F;r=r+1|0;}while((r|0)<16);i=g;return}function xxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+(e+8)|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+(e+8)|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=e<<1;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=b+(g+8)|0;j=f|0;i=f+4|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(h+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=f;f=g+e|0;g=h+e|0;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;e=b+g|0;f=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=e;e=b+(g+8)|0;g=e|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(h+8)|0;c[b>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[b+4>>2]=e;return}function yxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;oza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=ZGb(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function zxa(a,b,c){a=a|0;b=b|0;c=c|0;oza(a,b,c,c);return}function Axa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;oza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=ZGb(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=F;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=ZGb(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function Bxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;pza(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k^b;h=ZGb(m|g,k|b,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ba(p,e)|0;g=a+o|0;c[g>>2]=h;c[g+4>>2]=F;g=n|8;n=l+g|0;h=c[n>>2]|0;m=c[n+4>>2]|0;n=j+g|0;g=n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^m;k=ZGb(b|h,n|m,((b^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(o+8)|0;c[g>>2]=k;c[g+4>>2]=F;p=p+1|0;}while((p|0)<8);i=f;return}function Cxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;oza(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;pza(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o^n;m=ZGb(h|g,o|n,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=m;c[g+4>>2]=F;g=p|8;p=j+g|0;m=p|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+g|0;g=m|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m+4|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m^p;o=ZGb(n|h,m|p,((n^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=o;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Dxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;oza(g|0,b,16,e);qza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=ZGb(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=F;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=ZGb(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Exa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;oza(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;pza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=ZGb(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=ZGb(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Fxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;pza(a,j,e,16);i=f;return}function Gxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;pza(k|0,m,16,16);qza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q^m;h=ZGb(g|o,q|m,((g^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=ba(b,e)|0;o=a+p|0;c[o>>2]=h;c[o+4>>2]=F;o=j|8;j=k+o|0;h=j|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+o|0;o=h|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h^j;q=ZGb(m|g,h|j,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(p+8)|0;c[o>>2]=q;c[o+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Hxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+832|0;qza(a,d|0,b,c,16,c);i=d;return}function Ixa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;pza(k|0,m,16,16);qza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h^m;n=ZGb(g|p,h|m,((g^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ba(b,e)|0;p=a+q|0;c[p>>2]=n;c[p+4>>2]=F;p=j|8;j=k+p|0;n=j|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^j;h=ZGb(m|g,n|j,((m^g)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(q+8)|0;c[p>>2]=h;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Jxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;pza(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^g;l=ZGb(h|p,m|g,((h^p)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(o,e)|0;p=a+b|0;c[p>>2]=l;c[p+4>>2]=F;p=n|8;n=k+p|0;l=c[n>>2]|0;h=c[n+4>>2]|0;n=j+p|0;p=n|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^h;m=ZGb(g|l,n|h,((g^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(b+8)|0;c[p>>2]=m;c[p+4>>2]=F;o=o+1|0;}while((o|0)<8);i=f;return}function Kxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;oza(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;pza(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^o;n=ZGb(h|g,m|o,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=q|8;q=j+g|0;n=q|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^q;m=ZGb(o|h,n|q,((o^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=m;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Lxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;oza(g|0,b+e|0,16,e);qza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=ZGb(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ba(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=F;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=ZGb(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Mxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;oza(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;pza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=ZGb(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ba(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=F;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=ZGb(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Nxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+e|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=b+f|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=f+e|0;e=b+g|0;b=e|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[f+4>>2]=e;return}function Oxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;lza(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=ZGb(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=F;h=b+e|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=ZGb(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=F;n=e<<1;m=b+n|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=ZGb(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=F;l=e*3|0;e=b+l|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=ZGb(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=F;i=f;return}function Pxa(a,b,c){a=a|0;b=b|0;c=c|0;lza(a,b,c,c);return}function Qxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;lza(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=ZGb(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=F;h=b+(e+2)|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=ZGb(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=F;n=e<<1;m=b+(n+2)|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=ZGb(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=F;l=e*3|0;e=b+(l+2)|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=ZGb(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=F;i=f;return}function Rxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;mza(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=p^s;h=ZGb(l|g,p|s,((l^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=h;c[k+4>>2]=F;k=c[o>>2]|0;h=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;l=c[o+4>>2]|0;o=l^h;s=ZGb(g|k,l|h,((g^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+e|0;c[o>>2]=s;c[o+4>>2]=F;o=c[n>>2]|0;s=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;g=c[n+4>>2]|0;n=g^s;h=ZGb(k|o,g|s,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+m|0;c[n>>2]=h;c[n+4>>2]=F;n=c[q>>2]|0;h=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;m=c[q+4>>2]|0;q=m^h;o=ZGb(j|n,m|h,((j^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+(e*3|0)|0;c[q>>2]=o;c[q+4>>2]=F;i=f;return}function Sxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;lza(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;mza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=r^g;q=ZGb(k|n,r|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=q;c[m+4>>2]=F;m=j+8|0;q=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;r=ZGb(k|q,g|n,((k^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=r;c[m+4>>2]=F;m=j+16|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^q;g=ZGb(k|r,n|q,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=r;c[m+4>>2]=F;i=f;return}function Txa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;lza(f,b,8,d);nza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=ZGb(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=F;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=ZGb(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=F;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=ZGb(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=ZGb(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=F;i=e;return}function Uxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;lza(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;mza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=ZGb(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=F;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=F;i=f;return}function Vxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+72|0;g=f|0;h=g|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=g+8|0;h=e-k|0;m=b+h|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=m;m=b;l=m|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=m;m=g+24|0;l=b+e|0;n=l|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=l;l=g+32|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=n;n=g+40|0;l=m+e|0;m=b+(l-k)|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;m=g+48|0;n=l+e|0;l=b+(n-k)|0;o=l|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=l;l=g+56|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[l+4>>2]=n;n=g+64|0;g=b+(h+m)|0;m=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=g;mza(a,j,e);i=f;return}function Wxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;mza(k,o,8);nza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=ZGb(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=F;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=ZGb(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=F;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=ZGb(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=ZGb(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=F;i=f;return}function Xxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+288|0;nza(a,d|0,b,c,c);i=d;return}function Yxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;mza(k,o,8);nza(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=ZGb(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=F;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=ZGb(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=F;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=ZGb(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=F;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=ZGb(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=F;i=f;return}function Zxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;mza(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=s^g;t=ZGb(o|l,s|g,((o^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=t;c[k+4>>2]=F;k=c[n>>2]|0;t=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^t;g=ZGb(l|k,o|t,((l^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=g;c[n+4>>2]=F;n=c[q>>2]|0;g=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;l=c[q+4>>2]|0;q=l^g;t=ZGb(k|n,l|g,((k^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+m|0;c[q>>2]=t;c[q+4>>2]=F;q=c[p>>2]|0;t=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;m=c[p+4>>2]|0;p=m^t;n=ZGb(j|q,m|t,((j^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(e*3|0)|0;c[p>>2]=n;c[p+4>>2]=F;i=f;return}function _xa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;lza(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;mza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=ZGb(k|n,o|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;o=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=o;c[m+4>>2]=F;m=j+16|0;o=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|o,n|r,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+p|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;p=c[m+4>>2]|0;m=p^g;o=ZGb(l|j,p|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=o;c[m+4>>2]=F;i=f;return}function $xa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;lza(f,b+d|0,8,d);nza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=ZGb(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=F;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=ZGb(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=F;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=ZGb(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=ZGb(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=F;i=e;return}function aya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;lza(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;mza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=ZGb(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=F;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=ZGb(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=F;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=ZGb(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=ZGb(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=F;i=f;return}function bya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;return}function cya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;uza(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+e|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function dya(a,b,c){a=a|0;b=b|0;c=c|0;uza(a,b,c,c);return}function eya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;uza(g,b,4,e);h=b+2|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+(e+2)|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function fya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;vza(h,j,4);n=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|n)-((j^n)>>>1&2147450879);n=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|n)-((m^n)>>>1&2147450879);i=f;return}function gya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;uza(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;vza(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function hya(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+120|0;f=e+112|0;g=i;i=i+8|0;uza(f,b,4,d);wza(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function iya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;uza(h,b,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;vza(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function jya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+32|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;vza(a,h,e);i=f;return}function kya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+112|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;vza(j,l,4);wza(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function lya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+112|0;wza(a,d|0,b,c,c);i=d;return}function mya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+112|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=2-m|0;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+2|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+2)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e+e|0;m=b+(p+n)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;vza(j,l,4);wza(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function nya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-k)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;vza(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2147450879);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2147450879);i=f;return}function oya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;l=b+e|0;uza(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;vza(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function pya(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+120|0;f=e+112|0;g=i;i=i+8|0;uza(f,b+d|0,4,d);wza(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function qya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;uza(h,b+e|0,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;vza(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function rya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=c[i+4>>2]|0;l=f;m=l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l^k;o=ZGb(n|j,l|k,((n^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[i>>2]=o;c[i+4>>2]=F;i=g+8|0;o=c[i>>2]|0;m=c[i+4>>2]|0;j=f+8|0;n=j|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j^m;l=ZGb(k|o,j|m,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[i>>2]=l;c[i+4>>2]=F;i=h+1|0;if((i|0)<16){f=f+e|0;g=g+e|0;h=i}else{break}}h=b+16|0;b=a+16|0;a=0;while(1){g=b;f=c[g>>2]|0;i=c[g+4>>2]|0;l=h;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^i;k=ZGb(o|f,l|i,((o^f)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[g>>2]=k;c[g+4>>2]=F;g=b+8|0;k=c[g>>2]|0;n=c[g+4>>2]|0;f=h+8|0;o=f|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f+4|0;f=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f^n;l=ZGb(i|k,f|n,((i^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[g>>2]=l;c[g+4>>2]=F;g=a+1|0;if((g|0)<16){h=h+e|0;b=b+e|0;a=g}else{break}}return}function sya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;oza(g|0,b,32,e);oza(g+16|0,b+16|0,32,e);h=e<<3;oza(g+256|0,b+h|0,32,e);oza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=ZGb(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ba(u,e)|0;l=h+16|0;q=b+l|0;m=q|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=u<<5;s=g+(m|16)|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+l|0;l=c[t>>2]|0;j=c[t+4>>2]|0;p=s^q;k=ZGb(r|o,s|q,((r^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;o=p^j;r=ZGb(k|l,p|j,((k^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;t=h+24|0;h=b+t|0;r=h|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+(m|24)|0;m=r|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r+4|0;r=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+t|0;t=c[m>>2]|0;k=c[m+4>>2]|0;j=r^h;p=ZGb(l|o,r|h,((l^o)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;o=j^k;l=ZGb(p|t,j|k,((p^t)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function tya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;tza(a,b,c,c);tza(a+16|0,b+16|0,c,c);d=c<<3;tza(a+d|0,b+d|0,c,c);e=d+16|0;tza(a+e|0,b+e|0,c,c);return}function uya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;oza(g|0,b,32,e);oza(g+16|0,b+16|0,32,e);h=e<<3;oza(g+256|0,b+h|0,32,e);oza(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=ZGb(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ba(u,e)|0;l=b+(h+18)|0;q=l|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=u<<5;j=g+(q|16)|0;s=j|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=a+(h+16)|0;r=c[s>>2]|0;o=c[s+4>>2]|0;p=j^l;k=ZGb(t|m,j|l,((t^m)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;m=p^o;t=ZGb(k|r,p|o,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[s>>2]=t;c[s+4>>2]=F;s=b+(h+26)|0;t=s|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=g+(q|24)|0;q=t|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=t+4|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=a+(h+24)|0;h=c[q>>2]|0;k=c[q+4>>2]|0;o=t^s;p=ZGb(r|m,t|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;m=o^k;r=ZGb(p|h,o|k,((p^h)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function vya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}pza(j|0,h+64|0,32,32);pza(j+16|0,h+80|0,32,32);pza(j+256|0,h+320|0,32,32);pza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=ZGb(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;m=t^s;n=ZGb(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=F;q=e|8;e=h+(q+64)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=ZGb(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^u;r=ZGb(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+80)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=ZGb(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=F;m=n^e;t=ZGb(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h+((l|8)+80)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=ZGb(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^k;s=ZGb(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function wya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;oza(j|0,e,32,f);oza(j+16|0,e+16|0,32,f);l=f<<3;oza(j+256|0,e+l|0,32,f);oza(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=ZGb(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=ZGb(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^m;t=ZGb(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^e;s=ZGb(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function xya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;oza(h|0,b,32,e);k=b+16|0;oza(h+16|0,k,32,e);l=e<<3;m=b+l|0;oza(h+256|0,m,32,e);n=b+(l+16)|0;oza(h+272|0,n,32,e);l=g|0;qza(j|0,l,b,32,32,e);b=g+32|0;qza(j+16|0,b,k,32,32,e);qza(j+256|0,l,m,32,32,e);qza(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(n,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^m;t=ZGb(o|k,l|m,((o^k)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;k=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=b|8;b=h+p|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=ZGb(q|k,o|b,((q^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;k=r^t;q=ZGb(s|g,r|t,((s^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;p=n+1|0;if((p|0)<16){n=p}else{u=0;break}}do{n=u<<5;p=n|16;q=h+p|0;k=q|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+p|0;p=k|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=k^q;m=ZGb(s|g,k|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;g=o^b;s=ZGb(m|r,o|b,((m^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=F;t=n|24;n=h+t|0;s=n|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;m=c[t+4>>2]|0;b=s^n;o=ZGb(r|g,s|n,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;g=b^m;r=ZGb(o|p,b|m,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function yya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;oza(j|0,e,32,f);oza(j+16|0,e+16|0,32,f);l=f<<3;oza(j+256|0,e+l|0,32,f);oza(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=ZGb(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=ZGb(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^m;t=ZGb(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^e;s=ZGb(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function zya(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;x=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=m+4|0;x=n;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=m+4|0;x=l;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+4|0;x=k;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}sza(b,g+64|0,e,32);sza(b+16|0,g+80|0,e,32);j=e<<3;sza(b+j|0,g+320|0,e,32);sza(b+(j+16)|0,g+336|0,e,32);i=f;return}function Aya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=j|0;qza(l|0,h,e,32,32,f);o=j+32|0;qza(l+16|0,o,e+16|0,32,32,f);j=f<<3;qza(l+256|0,h,e+j|0,32,32,f);qza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=ZGb(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;n=t^q;s=ZGb(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=F;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=ZGb(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=F;n=q^u;r=ZGb(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=F;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=ZGb(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^e;t=ZGb(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=ZGb(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^o;q=ZGb(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function Bya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+2688|0;e=d|0;f=e|0;rza(a,f,b,c,32,c);g=e+32|0;rza(a+16|0,g,b+16|0,c,32,c);e=c<<3;rza(a+e|0,f,b+e|0,c,32,c);f=e+16|0;rza(a+f|0,g,b+f|0,c,32,c);i=d;return}function Cya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=r+4|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r+4|0;x=q;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=r+4|0;x=p;a[s]=x;x=x>>8;a[s+1|0]=x;x=x>>8;a[s+2|0]=x;x=x>>8;a[s+3|0]=x;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=j|0;qza(l|0,h,e,32,32,f);o=j+32|0;qza(l+16|0,o,e+16|0,32,32,f);j=f<<3;qza(l+256|0,h,e+j|0,32,32,f);qza(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ba(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=ZGb(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;n=t^q;s=ZGb(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=F;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=ZGb(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=F;n=q^u;r=ZGb(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=F;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=ZGb(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^e;t=ZGb(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=ZGb(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^o;q=ZGb(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function Dya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=o+4|0;x=p;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;x=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=o+4|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=m;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}pza(j|0,h+64|0,32,32);pza(j+16|0,h+80|0,32,32);pza(j+256|0,h+320|0,32,32);pza(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=ZGb(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;m=t^s;n=ZGb(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=F;q=e|8;e=h+(q+96)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=ZGb(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^u;r=ZGb(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=F;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+112)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=ZGb(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=F;m=n^e;t=ZGb(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h+((l|8)+112)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=ZGb(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=F;m=e^k;s=ZGb(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function Eya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;oza(j|0,e+f|0,32,f);l=f+16|0;oza(j+16|0,e+l|0,32,f);m=f<<3;oza(j+256|0,e+(m+f)|0,32,f);oza(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=ZGb(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=ZGb(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^l;t=ZGb(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=F;n=l^e;s=ZGb(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function Fya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;oza(h|0,b+e|0,32,e);oza(h+16|0,b+(e+16)|0,32,e);k=e<<3;oza(h+256|0,b+(k+e)|0,32,e);l=k+16|0;oza(h+272|0,b+(l+e)|0,32,e);m=g|0;qza(j|0,m,b,32,32,e);n=g+32|0;qza(j+16|0,n,b+16|0,32,32,e);qza(j+256|0,m,b+k|0,32,32,e);qza(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ba(l,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=k^n;t=ZGb(o|m,k|n,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=b|8;b=h+p|0;o=b|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=ZGb(q|m,o|b,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|g,r|t,((s^g)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;p=l+1|0;if((p|0)<16){l=p}else{u=0;break}}do{l=u<<5;p=l|16;q=h+p|0;m=q|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+p|0;p=m|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=m^q;n=ZGb(s|g,m|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;g=o^b;s=ZGb(n|r,o|b,((n^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=F;t=l|24;l=h+t|0;s=l|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+4|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;n=c[t+4>>2]|0;b=s^l;o=ZGb(r|g,s|l,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;g=b^n;r=ZGb(o|p,b|n,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=F;u=u+1|0;}while((u|0)<16);i=f;return}function Gya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;oza(j|0,e+f|0,32,f);l=f+16|0;oza(j+16|0,e+l|0,32,f);m=f<<3;oza(j+256|0,e+(m+f)|0,32,f);oza(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;x=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=p+4|0;x=q;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=p+4|0;x=o;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;x=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=p+4|0;x=n;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}pza(k|0,h+64|0,32,32);pza(k+16|0,h+80|0,32,32);pza(k+256|0,h+320|0,32,32);pza(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=ZGb(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=F;q=t^s;p=ZGb(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=ZGb(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;q=s^u;r=ZGb(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=F;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=ZGb(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;n=p^l;t=ZGb(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=F;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=ZGb(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=F;n=l^e;s=ZGb(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=F;v=v+1|0;}while((v|0)<16);i=g;return}function Hya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;j=f;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j^i;m=ZGb(l|h,j|i,((l^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[g>>2]=m;c[g+4>>2]=F;g=b+8|0;m=c[g>>2]|0;k=c[g+4>>2]|0;h=f+8|0;l=h|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h^k;j=ZGb(i|m,h|k,((i^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[g>>2]=j;c[g+4>>2]=F;g=a+1|0;if((g|0)<8){f=f+e|0;b=b+e|0;a=g}else{break}}return}function Iya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;oza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=ZGb(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function Jya(a,b,c){a=a|0;b=b|0;c=c|0;tza(a,b,c,c);return}function Kya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;oza(g|0,b,16,e);h=0;do{j=ba(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=ZGb(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;p=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=F;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=ZGb(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;h=h+1|0;}while((h|0)<8);i=f;return}function Lya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;pza(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ba(p,e)|0;h=a+o|0;q=c[h>>2]|0;r=c[h+4>>2]|0;s=k^b;t=ZGb(m|g,k|b,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[h>>2]=m;c[h+4>>2]=F;h=n|8;n=l+h|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=j+h|0;h=n|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(o+8)|0;o=c[h>>2]|0;t=c[h+4>>2]|0;r=n^g;s=ZGb(q|m,n|g,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[h>>2]=q;c[h+4>>2]=F;p=p+1|0;}while((p|0)<8);i=f;return}function Mya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;oza(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;pza(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;m=a+b|0;q=c[m>>2]|0;r=c[m+4>>2]|0;s=o^n;t=ZGb(h|g,o|n,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;h=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=p|8;p=j+m|0;h=p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+m|0;m=h|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+(b+8)|0;b=c[m>>2]|0;t=c[m+4>>2]|0;r=h^p;s=ZGb(q|g,h|p,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Nya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;oza(g|0,b,16,e);qza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=ZGb(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=ZGb(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Oya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;oza(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;pza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=ZGb(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=ZGb(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Pya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;sza(a,j,e,16);i=f;return}function Qya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;pza(k|0,m,16,16);qza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ba(b,e)|0;h=a+p|0;n=c[h>>2]|0;r=c[h+4>>2]|0;s=q^m;t=ZGb(g|o,q|m,((g^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;o=s^r;g=ZGb(t|n,s|r,((t^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=g;c[h+4>>2]=F;h=j|8;j=k+h|0;g=j|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+h|0;h=g|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(p+8)|0;p=c[h>>2]|0;t=c[h+4>>2]|0;r=g^j;s=ZGb(n|o,g|j,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;o=r^t;n=ZGb(s|p,r|t,((s^p)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=n;c[h+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Rya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+832|0;rza(a,d|0,b,c,16,c);i=d;return}function Sya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;pza(k|0,m,16,16);qza(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=ba(b,e)|0;n=a+q|0;o=c[n>>2]|0;r=c[n+4>>2]|0;s=h^m;t=ZGb(g|p,h|m,((g^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;p=s^r;g=ZGb(t|o,s|r,((t^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=F;n=j|8;j=k+n|0;g=j|0;p=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+n|0;n=g|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+4|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(q+8)|0;q=c[n>>2]|0;t=c[n+4>>2]|0;r=g^j;s=ZGb(o|p,g|j,((o^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;p=r^t;o=ZGb(s|q,r|t,((s^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=o;c[n+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Tya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;pza(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(o,e)|0;l=a+b|0;q=c[l>>2]|0;r=c[l+4>>2]|0;s=m^g;t=ZGb(h|p,m|g,((h^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;p=s^r;h=ZGb(t|q,s|r,((t^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[l>>2]=h;c[l+4>>2]=F;l=n|8;n=k+l|0;h=c[n>>2]|0;p=c[n+4>>2]|0;n=j+l|0;l=n|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(b+8)|0;b=c[l>>2]|0;t=c[l+4>>2]|0;r=n^p;s=ZGb(q|h,n|p,((q^h)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;h=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=F;o=o+1|0;}while((o|0)<8);i=f;return}function Uya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;oza(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;pza(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;p=c[n>>2]|0;r=c[n+4>>2]|0;s=m^o;t=ZGb(h|g,m|o,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;h=ZGb(t|p,s|r,((t^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=h;c[n+4>>2]=F;n=q|8;q=j+n|0;h=q|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=h^q;s=ZGb(p|g,h|q,((p^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;p=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=p;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Vya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;oza(g|0,b+e|0,16,e);qza(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ba(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=ZGb(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;m=s^r;o=ZGb(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=F;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=ZGb(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;m=r^t;q=ZGb(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=F;b=b+1|0;}while((b|0)<8);i=f;return}function Wya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;oza(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;pza(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ba(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=ZGb(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=F;g=s^r;m=ZGb(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=F;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=ZGb(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^t;q=ZGb(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=F;l=l+1|0;}while((l|0)<8);i=f;return}function Xya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=c[f>>2]|0;h=c[f+4>>2]|0;i=b;j=i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i+4|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i^h;l=ZGb(k|g,i|h,((k^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[f>>2]=l;c[f+4>>2]=F;f=a+e|0;l=c[f>>2]|0;j=c[f+4>>2]|0;g=b+e|0;k=g|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^j;i=ZGb(h|l,g|j,((h^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[f>>2]=i;c[f+4>>2]=F;f=e<<1;i=a+f|0;k=c[i>>2]|0;l=c[i+4>>2]|0;h=b+f|0;j=h|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h^l;m=ZGb(g|k,h|l,((g^k)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[i>>2]=m;c[i+4>>2]=F;i=f+e|0;e=a+i|0;a=c[e>>2]|0;f=c[e+4>>2]|0;m=b+i|0;i=m|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m^f;j=ZGb(b|a,m|f,((b^a)>>>1|i<<31)&2147450879,(i>>>1|0<<31)&2147450879)|0;c[e>>2]=j;c[e+4>>2]=F;return}function Yya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;lza(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=ZGb(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;l=p^o;k=ZGb(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=F;h=b+e|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=ZGb(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^p;n=ZGb(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=F;k=e<<1;n=b+k|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=ZGb(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;o=h^j;m=ZGb(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=F;l=e*3|0;e=b+l|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=ZGb(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;m=k^a;g=ZGb(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=F;i=f;return}function Zya(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d>>1;d=0;g=a;a=c;while(1){c=a+2|0;h=a-2|0;i=a+4|0;j=a+6|0;k=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[i>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<16384>>>0){l=k}else{l=-k>>31&16383}b[g>>1]=((e[g>>1]|0)+1+l|0)>>>1;k=g+2|0;m=a+8|0;n=(((e[i>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[h>>1]|0)+(((e[j>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[m>>1]|0)>>5;if(n>>>0<16384>>>0){o=n}else{o=-n>>31&16383}b[k>>1]=((e[k>>1]|0)+1+o|0)>>>1;k=g+4|0;n=a+10|0;h=(((e[j>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[m>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(h>>>0<16384>>>0){p=h}else{p=-h>>31&16383}b[k>>1]=((e[k>>1]|0)+1+p|0)>>>1;k=g+6|0;h=(((e[m>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(h>>>0<16384>>>0){q=h}else{q=-h>>31&16383}b[k>>1]=((e[k>>1]|0)+1+q|0)>>>1;k=d+1|0;if((k|0)<4){d=k;g=g+(f<<1)|0;a=a+(f<<1)|0}else{break}}return}function _ya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;lza(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=ZGb(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=F;l=p^o;k=ZGb(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=F;h=b+(e+2)|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=ZGb(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=F;l=j^p;n=ZGb(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=F;k=e<<1;n=b+(k+2)|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=ZGb(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=F;o=h^j;m=ZGb(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=F;l=e*3|0;e=b+(l+2)|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=ZGb(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;m=k^a;g=ZGb(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=F;i=f;return}function $ya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;mza(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=a;h=c[k>>2]|0;b=c[k+4>>2]|0;r=p^s;t=ZGb(l|g,p|s,((l^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;g=r^b;l=ZGb(t|h,r|b,((t^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[k>>2]=l;c[k+4>>2]=F;k=c[o>>2]|0;l=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;h=c[o+4>>2]|0;o=a+e|0;t=c[o>>2]|0;b=c[o+4>>2]|0;r=h^l;s=ZGb(g|k,h|l,((g^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=F;k=r^b;g=ZGb(s|t,r|b,((s^t)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[o>>2]=g;c[o+4>>2]=F;o=c[n>>2]|0;g=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=a+m|0;m=c[n>>2]|0;s=c[n+4>>2]|0;b=t^g;r=ZGb(k|o,t|g,((k^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;o=b^s;k=ZGb(r|m,b|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[n>>2]=k;c[n+4>>2]=F;n=c[q>>2]|0;k=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;o=c[q+4>>2]|0;q=a+(e*3|0)|0;e=c[q>>2]|0;a=c[q+4>>2]|0;m=o^k;r=ZGb(j|n,o|k,((j^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=F;n=m^a;j=ZGb(r|e,m|a,((r^e)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=j;c[q+4>>2]=F;i=f;return}function aza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;lza(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;mza(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=a;q=c[m>>2]|0;h=c[m+4>>2]|0;b=r^g;p=ZGb(k|n,r|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;n=b^h;k=ZGb(p|q,b|h,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=F;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;q=c[m>>2]|0;p=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=p^n;r=ZGb(q|k,p|n,((q^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;k=g^b;q=ZGb(r|h,g|b,((r^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=F;m=j+16|0;q=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;r=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=r^k;n=ZGb(h|q,r|k,((h^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=F;q=g^b;h=ZGb(n|o,g|b,((n^o)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=F;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;q=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=q^h;n=ZGb(l|j,q|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;j=o^a;l=ZGb(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=F;i=f;return}function bza(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;lza(f,b,8,d);nza(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=ZGb(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;b=o^n;g=ZGb(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=F;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=ZGb(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=F;g=k^o;m=ZGb(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=F;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=ZGb(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=F;m=b^k;n=ZGb(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=F;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=ZGb(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=F;f=o^a;h=ZGb(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=F;i=e;return}



function Zca(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0;g=i;i=i+32|0;h=g|0;j=g+8|0;k=g+16|0;l=f+427376|0;m=c[l>>2]|0;n=f+427380|0;o=c[n>>2]|0;p=f+427412|0;q=c[p>>2]|0;r=f+4064|0;s=c[(c[r>>2]|0)+(q<<2)>>2]|0;t=f+4792|0;if((c[t>>2]|0)==0){u=(c[f+6140>>2]|0)!=0|0}else{u=0}v=f+4752|0;w=f+4776|0;x=f+8|0;y=c[f+2528>>2]|0;z=c[v>>2]|0;A=c[w>>2]|0;B=(ba(A,o)|0)+(m<<z)<<4;C=y+B|0;D=k|0;c[D>>2]=C;E=y+((ba(m<<2&12,A)|0)+B+(64<<z))|0;Xe[c[x>>2]&4095](E,A,4);A=c[f+2532>>2]|0;E=c[v>>2]|0;z=c[w>>2]|0;G=(ba(z,o)|0)+(m<<E)<<4;H=A+G|0;I=k+4|0;c[I>>2]=H;J=A+((ba(c[l>>2]<<2&12,z)|0)+G+(64<<E))|0;Xe[c[x>>2]&4095](J,z,4);z=c[f+2536>>2]|0;J=c[v>>2]|0;E=c[w>>2]|0;K=(ba(E,o)|0)+(m<<J)<<4;m=z+K|0;L=k+8|0;c[L>>2]=m;M=z+((ba(c[l>>2]<<2&12,E)|0)+K+(64<<J))|0;Xe[c[x>>2]&4095](M,E,4);E=f+199428|0;a[(c[f+199432>>2]|0)+q|0]=c[E>>2];q=f+177092|0;M=c[w>>2]|0;do{if((c[q>>2]|0)==0){c[f+6116>>2]=M;c[f+6112>>2]=M;N=M;O=f+5716|0;P=m;Q=C;R=H}else{J=M<<1;c[f+6116>>2]=J;c[f+6112>>2]=J;S=f+5908|0;if((o&1|0)==0){T=m;U=C;V=H}else{W=M*-15|0;X=y+(B+W)|0;c[D>>2]=X;Y=A+(G+W)|0;c[I>>2]=Y;Z=z+(K+W)|0;c[L>>2]=Z;T=Z;U=X;V=Y}if((c[f+177088>>2]|0)==0){N=J;O=S;P=T;Q=U;R=V;break}if((c[E>>2]|0)==0){N=J;O=S;P=T;Q=U;R=V;break}Y=(s&8|0)==0;X=0;while(1){do{if((12288<<(X<<1)&s|0)!=0){Z=f+5632+(X*40|0)+12|0;W=a[Z]|0;if(!Y){_=ba((W<<24>>24)+16^c[n>>2]&1,16843009)|0;c[Z>>2]=_;c[f+5632+(X*40|0)+20>>2]=_;c[f+5632+(X*40|0)+28>>2]=_;c[f+5632+(X*40|0)+36>>2]=_;break}if(W<<24>>24>-1){_=((c[n>>2]&1^(W<<24>>24)+16)*257|0)&65535;b[Z>>1]=_;b[f+5632+(X*40|0)+20>>1]=_}_=f+5632+(X*40|0)+14|0;Z=a[_]|0;if(Z<<24>>24>-1){W=((c[n>>2]&1^(Z<<24>>24)+16)*257|0)&65535;b[_>>1]=W;b[f+5632+(X*40|0)+22>>1]=W}W=f+5632+(X*40|0)+28|0;_=a[W]|0;if(_<<24>>24>-1){Z=((c[n>>2]&1^(_<<24>>24)+16)*257|0)&65535;b[W>>1]=Z;b[f+5632+(X*40|0)+36>>1]=Z}Z=f+5632+(X*40|0)+30|0;W=a[Z]|0;if(!(W<<24>>24>-1)){break}_=((c[n>>2]&1^(W<<24>>24)+16)*257|0)&65535;b[Z>>1]=_;b[f+5632+(X*40|0)+38>>1]=_}}while(0);_=X+1|0;if(_>>>0<(c[E>>2]|0)>>>0){X=_}else{N=J;O=S;P=T;Q=U;R=V;break}}}}while(0);if((s&4|0)!=0){if((c[v>>2]|0)==0){V=f+421184|0;U=0;while(1){T=Q+(ba(U,N)|0)|0;UGb(T|0,(c[V>>2]|0)+(U<<4)|0,16)|0;T=U+1|0;if((T|0)<16){U=T}else{$=0;break}}while(1){U=R+(ba($,N)|0)|0;UGb(U|0,(c[V>>2]|0)+(($<<4)+256)|0,16)|0;U=$+1|0;if((U|0)<16){$=U}else{aa=0;break}}do{$=P+(ba(aa,N)|0)|0;UGb($|0,(c[V>>2]|0)+((aa<<4)+512)|0,16)|0;aa=aa+1|0;}while((aa|0)<16);i=g;return}aa=c[f+7308>>2]|0;V=c[f+421184>>2]|0;$=(aa*768|0)>>>0>2147483639>>>0|(V|0)==0?0:V;V=32-aa|0;U=aa<<4;T=aa<<8;E=0;L=0;while(1){K=Q+(ba(L,N)|0)|0;z=E;I=0;while(1){G=$+(z>>>3)|0;b[K+(I<<1)>>1]=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(z&7)>>>(V>>>0);G=I+1|0;if((G|0)<16){z=z+aa|0;I=G}else{break}}I=L+1|0;if((I|0)<16){E=U+E|0;L=I}else{ca=T;da=0;break}}while(1){T=R+(ba(da,N)|0)|0;L=ca;E=0;while(1){I=$+(L>>>3)|0;b[T+(E<<1)>>1]=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>(V>>>0);I=E+1|0;if((I|0)<16){L=L+aa|0;E=I}else{break}}E=da+1|0;if((E|0)<16){ca=U+ca|0;da=E}else{break}}da=aa<<9;ca=0;while(1){E=P+(ba(ca,N)|0)|0;L=da;T=0;while(1){I=$+(L>>>3)|0;b[E+(T<<1)>>1]=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>(V>>>0);I=T+1|0;if((I|0)<16){L=L+aa|0;T=I}else{break}}T=ca+1|0;if((T|0)<16){da=U+da|0;ca=T}else{break}}i=g;return}a:do{if((s&7|0)==0){ca=c[f+1028>>2]|0;da=f+148|0;U=c[f+1032>>2]|0;aa=f+164|0;V=f+12|0;$=f+28|0;T=c[(c[r>>2]|0)+(c[p>>2]<<2)>>2]|0;L=c[v>>2]|0;E=a[f+5644|0]|0;if(E<<24>>24>-1){I=E<<24>>24;E=c[l>>2]|0;z=((E<<4|8)+(b[f+5360>>1]>>2)<<L)+(64<<L)+(ba((c[n>>2]<<4|E<<2&12)+(b[f+5362>>1]>>2)|0,N)|0)|0;Xe[c[x>>2]&4095]((c[f+199440+(I*2224|0)>>2]|0)+z|0,M,4);Xe[c[x>>2]&4095]((c[f+199440+(I*2224|0)+4>>2]|0)+z|0,c[w>>2]|0,4);Xe[c[x>>2]&4095]((c[f+199440+(I*2224|0)+8>>2]|0)+z|0,c[w>>2]|0,4)}do{if((T&8|0)==0){if((T&16|0)!=0){z=ca+64|0;I=U+64|0;Dda(f,0,0,8,8<<c[v>>2],Q,R,P,0,0,z,c[da>>2]|0,I,c[aa>>2]|0,V,$,T&4096,T&16384);Dda(f,8,0,8,8<<c[v>>2],Q,R,P,0,4,z,c[da>>2]|0,I,c[aa>>2]|0,V,$,T&8192,T&32768);break}I=f+6112|0;if((T&32|0)!=0){z=ca+64|0;E=f+152|0;L=U+64|0;K=f+168|0;G=f+16|0;A=f+32|0;Dda(f,0,0,16,c[I>>2]<<3,Q,R,P,0,0,z,c[E>>2]|0,L,c[K>>2]|0,G,A,T&4096,T&16384);Dda(f,4,0,16,c[I>>2]<<3,Q,R,P,4,0,z,c[E>>2]|0,L,c[K>>2]|0,G,A,T&8192,T&32768);break}A=ca+128|0;G=f+156|0;K=U+128|0;L=f+172|0;E=f+20|0;z=f+36|0;D=f+152|0;B=f+168|0;y=f+16|0;H=f+32|0;C=ca+64|0;m=U+64|0;o=0;do{S=e[f+177112+(o<<1)>>1]|0;J=o<<2;X=J&4;Y=o<<1&4;do{if((S&8|0)==0){if((S&16|0)!=0){_=S&4096;Z=S&16384;Dda(f,J,0,4,4<<c[v>>2],Q,R,P,X,Y,A,c[D>>2]|0,K,c[B>>2]|0,y,H,_,Z);Dda(f,J|2,0,4,4<<c[v>>2],Q,R,P,X,Y|2,A,c[D>>2]|0,K,c[B>>2]|0,y,H,_,Z);break}if((S&32|0)==0){Z=S&4096;_=S&16384;Dda(f,J,1,4,0,Q,R,P,X,Y,A,c[G>>2]|0,K,c[L>>2]|0,E,z,Z,_);W=X|2;Dda(f,J|1,1,4,0,Q,R,P,W,Y,A,c[G>>2]|0,K,c[L>>2]|0,E,z,Z,_);ea=Y|2;Dda(f,J|2,1,4,0,Q,R,P,X,ea,A,c[G>>2]|0,K,c[L>>2]|0,E,z,Z,_);Dda(f,J|3,1,4,0,Q,R,P,W,ea,A,c[G>>2]|0,K,c[L>>2]|0,E,z,Z,_);break}else{_=S&4096;Z=S&16384;Dda(f,J,0,8,c[I>>2]<<2,Q,R,P,X,Y,A,c[G>>2]|0,K,c[L>>2]|0,E,z,_,Z);Dda(f,J|1,0,8,c[I>>2]<<2,Q,R,P,X|2,Y,A,c[G>>2]|0,K,c[L>>2]|0,E,z,_,Z);break}}else{Dda(f,J,1,8,0,Q,R,P,X,Y,C,c[D>>2]|0,m,c[B>>2]|0,y,H,S&4096,S&16384)}}while(0);o=o+1|0;}while((o|0)<4)}else{Dda(f,0,1,16,0,Q,R,P,0,0,ca|0,c[da>>2]|0,U|0,c[aa>>2]|0,V,$,T&4096,T&16384)}}while(0);T=c[v>>2]|0;$=a[f+5684|0]|0;if(!($<<24>>24>-1)){break}V=$<<24>>24;$=c[l>>2]|0;aa=(($<<4|8)+(b[f+5520>>1]>>2)<<T)+(64<<T)+(ba((c[n>>2]<<4|$<<2&12)+(b[f+5522>>1]>>2)|0,c[f+6112>>2]|0)|0)|0;Xe[c[x>>2]&4095]((c[f+306192+(V*2224|0)>>2]|0)+aa|0,c[w>>2]|0,4);Xe[c[x>>2]&4095]((c[f+306192+(V*2224|0)+4>>2]|0)+aa|0,c[w>>2]|0,4);Xe[c[x>>2]&4095]((c[f+306192+(V*2224|0)+8>>2]|0)+aa|0,c[w>>2]|0,4)}else{aa=f+427420|0;V=c[aa>>2]|0;b:do{if((V|0)!=0){$=c[v>>2]|0;do{if((c[f+177088>>2]|0)==0){fa=1}else{T=(c[f+177096>>2]|0)!=0;if((c[n>>2]&1|0)==0){fa=T&1^1;break}else{if(T){fa=1;break}else{break b}}}}while(0);if((V|0)==2){ga=(e[(c[f+177072>>2]|0)+((c[p>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);ha=c[f+4864>>2]|0;ia=c[l>>2]|0}else{T=c[l>>2]|0;ga=(T|0)>0;ha=(c[n>>2]|0)>((c[q>>2]|0)!=0|0)|0;ia=T}T=N+1+$|0;U=ia-1|0;da=f+5176+(fa<<2)|0;ca=c[da>>2]|0;o=ca+(ia*96|0)|0;if((ha|0)==0){break}do{if(ga){H=8<<$;y=ca+(U*96|0)+H|0;B=c[y>>2]|0;m=c[y+4>>2]|0;D=(-7<<$)-T|0;C=Q+D|0;z=c[C+4>>2]|0;c[y>>2]=c[C>>2];c[y+4>>2]=z;c[C>>2]=B;c[C+4>>2]=m;if(($|0)==0){m=o;ja=Q+(1-T)|0;ka=1;la=c[m+4>>2]|0;ma=c[m>>2]|0;na=m;oa=41;break}else{m=H+8+(ca+(U*96|0))|0;H=c[m>>2]|0;C=c[m+4>>2]|0;B=Q+(D+8)|0;D=c[B+4>>2]|0;c[m>>2]=c[B>>2];c[m+4>>2]=D;c[B>>2]=H;c[B+4>>2]=C;oa=39;break}}else{oa=39}}while(0);do{if((oa|0)==39){C=o;B=c[C>>2]|0;H=c[C+4>>2]|0;D=1<<$;m=D-T|0;z=Q+m|0;if(($|0)==0){ja=z;ka=D;la=H;ma=B;na=C;oa=41;break}y=c[z+4>>2]|0;c[C>>2]=c[z>>2];c[C+4>>2]=y;c[z>>2]=B;c[z+4>>2]=H;H=ca+(ia*96|0)+8|0;z=c[H>>2]|0;B=c[H+4>>2]|0;y=Q+(m+8)|0;m=c[y+4>>2]|0;c[H>>2]=c[y>>2];c[H+4>>2]=m;c[y>>2]=z;c[y+4>>2]=B;pa=1;qa=D}}while(0);if((oa|0)==41){o=c[ja+4>>2]|0;c[na>>2]=c[ja>>2];c[na+4>>2]=o;c[ja>>2]=ma;c[ja+4>>2]=la;pa=0;qa=ka}o=8<<$;D=ca+(ia*96|0)+o|0;B=c[D>>2]|0;y=c[D+4>>2]|0;z=(9<<$)-T|0;m=Q+z|0;H=c[m+4>>2]|0;c[D>>2]=c[m>>2];c[D+4>>2]=H;c[m>>2]=B;c[m+4>>2]=y;if(pa){y=o+8+(ca+(ia*96|0))|0;o=c[y>>2]|0;m=c[y+4>>2]|0;B=Q+(z+8)|0;H=c[B+4>>2]|0;c[y>>2]=c[B>>2];c[y+4>>2]=H;c[B>>2]=o;c[B+4>>2]=m}m=(c[l>>2]|0)+1|0;B=f+427400|0;do{if((m|0)<(c[B>>2]|0)){o=(c[da>>2]|0)+(m*96|0)|0;H=c[o>>2]|0;y=c[o+4>>2]|0;D=(17<<$)-T|0;C=Q+D|0;E=c[C+4>>2]|0;c[o>>2]=c[C>>2];c[o+4>>2]=E;c[C>>2]=H;c[C+4>>2]=y;if(!pa){break}y=(c[da>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+8|0;C=c[y>>2]|0;H=c[y+4>>2]|0;E=Q+(D+8)|0;D=c[E+4>>2]|0;c[y>>2]=c[E>>2];c[y+4>>2]=D;c[E>>2]=C;c[E+4>>2]=H}}while(0);do{if(ga){m=24<<$;H=ca+(U*96|0)+m|0;E=c[H>>2]|0;C=c[H+4>>2]|0;D=(-7<<$)-T|0;y=R+D|0;o=c[y+4>>2]|0;c[H>>2]=c[y>>2];c[H+4>>2]=o;c[y>>2]=E;c[y+4>>2]=C;if(pa){C=m+8+(ca+(U*96|0))|0;m=c[C>>2]|0;y=c[C+4>>2]|0;E=R+(D+8)|0;o=c[E+4>>2]|0;c[C>>2]=c[E>>2];c[C+4>>2]=o;c[E>>2]=m;c[E+4>>2]=y}y=40<<$;E=ca+(U*96|0)+y|0;m=c[E>>2]|0;o=c[E+4>>2]|0;C=P+D|0;H=c[C+4>>2]|0;c[E>>2]=c[C>>2];c[E+4>>2]=H;c[C>>2]=m;c[C+4>>2]=o;if(pa){o=y+8+(ca+(U*96|0))|0;y=c[o>>2]|0;C=c[o+4>>2]|0;m=P+(D+8)|0;D=c[m+4>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=D;c[m>>2]=y;c[m+4>>2]=C;C=16<<$;m=ca+(ia*96|0)+C|0;y=qa-T|0;ra=C;sa=m;ta=c[m+4>>2]|0;ua=c[m>>2]|0;va=y;wa=R+y|0;oa=54;break}else{y=16<<$;m=ca+(ia*96|0)+y|0;C=qa-T|0;xa=y;ya=m;za=c[m+4>>2]|0;Aa=c[m>>2]|0;Ba=C;Ca=R+C|0;oa=55;break}}else{C=16<<$;m=ca+(ia*96|0)+C|0;y=c[m>>2]|0;D=c[m+4>>2]|0;o=qa-T|0;H=R+o|0;if(pa){ra=C;sa=m;ta=D;ua=y;va=o;wa=H;oa=54}else{xa=C;ya=m;za=D;Aa=y;Ba=o;Ca=H;oa=55}}}while(0);if((oa|0)==54){U=c[wa+4>>2]|0;c[sa>>2]=c[wa>>2];c[sa+4>>2]=U;c[wa>>2]=ua;c[wa+4>>2]=ta;U=ra+8+(ca+(ia*96|0))|0;H=c[U>>2]|0;o=c[U+4>>2]|0;y=R+(va+8)|0;D=c[y+4>>2]|0;c[U>>2]=c[y>>2];c[U+4>>2]=D;c[y>>2]=H;c[y+4>>2]=o;Da=1;Ea=ra;Fa=va}else if((oa|0)==55){o=c[Ca+4>>2]|0;c[ya>>2]=c[Ca>>2];c[ya+4>>2]=o;c[Ca>>2]=Aa;c[Ca+4>>2]=za;Da=0;Ea=xa;Fa=Ba}o=24<<$;y=ca+(ia*96|0)+o|0;H=c[y>>2]|0;D=c[y+4>>2]|0;U=R+z|0;m=c[U+4>>2]|0;c[y>>2]=c[U>>2];c[y+4>>2]=m;c[U>>2]=H;c[U+4>>2]=D;if(Da){D=o+8+(ca+(ia*96|0))|0;o=c[D>>2]|0;U=c[D+4>>2]|0;H=R+(z+8)|0;m=c[H+4>>2]|0;c[D>>2]=c[H>>2];c[D+4>>2]=m;c[H>>2]=o;c[H+4>>2]=U;U=32<<$;H=ca+(ia*96|0)+U|0;o=c[H>>2]|0;m=c[H+4>>2]|0;D=P+Fa|0;y=c[D+4>>2]|0;c[H>>2]=c[D>>2];c[H+4>>2]=y;c[D>>2]=o;c[D+4>>2]=m;m=U+8+(ca+(ia*96|0))|0;D=c[m>>2]|0;o=c[m+4>>2]|0;y=P+(Fa+8)|0;H=c[y+4>>2]|0;c[m>>2]=c[y>>2];c[m+4>>2]=H;c[y>>2]=D;c[y+4>>2]=o;Ga=U}else{U=32<<$;o=ca+(ia*96|0)+U|0;y=c[o>>2]|0;D=c[o+4>>2]|0;H=P+Fa|0;m=c[H+4>>2]|0;c[o>>2]=c[H>>2];c[o+4>>2]=m;c[H>>2]=y;c[H+4>>2]=D;Ga=U}U=40<<$;D=ca+(ia*96|0)+U|0;H=c[D>>2]|0;y=c[D+4>>2]|0;m=P+z|0;o=c[m+4>>2]|0;c[D>>2]=c[m>>2];c[D+4>>2]=o;c[m>>2]=H;c[m+4>>2]=y;if(Da){y=U+8+(ca+(ia*96|0))|0;U=c[y>>2]|0;m=c[y+4>>2]|0;H=P+(z+8)|0;o=c[H+4>>2]|0;c[y>>2]=c[H>>2];c[y+4>>2]=o;c[H>>2]=U;c[H+4>>2]=m}m=(c[l>>2]|0)+1|0;if((m|0)>=(c[B>>2]|0)){break}H=(c[da>>2]|0)+(m*96|0)+Ea|0;m=c[H>>2]|0;U=c[H+4>>2]|0;o=(17<<$)-T|0;y=R+o|0;D=c[y+4>>2]|0;c[H>>2]=c[y>>2];c[H+4>>2]=D;c[y>>2]=m;c[y+4>>2]=U;if(Da){U=Ea+8+((c[da>>2]|0)+(((c[l>>2]|0)+1|0)*96|0))|0;y=c[U>>2]|0;m=c[U+4>>2]|0;D=R+(o+8)|0;H=c[D+4>>2]|0;c[U>>2]=c[D>>2];c[U+4>>2]=H;c[D>>2]=y;c[D+4>>2]=m;Ha=1}else{Ha=0}m=(c[da>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+Ga|0;D=c[m>>2]|0;y=c[m+4>>2]|0;H=P+o|0;U=c[H+4>>2]|0;c[m>>2]=c[H>>2];c[m+4>>2]=U;c[H>>2]=D;c[H+4>>2]=y;if(!Ha){break}y=Ga+8+((c[da>>2]|0)+(((c[l>>2]|0)+1|0)*96|0))|0;H=c[y>>2]|0;D=c[y+4>>2]|0;U=P+(o+8)|0;o=c[U+4>>2]|0;c[y>>2]=c[U>>2];c[y+4>>2]=o;c[U>>2]=H;c[U+4>>2]=D}}while(0);V=h;D=j;U=(s&1|0)==0;H=f+4836|0;o=(u|0)==0;y=f+128|0;m=(s&16777216|0)==0;C=(u|0)!=0;E=f+140|0;L=f+6128|0;K=f+421200|0;G=f+5168|0;A=3-N|0;I=3-((N|0)/2|0)|0;S=f+104|0;Y=f+96|0;X=f+136|0;J=f+5160|0;Z=f+108|0;_=f+100|0;ea=0;do{W=c[v>>2]|0;Ia=c[k+(ea<<2)>>2]|0;if((ea|0)==0){Ja=t}else{Ja=f+4756+(ea-1<<2)|0}Ka=c[Ja>>2]|0;La=ea<<4;c:do{if(U){ne[c[f+5084+(c[H>>2]<<2)>>2]&1023](Ia,N);if((a[(d[ea+473472|0]|0)+(f+5184)|0]|0)==0){break}if(o){Xe[c[y>>2]&4095](f+421200+(ea<<8<<W<<1)|0,f+424272+(ea<<6)|0,c[(c[f+177020+(ea<<2)>>2]|0)+(Ka<<6)>>2]|0);break}Ma=ea<<8<<W;Na=(W|0)==0;Oa=f+424272+(ea<<6)|0;Pa=f+421200+(Ma<<1)|0;Qa=0;do{Ra=d[931704+Qa|0]|0;if(Na){b[f+421200+(Ra+Ma<<1)>>1]=b[f+424272+(ea<<6)+(Qa<<1)>>1]|0}else{c[Pa+(Ra<<2)>>2]=c[Oa+(Qa<<2)>>2]}Qa=Qa+1|0;}while((Qa|0)<16)}else{if(!m){if(C){Qa=c[X>>2]|0;Sa=Qa;Ta=Qa}else{Sa=c[_>>2]|0;Ta=c[Z>>2]|0}Qa=ea<<8;Oa=(W|0)==0;Pa=0;while(1){Ma=Pa+La|0;Na=Ia+(c[O+(Ma<<2)>>2]|0)|0;Ra=a[(d[473424+Pa|0]|0)+(f+4888)|0]|0;Ua=Ra<<24>>24;do{if(C){if(!((c[L>>2]|0)==244&Ra<<24>>24<2)){oa=78;break}Xe[c[f+5128+(Ua<<2)>>2]&4095](Na,f+421200+((Pa<<4)+Qa<<W<<1)|0,N)}else{oa=78}}while(0);d:do{if((oa|0)==78){oa=0;Ra=a[(d[473424+Ma|0]|0)+(f+5184)|0]|0;cf[c[f+4992+(Ua<<2)>>2]&1023](Na,c[J>>2]<<Pa&32768,c[G>>2]<<Pa&16384,N);do{if((Ra<<24>>24|0)==0){break d}else if((Ra<<24>>24|0)==1){Va=(Pa<<4)+Qa|0;if(Oa){Wa=e[f+421200+(Va<<1)>>1]|0}else{Wa=c[K+(Va<<2)>>2]|0}if((Wa|0)==0){Xa=Va;break}Xe[Ta&4095](Na,f+421200+(Va<<W<<1)|0,N);break d}else{Xa=(Pa<<4)+Qa|0}}while(0);Xe[Sa&4095](Na,f+421200+(Xa<<W<<1)|0,N)}}while(0);Pa=Pa+4|0;if((Pa|0)>=16){break c}}}if(C){Pa=c[E>>2]|0;Ya=Pa;Za=Pa}else{Ya=c[Y>>2]|0;Za=c[S>>2]|0}Pa=ea<<8;Qa=(W|0)==0;Oa=(4<<W)-N|0;Na=0;do{Ua=Na+La|0;Ma=c[O+(Ua<<2)>>2]|0;Ra=Ia+Ma|0;Va=a[(d[473424+Na|0]|0)+(f+4888)|0]|0;_a=Va<<24>>24;do{if(C){if(!((c[L>>2]|0)==244&Va<<24>>24<2)){oa=94;break}Xe[c[f+5120+(_a<<2)>>2]&4095](Ra,f+421200+((Na<<4)+Pa<<W<<1)|0,N)}else{oa=94}}while(0);e:do{if((oa|0)==94){oa=0;do{if((Va<<24>>24|0)==7|(Va<<24>>24|0)==3){if((c[G>>2]&32768>>>(Na>>>0)|0)!=0){$a=Ia+(Oa+Ma)|0;break}if(Qa){c[h>>2]=ba(d[Ia+(A+Ma)|0]|0,16843009)|0;$a=V;break}else{ab=gHb(e[Ra+(I<<1)>>1]|0,0,65537,65537)|0;c[j>>2]=ab;c[j+4>>2]=F;$a=D;break}}else{$a=0}}while(0);Xe[c[f+4932+(_a<<2)>>2]&4095](Ra,$a,N);ab=a[(d[473424+Ua|0]|0)+(f+5184)|0]|0;if(ab<<24>>24==0){break}bb=(Na<<4)+Pa|0;do{if(ab<<24>>24==1){if(Qa){cb=e[f+421200+(bb<<1)>>1]|0}else{cb=c[K+(bb<<2)>>2]|0}if((cb|0)==0){break}Xe[Za&4095](Ra,f+421200+(bb<<W<<1)|0,N);break e}}while(0);Xe[Ya&4095](Ra,f+421200+(bb<<W<<1)|0,N)}}while(0);Na=Na+1|0;}while((Na|0)<16)}}while(0);ea=ea+1|0;}while((ea|0)<3);ea=c[aa>>2]|0;if((ea|0)==0){break}K=c[v>>2]|0;do{if((c[f+177088>>2]|0)==0){db=1}else{D=(c[f+177096>>2]|0)!=0;if((c[n>>2]&1|0)==0){db=D&1^1;break}else{if(D){db=1;break}else{break a}}}}while(0);if((ea|0)==2){eb=(e[(c[f+177072>>2]|0)+((c[p>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);fb=c[f+4864>>2]|0;gb=c[l>>2]|0}else{aa=c[l>>2]|0;eb=(aa|0)>0;fb=(c[n>>2]|0)>((c[q>>2]|0)!=0|0)|0;gb=aa}aa=N+1+K|0;D=gb-1|0;I=f+5176+(db<<2)|0;V=c[I>>2]|0;A=V+(gb*96|0)|0;if((fb|0)==0){break}do{if(eb){G=8<<K;L=V+(D*96|0)+G|0;C=c[L>>2]|0;S=c[L+4>>2]|0;Y=(-7<<K)-aa|0;E=Q+Y|0;J=c[E+4>>2]|0;c[L>>2]=c[E>>2];c[L+4>>2]=J;c[E>>2]=C;c[E+4>>2]=S;if((K|0)==0){S=A;hb=Q+(1-aa)|0;ib=1;jb=c[S+4>>2]|0;kb=c[S>>2]|0;oa=133;break}else{S=G+8+(V+(D*96|0))|0;G=c[S>>2]|0;E=c[S+4>>2]|0;C=Q+(Y+8)|0;Y=c[C+4>>2]|0;c[S>>2]=c[C>>2];c[S+4>>2]=Y;c[C>>2]=G;c[C+4>>2]=E;oa=131;break}}else{oa=131}}while(0);do{if((oa|0)==131){ea=A;E=c[ea>>2]|0;C=c[ea+4>>2]|0;ea=1<<K;G=ea-aa|0;Y=Q+G|0;if((K|0)==0){hb=Y;ib=ea;jb=C;kb=E;oa=133;break}c[Y>>2]=E;c[Y+4>>2]=C;C=V+(gb*96|0)+8|0;Y=c[C+4>>2]|0;E=Q+(G+8)|0;c[E>>2]=c[C>>2];c[E+4>>2]=Y;lb=1;mb=ea}}while(0);if((oa|0)==133){c[hb>>2]=kb;c[hb+4>>2]=jb;lb=0;mb=ib}A=8<<K;ea=V+(gb*96|0)+A|0;Y=c[ea>>2]|0;E=c[ea+4>>2]|0;C=(9<<K)-aa|0;G=Q+C|0;S=c[G+4>>2]|0;c[ea>>2]=c[G>>2];c[ea+4>>2]=S;c[G>>2]=Y;c[G+4>>2]=E;if(lb){E=A+8+(V+(gb*96|0))|0;A=c[E>>2]|0;G=c[E+4>>2]|0;Y=Q+(C+8)|0;S=c[Y+4>>2]|0;c[E>>2]=c[Y>>2];c[E+4>>2]=S;c[Y>>2]=A;c[Y+4>>2]=G}G=(c[l>>2]|0)+1|0;Y=f+427400|0;do{if((G|0)<(c[Y>>2]|0)){A=(c[I>>2]|0)+(G*96|0)|0;S=c[A>>2]|0;E=c[A+4>>2]|0;ea=(17<<K)-aa|0;J=Q+ea|0;L=c[J+4>>2]|0;c[A>>2]=c[J>>2];c[A+4>>2]=L;c[J>>2]=S;c[J+4>>2]=E;if(!lb){break}E=(c[I>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+8|0;J=c[E>>2]|0;S=c[E+4>>2]|0;L=Q+(ea+8)|0;ea=c[L+4>>2]|0;c[E>>2]=c[L>>2];c[E+4>>2]=ea;c[L>>2]=J;c[L+4>>2]=S}}while(0);do{if(eb){G=24<<K;S=V+(D*96|0)+G|0;L=c[S>>2]|0;J=c[S+4>>2]|0;ea=(-7<<K)-aa|0;E=R+ea|0;A=c[E+4>>2]|0;c[S>>2]=c[E>>2];c[S+4>>2]=A;c[E>>2]=L;c[E+4>>2]=J;if(lb){J=G+8+(V+(D*96|0))|0;G=c[J>>2]|0;E=c[J+4>>2]|0;L=R+(ea+8)|0;A=c[L+4>>2]|0;c[J>>2]=c[L>>2];c[J+4>>2]=A;c[L>>2]=G;c[L+4>>2]=E}E=40<<K;L=V+(D*96|0)+E|0;G=c[L>>2]|0;A=c[L+4>>2]|0;J=P+ea|0;S=c[J+4>>2]|0;c[L>>2]=c[J>>2];c[L+4>>2]=S;c[J>>2]=G;c[J+4>>2]=A;if(lb){A=E+8+(V+(D*96|0))|0;E=c[A>>2]|0;J=c[A+4>>2]|0;G=P+(ea+8)|0;ea=c[G+4>>2]|0;c[A>>2]=c[G>>2];c[A+4>>2]=ea;c[G>>2]=E;c[G+4>>2]=J;J=16<<K;G=V+(gb*96|0)+J|0;E=mb-aa|0;nb=J;ob=c[G+4>>2]|0;pb=c[G>>2]|0;qb=E;rb=R+E|0;oa=146;break}else{E=16<<K;G=V+(gb*96|0)+E|0;J=mb-aa|0;sb=E;tb=c[G+4>>2]|0;ub=c[G>>2]|0;vb=J;wb=R+J|0;oa=147;break}}else{J=16<<K;G=V+(gb*96|0)+J|0;E=c[G>>2]|0;ea=c[G+4>>2]|0;G=mb-aa|0;A=R+G|0;if(lb){nb=J;ob=ea;pb=E;qb=G;rb=A;oa=146}else{sb=J;tb=ea;ub=E;vb=G;wb=A;oa=147}}}while(0);if((oa|0)==146){c[rb>>2]=pb;c[rb+4>>2]=ob;D=nb+8+(V+(gb*96|0))|0;A=c[D+4>>2]|0;G=R+(qb+8)|0;c[G>>2]=c[D>>2];c[G+4>>2]=A;xb=1;yb=nb;zb=qb}else if((oa|0)==147){c[wb>>2]=ub;c[wb+4>>2]=tb;xb=0;yb=sb;zb=vb}A=24<<K;G=V+(gb*96|0)+A|0;D=c[G>>2]|0;E=c[G+4>>2]|0;ea=R+C|0;J=c[ea+4>>2]|0;c[G>>2]=c[ea>>2];c[G+4>>2]=J;c[ea>>2]=D;c[ea+4>>2]=E;if(xb){E=A+8+(V+(gb*96|0))|0;A=c[E>>2]|0;ea=c[E+4>>2]|0;D=R+(C+8)|0;J=c[D+4>>2]|0;c[E>>2]=c[D>>2];c[E+4>>2]=J;c[D>>2]=A;c[D+4>>2]=ea;ea=32<<K;D=V+(gb*96|0)+ea|0;A=c[D+4>>2]|0;J=P+zb|0;c[J>>2]=c[D>>2];c[J+4>>2]=A;A=ea+8+(V+(gb*96|0))|0;J=c[A+4>>2]|0;D=P+(zb+8)|0;c[D>>2]=c[A>>2];c[D+4>>2]=J;Ab=ea}else{ea=32<<K;J=V+(gb*96|0)+ea|0;D=c[J+4>>2]|0;A=P+zb|0;c[A>>2]=c[J>>2];c[A+4>>2]=D;Ab=ea}ea=40<<K;D=V+(gb*96|0)+ea|0;A=c[D>>2]|0;J=c[D+4>>2]|0;E=P+C|0;G=c[E+4>>2]|0;c[D>>2]=c[E>>2];c[D+4>>2]=G;c[E>>2]=A;c[E+4>>2]=J;if(xb){J=ea+8+(V+(gb*96|0))|0;ea=c[J>>2]|0;E=c[J+4>>2]|0;A=P+(C+8)|0;G=c[A+4>>2]|0;c[J>>2]=c[A>>2];c[J+4>>2]=G;c[A>>2]=ea;c[A+4>>2]=E}E=(c[l>>2]|0)+1|0;if((E|0)>=(c[Y>>2]|0)){break}A=(c[I>>2]|0)+(E*96|0)+yb|0;E=c[A>>2]|0;ea=c[A+4>>2]|0;G=(17<<K)-aa|0;J=R+G|0;D=c[J+4>>2]|0;c[A>>2]=c[J>>2];c[A+4>>2]=D;c[J>>2]=E;c[J+4>>2]=ea;if(xb){ea=yb+8+((c[I>>2]|0)+(((c[l>>2]|0)+1|0)*96|0))|0;J=c[ea>>2]|0;E=c[ea+4>>2]|0;D=R+(G+8)|0;A=c[D+4>>2]|0;c[ea>>2]=c[D>>2];c[ea+4>>2]=A;c[D>>2]=J;c[D+4>>2]=E;Bb=1}else{Bb=0}E=(c[I>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+Ab|0;D=c[E>>2]|0;J=c[E+4>>2]|0;A=P+G|0;ea=c[A+4>>2]|0;c[E>>2]=c[A>>2];c[E+4>>2]=ea;c[A>>2]=D;c[A+4>>2]=J;if(!Bb){break}J=Ab+8+((c[I>>2]|0)+(((c[l>>2]|0)+1|0)*96|0))|0;A=c[J>>2]|0;D=c[J+4>>2]|0;ea=P+(G+8)|0;G=c[ea+4>>2]|0;c[J>>2]=c[ea>>2];c[J+4>>2]=G;c[ea>>2]=A;c[ea+4>>2]=D}}while(0);P=(s&1|0)==0;l=(s&2|0)==0;Ab=f+426564|0;Bb=(u|0)==0;u=(s&16777216|0)!=0;s=f+116|0;R=f+112|0;yb=u?4:1;xb=f+140|0;gb=u?f+136|0:xb;zb=f+124|0;vb=f+6128|0;sb=f+4836|0;tb=f+421200|0;wb=0;do{ub=c[v>>2]|0;qb=c[k+(wb<<2)>>2]|0;nb=wb<<4;ob=O+(nb<<2)|0;f:do{if(P){if(l){if((c[Ab>>2]&15|0)==0){break}if(Bb){if(u){le[c[s>>2]&1023](qb,ob,f+421200+(wb<<8<<ub<<1)|0,N,(wb*40|0)+(f+5184)|0);break}else{le[c[R>>2]&1023](qb,ob,f+421200+(wb<<8<<ub<<1)|0,N,(wb*40|0)+(f+5184)|0);break}}rb=c[gb>>2]|0;pb=wb<<8;lb=0;while(1){mb=lb+nb|0;if((a[(d[473424+mb|0]|0)+(f+5184)|0]|0)!=0){Xe[rb&4095](qb+(c[O+(mb<<2)>>2]|0)|0,f+421200+((lb<<4)+pb<<ub<<1)|0,N)}lb=lb+yb|0;if((lb|0)>=16){break f}}}if(Bb){le[c[zb>>2]&1023](qb,ob,f+421200+(wb<<8<<ub<<1)|0,N,(wb*40|0)+(f+5184)|0);break}do{if((c[vb>>2]|0)==244){lb=c[sb>>2]|0;if(!((lb-1|0)>>>0<2>>>0)){break}cf[c[f+5148+(lb<<2)>>2]&1023](qb,ob,f+421200+(wb<<8<<ub<<1)|0,N);break f}}while(0);lb=wb<<8;pb=(ub|0)==0;rb=0;do{mb=rb+nb|0;eb=(rb<<4)+lb|0;if((a[(d[473424+mb|0]|0)+(f+5184)|0]|0)==0){if(pb){Cb=e[f+421200+(eb<<1)>>1]|0}else{Cb=c[tb+(eb<<2)>>2]|0}if((Cb|0)!=0){oa=190}}else{oa=190}if((oa|0)==190){oa=0;Xe[c[xb>>2]&4095](qb+(c[O+(mb<<2)>>2]|0)|0,f+421200+(eb<<ub<<1)|0,N)}rb=rb+1|0;}while((rb|0)<16)}}while(0);wb=wb+1|0;}while((wb|0)<3);i=g;return}function _ca(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=f+427376|0;l=c[k>>2]|0;m=f+427380|0;n=c[m>>2]|0;o=f+427412|0;p=c[o>>2]|0;q=f+4064|0;r=c[(c[q>>2]|0)+(p<<2)>>2]|0;s=f+4776|0;t=f+8|0;u=c[f+2528>>2]|0;v=c[s>>2]|0;w=(ba(v,n)|0)+l<<4;x=u+w|0;c[j>>2]=x;y=u+(w+64+(ba(l<<2&12,v)|0))|0;Xe[c[t>>2]&4095](y,v,4);v=c[f+2532>>2]|0;y=c[s>>2]|0;z=(ba(y,n)|0)+l<<4;A=v+z|0;c[j+4>>2]=A;B=v+(z+64+(ba(c[k>>2]<<2&12,y)|0))|0;Xe[c[t>>2]&4095](B,y,4);y=c[f+2536>>2]|0;B=c[s>>2]|0;C=(ba(B,n)|0)+l<<4;l=y+C|0;c[j+8>>2]=l;n=y+(C+64+(ba(c[k>>2]<<2&12,B)|0))|0;Xe[c[t>>2]&4095](n,B,4);a[(c[f+199432>>2]|0)+p|0]=c[f+199428>>2];p=c[s>>2]|0;c[f+6116>>2]=p;B=f+6112|0;c[B>>2]=p;do{if((r&7|0)==0){n=c[f+1028>>2]|0;D=f+148|0;E=c[f+1032>>2]|0;F=f+164|0;G=f+12|0;H=f+28|0;I=c[(c[q>>2]|0)+(c[o>>2]<<2)>>2]|0;J=a[f+5644|0]|0;if(J<<24>>24>-1){K=J<<24>>24;J=c[k>>2]|0;L=(b[f+5360>>1]>>2)+64+(J<<4|8)+(ba((c[m>>2]<<4|J<<2&12)+(b[f+5362>>1]>>2)|0,p)|0)|0;Xe[c[t>>2]&4095]((c[f+199440+(K*2224|0)>>2]|0)+L|0,p,4);Xe[c[t>>2]&4095]((c[f+199440+(K*2224|0)+4>>2]|0)+L|0,c[s>>2]|0,4);Xe[c[t>>2]&4095]((c[f+199440+(K*2224|0)+8>>2]|0)+L|0,c[s>>2]|0,4)}do{if((I&8|0)==0){if((I&16|0)!=0){L=n+64|0;K=E+64|0;Cda(f,0,0,8,8,x,A,l,0,0,L,c[D>>2]|0,K,c[F>>2]|0,G,H,I&4096,I&16384);Cda(f,8,0,8,8,x,A,l,0,4,L,c[D>>2]|0,K,c[F>>2]|0,G,H,I&8192,I&32768);break}if((I&32|0)!=0){K=n+64|0;L=f+152|0;J=E+64|0;M=f+168|0;N=f+16|0;O=f+32|0;Cda(f,0,0,16,c[B>>2]<<3,x,A,l,0,0,K,c[L>>2]|0,J,c[M>>2]|0,N,O,I&4096,I&16384);Cda(f,4,0,16,c[B>>2]<<3,x,A,l,4,0,K,c[L>>2]|0,J,c[M>>2]|0,N,O,I&8192,I&32768);break}O=n+128|0;N=f+156|0;M=E+128|0;J=f+172|0;L=f+20|0;K=f+36|0;P=f+152|0;Q=f+168|0;R=f+16|0;S=f+32|0;T=n+64|0;U=E+64|0;V=0;do{W=e[f+177112+(V<<1)>>1]|0;X=V<<2;Y=X&4;Z=V<<1&4;do{if((W&8|0)==0){if((W&16|0)!=0){_=W&4096;$=W&16384;Cda(f,X,0,4,4,x,A,l,Y,Z,O,c[P>>2]|0,M,c[Q>>2]|0,R,S,_,$);Cda(f,X|2,0,4,4,x,A,l,Y,Z|2,O,c[P>>2]|0,M,c[Q>>2]|0,R,S,_,$);break}if((W&32|0)==0){$=W&4096;_=W&16384;Cda(f,X,1,4,0,x,A,l,Y,Z,O,c[N>>2]|0,M,c[J>>2]|0,L,K,$,_);aa=Y|2;Cda(f,X|1,1,4,0,x,A,l,aa,Z,O,c[N>>2]|0,M,c[J>>2]|0,L,K,$,_);ca=Z|2;Cda(f,X|2,1,4,0,x,A,l,Y,ca,O,c[N>>2]|0,M,c[J>>2]|0,L,K,$,_);Cda(f,X|3,1,4,0,x,A,l,aa,ca,O,c[N>>2]|0,M,c[J>>2]|0,L,K,$,_);break}else{_=W&4096;$=W&16384;Cda(f,X,0,8,c[B>>2]<<2,x,A,l,Y,Z,O,c[N>>2]|0,M,c[J>>2]|0,L,K,_,$);Cda(f,X|1,0,8,c[B>>2]<<2,x,A,l,Y|2,Z,O,c[N>>2]|0,M,c[J>>2]|0,L,K,_,$);break}}else{Cda(f,X,1,8,0,x,A,l,Y,Z,T,c[P>>2]|0,U,c[Q>>2]|0,R,S,W&4096,W&16384)}}while(0);V=V+1|0;}while((V|0)<4)}else{Cda(f,0,1,16,0,x,A,l,0,0,n|0,c[D>>2]|0,E|0,c[F>>2]|0,G,H,I&4096,I&16384)}}while(0);I=a[f+5684|0]|0;if(!(I<<24>>24>-1)){break}H=I<<24>>24;I=c[k>>2]|0;G=(b[f+5520>>1]>>2)+64+(I<<4|8)+(ba((c[m>>2]<<4|I<<2&12)+(b[f+5522>>1]>>2)|0,c[B>>2]|0)|0)|0;Xe[c[t>>2]&4095]((c[f+306192+(H*2224|0)>>2]|0)+G|0,c[s>>2]|0,4);Xe[c[t>>2]&4095]((c[f+306192+(H*2224|0)+4>>2]|0)+G|0,c[s>>2]|0,4);Xe[c[t>>2]&4095]((c[f+306192+(H*2224|0)+8>>2]|0)+G|0,c[s>>2]|0,4)}else{G=f+427420|0;H=c[G>>2]|0;if((H|0)==2){da=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);ea=c[f+4864>>2]|0;fa=c[k>>2]|0;ga=5}else if((H|0)!=0){H=c[k>>2]|0;da=(H|0)>0;ea=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;fa=H;ga=5}do{if((ga|0)==5){H=fa-1|0;I=f+5180|0;F=c[I>>2]|0;if((ea|0)==0){break}if(da){E=F+(H*96|0)+8|0;D=c[E>>2]|0;n=c[E+4>>2]|0;V=u+(w+(-8-p))|0;S=c[V+4>>2]|0;c[E>>2]=c[V>>2];c[E+4>>2]=S;c[V>>2]=D;c[V+4>>2]=n}n=F+(fa*96|0)|0;V=c[n>>2]|0;D=c[n+4>>2]|0;S=u+(w-p)|0;E=c[S+4>>2]|0;c[n>>2]=c[S>>2];c[n+4>>2]=E;c[S>>2]=V;c[S+4>>2]=D;D=F+(fa*96|0)+8|0;S=c[D>>2]|0;V=c[D+4>>2]|0;E=8-p|0;n=u+(w+E)|0;R=c[n+4>>2]|0;c[D>>2]=c[n>>2];c[D+4>>2]=R;c[n>>2]=S;c[n+4>>2]=V;V=(c[k>>2]|0)+1|0;n=f+427400|0;if((V|0)<(c[n>>2]|0)){S=(c[I>>2]|0)+(V*96|0)|0;V=c[S>>2]|0;R=c[S+4>>2]|0;D=u+(w+(16-p))|0;Q=c[D+4>>2]|0;c[S>>2]=c[D>>2];c[S+4>>2]=Q;c[D>>2]=V;c[D+4>>2]=R}if(da){R=F+(H*96|0)+24|0;D=c[R>>2]|0;V=c[R+4>>2]|0;Q=-8-p|0;S=v+(z+Q)|0;U=c[S+4>>2]|0;c[R>>2]=c[S>>2];c[R+4>>2]=U;c[S>>2]=D;c[S+4>>2]=V;V=F+(H*96|0)+40|0;H=c[V>>2]|0;S=c[V+4>>2]|0;D=y+(C+Q)|0;Q=c[D+4>>2]|0;c[V>>2]=c[D>>2];c[V+4>>2]=Q;c[D>>2]=H;c[D+4>>2]=S}S=F+(fa*96|0)+16|0;D=c[S>>2]|0;H=c[S+4>>2]|0;Q=v+(z-p)|0;V=c[Q+4>>2]|0;c[S>>2]=c[Q>>2];c[S+4>>2]=V;c[Q>>2]=D;c[Q+4>>2]=H;H=F+(fa*96|0)+24|0;Q=c[H>>2]|0;D=c[H+4>>2]|0;V=v+(z+E)|0;S=c[V+4>>2]|0;c[H>>2]=c[V>>2];c[H+4>>2]=S;c[V>>2]=Q;c[V+4>>2]=D;D=F+(fa*96|0)+32|0;V=c[D>>2]|0;Q=c[D+4>>2]|0;S=y+(C-p)|0;H=c[S+4>>2]|0;c[D>>2]=c[S>>2];c[D+4>>2]=H;c[S>>2]=V;c[S+4>>2]=Q;Q=F+(fa*96|0)+40|0;F=c[Q>>2]|0;S=c[Q+4>>2]|0;V=y+(C+E)|0;E=c[V+4>>2]|0;c[Q>>2]=c[V>>2];c[Q+4>>2]=E;c[V>>2]=F;c[V+4>>2]=S;S=(c[k>>2]|0)+1|0;if((S|0)>=(c[n>>2]|0)){break}n=(c[I>>2]|0)+(S*96|0)+16|0;S=c[n>>2]|0;V=c[n+4>>2]|0;F=16-p|0;E=v+(z+F)|0;Q=c[E+4>>2]|0;c[n>>2]=c[E>>2];c[n+4>>2]=Q;c[E>>2]=S;c[E+4>>2]=V;V=(c[I>>2]|0)+(((c[k>>2]|0)+1|0)*96|0)+32|0;I=c[V>>2]|0;E=c[V+4>>2]|0;S=y+(C+F)|0;F=c[S+4>>2]|0;c[V>>2]=c[S>>2];c[V+4>>2]=F;c[S>>2]=I;c[S+4>>2]=E}}while(0);E=h;S=f+4792|0;I=(r&1|0)==0;F=f+4836|0;V=f+128|0;Q=(r&16777216|0)==0;n=f+104|0;H=f+96|0;D=f+5168|0;U=3-p|0;R=4-p|0;P=f+108|0;T=f+100|0;K=f+5160|0;L=0;J=x;while(1){if((L|0)==0){ha=S}else{ha=f+4756+(L-1<<2)|0}M=c[ha>>2]|0;N=L<<4;a:do{if(I){ne[c[f+5084+(c[F>>2]<<2)>>2]&1023](J,p);if((a[(d[L+473472|0]|0)+(f+5184)|0]|0)==0){break}Xe[c[V>>2]&4095](f+421200+(L<<8<<1)|0,f+424272+(L<<6)|0,c[(c[f+177020+(L<<2)>>2]|0)+(M<<6)>>2]|0)}else{if(!Q){O=c[P>>2]|0;W=c[T>>2]|0;Z=L<<8;Y=0;while(1){X=Y+N|0;$=J+(c[f+5716+(X<<2)>>2]|0)|0;_=a[(d[473424+X|0]|0)+(f+5184)|0]|0;cf[c[f+4992+(a[(a[473424+Y|0]&255)+(f+4888)|0]<<24>>24<<2)>>2]&1023]($,c[K>>2]<<Y&32768,c[D>>2]<<Y&16384,p);do{if((_<<24>>24|0)==1){X=(Y<<4)+Z|0;ca=f+421200+(X<<1)|0;if((b[ca>>1]|0)==0){ia=X;ga=24;break}Xe[O&4095]($,ca,p)}else if((_<<24>>24|0)!=0){ia=(Y<<4)+Z|0;ga=24}}while(0);if((ga|0)==24){ga=0;Xe[W&4095]($,f+421200+(ia<<1)|0,p)}Y=Y+4|0;if((Y|0)>=16){break a}}}Y=c[n>>2]|0;W=c[H>>2]|0;Z=L<<8;O=0;do{_=O+N|0;ca=c[f+5716+(_<<2)>>2]|0;X=J+ca|0;aa=a[(d[473424+O|0]|0)+(f+4888)|0]|0;ja=aa<<24>>24;do{if((aa<<24>>24|0)==7|(aa<<24>>24|0)==3){if((c[D>>2]&32768>>>(O>>>0)|0)==0){c[h>>2]=ba(d[J+(U+ca)|0]|0,16843009)|0;ka=E;break}else{ka=J+(R+ca)|0;break}}else{ka=0}}while(0);Xe[c[f+4932+(ja<<2)>>2]&4095](X,ka,p);ca=a[(d[473424+_|0]|0)+(f+5184)|0]|0;b:do{if(!(ca<<24>>24==0)){aa=f+421200+((O<<4)+Z<<1)|0;do{if(ca<<24>>24==1){if((b[aa>>1]|0)==0){break}Xe[Y&4095](X,aa,p);break b}}while(0);Xe[W&4095](X,aa,p)}}while(0);O=O+1|0;}while((O|0)<16)}}while(0);N=L+1|0;if((N|0)>=3){break}L=N;J=c[j+(N<<2)>>2]|0}J=c[G>>2]|0;if((J|0)==2){la=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);ma=c[f+4864>>2]|0;na=c[k>>2]|0}else if((J|0)==0){break}else{J=c[k>>2]|0;la=(J|0)>0;ma=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;na=J}J=na-1|0;L=f+5180|0;R=c[L>>2]|0;if((ma|0)==0){break}if(la){E=R+(J*96|0)+8|0;U=c[E>>2]|0;D=c[E+4>>2]|0;H=u+(w+(-8-p))|0;n=c[H+4>>2]|0;c[E>>2]=c[H>>2];c[E+4>>2]=n;c[H>>2]=U;c[H+4>>2]=D}D=R+(na*96|0)|0;H=c[D+4>>2]|0;U=u+(w-p)|0;c[U>>2]=c[D>>2];c[U+4>>2]=H;H=R+(na*96|0)+8|0;U=c[H>>2]|0;D=c[H+4>>2]|0;n=8-p|0;E=u+(w+n)|0;K=c[E+4>>2]|0;c[H>>2]=c[E>>2];c[H+4>>2]=K;c[E>>2]=U;c[E+4>>2]=D;D=(c[k>>2]|0)+1|0;E=f+427400|0;if((D|0)<(c[E>>2]|0)){U=(c[L>>2]|0)+(D*96|0)|0;D=c[U>>2]|0;K=c[U+4>>2]|0;H=u+(w+(16-p))|0;T=c[H+4>>2]|0;c[U>>2]=c[H>>2];c[U+4>>2]=T;c[H>>2]=D;c[H+4>>2]=K}if(la){K=R+(J*96|0)+24|0;H=c[K>>2]|0;D=c[K+4>>2]|0;T=-8-p|0;U=v+(z+T)|0;P=c[U+4>>2]|0;c[K>>2]=c[U>>2];c[K+4>>2]=P;c[U>>2]=H;c[U+4>>2]=D;D=R+(J*96|0)+40|0;J=c[D>>2]|0;U=c[D+4>>2]|0;H=y+(C+T)|0;T=c[H+4>>2]|0;c[D>>2]=c[H>>2];c[D+4>>2]=T;c[H>>2]=J;c[H+4>>2]=U}U=R+(na*96|0)+16|0;H=c[U+4>>2]|0;J=v+(z-p)|0;c[J>>2]=c[U>>2];c[J+4>>2]=H;H=R+(na*96|0)+24|0;J=c[H>>2]|0;U=c[H+4>>2]|0;T=v+(z+n)|0;D=c[T+4>>2]|0;c[H>>2]=c[T>>2];c[H+4>>2]=D;c[T>>2]=J;c[T+4>>2]=U;U=R+(na*96|0)+32|0;T=c[U+4>>2]|0;J=y+(C-p)|0;c[J>>2]=c[U>>2];c[J+4>>2]=T;T=R+(na*96|0)+40|0;R=c[T>>2]|0;J=c[T+4>>2]|0;U=y+(C+n)|0;n=c[U+4>>2]|0;c[T>>2]=c[U>>2];c[T+4>>2]=n;c[U>>2]=R;c[U+4>>2]=J;J=(c[k>>2]|0)+1|0;if((J|0)>=(c[E>>2]|0)){break}E=(c[L>>2]|0)+(J*96|0)+16|0;J=c[E>>2]|0;U=c[E+4>>2]|0;R=16-p|0;n=v+(z+R)|0;T=c[n+4>>2]|0;c[E>>2]=c[n>>2];c[E+4>>2]=T;c[n>>2]=J;c[n+4>>2]=U;U=(c[L>>2]|0)+(((c[k>>2]|0)+1|0)*96|0)+32|0;L=c[U>>2]|0;n=c[U+4>>2]|0;J=y+(C+R)|0;R=c[J+4>>2]|0;c[U>>2]=c[J>>2];c[U+4>>2]=R;c[J>>2]=L;c[J+4>>2]=n}}while(0);C=(r&1|0)==0;y=(r&2|0)==0;k=f+426564|0;z=(r&16777216|0)==0;r=f+112|0;v=f+116|0;na=f+124|0;la=f+5716|0;if(!C){i=g;return}c:do{if(y){do{if((c[k>>2]&15|0)!=0){if(z){le[c[r>>2]&1023](x,la,f+421200|0,p,f+5184|0);break}else{le[c[v>>2]&1023](x,la,f+421200|0,p,f+5184|0);ga=80;break c}}}while(0)}else{le[c[na>>2]&1023](x,la,f+421200|0,p,f+5184|0);ga=80}}while(0);do{if((ga|0)==80){if(C){break}i=g;return}}while(0);ga=f+5780|0;do{if(y){if((c[k>>2]&15|0)==0){break}if(z){le[c[r>>2]&1023](A,ga,f+421712|0,p,f+5224|0);break}else{le[c[v>>2]&1023](A,ga,f+421712|0,p,f+5224|0);break}}else{le[c[na>>2]&1023](A,ga,f+421712|0,p,f+5224|0)}}while(0);ga=f+5844|0;if(!C){i=g;return}if(!y){le[c[na>>2]&1023](l,ga,f+422224|0,p,f+5264|0);i=g;return}if((c[k>>2]&15|0)==0){i=g;return}if(z){le[c[r>>2]&1023](l,ga,f+422224|0,p,f+5264|0);i=g;return}else{le[c[v>>2]&1023](l,ga,f+422224|0,p,f+5264|0);i=g;return}}function $ca(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=f+427376|0;m=c[l>>2]|0;n=f+427380|0;o=c[n>>2]|0;p=f+427412|0;q=c[p>>2]|0;r=f+4064|0;s=c[(c[r>>2]|0)+(q<<2)>>2]|0;t=f+4792|0;if((c[t>>2]|0)==0){u=(c[f+6140>>2]|0)!=0}else{u=0}v=(c[(c[f>>2]|0)+48>>2]|0)==28;w=16>>>((c[f+4788>>2]|0)>>>0);y=f+6136|0;z=(c[y>>2]|0)==2;A=c[f+2528>>2]|0;B=f+4752|0;C=c[B>>2]|0;D=m<<C;E=f+4776|0;G=c[E>>2]|0;H=(ba(G,o)|0)+D<<4;I=A+H|0;J=c[f+2532>>2]|0;K=f+4780|0;L=(ba(ba(w,o)|0,c[K>>2]|0)|0)+(D<<3)|0;D=J+L|0;M=c[f+2536>>2]|0;N=M+L|0;O=f+8|0;P=A+(H+(64<<C)+(ba(m<<2&12,G)|0))|0;Xe[c[O>>2]&4095](P,G,4);G=(ba(c[l>>2]&7,c[K>>2]|0)|0)+L|0;Xe[c[O>>2]&4095](J+(G+(64<<c[B>>2]))|0,N-D|0,2);G=f+199428|0;a[(c[f+199432>>2]|0)+q|0]=c[G>>2];q=f+177092|0;P=c[E>>2]|0;do{if((c[q>>2]|0)==0){c[f+6112>>2]=P;m=c[K>>2]|0;c[f+6116>>2]=m;Q=I;R=D;S=N;T=P;U=m;V=f+5716|0}else{m=P<<1;c[f+6112>>2]=m;C=c[K>>2]|0;W=C<<1;c[f+6116>>2]=W;X=f+5908|0;if((o&1|0)==0){Y=I;Z=D;_=N}else{$=L-(ba(C,w-1|0)|0)|0;Y=A+((P*-15|0)+H)|0;Z=J+$|0;_=M+$|0}if((c[f+177088>>2]|0)==0){Q=Y;R=Z;S=_;T=m;U=W;V=X;break}if((c[G>>2]|0)==0){Q=Y;R=Z;S=_;T=m;U=W;V=X;break}$=(s&8|0)==0;C=0;while(1){do{if((12288<<(C<<1)&s|0)!=0){aa=f+5632+(C*40|0)+12|0;ca=a[aa]|0;if(!$){da=ba((ca<<24>>24)+16^c[n>>2]&1,16843009)|0;c[aa>>2]=da;c[f+5632+(C*40|0)+20>>2]=da;c[f+5632+(C*40|0)+28>>2]=da;c[f+5632+(C*40|0)+36>>2]=da;break}if(ca<<24>>24>-1){da=((c[n>>2]&1^(ca<<24>>24)+16)*257|0)&65535;b[aa>>1]=da;b[f+5632+(C*40|0)+20>>1]=da}da=f+5632+(C*40|0)+14|0;aa=a[da]|0;if(aa<<24>>24>-1){ca=((c[n>>2]&1^(aa<<24>>24)+16)*257|0)&65535;b[da>>1]=ca;b[f+5632+(C*40|0)+22>>1]=ca}ca=f+5632+(C*40|0)+28|0;da=a[ca]|0;if(da<<24>>24>-1){aa=((c[n>>2]&1^(da<<24>>24)+16)*257|0)&65535;b[ca>>1]=aa;b[f+5632+(C*40|0)+36>>1]=aa}aa=f+5632+(C*40|0)+30|0;ca=a[aa]|0;if(!(ca<<24>>24>-1)){break}da=((c[n>>2]&1^(ca<<24>>24)+16)*257|0)&65535;b[aa>>1]=da;b[f+5632+(C*40|0)+38>>1]=da}}while(0);da=C+1|0;if(da>>>0<(c[G>>2]|0)>>>0){C=da}else{Q=Y;R=Z;S=_;T=m;U=W;V=X;break}}}}while(0);if((s&4|0)!=0){_=c[f+7308>>2]|0;Z=f+421184|0;Y=c[Z>>2]|0;if((c[B>>2]|0)==0){UGb(Q|0,Y|0,16)|0;UGb(Q+T|0,(c[Z>>2]|0)+16|0,16)|0;UGb(Q+(T<<1)|0,(c[Z>>2]|0)+32|0,16)|0;UGb(Q+(T*3|0)|0,(c[Z>>2]|0)+48|0,16)|0;UGb(Q+(T<<2)|0,(c[Z>>2]|0)+64|0,16)|0;UGb(Q+(T*5|0)|0,(c[Z>>2]|0)+80|0,16)|0;UGb(Q+(T*6|0)|0,(c[Z>>2]|0)+96|0,16)|0;UGb(Q+(T*7|0)|0,(c[Z>>2]|0)+112|0,16)|0;UGb(Q+(T<<3)|0,(c[Z>>2]|0)+128|0,16)|0;UGb(Q+(T*9|0)|0,(c[Z>>2]|0)+144|0,16)|0;UGb(Q+(T*10|0)|0,(c[Z>>2]|0)+160|0,16)|0;UGb(Q+(T*11|0)|0,(c[Z>>2]|0)+176|0,16)|0;UGb(Q+(T*12|0)|0,(c[Z>>2]|0)+192|0,16)|0;UGb(Q+(T*13|0)|0,(c[Z>>2]|0)+208|0,16)|0;UGb(Q+(T*14|0)|0,(c[Z>>2]|0)+224|0,16)|0;UGb(Q+(T*15|0)|0,(c[Z>>2]|0)+240|0,16)|0;if((c[y>>2]|0)==0){G=1<<_-1&255;TGb(R|0,G|0,8)|0;TGb(S|0,G|0,8)|0;TGb(R+U|0,G|0,8)|0;TGb(S+U|0,G|0,8)|0;M=U<<1;TGb(R+M|0,G|0,8)|0;TGb(S+M|0,G|0,8)|0;M=U*3|0;TGb(R+M|0,G|0,8)|0;TGb(S+M|0,G|0,8)|0;M=U<<2;TGb(R+M|0,G|0,8)|0;TGb(S+M|0,G|0,8)|0;M=U*5|0;TGb(R+M|0,G|0,8)|0;TGb(S+M|0,G|0,8)|0;M=U*6|0;TGb(R+M|0,G|0,8)|0;TGb(S+M|0,G|0,8)|0;M=U*7|0;TGb(R+M|0,G|0,8)|0;TGb(S+M|0,G|0,8)|0;i=g;return}G=c[Z>>2]|0;Z=(w<<3)+256|0;if((w|0)>0){ea=0}else{i=g;return}do{M=ba(ea,U)|0;J=ea<<3;H=G+(J+256)|0;A=R+M|0;L=H|0;N=H+4|0;H=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;N=A|0;x=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;N=A+4|0;x=H;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;N=G+(Z+J)|0;J=S+M|0;M=N|0;H=N+4|0;N=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=J|0;x=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;H=J+4|0;x=N;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;ea=ea+1|0;}while((ea|0)<(w|0));i=g;return}ea=c[y>>2]|0;y=(ba(e[1207552+(ea<<1)>>1]|0,_)|0)>>>0>2147483639>>>0|(Y|0)==0;Z=y?0:Y;Y=32-_|0;y=_<<4;G=_<<8;H=0;N=0;while(1){J=Q+(ba(N,T)|0)|0;M=H;A=0;while(1){L=Z+(M>>>3)|0;b[J+(A<<1)>>1]=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);L=A+1|0;if((L|0)<16){M=M+_|0;A=L}else{break}}A=N+1|0;if((A|0)<16){H=y+H|0;N=A}else{break}}N=(w|0)>0;if((ea|0)==0){if(!N){i=g;return}ea=1<<_-1&65535;H=0;do{y=ba(H,U)|0;b[S+y>>1]=ea;b[R+y>>1]=ea;b[S+(y+2)>>1]=ea;b[R+(y+2)>>1]=ea;b[S+(y+4)>>1]=ea;b[R+(y+4)>>1]=ea;b[S+(y+6)>>1]=ea;b[R+(y+6)>>1]=ea;b[S+(y+8)>>1]=ea;b[R+(y+8)>>1]=ea;b[S+(y+10)>>1]=ea;b[R+(y+10)>>1]=ea;b[S+(y+12)>>1]=ea;b[R+(y+12)>>1]=ea;b[S+(y+14)>>1]=ea;b[R+(y+14)>>1]=ea;H=H+1|0;}while((H|0)<(w|0));i=g;return}if(!N){i=g;return}H=_<<3;ea=w<<3;y=G;G=0;while(1){A=ba(G,U)|0;M=Z+(y>>>3)|0;J=y+_|0;b[R+A>>1]=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)>>>(Y>>>0);M=Z+(J>>>3)|0;L=J+_|0;b[R+(A+2)>>1]=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=Z+(L>>>3)|0;M=L+_|0;b[R+(A+4)>>1]=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7)>>>(Y>>>0);L=Z+(M>>>3)|0;J=M+_|0;b[R+(A+6)>>1]=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);M=Z+(J>>>3)|0;L=J+_|0;b[R+(A+8)>>1]=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=Z+(L>>>3)|0;M=L+_|0;b[R+(A+10)>>1]=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7)>>>(Y>>>0);L=Z+(M>>>3)|0;J=M+_|0;b[R+(A+12)>>1]=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);M=Z+(J>>>3)|0;b[R+(A+14)>>1]=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=G+1|0;if((J|0)<(w|0)){y=H+y|0;G=J}else{break}}if(!N){i=g;return}N=_<<3;G=ba(_,ea+256|0)|0;ea=0;while(1){y=ba(ea,U)|0;H=Z+(G>>>3)|0;J=G+_|0;b[S+y>>1]=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(G&7)>>>(Y>>>0);H=Z+(J>>>3)|0;M=J+_|0;b[S+(y+2)>>1]=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=Z+(M>>>3)|0;H=M+_|0;b[S+(y+4)>>1]=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);M=Z+(H>>>3)|0;J=H+_|0;b[S+(y+6)>>1]=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(H&7)>>>(Y>>>0);H=Z+(J>>>3)|0;M=J+_|0;b[S+(y+8)>>1]=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=Z+(M>>>3)|0;H=M+_|0;b[S+(y+10)>>1]=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);M=Z+(H>>>3)|0;J=H+_|0;b[S+(y+12)>>1]=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(H&7)>>>(Y>>>0);H=Z+(J>>>3)|0;b[S+(y+14)>>1]=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=ea+1|0;if((J|0)<(w|0)){G=N+G|0;ea=J}else{break}}i=g;return}ea=(s&7|0)!=0;a:do{if(ea){G=f+427420|0;N=c[G>>2]|0;b:do{if((N|0)!=0){w=c[B>>2]|0;do{if((c[f+177088>>2]|0)==0){fa=1}else{Y=(c[f+177096>>2]|0)!=0;if((c[n>>2]&1|0)==0){fa=Y&1^1;break}else{if(Y){fa=1;break}else{break b}}}}while(0);if((N|0)==2){ga=(e[(c[f+177072>>2]|0)+((c[p>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);ha=c[f+4864>>2]|0;ia=c[l>>2]|0}else{Y=c[l>>2]|0;ga=(Y|0)>0;ha=(c[n>>2]|0)>((c[q>>2]|0)!=0|0)|0;ia=Y}Y=T+1+w|0;Z=U+1+w|0;_=ia-1|0;J=f+5176+(fa<<2)|0;H=c[J>>2]|0;y=H+(ia*96|0)|0;if((ha|0)==0){break}do{if(ga){M=8<<w;A=H+(_*96|0)+M|0;L=c[A>>2]|0;D=c[A+4>>2]|0;I=(-7<<w)-Y|0;o=Q+I|0;X=c[o+4>>2]|0;c[A>>2]=c[o>>2];c[A+4>>2]=X;c[o>>2]=L;c[o+4>>2]=D;if((w|0)==0){D=y;ja=Q+(1-Y)|0;ka=c[D+4>>2]|0;la=c[D>>2]|0;ma=D;na=53;break}else{D=M+8+(H+(_*96|0))|0;M=c[D>>2]|0;o=c[D+4>>2]|0;L=Q+(I+8)|0;I=c[L+4>>2]|0;c[D>>2]=c[L>>2];c[D+4>>2]=I;c[L>>2]=M;c[L+4>>2]=o;na=51;break}}else{na=51}}while(0);do{if((na|0)==51){o=y;L=c[o>>2]|0;M=c[o+4>>2]|0;I=(1<<w)-Y|0;D=Q+I|0;if((w|0)==0){ja=D;ka=M;la=L;ma=o;na=53;break}X=c[D+4>>2]|0;c[o>>2]=c[D>>2];c[o+4>>2]=X;c[D>>2]=L;c[D+4>>2]=M;M=H+(ia*96|0)+8|0;D=c[M>>2]|0;L=c[M+4>>2]|0;X=Q+(I+8)|0;I=c[X+4>>2]|0;c[M>>2]=c[X>>2];c[M+4>>2]=I;c[X>>2]=D;c[X+4>>2]=L;oa=1}}while(0);if((na|0)==53){y=c[ja+4>>2]|0;c[ma>>2]=c[ja>>2];c[ma+4>>2]=y;c[ja>>2]=la;c[ja+4>>2]=ka;oa=0}y=8<<w;L=H+(ia*96|0)+y|0;X=c[L>>2]|0;D=c[L+4>>2]|0;I=(9<<w)-Y|0;M=Q+I|0;o=c[M+4>>2]|0;c[L>>2]=c[M>>2];c[L+4>>2]=o;c[M>>2]=X;c[M+4>>2]=D;if(oa){D=y+8+(H+(ia*96|0))|0;y=c[D>>2]|0;M=c[D+4>>2]|0;X=Q+(I+8)|0;I=c[X+4>>2]|0;c[D>>2]=c[X>>2];c[D+4>>2]=I;c[X>>2]=y;c[X+4>>2]=M}M=(c[l>>2]|0)+1|0;do{if((M|0)<(c[f+427400>>2]|0)){X=(c[J>>2]|0)+(M*96|0)|0;y=c[X>>2]|0;I=c[X+4>>2]|0;D=(17<<w)-Y|0;o=Q+D|0;L=c[o+4>>2]|0;c[X>>2]=c[o>>2];c[X+4>>2]=L;c[o>>2]=y;c[o+4>>2]=I;if(!oa){break}I=(c[J>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+8|0;o=c[I>>2]|0;y=c[I+4>>2]|0;L=Q+(D+8)|0;D=c[L+4>>2]|0;c[I>>2]=c[L>>2];c[I+4>>2]=D;c[L>>2]=o;c[L+4>>2]=y}}while(0);J=16<<w;do{if(ga){Y=H+(_*96|0)+J|0;M=c[Y>>2]|0;y=c[Y+4>>2]|0;L=(-7<<w)-Z|0;o=R+L|0;D=c[o+4>>2]|0;c[Y>>2]=c[o>>2];c[Y+4>>2]=D;c[o>>2]=M;c[o+4>>2]=y;if(oa){y=J+8+(H+(_*96|0))|0;o=c[y>>2]|0;M=c[y+4>>2]|0;D=R+(L+8)|0;Y=c[D+4>>2]|0;c[y>>2]=c[D>>2];c[y+4>>2]=Y;c[D>>2]=o;c[D+4>>2]=M}M=24<<w;D=H+(_*96|0)+M|0;o=c[D>>2]|0;Y=c[D+4>>2]|0;y=S+L|0;I=c[y+4>>2]|0;c[D>>2]=c[y>>2];c[D+4>>2]=I;c[y>>2]=o;c[y+4>>2]=Y;if(!oa){pa=0;break}Y=M+8+(H+(_*96|0))|0;M=c[Y>>2]|0;y=c[Y+4>>2]|0;o=S+(L+8)|0;L=c[o+4>>2]|0;c[Y>>2]=c[o>>2];c[Y+4>>2]=L;c[o>>2]=M;c[o+4>>2]=y;pa=1}else{pa=oa}}while(0);_=H+(ia*96|0)+J|0;y=c[_>>2]|0;o=c[_+4>>2]|0;M=1-Z+w|0;L=R+M|0;Y=c[L+4>>2]|0;c[_>>2]=c[L>>2];c[_+4>>2]=Y;c[L>>2]=y;c[L+4>>2]=o;if(pa){o=J+8+(H+(ia*96|0))|0;L=c[o>>2]|0;y=c[o+4>>2]|0;Y=R+(M+8)|0;_=c[Y+4>>2]|0;c[o>>2]=c[Y>>2];c[o+4>>2]=_;c[Y>>2]=L;c[Y+4>>2]=y}y=24<<w;Y=H+(ia*96|0)+y|0;L=c[Y>>2]|0;_=c[Y+4>>2]|0;o=S+M|0;I=c[o+4>>2]|0;c[Y>>2]=c[o>>2];c[Y+4>>2]=I;c[o>>2]=L;c[o+4>>2]=_;if(!pa){break}_=y+8+(H+(ia*96|0))|0;y=c[_>>2]|0;o=c[_+4>>2]|0;L=S+(M+8)|0;M=c[L+4>>2]|0;c[_>>2]=c[L>>2];c[_+4>>2]=M;c[L>>2]=y;c[L+4>>2]=o}}while(0);N=f+4832|0;ne[c[f+5040+(c[N>>2]<<2)>>2]&1023](R,U);ne[c[f+5040+(c[N>>2]<<2)>>2]&1023](S,U);N=c[B>>2]|0;o=h;L=j;y=c[t>>2]|0;c:do{if((s&1|0)==0){ne[c[f+5084+(c[f+4836>>2]<<2)>>2]&1023](Q,T);if(!v){RZa(f+421200|0,f+424272|0,y);break}if((a[f+5184|0]|0)==0){break}if(!u){Xe[c[f+128>>2]&4095](f+421200|0,f+424272|0,c[(c[f+177020>>2]|0)+(y<<6)>>2]|0);break}M=(N|0)==0;_=f+424272|0;I=f+421200|0;Y=0;do{D=d[931704+Y|0]|0;if(M){b[f+421200+(D<<1)>>1]=b[f+424272+(Y<<1)>>1]|0}else{c[I+(D<<2)>>2]=c[_+(Y<<2)>>2]}Y=Y+1|0;}while((Y|0)<16)}else{if((s&16777216|0)!=0){if(u){Y=c[f+136>>2]|0;qa=Y;ra=Y}else{qa=c[f+100>>2]|0;ra=c[f+108>>2]|0}Y=f+6128|0;_=f+5160|0;I=f+5168|0;M=(N|0)==0;H=f+421200|0;w=0;while(1){J=Q+(c[V+(w<<2)>>2]|0)|0;Z=d[473424+w|0]|0;D=a[f+4888+Z|0]|0;X=D<<24>>24;do{if(u){if(!((c[Y>>2]|0)==244&D<<24>>24<2)){na=77;break}Xe[c[f+5128+(X<<2)>>2]&4095](J,f+421200+(w<<4<<N<<1)|0,T)}else{na=77}}while(0);d:do{if((na|0)==77){na=0;D=a[f+5184+Z|0]|0;cf[c[f+4992+(X<<2)>>2]&1023](J,c[_>>2]<<w&32768,c[I>>2]<<w&16384,T);do{if((D<<24>>24|0)==1){A=w<<4;if(M){sa=e[f+421200+(A<<1)>>1]|0}else{sa=c[H+(A<<2)>>2]|0}if((sa|0)==0){ta=A;break}Xe[ra&4095](J,f+421200+(A<<N<<1)|0,T);break d}else if((D<<24>>24|0)==0){break d}else{ta=w<<4}}while(0);Xe[qa&4095](J,f+421200+(ta<<N<<1)|0,T)}}while(0);w=w+4|0;if((w|0)>=16){break c}}}if(u){w=c[f+140>>2]|0;ua=w;va=w}else{ua=c[f+96>>2]|0;va=c[f+104>>2]|0}w=f+6128|0;H=(N|0)==0;M=f+421200|0;I=f+5168|0;_=3-T|0;Y=3-((T|0)/2|0)|0;J=(4<<N)-T|0;X=0;do{Z=c[V+(X<<2)>>2]|0;D=Q+Z|0;A=d[473424+X|0]|0;W=a[f+4888+A|0]|0;m=W<<24>>24;do{if(u){if(!((c[w>>2]|0)==244&W<<24>>24<2)){na=93;break}Xe[c[f+5120+(m<<2)>>2]&4095](D,f+421200+(X<<4<<N<<1)|0,T)}else{na=93}}while(0);e:do{if((na|0)==93){na=0;do{if((W<<24>>24|0)==7|(W<<24>>24|0)==3){if((c[I>>2]&32768>>>(X>>>0)|0)!=0){wa=Q+(J+Z)|0;break}if(H){c[h>>2]=ba(d[Q+(_+Z)|0]|0,16843009)|0;wa=o;break}else{C=gHb(e[D+(Y<<1)>>1]|0,0,65537,65537)|0;c[j>>2]=C;c[j+4>>2]=F;wa=L;break}}else{wa=0}}while(0);Xe[c[f+4932+(m<<2)>>2]&4095](D,wa,T);C=a[f+5184+A|0]|0;if(C<<24>>24==0){break}if(!v){SZa(D,f+421200+(X<<4<<1)|0,T,y,0);break}$=X<<4;do{if(C<<24>>24==1){if(H){xa=e[f+421200+($<<1)>>1]|0}else{xa=c[M+($<<2)>>2]|0}if((xa|0)==0){break}Xe[va&4095](D,f+421200+($<<N<<1)|0,T);break e}}while(0);Xe[ua&4095](D,f+421200+($<<N<<1)|0,T)}}while(0);X=X+1|0;}while((X|0)<16)}}while(0);N=c[G>>2]|0;if((N|0)==0){na=190;break}y=c[B>>2]|0;do{if((c[f+177088>>2]|0)==0){ya=1}else{L=(c[f+177096>>2]|0)!=0;if((c[n>>2]&1|0)==0){ya=L&1^1;break}else{if(L){ya=1;break}else{na=190;break a}}}}while(0);if((N|0)==2){za=(e[(c[f+177072>>2]|0)+((c[p>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);Aa=c[f+4864>>2]|0;Ba=c[l>>2]|0}else{G=c[l>>2]|0;za=(G|0)>0;Aa=(c[n>>2]|0)>((c[q>>2]|0)!=0|0)|0;Ba=G}G=T+1+y|0;L=U+1+y|0;o=Ba-1|0;X=f+5176+(ya<<2)|0;M=c[X>>2]|0;H=M+(Ba*96|0)|0;if((Aa|0)==0){na=190;break}do{if(za){Y=8<<y;_=M+(o*96|0)+Y|0;J=c[_>>2]|0;I=c[_+4>>2]|0;w=(-7<<y)-G|0;D=Q+w|0;A=c[D+4>>2]|0;c[_>>2]=c[D>>2];c[_+4>>2]=A;c[D>>2]=J;c[D+4>>2]=I;if((y|0)==0){I=H;Ca=Q+(1-G)|0;Da=c[I+4>>2]|0;Ea=c[I>>2]|0;na=135;break}else{I=Y+8+(M+(o*96|0))|0;Y=c[I>>2]|0;D=c[I+4>>2]|0;J=Q+(w+8)|0;w=c[J+4>>2]|0;c[I>>2]=c[J>>2];c[I+4>>2]=w;c[J>>2]=Y;c[J+4>>2]=D;na=133;break}}else{na=133}}while(0);do{if((na|0)==133){N=H;D=c[N>>2]|0;J=c[N+4>>2]|0;N=(1<<y)-G|0;Y=Q+N|0;if((y|0)==0){Ca=Y;Da=J;Ea=D;na=135;break}c[Y>>2]=D;c[Y+4>>2]=J;J=M+(Ba*96|0)+8|0;Y=c[J+4>>2]|0;D=Q+(N+8)|0;c[D>>2]=c[J>>2];c[D+4>>2]=Y;Fa=1}}while(0);if((na|0)==135){c[Ca>>2]=Ea;c[Ca+4>>2]=Da;Fa=0}H=8<<y;Y=M+(Ba*96|0)+H|0;D=c[Y>>2]|0;J=c[Y+4>>2]|0;N=(9<<y)-G|0;w=Q+N|0;I=c[w+4>>2]|0;c[Y>>2]=c[w>>2];c[Y+4>>2]=I;c[w>>2]=D;c[w+4>>2]=J;if(Fa){J=H+8+(M+(Ba*96|0))|0;H=c[J>>2]|0;w=c[J+4>>2]|0;D=Q+(N+8)|0;N=c[D+4>>2]|0;c[J>>2]=c[D>>2];c[J+4>>2]=N;c[D>>2]=H;c[D+4>>2]=w}w=(c[l>>2]|0)+1|0;do{if((w|0)<(c[f+427400>>2]|0)){D=(c[X>>2]|0)+(w*96|0)|0;H=c[D>>2]|0;N=c[D+4>>2]|0;J=(17<<y)-G|0;I=Q+J|0;Y=c[I+4>>2]|0;c[D>>2]=c[I>>2];c[D+4>>2]=Y;c[I>>2]=H;c[I+4>>2]=N;if(!Fa){break}N=(c[X>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+8|0;I=c[N>>2]|0;H=c[N+4>>2]|0;Y=Q+(J+8)|0;J=c[Y+4>>2]|0;c[N>>2]=c[Y>>2];c[N+4>>2]=J;c[Y>>2]=I;c[Y+4>>2]=H}}while(0);X=16<<y;do{if(za){G=M+(o*96|0)+X|0;w=c[G>>2]|0;H=c[G+4>>2]|0;Y=(-7<<y)-L|0;I=R+Y|0;J=c[I+4>>2]|0;c[G>>2]=c[I>>2];c[G+4>>2]=J;c[I>>2]=w;c[I+4>>2]=H;if(Fa){H=X+8+(M+(o*96|0))|0;I=c[H>>2]|0;w=c[H+4>>2]|0;J=R+(Y+8)|0;G=c[J+4>>2]|0;c[H>>2]=c[J>>2];c[H+4>>2]=G;c[J>>2]=I;c[J+4>>2]=w}w=24<<y;J=M+(o*96|0)+w|0;I=c[J>>2]|0;G=c[J+4>>2]|0;H=S+Y|0;N=c[H+4>>2]|0;c[J>>2]=c[H>>2];c[J+4>>2]=N;c[H>>2]=I;c[H+4>>2]=G;if(!Fa){Ga=0;break}G=w+8+(M+(o*96|0))|0;w=c[G>>2]|0;H=c[G+4>>2]|0;I=S+(Y+8)|0;Y=c[I+4>>2]|0;c[G>>2]=c[I>>2];c[G+4>>2]=Y;c[I>>2]=w;c[I+4>>2]=H;Ga=1}else{Ga=Fa}}while(0);o=M+(Ba*96|0)+X|0;H=c[o>>2]|0;I=c[o+4>>2]|0;w=1-L+y|0;Y=R+w|0;G=c[Y+4>>2]|0;c[o>>2]=c[Y>>2];c[o+4>>2]=G;c[Y>>2]=H;c[Y+4>>2]=I;if(Ga){I=X+8+(M+(Ba*96|0))|0;Y=c[I>>2]|0;H=c[I+4>>2]|0;G=R+(w+8)|0;o=c[G+4>>2]|0;c[I>>2]=c[G>>2];c[I+4>>2]=o;c[G>>2]=Y;c[G+4>>2]=H}H=24<<y;G=M+(Ba*96|0)+H|0;Y=c[G>>2]|0;o=c[G+4>>2]|0;I=S+w|0;N=c[I+4>>2]|0;c[G>>2]=c[I>>2];c[G+4>>2]=N;c[I>>2]=Y;c[I+4>>2]=o;if(!Ga){na=190;break}o=H+8+(M+(Ba*96|0))|0;H=c[o>>2]|0;I=c[o+4>>2]|0;Y=S+(w+8)|0;w=c[Y+4>>2]|0;c[o>>2]=c[Y>>2];c[o+4>>2]=w;c[Y>>2]=H;c[Y+4>>2]=I;na=190}else{if(!v){na=190;break}I=c[f+1028>>2]|0;Y=f+148|0;H=c[f+1032>>2]|0;w=f+164|0;o=f+12|0;N=f+28|0;G=c[(c[r>>2]|0)+(c[p>>2]<<2)>>2]|0;J=c[B>>2]|0;D=a[f+5644|0]|0;A=D<<24>>24>-1;if(z){if(A){_=D<<24>>24;m=c[l>>2]|0;Z=(m<<4|8)+(b[f+5360>>1]>>2)|0;W=(b[f+5362>>1]>>2)+(c[n>>2]<<4)|0;C=(Z<<J)+(64<<J)+(ba(W+(m<<2&12)|0,T)|0)|0;Xe[c[O>>2]&4095]((c[f+199440+(_*2224|0)>>2]|0)+C|0,P,4);C=(ba((c[l>>2]&7)+(W>>1)|0,c[K>>2]|0)|0)+((Z>>1)+64<<J)|0;Z=c[f+199440+(_*2224|0)+4>>2]|0;Xe[c[O>>2]&4095](Z+C|0,(c[f+199440+(_*2224|0)+8>>2]|0)-Z|0,2)}do{if((G&8|0)==0){if((G&16|0)!=0){Z=I+64|0;_=H+64|0;Bda(f,0,0,8,8<<c[B>>2],Q,R,S,0,0,Z,c[Y>>2]|0,_,c[w>>2]|0,o,N,G&4096,G&16384);Bda(f,8,0,8,8<<c[B>>2],Q,R,S,0,4,Z,c[Y>>2]|0,_,c[w>>2]|0,o,N,G&8192,G&32768);break}_=f+6112|0;if((G&32|0)!=0){Z=I+64|0;C=f+152|0;W=H+64|0;m=f+168|0;da=f+16|0;aa=f+32|0;Bda(f,0,0,16,c[_>>2]<<3,Q,R,S,0,0,Z,c[C>>2]|0,W,c[m>>2]|0,da,aa,G&4096,G&16384);Bda(f,4,0,16,c[_>>2]<<3,Q,R,S,4,0,Z,c[C>>2]|0,W,c[m>>2]|0,da,aa,G&8192,G&32768);break}aa=I+128|0;da=f+156|0;m=H+128|0;W=f+172|0;C=f+20|0;Z=f+36|0;ca=f+152|0;Ha=f+168|0;Ia=f+16|0;Ja=f+32|0;Ka=I+64|0;La=H+64|0;Ma=0;do{Na=e[f+177112+(Ma<<1)>>1]|0;Oa=Ma<<2;Pa=Oa&4;Qa=Ma<<1&4;do{if((Na&8|0)==0){if((Na&16|0)!=0){Ra=Na&4096;Sa=Na&16384;Bda(f,Oa,0,4,4<<c[B>>2],Q,R,S,Pa,Qa,aa,c[ca>>2]|0,m,c[Ha>>2]|0,Ia,Ja,Ra,Sa);Bda(f,Oa|2,0,4,4<<c[B>>2],Q,R,S,Pa,Qa|2,aa,c[ca>>2]|0,m,c[Ha>>2]|0,Ia,Ja,Ra,Sa);break}if((Na&32|0)==0){Sa=Na&4096;Ra=Na&16384;Bda(f,Oa,1,4,0,Q,R,S,Pa,Qa,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Sa,Ra);Ta=Pa|2;Bda(f,Oa|1,1,4,0,Q,R,S,Ta,Qa,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Sa,Ra);Ua=Qa|2;Bda(f,Oa|2,1,4,0,Q,R,S,Pa,Ua,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Sa,Ra);Bda(f,Oa|3,1,4,0,Q,R,S,Ta,Ua,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Sa,Ra);break}else{Ra=Na&4096;Sa=Na&16384;Bda(f,Oa,0,8,c[_>>2]<<2,Q,R,S,Pa,Qa,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Ra,Sa);Bda(f,Oa|1,0,8,c[_>>2]<<2,Q,R,S,Pa|2,Qa,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Ra,Sa);break}}else{Bda(f,Oa,1,8,0,Q,R,S,Pa,Qa,Ka,c[ca>>2]|0,La,c[Ha>>2]|0,Ia,Ja,Na&4096,Na&16384)}}while(0);Ma=Ma+1|0;}while((Ma|0)<4)}else{Bda(f,0,1,16,0,Q,R,S,0,0,I|0,c[Y>>2]|0,H|0,c[w>>2]|0,o,N,G&4096,G&16384)}}while(0);M=c[B>>2]|0;y=a[f+5684|0]|0;if(!(y<<24>>24>-1)){Va=M;break}X=y<<24>>24;y=c[l>>2]|0;L=(y<<4|8)+(b[f+5520>>1]>>2)|0;Ma=(b[f+5522>>1]>>2)+(c[n>>2]<<4)|0;Ja=(L<<M)+(64<<M)+(ba(Ma+(y<<2&12)|0,c[f+6112>>2]|0)|0)|0;Xe[c[O>>2]&4095]((c[f+306192+(X*2224|0)>>2]|0)+Ja|0,c[E>>2]|0,4);Ja=(ba((c[l>>2]&7)+(Ma>>1)|0,c[K>>2]|0)|0)+((L>>1)+64<<M)|0;M=c[f+306192+(X*2224|0)+4>>2]|0;Xe[c[O>>2]&4095](M+Ja|0,(c[f+306192+(X*2224|0)+8>>2]|0)-M|0,2);na=190;break}else{if(A){M=D<<24>>24;X=c[l>>2]|0;Ja=(X<<4|8)+(b[f+5360>>1]>>2)|0;L=(b[f+5362>>1]>>2)+(c[n>>2]<<4)|0;Ma=(Ja<<J)+(64<<J)+(ba(L+(X<<2&12)|0,T)|0)|0;Xe[c[O>>2]&4095]((c[f+199440+(M*2224|0)>>2]|0)+Ma|0,P,4);Ma=(ba((c[l>>2]&7)+(L>>1)|0,c[K>>2]|0)|0)+((Ja>>1)+64<<J)|0;Ja=c[f+199440+(M*2224|0)+4>>2]|0;Xe[c[O>>2]&4095](Ja+Ma|0,(c[f+199440+(M*2224|0)+8>>2]|0)-Ja|0,2)}do{if((G&8|0)==0){if((G&16|0)!=0){Ja=I+64|0;M=H+64|0;Ada(f,0,0,8,8<<c[B>>2],Q,R,S,0,0,Ja,c[Y>>2]|0,M,c[w>>2]|0,o,N,G&4096,G&16384);Ada(f,8,0,8,8<<c[B>>2],Q,R,S,0,4,Ja,c[Y>>2]|0,M,c[w>>2]|0,o,N,G&8192,G&32768);break}M=f+6112|0;if((G&32|0)!=0){Ja=I+64|0;Ma=f+152|0;L=H+64|0;X=f+168|0;y=f+16|0;Ia=f+32|0;Ada(f,0,0,16,c[M>>2]<<3,Q,R,S,0,0,Ja,c[Ma>>2]|0,L,c[X>>2]|0,y,Ia,G&4096,G&16384);Ada(f,4,0,16,c[M>>2]<<3,Q,R,S,4,0,Ja,c[Ma>>2]|0,L,c[X>>2]|0,y,Ia,G&8192,G&32768);break}Ia=I+128|0;y=f+156|0;X=H+128|0;L=f+172|0;Ma=f+20|0;Ja=f+36|0;Ha=f+152|0;La=f+168|0;ca=f+16|0;Ka=f+32|0;Z=I+64|0;C=H+64|0;W=0;do{m=e[f+177112+(W<<1)>>1]|0;da=W<<2;aa=da&4;_=W<<1&4;do{if((m&8|0)==0){if((m&16|0)!=0){Na=m&4096;Qa=m&16384;Ada(f,da,0,4,4<<c[B>>2],Q,R,S,aa,_,Ia,c[Ha>>2]|0,X,c[La>>2]|0,ca,Ka,Na,Qa);Ada(f,da|2,0,4,4<<c[B>>2],Q,R,S,aa,_|2,Ia,c[Ha>>2]|0,X,c[La>>2]|0,ca,Ka,Na,Qa);break}if((m&32|0)==0){Qa=m&4096;Na=m&16384;Ada(f,da,1,4,0,Q,R,S,aa,_,Ia,c[y>>2]|0,X,c[L>>2]|0,Ma,Ja,Qa,Na);Pa=aa|2;Ada(f,da|1,1,4,0,Q,R,S,Pa,_,Ia,c[y>>2]|0,X,c[L>>2]|0,Ma,Ja,Qa,Na);Oa=_|2;Ada(f,da|2,1,4,0,Q,R,S,aa,Oa,Ia,c[y>>2]|0,X,c[L>>2]|0,Ma,Ja,Qa,Na);Ada(f,da|3,1,4,0,Q,R,S,Pa,Oa,Ia,c[y>>2]|0,X,c[L>>2]|0,Ma,Ja,Qa,Na);break}else{Na=m&4096;Qa=m&16384;Ada(f,da,0,8,c[M>>2]<<2,Q,R,S,aa,_,Ia,c[y>>2]|0,X,c[L>>2]|0,Ma,Ja,Na,Qa);Ada(f,da|1,0,8,c[M>>2]<<2,Q,R,S,aa|2,_,Ia,c[y>>2]|0,X,c[L>>2]|0,Ma,Ja,Na,Qa);break}}else{Ada(f,da,1,8,0,Q,R,S,aa,_,Z,c[Ha>>2]|0,C,c[La>>2]|0,ca,Ka,m&4096,m&16384)}}while(0);W=W+1|0;}while((W|0)<4)}else{Ada(f,0,1,16,0,Q,R,S,0,0,I|0,c[Y>>2]|0,H|0,c[w>>2]|0,o,N,G&4096,G&16384)}}while(0);G=c[B>>2]|0;N=a[f+5684|0]|0;if(!(N<<24>>24>-1)){Va=G;break}o=N<<24>>24;N=c[l>>2]|0;w=(N<<4|8)+(b[f+5520>>1]>>2)|0;H=(b[f+5522>>1]>>2)+(c[n>>2]<<4)|0;Y=(w<<G)+(64<<G)+(ba(H+(N<<2&12)|0,c[f+6112>>2]|0)|0)|0;Xe[c[O>>2]&4095]((c[f+306192+(o*2224|0)>>2]|0)+Y|0,c[E>>2]|0,4);Y=(ba((c[l>>2]&7)+(H>>1)|0,c[K>>2]|0)|0)+((w>>1)+64<<G)|0;G=c[f+306192+(o*2224|0)+4>>2]|0;Xe[c[O>>2]&4095](G+Y|0,(c[f+306192+(o*2224|0)+8>>2]|0)-G|0,2);na=190;break}}}while(0);if((na|0)==190){Va=c[B>>2]|0}f:do{if((s&1|0)==0){if(!v){O=ea&1;K=0;while(1){l=f+421200+(K<<4<<1)|0;if((a[(d[473424+K|0]|0)+(f+5184)|0]|0)==0){if((b[l>>1]|0)!=0){na=219}}else{na=219}if((na|0)==219){na=0;SZa(Q+(c[V+(K<<2)>>2]|0)|0,l,T,c[t>>2]|0,O)}K=K+1|0;if((K|0)>=16){break f}}}if((s&2|0)==0){if((c[f+426564>>2]&15|0)==0){break}K=(s&16777216|0)!=0;if(!u){if(K){le[c[f+116>>2]&1023](Q,V,f+421200|0,T,f+5184|0);break}else{le[c[f+112>>2]&1023](Q,V,f+421200|0,T,f+5184|0);break}}O=K?4:1;l=c[(K?f+136|0:f+140|0)>>2]|0;K=0;while(1){if((a[(d[473424+K|0]|0)+(f+5184)|0]|0)!=0){Xe[l&4095](Q+(c[V+(K<<2)>>2]|0)|0,f+421200+(K<<4<<Va<<1)|0,T)}K=K+O|0;if((K|0)>=16){break f}}}if(!u){le[c[f+124>>2]&1023](Q,V,f+421200|0,T,f+5184|0);break}do{if((c[f+6128>>2]|0)==244){K=c[f+4836>>2]|0;if(!((K-1|0)>>>0<2>>>0)){break}cf[c[f+5148+(K<<2)>>2]&1023](Q,V,f+421200|0,T);break f}}while(0);K=(Va|0)==0;O=f+421200|0;l=f+140|0;E=0;do{n=E<<4;if((a[(d[473424+E|0]|0)+(f+5184)|0]|0)==0){if(K){Wa=e[f+421200+(n<<1)>>1]|0}else{Wa=c[O+(n<<2)>>2]|0}if((Wa|0)!=0){na=205}}else{na=205}if((na|0)==205){na=0;Xe[c[l>>2]&4095](Q+(c[V+(E<<2)>>2]|0)|0,f+421200+(n<<Va<<1)|0,T)}E=E+1|0;}while((E|0)<16)}}while(0);if((c[f+426564>>2]&48|0)==0){i=g;return}T=k|0;c[T>>2]=R;Va=k+4|0;c[Va>>2]=S;if(!u){if(v){v=c[f+4756>>2]|0;if(z){Xa=v+3|0;Ya=(c[f+4760>>2]|0)+3|0}else{Xa=v;Ya=c[f+4760>>2]|0}if((a[f+5224|0]|0)!=0){ne[c[f+132>>2]&1023](f+421200+(256<<c[B>>2]<<1)|0,c[(c[f+177020+((ea?1:4)<<2)>>2]|0)+(Xa<<6)>>2]|0)}if((a[f+5264|0]|0)!=0){ne[c[f+132>>2]&1023](f+421200+(512<<c[B>>2]<<1)|0,c[(c[f+177020+((ea?2:5)<<2)>>2]|0)+(Ya<<6)>>2]|0)}le[c[f+120>>2]&1023](T,V,f+421200|0,U,f+5184|0);i=g;return}T=f+132|0;ne[c[T>>2]&1023](f+421712|0,c[(c[f+177020+((ea?1:4)<<2)>>2]|0)+(c[f+4756>>2]<<6)>>2]|0);ne[c[T>>2]&1023](f+422224|0,c[(c[f+177020+((ea?2:5)<<2)>>2]|0)+(c[f+4760>>2]<<6)>>2]|0);T=1;do{Ya=T<<4;do{if((Ya|0)<(Ya|4|0)){Xa=k+(T-1<<2)|0;v=f+421200+(T<<8<<1)|0;if((a[(d[473424+Ya|0]|0)+(f+5184)|0]|0)==0){if((b[v>>1]|0)!=0){na=259}}else{na=259}if((na|0)==259){na=0;SZa((c[Xa>>2]|0)+(c[V+(Ya<<2)>>2]|0)|0,v,U,(d[(c[t>>2]|0)+1207828|0]|0)-12|0,2)}v=Ya|1;u=f+421200+(v<<4<<1)|0;if((a[(d[473424+v|0]|0)+(f+5184)|0]|0)==0){if((b[u>>1]|0)!=0){na=298}}else{na=298}if((na|0)==298){na=0;SZa((c[Xa>>2]|0)+(c[V+(v<<2)>>2]|0)|0,u,U,(d[(c[t>>2]|0)+1207828|0]|0)-12|0,2)}u=v+1|0;v=f+421200+(u<<4<<1)|0;if((a[(d[473424+u|0]|0)+(f+5184)|0]|0)==0){if((b[v>>1]|0)!=0){na=301}}else{na=301}if((na|0)==301){na=0;SZa((c[Xa>>2]|0)+(c[V+(u<<2)>>2]|0)|0,v,U,(d[(c[t>>2]|0)+1207828|0]|0)-12|0,2)}v=Ya|3;u=f+421200+(v<<4<<1)|0;if((a[(d[473424+v|0]|0)+(f+5184)|0]|0)==0){if((b[u>>1]|0)==0){break}}SZa((c[Xa>>2]|0)+(c[V+(v<<2)>>2]|0)|0,u,U,(d[(c[t>>2]|0)+1207828|0]|0)-12|0,2)}}while(0);T=T+1|0;}while((T|0)<3);i=g;return}do{if(ea){if((c[f+6128>>2]|0)!=244){break}T=f+4832|0;t=c[T>>2]|0;if(!((t-1|0)>>>0<2>>>0)){break}cf[c[f+5136+(t<<2)>>2]&1023](R,V+64|0,f+421200+(256<<c[B>>2]<<1)|0,U);cf[c[f+5136+(c[T>>2]<<2)>>2]&1023](c[Va>>2]|0,V+128|0,f+421200+(512<<c[B>>2]<<1)|0,U);i=g;return}}while(0);Va=c[f+140>>2]|0;R=f+421200|0;ea=1;do{T=ea<<4;t=T|4;do{if((T|0)<(t|0)){Ya=k+(ea-1<<2)|0;u=c[B>>2]|0;v=ea<<8;if((a[(d[473424+T|0]|0)+(f+5184)|0]|0)==0){if((u|0)==0){Za=e[f+421200+(v<<1)>>1]|0}else{Za=c[R+(v<<2)>>2]|0}if((Za|0)!=0){na=234}}else{na=234}if((na|0)==234){na=0;Xe[Va&4095]((c[Ya>>2]|0)+(c[V+(T<<2)>>2]|0)|0,f+421200+(v<<u<<1)|0,U)}u=T|1;v=c[B>>2]|0;Xa=u<<4;if((a[(d[473424+u|0]|0)+(f+5184)|0]|0)==0){if((v|0)==0){_a=e[f+421200+(Xa<<1)>>1]|0}else{_a=c[R+(Xa<<2)>>2]|0}if((_a|0)!=0){na=267}}else{na=267}if((na|0)==267){na=0;Xe[Va&4095]((c[Ya>>2]|0)+(c[V+(u<<2)>>2]|0)|0,f+421200+(Xa<<v<<1)|0,U)}v=u+1|0;u=c[B>>2]|0;Xa=v<<4;if((a[(d[473424+v|0]|0)+(f+5184)|0]|0)==0){if((u|0)==0){$a=e[f+421200+(Xa<<1)>>1]|0}else{$a=c[R+(Xa<<2)>>2]|0}if(($a|0)!=0){na=273}}else{na=273}if((na|0)==273){na=0;Xe[Va&4095]((c[Ya>>2]|0)+(c[V+(v<<2)>>2]|0)|0,f+421200+(Xa<<u<<1)|0,U)}u=T|3;Xa=c[B>>2]|0;v=u<<4;if((a[(d[473424+u|0]|0)+(f+5184)|0]|0)==0){if((Xa|0)==0){ab=e[f+421200+(v<<1)>>1]|0}else{ab=c[R+(v<<2)>>2]|0}if((ab|0)==0){break}}Xe[Va&4095]((c[Ya>>2]|0)+(c[V+(u<<2)>>2]|0)|0,f+421200+(v<<Xa<<1)|0,U)}}while(0);do{if(z){if((t|0)>=(T|8|0)){break}Xa=k+(ea-1<<2)|0;v=t+4|0;u=c[B>>2]|0;Ya=t<<4;if((a[(d[473424+v|0]|0)+(f+5184)|0]|0)==0){if((u|0)==0){bb=e[f+421200+(Ya<<1)>>1]|0}else{bb=c[R+(Ya<<2)>>2]|0}if((bb|0)!=0){na=243}}else{na=243}if((na|0)==243){na=0;Xe[Va&4095]((c[Xa>>2]|0)+(c[V+(v<<2)>>2]|0)|0,f+421200+(Ya<<u<<1)|0,U)}u=T|5;Ya=u+4|0;v=c[B>>2]|0;S=u<<4;if((a[(d[473424+Ya|0]|0)+(f+5184)|0]|0)==0){if((v|0)==0){cb=e[f+421200+(S<<1)>>1]|0}else{cb=c[R+(S<<2)>>2]|0}if((cb|0)!=0){na=284}}else{na=284}if((na|0)==284){na=0;Xe[Va&4095]((c[Xa>>2]|0)+(c[V+(Ya<<2)>>2]|0)|0,f+421200+(S<<v<<1)|0,U)}v=u+5|0;S=c[B>>2]|0;Ya=(u<<4)+16|0;if((a[(d[473424+v|0]|0)+(f+5184)|0]|0)==0){if((S|0)==0){db=e[f+421200+(Ya<<1)>>1]|0}else{db=c[R+(Ya<<2)>>2]|0}if((db|0)!=0){na=290}}else{na=290}if((na|0)==290){na=0;Xe[Va&4095]((c[Xa>>2]|0)+(c[V+(v<<2)>>2]|0)|0,f+421200+(Ya<<S<<1)|0,U)}S=T|7;Ya=S+4|0;v=c[B>>2]|0;u=S<<4;if((a[(d[473424+Ya|0]|0)+(f+5184)|0]|0)==0){if((v|0)==0){eb=e[f+421200+(u<<1)>>1]|0}else{eb=c[R+(u<<2)>>2]|0}if((eb|0)==0){break}}Xe[Va&4095]((c[Xa>>2]|0)+(c[V+(Ya<<2)>>2]|0)|0,f+421200+(u<<v<<1)|0,U)}}while(0);ea=ea+1|0;}while((ea|0)<3);i=g;return}function ada(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=f+427376|0;l=c[k>>2]|0;m=f+427380|0;n=c[m>>2]|0;o=f+427412|0;p=c[o>>2]|0;q=f+4064|0;r=c[(c[q>>2]|0)+(p<<2)>>2]|0;s=f+5716|0;t=(c[f+6136>>2]|0)==2;u=c[f+2528>>2]|0;v=f+4776|0;w=c[v>>2]|0;x=(ba(w,n)|0)+(l<<1)<<4;y=u+x|0;z=c[f+2532>>2]|0;A=f+4780|0;B=(ba(ba(16>>>((c[f+4788>>2]|0)>>>0),n)|0,c[A>>2]|0)|0)+(l<<4)|0;n=z+B|0;C=c[f+2536>>2]|0;D=C+B|0;E=f+8|0;G=u+((ba(w,l<<2&12)|0)+128+x)|0;Xe[c[E>>2]&4095](G,w,4);w=z+(B+128+(ba(c[k>>2]&7,c[A>>2]|0)|0))|0;Xe[c[E>>2]&4095](w,D-n|0,2);a[(c[f+199432>>2]|0)+p|0]=c[f+199428>>2];p=c[v>>2]|0;w=f+6112|0;c[w>>2]=p;G=c[A>>2]|0;c[f+6116>>2]=G;l=(r&7|0)!=0;do{if(l){H=f+427420|0;I=c[H>>2]|0;if((I|0)==2){J=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);K=c[f+4864>>2]|0;L=c[k>>2]|0;M=5}else if((I|0)!=0){I=c[k>>2]|0;J=(I|0)>0;K=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;L=I;M=5}do{if((M|0)==5){I=L-1|0;N=f+5180|0;O=c[N>>2]|0;if((K|0)==0){break}if(J){P=O+(I*96|0)+16|0;Q=c[P>>2]|0;R=c[P+4>>2]|0;S=-16-p|0;T=u+(S+x)|0;U=c[T+4>>2]|0;c[P>>2]=c[T>>2];c[P+4>>2]=U;c[T>>2]=Q;c[T+4>>2]=R;R=O+(I*96|0)+24|0;T=c[R>>2]|0;Q=c[R+4>>2]|0;U=x|8;P=u+(U+S)|0;S=c[P+4>>2]|0;c[R>>2]=c[P>>2];c[R+4>>2]=S;c[P>>2]=T;c[P+4>>2]=Q;V=U}else{V=x|8}U=O+(L*96|0)|0;Q=c[U>>2]|0;P=c[U+4>>2]|0;T=u+(x-p)|0;S=c[T+4>>2]|0;c[U>>2]=c[T>>2];c[U+4>>2]=S;c[T>>2]=Q;c[T+4>>2]=P;P=O+(L*96|0)+8|0;T=c[P>>2]|0;Q=c[P+4>>2]|0;S=u+(V-p)|0;U=c[S+4>>2]|0;c[P>>2]=c[S>>2];c[P+4>>2]=U;c[S>>2]=T;c[S+4>>2]=Q;Q=O+(L*96|0)+16|0;S=c[Q>>2]|0;T=c[Q+4>>2]|0;U=16-p|0;P=u+(U+x)|0;R=c[P+4>>2]|0;c[Q>>2]=c[P>>2];c[Q+4>>2]=R;c[P>>2]=S;c[P+4>>2]=T;T=O+(L*96|0)+24|0;P=c[T>>2]|0;S=c[T+4>>2]|0;R=u+(V+U)|0;U=c[R+4>>2]|0;c[T>>2]=c[R>>2];c[T+4>>2]=U;c[R>>2]=P;c[R+4>>2]=S;S=(c[k>>2]|0)+1|0;if((S|0)<(c[f+427400>>2]|0)){R=(c[N>>2]|0)+(S*96|0)|0;S=c[R>>2]|0;P=c[R+4>>2]|0;U=32-p|0;T=u+(U+x)|0;Q=c[T+4>>2]|0;c[R>>2]=c[T>>2];c[R+4>>2]=Q;c[T>>2]=S;c[T+4>>2]=P;P=(c[N>>2]|0)+(((c[k>>2]|0)+1|0)*96|0)+8|0;N=c[P>>2]|0;T=c[P+4>>2]|0;S=u+(V+U)|0;U=c[S+4>>2]|0;c[P>>2]=c[S>>2];c[P+4>>2]=U;c[S>>2]=N;c[S+4>>2]=T}if(J){T=O+(I*96|0)+32|0;S=c[T>>2]|0;N=c[T+4>>2]|0;U=-16-G|0;P=U+B|0;Q=z+P|0;R=c[Q+4>>2]|0;c[T>>2]=c[Q>>2];c[T+4>>2]=R;c[Q>>2]=S;c[Q+4>>2]=N;N=O+(I*96|0)+40|0;Q=c[N>>2]|0;S=c[N+4>>2]|0;R=U+8+B|0;U=z+R|0;T=c[U+4>>2]|0;c[N>>2]=c[U>>2];c[N+4>>2]=T;c[U>>2]=Q;c[U+4>>2]=S;S=O+(I*96|0)+48|0;U=c[S>>2]|0;Q=c[S+4>>2]|0;T=C+P|0;P=c[T+4>>2]|0;c[S>>2]=c[T>>2];c[S+4>>2]=P;c[T>>2]=U;c[T+4>>2]=Q;Q=O+(I*96|0)+56|0;I=c[Q>>2]|0;T=c[Q+4>>2]|0;U=C+R|0;R=c[U+4>>2]|0;c[Q>>2]=c[U>>2];c[Q+4>>2]=R;c[U>>2]=I;c[U+4>>2]=T}T=O+(L*96|0)+32|0;U=c[T>>2]|0;I=c[T+4>>2]|0;R=B-G|0;Q=z+R|0;P=c[Q+4>>2]|0;c[T>>2]=c[Q>>2];c[T+4>>2]=P;c[Q>>2]=U;c[Q+4>>2]=I;I=O+(L*96|0)+40|0;Q=c[I>>2]|0;U=c[I+4>>2]|0;P=8-G+B|0;T=z+P|0;S=c[T+4>>2]|0;c[I>>2]=c[T>>2];c[I+4>>2]=S;c[T>>2]=Q;c[T+4>>2]=U;U=O+(L*96|0)+48|0;T=c[U>>2]|0;Q=c[U+4>>2]|0;S=C+R|0;R=c[S+4>>2]|0;c[U>>2]=c[S>>2];c[U+4>>2]=R;c[S>>2]=T;c[S+4>>2]=Q;Q=O+(L*96|0)+56|0;O=c[Q>>2]|0;S=c[Q+4>>2]|0;T=C+P|0;P=c[T+4>>2]|0;c[Q>>2]=c[T>>2];c[Q+4>>2]=P;c[T>>2]=O;c[T+4>>2]=S}}while(0);S=f+4832|0;ne[c[f+5040+(c[S>>2]<<2)>>2]&1023](n,G);ne[c[f+5040+(c[S>>2]<<2)>>2]&1023](D,G);S=h;T=c[f+4792>>2]|0;a:do{if((r&1|0)==0){ne[c[f+5084+(c[f+4836>>2]<<2)>>2]&1023](y,p);if((a[f+5184|0]|0)==0){break}Xe[c[f+128>>2]&4095](f+421200|0,f+424272|0,c[(c[f+177020>>2]|0)+(T<<6)>>2]|0)}else{if((r&16777216|0)!=0){O=c[f+108>>2]|0;P=c[f+100>>2]|0;Q=f+5160|0;R=f+5168|0;U=f+421200|0;I=0;while(1){N=u+((c[f+5716+(I<<2)>>2]|0)+x)|0;W=d[473424+I|0]|0;X=a[f+5184+W|0]|0;cf[c[f+4992+(a[f+4888+W|0]<<24>>24<<2)>>2]&1023](N,c[Q>>2]<<I&32768,c[R>>2]<<I&16384,p);do{if((X<<24>>24|0)==1){W=I<<4;if((c[U+(W<<2)>>2]|0)==0){Y=W;M=21;break}Xe[O&4095](N,f+421200+(I<<5<<1)|0,p)}else if((X<<24>>24|0)!=0){Y=I<<4;M=21}}while(0);if((M|0)==21){M=0;Xe[P&4095](N,f+421200+(Y<<1<<1)|0,p)}I=I+4|0;if((I|0)>=16){break a}}}I=c[f+104>>2]|0;P=c[f+96>>2]|0;O=f+421200|0;U=f+5168|0;R=3-((p|0)/2|0)|0;Q=(x|8)-p|0;X=0;do{W=c[f+5716+(X<<2)>>2]|0;Z=u+(W+x)|0;_=d[473424+X|0]|0;$=a[f+4888+_|0]|0;aa=$<<24>>24;do{if(($<<24>>24|0)==7|($<<24>>24|0)==3){if((c[U>>2]&32768>>>(X>>>0)|0)==0){ca=gHb(e[Z+(R<<1)>>1]|0,0,65537,65537)|0;c[h>>2]=ca;c[h+4>>2]=F;da=S;break}else{da=u+(Q+W)|0;break}}else{da=0}}while(0);Xe[c[f+4932+(aa<<2)>>2]&4095](Z,da,p);W=a[f+5184+_|0]|0;do{if((W<<24>>24|0)==1){if((c[O+(X<<4<<2)>>2]|0)==0){M=31;break}Xe[I&4095](Z,f+421200+(X<<5<<1)|0,p)}else if((W<<24>>24|0)!=0){M=31}}while(0);if((M|0)==31){M=0;Xe[P&4095](Z,f+421200+(X<<5<<1)|0,p)}X=X+1|0;}while((X|0)<16)}}while(0);S=c[H>>2]|0;if((S|0)==2){ea=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);fa=c[f+4864>>2]|0;ga=c[k>>2]|0}else if((S|0)==0){break}else{S=c[k>>2]|0;ea=(S|0)>0;fa=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;ga=S}S=ga-1|0;T=f+5180|0;X=c[T>>2]|0;if((fa|0)==0){break}if(ea){P=X+(S*96|0)+16|0;I=c[P>>2]|0;O=c[P+4>>2]|0;Q=-16-p|0;R=u+(Q+x)|0;U=c[R+4>>2]|0;c[P>>2]=c[R>>2];c[P+4>>2]=U;c[R>>2]=I;c[R+4>>2]=O;O=X+(S*96|0)+24|0;R=c[O>>2]|0;I=c[O+4>>2]|0;U=x|8;P=u+(U+Q)|0;Q=c[P+4>>2]|0;c[O>>2]=c[P>>2];c[O+4>>2]=Q;c[P>>2]=R;c[P+4>>2]=I;ha=U}else{ha=x|8}U=X+(ga*96|0)|0;I=c[U+4>>2]|0;P=u+(x-p)|0;c[P>>2]=c[U>>2];c[P+4>>2]=I;I=X+(ga*96|0)+8|0;P=c[I+4>>2]|0;U=u+(ha-p)|0;c[U>>2]=c[I>>2];c[U+4>>2]=P;P=X+(ga*96|0)+16|0;U=c[P>>2]|0;I=c[P+4>>2]|0;R=16-p|0;Q=u+(R+x)|0;O=c[Q+4>>2]|0;c[P>>2]=c[Q>>2];c[P+4>>2]=O;c[Q>>2]=U;c[Q+4>>2]=I;I=X+(ga*96|0)+24|0;Q=c[I>>2]|0;U=c[I+4>>2]|0;O=u+(ha+R)|0;R=c[O+4>>2]|0;c[I>>2]=c[O>>2];c[I+4>>2]=R;c[O>>2]=Q;c[O+4>>2]=U;U=(c[k>>2]|0)+1|0;if((U|0)<(c[f+427400>>2]|0)){O=(c[T>>2]|0)+(U*96|0)|0;U=c[O>>2]|0;Q=c[O+4>>2]|0;R=32-p|0;I=u+(R+x)|0;P=c[I+4>>2]|0;c[O>>2]=c[I>>2];c[O+4>>2]=P;c[I>>2]=U;c[I+4>>2]=Q;Q=(c[T>>2]|0)+(((c[k>>2]|0)+1|0)*96|0)+8|0;T=c[Q>>2]|0;I=c[Q+4>>2]|0;U=u+(ha+R)|0;R=c[U+4>>2]|0;c[Q>>2]=c[U>>2];c[Q+4>>2]=R;c[U>>2]=T;c[U+4>>2]=I}if(ea){I=X+(S*96|0)+32|0;U=c[I>>2]|0;T=c[I+4>>2]|0;R=-16-G|0;Q=R+B|0;P=z+Q|0;O=c[P+4>>2]|0;c[I>>2]=c[P>>2];c[I+4>>2]=O;c[P>>2]=U;c[P+4>>2]=T;T=X+(S*96|0)+40|0;P=c[T>>2]|0;U=c[T+4>>2]|0;O=R+8+B|0;R=z+O|0;I=c[R+4>>2]|0;c[T>>2]=c[R>>2];c[T+4>>2]=I;c[R>>2]=P;c[R+4>>2]=U;U=X+(S*96|0)+48|0;R=c[U>>2]|0;P=c[U+4>>2]|0;I=C+Q|0;Q=c[I+4>>2]|0;c[U>>2]=c[I>>2];c[U+4>>2]=Q;c[I>>2]=R;c[I+4>>2]=P;P=X+(S*96|0)+56|0;S=c[P>>2]|0;I=c[P+4>>2]|0;R=C+O|0;O=c[R+4>>2]|0;c[P>>2]=c[R>>2];c[P+4>>2]=O;c[R>>2]=S;c[R+4>>2]=I}I=X+(ga*96|0)+32|0;R=c[I>>2]|0;S=c[I+4>>2]|0;O=B-G|0;P=z+O|0;Q=c[P+4>>2]|0;c[I>>2]=c[P>>2];c[I+4>>2]=Q;c[P>>2]=R;c[P+4>>2]=S;S=X+(ga*96|0)+40|0;P=c[S>>2]|0;R=c[S+4>>2]|0;Q=8-G+B|0;I=z+Q|0;U=c[I+4>>2]|0;c[S>>2]=c[I>>2];c[S+4>>2]=U;c[I>>2]=P;c[I+4>>2]=R;R=X+(ga*96|0)+48|0;I=c[R>>2]|0;P=c[R+4>>2]|0;U=C+O|0;O=c[U+4>>2]|0;c[R>>2]=c[U>>2];c[R+4>>2]=O;c[U>>2]=I;c[U+4>>2]=P;P=X+(ga*96|0)+56|0;X=c[P>>2]|0;U=c[P+4>>2]|0;I=C+Q|0;Q=c[I+4>>2]|0;c[P>>2]=c[I>>2];c[P+4>>2]=Q;c[I>>2]=X;c[I+4>>2]=U}else{U=c[f+1028>>2]|0;I=f+148|0;X=c[f+1032>>2]|0;Q=f+164|0;P=f+12|0;O=f+28|0;R=c[(c[q>>2]|0)+(c[o>>2]<<2)>>2]|0;S=a[f+5644|0]|0;T=S<<24>>24>-1;if(t){if(T){W=S<<24>>24;_=c[k>>2]|0;aa=(_<<4|8)+(b[f+5360>>1]>>2)|0;$=(b[f+5362>>1]>>2)+(c[m>>2]<<4)|0;N=(aa<<1)+128+(ba($+(_<<2&12)|0,p)|0)|0;Xe[c[E>>2]&4095]((c[f+199440+(W*2224|0)>>2]|0)+N|0,p,4);N=(ba((c[k>>2]&7)+($>>1)|0,c[A>>2]|0)|0)+(aa+128&-2)|0;aa=c[f+199440+(W*2224|0)+4>>2]|0;Xe[c[E>>2]&4095](aa+N|0,(c[f+199440+(W*2224|0)+8>>2]|0)-aa|0,2)}do{if((R&8|0)==0){if((R&16|0)!=0){aa=U+64|0;W=X+64|0;zda(f,0,0,8,16,y,n,D,0,0,aa,c[I>>2]|0,W,c[Q>>2]|0,P,O,R&4096,R&16384);zda(f,8,0,8,16,y,n,D,0,4,aa,c[I>>2]|0,W,c[Q>>2]|0,P,O,R&8192,R&32768);break}if((R&32|0)!=0){W=U+64|0;aa=f+152|0;N=X+64|0;$=f+168|0;_=f+16|0;ca=f+32|0;zda(f,0,0,16,c[w>>2]<<3,y,n,D,0,0,W,c[aa>>2]|0,N,c[$>>2]|0,_,ca,R&4096,R&16384);zda(f,4,0,16,c[w>>2]<<3,y,n,D,4,0,W,c[aa>>2]|0,N,c[$>>2]|0,_,ca,R&8192,R&32768);break}ca=U+128|0;_=f+156|0;$=X+128|0;N=f+172|0;aa=f+20|0;W=f+36|0;ia=f+152|0;ja=f+168|0;ka=f+16|0;la=f+32|0;ma=U+64|0;na=X+64|0;oa=0;do{pa=e[f+177112+(oa<<1)>>1]|0;qa=oa<<2;ra=qa&4;sa=oa<<1&4;do{if((pa&8|0)==0){if((pa&16|0)!=0){ta=pa&4096;ua=pa&16384;zda(f,qa,0,4,8,y,n,D,ra,sa,ca,c[ia>>2]|0,$,c[ja>>2]|0,ka,la,ta,ua);zda(f,qa|2,0,4,8,y,n,D,ra,sa|2,ca,c[ia>>2]|0,$,c[ja>>2]|0,ka,la,ta,ua);break}if((pa&32|0)==0){ua=pa&4096;ta=pa&16384;zda(f,qa,1,4,0,y,n,D,ra,sa,ca,c[_>>2]|0,$,c[N>>2]|0,aa,W,ua,ta);va=ra|2;zda(f,qa|1,1,4,0,y,n,D,va,sa,ca,c[_>>2]|0,$,c[N>>2]|0,aa,W,ua,ta);wa=sa|2;zda(f,qa|2,1,4,0,y,n,D,ra,wa,ca,c[_>>2]|0,$,c[N>>2]|0,aa,W,ua,ta);zda(f,qa|3,1,4,0,y,n,D,va,wa,ca,c[_>>2]|0,$,c[N>>2]|0,aa,W,ua,ta);break}else{ta=pa&4096;ua=pa&16384;zda(f,qa,0,8,c[w>>2]<<2,y,n,D,ra,sa,ca,c[_>>2]|0,$,c[N>>2]|0,aa,W,ta,ua);zda(f,qa|1,0,8,c[w>>2]<<2,y,n,D,ra|2,sa,ca,c[_>>2]|0,$,c[N>>2]|0,aa,W,ta,ua);break}}else{zda(f,qa,1,8,0,y,n,D,ra,sa,ma,c[ia>>2]|0,na,c[ja>>2]|0,ka,la,pa&4096,pa&16384)}}while(0);oa=oa+1|0;}while((oa|0)<4)}else{zda(f,0,1,16,0,y,n,D,0,0,U|0,c[I>>2]|0,X|0,c[Q>>2]|0,P,O,R&4096,R&16384)}}while(0);H=a[f+5684|0]|0;if(!(H<<24>>24>-1)){break}oa=H<<24>>24;H=c[k>>2]|0;la=(H<<4|8)+(b[f+5520>>1]>>2)|0;ka=(b[f+5522>>1]>>2)+(c[m>>2]<<4)|0;ja=(la<<1)+128+(ba(ka+(H<<2&12)|0,c[w>>2]|0)|0)|0;Xe[c[E>>2]&4095]((c[f+306192+(oa*2224|0)>>2]|0)+ja|0,c[v>>2]|0,4);ja=(ba((c[k>>2]&7)+(ka>>1)|0,c[A>>2]|0)|0)+(la+128&-2)|0;la=c[f+306192+(oa*2224|0)+4>>2]|0;Xe[c[E>>2]&4095](la+ja|0,(c[f+306192+(oa*2224|0)+8>>2]|0)-la|0,2);break}else{if(T){la=S<<24>>24;oa=c[k>>2]|0;ja=(oa<<4|8)+(b[f+5360>>1]>>2)|0;ka=(b[f+5362>>1]>>2)+(c[m>>2]<<4)|0;H=(ja<<1)+128+(ba(ka+(oa<<2&12)|0,p)|0)|0;Xe[c[E>>2]&4095]((c[f+199440+(la*2224|0)>>2]|0)+H|0,p,4);H=(ba((c[k>>2]&7)+(ka>>1)|0,c[A>>2]|0)|0)+(ja+128&-2)|0;ja=c[f+199440+(la*2224|0)+4>>2]|0;Xe[c[E>>2]&4095](ja+H|0,(c[f+199440+(la*2224|0)+8>>2]|0)-ja|0,2)}do{if((R&8|0)==0){if((R&16|0)!=0){ja=U+64|0;la=X+64|0;yda(f,0,0,8,16,y,n,D,0,0,ja,c[I>>2]|0,la,c[Q>>2]|0,P,O,R&4096,R&16384);yda(f,8,0,8,16,y,n,D,0,4,ja,c[I>>2]|0,la,c[Q>>2]|0,P,O,R&8192,R&32768);break}if((R&32|0)!=0){la=U+64|0;ja=f+152|0;H=X+64|0;ka=f+168|0;oa=f+16|0;na=f+32|0;yda(f,0,0,16,c[w>>2]<<3,y,n,D,0,0,la,c[ja>>2]|0,H,c[ka>>2]|0,oa,na,R&4096,R&16384);yda(f,4,0,16,c[w>>2]<<3,y,n,D,4,0,la,c[ja>>2]|0,H,c[ka>>2]|0,oa,na,R&8192,R&32768);break}na=U+128|0;oa=f+156|0;ka=X+128|0;H=f+172|0;ja=f+20|0;la=f+36|0;ia=f+152|0;ma=f+168|0;W=f+16|0;aa=f+32|0;N=U+64|0;$=X+64|0;_=0;do{ca=e[f+177112+(_<<1)>>1]|0;pa=_<<2;sa=pa&4;ra=_<<1&4;do{if((ca&8|0)==0){if((ca&16|0)!=0){qa=ca&4096;Z=ca&16384;yda(f,pa,0,4,8,y,n,D,sa,ra,na,c[ia>>2]|0,ka,c[ma>>2]|0,W,aa,qa,Z);yda(f,pa|2,0,4,8,y,n,D,sa,ra|2,na,c[ia>>2]|0,ka,c[ma>>2]|0,W,aa,qa,Z);break}if((ca&32|0)==0){Z=ca&4096;qa=ca&16384;yda(f,pa,1,4,0,y,n,D,sa,ra,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,Z,qa);ua=sa|2;yda(f,pa|1,1,4,0,y,n,D,ua,ra,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,Z,qa);ta=ra|2;yda(f,pa|2,1,4,0,y,n,D,sa,ta,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,Z,qa);yda(f,pa|3,1,4,0,y,n,D,ua,ta,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,Z,qa);break}else{qa=ca&4096;Z=ca&16384;yda(f,pa,0,8,c[w>>2]<<2,y,n,D,sa,ra,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,qa,Z);yda(f,pa|1,0,8,c[w>>2]<<2,y,n,D,sa|2,ra,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,qa,Z);break}}else{yda(f,pa,1,8,0,y,n,D,sa,ra,N,c[ia>>2]|0,$,c[ma>>2]|0,W,aa,ca&4096,ca&16384)}}while(0);_=_+1|0;}while((_|0)<4)}else{yda(f,0,1,16,0,y,n,D,0,0,U|0,c[I>>2]|0,X|0,c[Q>>2]|0,P,O,R&4096,R&16384)}}while(0);R=a[f+5684|0]|0;if(!(R<<24>>24>-1)){break}O=R<<24>>24;R=c[k>>2]|0;P=(R<<4|8)+(b[f+5520>>1]>>2)|0;Q=(b[f+5522>>1]>>2)+(c[m>>2]<<4)|0;X=(P<<1)+128+(ba(Q+(R<<2&12)|0,c[w>>2]|0)|0)|0;Xe[c[E>>2]&4095]((c[f+306192+(O*2224|0)>>2]|0)+X|0,c[v>>2]|0,4);X=(ba((c[k>>2]&7)+(Q>>1)|0,c[A>>2]|0)|0)+(P+128&-2)|0;P=c[f+306192+(O*2224|0)+4>>2]|0;Xe[c[E>>2]&4095](P+X|0,(c[f+306192+(O*2224|0)+8>>2]|0)-P|0,2);break}}}while(0);do{if((r&1|0)==0){if((r&2|0)!=0){le[c[f+124>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}if((c[f+426564>>2]&15|0)==0){break}if((r&16777216|0)==0){le[c[f+112>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}else{le[c[f+116>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}}}while(0);if((c[f+426564>>2]&48|0)==0){i=g;return}p=j|0;c[p>>2]=n;c[j+4>>2]=D;D=c[f+4756>>2]|0;if(t){xa=D+3|0;ya=(c[f+4760>>2]|0)+3|0}else{xa=D;ya=c[f+4760>>2]|0}if((a[f+5224|0]|0)!=0){ne[c[f+132>>2]&1023](f+422224|0,c[(c[f+177020+((l?1:4)<<2)>>2]|0)+(xa<<6)>>2]|0)}if((a[f+5264|0]|0)!=0){ne[c[f+132>>2]&1023](f+423248|0,c[(c[f+177020+((l?2:5)<<2)>>2]|0)+(ya<<6)>>2]|0)}le[c[f+120>>2]&1023](p,s,f+421200|0,G,f+5184|0);i=g;return}function bda(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=f+427376|0;l=c[k>>2]|0;m=f+427380|0;n=c[m>>2]|0;o=f+427412|0;p=c[o>>2]|0;q=f+4064|0;r=c[(c[q>>2]|0)+(p<<2)>>2]|0;s=f+5716|0;t=(c[f+6136>>2]|0)==2;u=c[f+2528>>2]|0;v=f+4776|0;w=c[v>>2]|0;x=(ba(w,n)|0)+l<<4;y=u+x|0;z=c[f+2532>>2]|0;A=f+4780|0;B=(ba(ba(16>>>((c[f+4788>>2]|0)>>>0),n)|0,c[A>>2]|0)|0)+(l<<3)|0;n=z+B|0;C=c[f+2536>>2]|0;D=C+B|0;E=f+8|0;F=u+((ba(w,l<<2&12)|0)+64+x)|0;Xe[c[E>>2]&4095](F,w,4);w=z+(B+64+(ba(c[k>>2]&7,c[A>>2]|0)|0))|0;Xe[c[E>>2]&4095](w,D-n|0,2);a[(c[f+199432>>2]|0)+p|0]=c[f+199428>>2];p=c[v>>2]|0;w=f+6112|0;c[w>>2]=p;F=c[A>>2]|0;c[f+6116>>2]=F;l=(r&7|0)!=0;do{if(l){G=f+427420|0;H=c[G>>2]|0;if((H|0)==2){I=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);J=c[f+4864>>2]|0;K=c[k>>2]|0;L=5}else if((H|0)!=0){H=c[k>>2]|0;I=(H|0)>0;J=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;K=H;L=5}do{if((L|0)==5){H=K-1|0;M=f+5180|0;N=c[M>>2]|0;if((J|0)==0){break}if(I){O=N+(H*96|0)+8|0;P=c[O>>2]|0;Q=c[O+4>>2]|0;R=u+(x-8-p)|0;S=c[R+4>>2]|0;c[O>>2]=c[R>>2];c[O+4>>2]=S;c[R>>2]=P;c[R+4>>2]=Q}Q=N+(K*96|0)|0;R=c[Q>>2]|0;P=c[Q+4>>2]|0;S=u+(x-p)|0;O=c[S+4>>2]|0;c[Q>>2]=c[S>>2];c[Q+4>>2]=O;c[S>>2]=R;c[S+4>>2]=P;P=N+(K*96|0)+8|0;S=c[P>>2]|0;R=c[P+4>>2]|0;O=u+((x|8)-p)|0;Q=c[O+4>>2]|0;c[P>>2]=c[O>>2];c[P+4>>2]=Q;c[O>>2]=S;c[O+4>>2]=R;R=(c[k>>2]|0)+1|0;if((R|0)<(c[f+427400>>2]|0)){O=(c[M>>2]|0)+(R*96|0)|0;R=c[O>>2]|0;M=c[O+4>>2]|0;S=u+(x+16-p)|0;Q=c[S+4>>2]|0;c[O>>2]=c[S>>2];c[O+4>>2]=Q;c[S>>2]=R;c[S+4>>2]=M}if(I){M=N+(H*96|0)+16|0;S=c[M>>2]|0;R=c[M+4>>2]|0;Q=-8-F+B|0;O=z+Q|0;P=c[O+4>>2]|0;c[M>>2]=c[O>>2];c[M+4>>2]=P;c[O>>2]=S;c[O+4>>2]=R;R=N+(H*96|0)+24|0;H=c[R>>2]|0;O=c[R+4>>2]|0;S=C+Q|0;Q=c[S+4>>2]|0;c[R>>2]=c[S>>2];c[R+4>>2]=Q;c[S>>2]=H;c[S+4>>2]=O}O=N+(K*96|0)+16|0;S=c[O>>2]|0;H=c[O+4>>2]|0;Q=B-F|0;R=z+Q|0;P=c[R+4>>2]|0;c[O>>2]=c[R>>2];c[O+4>>2]=P;c[R>>2]=S;c[R+4>>2]=H;H=N+(K*96|0)+24|0;N=c[H>>2]|0;R=c[H+4>>2]|0;S=C+Q|0;Q=c[S+4>>2]|0;c[H>>2]=c[S>>2];c[H+4>>2]=Q;c[S>>2]=N;c[S+4>>2]=R}}while(0);R=f+4832|0;ne[c[f+5040+(c[R>>2]<<2)>>2]&1023](n,F);ne[c[f+5040+(c[R>>2]<<2)>>2]&1023](D,F);R=h;S=c[f+4792>>2]|0;a:do{if((r&1|0)==0){ne[c[f+5084+(c[f+4836>>2]<<2)>>2]&1023](y,p);if((a[f+5184|0]|0)==0){break}Xe[c[f+128>>2]&4095](f+421200|0,f+424272|0,c[(c[f+177020>>2]|0)+(S<<6)>>2]|0)}else{if((r&16777216|0)!=0){N=c[f+108>>2]|0;Q=c[f+100>>2]|0;H=f+5160|0;P=f+5168|0;O=0;while(1){M=u+((c[f+5716+(O<<2)>>2]|0)+x)|0;T=d[473424+O|0]|0;U=a[f+5184+T|0]|0;cf[c[f+4992+(a[f+4888+T|0]<<24>>24<<2)>>2]&1023](M,c[H>>2]<<O&32768,c[P>>2]<<O&16384,p);do{if((U<<24>>24|0)==1){T=O<<4;V=f+421200+(T<<1)|0;if((b[V>>1]|0)==0){W=T;L=20;break}Xe[N&4095](M,V,p)}else if((U<<24>>24|0)!=0){W=O<<4;L=20}}while(0);if((L|0)==20){L=0;Xe[Q&4095](M,f+421200+(W<<1)|0,p)}O=O+4|0;if((O|0)>=16){break a}}}O=c[f+104>>2]|0;Q=c[f+96>>2]|0;N=f+5168|0;P=(x|3)-p|0;H=(x|4)-p|0;U=0;do{V=c[f+5716+(U<<2)>>2]|0;T=u+(V+x)|0;X=d[473424+U|0]|0;Y=a[f+4888+X|0]|0;Z=Y<<24>>24;do{if((Y<<24>>24|0)==7|(Y<<24>>24|0)==3){if((c[N>>2]&32768>>>(U>>>0)|0)==0){c[h>>2]=ba(d[u+(P+V)|0]|0,16843009)|0;_=R;break}else{_=u+(H+V)|0;break}}else{_=0}}while(0);Xe[c[f+4932+(Z<<2)>>2]&4095](T,_,p);V=a[f+5184+X|0]|0;b:do{if(!(V<<24>>24==0)){Y=f+421200+(U<<4<<1)|0;do{if(V<<24>>24==1){if((b[Y>>1]|0)==0){break}Xe[O&4095](T,Y,p);break b}}while(0);Xe[Q&4095](T,Y,p)}}while(0);U=U+1|0;}while((U|0)<16)}}while(0);R=c[G>>2]|0;if((R|0)==2){$=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);aa=c[f+4864>>2]|0;ca=c[k>>2]|0}else if((R|0)==0){break}else{R=c[k>>2]|0;$=(R|0)>0;aa=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;ca=R}R=ca-1|0;S=f+5180|0;U=c[S>>2]|0;if((aa|0)==0){break}if($){Q=U+(R*96|0)+8|0;O=c[Q>>2]|0;H=c[Q+4>>2]|0;P=u+(x-8-p)|0;N=c[P+4>>2]|0;c[Q>>2]=c[P>>2];c[Q+4>>2]=N;c[P>>2]=O;c[P+4>>2]=H}H=U+(ca*96|0)|0;P=c[H+4>>2]|0;O=u+(x-p)|0;c[O>>2]=c[H>>2];c[O+4>>2]=P;P=U+(ca*96|0)+8|0;O=c[P>>2]|0;H=c[P+4>>2]|0;N=u+((x|8)-p)|0;Q=c[N+4>>2]|0;c[P>>2]=c[N>>2];c[P+4>>2]=Q;c[N>>2]=O;c[N+4>>2]=H;H=(c[k>>2]|0)+1|0;if((H|0)<(c[f+427400>>2]|0)){N=(c[S>>2]|0)+(H*96|0)|0;H=c[N>>2]|0;S=c[N+4>>2]|0;O=u+(x+16-p)|0;Q=c[O+4>>2]|0;c[N>>2]=c[O>>2];c[N+4>>2]=Q;c[O>>2]=H;c[O+4>>2]=S}if($){S=U+(R*96|0)+16|0;O=c[S>>2]|0;H=c[S+4>>2]|0;Q=-8-F+B|0;N=z+Q|0;P=c[N+4>>2]|0;c[S>>2]=c[N>>2];c[S+4>>2]=P;c[N>>2]=O;c[N+4>>2]=H;H=U+(R*96|0)+24|0;R=c[H>>2]|0;N=c[H+4>>2]|0;O=C+Q|0;Q=c[O+4>>2]|0;c[H>>2]=c[O>>2];c[H+4>>2]=Q;c[O>>2]=R;c[O+4>>2]=N}N=U+(ca*96|0)+16|0;O=c[N>>2]|0;R=c[N+4>>2]|0;Q=B-F|0;H=z+Q|0;P=c[H+4>>2]|0;c[N>>2]=c[H>>2];c[N+4>>2]=P;c[H>>2]=O;c[H+4>>2]=R;R=U+(ca*96|0)+24|0;U=c[R>>2]|0;H=c[R+4>>2]|0;O=C+Q|0;Q=c[O+4>>2]|0;c[R>>2]=c[O>>2];c[R+4>>2]=Q;c[O>>2]=U;c[O+4>>2]=H}else{H=c[f+1028>>2]|0;O=f+148|0;U=c[f+1032>>2]|0;Q=f+164|0;R=f+12|0;P=f+28|0;N=c[(c[q>>2]|0)+(c[o>>2]<<2)>>2]|0;S=a[f+5644|0]|0;T=S<<24>>24>-1;if(t){if(T){V=S<<24>>24;X=c[k>>2]|0;Z=(X<<4|8)+(b[f+5360>>1]>>2)|0;M=(b[f+5362>>1]>>2)+(c[m>>2]<<4)|0;da=Z+64+(ba(M+(X<<2&12)|0,p)|0)|0;Xe[c[E>>2]&4095]((c[f+199440+(V*2224|0)>>2]|0)+da|0,p,4);da=(Z>>1)+64+(ba((c[k>>2]&7)+(M>>1)|0,c[A>>2]|0)|0)|0;M=c[f+199440+(V*2224|0)+4>>2]|0;Xe[c[E>>2]&4095](M+da|0,(c[f+199440+(V*2224|0)+8>>2]|0)-M|0,2)}do{if((N&8|0)==0){if((N&16|0)!=0){M=H+64|0;V=U+64|0;xda(f,0,0,8,8,y,n,D,0,0,M,c[O>>2]|0,V,c[Q>>2]|0,R,P,N&4096,N&16384);xda(f,8,0,8,8,y,n,D,0,4,M,c[O>>2]|0,V,c[Q>>2]|0,R,P,N&8192,N&32768);break}if((N&32|0)!=0){V=H+64|0;M=f+152|0;da=U+64|0;Z=f+168|0;X=f+16|0;ea=f+32|0;xda(f,0,0,16,c[w>>2]<<3,y,n,D,0,0,V,c[M>>2]|0,da,c[Z>>2]|0,X,ea,N&4096,N&16384);xda(f,4,0,16,c[w>>2]<<3,y,n,D,4,0,V,c[M>>2]|0,da,c[Z>>2]|0,X,ea,N&8192,N&32768);break}ea=H+128|0;X=f+156|0;Z=U+128|0;da=f+172|0;M=f+20|0;V=f+36|0;fa=f+152|0;ga=f+168|0;ha=f+16|0;ia=f+32|0;ja=H+64|0;ka=U+64|0;la=0;do{ma=e[f+177112+(la<<1)>>1]|0;na=la<<2;oa=na&4;pa=la<<1&4;do{if((ma&8|0)==0){if((ma&16|0)!=0){qa=ma&4096;ra=ma&16384;xda(f,na,0,4,4,y,n,D,oa,pa,ea,c[fa>>2]|0,Z,c[ga>>2]|0,ha,ia,qa,ra);xda(f,na|2,0,4,4,y,n,D,oa,pa|2,ea,c[fa>>2]|0,Z,c[ga>>2]|0,ha,ia,qa,ra);break}if((ma&32|0)==0){ra=ma&4096;qa=ma&16384;xda(f,na,1,4,0,y,n,D,oa,pa,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,ra,qa);sa=oa|2;xda(f,na|1,1,4,0,y,n,D,sa,pa,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,ra,qa);ta=pa|2;xda(f,na|2,1,4,0,y,n,D,oa,ta,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,ra,qa);xda(f,na|3,1,4,0,y,n,D,sa,ta,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,ra,qa);break}else{qa=ma&4096;ra=ma&16384;xda(f,na,0,8,c[w>>2]<<2,y,n,D,oa,pa,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,qa,ra);xda(f,na|1,0,8,c[w>>2]<<2,y,n,D,oa|2,pa,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,qa,ra);break}}else{xda(f,na,1,8,0,y,n,D,oa,pa,ja,c[fa>>2]|0,ka,c[ga>>2]|0,ha,ia,ma&4096,ma&16384)}}while(0);la=la+1|0;}while((la|0)<4)}else{xda(f,0,1,16,0,y,n,D,0,0,H|0,c[O>>2]|0,U|0,c[Q>>2]|0,R,P,N&4096,N&16384)}}while(0);G=a[f+5684|0]|0;if(!(G<<24>>24>-1)){break}la=G<<24>>24;G=c[k>>2]|0;ia=(G<<4|8)+(b[f+5520>>1]>>2)|0;ha=(b[f+5522>>1]>>2)+(c[m>>2]<<4)|0;ga=ia+64+(ba(ha+(G<<2&12)|0,c[w>>2]|0)|0)|0;Xe[c[E>>2]&4095]((c[f+306192+(la*2224|0)>>2]|0)+ga|0,c[v>>2]|0,4);ga=(ia>>1)+64+(ba((c[k>>2]&7)+(ha>>1)|0,c[A>>2]|0)|0)|0;ha=c[f+306192+(la*2224|0)+4>>2]|0;Xe[c[E>>2]&4095](ha+ga|0,(c[f+306192+(la*2224|0)+8>>2]|0)-ha|0,2);break}else{if(T){ha=S<<24>>24;la=c[k>>2]|0;ga=(la<<4|8)+(b[f+5360>>1]>>2)|0;ia=(b[f+5362>>1]>>2)+(c[m>>2]<<4)|0;G=ga+64+(ba(ia+(la<<2&12)|0,p)|0)|0;Xe[c[E>>2]&4095]((c[f+199440+(ha*2224|0)>>2]|0)+G|0,p,4);G=(ga>>1)+64+(ba((c[k>>2]&7)+(ia>>1)|0,c[A>>2]|0)|0)|0;ia=c[f+199440+(ha*2224|0)+4>>2]|0;Xe[c[E>>2]&4095](ia+G|0,(c[f+199440+(ha*2224|0)+8>>2]|0)-ia|0,2)}do{if((N&8|0)==0){if((N&16|0)!=0){ia=H+64|0;ha=U+64|0;wda(f,0,0,8,8,y,n,D,0,0,ia,c[O>>2]|0,ha,c[Q>>2]|0,R,P,N&4096,N&16384);wda(f,8,0,8,8,y,n,D,0,4,ia,c[O>>2]|0,ha,c[Q>>2]|0,R,P,N&8192,N&32768);break}if((N&32|0)!=0){ha=H+64|0;ia=f+152|0;G=U+64|0;ga=f+168|0;la=f+16|0;ka=f+32|0;wda(f,0,0,16,c[w>>2]<<3,y,n,D,0,0,ha,c[ia>>2]|0,G,c[ga>>2]|0,la,ka,N&4096,N&16384);wda(f,4,0,16,c[w>>2]<<3,y,n,D,4,0,ha,c[ia>>2]|0,G,c[ga>>2]|0,la,ka,N&8192,N&32768);break}ka=H+128|0;la=f+156|0;ga=U+128|0;G=f+172|0;ia=f+20|0;ha=f+36|0;fa=f+152|0;ja=f+168|0;V=f+16|0;M=f+32|0;da=H+64|0;Z=U+64|0;X=0;do{ea=e[f+177112+(X<<1)>>1]|0;ma=X<<2;pa=ma&4;oa=X<<1&4;do{if((ea&8|0)==0){if((ea&16|0)!=0){na=ea&4096;ra=ea&16384;wda(f,ma,0,4,4,y,n,D,pa,oa,ka,c[fa>>2]|0,ga,c[ja>>2]|0,V,M,na,ra);wda(f,ma|2,0,4,4,y,n,D,pa,oa|2,ka,c[fa>>2]|0,ga,c[ja>>2]|0,V,M,na,ra);break}if((ea&32|0)==0){ra=ea&4096;na=ea&16384;wda(f,ma,1,4,0,y,n,D,pa,oa,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,ra,na);qa=pa|2;wda(f,ma|1,1,4,0,y,n,D,qa,oa,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,ra,na);ta=oa|2;wda(f,ma|2,1,4,0,y,n,D,pa,ta,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,ra,na);wda(f,ma|3,1,4,0,y,n,D,qa,ta,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,ra,na);break}else{na=ea&4096;ra=ea&16384;wda(f,ma,0,8,c[w>>2]<<2,y,n,D,pa,oa,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,na,ra);wda(f,ma|1,0,8,c[w>>2]<<2,y,n,D,pa|2,oa,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,na,ra);break}}else{wda(f,ma,1,8,0,y,n,D,pa,oa,da,c[fa>>2]|0,Z,c[ja>>2]|0,V,M,ea&4096,ea&16384)}}while(0);X=X+1|0;}while((X|0)<4)}else{wda(f,0,1,16,0,y,n,D,0,0,H|0,c[O>>2]|0,U|0,c[Q>>2]|0,R,P,N&4096,N&16384)}}while(0);N=a[f+5684|0]|0;if(!(N<<24>>24>-1)){break}P=N<<24>>24;N=c[k>>2]|0;R=(N<<4|8)+(b[f+5520>>1]>>2)|0;Q=(b[f+5522>>1]>>2)+(c[m>>2]<<4)|0;U=R+64+(ba(Q+(N<<2&12)|0,c[w>>2]|0)|0)|0;Xe[c[E>>2]&4095]((c[f+306192+(P*2224|0)>>2]|0)+U|0,c[v>>2]|0,4);U=(R>>1)+64+(ba((c[k>>2]&7)+(Q>>1)|0,c[A>>2]|0)|0)|0;Q=c[f+306192+(P*2224|0)+4>>2]|0;Xe[c[E>>2]&4095](Q+U|0,(c[f+306192+(P*2224|0)+8>>2]|0)-Q|0,2);break}}}while(0);do{if((r&1|0)==0){if((r&2|0)!=0){le[c[f+124>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}if((c[f+426564>>2]&15|0)==0){break}if((r&16777216|0)==0){le[c[f+112>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}else{le[c[f+116>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}}}while(0);if((c[f+426564>>2]&48|0)==0){i=g;return}p=j|0;c[p>>2]=n;c[j+4>>2]=D;D=c[f+4756>>2]|0;if(t){ua=D+3|0;va=(c[f+4760>>2]|0)+3|0}else{ua=D;va=c[f+4760>>2]|0}if((a[f+5224|0]|0)!=0){ne[c[f+132>>2]&1023](f+421712|0,c[(c[f+177020+((l?1:4)<<2)>>2]|0)+(ua<<6)>>2]|0)}if((a[f+5264|0]|0)!=0){ne[c[f+132>>2]&1023](f+422224|0,c[(c[f+177020+((l?2:5)<<2)>>2]|0)+(va<<6)>>2]|0)}le[c[f+120>>2]&1023](p,s,f+421200|0,F,f+5184|0);i=g;return}function cda(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=b+177120|0;c[e>>2]=0;f=b+177124|0;c[f>>2]=0;g=b+1096|0;h=c[g>>2]|0;i=b+1088|0;j=c[i>>2]|0;k=j+(h>>>3)|0;l=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(h&7);if(l>>>0>134217727>>>0){k=l>>>23;m=(d[1213744+k|0]|0)+h|0;c[g>>2]=m;n=d[1108392+k|0]|0;o=m}else{m=l>>>0>65535>>>0;k=m?l>>>16:l;p=m?16:0;if((k&65280|0)==0){q=p;r=k}else{q=p|8;r=k>>>8}k=(d[1191992+r|0]|0)+q<<1;q=h+63-k|0;c[g>>2]=q;n=(l>>>((k-31|0)>>>0))-1|0;o=q}c[b+177128>>2]=n;q=b+6136|0;if((c[q>>2]|0)==0){s=c[b+177132>>2]|0}else{k=j+(o>>>3)|0;j=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(o&7);if(j>>>0>134217727>>>0){k=j>>>23;c[g>>2]=(d[1213744+k|0]|0)+o;t=d[1108392+k|0]|0}else{k=j>>>0>65535>>>0;l=k?j>>>16:j;h=k?16:0;if((l&65280|0)==0){u=h;v=l}else{u=h|8;v=l>>>8}l=(d[1191992+v|0]|0)+u<<1;c[g>>2]=o+63-l;t=(j>>>((l-31|0)>>>0))-1|0}c[b+177132>>2]=t;s=t}t=1<<n;n=1<<s;s=b+177080|0;l=0;while(1){if((l|0)>=2){break}j=b+572484+(l<<2)|0;c[j>>2]=0;o=b+572492+(l<<2)|0;c[o>>2]=0;u=b+199420+(l<<2)|0;if((c[u>>2]|0)!=0){v=0;do{h=c[g>>2]|0;k=c[i>>2]|0;r=d[k+(h>>>3)|0]|0;p=h+1|0;c[g>>2]=p;do{if((r&128>>>((h&7)>>>0)|0)==0){c[b+177136+(v<<4)+(l<<3)>>2]=t;c[b+177136+(v<<4)+(l<<3)+4>>2]=0}else{m=k+(p>>>3)|0;w=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7);if(w>>>0>134217727>>>0){m=w>>>23;c[g>>2]=(d[1213744+m|0]|0)+p;x=a[1139096+m|0]|0}else{m=w>>>0>65535>>>0;y=m?w>>>16:w;w=m?16:0;if((y&65280|0)==0){z=w;A=y}else{z=w|8;A=y>>>8}y=(d[1191992+A|0]|0)+z|0;w=31-y+p|0;m=k+(w>>>3)|0;B=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(w&7)>>>(y>>>0);c[g>>2]=32-y+w;w=B>>>1;x=(B&1|0)==0?w:-w|0}w=b+177136+(v<<4)+(l<<3)|0;c[w>>2]=x;B=c[g>>2]|0;y=c[i>>2]|0;m=y+(B>>>3)|0;C=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7);if(C>>>0>134217727>>>0){m=C>>>23;c[g>>2]=(d[1213744+m|0]|0)+B;D=a[1139096+m|0]|0}else{m=C>>>0>65535>>>0;E=m?C>>>16:C;C=m?16:0;if((E&65280|0)==0){F=C;G=E}else{F=C|8;G=E>>>8}E=(d[1191992+G|0]|0)+F|0;C=31-E+B|0;B=y+(C>>>3)|0;y=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>(E>>>0);c[g>>2]=32-E+C;C=y>>>1;D=(y&1|0)==0?C:-C|0}c[b+177136+(v<<4)+(l<<3)+4>>2]=D;if((c[w>>2]|0)==(t|0)&(D|0)==0){break}c[e>>2]=1;c[j>>2]=1}}while(0);a:do{if((c[q>>2]|0)!=0){k=c[g>>2]|0;p=c[i>>2]|0;h=d[p+(k>>>3)|0]|0;r=k+1|0;c[g>>2]=r;if((h&128>>>((k&7)>>>0)|0)==0){c[b+177904+(v<<5)+(l<<4)>>2]=n;c[b+177904+(v<<5)+(l<<4)+4>>2]=0;c[b+177904+(v<<5)+(l<<4)+8>>2]=n;c[b+177904+(v<<5)+(l<<4)+12>>2]=0;break}else{H=0;I=r;J=p}while(1){p=J+(I>>>3)|0;r=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(I&7);if(r>>>0>134217727>>>0){p=r>>>23;c[g>>2]=(d[1213744+p|0]|0)+I;K=a[1139096+p|0]|0}else{p=r>>>0>65535>>>0;k=p?r>>>16:r;r=p?16:0;if((k&65280|0)==0){L=r;M=k}else{L=r|8;M=k>>>8}k=(d[1191992+M|0]|0)+L|0;r=31-k+I|0;p=J+(r>>>3)|0;h=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>(k>>>0);c[g>>2]=32-k+r;r=h>>>1;K=(h&1|0)==0?r:-r|0}r=b+177904+(v<<5)+(l<<4)+(H<<3)|0;c[r>>2]=K;h=c[g>>2]|0;k=c[i>>2]|0;p=k+(h>>>3)|0;w=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(h&7);if(w>>>0>134217727>>>0){p=w>>>23;c[g>>2]=(d[1213744+p|0]|0)+h;N=a[1139096+p|0]|0}else{p=w>>>0>65535>>>0;C=p?w>>>16:w;w=p?16:0;if((C&65280|0)==0){O=w;P=C}else{O=w|8;P=C>>>8}C=(d[1191992+P|0]|0)+O|0;w=31-C+h|0;h=k+(w>>>3)|0;k=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(w&7)>>>(C>>>0);c[g>>2]=32-C+w;w=k>>>1;N=(k&1|0)==0?w:-w|0}c[b+177904+(v<<5)+(l<<4)+(H<<3)+4>>2]=N;if(!((c[r>>2]|0)==(n|0)&(N|0)==0)){c[f>>2]=1;c[o>>2]=1}r=H+1|0;if((r|0)>=2){break a}H=r;I=c[g>>2]|0;J=c[i>>2]|0}}}while(0);v=v+1|0;}while(v>>>0<(c[u>>2]|0)>>>0)}if((c[s>>2]|0)==3){l=l+1|0}else{break}}if((c[e>>2]|0)!=0){Q=1;c[e>>2]=Q;return 0}Q=(c[f>>2]|0)!=0|0;c[e>>2]=Q;return 0}function dda(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=c[a+6144>>2]|0;g=c[a+428672>>2]|0;h=a+428668|0;c[h>>2]=g;i=c[a+428656>>2]|0;if((i|0)<(c[a+428676>>2]|0)){j=g+(1<<f)|0;c[h>>2]=j;k=j}else{k=g}g=c[a+6148>>2]|0;do{if((g|0)==0){j=1<<c[a+6152>>2];h=c[a+428636>>2]|0;f=c[a+428664>>2]|0;do{if((h|0)<(f|0)){if((f-h|0)<((j|0)/2|0|0)){l=7;break}m=(c[a+428660>>2]|0)+j|0;c[a+428640>>2]=m;n=m}else{l=7}}while(0);a:do{if((l|0)==7){do{if((h|0)>(f|0)){if((f-h|0)>=((j|0)/-2|0|0)){break}m=(c[a+428660>>2]|0)-j|0;c[a+428640>>2]=m;n=m;break a}}while(0);m=c[a+428660>>2]|0;c[a+428640>>2]=m;n=m}}while(0);j=h+n|0;f=c[a+177100>>2]|0;if((f|0)!=3){o=j;p=j;q=f;l=23;break}r=j;s=(c[a+428644>>2]|0)+j|0;l=25}else if((g|0)==1){j=c[a+6168>>2]|0;f=(j|0)==0?0:i+k|0;m=(c[a+427432>>2]|0)==0;t=((m&(f|0)>0)<<31>>31)+f|0;if((j|0)>0){f=0;u=0;while(1){v=(b[a+6272+(u<<1)>>1]|0)+f|0;w=u+1|0;if((w|0)<(j|0)){f=v;u=w}else{x=v;break}}}else{x=0}do{if((t|0)>0){u=t-1|0;f=(u|0)%(j|0)|0;h=ba((u|0)/(j|0)|0,x)|0;if((f|0)<0){y=h;break}else{z=h;A=0}while(1){h=(b[a+6272+(A<<1)>>1]|0)+z|0;u=A+1|0;if((u|0)>(f|0)){y=h;break}else{z=h;A=u}}}else{y=0}}while(0);if(m){B=(c[a+6160>>2]|0)+y|0}else{B=y}j=(c[a+428648>>2]|0)+B|0;t=j+(c[a+6164>>2]|0)|0;f=c[a+177100>>2]|0;if((f|0)!=3){o=t;p=j;q=f;l=23;break}r=j;s=(c[a+428652>>2]|0)+t|0;l=25}else{t=(((c[a+427432>>2]|0)==0)<<31>>31)+(i+k<<1)|0;o=t;p=t;q=c[a+177100>>2]|0;l=23}}while(0);do{if((l|0)==23){if((q|0)!=2){r=p;s=o;l=25;break}C=c[d>>2]|0;D=o}}while(0);do{if((l|0)==25){c[d>>2]=r;if((c[a+177100>>2]|0)!=1){C=r;D=s;break}E=r;F=c[d+4>>2]|0;G=(E|0)>(F|0);H=G?F:E;c[e>>2]=H;return 0}}while(0);c[d+4>>2]=D;E=C;F=D;G=(E|0)>(F|0);H=G?F:E;c[e>>2]=H;return 0}function eda(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;e=c[a+7348>>2]|0;f=c[a+7352>>2]|0;g=c[a+177080>>2]|0;do{if((g|0)==1){h=0;j=0;k=0}else{l=(c[a+177100>>2]|0)==3?15:31;m=(g|0)==3;n=a+1096|0;o=c[n>>2]|0;if(m){p=c[a+1088>>2]|0;q=(d[p+(o>>>3)|0]|0)<<(o&7)>>>7;r=o+1|0;c[n>>2]=r;c[a+197872>>2]=q&1;s=r;t=p}else{s=o;t=c[a+1088>>2]|0}o=a+1096|0;p=d[t+(s>>>3)|0]|0;r=s+1|0;c[o>>2]=r;do{if((p&128>>>((s&7)>>>0)|0)==0){u=f;v=e;w=g}else{q=t+(r>>>3)|0;n=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7);if(n>>>0>134217727>>>0){q=n>>>23;x=(d[1213744+q|0]|0)+r|0;c[o>>2]=x;y=d[1108392+q|0]|0;z=x}else{x=n>>>0>65535>>>0;q=x?n>>>16:n;A=x?16:0;if((q&65280|0)==0){B=A;C=q}else{B=A|8;C=q>>>8}q=(d[1191992+C|0]|0)+B<<1;A=s+64-q|0;c[o>>2]=A;y=(n>>>((q-31|0)>>>0))-1|0;z=A}A=y+1|0;if(!m){u=1;v=A;w=g;break}q=t+(z>>>3)|0;n=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(z&7);if(n>>>0>134217727>>>0){q=n>>>23;c[o>>2]=(d[1213744+q|0]|0)+z;D=d[1108392+q|0]|0}else{q=n>>>0>65535>>>0;x=q?n>>>16:n;E=q?16:0;if((x&65280|0)==0){F=E;G=x}else{F=E|8;G=x>>>8}x=(d[1191992+G|0]|0)+F<<1;c[o>>2]=z+63-x;D=(n>>>((x-31|0)>>>0))-1|0}u=D+1|0;v=A;w=3}}while(0);o=v-1|0;m=u-1|0;if(!(o>>>0>l>>>0|m>>>0>l>>>0)){h=u;j=v;k=(w|0)==3?2:1;break}yDb(c[a>>2]|0,16,2308352,(r=i,i=i+32|0,c[r>>2]=o,c[r+8>>2]=l,c[r+16>>2]=m,c[r+24>>2]=l,r)|0);i=r;c[a+199424>>2]=0;c[a+199420>>2]=0;c[a+199428>>2]=0;H=-1094995529;i=b;return H|0}}while(0);w=a+199428|0;v=a+199420|0;do{if((k|0)==(c[w>>2]|0)){if((j|0)!=(c[v>>2]|0)){break}if((h|0)==(c[a+199424>>2]|0)){H=0}else{break}i=b;return H|0}}while(0);c[v>>2]=j;c[a+199424>>2]=h;c[w>>2]=k;H=1;i=b;return H|0}function fda(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=g;m=e;c[g+4816>>2]=c[b+88>>2];c[g+4800>>2]=0;a:do{if((k|0)==0){n=0;o=g+2524|0}else{b:do{if((c[g+427456>>2]|0)!=0&(k|0)>8){if((a[j]|0)!=1){break}if((a[j+2|0]|0)!=0){break}if(!((a[j+4|0]&-4)<<24>>24==-4)){break}e=a[j+5|0]&31;if((e|0)==0){break}if((a[j+8|0]|0)!=103){break}p=k+j|0;q=j+6|0;r=e;while(1){e=r-1|0;s=q;t=(de((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535;s=t+2|0;if((s|0)>(p-q|0)){break b}if((a[q+2|0]|0)!=103){break b}u=q+s|0;if((e|0)==0){break}else{q=u;r=e}}r=a[u]|0;if(r<<24>>24==0){break}p=k+j|0;e=q+(t+3)|0;s=r&255;while(1){r=s-1|0;v=e;w=((de((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)+2|0;if((w|0)>(p-e|0)){break b}if((a[e+2|0]|0)!=104){break b}if((r|0)==0){break}else{e=e+w|0;s=r}}x=Uca(l,j,k)|0;i=h;return x|0}}while(0);s=Vca(l,j,k,0)|0;if((s|0)<0){x=-1094995529;i=h;return x|0}e=g+2524|0;p=(c[e>>2]|0)==0;do{if(p){if((c[g+427436>>2]|0)!=10){break}if((s|0)<=(k|0)){n=s;o=e;break a}yDb(0,0,1895544,(y=i,i=i+24|0,c[y>>2]=2258064,c[y+8>>2]=2332720,c[y+16>>2]=5264,y)|0);i=y;Cd();return 0}}while(0);do{if((c[b+92>>2]&32768|0)==0){if(!p){z=41;break}if((c[b+856>>2]|0)>7){x=k;i=h;return x|0}do{if((k|0)>3){if((PGb(2243864,j,4)|0)==0){x=k}else{break}i=h;return x|0}}while(0);yDb(b,16,2231344,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;x=-1094995529;i=h;return x|0}else{e=c[g+427396>>2]|0;if((c[g+427380>>2]|0)<(e|0)|(e|0)==0){break}kda(l,1);z=41}}while(0);do{if((z|0)==41){lda(l,0);c[f>>2]=0;p=g+571424|0;e=c[p>>2]|0;if((e|0)==0){break}if((c[e+2200>>2]|0)==0){break}q=jda(l,m,e)|0;if((q|0)<0){x=q;i=h;return x|0}else{c[f>>2]=1;TOa(c[g>>2]|0,c[p>>2]|0,m,c[g+2412>>2]|0,g+4808|0,c[g+427400>>2]|0,c[g+427396>>2]|0,c[g+427404>>2]|0,1);break}}}while(0);p=(s|0)==0?1:s;x=(p+10|0)>(k|0)?k:p;i=h;return x|0}}while(0);c[o>>2]=0;c[g+177104>>2]=0;o=g+571288|0;k=o;z=c[o>>2]|0;o=c[g+571292>>2]|0;c:do{if((o|0)==0){A=z;B=0}else{g=z;y=1;b=0;j=o;while(1){if((c[j+84>>2]|0)!=0){A=g;B=b;break c}if((c[j+1620>>2]|0)!=0){A=g;B=b;break c}t=(c[j+1612>>2]|0)<(c[g+1612>>2]|0);u=t?j:g;p=t?y:b;t=y+1|0;q=c[k+(t<<2)>>2]|0;if((q|0)==0){A=u;B=p;break}else{g=u;y=t;b=p;j=q}}}}while(0);o=k+(B<<2)|0;if((c[o>>2]|0)!=0){z=B;B=o;while(1){o=z+1|0;j=k+(o<<2)|0;c[B>>2]=c[j>>2];if((c[j>>2]|0)==0){break}else{z=o;B=j}}}if((A|0)==0){x=n;i=h;return x|0}B=A+2192|0;c[B>>2]=c[B>>2]&-5;B=jda(l,m,A)|0;if((B|0)<0){x=B;i=h;return x|0}c[f>>2]=1;x=n;i=h;return x|0}function gda(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;a=b;iea(a);Tca(a,1);d=0;while(1){$Db(a+427476+(d<<2)|0);e=d+1|0;if((e|0)<32){d=e}else{f=0;break}}do{$Db(a+427604+(f<<2)|0);f=f+1|0;}while((f|0)<256);ida(a,b+2528|0);return 0}function hda(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;b=c[a+60>>2]|0;a=b+571288|0;d=a;e=0;do{f=d+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){c[g+2192>>2]=0}c[f>>2]=0;e=e+1|0;}while((e|0)<17);e=b;c[b+571432>>2]=-2147483648;c[b+571428>>2]=-2147483648;c[b+572412>>2]=1;iea(e);c[b+428672>>2]=0;c[b+428660>>2]=65536;c[b+428664>>2]=0;c[b+571360>>2]=-2147483648;c[b+571364>>2]=-2147483648;c[b+571368>>2]=-2147483648;c[b+571372>>2]=-2147483648;c[b+571376>>2]=-2147483648;c[b+571380>>2]=-2147483648;c[b+571384>>2]=-2147483648;c[b+571388>>2]=-2147483648;c[b+571392>>2]=-2147483648;c[b+571396>>2]=-2147483648;c[b+571400>>2]=-2147483648;c[b+571404>>2]=-2147483648;c[b+571408>>2]=-2147483648;c[b+571412>>2]=-2147483648;c[b+571416>>2]=-2147483648;c[b+571420>>2]=-2147483648;c[b+428676>>2]=-1;d=b+2524|0;f=c[d>>2]|0;if((f|0)!=0){c[f+2192>>2]=0;g=c[a>>2]|0;a:do{if((g|0)==0){h=0}else{a=1;i=0;j=g;k=f;while(1){if((j|0)==(k|0)){l=i}else{c[e+571288+(i<<2)>>2]=j;l=i+1|0}m=c[e+571288+(a<<2)>>2]|0;if((m|0)==0){h=l;break a}a=a+1|0;i=l;j=m;k=c[d>>2]|0}}}while(0);c[e+571288+(h<<2)>>2]=0}c[b+177104>>2]=0;TGb(b+199440|0,0,213504)|0;TGb(b+428696|0,0,142336)|0;mea(e);c[b+572476>>2]=-1;c[b+572480>>2]=0;c[b+199428>>2]=0;c[b+572376>>2]=0;c[b+572232>>2]=1;h=b+2520|0;l=c[h>>2]|0;if((l|0)==0){c[d>>2]=0;n=b+2528|0;o=n;ida(e,o);p=b+427380|0;q=p;c[q>>2]=0;r=b+427376|0;s=r;c[s>>2]=0;t=b+1064|0;u=t;c[u>>2]=-1;v=b+1068|0;w=v;c[w>>2]=0;x=b+1072|0;y=x;c[y>>2]=0;z=b+1076|0;A=z;c[A>>2]=0;B=b+1052|0;C=B;c[C>>2]=0;D=b+1056|0;E=D;c[E>>2]=0;Tca(e,1);F=b+4812|0;G=F;c[G>>2]=0;return}else{H=0;I=l}while(1){ida(e,I+(H*2224|0)|0);l=H+1|0;if((l|0)>=36){break}H=l;I=c[h>>2]|0}c[d>>2]=0;n=b+2528|0;o=n;ida(e,o);p=b+427380|0;q=p;c[q>>2]=0;r=b+427376|0;s=r;c[s>>2]=0;t=b+1064|0;u=t;c[u>>2]=-1;v=b+1068|0;w=v;c[w>>2]=0;x=b+1072|0;y=x;c[y>>2]=0;z=b+1076|0;A=z;c[A>>2]=0;B=b+1052|0;C=B;c[C>>2]=0;D=b+1056|0;E=D;c[E>>2]=0;Tca(e,1);F=b+4812|0;G=F;c[G>>2]=0;return}function ida(a,b){a=a|0;b=b|0;if((c[b+360>>2]|0)==0){return}U0a(c[a>>2]|0,b+1496|0);XAb(b+1596|0);a=b+1508|0;XAb(a);XAb(b+1532|0);XAb(b+1516|0);XAb(b+1548|0);XAb(b+1520|0);XAb(b+1552|0);TGb(a|0,0,716)|0;return}function jda(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=bFb(c[f+80>>2]|0)|0;h=MCb(e,f|0)|0;if((h|0)<0){i=h;return i|0}CBb(e+440|0,2152064,oea(b)|0,0)|0;if((c[f+2208>>2]|0)==0){i=0;return i|0}h=g+4|0;if((a[h]|0)==0){i=0;return i|0}j=g+5|0;k=g+6|0;g=f+2212|0;l=b+4752|0;b=f+2216|0;f=0;while(1){if((f|0)>0){m=d[k]|0;n=d[j]|0}else{m=0;n=0}o=(ba(c[b>>2]>>m,c[e+32+(f<<2)>>2]|0)|0)+(c[g>>2]>>n<<c[l>>2])|0;p=e+(f<<2)|0;c[p>>2]=(c[p>>2]|0)+o;o=f+1|0;if((o|0)<(d[h]|0)){f=o}else{i=0;break}}return i|0}function kda(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;e=c[a+2524>>2]|0;f=e|0;g=e+88|0;c[g>>2]=c[a+572392>>2];h=a+571424|0;if((c[h>>2]|0)!=0){i=d;return}j=e+1604|0;if((c[j>>2]|0)==2147483647){i=d;return}k=e+1608|0;if((c[k>>2]|0)==2147483647){i=d;return}l=e+296|0;c[l>>2]=0;m=e+292|0;c[m>>2]=0;n=a+7284|0;do{if((c[n>>2]|0)==0){if((c[a+177088>>2]|0)==0){o=(c[a+177100>>2]|0)!=3|0}else{o=1}c[l>>2]=o;p=o}else{q=a+572408|0;a:do{switch(c[q>>2]|0){case 8:{c[m>>2]=4;r=0;break};case 3:case 4:{do{if((c[a+177088>>2]|0)==0){if((c[a+177100>>2]|0)!=3){break}s=c[a+572412>>2]|0;c[l>>2]=s;r=s;break a}}while(0);c[l>>2]=1;r=1;break};case 5:case 6:{c[m>>2]=1;r=0;break};case 1:case 2:{c[l>>2]=1;r=1;break};case 7:{c[m>>2]=2;r=0;break};default:{r=0}}}while(0);s=c[a+572432>>2]|0;if((s&3|0)==0){p=r;break}if(!((c[q>>2]|0)>>>0<5>>>0)){p=r;break}t=s>>>1&1;c[l>>2]=t;p=t}}while(0);c[a+572412>>2]=p;p=c[j>>2]|0;j=c[k>>2]|0;b:do{if((p|0)==(j|0)){do{if((c[l>>2]|0)==0){if((c[n>>2]|0)!=0){break}c[e+300>>2]=0;break b}}while(0);q=c[a+572408>>2]|0;if((q|0)==3|(q|0)==5){c[e+300>>2]=1;break}else{c[e+300>>2]=0;break}}else{c[e+300>>2]=(p|0)<(j|0)}}while(0);do{if((c[a+572416>>2]|0)!=0){j=a+572420|0;if(!((c[j>>2]|0)>>>0<7>>>0)){break}p=a+572424|0;if(!(((c[p>>2]|0)-1|0)>>>0<2>>>0)){break}n=VFb(f)|0;if((n|0)==0){i=d;return}c:do{switch(c[j>>2]|0){case 3:{l=n|0;if((c[a+572428>>2]|0)==0){c[l>>2]=1;break c}else{c[l>>2]=5;break c}break};case 0:{c[n>>2]=4;break};case 6:{c[n>>2]=0;break};case 2:{c[n>>2]=7;break};case 1:{c[n>>2]=6;break};case 4:{c[n>>2]=2;break};case 5:{c[n>>2]=3;break};default:{}}}while(0);if((c[p>>2]|0)!=2){break}c[n+4>>2]=1}}while(0);f=a+572232|0;j=e+1620|0;c[j>>2]=c[f>>2];c[f>>2]=0;f=a+6784|0;l=c[a>>2]|0;do{if((c[f>>2]|0)!=0){q=l+176|0;k=c[a+6788>>2]|0;if((c[q>>2]|0)>=(k|0)){break}c[q>>2]=k;c[a+4808>>2]=0}}while(0);k=a|0;do{if((c[l+680>>2]|0)>0){if((c[f>>2]|0)!=0){break}c[l+176>>2]=15;c[a+4808>>2]=0}}while(0);l=e+1612|0;q=0;while(1){u=c[l>>2]|0;r=c[a+571360+(q<<2)>>2]|0;v=(q|0)==0;if((u|0)<(r|0)){w=52;break}if(v){q=q+1|0;continue}else{c[a+571360+(q-1<<2)>>2]=r;r=q+1|0;if((r|0)==16){w=53;break}else{q=r;continue}}}if((w|0)==52){if(v){x=0}else{y=q;z=u;w=54}}else if((w|0)==53){y=16;z=c[l>>2]|0;w=54}if((w|0)==54){c[a+571360+(y-1<<2)>>2]=z;x=y}y=16-x|0;do{if((c[g>>2]|0)==3){w=61}else{x=c[a+571416>>2]|0;if((x|0)==-2147483648){A=y;break}if(((c[a+571420>>2]|0)-x|0)>2){w=61}else{A=y}}}while(0);if((w|0)==61){A=(y|0)>1?y:1}y=c[k>>2]|0;do{if((A|0)==16){g=a+571360|0;x=c[g>>2]|0;yDb(y,40,2209904,(B=i,i=i+16|0,c[B>>2]=c[l>>2],c[B+8>>2]=x,B)|0);i=B;c[a+571364>>2]=-2147483648;c[a+571368>>2]=-2147483648;c[a+571372>>2]=-2147483648;c[a+571376>>2]=-2147483648;c[a+571380>>2]=-2147483648;c[a+571384>>2]=-2147483648;c[a+571388>>2]=-2147483648;c[a+571392>>2]=-2147483648;c[a+571396>>2]=-2147483648;c[a+571400>>2]=-2147483648;c[a+571404>>2]=-2147483648;c[a+571408>>2]=-2147483648;c[a+571412>>2]=-2147483648;c[a+571416>>2]=-2147483648;c[a+571420>>2]=-2147483648;c[g>>2]=c[l>>2];c[j>>2]=1;C=0}else{if((c[y+176>>2]|0)>=(A|0)){C=0;break}if((c[f>>2]|0)!=0){C=0;break}yDb(y,40,2201200,(B=i,i=i+8|0,c[B>>2]=A,B)|0);i=B;c[(c[k>>2]|0)+176>>2]=A;c[a+4808>>2]=0;C=0}}while(0);while(1){D=a+571288+(C<<2)|0;E=C+1|0;if((c[D>>2]|0)==0){break}else{C=E}}if((C|0)>=17){yDb(0,0,1895544,(B=i,i=i+24|0,c[B>>2]=2192744,c[B+8>>2]=2332720,c[B+16>>2]=2219,B)|0);i=B;Cd()}c[D>>2]=e;D=e+2192|0;if((c[D>>2]|0)==0){c[D>>2]=4}D=a+571288|0;e=c[D>>2]|0;C=c[a+571292>>2]|0;d:do{if((C|0)==0){F=0;G=e}else{A=1;y=0;f=e;j=C;while(1){if((c[j+84>>2]|0)!=0){F=y;G=f;break d}if((c[j+1620>>2]|0)!=0){F=y;G=f;break d}l=(c[j+1612>>2]|0)<(c[f+1612>>2]|0);g=l?A:y;x=l?j:f;l=A+1|0;z=c[a+571288+(l<<2)>>2]|0;if((z|0)==0){F=g;G=x;break}else{A=l;y=g;f=x;j=z}}}}while(0);C=c[k>>2]|0;j=C+176|0;do{if((c[j>>2]|0)==0){if((c[e+84>>2]|0)==0){if((c[e+1620>>2]|0)==0){break}}c[a+571432>>2]=-2147483648}}while(0);e=c[G+1612>>2]|0;f=a+571432|0;y=(e|0)<(c[f>>2]|0);if(y){w=82}else{A=c[j>>2]|0;if((E|0)>(A|0)){w=82}else{H=C;I=A;w=86}}do{if((w|0)==82){A=G+2192|0;c[A>>2]=c[A>>2]&-5;A=a+571288+(F<<2)|0;if((c[A>>2]|0)!=0){C=F;j=A;while(1){A=C+1|0;n=a+571288+(A<<2)|0;c[j>>2]=c[n>>2];if((c[n>>2]|0)==0){break}else{C=A;j=n}}}j=c[k>>2]|0;if(y){J=j;w=93;break}H=j;I=c[j+176>>2]|0;w=86}}while(0);e:do{if((w|0)==86){if((E|0)<=(I|0)){J=H;w=93;break}c[h>>2]=G;do{if((F|0)==0){j=c[D>>2]|0;if((j|0)==0){break}if((c[j+84>>2]|0)==0){if((c[j+1620>>2]|0)==0){break}}c[f>>2]=-2147483648;K=G;break e}}while(0);c[f>>2]=e;K=G}}while(0);if((w|0)==93){yDb(J,48,2176424,(B=i,i=i+8|0,c[B>>2]=y?2165752:9203376,B)|0);i=B;K=c[h>>2]|0}if((K|0)!=0){h=K+2200|0;K=a+572480|0;a=c[K>>2]|0;if((c[h>>2]|0)==0){L=0;M=a}else{B=a|2;c[K>>2]=B;L=c[h>>2]|0;M=B}c[h>>2]=L|M>>>1&1}if((b|0)==0){i=d;return}b=c[k>>2]|0;if((c[b+712>>2]|0)!=0){i=d;return}X0a(b);i=d;return}function lda(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[a>>2]|0;c[a+427380>>2]=0;f=(b|0)!=0;if(f){g=3}else{if((c[e+816>>2]&1|0)==0){g=3}}if((g|0)==3){if((c[a+4796>>2]|0)==0){kea(a,a+571436|0,c[a+572228>>2]|0)|0;c[a+428660>>2]=c[a+428640>>2];c[a+428664>>2]=c[a+428636>>2]}c[a+428672>>2]=c[a+428668>>2];c[a+428676>>2]=c[a+428656>>2];c[a+571428>>2]=c[a+571432>>2]}g=c[e+712>>2]|0;do{if((g|0)!=0){if((re[c[g+32>>2]&4095](e)|0)>=0){break}yDb(e,16,2219200,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b}}while(0);e=a+177100|0;do{if((c[e>>2]|0)==3){if((c[a+572376>>2]|0)==0){break}if((c[a+7324>>2]|0)!=0){break}c[a+2484>>2]=c[a+2524>>2];Mkb(a+2352|0)}}while(0);if(f){h=a+572376|0;c[h>>2]=0;i=d;return}if((c[a+4796>>2]|0)!=0){h=a+572376|0;c[h>>2]=0;i=d;return}Y0a((c[a+2524>>2]|0)+1496|0,2147483647,(c[e>>2]|0)==2|0);h=a+572376|0;c[h>>2]=0;i=d;return}function mda(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0;g=i;i=i+64|0;h=g|0;c[e+1028>>2]=e+180;c[e+1032>>2]=e+436;j=e+1088|0;k=j|0;l=c[k>>2]|0;m=e+1096|0;n=c[m>>2]|0;o=l+(n>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(n&7);o=n+16|0;q=l+(o>>>3)|0;r=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(o&7)>>>16|p&-65536;o=r>>>0>65535>>>0;q=o?p>>>16:r;r=o?16:0;if((q&65280|0)==0){s=r;t=q}else{s=r|8;t=q>>>8}q=(d[1191992+t|0]|0)+s|0;s=31-q|0;t=s+n|0;c[m>>2]=t;n=s+1|0;do{if((n|0)==0){u=-1}else{r=l+(t>>>3)|0;o=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7);if((n|0)<26){c[m>>2]=t+n;v=o>>>(q>>>0)}else{r=t+16|0;c[m>>2]=r;p=l+(r>>>3)|0;w=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>((47-s|0)>>>0);c[m>>2]=t+n;v=w|o>>>16<<s-15}o=v-1|0;if((o|0)!=0){u=o;break}o=f+572376|0;do{if((c[o>>2]|0)!=0){if((c[e+2524>>2]|0)==0){break}if((c[e+177100>>2]|0)==3){break}lda(e,1)}}while(0);c[o>>2]=0;if((c[f+177104>>2]|0)!=0){u=0;break}w=e+2524|0;r=c[w>>2]|0;do{if((r|0)!=0){if((c[e+4796>>2]|0)!=0){break}Y0a(r+1496|0,2147483647,(c[e+177100>>2]|0)==2|0)}}while(0);c[w>>2]=0;u=0}}while(0);v=c[m>>2]|0;s=c[k>>2]|0;n=s+(v>>>3)|0;t=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(v&7)>>>23;n=(d[1213744+t|0]|0)+v|0;c[m>>2]=n;v=a[1108392+t|0]|0;t=v&255;if((v&255)>>>0>9>>>0){l=c[e+427376>>2]|0;q=c[e+427380>>2]|0;yDb(c[e>>2]|0,16,1973680,(x=i,i=i+24|0,c[x>>2]=t,c[x+8>>2]=l,c[x+16>>2]=q,x)|0);i=x;y=-1094995529;i=g;return y|0}if((v&255)>>>0>4>>>0){c[e+177084>>2]=1;z=t-5|0}else{c[e+177084>>2]=0;z=t}t=d[986368+z|0]|0;v=e+177076|0;c[v>>2]=t;q=t&3;l=e+177080|0;c[l>>2]=q;r=e+427436|0;if(!((c[r>>2]|0)!=5|(q|0)==1)){yDb(c[e>>2]|0,16,1970984,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=g;return y|0}c[e+572392>>2]=t;q=s+(n>>>3)|0;s=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(n&7);do{if(s>>>0>134217727>>>0){q=s>>>23;c[m>>2]=(d[1213744+q|0]|0)+n;A=d[1108392+q|0]|0}else{q=s>>>0>65535>>>0;o=q?s>>>16:s;p=q?16:0;if((o&65280|0)==0){B=p;C=o}else{B=p|8;C=o>>>8}o=(d[1191992+C|0]|0)+B<<1;c[m>>2]=n+63-o;p=(s>>>((o-31|0)>>>0))-1|0;if(!(p>>>0>255>>>0)){A=p;break}yDb(c[e>>2]|0,16,1962480,(x=i,i=i+8|0,c[x>>2]=p,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);s=c[f+427604+(A<<2)>>2]|0;if((s|0)==0){yDb(c[e>>2]|0,16,1959680,(x=i,i=i+8|0,c[x>>2]=A,x)|0);i=x;y=-1094995529;i=g;return y|0}n=f+8056|0;B=c[n>>2]|0;if(!((B|0)<0|(A|0)==(B|0))){yDb(c[e>>2]|0,16,1957544,(x=i,i=i+16|0,c[x>>2]=B,c[x+8>>2]=A,x)|0);i=x;y=-1094995529;i=g;return y|0}B=e+7328|0;UGb(B|0,s|0,728)|0;s=B|0;B=c[s>>2]|0;C=c[f+427476+(B<<2)>>2]|0;if((C|0)==0){yDb(c[e>>2]|0,16,1955160,(x=i,i=i+8|0,c[x>>2]=B,x)|0);i=x;y=-1094995529;i=g;return y|0}p=e+6124|0;do{if((B|0)==(c[p>>2]|0)){if((B|0)!=(c[e+6120>>2]|0)){D=39;break}if((c[C+1200>>2]|0)==0){E=0}else{D=39}}else{D=39}}while(0);do{if((D|0)==39){UGb(p|0,C|0,1204)|0;do{if((c[e+427400>>2]|0)==(c[e+6180>>2]|0)){if((c[e+427396>>2]|0)!=(ba(2-(c[e+6188>>2]|0)|0,c[e+6184>>2]|0)|0)){D=43;break}B=c[(c[e>>2]|0)+796>>2]|0;if((B|0)!=(c[e+7308>>2]|0)){D=43;break}if((c[e+572632>>2]|0)==(c[e+6136>>2]|0)){G=0;H=B}else{D=43}}else{D=43}}while(0);if((D|0)==43){G=1;H=c[e+7308>>2]|0}w=e+427468|0;B=e+7308|0;if((c[w>>2]|0)==(H|0)){o=e+427472|0;q=c[e+6136>>2]|0;if((c[o>>2]|0)==(q|0)){I=G}else{J=q;K=o;D=47}}else{J=c[e+6136>>2]|0;K=e+427472|0;D=47}if((D|0)==47){c[w>>2]=c[B>>2];c[K>>2]=J;I=1}do{if((c[e+4816>>2]&524288|0)==0){if((c[e+6784>>2]|0)==0){break}if((c[e+6788>>2]|0)==0){D=51}}else{D=51}}while(0);a:do{if((D|0)==51){w=c[e>>2]|0;do{if((c[w+176>>2]|0)<=1){if((c[e+571288>>2]|0)!=0){break}c[e+4808>>2]=1;break a}}while(0);yDb(w,24,2328056,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}}while(0);o=e|0;q=c[o>>2]|0;L=q+176|0;if((c[L>>2]|0)<2){c[L>>2]=(c[e+4808>>2]|0)==0}L=q+796|0;M=c[B>>2]|0;if((c[L>>2]|0)==(M|0)){if((c[e+572632>>2]|0)==(c[e+6136>>2]|0)){E=I;break}}N=c[q+12>>2]|0;do{if((N|0)==0){D=64}else{if((c[N+16>>2]&128|0)==0){D=64;break}if((M|0)==8){O=e+6136|0;if((c[O>>2]|0)<=1){P=8;Q=O;break}}yDb(q,16,2324832,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);b:do{if((D|0)==64){do{if(!((M-8|0)>>>0>6>>>0)){if((M|0)==13|(M|0)==11){break}P=M;Q=e+6136|0;break b}}while(0);yDb(q,16,2334216,(x=i,i=i+8|0,c[x>>2]=M,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);c[L>>2]=P;M=c[Q>>2]|0;c[e+572632>>2]=M;q=c[B>>2]|0;c[e+4752>>2]=(q|0)>8;Gea(e+12|0,q,M);pea(e+148|0,c[e+7312>>2]|0);Soa(e+180|0,c[B>>2]|0);cia(e+4932|0,c[(c[o>>2]|0)+48>>2]|0,c[B>>2]|0,c[Q>>2]|0);Z3(e+1108|0,c[o>>2]|0);T3a(e+4|0,c[B>>2]|0);E=I}}while(0);I=c[e+6128>>2]|0;if((I|0)==66){R=c[e+7320>>2]<<8&512|66}else if((I|0)==110|(I|0)==122|(I|0)==244){R=c[e+7320>>2]<<8&2048|I}else{R=I}I=e|0;Q=c[I>>2]|0;c[Q+840>>2]=R;c[Q+844>>2]=c[e+6132>>2];R=e+6172|0;c[Q+364>>2]=c[R>>2];P=e+4812|0;do{if((c[P>>2]|0)==0){S=0}else{J=c[e+6180>>2]|0;if((J<<4|0)!=(c[Q+128>>2]|0)){S=1;break}K=c[e+6184>>2]|0;G=2-(c[e+6188>>2]|0)|0;H=ba(K<<4,G)|0;if((H|0)!=(c[Q+132>>2]|0)){S=1;break}if((c[Q+796>>2]|0)!=(c[e+7308>>2]|0)){S=1;break}if((c[e+572632>>2]|0)!=(c[e+6136>>2]|0)){S=1;break}H=c[e+6224>>2]|0;C=c[e+6228>>2]|0;p=c[Q+224>>2]|0;M=c[Q+228>>2]|0;q=gHb(M,(M|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;w=F;N=gHb(p,(p|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;if(!((q|0)==(N|0)&(w|0)==(F|0))){S=1;break}if((M|0)==0|(C|0)==0){if((H|0)==0|(p|0)==0){S=1;break}if((H>>31|0)!=(p>>31|0)){S=1;break}}if((c[e+427400>>2]|0)!=(J|0)){S=1;break}S=(c[e+427396>>2]|0)!=(ba(G,K)|0)|0}}while(0);Q=f|0;K=c[(c[Q>>2]|0)+140>>2]|0;if((K|0)==13){T=4}else if((K|0)==12){T=0}else if((K|0)==14){T=5}else{T=K}K=rda(f,0)|0;if((K|0)==12){U=0}else if((K|0)==13){U=4}else if((K|0)==14){U=5}else{U=K}K=(T|0)==(U|0);U=c[e+6180>>2]|0;T=e+427400|0;c[T>>2]=U;G=e+6188|0;J=ba(2-(c[G>>2]|0)|0,c[e+6184>>2]|0)|0;p=e+427396|0;c[p>>2]=J;H=e+427408|0;c[H>>2]=ba(J,U)|0;C=e+427404|0;c[C>>2]=U+1;c[e+6108>>2]=U<<2;c[e+4788>>2]=(c[e+6136>>2]|0)<2;M=U<<4;U=e+4768|0;c[U>>2]=M;w=J<<4;J=e+4772|0;c[J>>2]=w;N=(c[e+6204>>2]|0)+(c[e+6208>>2]|0)|0;q=M-N|0;O=(c[e+6216>>2]|0)+(c[e+6212>>2]|0)|0;V=w-O|0;if(!(N>>>0<M>>>0)){yDb(0,0,1895544,(x=i,i=i+24|0,c[x>>2]=2343400,c[x+8>>2]=2332720,c[x+16>>2]=3256,x)|0);i=x;Cd();return 0}if(!(O>>>0<w>>>0)){yDb(0,0,1895544,(x=i,i=i+24|0,c[x>>2]=2341992,c[x+8>>2]=2332720,c[x+16>>2]=3257,x)|0);i=x;Cd();return 0}O=e+6200|0;do{if((c[O>>2]|0)==0){N=c[I>>2]|0;W=c[N+120>>2]|0;if((W+15&-16|0)!=(M|0)){X=V;Y=q;break}Z=c[N+124>>2]|0;N=(Z+15&-16|0)==(w|0);X=N?Z:V;Y=N?W:q}else{X=V;Y=q}}while(0);do{if((Y|0)<1|(X|0)<1){yDb(c[I>>2]|0,16,2340928,(x=i,i=i+16|0,c[x>>2]=Y,c[x+8>>2]=X,x)|0);i=x;q=c[I>>2]|0;if((c[q+696>>2]&8|0)==0){yDb(q,24,2339560,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;TGb(O|0,0,20)|0;q=c[U>>2]|0;_=c[J>>2]|0;$=q;aa=q;break}else{y=-1094995529;i=g;return y|0}}else{_=X;$=Y;aa=M}}while(0);M=c[I>>2]|0;c[M+128>>2]=aa;Y=c[J>>2]|0;c[M+132>>2]=Y;c[M+120>>2]=$;c[M+124>>2]=_;do{if((c[e+6232>>2]|0)==0){ca=E}else{c[M+396>>2]=(c[e+6236>>2]|0)>0?2:1;if((c[e+6240>>2]|0)==0){ca=E;break}_=M+392|0;$=c[e+6252>>2]|0;X=(c[_>>2]|0)==($|0)?E:1;c[M+384>>2]=c[e+6244>>2];c[M+388>>2]=c[e+6248>>2];c[_>>2]=$;ca=X}}while(0);E=c[P>>2]|0;if((E|0)==0){D=121}else{X=c[U>>2]|0;if((X|0)==(aa|0)){if((c[J>>2]|0)==(Y|0)&(K&(S|0)==0)&(ca|0)==0){da=E}else{D=107}}else{D=107}do{if((D|0)==107){if((e|0)!=(f|0)){E=c[J>>2]|0;ca=(c[f+572376>>2]|0)+1|0;yDb(M,16,1953048,(x=i,i=i+40|0,c[x>>2]=X,c[x+8>>2]=aa,c[x+16>>2]=E,c[x+24>>2]=Y,c[x+32>>2]=ca,x)|0);i=x;y=-1094995529;i=g;return y|0}c[e+571432>>2]=-2147483648;c[e+571428>>2]=-2147483648;c[e+572412>>2]=1;iea(e);c[e+428672>>2]=0;c[e+428660>>2]=65536;c[e+428664>>2]=0;c[e+571360>>2]=-2147483648;c[e+571364>>2]=-2147483648;c[e+571368>>2]=-2147483648;c[e+571372>>2]=-2147483648;c[e+571376>>2]=-2147483648;c[e+571380>>2]=-2147483648;c[e+571384>>2]=-2147483648;c[e+571388>>2]=-2147483648;c[e+571392>>2]=-2147483648;c[e+571396>>2]=-2147483648;c[e+571400>>2]=-2147483648;c[e+571404>>2]=-2147483648;c[e+571408>>2]=-2147483648;c[e+571412>>2]=-2147483648;c[e+571416>>2]=-2147483648;c[e+571420>>2]=-2147483648;c[e+428676>>2]=-1;ca=e+2524|0;E=c[ca>>2]|0;if((E|0)!=0){c[E+2192>>2]=0;S=c[e+571288>>2]|0;c:do{if((S|0)==0){ea=0}else{K=1;$=0;_=S;O=E;while(1){if((_|0)==(O|0)){fa=$}else{c[e+571288+($<<2)>>2]=_;fa=$+1|0}q=c[e+571288+(K<<2)>>2]|0;if((q|0)==0){ea=fa;break c}K=K+1|0;$=fa;_=q;O=c[ca>>2]|0}}}while(0);c[e+571288+(ea<<2)>>2]=0}c[e+177104>>2]=0;TGb(e+199440|0,0,213504)|0;TGb(e+428696|0,0,142336)|0;mea(e);c[e+572476>>2]=-1;c[e+572480>>2]=0;c[e+199428>>2]=0;c[e+572376>>2]=0;c[e+572232>>2]=1;ca=rda(e,1)|0;if((ca|0)<0){y=ca;i=g;return y|0}E=c[I>>2]|0;c[E+140>>2]=ca;S=c[U>>2]|0;B=c[J>>2]|0;o=ZEb(ca)|0;yDb(E,32,1950704,(x=i,i=i+24|0,c[x>>2]=S,c[x+8>>2]=B,c[x+16>>2]=o,x)|0);i=x;o=sda(e,1)|0;if((o|0)>=0){da=c[P>>2]|0;break}yDb(c[I>>2]|0,16,1948856,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=o;i=g;return y|0}}while(0);if((da|0)==0){D=121}}do{if((D|0)==121){if((e|0)!=(f|0)){yDb(c[I>>2]|0,16,1946800,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1163346256;i=g;return y|0}da=rda(e,1)|0;if((da|0)<0){y=da;i=g;return y|0}c[(c[I>>2]|0)+140>>2]=da;da=sda(e,0)|0;if((da|0)>=0){break}yDb(c[I>>2]|0,16,1948856,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=da;i=g;return y|0}}while(0);do{if((e|0)==(f|0)){da=e+428628|0;if((c[da>>2]|0)==(A|0)){break}c[da>>2]=A;Sca(e)}}while(0);da=e+6144|0;P=c[da>>2]|0;J=c[m>>2]|0;U=c[k>>2]|0;ea=U+(J>>>3)|0;fa=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(J&7)>>>((32-P|0)>>>0);ea=J+P|0;c[m>>2]=ea;J=e+428656|0;c[J>>2]=fa;c[e+177096>>2]=0;Y=e+177088|0;c[Y>>2]=0;aa=f+177100|0;X=c[aa>>2]|0;M=c[f+4796>>2]|0;o=e+427432|0;B=(c[o>>2]|0)==0|0;S=e+4796|0;c[S>>2]=B;do{if((c[G>>2]|0)==0){if((c[e+6196>>2]|0)==0&(z|0)==1){yDb(c[I>>2]|0,16,1944712,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1;i=g;return y|0}E=d[U+(ea>>>3)|0]|0;ca=ea+1|0;c[m>>2]=ca;if((E&128>>>((ea&7)>>>0)|0)==0){c[e+177100>>2]=3;c[Y>>2]=c[e+6192>>2];ga=3;break}else{E=d[U+(ca>>>3)|0]<<(ca&7)>>>7;c[m>>2]=ea+2;ca=(E&1)+1|0;c[e+177100>>2]=ca;ga=ca;break}}else{c[e+177100>>2]=3;ga=3}}while(0);ea=e+177100|0;c[e+177092>>2]=(ga|0)!=3;U=f+572376|0;G=c[U>>2]|0;do{if((G|0)==0){ca=e+428676|0;E=c[ca>>2]|0;do{if((fa|0)!=(E|0)){L=1<<P;O=c[R>>2]|0;if((fa-E+((E|0)>(fa|0)?L:0)|0)<=(O|0)){break}_=fa-O-1|0;c[ca>>2]=((_|0)<0?L:0)+_}}while(0);E=f+177104|0;do{if((c[E>>2]|0)!=0){_=f+2524|0;L=c[_>>2]|0;if((c[L+1500>>2]|0)==(c[Q>>2]|0)){Y0a(L+1496|0,2147483647,(X|0)==2|0);ha=c[ea>>2]|0}else{ha=ga}if((ha|0)==3|(ha|0)==(X|0)){if((X|0)==3){break}Y0a((c[_>>2]|0)+1496|0,2147483647,(X|0)==1|0);break}L=c[_>>2]|0;if((c[L+1616>>2]|0)!=(c[J>>2]|0)){if((X|0)==3){break}Y0a(L+1496|0,2147483647,(X|0)==1|0);break}do{if(!((X|0)==1&(ha|0)==2)){if((X|0)==2&(ha|0)==1){break}yDb(c[I>>2]|0,16,1931720,(x=i,i=i+16|0,c[x>>2]=X,c[x+8>>2]=ha,x)|0);i=x;c[ea>>2]=X;c[S>>2]=M;y=-1094995529;i=g;return y|0}}while(0);if((M|0)==(c[S>>2]|0)){break}DDb(c[I>>2]|0,1929896,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;c[ea>>2]=X;c[S>>2]=M;y=-1163346256;i=g;return y|0}}while(0);L=c[J>>2]|0;_=c[ca>>2]|0;d:do{if((L|0)==(_|0)){ia=L;D=178}else{O=e+572240|0;$=e+6176|0;K=e+2524|0;q=e+571436|0;V=e+572228|0;w=e+571032|0;W=L;N=_;while(1){if((c[E>>2]|0)!=0){D=161;break}if((W|0)==((N+1|0)%(1<<c[da>>2]|0)|0|0)){ia=W;D=178;break d}if((c[O>>2]|0)==0){ja=0}else{ja=c[w>>2]|0}yDb(c[I>>2]|0,48,1928200,(x=i,i=i+16|0,c[x>>2]=W,c[x+8>>2]=N,x)|0);i=x;if((c[$>>2]|0)==0){c[e+571360>>2]=-2147483648;c[e+571364>>2]=-2147483648;c[e+571368>>2]=-2147483648;c[e+571372>>2]=-2147483648;c[e+571376>>2]=-2147483648;c[e+571380>>2]=-2147483648;c[e+571384>>2]=-2147483648;c[e+571388>>2]=-2147483648;c[e+571392>>2]=-2147483648;c[e+571396>>2]=-2147483648;c[e+571400>>2]=-2147483648;c[e+571404>>2]=-2147483648;c[e+571408>>2]=-2147483648;c[e+571412>>2]=-2147483648;c[e+571416>>2]=-2147483648;c[e+571420>>2]=-2147483648}ka=tda(e)|0;if((ka|0)<0){D=168;break}Z=((c[ca>>2]|0)+1|0)%(1<<c[da>>2]|0)|0;c[ca>>2]=Z;la=c[K>>2]|0;c[la+1616>>2]=Z;c[la+2204>>2]=(c[$>>2]|0)==0;Y0a(la+1496|0,2147483647,0);Y0a((c[K>>2]|0)+1496|0,2147483647,1);la=jea(e,1)|0;if((la|0)<0){if((c[(c[I>>2]|0)+696>>2]&8|0)!=0){y=la;D=372;break}}la=kea(e,q,c[V>>2]|0)|0;if((la|0)<0){if((c[(c[I>>2]|0)+696>>2]&8|0)!=0){y=la;D=372;break}}if((c[O>>2]|0)!=0){la=c[w>>2]|0;if((ja|0)==0){ma=la}else{jDb(la|0,la+32|0,ja|0,ja+32|0,c[(c[I>>2]|0)+140>>2]|0,c[T>>2]<<4,c[p>>2]<<4);la=c[w>>2]|0;c[la+1612>>2]=(c[ja+1612>>2]|0)+2;ma=la}c[ma+1616>>2]=c[ca>>2]}la=c[J>>2]|0;Z=c[ca>>2]|0;if((la|0)==(Z|0)){ia=la;D=178;break d}else{W=la;N=Z}}if((D|0)==161){N=c[ea>>2]|0;na=N;oa=(N|0)!=3;pa=W;D=179;break}else if((D|0)==168){c[E>>2]=0;y=ka;i=g;return y|0}else if((D|0)==372){i=g;return y|0}}}while(0);do{if((D|0)==178){ca=c[ea>>2]|0;_=(ca|0)!=3;if((c[E>>2]|0)!=0){na=ca;oa=_;pa=ia;D=179;break}ca=_&1;c[E>>2]=ca;qa=ca}}while(0);do{if((D|0)==179){ca=f+2524|0;if((na|0)==(X|0)|oa^1){c[ca>>2]=0;_=(na|0)!=3|0;c[E>>2]=_;qa=_;break}_=c[ca>>2]|0;if((c[_+1616>>2]|0)==(pa|0)){c[E>>2]=0;qa=0;break}else{Y0a(_+1496|0,2147483647,(c[aa>>2]|0)==2|0);c[E>>2]=1;c[ca>>2]=0;qa=1;break}}}while(0);do{if((c[ea>>2]|0)!=3&(qa|0)==0){ca=e+2520|0;_=e+2524|0;L=0;do{N=c[ca>>2]|0;w=N+(L*2224|0)|0;do{if((c[N+(L*2224|0)+360>>2]|0)!=0){if((c[N+(L*2224|0)+2192>>2]|0)!=0){break}if((w|0)==(c[_>>2]|0)){break}ida(e,w)}}while(0);L=L+1|0;}while((L|0)<36)}else{if((tda(e)|0)>=0){break}c[E>>2]=0;y=-1094995529;i=g;return y|0}}while(0);E=c[ea>>2]|0;do{if((E|0)==3){TGb(c[e+177072>>2]|0,-1|0,(ba(c[p>>2]<<1,c[C>>2]|0)|0)-2|0)|0}else{L=(E|0)==2|0;_=c[p>>2]|0;if(!(L>>>0<_>>>0)){break}ca=e+177072|0;W=L;L=_;while(1){_=c[C>>2]|0;w=W+1|0;TGb((c[ca>>2]|0)+((ba(_,W)|0)<<1)|0,-1|0,_-((w|0)==(L|0))<<1|0)|0;_=c[p>>2]|0;if(w>>>0<_>>>0){W=w;L=_}else{break}}}}while(0);c[f+572396>>2]=-1}else{if(!((X|0)==(ga|0)&(M|0)==(B|0))){yDb(c[I>>2]|0,16,1942344,(x=i,i=i+16|0,c[x>>2]=X,c[x+8>>2]=ga,x)|0);i=x;c[ea>>2]=X;c[S>>2]=M;y=-1094995529;i=g;return y|0}if((c[f+2524>>2]|0)!=0){break}yDb(c[I>>2]|0,16,1934320,(x=i,i=i+8|0,c[x>>2]=G+1,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);G=(e|0)!=(f|0);if(G){UGb(e+5716|0,f+5716|0,384)|0;c[e+2524>>2]=c[f+2524>>2];UGb(e+2528|0,f+2528|0,2224)|0;c[e+4776>>2]=c[f+4776>>2];c[e+4780>>2]=c[f+4780>>2];c[e+177104>>2]=c[f+177104>>2];c[e+428660>>2]=c[f+428660>>2];c[e+428664>>2]=c[f+428664>>2];c[e+428672>>2]=c[f+428672>>2];c[e+428676>>2]=c[f+428676>>2];c[e+572240>>2]=c[f+572240>>2];UGb(e+571032|0,f+571032|0,128)|0;UGb(e+571160|0,f+571160|0,128)|0;UGb(e+428696|0,f+428696|0,142336)|0;M=e+177020|0;S=f+177020|0;c[M>>2]=c[S>>2];c[M+4>>2]=c[S+4>>2];c[M+8>>2]=c[S+8>>2];c[M+12>>2]=c[S+12>>2];c[M+16>>2]=c[S+16>>2];c[M+20>>2]=c[S+20>>2];S=e+177044|0;M=f+177044|0;c[S>>2]=c[M>>2];c[S+4>>2]=c[M+4>>2];c[S+8>>2]=c[M+8>>2];c[S+12>>2]=c[M+12>>2];c[S+16>>2]=c[M+16>>2];c[S+20>>2]=c[M+20>>2]}M=e+572384|0;S=c[M>>2]|0;e:do{if((S|0)!=0){X=e+4776|0;ga=0;B=S;f:while(1){p=c[e+572248+(ga<<2)>>2]|0;do{if((p|0)==0){ra=B}else{C=c[X>>2]|0;qa=((C|0)>-1?C:-C|0)+63&-32;sa=p+572636|0;if((c[sa>>2]|0)!=0){ra=B;break}c[sa>>2]=WDb(qa*96|0)|0;ta=p+572684|0;c[ta>>2]=cEb(qa*42|0)|0;C=cEb(qa<<6)|0;ua=p+768|0;c[ua>>2]=C;if((c[sa>>2]|0)==0){break f}if((c[ta>>2]|0)==0|(C|0)==0){break f}c[p+784>>2]=C;ra=c[M>>2]|0}}while(0);p=ga+1|0;if(p>>>0<ra>>>0){ga=p;B=ra}else{break e}}$Db(sa);$Db(ta);$Db(ua);y=-12;i=g;return y|0}}while(0);ua=e+2524|0;ta=c[ua>>2]|0;c[ta+1616>>2]=c[J>>2];sa=(c[Y>>2]|0)==0;if(sa){va=(c[ea>>2]|0)!=3|0}else{va=1}ra=c[H>>2]|0;if(!(u<<va>>>0<ra>>>0&u>>>0<ra>>>0)){yDb(c[I>>2]|0,16,1926496,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=g;return y|0}ra=c[T>>2]|0;T=(u>>>0)%(ra>>>0)|0;c[e+427376>>2]=T;c[e+427384>>2]=T;T=c[ea>>2]|0;if(sa){wa=(T|0)!=3|0}else{wa=1}sa=((u>>>0)/(ra>>>0)|0)<<wa;wa=e+427380|0;c[wa>>2]=sa;ra=e+427388|0;c[ra>>2]=sa;do{if((T|0)==2){va=sa+1|0;c[wa>>2]=va;c[ra>>2]=va;xa=c[J>>2]|0;D=221}else{va=c[J>>2]|0;if((T|0)!=3){xa=va;D=221;break}c[e+428680>>2]=va;c[e+428684>>2]=1<<c[da>>2];ya=0}}while(0);if((D|0)==221){c[e+428680>>2]=xa<<1|1;c[e+428684>>2]=1<<(c[da>>2]|0)+1;ya=1}do{if((c[r>>2]|0)==5){da=c[m>>2]|0;xa=(c[k>>2]|0)+(da>>>3)|0;T=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(da&7);if(T>>>0>134217727>>>0){c[m>>2]=(d[1213744+(T>>>23)|0]|0)+da;break}xa=T>>>0>65535>>>0;wa=xa?T>>>16:T;T=xa?16:0;if((wa&65280|0)==0){za=T;Aa=wa}else{za=T|8;Aa=wa>>>8}c[m>>2]=da+63-((d[1191992+Aa|0]|0)+za<<1)}}while(0);za=c[e+6148>>2]|0;do{if((za|0)==0){Aa=c[e+6152>>2]|0;da=c[m>>2]|0;wa=c[k>>2]|0;T=wa+(da>>>3)|0;xa=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(da&7)>>>((32-Aa|0)>>>0);T=da+Aa|0;c[m>>2]=T;c[e+428636>>2]=xa;if((c[e+7336>>2]|0)!=1|ya){break}xa=wa+(T>>>3)|0;Aa=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(T&7);if(Aa>>>0>134217727>>>0){xa=Aa>>>23;c[m>>2]=(d[1213744+xa|0]|0)+T;Ba=a[1139096+xa|0]|0}else{xa=Aa>>>0>65535>>>0;da=xa?Aa>>>16:Aa;Aa=xa?16:0;if((da&65280|0)==0){Ca=Aa;Da=da}else{Ca=Aa|8;Da=da>>>8}da=(d[1191992+Da|0]|0)+Ca|0;Aa=31-da+T|0;T=wa+(Aa>>>3)|0;wa=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(Aa&7)>>>(da>>>0);c[m>>2]=32-da+Aa;Aa=wa>>>1;Ba=(wa&1|0)==0?Aa:-Aa|0}c[e+428644>>2]=Ba;if((za|0)==1){D=236}}else if((za|0)==1){D=236}}while(0);do{if((D|0)==236){if((c[e+6156>>2]|0)!=0){break}za=c[m>>2]|0;Ba=c[k>>2]|0;Ca=Ba+(za>>>3)|0;Da=(fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(za&7);if(Da>>>0>134217727>>>0){Ca=Da>>>23;Aa=(d[1213744+Ca|0]|0)+za|0;c[m>>2]=Aa;Ea=a[1139096+Ca|0]|0;Fa=Aa}else{Aa=Da>>>0>65535>>>0;Ca=Aa?Da>>>16:Da;Da=Aa?16:0;if((Ca&65280|0)==0){Ga=Da;Ha=Ca}else{Ga=Da|8;Ha=Ca>>>8}Ca=(d[1191992+Ha|0]|0)+Ga|0;Da=31-Ca+za|0;za=Ba+(Da>>>3)|0;Aa=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Da&7)>>>(Ca>>>0);za=32-Ca+Da|0;c[m>>2]=za;Da=Aa>>>1;Ea=(Aa&1|0)==0?Da:-Da|0;Fa=za}c[e+428648>>2]=Ea;if((c[e+7336>>2]|0)!=1|ya){break}za=Ba+(Fa>>>3)|0;Da=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Fa&7);if(Da>>>0>134217727>>>0){za=Da>>>23;c[m>>2]=(d[1213744+za|0]|0)+Fa;Ia=a[1139096+za|0]|0}else{za=Da>>>0>65535>>>0;Aa=za?Da>>>16:Da;Da=za?16:0;if((Aa&65280|0)==0){Ja=Da;Ka=Aa}else{Ja=Da|8;Ka=Aa>>>8}Aa=(d[1191992+Ka|0]|0)+Ja|0;Da=31-Aa+Fa|0;za=Ba+(Da>>>3)|0;Ba=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Da&7)>>>(Aa>>>0);c[m>>2]=32-Aa+Da;Da=Ba>>>1;Ia=(Ba&1|0)==0?Da:-Da|0}c[e+428652>>2]=Ia}}while(0);dda(e,ta+1604|0,ta+1612|0)|0;if((c[e+7388>>2]|0)!=0){ta=c[m>>2]|0;Ia=(c[k>>2]|0)+(ta>>>3)|0;Fa=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(ta&7);if(Fa>>>0>134217727>>>0){Ia=Fa>>>23;c[m>>2]=(d[1213744+Ia|0]|0)+ta;La=d[1108392+Ia|0]|0}else{Ia=Fa>>>0>65535>>>0;Ja=Ia?Fa>>>16:Fa;Ka=Ia?16:0;if((Ja&65280|0)==0){Ma=Ka;Na=Ja}else{Ma=Ka|8;Na=Ja>>>8}Ja=(d[1191992+Na|0]|0)+Ma<<1;c[m>>2]=ta+63-Ja;La=(Fa>>>((Ja-31|0)>>>0))-1|0}c[e+428688>>2]=La}La=eda(e)|0;if((La|0)<0){y=La;i=g;return y|0}g:do{if((z|0)!=2){do{if((c[U>>2]|0)!=0){if((t|0)!=(c[f+572396>>2]|0)){break}if((PGb(f+572400|0,f+199420|0,8)|0)==0){break g}}}while(0);eea(e)|0}}while(0);do{if((c[l>>2]|0)!=1){z=gea(e)|0;if((z|0)>=0){break}c[e+199420>>2]=0;c[e+199424>>2]=0;y=z;i=g;return y|0}}while(0);if((c[e+7356>>2]|0)==0){D=267}else{if((c[l>>2]|0)==2){D=269}else{D=267}}h:do{if((D|0)==267){z=c[e+7360>>2]|0;do{if((z|0)==1){if((c[l>>2]|0)==3){D=269;break h}}else if((z|0)==2){if((c[l>>2]|0)!=3){break}uda(e,-1);break h}}while(0);c[e+177120>>2]=0;TGb(e+572484|0,0,16)|0}}while(0);if((D|0)==269){cda(e)|0}do{if((c[o>>2]|0)!=0){if((c[(c[I>>2]|0)+816>>2]&1|0)==0){Oa=1}else{Oa=(c[U>>2]|0)==0|0}if((lea(f,j,Oa)|0)>=0){break}if((c[(c[I>>2]|0)+696>>2]&8|0)==0){break}else{y=-1094995529}i=g;return y|0}}while(0);do{if((c[Y>>2]|0)==0){D=282}else{hea(e);if((c[e+7360>>2]|0)!=2){D=282;break}if((c[l>>2]|0)!=3){break}uda(e,0);uda(e,1);D=282}}while(0);do{if((D|0)==282){if((c[l>>2]|0)!=3){break}if((c[e+197872>>2]|0)!=0){break}Vda(e)}}while(0);Wda(e);Y=c[l>>2]|0;l=(Y|0)==1;do{if(!l){if((c[e+7332>>2]|0)==0){break}Oa=c[m>>2]|0;j=(c[k>>2]|0)+(Oa>>>3)|0;z=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(Oa&7)>>>23;c[m>>2]=(d[1213744+z|0]|0)+Oa;Oa=a[1108392+z|0]|0;z=Oa&255;if(!((Oa&255)>>>0>2>>>0)){c[e+572244>>2]=z;break}yDb(c[I>>2]|0,16,1924912,(x=i,i=i+8|0,c[x>>2]=z,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);c[e+426580>>2]=0;z=c[e+7364>>2]|0;Oa=c[m>>2]|0;j=c[k>>2]|0;k=j+(Oa>>>3)|0;La=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Oa&7);if(La>>>0>134217727>>>0){k=La>>>23;Ja=(d[1213744+k|0]|0)+Oa|0;c[m>>2]=Ja;Pa=a[1139096+k|0]|0;Qa=Ja}else{Ja=La>>>0>65535>>>0;k=Ja?La>>>16:La;La=Ja?16:0;if((k&65280|0)==0){Ra=La;Sa=k}else{Ra=La|8;Sa=k>>>8}k=(d[1191992+Sa|0]|0)+Ra|0;Ra=31-k+Oa|0;Oa=j+(Ra>>>3)|0;Sa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Ra&7)>>>(k>>>0);Oa=32-k+Ra|0;c[m>>2]=Oa;Ra=Sa>>>1;Pa=(Sa&1|0)==0?Ra:-Ra|0;Qa=Oa}Oa=Pa+z|0;z=e+7308|0;Pa=c[z>>2]|0;if(Oa>>>0>((Pa*6|0)+3|0)>>>0){yDb(c[I>>2]|0,16,1923336,(x=i,i=i+8|0,c[x>>2]=Oa,x)|0);i=x;y=-1094995529;i=g;return y|0}Ra=e+4792|0;c[Ra>>2]=Oa;c[e+4756>>2]=d[e+7876+Oa|0]|0;c[e+4760>>2]=d[e+7964+Oa|0]|0;Oa=c[v>>2]|0;if((Oa|0)==6){Sa=Qa+1|0;c[m>>2]=Sa;Ta=Sa;D=300}else{if((Oa-5|0)>>>0<2>>>0){Ta=Qa;D=300}else{Ua=Qa}}do{if((D|0)==300){Qa=j+(Ta>>>3)|0;Oa=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Ta&7);if(Oa>>>0>134217727>>>0){Qa=(d[1213744+(Oa>>>23)|0]|0)+Ta|0;c[m>>2]=Qa;Ua=Qa;break}Qa=Oa>>>0>65535>>>0;Sa=Qa?Oa>>>16:Oa;Oa=Qa?16:0;if((Sa&65280|0)==0){Va=Oa;Wa=Sa}else{Va=Oa|8;Wa=Sa>>>8}Sa=Ta+63+(((d[1191992+Wa|0]|0)+Va|0)*-2|0)|0;c[m>>2]=Sa;Ua=Sa}}while(0);Va=e+427420|0;c[Va>>2]=1;Wa=e+427424|0;c[Wa>>2]=0;Ta=e+427428|0;c[Ta>>2]=0;do{if((c[e+7380>>2]|0)==0){Xa=1;Ya=0;Za=0}else{Sa=j+(Ua>>>3)|0;Oa=(fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ua&7)>>>23;Sa=(d[1213744+Oa|0]|0)+Ua|0;c[m>>2]=Sa;Qa=a[1108392+Oa|0]|0;Oa=Qa&255;if((Qa&255)>>>0>2>>>0){yDb(c[I>>2]|0,16,1921616,(x=i,i=i+8|0,c[x>>2]=Oa,x)|0);i=x;y=-1094995529;i=g;return y|0}k=(Qa&255)>>>0<2>>>0|0;Qa=k^Oa;c[Va>>2]=Qa;if((Oa|0)==(k|0)){Xa=Qa;Ya=0;Za=0;break}k=j+(Sa>>>3)|0;Oa=(fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Sa&7);if(Oa>>>0>134217727>>>0){k=Oa>>>23;La=(d[1213744+k|0]|0)+Sa|0;c[m>>2]=La;_a=a[1139096+k|0]|0;$a=La}else{La=Oa>>>0>65535>>>0;k=La?Oa>>>16:Oa;Oa=La?16:0;if((k&65280|0)==0){ab=Oa;bb=k}else{ab=Oa|8;bb=k>>>8}k=(d[1191992+bb|0]|0)+ab|0;Oa=31-k+Sa|0;Sa=j+(Oa>>>3)|0;La=(fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Oa&7)>>>(k>>>0);Sa=32-k+Oa|0;c[m>>2]=Sa;Oa=La>>>1;_a=(La&1|0)==0?Oa:-Oa|0;$a=Sa}Sa=_a<<1;c[Wa>>2]=Sa;Oa=j+($a>>>3)|0;La=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<($a&7);if(La>>>0>134217727>>>0){Oa=La>>>23;c[m>>2]=(d[1213744+Oa|0]|0)+$a;cb=a[1139096+Oa|0]|0}else{Oa=La>>>0>65535>>>0;k=Oa?La>>>16:La;La=Oa?16:0;if((k&65280|0)==0){db=La;eb=k}else{db=La|8;eb=k>>>8}k=(d[1191992+eb|0]|0)+db|0;La=31-k+$a|0;Oa=j+(La>>>3)|0;Ja=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(La&7)>>>(k>>>0);c[m>>2]=32-k+La;La=Ja>>>1;cb=(Ja&1|0)==0?La:-La|0}La=cb<<1;c[Ta>>2]=La;if(!((Sa+12|0)>>>0>24>>>0|(La|0)>12|(La|0)<-12)){Xa=Qa;Ya=Sa;Za=La;break}yDb(c[I>>2]|0,16,1919688,(x=i,i=i+16|0,c[x>>2]=Sa,c[x+8>>2]=La,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);cb=c[I>>2]|0;m=c[cb+848>>2]|0;do{if((m|0)>47){D=326}else{if(!((m|0)<32|l)){D=326;break}if((m|0)>15&(Y|0)==3){D=326;break}if((m|0)>7){if((c[o>>2]|0)==0){D=326;break}}if((Xa|0)!=1){fb=Ya;gb=Za;hb=Pa;break}j=f+572380|0;if((c[j>>2]|0)<=1){fb=Ya;gb=Za;hb=Pa;break}if((c[cb+92>>2]&1|0)!=0){c[Va>>2]=2;fb=Ya;gb=Za;hb=Pa;break}c[j>>2]=1;j=f+572388|0;if((c[j>>2]|0)==0){yDb(cb,32,1917928,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;c[j>>2]=1}if(!G){fb=c[Wa>>2]|0;gb=c[Ta>>2]|0;hb=c[z>>2]|0;break}yDb(c[I>>2]|0,16,1911336,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=1;i=g;return y|0}}while(0);if((D|0)==326){c[Va>>2]=0;fb=Ya;gb=Za;hb=Pa}Pa=c[e+7372>>2]|0;Za=(Pa|0)<0?0:Pa;Pa=c[e+7376>>2]|0;c[e+4764>>2]=-33-((fb|0)>(gb|0)?gb:fb)+(hb*6|0)-((Za|0)>(Pa|0)?Za:Pa);c[f+572396>>2]=t;t=f+199420|0;Pa=f+572400|0;Za=c[t+4>>2]|0;c[Pa>>2]=c[t>>2];c[Pa+4>>2]=Za;Za=c[U>>2]|0;Pa=Za+1|0;c[U>>2]=Pa;U=e+177068|0;c[U>>2]=Pa;t=c[ra>>2]|0;if((Pa|0)!=0){b[f+572640+((Za&15)<<1)>>1]=t}Za=b[f+572640+((Pa&15)<<1)>>1]|0;if((Za|0)<=(t|0)&(Za+3|0)>=(t|0)&(Pa|0)>15){yDb(c[I>>2]|0,24,1909136,(x=i,i=i+16|0,c[x>>2]=Pa,c[x+8>>2]=16,x)|0);i=x}Pa=e+199428|0;t=e+572240|0;Za=e+572236|0;ra=0;do{hb=c[U>>2]&15;fb=e+199420+(ra<<2)|0;gb=c[Pa>>2]|0;Ya=0;do{z=h+(Ya<<2)|0;c[z>>2]=60;i:do{if(ra>>>0<gb>>>0){if(!(Ya>>>0<(c[fb>>2]|0)>>>0)){break}G=c[e+199440+(ra*106752|0)+(Ya*2224|0)+360>>2]|0;if((G|0)==0){break}cb=c[G>>2]|0;G=c[t>>2]|0;Xa=0;while(1){if((Xa|0)>=(G|0)){break}if((c[c[(c[e+571032+(Xa<<2)>>2]|0)+360>>2]>>2]|0)==(cb|0)){D=348;break}else{Xa=Xa+1|0}}if((D|0)==348){D=0;c[z>>2]=Xa}o=c[Za>>2]|0;if((o|0)>0){ib=0}else{break}while(1){m=c[e+571160+(ib<<2)>>2]|0;if((m|0)!=0){if((c[c[m+360>>2]>>2]|0)==(cb|0)){break}}m=ib+1|0;if((m|0)<(o|0)){ib=m}else{break i}}c[z>>2]=G+ib}}while(0);Ya=Ya+1|0;}while(Ya>>>0<16>>>0);c[e+412944+(hb<<9)+(ra<<8)+4>>2]=-1;c[e+412944+(hb<<9)+(ra<<8)>>2]=-1;Ya=0;do{c[e+412944+(hb<<9)+(ra<<8)+(Ya+2<<2)>>2]=c[e+199440+(ra*106752|0)+(Ya*2224|0)+2192>>2]&3|c[h+(Ya<<2)>>2]<<2;Ya=Ya+1|0;}while(Ya>>>0<16>>>0);c[e+412944+(hb<<9)+(ra<<8)+76>>2]=-1;c[e+412944+(hb<<9)+(ra<<8)+72>>2]=-1;Ya=16;do{c[e+412944+(hb<<9)+(ra<<8)+(Ya+4<<2)>>2]=c[e+199440+(ra*106752|0)+(Ya*2224|0)+2192>>2]&3|c[h+((Ya-16|0)>>>1<<2)>>2]<<2;Ya=Ya+1|0;}while(Ya>>>0<48>>>0);ra=ra+1|0;}while(ra>>>0<2>>>0);ra=e+199420|0;h=c[ra>>2]|0;if((h|0)!=0){c[e+2488>>2]=e+199440}ib=e+199424|0;if((c[ib>>2]|0)!=0){c[e+2492>>2]=e+306192}c[e+2508>>2]=h;c[n>>2]=A;c[(c[f+427476+(c[s>>2]<<2)>>2]|0)+1200>>2]=0;c[e+7324>>2]=0;c[e+6120>>2]=c[s>>2];s=c[I>>2]|0;if((c[s+688>>2]&1|0)==0){y=0;i=g;return y|0}I=c[U>>2]|0;U=c[ea>>2]|0;if((U|0)==3){jb=1906080}else{jb=(U|0)==1?1904320:1902808}U=(mGb(c[v>>2]|0)|0)<<24>>24;ea=(c[e+177084>>2]|0)!=0?1901656:9203376;f=(c[r>>2]|0)==5?1900280:9203376;r=c[J>>2]|0;J=c[ua>>2]|0;ua=c[J+1604>>2]|0;n=c[J+1608>>2]|0;J=c[ra>>2]|0;ra=c[ib>>2]|0;ib=c[Ra>>2]|0;Ra=c[Va>>2]|0;Va=c[Wa>>2]|0;Wa=c[Ta>>2]|0;Ta=c[e+177120>>2]|0;if((Ta|0)==1){kb=(c[e+177124>>2]|0)!=0?1899144:9203376}else{kb=9203376}if((c[v>>2]|0)==3){lb=(c[e+197872>>2]|0)!=0?1897248:1890896}else{lb=9203376}yDb(s,48,1907632,(x=i,i=i+152|0,c[x>>2]=I,c[x+8>>2]=jb,c[x+16>>2]=u,c[x+24>>2]=U,c[x+32>>2]=ea,c[x+40>>2]=f,c[x+48>>2]=A,c[x+56>>2]=r,c[x+64>>2]=ua,c[x+72>>2]=n,c[x+80>>2]=J,c[x+88>>2]=ra,c[x+96>>2]=ib,c[x+104>>2]=Ra,c[x+112>>2]=Va,c[x+120>>2]=Wa,c[x+128>>2]=Ta,c[x+136>>2]=kb,c[x+144>>2]=lb,x)|0);i=x;y=0;i=g;return y|0}function nda(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=a;f=c[a>>2]|0;g=a+427380|0;if((c[g>>2]|0)>=(c[a+427396>>2]|0)){yDb(0,0,1895544,(h=i,i=i+24|0,c[h>>2]=1991824,c[h+8>>2]=2332720,c[h+16>>2]=4731,h)|0);i=h;Cd()}if((c[f+712>>2]|0)!=0){i=d;return}if((c[(c[f+12>>2]|0)+16>>2]&128|0)!=0){i=d;return}if((b|0)==0){yDb(0,0,1895544,(h=i,i=i+24|0,c[h>>2]=1988352,c[h+8>>2]=2332720,c[h+16>>2]=4739,h)|0);i=h;Cd()}else if((b|0)==1){oda(f,e)|0;i=d;return}else{e=a+427372|0;h=1;do{j=c[a+572248+(h<<2)>>2]|0;c[j+2384>>2]=0;c[j+427372>>2]=c[e>>2];h=h+1|0;}while(h>>>0<b>>>0);oe[c[f+824>>2]&63](f,748,a+572248|0,0,b,4)|0;f=c[a+572248+(b-1<<2)>>2]|0;c[a+427376>>2]=c[f+427376>>2];c[g>>2]=c[f+427380>>2];c[a+4796>>2]=c[f+4796>>2];c[a+177100>>2]=c[f+177100>>2];f=a+2384|0;g=1;h=c[f>>2]|0;do{h=h+(c[(c[a+572248+(g<<2)>>2]|0)+2384>>2]|0)|0;c[f>>2]=h;g=g+1|0;}while(g>>>0<b>>>0);i=d;return}}function oda(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;g=i;h=c[f>>2]|0;f=h;j=h+427376|0;k=c[j>>2]|0;l=h+427392|0;c[l>>2]=-1;if((c[h+5776>>2]|0)!=(((c[h+4776>>2]|0)*12|0)+(12<<c[h+4752>>2])|0)){yDb(0,0,1895544,(m=i,i=i+24|0,c[m>>2]=1983904,c[m+8>>2]=2332720,c[m+16>>2]=4550,m)|0);i=m;Cd();return 0}n=h+177088|0;do{if((c[n>>2]|0)==0){if((c[h+177100>>2]|0)!=3){o=1;break}o=(c[b+48>>2]|0)!=28|0}else{o=1}}while(0);c[h+427416>>2]=o;o=h;do{if((c[(c[o>>2]|0)+816>>2]&2|0)==0){if((c[h+177100>>2]|0)!=3){break}b=c[h+2392>>2]|0;if((b|0)==0){break}p=(ba(c[h+427400>>2]|0,c[h+427388>>2]|0)|0)+(c[h+427384>>2]|0)|0;q=(c[h+427408>>2]|0)-1|0;if((p|0)<0){break}r=(p|0)>(q|0)?q:p;if((r|0)==0){break}if((a[b+(c[(c[h+2360>>2]|0)+(r-1<<2)>>2]|0)|0]&-2)<<24>>24==112){break}c[h+2388>>2]=1}}while(0);if((c[h+7332>>2]|0)==0){r=Rda(f)|0;a:do{if((r|0)>-1){b=h+427400|0;p=h+1096|0;q=h+1100|0;s=h+427380|0;t=h+177100|0;u=h+427396|0;v=h+427404|0;w=h+177072|0;x=h+177068|0;y=h+4064|0;z=h+177092|0;A=h+177096|0;B=k;C=r;while(1){Yca(f);if((c[n>>2]|0)==0){D=C}else{c[s>>2]=(c[s>>2]|0)+1;E=Rda(f)|0;if((E|0)>-1){Yca(f)}c[s>>2]=(c[s>>2]|0)-1;D=E}if((D|0)<0){F=D;G=s;break a}E=(c[j>>2]|0)+1|0;c[j>>2]=E;if((E|0)<(c[b>>2]|0)){H=B}else{pda(f,B,E);c[j>>2]=0;qda(f);E=c[s>>2]|0;I=E+1|0;c[s>>2]=I;do{if((c[n>>2]|0)==0){if((c[t>>2]|0)==3){J=I;break}K=E+2|0;c[s>>2]=K;J=K}else{K=E+2|0;c[s>>2]=K;if((K|0)>=(c[u>>2]|0)){J=K;break}L=c[v>>2]|0;M=(ba(L,K)|0)+(c[j>>2]|0)|0;N=M-1|0;O=c[w>>2]|0;P=c[x>>2]|0;do{if((e[O+(N<<1)>>1]|0|0)==(P|0)){Q=c[(c[y>>2]|0)+(N<<2)>>2]|0}else{R=M-L|0;if((e[O+(R<<1)>>1]|0|0)!=(P|0)){Q=0;break}Q=c[(c[y>>2]|0)+(R<<2)>>2]|0}}while(0);P=Q>>>7&1;c[z>>2]=P;c[A>>2]=P;J=K}}while(0);if((J|0)<(c[u>>2]|0)){H=0}else{S=70;break}}T=c[p>>2]|0;U=c[q>>2]|0;if((U-T|0)<1){if((c[l>>2]|0)<1){S=78;break}}E=Rda(f)|0;if((E|0)>-1){B=H;C=E}else{F=E;G=s;break a}}if((S|0)==70){C=c[p>>2]|0;B=c[q>>2]|0;do{if((B|0)!=(C|0)){if((B-C|0)>0){if((c[(c[o>>2]|0)+696>>2]&262144|0)==0){break}}Lkb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,c[j>>2]|0,J,112);V=-1094995529;i=g;return V|0}}while(0);Lkb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,(c[j>>2]|0)-1|0,J,112);V=0;i=g;return V|0}else if((S|0)==78){C=c[h+427384>>2]|0;B=c[h+427388>>2]|0;q=c[j>>2]|0;if((U|0)!=(T|0)){Lkb(h+2352|0,C,B,q,c[s>>2]|0,14);V=-1094995529;i=g;return V|0}Lkb(h+2352|0,C,B,q-1|0,c[s>>2]|0,112);q=c[j>>2]|0;if((q|0)<=(H|0)){V=0;i=g;return V|0}pda(f,H,q);V=0;i=g;return V|0}}else{F=r;G=h+427380|0}}while(0);r=c[G>>2]|0;yDb(c[o>>2]|0,16,1975816,(m=i,i=i+16|0,c[m>>2]=c[j>>2],c[m+8>>2]=r,m)|0);i=m;Lkb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,c[j>>2]|0,c[G>>2]|0,14);V=F;i=g;return V|0}F=h+1096|0;G=c[F>>2]|0;r=-G&7;if((r|0)==0){W=G}else{H=r+G|0;c[F>>2]=H;W=H}H=h+425488|0;Uhb(H,(c[h+1088>>2]|0)+((W|0)/8|0)|0,(7-W+(c[h+1100>>2]|0)|0)/8|0);Eda(f);W=h+427380|0;F=h+425492|0;G=H;H=h+425504|0;r=h+4820|0;T=h+425508|0;U=h+427400|0;J=h+427396|0;l=h+177100|0;Q=h+427404|0;D=h+177072|0;q=h+177068|0;B=h+4064|0;C=h+177092|0;p=h+177096|0;u=h+425500|0;A=k;while(1){k=Fda(f)|0;do{if((k|0)>-1){Yca(f);if((c[n>>2]|0)==0){X=k;break}c[W>>2]=(c[W>>2]|0)+1;z=Fda(f)|0;if((z|0)>-1){Yca(f)}c[W>>2]=(c[W>>2]|0)-1;X=z}else{X=k}}while(0);k=c[F>>2]|0;s=k-2|0;c[F>>2]=s;z=c[G>>2]|0;do{if((z|0)<(s<<17|0)){y=(k-258|0)>>>31;c[F>>2]=s<<y;x=z<<y;c[G>>2]=x;if((x&65535|0)!=0){Y=0;break}y=c[H>>2]|0;c[G>>2]=x-65535+((d[y+1|0]|0)<<1|(d[y]|0)<<9);c[H>>2]=y+2;Y=0}else{Y=(c[H>>2]|0)-(c[u>>2]|0)|0}}while(0);z=c[H>>2]|0;s=c[T>>2]|0;if((c[r>>2]&16384|0)!=0){if(z>>>0>(s+2|0)>>>0){S=31;break}}if(z>>>0>(s+2|0)>>>0){yDb(c[o>>2]|0,48,1981280,(m=i,i=i+8|0,c[m>>2]=s-z,m)|0);i=m}if((X|0)<0){S=36;break}z=c[H>>2]|0;s=c[T>>2]|0;if(z>>>0>(s+4|0)>>>0){Z=s;_=z;break}z=(c[j>>2]|0)+1|0;c[j>>2]=z;do{if((z|0)<(c[U>>2]|0)){$=A}else{pda(f,A,z);c[j>>2]=0;qda(f);s=c[W>>2]|0;c[W>>2]=s+1;if((c[n>>2]|0)==0){if((c[l>>2]|0)==3){$=0;break}c[W>>2]=s+2;$=0;break}k=s+2|0;c[W>>2]=k;if((k|0)>=(c[J>>2]|0)){$=0;break}s=c[Q>>2]|0;y=(ba(s,k)|0)+(c[j>>2]|0)|0;k=y-1|0;x=c[D>>2]|0;w=c[q>>2]|0;do{if((e[x+(k<<1)>>1]|0|0)==(w|0)){aa=c[(c[B>>2]|0)+(k<<2)>>2]|0}else{v=y-s|0;if((e[x+(v<<1)>>1]|0|0)!=(w|0)){aa=0;break}aa=c[(c[B>>2]|0)+(v<<2)>>2]|0}}while(0);w=aa>>>7&1;c[C>>2]=w;c[p>>2]=w;$=0}}while(0);ca=c[W>>2]|0;if((Y|0)!=0){S=51;break}if((ca|0)<(c[J>>2]|0)){A=$}else{S=51;break}}if((S|0)==31){Lkb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,(c[j>>2]|0)-1|0,c[W>>2]|0,112);J=c[j>>2]|0;if((J|0)<(A|0)){V=0;i=g;return V|0}pda(f,A,J+1|0);V=0;i=g;return V|0}else if((S|0)==36){Z=c[T>>2]|0;_=c[H>>2]|0}else if((S|0)==51){Lkb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,(c[j>>2]|0)-1|0,ca,112);ca=c[j>>2]|0;if((ca|0)<=($|0)){V=0;i=g;return V|0}pda(f,$,ca);V=0;i=g;return V|0}ca=c[W>>2]|0;yDb(c[o>>2]|0,16,1978464,(m=i,i=i+24|0,c[m>>2]=c[j>>2],c[m+8>>2]=ca,c[m+16>>2]=Z-_,m)|0);i=m;Lkb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,c[j>>2]|0,c[W>>2]|0,14);V=-1094995529;i=g;return V|0}function pda(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0;i=f+427380|0;j=f+177088|0;k=c[j>>2]|0;l=k+(c[i>>2]|0)|0;m=f+177076|0;n=c[m>>2]|0;o=f+4752|0;p=c[o>>2]|0;q=16>>>((c[f+4788>>2]|0)>>>0);r=f+427420|0;if(!((c[r>>2]|0)!=0&(g|0)<(h|0))){s=k;c[m>>2]=n;t=f+427376|0;c[t>>2]=h;u=l-s|0;c[i>>2]=u;v=f+4792|0;w=c[v>>2]|0;x=f+7876+w|0;y=a[x]|0;z=y&255;A=f+4756|0;c[A>>2]=z;B=f+7964+w|0;C=a[B]|0;D=C&255;E=f+4760|0;c[E>>2]=D;return}F=f+427404|0;G=f+427412|0;H=f+177072|0;I=f+177068|0;J=f+4064|0;K=f+199432|0;L=f+199428|0;M=f+427376|0;N=f+2528|0;O=f+4776|0;P=f+2532|0;Q=f+6136|0;R=f+4780|0;S=f+2536|0;T=f+177092|0;U=f+6112|0;V=f+6116|0;W=f+4844|0;X=f+4852|0;Y=f+4856|0;Z=f+4764|0;_=f+4040|0;$=f+4864|0;aa=f+4872|0;ca=f+4876|0;da=f+6108|0;ea=f+5360|0;fa=f+5392|0;ga=f+5424|0;ha=f+5456|0;ia=f+5644|0;ja=ea;ka=fa;la=ga;ma=ha;na=f+5652|0;oa=f+5660|0;pa=f+5668|0;qa=f+5520|0;ra=f+5552|0;sa=f+5584|0;ta=f+5616|0;ua=f+5684|0;va=qa;wa=ra;xa=sa;ya=ta;za=f+5692|0;Aa=f+5700|0;Ba=f+5708|0;Ca=f+4088|0;Da=f+177096|0;Ea=f+4056|0;Fa=qa;qa=f+5528|0;Ga=ra;ra=f+5560|0;Ha=sa;sa=f+5592|0;Ia=ta;ta=f+5624|0;Ja=f+5488|0;Ka=f+5676|0;La=Ka;Ma=Ja;Na=f+5516|0;Oa=f+5548|0;Pa=f+5580|0;Qa=f+5612|0;Ra=f+5707|0;Sa=f+5699|0;Ta=f+5691|0;Ua=f+5683|0;Va=f+6100|0;Wa=Ja;Ja=f+5496|0;Xa=f+5677|0;Ya=f+5679|0;Za=f+5678|0;_a=f+5304|0;$a=f+5196|0;ab=$a;bb=f+5204|0;cb=bb;db=f+5212|0;eb=db;fb=f+5220|0;gb=fb;hb=f+426560|0;ib=f+426564|0;jb=f+7332|0;kb=f+7392|0;lb=f+5205|0;mb=f+5197|0;nb=f+5207|0;ob=f+5206|0;pb=f+5199|0;qb=f+5198|0;rb=f+5221|0;sb=f+5213|0;tb=f+5223|0;ub=f+5222|0;vb=f+5215|0;wb=f+5214|0;xb=f+5219|0;yb=f+5211|0;zb=f+5203|0;Ab=f+5195|0;Bb=f+5189|0;Cb=f+5188|0;Db=f+5191|0;Eb=f+5190|0;Fb=Cb;Gb=f+4084|0;Hb=f+4052|0;Ib=ea;ea=f+5368|0;Jb=fa;fa=f+5400|0;Kb=ga;ga=f+5432|0;Lb=ha;ha=f+5464|0;Mb=f+5328|0;Nb=f+5636|0;Ob=Nb;Pb=Mb;Qb=f+5356|0;Rb=f+5388|0;Sb=f+5420|0;Tb=f+5452|0;Ub=f+5667|0;Vb=f+5659|0;Wb=f+5651|0;Xb=f+5643|0;Yb=Mb;Mb=f+5336|0;Zb=f+5637|0;_b=f+5639|0;$b=f+5638|0;ac=f+4756|0;bc=f+4760|0;cc=f+5176|0;dc=q-1|0;ec=g;g=k;while(1){a:do{if((g|0)>=0){k=ec<<p;fc=l-g|0;gc=g;while(1){hc=(ba(c[F>>2]|0,fc)|0)+ec|0;c[G>>2]=hc;c[I>>2]=e[(c[H>>2]|0)+(hc<<1)>>1]|0;ic=c[(c[J>>2]|0)+(hc<<2)>>2]|0;c[L>>2]=d[(c[K>>2]|0)+hc|0]|0;jc=(gc|0)==0;if(jc){kc=c[T>>2]|0}else{lc=ic>>>7&1;c[T>>2]=lc;c[Da>>2]=lc;kc=lc}c[M>>2]=ec;c[i>>2]=fc;lc=c[N>>2]|0;mc=c[O>>2]|0;nc=(ba(mc,fc)|0)+k<<4;oc=lc+nc|0;pc=c[P>>2]|0;qc=c[Q>>2]|0;rc=(qc|0)==3;sc=ba(8<<(rc&1),k)|0;tc=c[R>>2]|0;uc=sc+(ba(ba(fc,q)|0,tc)|0)|0;sc=pc+uc|0;vc=c[S>>2]|0;wc=vc+uc|0;do{if((kc|0)==0){c[U>>2]=mc;c[V>>2]=tc;xc=oc;yc=sc;zc=wc;Ac=mc;Bc=tc}else{Cc=mc<<1;c[U>>2]=Cc;Dc=tc<<1;c[V>>2]=Dc;if((fc&1|0)==0){xc=oc;yc=sc;zc=wc;Ac=Cc;Bc=Dc;break}Ec=uc-(ba(tc,dc)|0)|0;xc=lc+((mc*-15|0)+nc)|0;yc=pc+Ec|0;zc=vc+Ec|0;Ac=Cc;Bc=Dc}}while(0);vc=c[o>>2]|0;pc=(qc|0)==2;do{if(jc){Fc=1;Gc=29}else{nc=(c[Da>>2]|0)!=0;if((fc&1|0)==0){if(nc){Fc=0;Gc=29;break}else{break}}if(nc){Fc=1;Gc=29;break}nc=c[cc>>2]|0;mc=Ac*14|0;lc=xc+mc|0;tc=c[lc+4>>2]|0;uc=nc+(ec*96|0)|0;c[uc>>2]=c[lc>>2];c[uc+4>>2]=tc;tc=xc+(mc+8)|0;uc=c[tc+4>>2]|0;lc=nc+(ec*96|0)+8|0;c[lc>>2]=c[tc>>2];c[lc+4>>2]=uc;uc=(vc|0)!=0;if(uc){lc=xc+(mc+16)|0;tc=c[lc+4>>2]|0;wc=nc+(ec*96|0)+16|0;c[wc>>2]=c[lc>>2];c[wc+4>>2]=tc;tc=xc+(mc+24)|0;mc=c[tc+4>>2]|0;wc=nc+(ec*96|0)+24|0;c[wc>>2]=c[tc>>2];c[wc+4>>2]=mc}if(rc){mc=Bc*14|0;wc=yc+mc|0;tc=c[wc>>2]|0;lc=c[wc+4>>2]|0;if(uc){wc=nc+(ec*96|0)+32|0;c[wc>>2]=tc;c[wc+4>>2]=lc;wc=mc+8|0;sc=yc+wc|0;oc=c[sc+4>>2]|0;Dc=nc+(ec*96|0)+40|0;c[Dc>>2]=c[sc>>2];c[Dc+4>>2]=oc;oc=mc+16|0;Dc=yc+oc|0;sc=c[Dc+4>>2]|0;Cc=nc+(ec*96|0)+48|0;c[Cc>>2]=c[Dc>>2];c[Cc+4>>2]=sc;sc=mc+24|0;Cc=yc+sc|0;Dc=c[Cc+4>>2]|0;Ec=nc+(ec*96|0)+56|0;c[Ec>>2]=c[Cc>>2];c[Ec+4>>2]=Dc;Dc=zc+mc|0;Ec=c[Dc+4>>2]|0;Cc=nc+(ec*96|0)+64|0;c[Cc>>2]=c[Dc>>2];c[Cc+4>>2]=Ec;Ec=zc+wc|0;wc=c[Ec+4>>2]|0;Cc=nc+(ec*96|0)+72|0;c[Cc>>2]=c[Ec>>2];c[Cc+4>>2]=wc;wc=zc+oc|0;oc=c[wc+4>>2]|0;Cc=nc+(ec*96|0)+80|0;c[Cc>>2]=c[wc>>2];c[Cc+4>>2]=oc;oc=zc+sc|0;sc=c[oc+4>>2]|0;Cc=nc+(ec*96|0)+88|0;c[Cc>>2]=c[oc>>2];c[Cc+4>>2]=sc;Fc=1;Gc=29;break}else{sc=nc+(ec*96|0)+16|0;c[sc>>2]=tc;c[sc+4>>2]=lc;lc=mc+8|0;sc=yc+lc|0;tc=c[sc+4>>2]|0;Cc=nc+(ec*96|0)+24|0;c[Cc>>2]=c[sc>>2];c[Cc+4>>2]=tc;tc=zc+mc|0;mc=c[tc+4>>2]|0;Cc=nc+(ec*96|0)+32|0;c[Cc>>2]=c[tc>>2];c[Cc+4>>2]=mc;mc=zc+lc|0;lc=c[mc+4>>2]|0;Cc=nc+(ec*96|0)+40|0;c[Cc>>2]=c[mc>>2];c[Cc+4>>2]=lc;Fc=1;Gc=29;break}}if(pc){lc=Bc*14|0;Cc=yc+lc|0;mc=c[Cc>>2]|0;tc=c[Cc+4>>2]|0;if(uc){Cc=nc+(ec*96|0)+32|0;c[Cc>>2]=mc;c[Cc+4>>2]=tc;Cc=lc+8|0;sc=yc+Cc|0;oc=c[sc+4>>2]|0;wc=nc+(ec*96|0)+40|0;c[wc>>2]=c[sc>>2];c[wc+4>>2]=oc;oc=zc+lc|0;wc=c[oc+4>>2]|0;sc=nc+(ec*96|0)+48|0;c[sc>>2]=c[oc>>2];c[sc+4>>2]=wc;wc=zc+Cc|0;Cc=c[wc+4>>2]|0;sc=nc+(ec*96|0)+56|0;c[sc>>2]=c[wc>>2];c[sc+4>>2]=Cc;Fc=1;Gc=29;break}else{Cc=nc+(ec*96|0)+16|0;c[Cc>>2]=mc;c[Cc+4>>2]=tc;tc=zc+lc|0;lc=c[tc+4>>2]|0;Cc=nc+(ec*96|0)+24|0;c[Cc>>2]=c[tc>>2];c[Cc+4>>2]=lc;Fc=1;Gc=29;break}}else{lc=Bc*6|0;Cc=yc+lc|0;tc=c[Cc>>2]|0;mc=c[Cc+4>>2]|0;if(uc){uc=nc+(ec*96|0)+32|0;c[uc>>2]=tc;c[uc+4>>2]=mc;uc=lc+8|0;Cc=yc+uc|0;sc=c[Cc+4>>2]|0;wc=nc+(ec*96|0)+40|0;c[wc>>2]=c[Cc>>2];c[wc+4>>2]=sc;sc=zc+lc|0;wc=c[sc+4>>2]|0;Cc=nc+(ec*96|0)+48|0;c[Cc>>2]=c[sc>>2];c[Cc+4>>2]=wc;wc=zc+uc|0;uc=c[wc+4>>2]|0;Cc=nc+(ec*96|0)+56|0;c[Cc>>2]=c[wc>>2];c[Cc+4>>2]=uc;Fc=1;Gc=29;break}else{uc=nc+(ec*96|0)+16|0;c[uc>>2]=tc;c[uc+4>>2]=mc;mc=zc+lc|0;lc=c[mc+4>>2]|0;uc=nc+(ec*96|0)+24|0;c[uc>>2]=c[mc>>2];c[uc+4>>2]=lc;Fc=1;Gc=29;break}}}}while(0);do{if((Gc|0)==29){Gc=0;jc=c[M>>2]|0;qc=c[f+5176+(Fc<<2)>>2]|0;lc=Ac<<4;uc=lc-Ac|0;mc=xc+uc|0;nc=c[mc+4>>2]|0;tc=qc+(jc*96|0)|0;c[tc>>2]=c[mc>>2];c[tc+4>>2]=nc;nc=xc+(uc+8)|0;tc=c[nc+4>>2]|0;mc=qc+(jc*96|0)+8|0;c[mc>>2]=c[nc>>2];c[mc+4>>2]=tc;tc=(vc|0)!=0;if(tc){mc=xc+(uc+16)|0;nc=c[mc+4>>2]|0;Cc=qc+(jc*96|0)+16|0;c[Cc>>2]=c[mc>>2];c[Cc+4>>2]=nc;nc=xc+(uc+24)|0;uc=c[nc+4>>2]|0;Cc=qc+(jc*96|0)+24|0;c[Cc>>2]=c[nc>>2];c[Cc+4>>2]=uc}if(rc){uc=lc-Bc|0;lc=yc+uc|0;Cc=c[lc>>2]|0;nc=c[lc+4>>2]|0;if(tc){lc=qc+(jc*96|0)+32|0;c[lc>>2]=Cc;c[lc+4>>2]=nc;lc=uc+8|0;mc=yc+lc|0;wc=c[mc+4>>2]|0;sc=qc+(jc*96|0)+40|0;c[sc>>2]=c[mc>>2];c[sc+4>>2]=wc;wc=uc+16|0;sc=yc+wc|0;mc=c[sc+4>>2]|0;oc=qc+(jc*96|0)+48|0;c[oc>>2]=c[sc>>2];c[oc+4>>2]=mc;mc=uc+24|0;oc=yc+mc|0;sc=c[oc+4>>2]|0;Ec=qc+(jc*96|0)+56|0;c[Ec>>2]=c[oc>>2];c[Ec+4>>2]=sc;sc=zc+uc|0;Ec=c[sc+4>>2]|0;oc=qc+(jc*96|0)+64|0;c[oc>>2]=c[sc>>2];c[oc+4>>2]=Ec;Ec=zc+lc|0;lc=c[Ec+4>>2]|0;oc=qc+(jc*96|0)+72|0;c[oc>>2]=c[Ec>>2];c[oc+4>>2]=lc;lc=zc+wc|0;wc=c[lc+4>>2]|0;oc=qc+(jc*96|0)+80|0;c[oc>>2]=c[lc>>2];c[oc+4>>2]=wc;wc=zc+mc|0;mc=c[wc+4>>2]|0;oc=qc+(jc*96|0)+88|0;c[oc>>2]=c[wc>>2];c[oc+4>>2]=mc;break}else{mc=qc+(jc*96|0)+16|0;c[mc>>2]=Cc;c[mc+4>>2]=nc;nc=uc+8|0;mc=yc+nc|0;Cc=c[mc+4>>2]|0;oc=qc+(jc*96|0)+24|0;c[oc>>2]=c[mc>>2];c[oc+4>>2]=Cc;Cc=zc+uc|0;uc=c[Cc+4>>2]|0;oc=qc+(jc*96|0)+32|0;c[oc>>2]=c[Cc>>2];c[oc+4>>2]=uc;uc=zc+nc|0;nc=c[uc+4>>2]|0;oc=qc+(jc*96|0)+40|0;c[oc>>2]=c[uc>>2];c[oc+4>>2]=nc;break}}if(pc){nc=Bc*15|0;oc=yc+nc|0;uc=c[oc>>2]|0;Cc=c[oc+4>>2]|0;if(tc){oc=qc+(jc*96|0)+32|0;c[oc>>2]=uc;c[oc+4>>2]=Cc;oc=nc+8|0;mc=yc+oc|0;wc=c[mc+4>>2]|0;lc=qc+(jc*96|0)+40|0;c[lc>>2]=c[mc>>2];c[lc+4>>2]=wc;wc=zc+nc|0;lc=c[wc+4>>2]|0;mc=qc+(jc*96|0)+48|0;c[mc>>2]=c[wc>>2];c[mc+4>>2]=lc;lc=zc+oc|0;oc=c[lc+4>>2]|0;mc=qc+(jc*96|0)+56|0;c[mc>>2]=c[lc>>2];c[mc+4>>2]=oc;break}else{oc=qc+(jc*96|0)+16|0;c[oc>>2]=uc;c[oc+4>>2]=Cc;Cc=zc+nc|0;nc=c[Cc+4>>2]|0;oc=qc+(jc*96|0)+24|0;c[oc>>2]=c[Cc>>2];c[oc+4>>2]=nc;break}}else{nc=Bc*7|0;oc=yc+nc|0;Cc=c[oc>>2]|0;uc=c[oc+4>>2]|0;if(tc){tc=qc+(jc*96|0)+32|0;c[tc>>2]=Cc;c[tc+4>>2]=uc;tc=nc+8|0;oc=yc+tc|0;mc=c[oc+4>>2]|0;lc=qc+(jc*96|0)+40|0;c[lc>>2]=c[oc>>2];c[lc+4>>2]=mc;mc=zc+nc|0;lc=c[mc+4>>2]|0;oc=qc+(jc*96|0)+48|0;c[oc>>2]=c[mc>>2];c[oc+4>>2]=lc;lc=zc+tc|0;tc=c[lc+4>>2]|0;oc=qc+(jc*96|0)+56|0;c[oc>>2]=c[lc>>2];c[oc+4>>2]=tc;break}else{tc=qc+(jc*96|0)+16|0;c[tc>>2]=Cc;c[tc+4>>2]=uc;uc=zc+nc|0;nc=c[uc+4>>2]|0;tc=qc+(jc*96|0)+24|0;c[tc>>2]=c[uc>>2];c[tc+4>>2]=nc;break}}}}while(0);pc=c[G>>2]|0;rc=c[F>>2]|0;vc=pc-(rc<<c[T>>2])|0;nc=pc-1|0;tc=(c[j>>2]|0)==0;do{if(tc){Hc=vc;Ic=nc;Jc=nc}else{uc=c[J>>2]|0;jc=c[uc+(nc<<2)>>2]&128;qc=ic&128;if((c[i>>2]&1|0)!=0){Hc=vc;Ic=nc-((jc|0)==(qc|0)?0:rc)|0;Jc=nc;break}if((qc|0)==0){Kc=vc}else{Kc=(((c[uc+(vc<<2)>>2]|0)>>>7&1)-1&rc)+vc|0}Hc=Kc;Ic=nc;Jc=((jc|0)==(qc|0)?0:rc)+nc|0}}while(0);c[W>>2]=Hc;c[X>>2]=Ic;c[Y>>2]=Jc;nc=c[Z>>2]|0;vc=c[_>>2]|0;qc=a[vc+pc|0]|0;do{if((qc|0)>(nc|0)){Gc=58}else{jc=(Ic|0)<0;if(!jc){if((qc+1+(a[vc+Ic|0]|0)>>1|0)>(nc|0)){Gc=58;break}}if((Hc|0)>=0){if((qc+1+(a[vc+Hc|0]|0)>>1|0)>(nc|0)){Gc=58;break}}if(tc){break}if(!jc){if((qc+1+(a[vc+Jc|0]|0)>>1|0)>(nc|0)){Gc=58;break}}if((Hc|0)<(rc|0)){break}if((qc+1+(a[vc+(Hc-rc)|0]|0)>>1|0)>(nc|0)){Gc=58}}}while(0);do{if((Gc|0)==58){Gc=0;nc=c[J>>2]|0;rc=c[nc+(Hc<<2)>>2]|0;qc=c[nc+(Ic<<2)>>2]|0;jc=c[nc+(Jc<<2)>>2]|0;nc=c[H>>2]|0;uc=nc+(Hc<<1)|0;Cc=b[uc>>1]|0;if((c[r>>2]|0)==2){oc=c[I>>2]|0;lc=(e[nc+(Jc<<1)>>1]|0)==(oc|0);Lc=(Cc&65535|0)==(oc|0)?rc:0;Mc=lc?qc:0;Nc=lc?jc:0}else{lc=(b[nc+(Jc<<1)>>1]|0)==-1;Lc=Cc<<16>>16==-1?0:rc;Mc=lc?0:qc;Nc=lc?0:jc}c[$>>2]=Lc;c[aa>>2]=Mc;c[ca>>2]=Nc;do{if((ic&7|0)==0){jc=c[da>>2]|0;lc=(ic&376|0)==0;do{if(!lc){if((Lc&12288|0)==0){TGb(Pb|0,0,16)|0;c[Ob>>2]=-1}else{qc=(c[(c[Va>>2]|0)+(Hc<<2)>>2]|0)+(jc*3|0)|0;rc=Hc<<2;oc=Cc&15;mc=(c[Da>>2]|0)!=0?20:2;wc=c[Hb>>2]|0;Ec=wc+(qc<<2)|0;sc=c[Ec+4>>2]|0;c[Yb>>2]=c[Ec>>2];c[Yb+4>>2]=sc;sc=wc+(qc<<2)+8|0;qc=c[sc+4>>2]|0;c[Mb>>2]=c[sc>>2];c[Mb+4>>2]=qc;qc=c[Gb>>2]|0;sc=c[f+412944+(oc<<9)+((a[qc+(rc|2)|0]|0)+mc<<2)>>2]&255;a[Zb]=sc;a[Nb]=sc;sc=c[f+412944+(oc<<9)+((a[qc+(rc|3)|0]|0)+mc<<2)>>2]&255;a[_b]=sc;a[$b]=sc}if(((Mc^ic)&128|0)!=0){break}if((Mc&12288|0)==0){c[Qb>>2]=0;c[Rb>>2]=0;c[Sb>>2]=0;c[Tb>>2]=0;a[Ub]=-1;a[Vb]=-1;a[Wb]=-1;a[Xb]=-1;break}else{sc=(c[(c[Va>>2]|0)+(Ic<<2)>>2]|0)+3|0;mc=Ic<<2;rc=b[nc+(Ic<<1)>>1]&15;qc=(c[Da>>2]|0)!=0?20:2;oc=c[Hb>>2]|0;c[Qb>>2]=c[oc+(sc<<2)>>2];c[Rb>>2]=c[oc+(sc+jc<<2)>>2];c[Sb>>2]=c[oc+(sc+(jc<<1)<<2)>>2];c[Tb>>2]=c[oc+(sc+(jc*3|0)<<2)>>2];sc=c[Gb>>2]|0;oc=c[f+412944+(rc<<9)+((a[sc+(mc|1)|0]|0)+qc<<2)>>2]&255;a[Wb]=oc;a[Xb]=oc;oc=c[f+412944+(rc<<9)+((a[sc+(mc|3)|0]|0)+qc<<2)>>2]&255;a[Ub]=oc;a[Vb]=oc;break}}}while(0);if((ic&12288|0)==0){TGb(ja|0,0,16)|0;TGb(ka|0,0,16)|0;TGb(la|0,0,16)|0;TGb(ma|0,0,16)|0;c[ia>>2]=-1;c[na>>2]=-1;c[oa>>2]=-1;c[pa>>2]=-1}else{oc=pc<<2;qc=c[Gb>>2]|0;mc=c[I>>2]&15;sc=(c[Da>>2]|0)!=0?20:2;rc=(c[f+412944+(mc<<9)+((a[qc+(oc|1)|0]|0)+sc<<2)>>2]<<16&16711680|c[f+412944+(mc<<9)+(sc+(a[qc+oc|0]|0)<<2)>>2]&255)*257|0;wc=(c[f+412944+(mc<<9)+((a[qc+(oc|3)|0]|0)+sc<<2)>>2]<<16&16711680|c[f+412944+(mc<<9)+((a[qc+(oc|2)|0]|0)+sc<<2)>>2]&255)*257|0;c[ia>>2]=rc;c[na>>2]=rc;c[oa>>2]=wc;c[pa>>2]=wc;wc=(ba(jc<<2,c[i>>2]|0)|0)+(c[M>>2]<<2)|0;rc=c[Hb>>2]|0;sc=rc+(wc<<2)|0;oc=c[sc+4>>2]|0;c[Ib>>2]=c[sc>>2];c[Ib+4>>2]=oc;oc=rc+((wc|2)<<2)|0;sc=c[oc+4>>2]|0;c[ea>>2]=c[oc>>2];c[ea+4>>2]=sc;sc=wc+jc|0;oc=rc+(sc<<2)|0;qc=c[oc+4>>2]|0;c[Jb>>2]=c[oc>>2];c[Jb+4>>2]=qc;qc=rc+(sc+2<<2)|0;sc=c[qc+4>>2]|0;c[fa>>2]=c[qc>>2];c[fa+4>>2]=sc;sc=wc+(jc<<1)|0;qc=rc+(sc<<2)|0;oc=c[qc+4>>2]|0;c[Kb>>2]=c[qc>>2];c[Kb+4>>2]=oc;oc=rc+(sc+2<<2)|0;sc=c[oc+4>>2]|0;c[ga>>2]=c[oc>>2];c[ga+4>>2]=sc;sc=wc+(jc*3|0)|0;wc=rc+(sc<<2)|0;oc=c[wc+4>>2]|0;c[Lb>>2]=c[wc>>2];c[Lb+4>>2]=oc;oc=rc+(sc+2<<2)|0;sc=c[oc+4>>2]|0;c[ha>>2]=c[oc>>2];c[ha+4>>2]=sc}do{if((c[L>>2]|0)==2){do{if(!lc){if((Lc&49152|0)==0){TGb(Ma|0,0,16)|0;c[La>>2]=-1}else{sc=(c[(c[Va>>2]|0)+(Hc<<2)>>2]|0)+(jc*3|0)|0;oc=Hc<<2;rc=f+412944+((b[uc>>1]&15)<<9)+(((c[Da>>2]|0)!=0?20:2)<<2)|0;wc=c[Ea>>2]|0;qc=wc+(sc<<2)|0;mc=c[qc+4>>2]|0;c[Wa>>2]=c[qc>>2];c[Wa+4>>2]=mc;mc=wc+(sc<<2)+8|0;sc=c[mc+4>>2]|0;c[Ja>>2]=c[mc>>2];c[Ja+4>>2]=sc;sc=c[Ca>>2]|0;mc=c[rc+256+(a[sc+(oc|2)|0]<<2)>>2]&255;a[Xa]=mc;a[Ka]=mc;mc=c[rc+256+(a[sc+(oc|3)|0]<<2)>>2]&255;a[Ya]=mc;a[Za]=mc}if(((Mc^ic)&128|0)!=0){break}if((Mc&49152|0)==0){c[Na>>2]=0;c[Oa>>2]=0;c[Pa>>2]=0;c[Qa>>2]=0;a[Ra]=-1;a[Sa]=-1;a[Ta]=-1;a[Ua]=-1;break}else{mc=(c[(c[Va>>2]|0)+(Ic<<2)>>2]|0)+3|0;oc=Ic<<2;sc=f+412944+((b[nc+(Ic<<1)>>1]&15)<<9)+(((c[Da>>2]|0)!=0?20:2)<<2)|0;rc=c[Ea>>2]|0;c[Na>>2]=c[rc+(mc<<2)>>2];c[Oa>>2]=c[rc+(mc+jc<<2)>>2];c[Pa>>2]=c[rc+(mc+(jc<<1)<<2)>>2];c[Qa>>2]=c[rc+(mc+(jc*3|0)<<2)>>2];mc=c[Ca>>2]|0;rc=c[sc+256+(a[mc+(oc|1)|0]<<2)>>2]&255;a[Ta]=rc;a[Ua]=rc;rc=c[sc+256+(a[mc+(oc|3)|0]<<2)>>2]&255;a[Ra]=rc;a[Sa]=rc;break}}}while(0);if((ic&49152|0)==0){TGb(va|0,0,16)|0;TGb(wa|0,0,16)|0;TGb(xa|0,0,16)|0;TGb(ya|0,0,16)|0;c[ua>>2]=-1;c[za>>2]=-1;c[Aa>>2]=-1;c[Ba>>2]=-1;break}else{rc=pc<<2;oc=c[Ca>>2]|0;mc=f+412944+((c[I>>2]&15)<<9)+(((c[Da>>2]|0)!=0?20:2)<<2)|0;sc=(c[mc+256+(a[oc+(rc|1)|0]<<2)>>2]<<16&16711680|c[mc+256+(a[oc+rc|0]<<2)>>2]&255)*257|0;wc=(c[mc+256+(a[oc+(rc|3)|0]<<2)>>2]<<16&16711680|c[mc+256+(a[oc+(rc|2)|0]<<2)>>2]&255)*257|0;c[ua>>2]=sc;c[za>>2]=sc;c[Aa>>2]=wc;c[Ba>>2]=wc;wc=(ba(jc<<2,c[i>>2]|0)|0)+(c[M>>2]<<2)|0;sc=c[Ea>>2]|0;rc=sc+(wc<<2)|0;oc=c[rc+4>>2]|0;c[Fa>>2]=c[rc>>2];c[Fa+4>>2]=oc;oc=sc+((wc|2)<<2)|0;rc=c[oc+4>>2]|0;c[qa>>2]=c[oc>>2];c[qa+4>>2]=rc;rc=wc+jc|0;oc=sc+(rc<<2)|0;mc=c[oc+4>>2]|0;c[Ga>>2]=c[oc>>2];c[Ga+4>>2]=mc;mc=sc+(rc+2<<2)|0;rc=c[mc+4>>2]|0;c[ra>>2]=c[mc>>2];c[ra+4>>2]=rc;rc=wc+(jc<<1)|0;mc=sc+(rc<<2)|0;oc=c[mc+4>>2]|0;c[Ha>>2]=c[mc>>2];c[Ha+4>>2]=oc;oc=sc+(rc+2<<2)|0;rc=c[oc+4>>2]|0;c[sa>>2]=c[oc>>2];c[sa+4>>2]=rc;rc=wc+(jc*3|0)|0;wc=sc+(rc<<2)|0;oc=c[wc+4>>2]|0;c[Ia>>2]=c[wc>>2];c[Ia+4>>2]=oc;oc=sc+(rc+2<<2)|0;rc=c[oc+4>>2]|0;c[ta>>2]=c[oc>>2];c[ta+4>>2]=rc;break}}}while(0);jc=c[_a>>2]|0;c[ab>>2]=c[jc+(pc*48|0)>>2];c[cb>>2]=c[jc+(pc*48|0)+4>>2];c[eb>>2]=c[jc+(pc*48|0)+8>>2];c[gb>>2]=c[jc+(pc*48|0)+12>>2];lc=c[hb>>2]|0;rc=b[lc+(pc<<1)>>1]|0;c[ib>>2]=rc&65535;if((Lc|0)!=0){c[Fb>>2]=c[jc+(Hc*48|0)+12>>2]}if((Mc|0)!=0){a[Ab]=a[jc+(Ic*48|0)+3|0]|0;a[zb]=a[jc+(Ic*48|0)+7|0]|0;a[yb]=a[jc+(Ic*48|0)+11|0]|0;a[xb]=a[jc+(Ic*48|0)+15|0]|0}if((c[jb>>2]|0)!=0){break}if((c[kb>>2]|0)==0){break}if((Lc&16777216|0)!=0){jc=lc+(Hc<<1)|0;oc=(e[jc>>1]|0)>>>12&4;a[Bb]=oc;a[Cb]=oc;oc=(e[jc>>1]|0)>>>12&8;a[Db]=oc;a[Eb]=oc}if((Mc&16777216|0)!=0){oc=(e[lc+(Ic<<1)>>1]|0)>>>12&2;a[zb]=oc;a[Ab]=oc}if((Nc&16777216|0)!=0){oc=(e[lc+(Jc<<1)>>1]|0)>>>12&8;a[xb]=oc;a[yb]=oc}if((ic&16777216|0)==0){break}oc=(rc&65535)>>>12&255;rc=oc&1;a[lb]=rc;a[bb]=rc;a[mb]=rc;a[$a]=rc;rc=oc&2;a[nb]=rc;a[ob]=rc;a[pb]=rc;a[qb]=rc;rc=oc&4;a[rb]=rc;a[fb]=rc;a[sb]=rc;a[db]=rc;rc=oc&8;a[tb]=rc;a[ub]=rc;a[vb]=rc;a[wb]=rc}}while(0);nc=vc+hc|0;c[ac>>2]=d[(a[nc]|0)+(f+7876)|0]|0;c[bc>>2]=d[(a[nc]|0)+(f+7964)|0]|0;if(tc){Zda(f,ec,fc,xc,yc,zc,Ac,Bc);break}else{_da(f,ec,fc,xc,yc,zc,Ac,Bc);break}}}while(0);tc=fc+1|0;if((tc|0)>(l|0)){break a}fc=tc;gc=c[j>>2]|0}}}while(0);gc=ec+1|0;fc=c[j>>2]|0;if((gc|0)<(h|0)){ec=gc;g=fc}else{s=fc;break}}c[m>>2]=n;t=f+427376|0;c[t>>2]=h;u=l-s|0;c[i>>2]=u;v=f+4792|0;w=c[v>>2]|0;x=f+7876+w|0;y=a[x]|0;z=y&255;A=f+4756|0;c[A>>2]=z;B=f+7964+w|0;C=a[B]|0;D=C&255;E=f+4760|0;c[E>>2]=D;return}function qda(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+177100|0;d=(c[b>>2]|0)!=3|0;e=c[a+427380>>2]>>d<<4;f=c[a+427396>>2]<<4>>d;d=c[a+177088>>2]|0;g=16<<d;h=20<<d;if((c[a+427420>>2]|0)==0){i=e;j=g}else{i=e-h|0;j=((e+g|0)<(f|0)?0:h)+g|0}if((i|0)>=(f|0)){return}if((i+j|0)<0){return}g=f-i|0;f=(i|0)<0;h=((j|0)>(g|0)?g:j)+(f?i:0)|0;j=f?0:i;Nca(a,j,h);if((c[a+4796>>2]|0)!=0){return}if((c[a+2388>>2]|0)!=0){return}Y0a((c[a+2524>>2]|0)+1496|0,j-1+h|0,(c[b>>2]|0)==2|0);return}function rda(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a+7308>>2]|0;a:do{switch(e|0){case 12:{f=c[a+6136>>2]|0;if((f|0)==2){g=306;break a}else if((f|0)==3){g=(c[(c[a>>2]|0)+392>>2]|0)==0?314:310;break a}else{g=302;break a}break};case 8:{f=c[a+6136>>2]|0;if((f|0)==3){h=a|0;j=c[h>>2]|0;k=c[j+392>>2]|0;if((k|0)==0){yDb(j,48,2338280,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;g=82;break a}else if((k|0)==8){yDb(j,24,2336896,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=c[h>>2]|0}else{m=j}g=(c[m+396>>2]|0)==2?14:5;break a}j=c[a>>2]|0;if((f|0)==2){g=(c[j+396>>2]|0)==2?13:4;break a}f=c[(c[j+12>>2]|0)+24>>2]|0;if((f|0)==0){n=(c[j+396>>2]|0)==2?983528:983536}else{n=f}f=j+140|0;b:do{if((b|0)==0){h=0;while(1){k=c[n+(h<<2)>>2]|0;if((k|0)==-1){break b}if((k|0)==(c[f>>2]|0)){g=k;break a}else{h=h+1|0}}}else{h=0;while(1){if((c[n+(h<<2)>>2]|0)==-1){break b}h=h+1|0}}}while(0);g=V0a(j,n)|0;break};case 14:{f=c[a+6136>>2]|0;if((f|0)==2){g=308;break a}else if((f|0)==3){g=(c[(c[a>>2]|0)+392>>2]|0)==0?316:312;break a}else{g=304;break a}break};case 9:{f=c[a+6136>>2]|0;if((f|0)==3){g=(c[(c[a>>2]|0)+392>>2]|0)==0?84:76;break a}else if((f|0)==2){g=80;break a}else{g=70;break a}break};case 10:{f=c[a+6136>>2]|0;if((f|0)==2){g=74;break a}else if((f|0)==3){g=(c[(c[a>>2]|0)+392>>2]|0)==0?86:78;break a}else{g=72;break a}break};default:{yDb(c[a>>2]|0,16,2334216,(l=i,i=i+8|0,c[l>>2]=e,l)|0);i=l;g=-1094995529}}}while(0);i=d;return g|0}function sda(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;g=d|0;h=d+6224|0;j=(c[g>>2]|0)+224|0;k=c[h+4>>2]|0;c[j>>2]=c[h>>2];c[j+4>>2]=k;k=c[g>>2]|0;if((c[k+228>>2]|0)==0){yDb(0,0,1895544,(l=i,i=i+24|0,c[l>>2]=1880304,c[l+8>>2]=2332720,c[l+16>>2]=3297,l)|0);i=l;Cd();return 0}eFb(c[k+140>>2]|0,d+4784|0,d+4788|0)|0;if((c[d+6256>>2]|0)!=0){k=_Gb(c[d+6264>>2]|0,0,(c[d+427372>>2]|0)>>>0<44>>>0|0)|0;j=c[g>>2]|0;iFb(j+104|0,j+108|0,c[d+6260>>2]|0,0,k,F,1073741824,0)|0}k=R0a(c[g>>2]|0)|0;c[(c[g>>2]|0)+712>>2]=k;if((e|0)!=0){Tca(d,0)}c[d+177104>>2]=0;c[d+572412>>2]=1;e=0;while(1){k=a[144+e|0]|0;a[d+426796+e|0]=k<<2&12|(k&255)>>>2;k=a[1071232+e|0]|0;a[d+426940+e|0]=k<<2&12|(k&255)>>>2;k=e+1|0;if((k|0)<16){e=k}else{m=0;break}}do{e=a[1075976+m|0]|0;a[d+426812+m|0]=e<<3&56|(e&255)>>>3;e=a[8+m|0]|0;a[d+426876+m|0]=e<<3&56|(e&255)>>>3;e=a[1071160+m|0]|0;a[d+426956+m|0]=e<<3&56|(e&255)>>>3;e=a[1071088+m|0]|0;a[d+427020+m|0]=e<<3&56|(e&255)>>>3;m=m+1|0;}while((m|0)<64);m=d+427084|0;if((c[d+6140>>2]|0)==0){UGb(m|0,d+426796|0,16)|0;UGb(d+427100|0,d+426812|0,64)|0;UGb(d+427164|0,d+426876|0,64)|0;UGb(d+427228|0,d+426940|0,16)|0;UGb(d+427244|0,d+426956|0,64)|0;UGb(d+427308|0,d+427020|0,64)|0}else{UGb(m|0,144,16)|0;UGb(d+427100|0,1075976,64)|0;UGb(d+427164|0,8,64)|0;UGb(d+427228|0,1071232,16)|0;UGb(d+427244|0,1071160,64)|0;UGb(d+427308|0,1071088,64)|0}m=Rca(d)|0;if((m|0)<0){yDb(c[g>>2]|0,16,2355888,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;n=m;i=f;return n|0}m=d+427396|0;e=c[m>>2]|0;if((e|0)>-1){o=1;p=e}else{yDb(c[g>>2]|0,24,2354640,(l=i,i=i+16|0,c[l>>2]=1,c[l+8>>2]=e,l)|0);i=l;o=e;p=c[m>>2]|0}c[d+572384>>2]=o;o=d+427404|0;e=c[o>>2]|0;k=ba(e,p)|0;j=d+427400|0;h=c[j>>2]|0;q=ba(h<<1|1,p<<1|1)|0;r=ba(e,p+1|0)|0;p=q+(r<<1)|0;e=cEb(h*96|0)|0;c[d+5176>>2]=e;h=(c[j>>2]|0)*96|0;do{if((e|0)==0){if((h|0)==0){s=0;t=20;break}yDb(c[g>>2]|0,16,2006760,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}else{s=h;t=20}}while(0);a:do{if((t|0)==20){h=cEb(s)|0;c[d+5180>>2]=h;e=c[j>>2]|0;do{if((h|0)==0){if((e*96|0|0)==0){break}yDb(c[g>>2]|0,16,2006760,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break a}}while(0);a[d+5704|0]=-2;a[d+5696|0]=-2;a[d+5688|0]=-2;a[d+5664|0]=-2;a[d+5656|0]=-2;a[d+5648|0]=-2;c[d+2352>>2]=c[g>>2];c[d+2356>>2]=d+1108;c[d+2512>>2]=70;c[d+2516>>2]=d;c[d+2500>>2]=1;h=d+427408|0;u=c[h>>2]|0;c[d+2364>>2]=u;c[d+2368>>2]=e;c[d+2372>>2]=c[m>>2];c[d+2376>>2]=c[o>>2];c[d+2380>>2]=e<<1|1;v=cEb((u<<2)+4|0)|0;u=v;c[d+2360>>2]=u;do{if((v|0)==0){if((c[h>>2]&1073741823|0)==1073741823){break}yDb(c[g>>2]|0,16,2006760,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break a}}while(0);h=c[m>>2]|0;v=c[j>>2]|0;if((h|0)>0){e=0;do{if((v|0)>0){w=ba(c[o>>2]|0,e)|0;x=0;do{c[u+((ba(v,e)|0)+x<<2)>>2]=w+x;x=x+1|0;}while((x|0)<(v|0))}e=e+1|0;}while((e|0)<(h|0))}c[u+((ba(h,v)|0)<<2)>>2]=(ba(c[o>>2]|0,h-1|0)|0)+v;e=cEb(k)|0;c[d+2392>>2]=e;x=(k|0)==0;if(!((e|0)!=0|x)){yDb(c[g>>2]|0,16,2006760,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}e=WDb(k)|0;c[d+2416>>2]=e;if(!((e|0)!=0|x)){yDb(c[g>>2]|0,16,2006760,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}TGb(e|0,1,k|0)|0;e=k+2|0;x=cEb(e)|0;c[d+2412>>2]=x;if(!((x|0)!=0|(e|0)==0)){yDb(c[g>>2]|0,16,2006760,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}e=WDb(ba(c[o>>2]|0,c[m>>2]|0)|0)|0;c[d+2396>>2]=e;do{if((e|0)==0){if((ba(c[o>>2]|0,c[m>>2]|0)|0)==0){break}yDb(c[g>>2]|0,16,2006760,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break a}}while(0);e=p<<1;v=cEb(e)|0;h=v;c[d+572688>>2]=h;if(!((v|0)!=0|(e|0)==0)){yDb(c[g>>2]|0,16,2006760,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}c[d+2400>>2]=h+((c[j>>2]<<1)+2<<1);e=q+1+(c[o>>2]|0)|0;c[d+2404>>2]=h+(e<<1);c[d+2408>>2]=h+(e+r<<1);if((p|0)>0){e=0;do{b[h+(e<<1)>>1]=1024;e=e+1|0;}while((e|0)<(p|0))}c[d+4812>>2]=1;n=0;i=f;return n|0}}while(0);yDb(c[g>>2]|0,16,2348304,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;n=-12;i=f;return n|0}function tda(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+16|0;e=b|0;f=c[a+4752>>2]|0;g=e|0;c[g>>2]=1<<(c[a+7308>>2]|0)-1;h=1<<(c[a+7312>>2]|0)-1;c[e+4>>2]=h;c[e+8>>2]=h;c[e+12>>2]=-1;e=a|0;if((_0a(c[e>>2]|0)|0)==0){yDb(c[e>>2]|0,16,1888752,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=b;return k|0}h=a+2520|0;l=0;do{m=c[h>>2]|0;n=m+(l*2224|0)|0;do{if((c[m+(l*2224|0)+360>>2]|0)!=0){if((c[m+(l*2224|0)+2192>>2]|0)!=0){break}ida(a,n)}}while(0);l=l+1|0;}while((l|0)<36);l=a+2524|0;c[l>>2]=0;n=c[h>>2]|0;m=0;while(1){if((c[n+(m*2224|0)+360>>2]|0)==0){o=m;break}if((c[n+(m*2224|0)+2188>>2]|0)!=0){if((c[n+(m*2224|0)+2192>>2]&4|0)==0){o=m;break}}p=m+1|0;if((p|0)<36){m=p}else{o=p;break}}do{if((o|0)==36){q=-1094995529}else{m=n+(o*2224|0)+2188|0;if((c[m>>2]|0)!=0){c[m>>2]=0;ida(a,n+(o*2224|0)|0)}if((o|0)<0){q=o;break}m=c[h>>2]|0;p=m+(o*2224|0)|0;r=a+177100|0;if((c[a+4796>>2]|0)==0){s=c[r>>2]|0}else{s=0}t=m+(o*2224|0)+2192|0;c[t>>2]=s;u=a+4804|0;v=c[u>>2]|0;c[u>>2]=v+1;u=p|0;c[m+(o*2224|0)+160>>2]=v;c[m+(o*2224|0)+2164>>2]=(c[r>>2]|0)!=3;c[m+(o*2224|0)+84>>2]=0;c[m+(o*2224|0)+1620>>2]=0;c[m+(o*2224|0)+2200>>2]=0;c[m+(o*2224|0)+2204>>2]=0;if((c[p>>2]|0)!=0){yDb(0,0,1895544,(j=i,i=i+24|0,c[j>>2]=1882872,c[j+8>>2]=2332720,c[j+16>>2]=434,j)|0);i=j;Cd();return 0}r=m+(o*2224|0)+1496|0;c[r>>2]=u;v=W0a(c[e>>2]|0,r,(c[t>>2]|0)!=0|0)|0;a:do{if((v|0)<0){w=v}else{t=a+4776|0;c[t>>2]=c[m+(o*2224|0)+32>>2];r=a+4780|0;c[r>>2]=c[m+(o*2224|0)+36>>2];c[m+(o*2224|0)+2208>>2]=c[a+6200>>2];c[m+(o*2224|0)+2216>>2]=c[a+6212>>2];c[m+(o*2224|0)+2212>>2]=c[a+6204>>2];x=c[(c[e>>2]|0)+712>>2]|0;do{if((x|0)!=0){y=m+(o*2224|0)+1600|0;if((c[y>>2]|0)!=0){yDb(0,0,1895544,(j=i,i=i+24|0,c[j>>2]=1881584,c[j+8>>2]=2332720,c[j+16>>2]=450,j)|0);i=j;Cd();return 0}z=c[x+36>>2]|0;if((z|0)==0){break}A=VAb(z)|0;c[m+(o*2224|0)+1596>>2]=A;if((A|0)==0){k=-12;i=b;return k|0}else{c[y>>2]=c[A+4>>2];break}}}while(0);x=a+572692|0;A=c[x>>2]|0;b:do{if((A|0)==0){y=a+427404|0;z=c[y>>2]|0;B=c[a+427396>>2]|0;C=(ba(B+1|0,z)|0)+1|0;D=ba(B<<4,c[a+427400>>2]<<2|1)|0;c[x>>2]=aBb(C+z|0,728)|0;E=a+572696|0;c[E>>2]=aBb(C+(c[y>>2]|0)<<2,728)|0;y=a+572700|0;c[y>>2]=aBb(D+16|0,728)|0;D=aBb(ba(z<<2,B)|0,728)|0;B=a+572704|0;c[B>>2]=D;z=c[x>>2]|0;do{if((z|0)!=0){if((c[E>>2]|0)==0){break}if(!((c[y>>2]|0)==0|(D|0)==0)){F=0;G=z;H=E;break b}}}while(0);bBb(x);bBb(E);bBb(y);bBb(B);w=-12;break a}else{F=v;G=A;H=a+572696|0}}while(0);A=m+(o*2224|0)+1508|0;c[A>>2]=cBb(G)|0;x=cBb(c[H>>2]|0)|0;c[m+(o*2224|0)+1532>>2]=x;z=c[A>>2]|0;if((z|0)==0|(x|0)==0){w=F;break}A=c[a+427404>>2]<<1|1;c[m+(o*2224|0)+1536>>2]=(c[x+4>>2]|0)+(A<<2);c[m+(o*2224|0)+1512>>2]=(c[z+4>>2]|0)+A;A=a+572700|0;z=a+572704|0;x=m+(o*2224|0)+1516|0;c[x>>2]=cBb(c[A>>2]|0)|0;D=cBb(c[z>>2]|0)|0;c[m+(o*2224|0)+1548>>2]=D;C=c[x>>2]|0;if((C|0)==0|(D|0)==0){w=F;break}c[m+(o*2224|0)+1524>>2]=(c[C+4>>2]|0)+16;c[m+(o*2224|0)+1556>>2]=c[D+4>>2];D=m+(o*2224|0)+1520|0;c[D>>2]=cBb(c[A>>2]|0)|0;A=cBb(c[z>>2]|0)|0;c[m+(o*2224|0)+1552>>2]=A;z=c[D>>2]|0;if((z|0)==0|(A|0)==0){w=F;break}c[m+(o*2224|0)+1528>>2]=(c[z+4>>2]|0)+16;c[m+(o*2224|0)+1560>>2]=c[A+4>>2];do{if((c[a+572480>>2]|0)==0){A=c[e>>2]|0;if((c[A+712>>2]|0)!=0){break}if((c[(c[A+12>>2]|0)+16>>2]&128|0)!=0){break}X$a(u,g)}}while(0);c[l>>2]=p;A=a+2528|0;ida(a,A);c[a+2484>>2]=0;z=c[l>>2]|0;if((c[a+2888>>2]|0)!=0){yDb(0,0,1895544,(j=i,i=i+24|0,c[j>>2]=1885360,c[j+8>>2]=2332720,c[j+16>>2]=319,j)|0);i=j;Cd();return 0}if((c[z+360>>2]|0)==0){yDb(0,0,1895544,(j=i,i=i+24|0,c[j>>2]=1884e3,c[j+8>>2]=2332720,c[j+16>>2]=320,j)|0);i=j;Cd();return 0}D=z+1496|0;c[D>>2]=z;C=a+4024|0;c[C>>2]=A;x=T0a(C,D)|0;if((x|0)<0){ida(a,A);k=x;i=b;return k|0}x=a+4036|0;c[x>>2]=WAb(c[z+1508>>2]|0)|0;D=WAb(c[z+1532>>2]|0)|0;c[a+4060>>2]=D;c:do{if((c[x>>2]|0)==0|(D|0)==0){I=56}else{c[a+4040>>2]=c[z+1512>>2];c[a+4064>>2]=c[z+1536>>2];C=a+4044|0;c[C>>2]=WAb(c[z+1516>>2]|0)|0;J=WAb(c[z+1548>>2]|0)|0;c[a+4076>>2]=J;if((c[C>>2]|0)==0|(J|0)==0){I=56;break}c[a+4052>>2]=c[z+1524>>2];c[a+4084>>2]=c[z+1556>>2];J=a+4048|0;c[J>>2]=WAb(c[z+1520>>2]|0)|0;C=WAb(c[z+1552>>2]|0)|0;c[a+4080>>2]=C;if((c[J>>2]|0)==0|(C|0)==0){I=56;break}c[a+4056>>2]=c[z+1528>>2];c[a+4088>>2]=c[z+1560>>2];do{if((c[z+1600>>2]|0)!=0){C=WAb(c[z+1596>>2]|0)|0;c[a+4124>>2]=C;if((C|0)==0){ida(a,A);break c}else{c[a+4128>>2]=c[C+4>>2];break}}}while(0);c[a+4132>>2]=c[z+1604>>2];c[a+4136>>2]=c[z+1608>>2];UGb(a+4160|0,z+1632|0,512)|0;B=a+4672|0;y=z+2144|0;c[B>>2]=c[y>>2];c[B+4>>2]=c[y+4>>2];c[B+8>>2]=c[y+8>>2];c[B+12>>2]=c[y+12>>2];c[a+4140>>2]=c[z+1612>>2];c[a+4144>>2]=c[z+1616>>2];c[a+4148>>2]=c[z+1620>>2];c[a+4152>>2]=c[z+1624>>2];c[a+4156>>2]=c[z+1628>>2];c[a+4688>>2]=c[z+2160>>2];c[a+4692>>2]=c[z+2164>>2];c[a+4716>>2]=c[z+2188>>2];c[a+4720>>2]=c[z+2192>>2];c[a+4736>>2]=c[z+2208>>2];c[a+4740>>2]=c[z+2212>>2];c[a+4744>>2]=c[z+2216>>2];c[a+4728>>2]=c[z+2200>>2];c[a+4732>>2]=c[z+2204>>2]}}while(0);if((I|0)==56){ida(a,A)}Kkb(a+2352|0);c[a+2492>>2]=0;c[a+2488>>2]=0;z=0;while(1){D=(d[473424+z|0]|0)-12|0;x=(D<<2&28)<<f;y=D>>3;c[a+5716+(z<<2)>>2]=x+(ba(c[t>>2]<<2,y)|0);c[a+5716+(z+48<<2)>>2]=x+(ba(c[t>>2]<<3,y)|0);y=z+1|0;if((y|0)<16){z=y}else{K=0;break}}do{z=(d[473424+K|0]|0)-12|0;t=(z<<2&28)<<f;A=z>>3;z=t+(ba(c[r>>2]<<2,A)|0)|0;c[a+5716+(K+32<<2)>>2]=z;c[a+5716+(K+16<<2)>>2]=z;z=t+(ba(c[r>>2]<<3,A)|0)|0;c[a+5716+(K+80<<2)>>2]=z;c[a+5716+(K+64<<2)>>2]=z;K=K+1|0;}while((K|0)<16);r=c[l>>2]|0;c[r+2192>>2]=0;c[r+1608>>2]=2147483647;c[r+1604>>2]=2147483647;c[a+571424>>2]=0;k=0;i=b;return k|0}}while(0);ida(a,p);k=(w|0)<0?w:-12;i=b;return k|0}}while(0);yDb(c[e>>2]|0,16,1887008,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=q;i=b;return k|0}function uda(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=(b|0)<0;TGb(a+572484|0,0,16)|0;do{if(d){e=c[a+177100>>2]|0;if((e|0)==3){f=(c[a+2524>>2]|0)+1612|0}else{f=(c[a+2524>>2]|0)+1604+(e-1<<2)|0}e=c[f>>2]|0;g=c[a+199420>>2]|0;h=c[a+199424>>2]|0;if((g|0)!=1){i=e;j=0;k=g;l=h;break}if((h|0)!=1){i=e;j=0;k=1;l=h;break}if((c[a+177088>>2]|0)!=0){i=e;j=0;k=g;l=1;break}if(((c[a+307804>>2]|0)+(c[a+201052>>2]|0)|0)!=(e<<1|0)){i=e;j=0;k=g;l=1;break}c[a+177120>>2]=0;c[a+177124>>2]=0;return}else{i=c[(c[a+2524>>2]|0)+1604+(b<<2)>>2]|0;j=16;k=(c[a+199420>>2]<<1)+16|0;l=(c[a+199424>>2]<<1)+16|0}}while(0);c[a+177120>>2]=2;c[a+177124>>2]=2;c[a+177128>>2]=5;c[a+177132>>2]=5;if((j|0)>=(k|0)){return}f=(j|0)<(l|0);g=j;do{e=c[a+199440+(g*2224|0)+1612>>2]|0;if(f){h=a+199440+(g*2224|0)+1628|0;m=i-e|0;n=(m|0)<-128;o=(m|0)>127?127:m;m=j;do{do{if((c[h>>2]|0)==0){if((c[a+306192+(m*2224|0)+1628>>2]|0)!=0){p=32;break}q=(c[a+306192+(m*2224|0)+1612>>2]|0)-e|0;if((q|0)<-128){r=-128}else{s=(q|0)>127?127:q;if((s|0)==0){p=32;break}else{r=s}}s=(ba(((((r|0)>-1?r:-r|0)>>1)+16384|0)/(r|0)|0,n?-128:o)|0)+32>>8;if(!((s+64|0)>>>0<193>>>0)){p=32;break}p=64-s|0}else{p=32}}while(0);if(d){c[a+179440+(g*384|0)+(m<<3)+4>>2]=p;c[a+179440+(g*384|0)+(m<<3)>>2]=p}else{c[a+179440+(g*384|0)+(m<<3)+(b<<2)>>2]=p}m=m+1|0;}while((m|0)<(l|0))}g=g+1|0;}while((g|0)<(k|0));return}function vda(a,d,e,f,g,h,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;l=i;c[a+427376>>2]=h;c[a+427380>>2]=j;k=a+427412|0;c[k>>2]=(ba(c[a+427404>>2]|0,j)|0)+h;TGb(a+5184|0,0,120)|0;h=(c[a+199420>>2]|0)>>>0>d>>>0?d:0;d=a+199440|0;if((c[d+(h*2224|0)>>2]|0)==0){yDb(c[a>>2]|0,48,2346296,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0}else{n=h}if((c[d+(n*2224|0)+2192>>2]&3|0)==3){d=c[k>>2]<<2;k=c[a+4084>>2]|0;h=(n*257|0)&65535;b[k+d>>1]=h;b[k+(d|2)>>1]=h;h=ba(n,16843009)|0;c[a+5644>>2]=h;c[a+5652>>2]=h;c[a+5660>>2]=h;c[a+5668>>2]=h;h=c[g+4>>2]<<16|c[g>>2]&65535;c[a+5360>>2]=h;c[a+5364>>2]=h;c[a+5368>>2]=h;c[a+5372>>2]=h;c[a+5392>>2]=h;c[a+5396>>2]=h;c[a+5400>>2]=h;c[a+5404>>2]=h;c[a+5424>>2]=h;c[a+5428>>2]=h;c[a+5432>>2]=h;c[a+5436>>2]=h;c[a+5456>>2]=h;c[a+5460>>2]=h;c[a+5464>>2]=h;c[a+5468>>2]=h;c[a+177092>>2]=0;c[a+177096>>2]=0;Yca(a);i=l;return}else{yDb(c[a>>2]|0,48,2344840,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;i=l;return}}function wda(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[473424+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=e+6112|0;B=c[A>>2]|0;D=(ba(n<<1,B)|0)+(m<<1)|0;E=j+D|0;F=e+6116|0;G=(ba(c[F>>2]|0,n)|0)+m|0;H=k+G|0;I=l+G|0;G=(c[e+427376>>2]<<3)+m|0;J=e+427380|0;K=e+177092|0;L=c[K>>2]|0;M=(c[J>>2]>>L<<3)+n|0;if(y){N=p;O=o}else{P=d[473424+f|0]|0;Q=a[e+5632+P|0]|0;R=(b[e+5312+(P<<2)>>1]|0)+(G<<3)|0;S=(b[e+5312+(P<<2)+2>>1]|0)+(M<<3)|0;P=S<<2&12|R&3;T=R>>2;U=S>>2;V=(ba(U,B)|0)+T|0;W=c[e+199440+(Q*2224|0)>>2]|0;X=W+V|0;Y=c[e+427400>>2]|0;Z=Y<<4;_=c[e+427396>>2]<<4>>L;L=R&7;$=(L|0)==0?0:-3;aa=(S&7|0)==0?0:-3;do{if((T|0)<(-$|0)){z=58}else{if((U|0)<(-aa|0)){z=58;break}if((T+16|0)>($+Z|0)){z=58;break}if((U+16|0)>(_+aa|0)){z=58}else{ca=X;da=0;ea=B}}}while(0);if((z|0)==58){X=e+572684|0;Ne[c[e+4>>2]&127](c[X>>2]|0,W+(-2-(B<<1)+V)|0,B,B,21,21,T-2|0,U-2|0,Z,_);aa=c[A>>2]|0;ca=(c[X>>2]|0)+((aa<<1)+2)|0;da=1;ea=aa}aa=o+(P<<2)|0;Xe[c[aa>>2]&4095](E,ca,ea);if((g|0)==0){Xe[c[aa>>2]&4095](j+(D+i)|0,ca+i|0,c[A>>2]|0)}if((c[K>>2]|0)==0){fa=S;ga=da}else{aa=(1-(c[e+199440+(Q*2224|0)+2192>>2]|0)+(c[J>>2]&1)<<1)+S|0;X=aa>>3;if((X|0)<0){ha=1}else{ha=(X+8|0)>=(_>>1|0)|0}fa=aa;ga=ha|da}aa=R>>3;X=fa>>3;$=c[F>>2]|0;ia=(ba($,X)|0)+aa|0;ja=(c[e+199440+(Q*2224|0)+4>>2]|0)+ia|0;ka=(c[e+199440+(Q*2224|0)+8>>2]|0)+ia|0;if((ga|0)==0){ia=h>>1;la=fa&7;Se[p&511](H,ja,$,ia,L,la);ma=ka;na=ia;oa=la}else{la=e+4|0;ia=e+572684|0;pa=Y<<3;qa=_>>1;Ne[c[la>>2]&127](c[ia>>2]|0,ja,$,$,9,9,aa,X,pa,qa);$=h>>1;ja=fa&7;Se[p&511](H,c[ia>>2]|0,c[F>>2]|0,$,L,ja);ra=c[F>>2]|0;Ne[c[la>>2]&127](c[ia>>2]|0,ka,ra,ra,9,9,aa,X,pa,qa);ma=c[ia>>2]|0;na=$;oa=ja}Se[p&511](I,ma,c[F>>2]|0,na,L,oa);N=r;O=q}if(u){return}ja=d[473424+f|0]|0;$=a[e+5672+ja|0]|0;ia=(b[e+5472+(ja<<2)>>1]|0)+(G<<3)|0;qa=(b[e+5472+(ja<<2)+2>>1]|0)+(M<<3)|0;ja=qa<<2&12|ia&3;pa=ia>>2;X=qa>>2;aa=c[A>>2]|0;ra=(ba(X,aa)|0)+pa|0;ka=c[e+306192+($*2224|0)>>2]|0;la=ka+ra|0;sa=c[e+427400>>2]|0;ta=sa<<4;ua=c[e+427396>>2]<<4>>c[K>>2];va=ia&7;wa=(va|0)==0?0:-3;xa=(qa&7|0)==0?0:-3;do{if((pa|0)<(-wa|0)){z=74}else{if((X|0)<(-xa|0)){z=74;break}if((pa+16|0)>(ta+wa|0)){z=74;break}if((X+16|0)>(ua+xa|0)){z=74}else{ya=la;za=0;Aa=aa}}}while(0);if((z|0)==74){la=e+572684|0;Ne[c[e+4>>2]&127](c[la>>2]|0,ka+(-2-(aa<<1)+ra)|0,aa,aa,21,21,pa-2|0,X-2|0,ta,ua);xa=c[A>>2]|0;ya=(c[la>>2]|0)+((xa<<1)+2)|0;za=1;Aa=xa}xa=O+(ja<<2)|0;Xe[c[xa>>2]&4095](E,ya,Aa);if((g|0)==0){Xe[c[xa>>2]&4095](j+(D+i)|0,ya+i|0,c[A>>2]|0)}if((c[K>>2]|0)==0){Ba=qa;Ca=za}else{xa=(1-(c[e+306192+($*2224|0)+2192>>2]|0)+(c[J>>2]&1)<<1)+qa|0;la=xa>>3;if((la|0)<0){Da=1}else{Da=(la+8|0)>=(ua>>1|0)|0}Ba=xa;Ca=Da|za}xa=ia>>3;la=Ba>>3;wa=c[F>>2]|0;M=(ba(wa,la)|0)+xa|0;G=(c[e+306192+($*2224|0)+4>>2]|0)+M|0;L=(c[e+306192+($*2224|0)+8>>2]|0)+M|0;if((Ca|0)==0){M=h>>1;_=Ba&7;Se[N&511](H,G,wa,M,va,_);Ea=L;Fa=M;Ga=_}else{_=e+4|0;M=e+572684|0;Y=sa<<3;Q=ua>>1;Ne[c[_>>2]&127](c[M>>2]|0,G,wa,wa,9,9,xa,la,Y,Q);wa=h>>1;G=Ba&7;Se[N&511](H,c[M>>2]|0,c[F>>2]|0,wa,va,G);R=c[F>>2]|0;Ne[c[_>>2]&127](c[M>>2]|0,L,R,R,9,9,xa,la,Y,Q);Ea=c[M>>2]|0;Fa=wa;Ga=G}Se[N&511](I,Ea,c[F>>2]|0,Fa,va,Ga);return}}while(0);Ga=c[s>>2]|0;Fa=c[s+4>>2]|0;s=c[t>>2]|0;Ea=c[t+4>>2]|0;t=e+6112|0;N=c[t>>2]|0;Ba=(ba(n<<1,N)|0)+(m<<1)|0;Ca=j+Ba|0;za=h>>1;Da=e+6116|0;ya=c[Da>>2]|0;Aa=(ba(ya,n)|0)+m|0;O=k+Aa|0;k=l+Aa|0;Aa=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;q=c[l>>2]|0;r=(C>>q<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[473424+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(Aa<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(r<<3)|0;v=C<<2&12|n&3;oa=n>>2;na=C>>2;ma=(ba(na,N)|0)+oa|0;fa=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;ga=fa+ma|0;da=c[e+427400>>2]|0;ha=da<<4;ca=c[e+427396>>2]<<4>>q;ea=n&7;x=(ea|0)==0?0:-3;G=(C&7|0)==0?0:-3;do{if((oa|0)<(-x|0)){z=41}else{if((na|0)<(-G|0)){z=41;break}if((oa+16|0)>(x+ha|0)){z=41;break}if((na+16|0)>(ca+G|0)){z=41}else{Ha=ga;Ia=0;Ja=N}}}while(0);if((z|0)==41){ga=e+572684|0;Ne[c[e+4>>2]&127](c[ga>>2]|0,fa+(-2-(N<<1)+ma)|0,N,N,21,21,oa-2|0,na-2|0,ha,ca);ha=c[t>>2]|0;Ha=(c[ga>>2]|0)+((ha<<1)+2)|0;Ia=1;Ja=ha}ha=o+(v<<2)|0;Xe[c[ha>>2]&4095](Ca,Ha,Ja);if((g|0)==0){Xe[c[ha>>2]&4095](j+(Ba+i)|0,Ha+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){Ka=C;La=Ia}else{Ha=(1-(c[e+199440+(u*106752|0)+(y*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+C|0;C=Ha>>3;if((C|0)<0){Ma=1}else{Ma=(C+8|0)>=(ca>>1|0)|0}Ka=Ha;La=Ma|Ia}Ia=n>>3;n=Ka>>3;Ma=c[Da>>2]|0;Ha=(ba(Ma,n)|0)+Ia|0;C=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+Ha|0;ha=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+Ha|0;if((La|0)==0){La=Ka&7;Se[p&511](O,C,Ma,za,ea,La);Na=ha;Oa=La}else{La=e+4|0;Ha=e+572684|0;Ja=da<<3;da=ca>>1;Ne[c[La>>2]&127](c[Ha>>2]|0,C,Ma,Ma,9,9,Ia,n,Ja,da);Ma=Ka&7;Se[p&511](O,c[Ha>>2]|0,c[Da>>2]|0,za,ea,Ma);Ka=c[Da>>2]|0;Ne[c[La>>2]&127](c[Ha>>2]|0,ha,Ka,Ka,9,9,Ia,n,Ja,da);Na=c[Ha>>2]|0;Oa=Ma}Se[p&511](k,Na,c[Da>>2]|0,za,ea,Oa);Se[Ga&511](Ca,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}Ga=e+177132|0;Se[Fa&511](O,c[Da>>2]|0,za,c[Ga>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);Se[Fa&511](k,c[Da>>2]|0,za,c[Ga>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+16|0;Ga=ya<<4;ya=u+Ga|0;Fa=d[473424+f|0]|0;f=a[e+5632+Fa|0]|0;Oa=a[e+5672+Fa|0]|0;ea=Aa<<3;Aa=(b[e+5312+(Fa<<2)>>1]|0)+ea|0;Na=r<<3;r=(b[e+5312+(Fa<<2)+2>>1]|0)+Na|0;Ma=r<<2&12|Aa&3;Ha=Aa>>2;da=r>>2;Ja=(ba(da,N)|0)+Ha|0;n=c[e+199440+(f*2224|0)>>2]|0;Ia=n+Ja|0;Ka=e+427400|0;ha=c[Ka>>2]|0;La=ha<<4;C=e+427396|0;ca=c[C>>2]<<4>>q;q=Aa&7;v=(q|0)==0?0:-3;ga=(r&7|0)==0?0:-3;do{if((Ha|0)<(-v|0)){z=10}else{if((da|0)<(-ga|0)){z=10;break}if((Ha+16|0)>(v+La|0)){z=10;break}if((da+16|0)>(ca+ga|0)){z=10}else{Pa=Ia;Qa=0;Ra=N}}}while(0);if((z|0)==10){Ia=e+572684|0;Ne[c[e+4>>2]&127](c[Ia>>2]|0,n+(-2-(N<<1)+Ja)|0,N,N,21,21,Ha-2|0,da-2|0,La,ca);La=c[t>>2]|0;Pa=(c[Ia>>2]|0)+((La<<1)+2)|0;Qa=1;Ra=La}La=o+(Ma<<2)|0;Xe[c[La>>2]&4095](Ca,Pa,Ra);Ra=(g|0)!=0;if(!Ra){Xe[c[La>>2]&4095](j+(Ba+i)|0,Pa+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){Sa=r;Ta=Qa}else{Pa=(1-(c[e+199440+(f*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+r|0;r=Pa>>3;if((r|0)<0){Ua=1}else{Ua=(r+8|0)>=(ca>>1|0)|0}Sa=Pa;Ta=Ua|Qa}Qa=Aa>>3;Aa=Sa>>3;Ua=c[Da>>2]|0;Pa=(ba(Ua,Aa)|0)+Qa|0;r=(c[e+199440+(f*2224|0)+4>>2]|0)+Pa|0;Ba=(c[e+199440+(f*2224|0)+8>>2]|0)+Pa|0;if((Ta|0)==0){Ta=Sa&7;Se[p&511](O,r,Ua,za,q,Ta);Va=Ba;Wa=Ta}else{Ta=e+4|0;Pa=e+572684|0;j=ha<<3;ha=ca>>1;Ne[c[Ta>>2]&127](c[Pa>>2]|0,r,Ua,Ua,9,9,Qa,Aa,j,ha);Ua=Sa&7;Se[p&511](O,c[Pa>>2]|0,c[Da>>2]|0,za,q,Ua);Sa=c[Da>>2]|0;Ne[c[Ta>>2]&127](c[Pa>>2]|0,Ba,Sa,Sa,9,9,Qa,Aa,j,ha);Va=c[Pa>>2]|0;Wa=Ua}Se[p&511](k,Va,c[Da>>2]|0,za,q,Wa);Wa=(b[e+5472+(Fa<<2)>>1]|0)+ea|0;ea=(b[e+5472+(Fa<<2)+2>>1]|0)+Na|0;Na=ea<<2&12|Wa&3;Fa=Wa>>2;q=ea>>2;Va=c[t>>2]|0;Ua=(ba(q,Va)|0)+Fa|0;Pa=c[e+306192+(Oa*2224|0)>>2]|0;ha=Pa+Ua|0;j=c[Ka>>2]|0;Ka=j<<4;Aa=c[C>>2]<<4>>c[l>>2];C=Wa&7;Qa=(C|0)==0?0:-3;Sa=(ea&7|0)==0?0:-3;do{if((Fa|0)<(-Qa|0)){z=24}else{if((q|0)<(-Sa|0)){z=24;break}if((Fa+16|0)>(Ka+Qa|0)){z=24;break}if((q+16|0)>(Aa+Sa|0)){z=24}else{Xa=ha;Ya=0;Za=Va}}}while(0);if((z|0)==24){z=e+572684|0;Ne[c[e+4>>2]&127](c[z>>2]|0,Pa+(-2-(Va<<1)+Ua)|0,Va,Va,21,21,Fa-2|0,q-2|0,Ka,Aa);Ka=c[t>>2]|0;Xa=(c[z>>2]|0)+((Ka<<1)+2)|0;Ya=1;Za=Ka}Ka=o+(Na<<2)|0;Xe[c[Ka>>2]&4095](ya,Xa,Za);if(!Ra){Xe[c[Ka>>2]&4095](u+(Ga+i)|0,Xa+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){_a=ea;$a=Ya}else{l=(1-(c[e+306192+(Oa*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+ea|0;ea=l>>3;if((ea|0)<0){ab=1}else{ab=(ea+8|0)>=(Aa>>1|0)|0}_a=l;$a=ab|Ya}Ya=Wa>>3;Wa=_a>>3;ab=c[Da>>2]|0;l=(ba(ab,Wa)|0)+Ya|0;ea=(c[e+306192+(Oa*2224|0)+4>>2]|0)+l|0;i=(c[e+306192+(Oa*2224|0)+8>>2]|0)+l|0;if(($a|0)==0){$a=_a&7;Se[p&511](u,ea,ab,za,C,$a);bb=i;cb=$a}else{$a=e+4|0;l=e+572684|0;Xa=j<<3;j=Aa>>1;Ne[c[$a>>2]&127](c[l>>2]|0,ea,ab,ab,9,9,Ya,Wa,Xa,j);ab=_a&7;Se[p&511](u,c[l>>2]|0,c[Da>>2]|0,za,C,ab);_a=c[Da>>2]|0;Ne[c[$a>>2]&127](c[l>>2]|0,i,_a,_a,9,9,Ya,Wa,Xa,j);bb=c[l>>2]|0;cb=ab}Se[p&511](y,bb,c[Da>>2]|0,za,C,cb);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Oa<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Be[s&127](Ca,ya,c[t>>2]|0,h,5,w,m,0);Be[Ea&127](O,u,c[Da>>2]|0,za,5,w,m,0);Be[Ea&127](k,y,c[Da>>2]|0,za,5,w,m,0);return}else{Be[s&127](Ca,ya,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Oa<<4)+8>>2]|0,(c[e+177136+(Oa<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);h=e+177132|0;Be[Ea&127](O,u,c[Da>>2]|0,za,c[h>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Oa<<5)+16>>2]|0,(c[e+177904+(Oa<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Be[Ea&127](k,y,c[Da>>2]|0,za,c[h>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Oa<<5)+24>>2]|0,(c[e+177904+(Oa<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function xda(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[473424+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=n<<1;B=e+6112|0;D=c[B>>2]|0;E=(ba(D,A)|0)+(m<<1)|0;F=j+E|0;G=e+6116|0;H=(ba(c[G>>2]|0,A)|0)+m|0;A=k+H|0;I=l+H|0;H=(c[e+427376>>2]<<3)+m|0;J=e+177092|0;K=c[J>>2]|0;L=(c[e+427380>>2]>>K<<3)+n|0;if(y){M=p;N=o}else{O=d[473424+f|0]|0;P=a[e+5632+O|0]|0;Q=(b[e+5312+(O<<2)>>1]|0)+(H<<3)|0;R=(b[e+5312+(O<<2)+2>>1]|0)+(L<<3)|0;O=R<<2&12|Q&3;S=Q>>2;T=R>>2;U=(ba(T,D)|0)+S|0;V=c[e+199440+(P*2224|0)>>2]|0;W=V+U|0;X=c[e+427400>>2]|0;Y=X<<4;Z=c[e+427396>>2]<<4>>K;K=Q&7;_=(K|0)==0?0:-3;$=(R&7|0)==0?0:-3;do{if((S|0)<(-_|0)){z=46}else{if((T|0)<(-$|0)){z=46;break}if((S+16|0)>(_+Y|0)){z=46;break}if((T+16|0)>(Z+$|0)){z=46}else{aa=W;ca=0;da=D}}}while(0);if((z|0)==46){W=e+572684|0;Ne[c[e+4>>2]&127](c[W>>2]|0,V+(-2-(D<<1)+U)|0,D,D,21,21,S-2|0,T-2|0,Y,Z);$=c[B>>2]|0;aa=(c[W>>2]|0)+(($<<1)+2)|0;ca=1;da=$}$=o+(O<<2)|0;Xe[c[$>>2]&4095](F,aa,da);if((g|0)==0){Xe[c[$>>2]&4095](j+(E+i)|0,aa+i|0,c[B>>2]|0)}$=Q>>3;W=c[G>>2]|0;_=(ba(W,T)|0)+$|0;ea=(c[e+199440+(P*2224|0)+4>>2]|0)+_|0;fa=(c[e+199440+(P*2224|0)+8>>2]|0)+_|0;if((ca|0)==0){_=R<<1&6;Se[p&511](A,ea,W,h,K,_);ga=fa;ha=_}else{_=e+4|0;ia=e+572684|0;ja=X<<3;Ne[c[_>>2]&127](c[ia>>2]|0,ea,W,W,9,17,$,T,ja,Z);W=R<<1&6;Se[p&511](A,c[ia>>2]|0,c[G>>2]|0,h,K,W);ea=c[G>>2]|0;Ne[c[_>>2]&127](c[ia>>2]|0,fa,ea,ea,9,17,$,T,ja,Z);ga=c[ia>>2]|0;ha=W}Se[p&511](I,ga,c[G>>2]|0,h,K,ha);M=r;N=q}if(u){return}W=d[473424+f|0]|0;ia=a[e+5672+W|0]|0;ja=(b[e+5472+(W<<2)>>1]|0)+(H<<3)|0;$=(b[e+5472+(W<<2)+2>>1]|0)+(L<<3)|0;W=$<<2&12|ja&3;ea=ja>>2;fa=$>>2;_=c[B>>2]|0;ka=(ba(fa,_)|0)+ea|0;la=c[e+306192+(ia*2224|0)>>2]|0;ma=la+ka|0;na=c[e+427400>>2]|0;oa=na<<4;pa=c[e+427396>>2]<<4>>c[J>>2];qa=ja&7;ra=(qa|0)==0?0:-3;sa=($&7|0)==0?0:-3;do{if((ea|0)<(-ra|0)){z=58}else{if((fa|0)<(-sa|0)){z=58;break}if((ea+16|0)>(oa+ra|0)){z=58;break}if((fa+16|0)>(pa+sa|0)){z=58}else{ta=ma;ua=0;va=_}}}while(0);if((z|0)==58){ma=e+572684|0;Ne[c[e+4>>2]&127](c[ma>>2]|0,la+(-2-(_<<1)+ka)|0,_,_,21,21,ea-2|0,fa-2|0,oa,pa);sa=c[B>>2]|0;ta=(c[ma>>2]|0)+((sa<<1)+2)|0;ua=1;va=sa}sa=N+(W<<2)|0;Xe[c[sa>>2]&4095](F,ta,va);if((g|0)==0){Xe[c[sa>>2]&4095](j+(E+i)|0,ta+i|0,c[B>>2]|0)}sa=ja>>3;ma=c[G>>2]|0;ra=(ba(ma,fa)|0)+sa|0;J=(c[e+306192+(ia*2224|0)+4>>2]|0)+ra|0;L=(c[e+306192+(ia*2224|0)+8>>2]|0)+ra|0;if((ua|0)==0){ra=$<<1&6;Se[M&511](A,J,ma,h,qa,ra);wa=L;xa=ra}else{ra=e+4|0;H=e+572684|0;K=na<<3;Ne[c[ra>>2]&127](c[H>>2]|0,J,ma,ma,9,17,sa,fa,K,pa);ma=$<<1&6;Se[M&511](A,c[H>>2]|0,c[G>>2]|0,h,qa,ma);J=c[G>>2]|0;Ne[c[ra>>2]&127](c[H>>2]|0,L,J,J,9,17,sa,fa,K,pa);wa=c[H>>2]|0;xa=ma}Se[M&511](I,wa,c[G>>2]|0,h,qa,xa);return}}while(0);xa=c[s>>2]|0;wa=c[s+4>>2]|0;s=c[t>>2]|0;M=c[t+4>>2]|0;t=n<<1;ua=e+6112|0;ta=c[ua>>2]|0;va=(ba(ta,t)|0)+(m<<1)|0;N=j+va|0;q=e+6116|0;r=c[q>>2]|0;ha=(ba(r,t)|0)+m|0;t=k+ha|0;k=l+ha|0;ha=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;ga=c[l>>2]|0;ca=(C>>ga<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[473424+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(ha<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(ca<<3)|0;v=C<<2&12|n&3;aa=n>>2;da=C>>2;x=(ba(da,ta)|0)+aa|0;ma=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;H=ma+x|0;K=c[e+427400>>2]|0;sa=K<<4;J=c[e+427396>>2]<<4>>ga;L=n&7;ra=(L|0)==0?0:-3;Z=(C&7|0)==0?0:-3;do{if((aa|0)<(-ra|0)){z=33}else{if((da|0)<(-Z|0)){z=33;break}if((aa+16|0)>(ra+sa|0)){z=33;break}if((da+16|0)>(J+Z|0)){z=33}else{ya=H;za=0;Aa=ta}}}while(0);if((z|0)==33){H=e+572684|0;Ne[c[e+4>>2]&127](c[H>>2]|0,ma+(-2-(ta<<1)+x)|0,ta,ta,21,21,aa-2|0,da-2|0,sa,J);sa=c[ua>>2]|0;ya=(c[H>>2]|0)+((sa<<1)+2)|0;za=1;Aa=sa}sa=o+(v<<2)|0;Xe[c[sa>>2]&4095](N,ya,Aa);if((g|0)==0){Xe[c[sa>>2]&4095](j+(va+i)|0,ya+i|0,c[ua>>2]|0)}ya=n>>3;n=c[q>>2]|0;sa=(ba(n,da)|0)+ya|0;Aa=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+sa|0;v=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+sa|0;if((za|0)==0){za=C<<1&6;Se[p&511](t,Aa,n,h,L,za);Ba=v;Ca=za}else{za=e+4|0;sa=e+572684|0;H=K<<3;Ne[c[za>>2]&127](c[sa>>2]|0,Aa,n,n,9,17,ya,da,H,J);n=C<<1&6;Se[p&511](t,c[sa>>2]|0,c[q>>2]|0,h,L,n);C=c[q>>2]|0;Ne[c[za>>2]&127](c[sa>>2]|0,v,C,C,9,17,ya,da,H,J);Ba=c[sa>>2]|0;Ca=n}Se[p&511](k,Ba,c[q>>2]|0,h,L,Ca);Se[xa&511](N,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}xa=e+177132|0;Se[wa&511](t,c[q>>2]|0,h,c[xa>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);Se[wa&511](k,c[q>>2]|0,h,c[xa>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+16|0;xa=r<<4;r=u+xa|0;wa=d[473424+f|0]|0;f=a[e+5632+wa|0]|0;Ca=a[e+5672+wa|0]|0;L=ha<<3;ha=(b[e+5312+(wa<<2)>>1]|0)+L|0;Ba=ca<<3;ca=(b[e+5312+(wa<<2)+2>>1]|0)+Ba|0;n=ca<<2&12|ha&3;sa=ha>>2;J=ca>>2;H=(ba(J,ta)|0)+sa|0;da=c[e+199440+(f*2224|0)>>2]|0;ya=da+H|0;C=e+427400|0;v=c[C>>2]|0;za=v<<4;Aa=e+427396|0;K=c[Aa>>2]<<4>>ga;ga=ha&7;aa=(ga|0)==0?0:-3;x=(ca&7|0)==0?0:-3;do{if((sa|0)<(-aa|0)){z=10}else{if((J|0)<(-x|0)){z=10;break}if((sa+16|0)>(aa+za|0)){z=10;break}if((J+16|0)>(K+x|0)){z=10}else{Da=ya;Ea=0;Fa=ta}}}while(0);if((z|0)==10){ya=e+572684|0;Ne[c[e+4>>2]&127](c[ya>>2]|0,da+(-2-(ta<<1)+H)|0,ta,ta,21,21,sa-2|0,J-2|0,za,K);za=c[ua>>2]|0;Da=(c[ya>>2]|0)+((za<<1)+2)|0;Ea=1;Fa=za}za=o+(n<<2)|0;Xe[c[za>>2]&4095](N,Da,Fa);Fa=(g|0)!=0;if(!Fa){Xe[c[za>>2]&4095](j+(va+i)|0,Da+i|0,c[ua>>2]|0)}Da=ha>>3;ha=c[q>>2]|0;va=(ba(ha,J)|0)+Da|0;j=(c[e+199440+(f*2224|0)+4>>2]|0)+va|0;za=(c[e+199440+(f*2224|0)+8>>2]|0)+va|0;if((Ea|0)==0){Ea=ca<<1&6;Se[p&511](t,j,ha,h,ga,Ea);Ga=za;Ha=Ea}else{Ea=e+4|0;va=e+572684|0;g=v<<3;Ne[c[Ea>>2]&127](c[va>>2]|0,j,ha,ha,9,17,Da,J,g,K);ha=ca<<1&6;Se[p&511](t,c[va>>2]|0,c[q>>2]|0,h,ga,ha);ca=c[q>>2]|0;Ne[c[Ea>>2]&127](c[va>>2]|0,za,ca,ca,9,17,Da,J,g,K);Ga=c[va>>2]|0;Ha=ha}Se[p&511](k,Ga,c[q>>2]|0,h,ga,Ha);Ha=(b[e+5472+(wa<<2)>>1]|0)+L|0;L=(b[e+5472+(wa<<2)+2>>1]|0)+Ba|0;Ba=L<<2&12|Ha&3;wa=Ha>>2;ga=L>>2;Ga=c[ua>>2]|0;ha=(ba(ga,Ga)|0)+wa|0;va=c[e+306192+(Ca*2224|0)>>2]|0;K=va+ha|0;g=c[C>>2]|0;C=g<<4;J=c[Aa>>2]<<4>>c[l>>2];l=Ha&7;Aa=(l|0)==0?0:-3;Da=(L&7|0)==0?0:-3;do{if((wa|0)<(-Aa|0)){z=20}else{if((ga|0)<(-Da|0)){z=20;break}if((wa+16|0)>(C+Aa|0)){z=20;break}if((ga+16|0)>(J+Da|0)){z=20}else{Ia=K;Ja=0;Ka=Ga}}}while(0);if((z|0)==20){z=e+572684|0;Ne[c[e+4>>2]&127](c[z>>2]|0,va+(-2-(Ga<<1)+ha)|0,Ga,Ga,21,21,wa-2|0,ga-2|0,C,J);C=c[ua>>2]|0;Ia=(c[z>>2]|0)+((C<<1)+2)|0;Ja=1;Ka=C}C=o+(Ba<<2)|0;Xe[c[C>>2]&4095](r,Ia,Ka);if(!Fa){Xe[c[C>>2]&4095](u+(xa+i)|0,Ia+i|0,c[ua>>2]|0)}i=Ha>>3;Ha=c[q>>2]|0;Ia=(ba(Ha,ga)|0)+i|0;xa=(c[e+306192+(Ca*2224|0)+4>>2]|0)+Ia|0;C=(c[e+306192+(Ca*2224|0)+8>>2]|0)+Ia|0;if((Ja|0)==0){Ja=L<<1&6;Se[p&511](u,xa,Ha,h,l,Ja);La=C;Ma=Ja}else{Ja=e+4|0;Ia=e+572684|0;Fa=g<<3;Ne[c[Ja>>2]&127](c[Ia>>2]|0,xa,Ha,Ha,9,17,i,ga,Fa,J);Ha=L<<1&6;Se[p&511](u,c[Ia>>2]|0,c[q>>2]|0,h,l,Ha);L=c[q>>2]|0;Ne[c[Ja>>2]&127](c[Ia>>2]|0,C,L,L,9,17,i,ga,Fa,J);La=c[Ia>>2]|0;Ma=Ha}Se[p&511](y,La,c[q>>2]|0,h,l,Ma);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Ca<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Be[s&127](N,r,c[ua>>2]|0,h,5,w,m,0);Be[M&127](t,u,c[q>>2]|0,h,5,w,m,0);Be[M&127](k,y,c[q>>2]|0,h,5,w,m,0);return}else{Be[s&127](N,r,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Ca<<4)+8>>2]|0,(c[e+177136+(Ca<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);ua=e+177132|0;Be[M&127](t,u,c[q>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Ca<<5)+16>>2]|0,(c[e+177904+(Ca<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Be[M&127](k,y,c[q>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Ca<<5)+24>>2]|0,(c[e+177904+(Ca<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function yda(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[473424+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=e+6112|0;B=c[A>>2]|0;D=(ba(n<<1,B)|0)+(m<<2)|0;E=j+D|0;F=e+6116|0;G=(ba(c[F>>2]|0,n)|0)+(m<<1)|0;H=k+G|0;I=l+G|0;G=(c[e+427376>>2]<<3)+m|0;J=e+427380|0;K=e+177092|0;L=c[K>>2]|0;M=(c[J>>2]>>L<<3)+n|0;if(y){N=p;O=o}else{P=d[473424+f|0]|0;Q=a[e+5632+P|0]|0;R=(b[e+5312+(P<<2)>>1]|0)+(G<<3)|0;S=(b[e+5312+(P<<2)+2>>1]|0)+(M<<3)|0;P=S<<2&12|R&3;T=R>>2;U=S>>2;V=(ba(U,B)|0)+(T<<1)|0;W=c[e+199440+(Q*2224|0)>>2]|0;X=W+V|0;Y=c[e+427400>>2]|0;Z=Y<<4;_=c[e+427396>>2]<<4>>L;L=R&7;$=(L|0)==0?0:-3;aa=(S&7|0)==0?0:-3;do{if((T|0)<(-$|0)){z=58}else{if((U|0)<(-aa|0)){z=58;break}if((T+16|0)>($+Z|0)){z=58;break}if((U+16|0)>(_+aa|0)){z=58}else{ca=X;da=0;ea=B}}}while(0);if((z|0)==58){X=e+572684|0;Ne[c[e+4>>2]&127](c[X>>2]|0,W+(-4-(B<<1)+V)|0,B,B,21,21,T-2|0,U-2|0,Z,_);aa=c[A>>2]|0;ca=(c[X>>2]|0)+((aa<<1)+4)|0;da=1;ea=aa}aa=o+(P<<2)|0;Xe[c[aa>>2]&4095](E,ca,ea);if((g|0)==0){Xe[c[aa>>2]&4095](j+(D+i)|0,ca+i|0,c[A>>2]|0)}if((c[K>>2]|0)==0){fa=S;ga=da}else{aa=(1-(c[e+199440+(Q*2224|0)+2192>>2]|0)+(c[J>>2]&1)<<1)+S|0;X=aa>>3;if((X|0)<0){ha=1}else{ha=(X+8|0)>=(_>>1|0)|0}fa=aa;ga=ha|da}aa=R>>3;X=fa>>3;$=c[F>>2]|0;ia=(ba($,X)|0)+(aa<<1)|0;ja=(c[e+199440+(Q*2224|0)+4>>2]|0)+ia|0;ka=(c[e+199440+(Q*2224|0)+8>>2]|0)+ia|0;if((ga|0)==0){ia=h>>1;la=fa&7;Se[p&511](H,ja,$,ia,L,la);ma=ka;na=ia;oa=la}else{la=e+4|0;ia=e+572684|0;pa=Y<<3;qa=_>>1;Ne[c[la>>2]&127](c[ia>>2]|0,ja,$,$,9,9,aa,X,pa,qa);$=h>>1;ja=fa&7;Se[p&511](H,c[ia>>2]|0,c[F>>2]|0,$,L,ja);ra=c[F>>2]|0;Ne[c[la>>2]&127](c[ia>>2]|0,ka,ra,ra,9,9,aa,X,pa,qa);ma=c[ia>>2]|0;na=$;oa=ja}Se[p&511](I,ma,c[F>>2]|0,na,L,oa);N=r;O=q}if(u){return}ja=d[473424+f|0]|0;$=a[e+5672+ja|0]|0;ia=(b[e+5472+(ja<<2)>>1]|0)+(G<<3)|0;qa=(b[e+5472+(ja<<2)+2>>1]|0)+(M<<3)|0;ja=qa<<2&12|ia&3;pa=ia>>2;X=qa>>2;aa=c[A>>2]|0;ra=(ba(X,aa)|0)+(pa<<1)|0;ka=c[e+306192+($*2224|0)>>2]|0;la=ka+ra|0;sa=c[e+427400>>2]|0;ta=sa<<4;ua=c[e+427396>>2]<<4>>c[K>>2];va=ia&7;wa=(va|0)==0?0:-3;xa=(qa&7|0)==0?0:-3;do{if((pa|0)<(-wa|0)){z=74}else{if((X|0)<(-xa|0)){z=74;break}if((pa+16|0)>(ta+wa|0)){z=74;break}if((X+16|0)>(ua+xa|0)){z=74}else{ya=la;za=0;Aa=aa}}}while(0);if((z|0)==74){la=e+572684|0;Ne[c[e+4>>2]&127](c[la>>2]|0,ka+(-4-(aa<<1)+ra)|0,aa,aa,21,21,pa-2|0,X-2|0,ta,ua);xa=c[A>>2]|0;ya=(c[la>>2]|0)+((xa<<1)+4)|0;za=1;Aa=xa}xa=O+(ja<<2)|0;Xe[c[xa>>2]&4095](E,ya,Aa);if((g|0)==0){Xe[c[xa>>2]&4095](j+(D+i)|0,ya+i|0,c[A>>2]|0)}if((c[K>>2]|0)==0){Ba=qa;Ca=za}else{xa=(1-(c[e+306192+($*2224|0)+2192>>2]|0)+(c[J>>2]&1)<<1)+qa|0;la=xa>>3;if((la|0)<0){Da=1}else{Da=(la+8|0)>=(ua>>1|0)|0}Ba=xa;Ca=Da|za}xa=ia>>3;la=Ba>>3;wa=c[F>>2]|0;M=(ba(wa,la)|0)+(xa<<1)|0;G=(c[e+306192+($*2224|0)+4>>2]|0)+M|0;L=(c[e+306192+($*2224|0)+8>>2]|0)+M|0;if((Ca|0)==0){M=h>>1;_=Ba&7;Se[N&511](H,G,wa,M,va,_);Ea=L;Fa=M;Ga=_}else{_=e+4|0;M=e+572684|0;Y=sa<<3;Q=ua>>1;Ne[c[_>>2]&127](c[M>>2]|0,G,wa,wa,9,9,xa,la,Y,Q);wa=h>>1;G=Ba&7;Se[N&511](H,c[M>>2]|0,c[F>>2]|0,wa,va,G);R=c[F>>2]|0;Ne[c[_>>2]&127](c[M>>2]|0,L,R,R,9,9,xa,la,Y,Q);Ea=c[M>>2]|0;Fa=wa;Ga=G}Se[N&511](I,Ea,c[F>>2]|0,Fa,va,Ga);return}}while(0);Ga=c[s>>2]|0;Fa=c[s+4>>2]|0;s=c[t>>2]|0;Ea=c[t+4>>2]|0;t=e+6112|0;N=c[t>>2]|0;Ba=(ba(n<<1,N)|0)+(m<<2)|0;Ca=j+Ba|0;za=h>>1;Da=e+6116|0;ya=c[Da>>2]|0;Aa=(ba(ya,n)|0)+(m<<1)|0;O=k+Aa|0;k=l+Aa|0;Aa=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;q=c[l>>2]|0;r=(C>>q<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[473424+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(Aa<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(r<<3)|0;v=C<<2&12|n&3;oa=n>>2;na=C>>2;ma=(ba(na,N)|0)+(oa<<1)|0;fa=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;ga=fa+ma|0;da=c[e+427400>>2]|0;ha=da<<4;ca=c[e+427396>>2]<<4>>q;ea=n&7;x=(ea|0)==0?0:-3;G=(C&7|0)==0?0:-3;do{if((oa|0)<(-x|0)){z=41}else{if((na|0)<(-G|0)){z=41;break}if((oa+16|0)>(x+ha|0)){z=41;break}if((na+16|0)>(ca+G|0)){z=41}else{Ha=ga;Ia=0;Ja=N}}}while(0);if((z|0)==41){ga=e+572684|0;Ne[c[e+4>>2]&127](c[ga>>2]|0,fa+(-4-(N<<1)+ma)|0,N,N,21,21,oa-2|0,na-2|0,ha,ca);ha=c[t>>2]|0;Ha=(c[ga>>2]|0)+((ha<<1)+4)|0;Ia=1;Ja=ha}ha=o+(v<<2)|0;Xe[c[ha>>2]&4095](Ca,Ha,Ja);if((g|0)==0){Xe[c[ha>>2]&4095](j+(Ba+i)|0,Ha+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){Ka=C;La=Ia}else{Ha=(1-(c[e+199440+(u*106752|0)+(y*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+C|0;C=Ha>>3;if((C|0)<0){Ma=1}else{Ma=(C+8|0)>=(ca>>1|0)|0}Ka=Ha;La=Ma|Ia}Ia=n>>3;n=Ka>>3;Ma=c[Da>>2]|0;Ha=(ba(Ma,n)|0)+(Ia<<1)|0;C=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+Ha|0;ha=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+Ha|0;if((La|0)==0){La=Ka&7;Se[p&511](O,C,Ma,za,ea,La);Na=ha;Oa=La}else{La=e+4|0;Ha=e+572684|0;Ja=da<<3;da=ca>>1;Ne[c[La>>2]&127](c[Ha>>2]|0,C,Ma,Ma,9,9,Ia,n,Ja,da);Ma=Ka&7;Se[p&511](O,c[Ha>>2]|0,c[Da>>2]|0,za,ea,Ma);Ka=c[Da>>2]|0;Ne[c[La>>2]&127](c[Ha>>2]|0,ha,Ka,Ka,9,9,Ia,n,Ja,da);Na=c[Ha>>2]|0;Oa=Ma}Se[p&511](k,Na,c[Da>>2]|0,za,ea,Oa);Se[Ga&511](Ca,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}Ga=e+177132|0;Se[Fa&511](O,c[Da>>2]|0,za,c[Ga>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);Se[Fa&511](k,c[Da>>2]|0,za,c[Ga>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+32|0;Ga=ya<<4;ya=u+Ga|0;Fa=d[473424+f|0]|0;f=a[e+5632+Fa|0]|0;Oa=a[e+5672+Fa|0]|0;ea=Aa<<3;Aa=(b[e+5312+(Fa<<2)>>1]|0)+ea|0;Na=r<<3;r=(b[e+5312+(Fa<<2)+2>>1]|0)+Na|0;Ma=r<<2&12|Aa&3;Ha=Aa>>2;da=r>>2;Ja=(ba(da,N)|0)+(Ha<<1)|0;n=c[e+199440+(f*2224|0)>>2]|0;Ia=n+Ja|0;Ka=e+427400|0;ha=c[Ka>>2]|0;La=ha<<4;C=e+427396|0;ca=c[C>>2]<<4>>q;q=Aa&7;v=(q|0)==0?0:-3;ga=(r&7|0)==0?0:-3;do{if((Ha|0)<(-v|0)){z=10}else{if((da|0)<(-ga|0)){z=10;break}if((Ha+16|0)>(v+La|0)){z=10;break}if((da+16|0)>(ca+ga|0)){z=10}else{Pa=Ia;Qa=0;Ra=N}}}while(0);if((z|0)==10){Ia=e+572684|0;Ne[c[e+4>>2]&127](c[Ia>>2]|0,n+(-4-(N<<1)+Ja)|0,N,N,21,21,Ha-2|0,da-2|0,La,ca);La=c[t>>2]|0;Pa=(c[Ia>>2]|0)+((La<<1)+4)|0;Qa=1;Ra=La}La=o+(Ma<<2)|0;Xe[c[La>>2]&4095](Ca,Pa,Ra);Ra=(g|0)!=0;if(!Ra){Xe[c[La>>2]&4095](j+(Ba+i)|0,Pa+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){Sa=r;Ta=Qa}else{Pa=(1-(c[e+199440+(f*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+r|0;r=Pa>>3;if((r|0)<0){Ua=1}else{Ua=(r+8|0)>=(ca>>1|0)|0}Sa=Pa;Ta=Ua|Qa}Qa=Aa>>3;Aa=Sa>>3;Ua=c[Da>>2]|0;Pa=(ba(Ua,Aa)|0)+(Qa<<1)|0;r=(c[e+199440+(f*2224|0)+4>>2]|0)+Pa|0;Ba=(c[e+199440+(f*2224|0)+8>>2]|0)+Pa|0;if((Ta|0)==0){Ta=Sa&7;Se[p&511](O,r,Ua,za,q,Ta);Va=Ba;Wa=Ta}else{Ta=e+4|0;Pa=e+572684|0;j=ha<<3;ha=ca>>1;Ne[c[Ta>>2]&127](c[Pa>>2]|0,r,Ua,Ua,9,9,Qa,Aa,j,ha);Ua=Sa&7;Se[p&511](O,c[Pa>>2]|0,c[Da>>2]|0,za,q,Ua);Sa=c[Da>>2]|0;Ne[c[Ta>>2]&127](c[Pa>>2]|0,Ba,Sa,Sa,9,9,Qa,Aa,j,ha);Va=c[Pa>>2]|0;Wa=Ua}Se[p&511](k,Va,c[Da>>2]|0,za,q,Wa);Wa=(b[e+5472+(Fa<<2)>>1]|0)+ea|0;ea=(b[e+5472+(Fa<<2)+2>>1]|0)+Na|0;Na=ea<<2&12|Wa&3;Fa=Wa>>2;q=ea>>2;Va=c[t>>2]|0;Ua=(ba(q,Va)|0)+(Fa<<1)|0;Pa=c[e+306192+(Oa*2224|0)>>2]|0;ha=Pa+Ua|0;j=c[Ka>>2]|0;Ka=j<<4;Aa=c[C>>2]<<4>>c[l>>2];C=Wa&7;Qa=(C|0)==0?0:-3;Sa=(ea&7|0)==0?0:-3;do{if((Fa|0)<(-Qa|0)){z=24}else{if((q|0)<(-Sa|0)){z=24;break}if((Fa+16|0)>(Ka+Qa|0)){z=24;break}if((q+16|0)>(Aa+Sa|0)){z=24}else{Xa=ha;Ya=0;Za=Va}}}while(0);if((z|0)==24){z=e+572684|0;Ne[c[e+4>>2]&127](c[z>>2]|0,Pa+(-4-(Va<<1)+Ua)|0,Va,Va,21,21,Fa-2|0,q-2|0,Ka,Aa);Ka=c[t>>2]|0;Xa=(c[z>>2]|0)+((Ka<<1)+4)|0;Ya=1;Za=Ka}Ka=o+(Na<<2)|0;Xe[c[Ka>>2]&4095](ya,Xa,Za);if(!Ra){Xe[c[Ka>>2]&4095](u+(Ga+i)|0,Xa+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){_a=ea;$a=Ya}else{l=(1-(c[e+306192+(Oa*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+ea|0;ea=l>>3;if((ea|0)<0){ab=1}else{ab=(ea+8|0)>=(Aa>>1|0)|0}_a=l;$a=ab|Ya}Ya=Wa>>3;Wa=_a>>3;ab=c[Da>>2]|0;l=(ba(ab,Wa)|0)+(Ya<<1)|0;ea=(c[e+306192+(Oa*2224|0)+4>>2]|0)+l|0;i=(c[e+306192+(Oa*2224|0)+8>>2]|0)+l|0;if(($a|0)==0){$a=_a&7;Se[p&511](u,ea,ab,za,C,$a);bb=i;cb=$a}else{$a=e+4|0;l=e+572684|0;Xa=j<<3;j=Aa>>1;Ne[c[$a>>2]&127](c[l>>2]|0,ea,ab,ab,9,9,Ya,Wa,Xa,j);ab=_a&7;Se[p&511](u,c[l>>2]|0,c[Da>>2]|0,za,C,ab);_a=c[Da>>2]|0;Ne[c[$a>>2]&127](c[l>>2]|0,i,_a,_a,9,9,Ya,Wa,Xa,j);bb=c[l>>2]|0;cb=ab}Se[p&511](y,bb,c[Da>>2]|0,za,C,cb);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Oa<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Be[s&127](Ca,ya,c[t>>2]|0,h,5,w,m,0);Be[Ea&127](O,u,c[Da>>2]|0,za,5,w,m,0);Be[Ea&127](k,y,c[Da>>2]|0,za,5,w,m,0);return}else{Be[s&127](Ca,ya,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Oa<<4)+8>>2]|0,(c[e+177136+(Oa<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);h=e+177132|0;Be[Ea&127](O,u,c[Da>>2]|0,za,c[h>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Oa<<5)+16>>2]|0,(c[e+177904+(Oa<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Be[Ea&127](k,y,c[Da>>2]|0,za,c[h>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Oa<<5)+24>>2]|0,(c[e+177904+(Oa<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function zda(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[473424+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=n<<1;B=e+6112|0;D=c[B>>2]|0;E=(ba(D,A)|0)+(m<<2)|0;F=j+E|0;G=e+6116|0;H=(ba(c[G>>2]|0,A)|0)+(m<<1)|0;A=k+H|0;I=l+H|0;H=(c[e+427376>>2]<<3)+m|0;J=e+177092|0;K=c[J>>2]|0;L=(c[e+427380>>2]>>K<<3)+n|0;if(y){M=p;N=o}else{O=d[473424+f|0]|0;P=a[e+5632+O|0]|0;Q=(b[e+5312+(O<<2)>>1]|0)+(H<<3)|0;R=(b[e+5312+(O<<2)+2>>1]|0)+(L<<3)|0;O=R<<2&12|Q&3;S=Q>>2;T=R>>2;U=(ba(T,D)|0)+(S<<1)|0;V=c[e+199440+(P*2224|0)>>2]|0;W=V+U|0;X=c[e+427400>>2]|0;Y=X<<4;Z=c[e+427396>>2]<<4>>K;K=Q&7;_=(K|0)==0?0:-3;$=(R&7|0)==0?0:-3;do{if((S|0)<(-_|0)){z=46}else{if((T|0)<(-$|0)){z=46;break}if((S+16|0)>(_+Y|0)){z=46;break}if((T+16|0)>(Z+$|0)){z=46}else{aa=W;ca=0;da=D}}}while(0);if((z|0)==46){W=e+572684|0;Ne[c[e+4>>2]&127](c[W>>2]|0,V+(-4-(D<<1)+U)|0,D,D,21,21,S-2|0,T-2|0,Y,Z);$=c[B>>2]|0;aa=(c[W>>2]|0)+(($<<1)+4)|0;ca=1;da=$}$=o+(O<<2)|0;Xe[c[$>>2]&4095](F,aa,da);if((g|0)==0){Xe[c[$>>2]&4095](j+(E+i)|0,aa+i|0,c[B>>2]|0)}$=Q>>3;W=c[G>>2]|0;_=(ba(W,T)|0)+($<<1)|0;ea=(c[e+199440+(P*2224|0)+4>>2]|0)+_|0;fa=(c[e+199440+(P*2224|0)+8>>2]|0)+_|0;if((ca|0)==0){_=R<<1&6;Se[p&511](A,ea,W,h,K,_);ga=fa;ha=_}else{_=e+4|0;ia=e+572684|0;ja=X<<3;Ne[c[_>>2]&127](c[ia>>2]|0,ea,W,W,9,17,$,T,ja,Z);W=R<<1&6;Se[p&511](A,c[ia>>2]|0,c[G>>2]|0,h,K,W);ea=c[G>>2]|0;Ne[c[_>>2]&127](c[ia>>2]|0,fa,ea,ea,9,17,$,T,ja,Z);ga=c[ia>>2]|0;ha=W}Se[p&511](I,ga,c[G>>2]|0,h,K,ha);M=r;N=q}if(u){return}W=d[473424+f|0]|0;ia=a[e+5672+W|0]|0;ja=(b[e+5472+(W<<2)>>1]|0)+(H<<3)|0;$=(b[e+5472+(W<<2)+2>>1]|0)+(L<<3)|0;W=$<<2&12|ja&3;ea=ja>>2;fa=$>>2;_=c[B>>2]|0;ka=(ba(fa,_)|0)+(ea<<1)|0;la=c[e+306192+(ia*2224|0)>>2]|0;ma=la+ka|0;na=c[e+427400>>2]|0;oa=na<<4;pa=c[e+427396>>2]<<4>>c[J>>2];qa=ja&7;ra=(qa|0)==0?0:-3;sa=($&7|0)==0?0:-3;do{if((ea|0)<(-ra|0)){z=58}else{if((fa|0)<(-sa|0)){z=58;break}if((ea+16|0)>(oa+ra|0)){z=58;break}if((fa+16|0)>(pa+sa|0)){z=58}else{ta=ma;ua=0;va=_}}}while(0);if((z|0)==58){ma=e+572684|0;Ne[c[e+4>>2]&127](c[ma>>2]|0,la+(-4-(_<<1)+ka)|0,_,_,21,21,ea-2|0,fa-2|0,oa,pa);sa=c[B>>2]|0;ta=(c[ma>>2]|0)+((sa<<1)+4)|0;ua=1;va=sa}sa=N+(W<<2)|0;Xe[c[sa>>2]&4095](F,ta,va);if((g|0)==0){Xe[c[sa>>2]&4095](j+(E+i)|0,ta+i|0,c[B>>2]|0)}sa=ja>>3;ma=c[G>>2]|0;ra=(ba(ma,fa)|0)+(sa<<1)|0;J=(c[e+306192+(ia*2224|0)+4>>2]|0)+ra|0;L=(c[e+306192+(ia*2224|0)+8>>2]|0)+ra|0;if((ua|0)==0){ra=$<<1&6;Se[M&511](A,J,ma,h,qa,ra);wa=L;xa=ra}else{ra=e+4|0;H=e+572684|0;K=na<<3;Ne[c[ra>>2]&127](c[H>>2]|0,J,ma,ma,9,17,sa,fa,K,pa);ma=$<<1&6;Se[M&511](A,c[H>>2]|0,c[G>>2]|0,h,qa,ma);J=c[G>>2]|0;Ne[c[ra>>2]&127](c[H>>2]|0,L,J,J,9,17,sa,fa,K,pa);wa=c[H>>2]|0;xa=ma}Se[M&511](I,wa,c[G>>2]|0,h,qa,xa);return}}while(0);xa=c[s>>2]|0;wa=c[s+4>>2]|0;s=c[t>>2]|0;M=c[t+4>>2]|0;t=n<<1;ua=e+6112|0;ta=c[ua>>2]|0;va=(ba(ta,t)|0)+(m<<2)|0;N=j+va|0;q=e+6116|0;r=c[q>>2]|0;ha=(ba(r,t)|0)+(m<<1)|0;t=k+ha|0;k=l+ha|0;ha=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;ga=c[l>>2]|0;ca=(C>>ga<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[473424+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(ha<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(ca<<3)|0;v=C<<2&12|n&3;aa=n>>2;da=C>>2;x=(ba(da,ta)|0)+(aa<<1)|0;ma=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;H=ma+x|0;K=c[e+427400>>2]|0;sa=K<<4;J=c[e+427396>>2]<<4>>ga;L=n&7;ra=(L|0)==0?0:-3;Z=(C&7|0)==0?0:-3;do{if((aa|0)<(-ra|0)){z=33}else{if((da|0)<(-Z|0)){z=33;break}if((aa+16|0)>(ra+sa|0)){z=33;break}if((da+16|0)>(J+Z|0)){z=33}else{ya=H;za=0;Aa=ta}}}while(0);if((z|0)==33){H=e+572684|0;Ne[c[e+4>>2]&127](c[H>>2]|0,ma+(-4-(ta<<1)+x)|0,ta,ta,21,21,aa-2|0,da-2|0,sa,J);sa=c[ua>>2]|0;ya=(c[H>>2]|0)+((sa<<1)+4)|0;za=1;Aa=sa}sa=o+(v<<2)|0;Xe[c[sa>>2]&4095](N,ya,Aa);if((g|0)==0){Xe[c[sa>>2]&4095](j+(va+i)|0,ya+i|0,c[ua>>2]|0)}ya=n>>3;n=c[q>>2]|0;sa=(ba(n,da)|0)+(ya<<1)|0;Aa=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+sa|0;v=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+sa|0;if((za|0)==0){za=C<<1&6;Se[p&511](t,Aa,n,h,L,za);Ba=v;Ca=za}else{za=e+4|0;sa=e+572684|0;H=K<<3;Ne[c[za>>2]&127](c[sa>>2]|0,Aa,n,n,9,17,ya,da,H,J);n=C<<1&6;Se[p&511](t,c[sa>>2]|0,c[q>>2]|0,h,L,n);C=c[q>>2]|0;Ne[c[za>>2]&127](c[sa>>2]|0,v,C,C,9,17,ya,da,H,J);Ba=c[sa>>2]|0;Ca=n}Se[p&511](k,Ba,c[q>>2]|0,h,L,Ca);Se[xa&511](N,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}xa=e+177132|0;Se[wa&511](t,c[q>>2]|0,h,c[xa>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);Se[wa&511](k,c[q>>2]|0,h,c[xa>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+32|0;xa=r<<4;r=u+xa|0;wa=d[473424+f|0]|0;f=a[e+5632+wa|0]|0;Ca=a[e+5672+wa|0]|0;L=ha<<3;ha=(b[e+5312+(wa<<2)>>1]|0)+L|0;Ba=ca<<3;ca=(b[e+5312+(wa<<2)+2>>1]|0)+Ba|0;n=ca<<2&12|ha&3;sa=ha>>2;J=ca>>2;H=(ba(J,ta)|0)+(sa<<1)|0;da=c[e+199440+(f*2224|0)>>2]|0;ya=da+H|0;C=e+427400|0;v=c[C>>2]|0;za=v<<4;Aa=e+427396|0;K=c[Aa>>2]<<4>>ga;ga=ha&7;aa=(ga|0)==0?0:-3;x=(ca&7|0)==0?0:-3;do{if((sa|0)<(-aa|0)){z=10}else{if((J|0)<(-x|0)){z=10;break}if((sa+16|0)>(aa+za|0)){z=10;break}if((J+16|0)>(K+x|0)){z=10}else{Da=ya;Ea=0;Fa=ta}}}while(0);if((z|0)==10){ya=e+572684|0;Ne[c[e+4>>2]&127](c[ya>>2]|0,da+(-4-(ta<<1)+H)|0,ta,ta,21,21,sa-2|0,J-2|0,za,K);za=c[ua>>2]|0;Da=(c[ya>>2]|0)+((za<<1)+4)|0;Ea=1;Fa=za}za=o+(n<<2)|0;Xe[c[za>>2]&4095](N,Da,Fa);Fa=(g|0)!=0;if(!Fa){Xe[c[za>>2]&4095](j+(va+i)|0,Da+i|0,c[ua>>2]|0)}Da=ha>>3;ha=c[q>>2]|0;va=(ba(ha,J)|0)+(Da<<1)|0;j=(c[e+199440+(f*2224|0)+4>>2]|0)+va|0;za=(c[e+199440+(f*2224|0)+8>>2]|0)+va|0;if((Ea|0)==0){Ea=ca<<1&6;Se[p&511](t,j,ha,h,ga,Ea);Ga=za;Ha=Ea}else{Ea=e+4|0;va=e+572684|0;g=v<<3;Ne[c[Ea>>2]&127](c[va>>2]|0,j,ha,ha,9,17,Da,J,g,K);ha=ca<<1&6;Se[p&511](t,c[va>>2]|0,c[q>>2]|0,h,ga,ha);ca=c[q>>2]|0;Ne[c[Ea>>2]&127](c[va>>2]|0,za,ca,ca,9,17,Da,J,g,K);Ga=c[va>>2]|0;Ha=ha}Se[p&511](k,Ga,c[q>>2]|0,h,ga,Ha);Ha=(b[e+5472+(wa<<2)>>1]|0)+L|0;L=(b[e+5472+(wa<<2)+2>>1]|0)+Ba|0;Ba=L<<2&12|Ha&3;wa=Ha>>2;ga=L>>2;Ga=c[ua>>2]|0;ha=(ba(ga,Ga)|0)+(wa<<1)|0;va=c[e+306192+(Ca*2224|0)>>2]|0;K=va+ha|0;g=c[C>>2]|0;C=g<<4;J=c[Aa>>2]<<4>>c[l>>2];l=Ha&7;Aa=(l|0)==0?0:-3;Da=(L&7|0)==0?0:-3;do{if((wa|0)<(-Aa|0)){z=20}else{if((ga|0)<(-Da|0)){z=20;break}if((wa+16|0)>(C+Aa|0)){z=20;break}if((ga+16|0)>(J+Da|0)){z=20}else{Ia=K;Ja=0;Ka=Ga}}}while(0);if((z|0)==20){z=e+572684|0;Ne[c[e+4>>2]&127](c[z>>2]|0,va+(-4-(Ga<<1)+ha)|0,Ga,Ga,21,21,wa-2|0,ga-2|0,C,J);C=c[ua>>2]|0;Ia=(c[z>>2]|0)+((C<<1)+4)|0;Ja=1;Ka=C}C=o+(Ba<<2)|0;Xe[c[C>>2]&4095](r,Ia,Ka);if(!Fa){Xe[c[C>>2]&4095](u+(xa+i)|0,Ia+i|0,c[ua>>2]|0)}i=Ha>>3;Ha=c[q>>2]|0;Ia=(ba(Ha,ga)|0)+(i<<1)|0;xa=(c[e+306192+(Ca*2224|0)+4>>2]|0)+Ia|0;C=(c[e+306192+(Ca*2224|0)+8>>2]|0)+Ia|0;if((Ja|0)==0){Ja=L<<1&6;Se[p&511](u,xa,Ha,h,l,Ja);La=C;Ma=Ja}else{Ja=e+4|0;Ia=e+572684|0;Fa=g<<3;Ne[c[Ja>>2]&127](c[Ia>>2]|0,xa,Ha,Ha,9,17,i,ga,Fa,J);Ha=L<<1&6;Se[p&511](u,c[Ia>>2]|0,c[q>>2]|0,h,l,Ha);L=c[q>>2]|0;Ne[c[Ja>>2]&127](c[Ia>>2]|0,C,L,L,9,17,i,ga,Fa,J);La=c[Ia>>2]|0;Ma=Ha}Se[p&511](y,La,c[q>>2]|0,h,l,Ma);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Ca<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Be[s&127](N,r,c[ua>>2]|0,h,5,w,m,0);Be[M&127](t,u,c[q>>2]|0,h,5,w,m,0);Be[M&127](k,y,c[q>>2]|0,h,5,w,m,0);return}else{Be[s&127](N,r,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Ca<<4)+8>>2]|0,(c[e+177136+(Ca<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);ua=e+177132|0;Be[M&127](t,u,c[q>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Ca<<5)+16>>2]|0,(c[e+177904+(Ca<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Be[M&127](k,y,c[q>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Ca<<5)+24>>2]|0,(c[e+177904+(Ca<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Ada(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[473424+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=c[e+4752>>2]|0;B=e+6112|0;D=c[B>>2]|0;E=(ba(n<<1,D)|0)+(m<<1<<A)|0;F=j+E|0;G=e+6116|0;H=(ba(c[G>>2]|0,n)|0)+(m<<A)|0;I=k+H|0;J=l+H|0;H=(c[e+427376>>2]<<3)+m|0;K=e+427380|0;L=e+177092|0;M=c[L>>2]|0;N=(c[K>>2]>>M<<3)+n|0;if(y){O=p;P=o}else{Q=d[473424+f|0]|0;R=a[e+5632+Q|0]|0;S=(b[e+5312+(Q<<2)>>1]|0)+(H<<3)|0;T=(b[e+5312+(Q<<2)+2>>1]|0)+(N<<3)|0;Q=T<<2&12|S&3;U=S>>2;V=T>>2;W=(ba(V,D)|0)+(U<<A)|0;X=c[e+199440+(R*2224|0)>>2]|0;Y=X+W|0;Z=c[e+427400>>2]|0;_=Z<<4;$=c[e+427396>>2]<<4>>M;M=S&7;aa=(M|0)==0?0:-3;ca=(T&7|0)==0?0:-3;do{if((U|0)<(-aa|0)){z=58}else{if((V|0)<(-ca|0)){z=58;break}if((U+16|0)>(aa+_|0)){z=58;break}if((V+16|0)>($+ca|0)){z=58}else{da=Y;ea=0;fa=D}}}while(0);if((z|0)==58){Y=e+572684|0;ca=2<<A;Ne[c[e+4>>2]&127](c[Y>>2]|0,X+(W-((D<<1)+ca))|0,D,D,21,21,U-2|0,V-2|0,_,$);aa=c[B>>2]|0;da=(c[Y>>2]|0)+((aa<<1)+ca)|0;ea=1;fa=aa}aa=o+(Q<<2)|0;Xe[c[aa>>2]&4095](F,da,fa);if((g|0)==0){Xe[c[aa>>2]&4095](j+(E+i)|0,da+i|0,c[B>>2]|0)}if((c[L>>2]|0)==0){ga=T;ha=ea}else{aa=(1-(c[e+199440+(R*2224|0)+2192>>2]|0)+(c[K>>2]&1)<<1)+T|0;ca=aa>>3;if((ca|0)<0){ia=1}else{ia=(ca+8|0)>=($>>1|0)|0}ga=aa;ha=ia|ea}aa=S>>3;ca=ga>>3;Y=c[G>>2]|0;ja=(ba(Y,ca)|0)+(aa<<A)|0;ka=(c[e+199440+(R*2224|0)+4>>2]|0)+ja|0;la=(c[e+199440+(R*2224|0)+8>>2]|0)+ja|0;if((ha|0)==0){ja=h>>1;ma=ga&7;Se[p&511](I,ka,Y,ja,M,ma);na=la;oa=ja;pa=ma}else{ma=e+4|0;ja=e+572684|0;qa=Z<<3;ra=$>>1;Ne[c[ma>>2]&127](c[ja>>2]|0,ka,Y,Y,9,9,aa,ca,qa,ra);Y=h>>1;ka=ga&7;Se[p&511](I,c[ja>>2]|0,c[G>>2]|0,Y,M,ka);sa=c[G>>2]|0;Ne[c[ma>>2]&127](c[ja>>2]|0,la,sa,sa,9,9,aa,ca,qa,ra);na=c[ja>>2]|0;oa=Y;pa=ka}Se[p&511](J,na,c[G>>2]|0,oa,M,pa);O=r;P=q}if(u){return}ka=d[473424+f|0]|0;Y=a[e+5672+ka|0]|0;ja=(b[e+5472+(ka<<2)>>1]|0)+(H<<3)|0;ra=(b[e+5472+(ka<<2)+2>>1]|0)+(N<<3)|0;ka=ra<<2&12|ja&3;qa=ja>>2;ca=ra>>2;aa=c[B>>2]|0;sa=(ba(ca,aa)|0)+(qa<<A)|0;la=c[e+306192+(Y*2224|0)>>2]|0;ma=la+sa|0;ta=c[e+427400>>2]|0;ua=ta<<4;va=c[e+427396>>2]<<4>>c[L>>2];wa=ja&7;xa=(wa|0)==0?0:-3;ya=(ra&7|0)==0?0:-3;do{if((qa|0)<(-xa|0)){z=74}else{if((ca|0)<(-ya|0)){z=74;break}if((qa+16|0)>(ua+xa|0)){z=74;break}if((ca+16|0)>(va+ya|0)){z=74}else{za=ma;Aa=0;Ba=aa}}}while(0);if((z|0)==74){ma=e+572684|0;ya=2<<A;Ne[c[e+4>>2]&127](c[ma>>2]|0,la+(sa-((aa<<1)+ya))|0,aa,aa,21,21,qa-2|0,ca-2|0,ua,va);xa=c[B>>2]|0;za=(c[ma>>2]|0)+((xa<<1)+ya)|0;Aa=1;Ba=xa}xa=P+(ka<<2)|0;Xe[c[xa>>2]&4095](F,za,Ba);if((g|0)==0){Xe[c[xa>>2]&4095](j+(E+i)|0,za+i|0,c[B>>2]|0)}if((c[L>>2]|0)==0){Ca=ra;Da=Aa}else{xa=(1-(c[e+306192+(Y*2224|0)+2192>>2]|0)+(c[K>>2]&1)<<1)+ra|0;ya=xa>>3;if((ya|0)<0){Ea=1}else{Ea=(ya+8|0)>=(va>>1|0)|0}Ca=xa;Da=Ea|Aa}xa=ja>>3;ya=Ca>>3;ma=c[G>>2]|0;N=(ba(ma,ya)|0)+(xa<<A)|0;H=(c[e+306192+(Y*2224|0)+4>>2]|0)+N|0;M=(c[e+306192+(Y*2224|0)+8>>2]|0)+N|0;if((Da|0)==0){N=h>>1;$=Ca&7;Se[O&511](I,H,ma,N,wa,$);Fa=M;Ga=N;Ha=$}else{$=e+4|0;N=e+572684|0;Z=ta<<3;R=va>>1;Ne[c[$>>2]&127](c[N>>2]|0,H,ma,ma,9,9,xa,ya,Z,R);ma=h>>1;H=Ca&7;Se[O&511](I,c[N>>2]|0,c[G>>2]|0,ma,wa,H);S=c[G>>2]|0;Ne[c[$>>2]&127](c[N>>2]|0,M,S,S,9,9,xa,ya,Z,R);Fa=c[N>>2]|0;Ga=ma;Ha=H}Se[O&511](J,Fa,c[G>>2]|0,Ga,wa,Ha);return}}while(0);Ha=c[s>>2]|0;Ga=c[s+4>>2]|0;s=c[t>>2]|0;Fa=c[t+4>>2]|0;t=c[e+4752>>2]|0;O=e+6112|0;Ca=c[O>>2]|0;Da=(ba(n<<1,Ca)|0)+(m<<1<<t)|0;Aa=j+Da|0;Ea=h>>1;za=e+6116|0;Ba=c[za>>2]|0;P=(ba(Ba,n)|0)+(m<<t)|0;q=k+P|0;k=l+P|0;P=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;r=c[l>>2]|0;pa=(C>>r<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[473424+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(P<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(pa<<3)|0;v=C<<2&12|n&3;oa=n>>2;na=C>>2;ga=(ba(na,Ca)|0)+(oa<<t)|0;ha=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;ea=ha+ga|0;ia=c[e+427400>>2]|0;da=ia<<4;fa=c[e+427396>>2]<<4>>r;x=n&7;H=(x|0)==0?0:-3;ma=(C&7|0)==0?0:-3;do{if((oa|0)<(-H|0)){z=41}else{if((na|0)<(-ma|0)){z=41;break}if((oa+16|0)>(H+da|0)){z=41;break}if((na+16|0)>(fa+ma|0)){z=41}else{Ia=ea;Ja=0;Ka=Ca}}}while(0);if((z|0)==41){ea=e+572684|0;ma=2<<t;Ne[c[e+4>>2]&127](c[ea>>2]|0,ha+(ga-((Ca<<1)+ma))|0,Ca,Ca,21,21,oa-2|0,na-2|0,da,fa);da=c[O>>2]|0;Ia=(c[ea>>2]|0)+((da<<1)+ma)|0;Ja=1;Ka=da}da=o+(v<<2)|0;Xe[c[da>>2]&4095](Aa,Ia,Ka);if((g|0)==0){Xe[c[da>>2]&4095](j+(Da+i)|0,Ia+i|0,c[O>>2]|0)}if((c[l>>2]|0)==0){La=C;Ma=Ja}else{Ia=(1-(c[e+199440+(u*106752|0)+(y*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+C|0;C=Ia>>3;if((C|0)<0){Na=1}else{Na=(C+8|0)>=(fa>>1|0)|0}La=Ia;Ma=Na|Ja}Ja=n>>3;n=La>>3;Na=c[za>>2]|0;Ia=(ba(Na,n)|0)+(Ja<<t)|0;C=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+Ia|0;da=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+Ia|0;if((Ma|0)==0){Ma=La&7;Se[p&511](q,C,Na,Ea,x,Ma);Oa=da;Pa=Ma}else{Ma=e+4|0;Ia=e+572684|0;Ka=ia<<3;ia=fa>>1;Ne[c[Ma>>2]&127](c[Ia>>2]|0,C,Na,Na,9,9,Ja,n,Ka,ia);Na=La&7;Se[p&511](q,c[Ia>>2]|0,c[za>>2]|0,Ea,x,Na);La=c[za>>2]|0;Ne[c[Ma>>2]&127](c[Ia>>2]|0,da,La,La,9,9,Ja,n,Ka,ia);Oa=c[Ia>>2]|0;Pa=Na}Se[p&511](k,Oa,c[za>>2]|0,Ea,x,Pa);Se[Ha&511](Aa,c[O>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}Ha=e+177132|0;Se[Ga&511](q,c[za>>2]|0,Ea,c[Ha>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);Se[Ga&511](k,c[za>>2]|0,Ea,c[Ha>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+(16<<t)|0;Ha=Ba<<4;Ba=u+Ha|0;Ga=d[473424+f|0]|0;f=a[e+5632+Ga|0]|0;Pa=a[e+5672+Ga|0]|0;x=P<<3;P=(b[e+5312+(Ga<<2)>>1]|0)+x|0;Oa=pa<<3;pa=(b[e+5312+(Ga<<2)+2>>1]|0)+Oa|0;Na=pa<<2&12|P&3;Ia=P>>2;ia=pa>>2;Ka=(ba(ia,Ca)|0)+(Ia<<t)|0;n=c[e+199440+(f*2224|0)>>2]|0;Ja=n+Ka|0;La=e+427400|0;da=c[La>>2]|0;Ma=da<<4;C=e+427396|0;fa=c[C>>2]<<4>>r;r=P&7;v=(r|0)==0?0:-3;ma=(pa&7|0)==0?0:-3;do{if((Ia|0)<(-v|0)){z=10}else{if((ia|0)<(-ma|0)){z=10;break}if((Ia+16|0)>(v+Ma|0)){z=10;break}if((ia+16|0)>(fa+ma|0)){z=10}else{Qa=Ja;Ra=0;Sa=Ca}}}while(0);if((z|0)==10){Ja=e+572684|0;ma=2<<t;Ne[c[e+4>>2]&127](c[Ja>>2]|0,n+(Ka-((Ca<<1)+ma))|0,Ca,Ca,21,21,Ia-2|0,ia-2|0,Ma,fa);Ma=c[O>>2]|0;Qa=(c[Ja>>2]|0)+((Ma<<1)+ma)|0;Ra=1;Sa=Ma}Ma=o+(Na<<2)|0;Xe[c[Ma>>2]&4095](Aa,Qa,Sa);Sa=(g|0)!=0;if(!Sa){Xe[c[Ma>>2]&4095](j+(Da+i)|0,Qa+i|0,c[O>>2]|0)}if((c[l>>2]|0)==0){Ta=pa;Ua=Ra}else{Qa=(1-(c[e+199440+(f*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+pa|0;pa=Qa>>3;if((pa|0)<0){Va=1}else{Va=(pa+8|0)>=(fa>>1|0)|0}Ta=Qa;Ua=Va|Ra}Ra=P>>3;P=Ta>>3;Va=c[za>>2]|0;Qa=(ba(Va,P)|0)+(Ra<<t)|0;pa=(c[e+199440+(f*2224|0)+4>>2]|0)+Qa|0;Da=(c[e+199440+(f*2224|0)+8>>2]|0)+Qa|0;if((Ua|0)==0){Ua=Ta&7;Se[p&511](q,pa,Va,Ea,r,Ua);Wa=Da;Xa=Ua}else{Ua=e+4|0;Qa=e+572684|0;j=da<<3;da=fa>>1;Ne[c[Ua>>2]&127](c[Qa>>2]|0,pa,Va,Va,9,9,Ra,P,j,da);Va=Ta&7;Se[p&511](q,c[Qa>>2]|0,c[za>>2]|0,Ea,r,Va);Ta=c[za>>2]|0;Ne[c[Ua>>2]&127](c[Qa>>2]|0,Da,Ta,Ta,9,9,Ra,P,j,da);Wa=c[Qa>>2]|0;Xa=Va}Se[p&511](k,Wa,c[za>>2]|0,Ea,r,Xa);Xa=(b[e+5472+(Ga<<2)>>1]|0)+x|0;x=(b[e+5472+(Ga<<2)+2>>1]|0)+Oa|0;Oa=x<<2&12|Xa&3;Ga=Xa>>2;r=x>>2;Wa=c[O>>2]|0;Va=(ba(r,Wa)|0)+(Ga<<t)|0;Qa=c[e+306192+(Pa*2224|0)>>2]|0;da=Qa+Va|0;j=c[La>>2]|0;La=j<<4;P=c[C>>2]<<4>>c[l>>2];C=Xa&7;Ra=(C|0)==0?0:-3;Ta=(x&7|0)==0?0:-3;do{if((Ga|0)<(-Ra|0)){z=24}else{if((r|0)<(-Ta|0)){z=24;break}if((Ga+16|0)>(La+Ra|0)){z=24;break}if((r+16|0)>(P+Ta|0)){z=24}else{Ya=da;Za=0;_a=Wa}}}while(0);if((z|0)==24){z=e+572684|0;da=2<<t;Ne[c[e+4>>2]&127](c[z>>2]|0,Qa+(Va-((Wa<<1)+da))|0,Wa,Wa,21,21,Ga-2|0,r-2|0,La,P);La=c[O>>2]|0;Ya=(c[z>>2]|0)+((La<<1)+da)|0;Za=1;_a=La}La=o+(Oa<<2)|0;Xe[c[La>>2]&4095](Ba,Ya,_a);if(!Sa){Xe[c[La>>2]&4095](u+(Ha+i)|0,Ya+i|0,c[O>>2]|0)}if((c[l>>2]|0)==0){$a=x;ab=Za}else{l=(1-(c[e+306192+(Pa*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+x|0;x=l>>3;if((x|0)<0){bb=1}else{bb=(x+8|0)>=(P>>1|0)|0}$a=l;ab=bb|Za}Za=Xa>>3;Xa=$a>>3;bb=c[za>>2]|0;l=(ba(bb,Xa)|0)+(Za<<t)|0;t=(c[e+306192+(Pa*2224|0)+4>>2]|0)+l|0;x=(c[e+306192+(Pa*2224|0)+8>>2]|0)+l|0;if((ab|0)==0){ab=$a&7;Se[p&511](u,t,bb,Ea,C,ab);cb=x;db=ab}else{ab=e+4|0;l=e+572684|0;i=j<<3;j=P>>1;Ne[c[ab>>2]&127](c[l>>2]|0,t,bb,bb,9,9,Za,Xa,i,j);bb=$a&7;Se[p&511](u,c[l>>2]|0,c[za>>2]|0,Ea,C,bb);$a=c[za>>2]|0;Ne[c[ab>>2]&127](c[l>>2]|0,x,$a,$a,9,9,Za,Xa,i,j);cb=c[l>>2]|0;db=bb}Se[p&511](y,cb,c[za>>2]|0,Ea,C,db);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Pa<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Be[s&127](Aa,Ba,c[O>>2]|0,h,5,w,m,0);Be[Fa&127](q,u,c[za>>2]|0,Ea,5,w,m,0);Be[Fa&127](k,y,c[za>>2]|0,Ea,5,w,m,0);return}else{Be[s&127](Aa,Ba,c[O>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Pa<<4)+8>>2]|0,(c[e+177136+(Pa<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);h=e+177132|0;Be[Fa&127](q,u,c[za>>2]|0,Ea,c[h>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Pa<<5)+16>>2]|0,(c[e+177904+(Pa<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Be[Fa&127](k,y,c[za>>2]|0,Ea,c[h>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Pa<<5)+24>>2]|0,(c[e+177904+(Pa<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Bda(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[473424+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=c[e+4752>>2]|0;B=n<<1;D=e+6112|0;E=c[D>>2]|0;F=(ba(E,B)|0)+(m<<1<<A)|0;G=j+F|0;H=e+6116|0;I=(ba(c[H>>2]|0,B)|0)+(m<<A)|0;B=k+I|0;J=l+I|0;I=(c[e+427376>>2]<<3)+m|0;K=e+177092|0;L=c[K>>2]|0;M=(c[e+427380>>2]>>L<<3)+n|0;if(y){N=p;O=o}else{P=d[473424+f|0]|0;Q=a[e+5632+P|0]|0;R=(b[e+5312+(P<<2)>>1]|0)+(I<<3)|0;S=(b[e+5312+(P<<2)+2>>1]|0)+(M<<3)|0;P=S<<2&12|R&3;T=R>>2;U=S>>2;V=(ba(U,E)|0)+(T<<A)|0;W=c[e+199440+(Q*2224|0)>>2]|0;X=W+V|0;Y=c[e+427400>>2]|0;Z=Y<<4;_=c[e+427396>>2]<<4>>L;L=R&7;$=(L|0)==0?0:-3;aa=(S&7|0)==0?0:-3;do{if((T|0)<(-$|0)){z=46}else{if((U|0)<(-aa|0)){z=46;break}if((T+16|0)>($+Z|0)){z=46;break}if((U+16|0)>(_+aa|0)){z=46}else{ca=X;da=0;ea=E}}}while(0);if((z|0)==46){X=e+572684|0;aa=2<<A;Ne[c[e+4>>2]&127](c[X>>2]|0,W+(V-((E<<1)+aa))|0,E,E,21,21,T-2|0,U-2|0,Z,_);$=c[D>>2]|0;ca=(c[X>>2]|0)+(($<<1)+aa)|0;da=1;ea=$}$=o+(P<<2)|0;Xe[c[$>>2]&4095](G,ca,ea);if((g|0)==0){Xe[c[$>>2]&4095](j+(F+i)|0,ca+i|0,c[D>>2]|0)}$=R>>3;aa=c[H>>2]|0;X=(ba(aa,U)|0)+($<<A)|0;fa=(c[e+199440+(Q*2224|0)+4>>2]|0)+X|0;ga=(c[e+199440+(Q*2224|0)+8>>2]|0)+X|0;if((da|0)==0){X=S<<1&6;Se[p&511](B,fa,aa,h,L,X);ha=ga;ia=X}else{X=e+4|0;ja=e+572684|0;ka=Y<<3;Ne[c[X>>2]&127](c[ja>>2]|0,fa,aa,aa,9,17,$,U,ka,_);aa=S<<1&6;Se[p&511](B,c[ja>>2]|0,c[H>>2]|0,h,L,aa);fa=c[H>>2]|0;Ne[c[X>>2]&127](c[ja>>2]|0,ga,fa,fa,9,17,$,U,ka,_);ha=c[ja>>2]|0;ia=aa}Se[p&511](J,ha,c[H>>2]|0,h,L,ia);N=r;O=q}if(u){return}aa=d[473424+f|0]|0;ja=a[e+5672+aa|0]|0;ka=(b[e+5472+(aa<<2)>>1]|0)+(I<<3)|0;$=(b[e+5472+(aa<<2)+2>>1]|0)+(M<<3)|0;aa=$<<2&12|ka&3;fa=ka>>2;ga=$>>2;X=c[D>>2]|0;la=(ba(ga,X)|0)+(fa<<A)|0;ma=c[e+306192+(ja*2224|0)>>2]|0;na=ma+la|0;oa=c[e+427400>>2]|0;pa=oa<<4;qa=c[e+427396>>2]<<4>>c[K>>2];ra=ka&7;sa=(ra|0)==0?0:-3;ta=($&7|0)==0?0:-3;do{if((fa|0)<(-sa|0)){z=58}else{if((ga|0)<(-ta|0)){z=58;break}if((fa+16|0)>(pa+sa|0)){z=58;break}if((ga+16|0)>(qa+ta|0)){z=58}else{ua=na;va=0;wa=X}}}while(0);if((z|0)==58){na=e+572684|0;ta=2<<A;Ne[c[e+4>>2]&127](c[na>>2]|0,ma+(la-((X<<1)+ta))|0,X,X,21,21,fa-2|0,ga-2|0,pa,qa);sa=c[D>>2]|0;ua=(c[na>>2]|0)+((sa<<1)+ta)|0;va=1;wa=sa}sa=O+(aa<<2)|0;Xe[c[sa>>2]&4095](G,ua,wa);if((g|0)==0){Xe[c[sa>>2]&4095](j+(F+i)|0,ua+i|0,c[D>>2]|0)}sa=ka>>3;ta=c[H>>2]|0;na=(ba(ta,ga)|0)+(sa<<A)|0;K=(c[e+306192+(ja*2224|0)+4>>2]|0)+na|0;M=(c[e+306192+(ja*2224|0)+8>>2]|0)+na|0;if((va|0)==0){na=$<<1&6;Se[N&511](B,K,ta,h,ra,na);xa=M;ya=na}else{na=e+4|0;I=e+572684|0;L=oa<<3;Ne[c[na>>2]&127](c[I>>2]|0,K,ta,ta,9,17,sa,ga,L,qa);ta=$<<1&6;Se[N&511](B,c[I>>2]|0,c[H>>2]|0,h,ra,ta);K=c[H>>2]|0;Ne[c[na>>2]&127](c[I>>2]|0,M,K,K,9,17,sa,ga,L,qa);xa=c[I>>2]|0;ya=ta}Se[N&511](J,xa,c[H>>2]|0,h,ra,ya);return}}while(0);ya=c[s>>2]|0;xa=c[s+4>>2]|0;s=c[t>>2]|0;N=c[t+4>>2]|0;t=c[e+4752>>2]|0;va=n<<1;ua=e+6112|0;wa=c[ua>>2]|0;O=(ba(wa,va)|0)+(m<<1<<t)|0;q=j+O|0;r=e+6116|0;ia=c[r>>2]|0;ha=(ba(ia,va)|0)+(m<<t)|0;va=k+ha|0;k=l+ha|0;ha=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;da=c[l>>2]|0;ca=(C>>da<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[473424+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(ha<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(ca<<3)|0;v=C<<2&12|n&3;ea=n>>2;x=C>>2;ta=(ba(x,wa)|0)+(ea<<t)|0;I=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;L=I+ta|0;sa=c[e+427400>>2]|0;K=sa<<4;M=c[e+427396>>2]<<4>>da;na=n&7;_=(na|0)==0?0:-3;U=(C&7|0)==0?0:-3;do{if((ea|0)<(-_|0)){z=33}else{if((x|0)<(-U|0)){z=33;break}if((ea+16|0)>(_+K|0)){z=33;break}if((x+16|0)>(M+U|0)){z=33}else{za=L;Aa=0;Ba=wa}}}while(0);if((z|0)==33){L=e+572684|0;U=2<<t;Ne[c[e+4>>2]&127](c[L>>2]|0,I+(ta-((wa<<1)+U))|0,wa,wa,21,21,ea-2|0,x-2|0,K,M);K=c[ua>>2]|0;za=(c[L>>2]|0)+((K<<1)+U)|0;Aa=1;Ba=K}K=o+(v<<2)|0;Xe[c[K>>2]&4095](q,za,Ba);if((g|0)==0){Xe[c[K>>2]&4095](j+(O+i)|0,za+i|0,c[ua>>2]|0)}za=n>>3;n=c[r>>2]|0;K=(ba(n,x)|0)+(za<<t)|0;Ba=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+K|0;v=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+K|0;if((Aa|0)==0){Aa=C<<1&6;Se[p&511](va,Ba,n,h,na,Aa);Ca=v;Da=Aa}else{Aa=e+4|0;K=e+572684|0;U=sa<<3;Ne[c[Aa>>2]&127](c[K>>2]|0,Ba,n,n,9,17,za,x,U,M);n=C<<1&6;Se[p&511](va,c[K>>2]|0,c[r>>2]|0,h,na,n);C=c[r>>2]|0;Ne[c[Aa>>2]&127](c[K>>2]|0,v,C,C,9,17,za,x,U,M);Ca=c[K>>2]|0;Da=n}Se[p&511](k,Ca,c[r>>2]|0,h,na,Da);Se[ya&511](q,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}ya=e+177132|0;Se[xa&511](va,c[r>>2]|0,h,c[ya>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);Se[xa&511](k,c[r>>2]|0,h,c[ya>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+(16<<t)|0;ya=ia<<4;ia=u+ya|0;xa=d[473424+f|0]|0;f=a[e+5632+xa|0]|0;Da=a[e+5672+xa|0]|0;na=ha<<3;ha=(b[e+5312+(xa<<2)>>1]|0)+na|0;Ca=ca<<3;ca=(b[e+5312+(xa<<2)+2>>1]|0)+Ca|0;n=ca<<2&12|ha&3;K=ha>>2;M=ca>>2;U=(ba(M,wa)|0)+(K<<t)|0;x=c[e+199440+(f*2224|0)>>2]|0;za=x+U|0;C=e+427400|0;v=c[C>>2]|0;Aa=v<<4;Ba=e+427396|0;sa=c[Ba>>2]<<4>>da;da=ha&7;L=(da|0)==0?0:-3;ea=(ca&7|0)==0?0:-3;do{if((K|0)<(-L|0)){z=10}else{if((M|0)<(-ea|0)){z=10;break}if((K+16|0)>(L+Aa|0)){z=10;break}if((M+16|0)>(sa+ea|0)){z=10}else{Ea=za;Fa=0;Ga=wa}}}while(0);if((z|0)==10){za=e+572684|0;ea=2<<t;Ne[c[e+4>>2]&127](c[za>>2]|0,x+(U-((wa<<1)+ea))|0,wa,wa,21,21,K-2|0,M-2|0,Aa,sa);Aa=c[ua>>2]|0;Ea=(c[za>>2]|0)+((Aa<<1)+ea)|0;Fa=1;Ga=Aa}Aa=o+(n<<2)|0;Xe[c[Aa>>2]&4095](q,Ea,Ga);Ga=(g|0)!=0;if(!Ga){Xe[c[Aa>>2]&4095](j+(O+i)|0,Ea+i|0,c[ua>>2]|0)}Ea=ha>>3;ha=c[r>>2]|0;O=(ba(ha,M)|0)+(Ea<<t)|0;j=(c[e+199440+(f*2224|0)+4>>2]|0)+O|0;Aa=(c[e+199440+(f*2224|0)+8>>2]|0)+O|0;if((Fa|0)==0){Fa=ca<<1&6;Se[p&511](va,j,ha,h,da,Fa);Ha=Aa;Ia=Fa}else{Fa=e+4|0;O=e+572684|0;g=v<<3;Ne[c[Fa>>2]&127](c[O>>2]|0,j,ha,ha,9,17,Ea,M,g,sa);ha=ca<<1&6;Se[p&511](va,c[O>>2]|0,c[r>>2]|0,h,da,ha);ca=c[r>>2]|0;Ne[c[Fa>>2]&127](c[O>>2]|0,Aa,ca,ca,9,17,Ea,M,g,sa);Ha=c[O>>2]|0;Ia=ha}Se[p&511](k,Ha,c[r>>2]|0,h,da,Ia);Ia=(b[e+5472+(xa<<2)>>1]|0)+na|0;na=(b[e+5472+(xa<<2)+2>>1]|0)+Ca|0;Ca=na<<2&12|Ia&3;xa=Ia>>2;da=na>>2;Ha=c[ua>>2]|0;ha=(ba(da,Ha)|0)+(xa<<t)|0;O=c[e+306192+(Da*2224|0)>>2]|0;sa=O+ha|0;g=c[C>>2]|0;C=g<<4;M=c[Ba>>2]<<4>>c[l>>2];l=Ia&7;Ba=(l|0)==0?0:-3;Ea=(na&7|0)==0?0:-3;do{if((xa|0)<(-Ba|0)){z=20}else{if((da|0)<(-Ea|0)){z=20;break}if((xa+16|0)>(C+Ba|0)){z=20;break}if((da+16|0)>(M+Ea|0)){z=20}else{Ja=sa;Ka=0;La=Ha}}}while(0);if((z|0)==20){z=e+572684|0;sa=2<<t;Ne[c[e+4>>2]&127](c[z>>2]|0,O+(ha-((Ha<<1)+sa))|0,Ha,Ha,21,21,xa-2|0,da-2|0,C,M);C=c[ua>>2]|0;Ja=(c[z>>2]|0)+((C<<1)+sa)|0;Ka=1;La=C}C=o+(Ca<<2)|0;Xe[c[C>>2]&4095](ia,Ja,La);if(!Ga){Xe[c[C>>2]&4095](u+(ya+i)|0,Ja+i|0,c[ua>>2]|0)}i=Ia>>3;Ia=c[r>>2]|0;Ja=(ba(Ia,da)|0)+(i<<t)|0;t=(c[e+306192+(Da*2224|0)+4>>2]|0)+Ja|0;ya=(c[e+306192+(Da*2224|0)+8>>2]|0)+Ja|0;if((Ka|0)==0){Ka=na<<1&6;Se[p&511](u,t,Ia,h,l,Ka);Ma=ya;Na=Ka}else{Ka=e+4|0;Ja=e+572684|0;C=g<<3;Ne[c[Ka>>2]&127](c[Ja>>2]|0,t,Ia,Ia,9,17,i,da,C,M);Ia=na<<1&6;Se[p&511](u,c[Ja>>2]|0,c[r>>2]|0,h,l,Ia);na=c[r>>2]|0;Ne[c[Ka>>2]&127](c[Ja>>2]|0,ya,na,na,9,17,i,da,C,M);Ma=c[Ja>>2]|0;Na=Ia}Se[p&511](y,Ma,c[r>>2]|0,h,l,Na);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Da<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Be[s&127](q,ia,c[ua>>2]|0,h,5,w,m,0);Be[N&127](va,u,c[r>>2]|0,h,5,w,m,0);Be[N&127](k,y,c[r>>2]|0,h,5,w,m,0);return}else{Be[s&127](q,ia,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Da<<4)+8>>2]|0,(c[e+177136+(Da<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);ua=e+177132|0;Be[N&127](va,u,c[r>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Da<<5)+16>>2]|0,(c[e+177904+(Da<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Be[N&127](k,y,c[r>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Da<<5)+24>>2]|0,(c[e+177904+(Da<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Cda(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0;r=e+177120|0;p=c[r>>2]|0;w=(u|0)==0;u=(v|0)==0;if((p|0)!=2|w|u){x=3}else{y=c[e+427380>>2]|0;z=d[473424+f|0]|0;if((c[e+179440+((a[e+5632+z|0]|0)*384|0)+(a[e+5672+z|0]<<3)+((y&1)<<2)>>2]|0)==32){x=3}else{A=y}}do{if((x|0)==3){if((p|0)==1){A=c[e+427380>>2]|0;break}y=e+6112|0;z=c[y>>2]|0;B=(ba(n<<1,z)|0)+(m<<1)|0;C=j+B|0;D=k+B|0;E=l+B|0;F=(c[e+427376>>2]<<3)+m|0;G=e+177092|0;H=c[G>>2]|0;I=(c[e+427380>>2]>>H<<3)+n|0;do{if(w){J=o}else{K=d[473424+f|0]|0;L=a[e+5632+K|0]|0;M=(b[e+5312+(K<<2)>>1]|0)+(F<<3)|0;N=(b[e+5312+(K<<2)+2>>1]|0)+(I<<3)|0;K=N<<2&12|M&3;O=M>>2;P=N>>2;Q=(ba(P,z)|0)+O|0;R=c[e+199440+(L*2224|0)>>2]|0;S=R+Q|0;T=c[e+427400>>2]<<4;U=c[e+427396>>2]<<4>>H;V=(M&7|0)==0?0:-3;M=(N&7|0)==0?0:-3;do{if((O|0)<(-V|0)){x=67}else{if((P|0)<(-M|0)){x=67;break}if((O+16|0)>(V+T|0)){x=67;break}if((P+16|0)>(U+M|0)){x=67}else{W=S;X=0;Y=z}}}while(0);if((x|0)==67){S=e+572684|0;Ne[c[e+4>>2]&127](c[S>>2]|0,R+(-2-(z<<1)+Q)|0,z,z,21,21,O-2|0,P-2|0,T,U);M=c[y>>2]|0;W=(c[S>>2]|0)+((M<<1)+2)|0;X=1;Y=M}M=o+(K<<2)|0;Xe[c[M>>2]&4095](C,W,Y);S=(g|0)!=0;if(!S){Xe[c[M>>2]&4095](j+(B+i)|0,W+i|0,c[y>>2]|0)}V=c[e+199440+(L*2224|0)+4>>2]|0;N=(X|0)!=0;if(N){Z=e+572684|0;_=c[y>>2]|0;Ne[c[e+4>>2]&127](c[Z>>2]|0,V+(Q-2-(_<<1))|0,_,_,21,21,O-2|0,P-2|0,T,U);_=c[y>>2]|0;$=(c[Z>>2]|0)+((_<<1)+2)|0;aa=_}else{$=V+Q|0;aa=c[y>>2]|0}Xe[c[M>>2]&4095](D,$,aa);if(!S){Xe[c[M>>2]&4095](k+(B+i)|0,$+i|0,c[y>>2]|0)}V=c[e+199440+(L*2224|0)+8>>2]|0;if(N){N=e+572684|0;_=c[y>>2]|0;Ne[c[e+4>>2]&127](c[N>>2]|0,V+(Q-2-(_<<1))|0,_,_,21,21,O-2|0,P-2|0,T,U);_=c[y>>2]|0;ca=(c[N>>2]|0)+((_<<1)+2)|0;da=_}else{ca=V+Q|0;da=c[y>>2]|0}Xe[c[M>>2]&4095](E,ca,da);if(S){J=q;break}Xe[c[M>>2]&4095](l+(B+i)|0,ca+i|0,c[y>>2]|0);J=q}}while(0);if(u){return}z=d[473424+f|0]|0;H=a[e+5672+z|0]|0;M=(b[e+5472+(z<<2)>>1]|0)+(F<<3)|0;S=(b[e+5472+(z<<2)+2>>1]|0)+(I<<3)|0;z=S<<2&12|M&3;V=M>>2;_=S>>2;N=c[y>>2]|0;Z=(ba(_,N)|0)+V|0;ea=c[e+306192+(H*2224|0)>>2]|0;fa=ea+Z|0;ga=c[e+427400>>2]<<4;ha=c[e+427396>>2]<<4>>c[G>>2];ia=(M&7|0)==0?0:-3;M=(S&7|0)==0?0:-3;do{if((V|0)<(-ia|0)){x=85}else{if((_|0)<(-M|0)){x=85;break}if((V+16|0)>(ga+ia|0)){x=85;break}if((_+16|0)>(ha+M|0)){x=85}else{ja=fa;ka=0;la=N}}}while(0);if((x|0)==85){fa=e+572684|0;Ne[c[e+4>>2]&127](c[fa>>2]|0,ea+(-2-(N<<1)+Z)|0,N,N,21,21,V-2|0,_-2|0,ga,ha);M=c[y>>2]|0;ja=(c[fa>>2]|0)+((M<<1)+2)|0;ka=1;la=M}M=J+(z<<2)|0;Xe[c[M>>2]&4095](C,ja,la);fa=(g|0)!=0;if(!fa){Xe[c[M>>2]&4095](j+(B+i)|0,ja+i|0,c[y>>2]|0)}ia=c[e+306192+(H*2224|0)+4>>2]|0;G=(ka|0)!=0;if(G){I=e+572684|0;F=c[y>>2]|0;Ne[c[e+4>>2]&127](c[I>>2]|0,ia+(Z-2-(F<<1))|0,F,F,21,21,V-2|0,_-2|0,ga,ha);F=c[y>>2]|0;ma=(c[I>>2]|0)+((F<<1)+2)|0;na=F}else{ma=ia+Z|0;na=c[y>>2]|0}Xe[c[M>>2]&4095](D,ma,na);if(!fa){Xe[c[M>>2]&4095](k+(B+i)|0,ma+i|0,c[y>>2]|0)}ia=c[e+306192+(H*2224|0)+8>>2]|0;if(G){G=e+572684|0;F=c[y>>2]|0;Ne[c[e+4>>2]&127](c[G>>2]|0,ia+(Z-2-(F<<1))|0,F,F,21,21,V-2|0,_-2|0,ga,ha);F=c[y>>2]|0;oa=(c[G>>2]|0)+((F<<1)+2)|0;pa=F}else{oa=ia+Z|0;pa=c[y>>2]|0}Xe[c[M>>2]&4095](E,oa,pa);if(fa){return}Xe[c[M>>2]&4095](l+(B+i)|0,oa+i|0,c[y>>2]|0);return}}while(0);oa=c[s>>2]|0;s=c[t>>2]|0;t=e+6112|0;pa=c[t>>2]|0;ma=(ba(n<<1,pa)|0)+(m<<1)|0;na=j+ma|0;ka=k+ma|0;ja=l+ma|0;la=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;J=e+177092|0;q=c[J>>2]|0;ca=(A>>q<<3)+n|0;if(w|u){u=(v|0)!=0|0;v=d[473424+f|0]|0;w=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(la<<3)|0;A=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(ca<<3)|0;v=A<<2&12|n&3;da=n>>2;$=A>>2;aa=(ba($,pa)|0)+da|0;X=c[e+199440+(u*106752|0)+(w*2224|0)>>2]|0;W=X+aa|0;Y=c[e+427400>>2]<<4;p=c[e+427396>>2]<<4>>q;M=(n&7|0)==0?0:-3;n=(A&7|0)==0?0:-3;do{if((da|0)<(-M|0)){x=47}else{if(($|0)<(-n|0)){x=47;break}if((da+16|0)>(M+Y|0)){x=47;break}if(($+16|0)>(p+n|0)){x=47}else{qa=W;ra=0;sa=pa}}}while(0);if((x|0)==47){W=e+572684|0;Ne[c[e+4>>2]&127](c[W>>2]|0,X+(-2-(pa<<1)+aa)|0,pa,pa,21,21,da-2|0,$-2|0,Y,p);X=c[t>>2]|0;qa=(c[W>>2]|0)+((X<<1)+2)|0;ra=1;sa=X}X=o+(v<<2)|0;Xe[c[X>>2]&4095](na,qa,sa);sa=(g|0)!=0;if(!sa){Xe[c[X>>2]&4095](j+(ma+i)|0,qa+i|0,c[t>>2]|0)}qa=c[e+199440+(u*106752|0)+(w*2224|0)+4>>2]|0;v=(ra|0)!=0;if(v){ra=e+572684|0;W=c[t>>2]|0;Ne[c[e+4>>2]&127](c[ra>>2]|0,qa+(aa-2-(W<<1))|0,W,W,21,21,da-2|0,$-2|0,Y,p);W=c[t>>2]|0;ta=(c[ra>>2]|0)+((W<<1)+2)|0;ua=W}else{ta=qa+aa|0;ua=c[t>>2]|0}Xe[c[X>>2]&4095](ka,ta,ua);if(!sa){Xe[c[X>>2]&4095](k+(ma+i)|0,ta+i|0,c[t>>2]|0)}ta=c[e+199440+(u*106752|0)+(w*2224|0)+8>>2]|0;if(v){v=e+572684|0;ua=c[t>>2]|0;Ne[c[e+4>>2]&127](c[v>>2]|0,ta+(aa-2-(ua<<1))|0,ua,ua,21,21,da-2|0,$-2|0,Y,p);p=c[t>>2]|0;va=(c[v>>2]|0)+((p<<1)+2)|0;wa=p}else{va=ta+aa|0;wa=c[t>>2]|0}Xe[c[X>>2]&4095](ja,va,wa);if(!sa){Xe[c[X>>2]&4095](l+(ma+i)|0,va+i|0,c[t>>2]|0)}Se[oa&511](na,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(w<<4)+(u<<3)>>2]|0,c[e+177136+(w<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}va=e+6116|0;X=e+177132|0;Se[oa&511](ka,c[va>>2]|0,h,c[X>>2]|0,c[e+177904+(w<<5)+(u<<4)>>2]|0,c[e+177904+(w<<5)+(u<<4)+4>>2]|0);Se[oa&511](ja,c[va>>2]|0,h,c[X>>2]|0,c[e+177904+(w<<5)+(u<<4)+8>>2]|0,c[e+177904+(w<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;w=u+16|0;X=e+6116|0;va=c[X>>2]<<4;oa=u+va|0;sa=d[473424+f|0]|0;f=a[e+5632+sa|0]|0;wa=a[e+5672+sa|0]|0;aa=la<<3;la=(b[e+5312+(sa<<2)>>1]|0)+aa|0;ta=ca<<3;ca=(b[e+5312+(sa<<2)+2>>1]|0)+ta|0;p=ca<<2&12|la&3;v=la>>2;Y=ca>>2;$=(ba(Y,pa)|0)+v|0;da=c[e+199440+(f*2224|0)>>2]|0;ua=da+$|0;qa=e+427400|0;W=c[qa>>2]<<4;ra=e+427396|0;n=c[ra>>2]<<4>>q;q=(la&7|0)==0?0:-3;la=(ca&7|0)==0?0:-3;do{if((v|0)<(-q|0)){x=10}else{if((Y|0)<(-la|0)){x=10;break}if((v+16|0)>(q+W|0)){x=10;break}if((Y+16|0)>(n+la|0)){x=10}else{xa=ua;ya=0;za=pa}}}while(0);if((x|0)==10){ua=e+572684|0;Ne[c[e+4>>2]&127](c[ua>>2]|0,da+(-2-(pa<<1)+$)|0,pa,pa,21,21,v-2|0,Y-2|0,W,n);pa=c[t>>2]|0;xa=(c[ua>>2]|0)+((pa<<1)+2)|0;ya=1;za=pa}pa=o+(p<<2)|0;Xe[c[pa>>2]&4095](na,xa,za);za=(g|0)!=0;if(!za){Xe[c[pa>>2]&4095](j+(ma+i)|0,xa+i|0,c[t>>2]|0)}xa=c[e+199440+(f*2224|0)+4>>2]|0;j=(ya|0)!=0;if(j){ya=e+572684|0;g=c[t>>2]|0;Ne[c[e+4>>2]&127](c[ya>>2]|0,xa+($-2-(g<<1))|0,g,g,21,21,v-2|0,Y-2|0,W,n);g=c[t>>2]|0;Aa=(c[ya>>2]|0)+((g<<1)+2)|0;Ba=g}else{Aa=xa+$|0;Ba=c[t>>2]|0}Xe[c[pa>>2]&4095](ka,Aa,Ba);if(!za){Xe[c[pa>>2]&4095](k+(ma+i)|0,Aa+i|0,c[t>>2]|0)}Aa=c[e+199440+(f*2224|0)+8>>2]|0;if(j){j=e+572684|0;k=c[t>>2]|0;Ne[c[e+4>>2]&127](c[j>>2]|0,Aa+($-2-(k<<1))|0,k,k,21,21,v-2|0,Y-2|0,W,n);n=c[t>>2]|0;Ca=(c[j>>2]|0)+((n<<1)+2)|0;Da=n}else{Ca=Aa+$|0;Da=c[t>>2]|0}Xe[c[pa>>2]&4095](ja,Ca,Da);if(!za){Xe[c[pa>>2]&4095](l+(ma+i)|0,Ca+i|0,c[t>>2]|0)}Ca=(b[e+5472+(sa<<2)>>1]|0)+aa|0;aa=(b[e+5472+(sa<<2)+2>>1]|0)+ta|0;ta=aa<<2&12|Ca&3;sa=Ca>>2;ma=aa>>2;l=c[t>>2]|0;pa=(ba(ma,l)|0)+sa|0;Da=c[e+306192+(wa*2224|0)>>2]|0;$=Da+pa|0;Aa=c[qa>>2]<<4;qa=c[ra>>2]<<4>>c[J>>2];J=(Ca&7|0)==0?0:-3;Ca=(aa&7|0)==0?0:-3;do{if((sa|0)<(-J|0)){x=27}else{if((ma|0)<(-Ca|0)){x=27;break}if((sa+16|0)>(Aa+J|0)){x=27;break}if((ma+16|0)>(qa+Ca|0)){x=27}else{Ea=$;Fa=0;Ga=l}}}while(0);if((x|0)==27){x=e+572684|0;Ne[c[e+4>>2]&127](c[x>>2]|0,Da+(-2-(l<<1)+pa)|0,l,l,21,21,sa-2|0,ma-2|0,Aa,qa);l=c[t>>2]|0;Ea=(c[x>>2]|0)+((l<<1)+2)|0;Fa=1;Ga=l}l=o+(ta<<2)|0;Xe[c[l>>2]&4095](oa,Ea,Ga);if(!za){Xe[c[l>>2]&4095](u+(va+i)|0,Ea+i|0,c[t>>2]|0)}Ea=c[e+306192+(wa*2224|0)+4>>2]|0;va=(Fa|0)!=0;if(va){Fa=e+572684|0;Ga=c[t>>2]|0;Ne[c[e+4>>2]&127](c[Fa>>2]|0,Ea+(pa-2-(Ga<<1))|0,Ga,Ga,21,21,sa-2|0,ma-2|0,Aa,qa);Ga=c[t>>2]|0;Ha=(c[Fa>>2]|0)+((Ga<<1)+2)|0;Ia=Ga}else{Ha=Ea+pa|0;Ia=c[t>>2]|0}Xe[c[l>>2]&4095](u,Ha,Ia);if(!za){Xe[c[l>>2]&4095](u+i|0,Ha+i|0,c[t>>2]|0)}Ha=c[e+306192+(wa*2224|0)+8>>2]|0;if(va){va=e+572684|0;Ia=c[t>>2]|0;Ne[c[e+4>>2]&127](c[va>>2]|0,Ha+(pa-2-(Ia<<1))|0,Ia,Ia,21,21,sa-2|0,ma-2|0,Aa,qa);qa=c[t>>2]|0;Ja=(c[va>>2]|0)+((qa<<1)+2)|0;Ka=qa}else{Ja=Ha+pa|0;Ka=c[t>>2]|0}Xe[c[l>>2]&4095](w,Ja,Ka);if(!za){Xe[c[l>>2]&4095](u+(i+16)|0,Ja+i|0,c[t>>2]|0)}if((c[r>>2]|0)==2){r=c[e+179440+(f*384|0)+(wa<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-r|0;Be[s&127](na,oa,c[t>>2]|0,h,5,r,m,0);Be[s&127](ka,u,c[X>>2]|0,h,5,r,m,0);Be[s&127](ja,w,c[X>>2]|0,h,5,r,m,0);return}else{Be[s&127](na,oa,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(wa<<4)+8>>2]|0,(c[e+177136+(wa<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);t=e+177132|0;Be[s&127](ka,u,c[X>>2]|0,h,c[t>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(wa<<5)+16>>2]|0,(c[e+177904+(wa<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Be[s&127](ja,w,c[X>>2]|0,h,c[t>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(wa<<5)+24>>2]|0,(c[e+177904+(wa<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Dda(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;r=e+177120|0;p=c[r>>2]|0;w=(u|0)==0;u=(v|0)==0;if((p|0)!=2|w|u){x=3}else{y=c[e+427380>>2]|0;z=d[473424+f|0]|0;if((c[e+179440+((a[e+5632+z|0]|0)*384|0)+(a[e+5672+z|0]<<3)+((y&1)<<2)>>2]|0)==32){x=3}else{A=y}}do{if((x|0)==3){if((p|0)==1){A=c[e+427380>>2]|0;break}y=c[e+4752>>2]|0;z=e+6112|0;B=c[z>>2]|0;C=(ba(n<<1,B)|0)+(m<<1<<y)|0;D=j+C|0;E=k+C|0;F=l+C|0;G=(c[e+427376>>2]<<3)+m|0;H=e+177092|0;I=c[H>>2]|0;J=(c[e+427380>>2]>>I<<3)+n|0;do{if(w){K=o}else{L=d[473424+f|0]|0;M=a[e+5632+L|0]|0;N=(b[e+5312+(L<<2)>>1]|0)+(G<<3)|0;O=(b[e+5312+(L<<2)+2>>1]|0)+(J<<3)|0;L=O<<2&12|N&3;P=N>>2;Q=O>>2;R=(ba(Q,B)|0)+(P<<y)|0;S=c[e+199440+(M*2224|0)>>2]|0;T=S+R|0;U=c[e+427400>>2]<<4;V=c[e+427396>>2]<<4>>I;W=(N&7|0)==0?0:-3;N=(O&7|0)==0?0:-3;do{if((P|0)<(-W|0)){x=67}else{if((Q|0)<(-N|0)){x=67;break}if((P+16|0)>(W+U|0)){x=67;break}if((Q+16|0)>(V+N|0)){x=67}else{X=T;Y=0;Z=B}}}while(0);if((x|0)==67){T=e+572684|0;N=2<<y;Ne[c[e+4>>2]&127](c[T>>2]|0,S+(R-((B<<1)+N))|0,B,B,21,21,P-2|0,Q-2|0,U,V);W=c[z>>2]|0;X=(c[T>>2]|0)+((W<<1)+N)|0;Y=1;Z=W}W=o+(L<<2)|0;Xe[c[W>>2]&4095](D,X,Z);N=(g|0)!=0;if(!N){Xe[c[W>>2]&4095](j+(C+i)|0,X+i|0,c[z>>2]|0)}T=c[e+199440+(M*2224|0)+4>>2]|0;O=(Y|0)!=0;if(O){_=e+572684|0;$=2<<y;aa=c[z>>2]|0;Ne[c[e+4>>2]&127](c[_>>2]|0,T+(R-$-(aa<<1))|0,aa,aa,21,21,P-2|0,Q-2|0,U,V);aa=c[z>>2]|0;ca=(c[_>>2]|0)+((aa<<1)+$)|0;da=aa}else{ca=T+R|0;da=c[z>>2]|0}Xe[c[W>>2]&4095](E,ca,da);if(!N){Xe[c[W>>2]&4095](k+(C+i)|0,ca+i|0,c[z>>2]|0)}T=c[e+199440+(M*2224|0)+8>>2]|0;if(O){O=e+572684|0;aa=2<<y;$=c[z>>2]|0;Ne[c[e+4>>2]&127](c[O>>2]|0,T+(R-aa-($<<1))|0,$,$,21,21,P-2|0,Q-2|0,U,V);$=c[z>>2]|0;ea=(c[O>>2]|0)+(($<<1)+aa)|0;fa=$}else{ea=T+R|0;fa=c[z>>2]|0}Xe[c[W>>2]&4095](F,ea,fa);if(N){K=q;break}Xe[c[W>>2]&4095](l+(C+i)|0,ea+i|0,c[z>>2]|0);K=q}}while(0);if(u){return}B=d[473424+f|0]|0;I=a[e+5672+B|0]|0;W=(b[e+5472+(B<<2)>>1]|0)+(G<<3)|0;N=(b[e+5472+(B<<2)+2>>1]|0)+(J<<3)|0;B=N<<2&12|W&3;T=W>>2;$=N>>2;aa=c[z>>2]|0;O=(ba($,aa)|0)+(T<<y)|0;_=c[e+306192+(I*2224|0)>>2]|0;ga=_+O|0;ha=c[e+427400>>2]<<4;ia=c[e+427396>>2]<<4>>c[H>>2];ja=(W&7|0)==0?0:-3;W=(N&7|0)==0?0:-3;do{if((T|0)<(-ja|0)){x=85}else{if(($|0)<(-W|0)){x=85;break}if((T+16|0)>(ha+ja|0)){x=85;break}if(($+16|0)>(ia+W|0)){x=85}else{ka=ga;la=0;ma=aa}}}while(0);if((x|0)==85){ga=e+572684|0;W=2<<y;Ne[c[e+4>>2]&127](c[ga>>2]|0,_+(O-((aa<<1)+W))|0,aa,aa,21,21,T-2|0,$-2|0,ha,ia);ja=c[z>>2]|0;ka=(c[ga>>2]|0)+((ja<<1)+W)|0;la=1;ma=ja}ja=K+(B<<2)|0;Xe[c[ja>>2]&4095](D,ka,ma);W=(g|0)!=0;if(!W){Xe[c[ja>>2]&4095](j+(C+i)|0,ka+i|0,c[z>>2]|0)}ga=c[e+306192+(I*2224|0)+4>>2]|0;H=(la|0)!=0;if(H){J=e+572684|0;G=2<<y;N=c[z>>2]|0;Ne[c[e+4>>2]&127](c[J>>2]|0,ga+(O-G-(N<<1))|0,N,N,21,21,T-2|0,$-2|0,ha,ia);N=c[z>>2]|0;na=(c[J>>2]|0)+((N<<1)+G)|0;oa=N}else{na=ga+O|0;oa=c[z>>2]|0}Xe[c[ja>>2]&4095](E,na,oa);if(!W){Xe[c[ja>>2]&4095](k+(C+i)|0,na+i|0,c[z>>2]|0)}ga=c[e+306192+(I*2224|0)+8>>2]|0;if(H){H=e+572684|0;N=2<<y;G=c[z>>2]|0;Ne[c[e+4>>2]&127](c[H>>2]|0,ga+(O-N-(G<<1))|0,G,G,21,21,T-2|0,$-2|0,ha,ia);G=c[z>>2]|0;pa=(c[H>>2]|0)+((G<<1)+N)|0;qa=G}else{pa=ga+O|0;qa=c[z>>2]|0}Xe[c[ja>>2]&4095](F,pa,qa);if(W){return}Xe[c[ja>>2]&4095](l+(C+i)|0,pa+i|0,c[z>>2]|0);return}}while(0);pa=c[s>>2]|0;s=c[t>>2]|0;t=c[e+4752>>2]|0;qa=e+6112|0;na=c[qa>>2]|0;oa=(ba(n<<1,na)|0)+(m<<1<<t)|0;la=j+oa|0;ka=k+oa|0;ma=l+oa|0;K=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;q=e+177092|0;ea=c[q>>2]|0;fa=(A>>ea<<3)+n|0;if(w|u){u=(v|0)!=0|0;v=d[473424+f|0]|0;w=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(K<<3)|0;A=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(fa<<3)|0;v=A<<2&12|n&3;ca=n>>2;da=A>>2;Y=(ba(da,na)|0)+(ca<<t)|0;X=c[e+199440+(u*106752|0)+(w*2224|0)>>2]|0;Z=X+Y|0;p=c[e+427400>>2]<<4;ja=c[e+427396>>2]<<4>>ea;W=(n&7|0)==0?0:-3;n=(A&7|0)==0?0:-3;do{if((ca|0)<(-W|0)){x=47}else{if((da|0)<(-n|0)){x=47;break}if((ca+16|0)>(W+p|0)){x=47;break}if((da+16|0)>(ja+n|0)){x=47}else{ra=Z;sa=0;ta=na}}}while(0);if((x|0)==47){Z=e+572684|0;n=2<<t;Ne[c[e+4>>2]&127](c[Z>>2]|0,X+(Y-((na<<1)+n))|0,na,na,21,21,ca-2|0,da-2|0,p,ja);X=c[qa>>2]|0;ra=(c[Z>>2]|0)+((X<<1)+n)|0;sa=1;ta=X}X=o+(v<<2)|0;Xe[c[X>>2]&4095](la,ra,ta);ta=(g|0)!=0;if(!ta){Xe[c[X>>2]&4095](j+(oa+i)|0,ra+i|0,c[qa>>2]|0)}ra=c[e+199440+(u*106752|0)+(w*2224|0)+4>>2]|0;v=(sa|0)!=0;if(v){sa=e+572684|0;n=2<<t;Z=c[qa>>2]|0;Ne[c[e+4>>2]&127](c[sa>>2]|0,ra+(Y-n-(Z<<1))|0,Z,Z,21,21,ca-2|0,da-2|0,p,ja);Z=c[qa>>2]|0;ua=(c[sa>>2]|0)+((Z<<1)+n)|0;va=Z}else{ua=ra+Y|0;va=c[qa>>2]|0}Xe[c[X>>2]&4095](ka,ua,va);if(!ta){Xe[c[X>>2]&4095](k+(oa+i)|0,ua+i|0,c[qa>>2]|0)}ua=c[e+199440+(u*106752|0)+(w*2224|0)+8>>2]|0;if(v){v=e+572684|0;va=2<<t;ra=c[qa>>2]|0;Ne[c[e+4>>2]&127](c[v>>2]|0,ua+(Y-va-(ra<<1))|0,ra,ra,21,21,ca-2|0,da-2|0,p,ja);ja=c[qa>>2]|0;wa=(c[v>>2]|0)+((ja<<1)+va)|0;xa=ja}else{wa=ua+Y|0;xa=c[qa>>2]|0}Xe[c[X>>2]&4095](ma,wa,xa);if(!ta){Xe[c[X>>2]&4095](l+(oa+i)|0,wa+i|0,c[qa>>2]|0)}Se[pa&511](la,c[qa>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(w<<4)+(u<<3)>>2]|0,c[e+177136+(w<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}wa=e+6116|0;X=e+177132|0;Se[pa&511](ka,c[wa>>2]|0,h,c[X>>2]|0,c[e+177904+(w<<5)+(u<<4)>>2]|0,c[e+177904+(w<<5)+(u<<4)+4>>2]|0);Se[pa&511](ma,c[wa>>2]|0,h,c[X>>2]|0,c[e+177904+(w<<5)+(u<<4)+8>>2]|0,c[e+177904+(w<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;w=16<<t;X=u+w|0;wa=e+6116|0;pa=c[wa>>2]<<4;ta=u+pa|0;xa=d[473424+f|0]|0;f=a[e+5632+xa|0]|0;Y=a[e+5672+xa|0]|0;ua=K<<3;K=(b[e+5312+(xa<<2)>>1]|0)+ua|0;ja=fa<<3;fa=(b[e+5312+(xa<<2)+2>>1]|0)+ja|0;va=fa<<2&12|K&3;v=K>>2;p=fa>>2;da=(ba(p,na)|0)+(v<<t)|0;ca=c[e+199440+(f*2224|0)>>2]|0;ra=ca+da|0;Z=e+427400|0;n=c[Z>>2]<<4;sa=e+427396|0;W=c[sa>>2]<<4>>ea;ea=(K&7|0)==0?0:-3;K=(fa&7|0)==0?0:-3;do{if((v|0)<(-ea|0)){x=10}else{if((p|0)<(-K|0)){x=10;break}if((v+16|0)>(ea+n|0)){x=10;break}if((p+16|0)>(W+K|0)){x=10}else{ya=ra;za=0;Aa=na}}}while(0);if((x|0)==10){ra=e+572684|0;K=2<<t;Ne[c[e+4>>2]&127](c[ra>>2]|0,ca+(da-((na<<1)+K))|0,na,na,21,21,v-2|0,p-2|0,n,W);na=c[qa>>2]|0;ya=(c[ra>>2]|0)+((na<<1)+K)|0;za=1;Aa=na}na=o+(va<<2)|0;Xe[c[na>>2]&4095](la,ya,Aa);Aa=(g|0)!=0;if(!Aa){Xe[c[na>>2]&4095](j+(oa+i)|0,ya+i|0,c[qa>>2]|0)}ya=c[e+199440+(f*2224|0)+4>>2]|0;j=(za|0)!=0;if(j){za=e+572684|0;g=2<<t;va=c[qa>>2]|0;Ne[c[e+4>>2]&127](c[za>>2]|0,ya+(da-g-(va<<1))|0,va,va,21,21,v-2|0,p-2|0,n,W);va=c[qa>>2]|0;Ba=(c[za>>2]|0)+((va<<1)+g)|0;Ca=va}else{Ba=ya+da|0;Ca=c[qa>>2]|0}Xe[c[na>>2]&4095](ka,Ba,Ca);if(!Aa){Xe[c[na>>2]&4095](k+(oa+i)|0,Ba+i|0,c[qa>>2]|0)}Ba=c[e+199440+(f*2224|0)+8>>2]|0;if(j){j=e+572684|0;k=2<<t;Ca=c[qa>>2]|0;Ne[c[e+4>>2]&127](c[j>>2]|0,Ba+(da-k-(Ca<<1))|0,Ca,Ca,21,21,v-2|0,p-2|0,n,W);W=c[qa>>2]|0;Da=(c[j>>2]|0)+((W<<1)+k)|0;Ea=W}else{Da=Ba+da|0;Ea=c[qa>>2]|0}Xe[c[na>>2]&4095](ma,Da,Ea);if(!Aa){Xe[c[na>>2]&4095](l+(oa+i)|0,Da+i|0,c[qa>>2]|0)}Da=(b[e+5472+(xa<<2)>>1]|0)+ua|0;ua=(b[e+5472+(xa<<2)+2>>1]|0)+ja|0;ja=ua<<2&12|Da&3;xa=Da>>2;oa=ua>>2;l=c[qa>>2]|0;na=(ba(oa,l)|0)+(xa<<t)|0;Ea=c[e+306192+(Y*2224|0)>>2]|0;da=Ea+na|0;Ba=c[Z>>2]<<4;Z=c[sa>>2]<<4>>c[q>>2];q=(Da&7|0)==0?0:-3;Da=(ua&7|0)==0?0:-3;do{if((xa|0)<(-q|0)){x=27}else{if((oa|0)<(-Da|0)){x=27;break}if((xa+16|0)>(Ba+q|0)){x=27;break}if((oa+16|0)>(Z+Da|0)){x=27}else{Fa=da;Ga=0;Ha=l}}}while(0);if((x|0)==27){x=e+572684|0;da=2<<t;Ne[c[e+4>>2]&127](c[x>>2]|0,Ea+(na-((l<<1)+da))|0,l,l,21,21,xa-2|0,oa-2|0,Ba,Z);l=c[qa>>2]|0;Fa=(c[x>>2]|0)+((l<<1)+da)|0;Ga=1;Ha=l}l=o+(ja<<2)|0;Xe[c[l>>2]&4095](ta,Fa,Ha);if(!Aa){Xe[c[l>>2]&4095](u+(pa+i)|0,Fa+i|0,c[qa>>2]|0)}Fa=c[e+306192+(Y*2224|0)+4>>2]|0;pa=(Ga|0)!=0;if(pa){Ga=e+572684|0;Ha=2<<t;ja=c[qa>>2]|0;Ne[c[e+4>>2]&127](c[Ga>>2]|0,Fa+(na-Ha-(ja<<1))|0,ja,ja,21,21,xa-2|0,oa-2|0,Ba,Z);ja=c[qa>>2]|0;Ia=(c[Ga>>2]|0)+((ja<<1)+Ha)|0;Ja=ja}else{Ia=Fa+na|0;Ja=c[qa>>2]|0}Xe[c[l>>2]&4095](u,Ia,Ja);if(!Aa){Xe[c[l>>2]&4095](u+i|0,Ia+i|0,c[qa>>2]|0)}Ia=c[e+306192+(Y*2224|0)+8>>2]|0;if(pa){pa=e+572684|0;Ja=2<<t;t=c[qa>>2]|0;Ne[c[e+4>>2]&127](c[pa>>2]|0,Ia+(na-Ja-(t<<1))|0,t,t,21,21,xa-2|0,oa-2|0,Ba,Z);Z=c[qa>>2]|0;Ka=(c[pa>>2]|0)+((Z<<1)+Ja)|0;La=Z}else{Ka=Ia+na|0;La=c[qa>>2]|0}Xe[c[l>>2]&4095](X,Ka,La);if(!Aa){Xe[c[l>>2]&4095](u+(w+i)|0,Ka+i|0,c[qa>>2]|0)}if((c[r>>2]|0)==2){r=c[e+179440+(f*384|0)+(Y<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-r|0;Be[s&127](la,ta,c[qa>>2]|0,h,5,r,m,0);Be[s&127](ka,u,c[wa>>2]|0,h,5,r,m,0);Be[s&127](ma,X,c[wa>>2]|0,h,5,r,m,0);return}else{Be[s&127](la,ta,c[qa>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Y<<4)+8>>2]|0,(c[e+177136+(Y<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);qa=e+177132|0;Be[s&127](ka,u,c[wa>>2]|0,h,c[qa>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Y<<5)+16>>2]|0,(c[e+177904+(Y<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Be[s&127](ma,X,c[wa>>2]|0,h,c[qa>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Y<<5)+24>>2]|0,(c[e+177904+(Y<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Eda(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=(c[b+4792>>2]|0)+48+((c[b+7308>>2]|0)*-6|0)|0;if((d|0)<0){e=0}else{e=(d|0)>51?51:d}if((c[b+177080>>2]|0)==1){f=1675264}else{f=1669120+(c[b+572244>>2]<<11)|0}d=0;do{g=(ba(a[f+(d<<1)|0]|0,e)|0)>>4;h=(g+(a[f+(d<<1)+1|0]|0)<<1)-127|0;g=h>>31^h;if((g|0)>124){i=(g&1|124)&255}else{i=g&255}a[b+425536+d|0]=i;d=d+1|0;}while((d|0)<1024);return}function Fda(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0;g=i;i=i+120|0;h=g|0;j=g+16|0;k=g+24|0;l=g+32|0;m=g+40|0;n=g+56|0;o=g+64|0;p=g+72|0;q=g+80|0;r=g+88|0;s=g+96|0;t=g+104|0;u=g+112|0;v=c[f+7392>>2]|0;w=f+6136|0;x=((c[w>>2]|0)-1|0)>>>0<2>>>0;y=c[f+4752>>2]|0;z=f+427376|0;A=c[z>>2]|0;B=f+427380|0;C=c[B>>2]|0;D=f+427404|0;E=(ba(c[D>>2]|0,C)|0)+A|0;F=f+427412|0;c[F>>2]=E;G=f+177080|0;H=f+177088|0;do{if((c[G>>2]|0)!=1){do{if((c[H>>2]|0)==0){I=6}else{if((C&1|0)==0){I=6;break}if((c[f+4824>>2]|0)==0){I=6;break}J=c[f+4828>>2]|0}}while(0);if((I|0)==6){J=Gda(f,A,C)|0}if((J|0)==0){break}do{if((c[H>>2]|0)!=0){if((c[B>>2]&1|0)!=0){break}K=f+4064|0;c[(c[K>>2]|0)+(E<<2)>>2]=2048;L=Gda(f,c[z>>2]|0,(c[B>>2]|0)+1|0)|0;c[f+4828>>2]=L;if((L|0)!=0){break}L=(c[F>>2]|0)-(c[D>>2]<<1)|0;M=f+177092|0;N=Ida(f+425488|0,((e[(c[f+177072>>2]|0)+(L<<1)>>1]|0)==(c[f+177068>>2]|0)&(c[(c[K>>2]|0)+(L<<2)>>2]|0)>>>7)+((c[z>>2]|0)!=0&c[M>>2]|70)+(f+425536)|0)|0;c[M>>2]=N;c[f+177096>>2]=N}}while(0);N=c[F>>2]|0;c[j>>2]=0;TGb((c[f+5304>>2]|0)+(N*48|0)|0,0,48)|0;M=f+177092|0;if((c[M>>2]|0)==0){O=0}else{c[j>>2]=128;O=128}a:do{if((c[G>>2]|0)==3){L=O|63744;c[j>>2]=L;if((c[f+197872>>2]|0)!=0){Hda(f,L);Kda(f,c[j>>2]|0)}Yda(f,j);c[j>>2]=c[j>>2]|2048;P=c[f+6108>>2]|0}else{L=O|14344;c[j>>2]=L;Hda(f,L);L=h;K=c[f+4084>>2]|0;Q=c[f+4052>>2]|0;R=c[f+6108>>2]|0;c[f+5644>>2]=0;c[f+5652>>2]=0;c[f+5660>>2]=0;c[f+5668>>2]=0;S=c[f+4872>>2]|0;if((S&12288|0)==0){if((S|0)!=0){T=4641008;U=-1;I=27}}else{V=c[f+4852>>2]|0;W=d[c[f+4880>>2]|0]|0;X=a[K+((W&254)+(V<<2|1))|0]|0;Y=Q+((ba(W,R)|0)+3+(c[(c[f+6100>>2]|0)+(V<<2)>>2]|0)<<2)|0;do{if((c[H>>2]|0)==0){Z=Y;_=X}else{V=(S&128|0)!=0;if((c[M>>2]|0)==0){if(!V){Z=Y;_=X;break}W=c[Y>>2]|0;c[h>>2]=W;b[h+2>>1]=W>>>16<<1;Z=h;_=X>>1;break}else{if(V){Z=Y;_=X;break}V=c[Y>>2]|0;c[h>>2]=V;b[h+2>>1]=(V>>16|0)/2|0;Z=h;_=X<<1;break}}}while(0);if((c[Z>>2]|_|0)!=0){T=Z;U=_;I=27}}do{if((I|0)==27){X=c[f+4864>>2]|0;if((X&12288|0)==0){if((X|0)==0){break}else{$=-1;aa=4641008}}else{Y=c[f+4844>>2]|0;S=a[K+(Y<<2|2)|0]|0;V=Q+((c[(c[f+6100>>2]|0)+(Y<<2)>>2]|0)+(R*3|0)<<2)|0;do{if((c[H>>2]|0)==0){ca=S;da=V}else{Y=(X&128|0)!=0;if((c[M>>2]|0)==0){if(!Y){ca=S;da=V;break}W=c[V>>2]|0;ea=h+4|0;c[ea>>2]=W;b[L+6>>1]=W>>>16<<1;ca=S>>1;da=ea;break}else{if(Y){ca=S;da=V;break}Y=c[V>>2]|0;ea=h+4|0;c[ea>>2]=Y;b[L+6>>1]=(Y>>16|0)/2|0;ca=S<<1;da=ea;break}}}while(0);if((c[da>>2]|ca|0)==0){break}else{$=ca;aa=da}}S=c[f+4868>>2]|0;do{if((S&12288|0)==0){if((S|0)!=0){fa=4641008;ga=-1;break}V=c[f+4860>>2]|0;if((V&12288|0)==0){fa=4641008;ga=(V|0)==0?-2:-1;break}X=c[f+4840>>2]|0;ea=c[f+4884>>2]|0;Y=a[K+(X<<2|ea&2|1)|0]|0;W=Q+(R+3+(ea&R<<1)+(c[(c[f+6100>>2]|0)+(X<<2)>>2]|0)<<2)|0;if((c[H>>2]|0)==0){fa=W;ga=Y;break}X=(V&128|0)!=0;if((c[M>>2]|0)==0){if(!X){fa=W;ga=Y;break}V=c[W>>2]|0;ea=h+8|0;c[ea>>2]=V;b[L+10>>1]=V>>>16<<1;fa=ea;ga=Y>>1;break}else{if(X){fa=W;ga=Y;break}X=c[W>>2]|0;W=h+8|0;c[W>>2]=X;b[L+10>>1]=(X>>16|0)/2|0;fa=W;ga=Y<<1;break}}else{Y=c[f+4848>>2]|0;W=a[K+(Y<<2|2)|0]|0;X=Q+((c[(c[f+6100>>2]|0)+(Y<<2)>>2]|0)+(R*3|0)<<2)|0;if((c[H>>2]|0)==0){fa=X;ga=W;break}Y=(S&128|0)!=0;if((c[M>>2]|0)==0){if(!Y){fa=X;ga=W;break}ea=c[X>>2]|0;V=h+8|0;c[V>>2]=ea;b[L+10>>1]=ea>>>16<<1;fa=V;ga=W>>1;break}else{if(Y){fa=X;ga=W;break}Y=c[X>>2]|0;X=h+8|0;c[X>>2]=Y;b[L+10>>1]=(Y>>16|0)/2|0;fa=X;ga=W<<1;break}}}while(0);S=($|0)!=0;W=(U|0)!=0;X=(S&1^1)+(W&1^1)+((ga|0)==0)|0;do{if((X|0)>1){Y=b[T>>1]|0;V=Y<<16>>16;ea=b[aa>>1]|0;ha=ea<<16>>16;ia=b[fa>>1]|0;ja=ia<<16>>16;do{if(Y<<16>>16>ea<<16>>16){if(!(ia<<16>>16>ea<<16>>16)){ka=ha;break}ka=(ja|0)>(V|0)?V:ja}else{if(!(ea<<16>>16>ia<<16>>16)){ka=ha;break}ka=(ja|0)>(V|0)?ja:V}}while(0);V=b[T+2>>1]|0;ja=V<<16>>16;ha=b[aa+2>>1]|0;ia=ha<<16>>16;ea=b[fa+2>>1]|0;Y=ea<<16>>16;if(V<<16>>16>ha<<16>>16){if(!(ea<<16>>16>ha<<16>>16)){la=ia;ma=ka;break}la=(Y|0)>(ja|0)?ja:Y;ma=ka;break}else{if(!(ha<<16>>16>ea<<16>>16)){la=ia;ma=ka;break}la=(Y|0)>(ja|0)?Y:ja;ma=ka;break}}else{if((X|0)==1){if(!W){la=b[T+2>>1]|0;ma=b[T>>1]|0;break}if(S){la=b[fa+2>>1]|0;ma=b[fa>>1]|0;break}else{la=b[aa+2>>1]|0;ma=b[aa>>1]|0;break}}ja=b[T>>1]|0;Y=ja<<16>>16;ia=b[aa>>1]|0;ea=ia<<16>>16;ha=b[fa>>1]|0;V=ha<<16>>16;do{if(ja<<16>>16>ia<<16>>16){if(!(ha<<16>>16>ia<<16>>16)){na=ea;break}na=(V|0)>(Y|0)?Y:V}else{if(!(ia<<16>>16>ha<<16>>16)){na=ea;break}na=(V|0)>(Y|0)?V:Y}}while(0);Y=b[T+2>>1]|0;V=Y<<16>>16;ea=b[aa+2>>1]|0;ha=ea<<16>>16;ia=b[fa+2>>1]|0;ja=ia<<16>>16;if(Y<<16>>16>ea<<16>>16){if(!(ia<<16>>16>ea<<16>>16)){la=ha;ma=na;break}la=(ja|0)>(V|0)?V:ja;ma=na;break}else{if(!(ea<<16>>16>ia<<16>>16)){la=ha;ma=na;break}la=(ja|0)>(V|0)?ja:V;ma=na;break}}}while(0);S=la<<16|ma&65535;c[f+5360>>2]=S;c[f+5364>>2]=S;c[f+5368>>2]=S;c[f+5372>>2]=S;c[f+5392>>2]=S;c[f+5396>>2]=S;c[f+5400>>2]=S;c[f+5404>>2]=S;c[f+5424>>2]=S;c[f+5428>>2]=S;c[f+5432>>2]=S;c[f+5436>>2]=S;c[f+5456>>2]=S;c[f+5460>>2]=S;c[f+5464>>2]=S;c[f+5468>>2]=S;P=R;break a}}while(0);TGb(f+5360|0,0,16)|0;TGb(f+5392|0,0,16)|0;TGb(f+5424|0,0,16)|0;TGb(f+5456|0,0,16)|0;P=R}}while(0);M=c[j>>2]|0;L=(ba(P<<2,c[B>>2]|0)|0)+(c[z>>2]<<2)|0;Q=c[F>>2]<<2;if((M&12288|0)==0){K=c[f+4084>>2]|0;b[K+Q>>1]=-1;b[K+(Q|2)>>1]=-1}else{K=c[f+4052>>2]|0;S=f+5360|0;W=c[S+4>>2]|0;X=K+(L<<2)|0;c[X>>2]=c[S>>2];c[X+4>>2]=W;W=f+5368|0;X=c[W+4>>2]|0;S=K+((L|2)<<2)|0;c[S>>2]=c[W>>2];c[S+4>>2]=X;X=f+5392|0;S=c[X+4>>2]|0;W=L+P|0;V=K+(W<<2)|0;c[V>>2]=c[X>>2];c[V+4>>2]=S;S=f+5400|0;V=c[S+4>>2]|0;X=K+(W+2<<2)|0;c[X>>2]=c[S>>2];c[X+4>>2]=V;V=f+5424|0;X=c[V+4>>2]|0;S=L+(P<<1)|0;W=K+(S<<2)|0;c[W>>2]=c[V>>2];c[W+4>>2]=X;X=f+5432|0;W=c[X+4>>2]|0;V=K+(S+2<<2)|0;c[V>>2]=c[X>>2];c[V+4>>2]=W;W=f+5456|0;V=c[W+4>>2]|0;X=L+(P*3|0)|0;S=K+(X<<2)|0;c[S>>2]=c[W>>2];c[S+4>>2]=V;V=f+5464|0;S=c[V+4>>2]|0;W=K+(X+2<<2)|0;c[W>>2]=c[V>>2];c[W+4>>2]=S;S=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;W=c[f+426584>>2]|0;V=W+(S<<1)|0;if((M&2048|0)==0){X=f+426664|0;K=c[X+4>>2]|0;ja=V;c[ja>>2]=c[X>>2];c[ja+4>>2]=K;b[W+(S+6<<1)>>1]=b[f+426622>>1]|0;b[W+(S+5<<1)>>1]=b[f+426638>>1]|0;b[W+(S+4<<1)>>1]=b[f+426654>>1]|0}else{TGb(V|0,0,16)|0}V=c[f+4084>>2]|0;a[V+Q|0]=a[f+5644|0]|0;a[V+(Q|1)|0]=a[f+5646|0]|0;a[V+(Q|2)|0]=a[f+5660|0]|0;a[V+(Q|3)|0]=a[f+5662|0]|0}if((M&49152|0)!=0){V=c[f+4056>>2]|0;S=f+5520|0;W=c[S+4>>2]|0;K=V+(L<<2)|0;c[K>>2]=c[S>>2];c[K+4>>2]=W;W=f+5528|0;K=c[W+4>>2]|0;S=V+((L|2)<<2)|0;c[S>>2]=c[W>>2];c[S+4>>2]=K;K=f+5552|0;S=c[K+4>>2]|0;W=L+P|0;ja=V+(W<<2)|0;c[ja>>2]=c[K>>2];c[ja+4>>2]=S;S=f+5560|0;ja=c[S+4>>2]|0;K=V+(W+2<<2)|0;c[K>>2]=c[S>>2];c[K+4>>2]=ja;ja=f+5584|0;K=c[ja+4>>2]|0;S=L+(P<<1)|0;W=V+(S<<2)|0;c[W>>2]=c[ja>>2];c[W+4>>2]=K;K=f+5592|0;W=c[K+4>>2]|0;ja=V+(S+2<<2)|0;c[ja>>2]=c[K>>2];c[ja+4>>2]=W;W=f+5616|0;ja=c[W+4>>2]|0;K=L+(P*3|0)|0;L=V+(K<<2)|0;c[L>>2]=c[W>>2];c[L+4>>2]=ja;ja=f+5624|0;L=c[ja+4>>2]|0;W=V+(K+2<<2)|0;c[W>>2]=c[ja>>2];c[W+4>>2]=L;L=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;W=c[f+426588>>2]|0;ja=W+(L<<1)|0;if((M&2048|0)==0){K=f+426744|0;V=c[K+4>>2]|0;S=ja;c[S>>2]=c[K>>2];c[S+4>>2]=V;b[W+(L+6<<1)>>1]=b[f+426702>>1]|0;b[W+(L+5<<1)>>1]=b[f+426718>>1]|0;b[W+(L+4<<1)>>1]=b[f+426734>>1]|0}else{TGb(ja|0,0,16)|0}ja=c[f+4088>>2]|0;a[ja+Q|0]=a[f+5684|0]|0;a[ja+(Q|1)|0]=a[f+5686|0]|0;a[ja+(Q|2)|0]=a[f+5700|0]|0;a[ja+(Q|3)|0]=a[f+5702|0]|0}do{if((c[G>>2]|0)==3){if((M&64|0)==0){break}Q=c[F>>2]<<2;ja=c[f+426752>>2]|0;a[ja+(Q|1)|0]=(e[f+177114>>1]|0)>>>1;a[ja+(Q|2)|0]=(e[f+177116>>1]|0)>>>1;a[ja+(Q|3)|0]=(e[f+177118>>1]|0)>>>1}}while(0);c[(c[f+4064>>2]|0)+(N<<2)>>2]=c[j>>2];a[(c[f+4040>>2]|0)+N|0]=c[f+4792>>2];b[(c[f+177072>>2]|0)+(N<<1)>>1]=c[f+177068>>2];c[f+4824>>2]=1;b[(c[f+426560>>2]|0)+(E<<1)>>1]=0;a[(c[f+426576>>2]|0)+E|0]=0;c[f+426580>>2]=0;oa=0;i=g;return oa|0}}while(0);do{if((c[H>>2]|0)!=0){if((c[B>>2]&1|0)!=0){break}j=(c[F>>2]|0)-(c[D>>2]<<1)|0;P=f+177092|0;ma=Ida(f+425488|0,((e[(c[f+177072>>2]|0)+(j<<1)>>1]|0)==(c[f+177068>>2]|0)&(c[(c[f+4064>>2]|0)+(j<<2)>>2]|0)>>>7)+((c[z>>2]|0)!=0&c[P>>2]|70)+(f+425536)|0)|0;c[P>>2]=ma;c[f+177096>>2]=ma}}while(0);c[f+4824>>2]=0;ma=f+177092|0;Hda(f,-(c[ma>>2]|0)|0);P=c[G>>2]|0;b:do{if((P|0)==2){j=f+425488|0;if((Ida(j,f+425550|0)|0)!=0){la=Jda(f,17,0)|0;c[k>>2]=la;pa=la;I=120;break}if((Ida(j,f+425551|0)|0)==0){qa=(Ida(j,f+425552|0)|0)*3|0}else{qa=2-(Ida(j,f+425553|0)|0)|0}j=d[594018+(qa<<2)|0]|0;la=e[594016+(qa<<2)>>1]|0;c[k>>2]=la;ra=j;sa=0;ta=la}else if((P|0)==3){la=f+425488|0;do{if((Ida(la,28-(((c[f+4872>>2]|0)+511|0)>>>8&1)+(((c[f+4864>>2]|0)+511|0)>>>8&1^1)+(f+425536)|0)|0)==0){c[k>>2]=0;ua=0}else{if((Ida(la,f+425566|0)|0)==0){j=(Ida(la,f+425568|0)|0)+1|0;c[k>>2]=j;ua=j;break}j=(Ida(la,f+425567|0)|0)<<3;na=f+425568|0;fa=((Ida(la,na)|0)<<2)+j|0;j=fa+((Ida(la,na)|0)<<1)|0;fa=j+(Ida(la,na)|0)|0;if((fa|0)<8){j=fa+3|0;c[k>>2]=j;ua=j;break}if((fa|0)==14){c[k>>2]=11;ua=11;break}else if((fa|0)==15){c[k>>2]=22;ua=22;break}else if((fa|0)==13){j=Jda(f,32,0)|0;c[k>>2]=j;pa=j;I=120;break b}else{j=(fa<<1)-4+(Ida(la,na)|0)|0;c[k>>2]=j;ua=j;break}}}while(0);la=d[1739114+(ua<<2)|0]|0;N=e[1739112+(ua<<2)>>1]|0;c[k>>2]=N;ra=la;sa=0;ta=N}else{N=Jda(f,3,1)|0;c[k>>2]=N;if((c[f+177076>>2]|0)!=5|(N|0)==0){pa=N;I=120;break}la=N-1|0;c[k>>2]=la;pa=la;I=120}}while(0);if((I|0)==120){ua=d[918715+(pa<<2)|0]|0;c[f+4836>>2]=d[918714+(pa<<2)|0]|0;P=e[918712+(pa<<2)>>1]|0;c[k>>2]=P;ra=0;sa=ua;ta=P}if((c[ma>>2]|0)==0){va=ta}else{P=ta|128;c[k>>2]=P;va=P}b[(c[f+177072>>2]|0)+(E<<1)>>1]=c[f+177068>>2];if((va&4|0)!=0){P=(ba(e[1207552+(c[w>>2]<<1)>>1]|0,c[f+7308>>2]|0)|0)>>3;ta=f+425488|0;ua=c[f+425504>>2]|0;pa=c[ta>>2]|0;qa=(pa&1|0)==0?ua:ua-1|0;ua=(pa&511|0)==0?qa:qa-1|0;qa=c[f+425508>>2]|0;if((qa-ua|0)<(P|0)){oa=-1;i=g;return oa|0}c[f+421184>>2]=ua;pa=ua+P|0;Uhb(ta,pa,qa-pa|0);b[(c[f+426560>>2]|0)+(E<<1)>>1]=-2065;a[(c[f+426576>>2]|0)+E|0]=0;a[(c[f+4040>>2]|0)+E|0]=0;TGb((c[f+5304>>2]|0)+(E*48|0)|0,16,48)|0;c[(c[f+4064>>2]|0)+(E<<2)>>2]=c[k>>2];c[f+426580>>2]=0;oa=0;i=g;return oa|0}pa=c[f+177096>>2]|0;c[l>>2]=c[f+199420>>2]<<pa;c[l+4>>2]=c[f+199424>>2]<<pa;Kda(f,va);va=c[k>>2]|0;c:do{if((va&7|0)==0){if((ra|0)==4){pa=f+425488|0;do{if((c[G>>2]|0)==3){qa=f+425572|0;ta=f+425573|0;P=f+425575|0;ua=f+425574|0;la=0;do{d:do{if((Mda(pa,qa)|0)==0){wa=0}else{if((Mda(pa,ta)|0)==0){wa=(Mda(pa,P)|0)+1|0;break}do{if((Mda(pa,ua)|0)==0){xa=3}else{if((Mda(pa,P)|0)==0){xa=7;break}wa=(Mda(pa,P)|0)+11|0;break d}}while(0);N=((Mda(pa,P)|0)<<1)+xa|0;wa=N+(Mda(pa,P)|0)|0}}while(0);c[m+(la<<2)>>2]=d[1738962+((wa&65535)<<2)|0]|0;b[f+177112+(la<<1)>>1]=b[1738960+((wa&65535)<<2)>>1]|0;la=la+1|0;}while((la|0)<4);la=f+177112|0;P=f+177114|0;ua=f+177116|0;ta=f+177118|0;if(((b[P>>1]|b[la>>1]|b[ua>>1]|b[ta>>1])&256)==0){break}Yda(f,k);a[f+5702|0]=-2;a[f+5662|0]=-2;a[f+5686|0]=-2;a[f+5646|0]=-2;qa=((e[la>>1]|0)>>>1&255)*257&65535;b[f+426768>>1]=qa;b[f+426776>>1]=qa;qa=((e[P>>1]|0)>>>1&255)*257&65535;b[f+426770>>1]=qa;b[f+426778>>1]=qa;qa=((e[ua>>1]|0)>>>1&255)*257&65535;b[f+426784>>1]=qa;b[f+426792>>1]=qa;qa=((e[ta>>1]|0)>>>1&255)*257&65535;b[f+426786>>1]=qa;b[f+426794>>1]=qa}else{qa=f+425557|0;ta=f+425558|0;ua=f+425559|0;do{if((Mda(pa,qa)|0)==0){if((Mda(pa,ta)|0)==0){ya=1;break}P=(Mda(pa,ua)|0)==0;ya=P?3:2}else{ya=0}}while(0);c[m>>2]=d[593978+(ya<<2)|0]|0;b[f+177112>>1]=b[593976+(ya<<2)>>1]|0;do{if((Mda(pa,qa)|0)==0){if((Mda(pa,ta)|0)==0){za=1;break}P=(Mda(pa,ua)|0)==0;za=P?3:2}else{za=0}}while(0);c[m+4>>2]=d[593978+(za<<2)|0]|0;b[f+177114>>1]=b[593976+(za<<2)>>1]|0;do{if((Mda(pa,qa)|0)==0){if((Mda(pa,ta)|0)==0){Aa=1;break}P=(Mda(pa,ua)|0)==0;Aa=P?3:2}else{Aa=0}}while(0);c[m+8>>2]=d[593978+(Aa<<2)|0]|0;b[f+177116>>1]=b[593976+(Aa<<2)>>1]|0;do{if((Mda(pa,qa)|0)==0){if((Mda(pa,ta)|0)==0){Ba=1;break}P=(Mda(pa,ua)|0)==0;Ba=P?3:2}else{Ba=0}}while(0);c[m+12>>2]=d[593978+(Ba<<2)|0]|0;b[f+177118>>1]=b[593976+(Ba<<2)>>1]|0}}while(0);pa=f+199428|0;e:do{if((c[pa>>2]|0)==0){Ca=0}else{ua=f+425488|0;ta=0;f:while(1){qa=4096<<(ta<<1);P=l+(ta<<2)|0;la=0;do{R=e[f+177112+(la<<1)>>1]|0;if((R&256|0)==0){do{if((R&qa|0)==0){Da=-1}else{Ea=c[P>>2]|0;if(!(Ea>>>0>1>>>0)){Da=0;break}N=d[473368+(la<<2)|0]|0;j=N-1|0;na=N-8|0;N=a[f+5632+(ta*40|0)+na|0]|0;fa=(a[f+5632+(ta*40|0)+j|0]|0)>0;do{if((c[G>>2]|0)==3){if(fa){Fa=(d[f+426756+j|0]|0)>>>7&255^1}else{Fa=0}if(!(N<<24>>24>0)){Ga=Fa;Ha=0;break}Ga=(a[f+426756+na|0]|0)<0?Fa:Fa|2;Ha=0}else{aa=fa&1;if(!(N<<24>>24>0)){Ga=aa;Ha=0;break}Ga=aa|2;Ha=0}}while(0);while(1){if((Mda(ua,Ga+54+(f+425536)|0)|0)==0){break}N=Ha+1|0;if((N|0)>31){Ia=-1;break f}else{Ga=(Ga>>2)+4|0;Ha=N}}if(Ha>>>0<Ea>>>0){Da=Ha&255}else{Ia=Ha;break f}}}while(0);R=d[473368+(la<<2)|0]|0;a[R+9+(f+5632+(ta*40|0))|0]=Da;a[R+8+(f+5632+(ta*40|0))|0]=Da;a[R+1+(f+5632+(ta*40|0))|0]=Da}la=la+1|0;}while((la|0)<4);la=ta+1|0;P=c[pa>>2]|0;if(la>>>0<P>>>0){ta=la}else{Ca=P;break e}}yDb(c[f>>2]|0,16,2283728,(Ja=i,i=i+16|0,c[Ja>>2]=Ia,c[Ja+8>>2]=Ea,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}}while(0);if((v|0)==0){Ka=0}else{ta=(c[f+6196>>2]|0)==0;ua=f+177112|0;Ka=((ta?24117616:7340144)&c[ua>>2]|0)==0&((ta?24117616:7340144)&c[ua+4>>2]|0)==0&1}if((Ca|0)==0){La=Ka;break}ua=f+2524|0;ta=f+4872|0;P=f+4852|0;la=f+6100|0;qa=f+6108|0;R=0;while(1){N=R<<1;fa=4096<<N;na=f+5632+(R*40|0)+11|0;j=f+5312+(R*160|0)+40|0;aa=j|0;T=j;j=12288<<N;N=f+5312+(R*160|0)+42|0;ka=0;do{ga=ka<<2;U=d[473368+ga|0]|0;a[f+5632+(R*40|0)+U|0]=a[U+1+(f+5632+(R*40|0))|0]|0;$=e[f+177112+(ka<<1)>>1]|0;do{if(($&256|0)==0){if(($&fa|0)==0){c[f+5312+(R*160|0)+(U<<2)>>2]=0;c[f+5312+(R*160|0)+(U<<2)+4>>2]=0;c[f+5312+(R*160|0)+(U<<2)+32>>2]=0;c[f+5312+(R*160|0)+(U<<2)+36>>2]=0;c[f+426592+(R*80|0)+(U<<1)>>2]=0;c[f+426592+(R*80|0)+(U<<1)+16>>2]=0;break}h=($&24|0)!=0?2:1;da=c[m+(ka<<2)>>2]|0;if((da|0)<=0){break}ca=($&8|0)==0;_=($&16|0)==0;Z=($&32|0)==0;O=0;do{J=a[473368+((ba(O,h)|0)+ga)|0]|0;C=J&255;A=a[f+5632+(R*40|0)+C|0]|0;M=A<<24>>24;Q=C-8|0;ja=a[f+5632+(R*40|0)+Q|0]|0;L=C-1|0;W=a[f+5632+(R*40|0)+L|0]|0;V=f+5312+(R*160|0)+(L<<2)|0;S=f+5312+(R*160|0)+(Q<<2)|0;K=Q+h|0;X=a[f+5632+(R*40|0)+K|0]|0;ha=X<<24>>24;ia=X<<24>>24==-2;do{if((c[H>>2]|0)!=0&ia&(J&255)>>>0>19>>>0&(C&7|0)==4){if((a[na]|0)==-2){I=207;break}X=c[ua>>2]|0;ea=c[X+1536>>2]|0;c[T>>2]=0;Y=(c[ta>>2]&128|0)==0;if((c[ma>>2]|0)==0){if(Y){I=207;break}Ma=c[D>>2]|0;Na=Ma+(c[P>>2]|0)|0;Oa=(c[B>>2]<<1&2)+(C>>>5)|0;if((c[ea+((ba(Oa>>>2,Ma)|0)+Na<<2)>>2]&j|0)==0){Pa=-1;Qa=aa;break}Ma=(c[(c[la>>2]|0)+(Na<<2)>>2]|0)+3+(ba(c[qa>>2]|0,Oa)|0)|0;Ra=c[X+1524+(R<<2)>>2]|0;b[aa>>1]=b[Ra+(Ma<<2)>>1]|0;b[N>>1]=b[Ra+(Ma<<2)+2>>1]<<1;Pa=a[(c[X+1556+(R<<2)>>2]|0)+((Oa&2147483646)+(Na<<2|1))|0]>>1;Qa=aa;break}else{if(!Y){I=207;break}Y=c[f+4852+(((J&255)>>>0>35>>>0)<<2)>>2]|0;Na=C>>>2;if((c[ea+(Y<<2)>>2]&j|0)==0){Pa=-1;Qa=aa;break}ea=(c[(c[la>>2]|0)+(Y<<2)>>2]|0)+3+(ba(c[qa>>2]|0,Na&3)|0)|0;Oa=c[X+1524+(R<<2)>>2]|0;b[aa>>1]=b[Oa+(ea<<2)>>1]|0;b[N>>1]=(b[Oa+(ea<<2)+2>>1]|0)/2|0;Pa=a[(c[X+1556+(R<<2)>>2]|0)+(Na&2|Y<<2|1)|0]<<1;Qa=aa;break}}else{I=207}}while(0);do{if((I|0)==207){I=0;if(ia){J=C-9|0;Pa=a[f+5632+(R*40|0)+J|0]|0;Qa=f+5312+(R*160|0)+(J<<2)|0;break}else{Pa=ha;Qa=f+5312+(R*160|0)+(K<<2)|0;break}}}while(0);K=ja<<24>>24==A<<24>>24;ha=W<<24>>24==A<<24>>24;ia=(ha&1)+(K&1)+((Pa|0)==(M|0))|0;do{if((ia|0)>1){J=b[V>>1]|0;Y=J<<16>>16;Na=b[S>>1]|0;X=Na<<16>>16;ea=b[Qa>>1]|0;Oa=ea<<16>>16;do{if(J<<16>>16>Na<<16>>16){if(!(ea<<16>>16>Na<<16>>16)){Sa=X;break}Sa=(Oa|0)>(Y|0)?Y:Oa}else{if(!(Na<<16>>16>ea<<16>>16)){Sa=X;break}Sa=(Oa|0)>(Y|0)?Oa:Y}}while(0);Y=b[f+5312+(R*160|0)+(L<<2)+2>>1]|0;Oa=Y<<16>>16;X=b[f+5312+(R*160|0)+(Q<<2)+2>>1]|0;ea=X<<16>>16;Na=b[Qa+2>>1]|0;J=Na<<16>>16;if(Y<<16>>16>X<<16>>16){if(!(Na<<16>>16>X<<16>>16)){Ta=ea;Ua=Sa;break}Ta=(J|0)>(Oa|0)?Oa:J;Ua=Sa;break}else{if(!(X<<16>>16>Na<<16>>16)){Ta=ea;Ua=Sa;break}Ta=(J|0)>(Oa|0)?J:Oa;Ua=Sa;break}}else{if((ia|0)==1){if(ha){Ta=b[f+5312+(R*160|0)+(L<<2)+2>>1]|0;Ua=b[V>>1]|0;break}if(K){Ta=b[f+5312+(R*160|0)+(Q<<2)+2>>1]|0;Ua=b[S>>1]|0;break}else{Ta=b[Qa+2>>1]|0;Ua=b[Qa>>1]|0;break}}Oa=b[V>>1]|0;J=Oa<<16>>16;if(!((Pa|0)!=-2|ja<<24>>24!=-2|W<<24>>24==-2)){Ta=b[f+5312+(R*160|0)+(L<<2)+2>>1]|0;Ua=J;break}ea=b[S>>1]|0;Na=ea<<16>>16;X=b[Qa>>1]|0;Y=X<<16>>16;do{if(Oa<<16>>16>ea<<16>>16){if(!(X<<16>>16>ea<<16>>16)){Va=Na;break}Va=(Y|0)>(J|0)?J:Y}else{if(!(ea<<16>>16>X<<16>>16)){Va=Na;break}Va=(Y|0)>(J|0)?Y:J}}while(0);J=b[f+5312+(R*160|0)+(L<<2)+2>>1]|0;Y=J<<16>>16;Na=b[f+5312+(R*160|0)+(Q<<2)+2>>1]|0;X=Na<<16>>16;ea=b[Qa+2>>1]|0;Oa=ea<<16>>16;if(J<<16>>16>Na<<16>>16){if(!(ea<<16>>16>Na<<16>>16)){Ta=X;Ua=Va;break}Ta=(Oa|0)>(Y|0)?Y:Oa;Ua=Va;break}else{if(!(Na<<16>>16>ea<<16>>16)){Ta=X;Ua=Va;break}Ta=(Oa|0)>(Y|0)?Oa:Y;Ua=Va;break}}}while(0);S=(d[f+426592+(R*80|0)+(Q<<1)+1|0]|0)+(d[f+426592+(R*80|0)+(L<<1)+1|0]|0)|0;W=(Lda(f,40,(d[f+426592+(R*80|0)+(Q<<1)|0]|0)+(d[f+426592+(R*80|0)+(L<<1)|0]|0)|0,n)|0)+Ua|0;ja=(Lda(f,47,S,o)|0)+Ta|0;do{if(ca){if(!_){S=W&65535;V=C+1|0;b[f+5312+(R*160|0)+(V<<2)>>1]=S;K=ja&65535;b[f+5312+(R*160|0)+(V<<2)+2>>1]=K;ha=c[n>>2]|0;a[f+426592+(R*80|0)+(V<<1)|0]=ha;ia=c[o>>2]|0;a[f+426592+(R*80|0)+(V<<1)+1|0]=ia;Wa=ha&255;Xa=ia&255;Ya=S;Za=K;break}if(Z){Wa=c[n>>2]&255;Xa=c[o>>2]&255;Ya=W&65535;Za=ja&65535;break}else{K=W&65535;S=C+8|0;b[f+5312+(R*160|0)+(S<<2)>>1]=K;ia=ja&65535;b[f+5312+(R*160|0)+(S<<2)+2>>1]=ia;ha=c[n>>2]|0;a[f+426592+(R*80|0)+(S<<1)|0]=ha;V=c[o>>2]|0;a[f+426592+(R*80|0)+(S<<1)+1|0]=V;Wa=ha&255;Xa=V&255;Ya=K;Za=ia;break}}else{ia=W&65535;K=C+9|0;b[f+5312+(R*160|0)+(K<<2)>>1]=ia;V=C+8|0;b[f+5312+(R*160|0)+(V<<2)>>1]=ia;ha=C+1|0;b[f+5312+(R*160|0)+(ha<<2)>>1]=ia;S=ja&65535;b[f+5312+(R*160|0)+(K<<2)+2>>1]=S;b[f+5312+(R*160|0)+(V<<2)+2>>1]=S;b[f+5312+(R*160|0)+(ha<<2)+2>>1]=S;M=c[n>>2]|0;A=M&255;a[f+426592+(R*80|0)+(K<<1)|0]=A;a[f+426592+(R*80|0)+(V<<1)|0]=A;a[f+426592+(R*80|0)+(ha<<1)|0]=A;A=c[o>>2]|0;Y=A&255;a[f+426592+(R*80|0)+(K<<1)+1|0]=Y;a[f+426592+(R*80|0)+(V<<1)+1|0]=Y;a[f+426592+(R*80|0)+(ha<<1)+1|0]=Y;Wa=M&255;Xa=A&255;Ya=ia;Za=S}}while(0);b[f+5312+(R*160|0)+(C<<2)>>1]=Ya;b[f+5312+(R*160|0)+(C<<2)+2>>1]=Za;a[f+426592+(R*80|0)+(C<<1)|0]=Wa;a[f+426592+(R*80|0)+(C<<1)+1|0]=Xa;O=O+1|0;}while((O|0)<(da|0))}else{c[f+426592+(R*80|0)+(U<<1)>>2]=0;c[f+426592+(R*80|0)+(U<<1)+16>>2]=0}}while(0);ka=ka+1|0;}while((ka|0)<4);ka=R+1|0;if(ka>>>0<(c[pa>>2]|0)>>>0){R=ka}else{La=Ka;break c}}}if((va&256|0)!=0){Yda(f,k);c[f+426616>>2]=0;c[f+426620>>2]=0;c[f+426632>>2]=0;c[f+426636>>2]=0;c[f+426648>>2]=0;c[f+426652>>2]=0;c[f+426664>>2]=0;c[f+426668>>2]=0;c[f+426696>>2]=0;c[f+426700>>2]=0;c[f+426712>>2]=0;c[f+426716>>2]=0;c[f+426728>>2]=0;c[f+426732>>2]=0;c[f+426744>>2]=0;c[f+426748>>2]=0;La=c[f+6196>>2]&v;break}if((va&8|0)!=0){R=f+199428|0;pa=c[R>>2]|0;if((pa|0)==0){La=v;break}qa=f+426767|0;la=f+426760|0;P=f+425488|0;ta=0;ua=pa;pa=va;g:while(1){if((pa&4096<<(ta<<1)|0)==0){_a=ua}else{$a=c[l+(ta<<2)>>2]|0;if($a>>>0>1>>>0){ka=a[f+5632+(ta*40|0)+4|0]|0;aa=(a[f+5632+(ta*40|0)+11|0]|0)>0;do{if((c[G>>2]|0)==3){if(aa){ab=(d[qa]|0)>>>7&255^1}else{ab=0}if(!(ka<<24>>24>0)){bb=ab;cb=0;break}bb=(a[la]|0)<0?ab:ab|2;cb=0}else{N=aa&1;if(!(ka<<24>>24>0)){bb=N;cb=0;break}bb=N|2;cb=0}}while(0);while(1){if((Mda(P,bb+54+(f+425536)|0)|0)==0){break}ka=cb+1|0;if((ka|0)>31){db=-1;I=268;break g}else{bb=(bb>>2)+4|0;cb=ka}}if(cb>>>0<$a>>>0){eb=cb}else{db=cb;I=268;break}}else{eb=0}ka=ba(eb,16843009)|0;c[f+5632+(ta*40|0)+12>>2]=ka;c[f+5632+(ta*40|0)+20>>2]=ka;c[f+5632+(ta*40|0)+28>>2]=ka;c[f+5632+(ta*40|0)+36>>2]=ka;_a=c[R>>2]|0}ka=ta+1|0;if(!(ka>>>0<_a>>>0)){break}ta=ka;ua=_a;pa=c[k>>2]|0}if((I|0)==268){yDb(c[f>>2]|0,16,2283728,(Ja=i,i=i+16|0,c[Ja>>2]=db,c[Ja+8>>2]=$a,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}if((_a|0)==0){La=v;break}else{fb=0;gb=_a}while(1){if((c[k>>2]&4096<<(fb<<1)|0)==0){hb=gb}else{pa=a[f+5632+(fb*40|0)+12|0]|0;ua=a[f+5632+(fb*40|0)+4|0]|0;ta=a[f+5632+(fb*40|0)+11|0]|0;P=f+5312+(fb*160|0)+44|0;la=f+5312+(fb*160|0)+16|0;qa=a[f+5632+(fb*40|0)+8|0]|0;if(qa<<24>>24==-2){ib=a[f+5632+(fb*40|0)+3|0]|0;jb=f+5312+(fb*160|0)+12|0}else{ib=qa;jb=f+5312+(fb*160|0)+32|0}qa=ua<<24>>24==pa<<24>>24;ka=ta<<24>>24==pa<<24>>24;aa=(ka&1)+(qa&1)+(ib<<24>>24==pa<<24>>24)|0;do{if((aa|0)>1){pa=b[P>>1]|0;N=pa<<16>>16;j=b[la>>1]|0;T=j<<16>>16;na=b[jb>>1]|0;fa=na<<16>>16;do{if(pa<<16>>16>j<<16>>16){if(!(na<<16>>16>j<<16>>16)){kb=T;break}kb=(fa|0)>(N|0)?N:fa}else{if(!(j<<16>>16>na<<16>>16)){kb=T;break}kb=(fa|0)>(N|0)?fa:N}}while(0);N=b[f+5312+(fb*160|0)+46>>1]|0;fa=N<<16>>16;T=b[f+5312+(fb*160|0)+18>>1]|0;na=T<<16>>16;j=b[jb+2>>1]|0;pa=j<<16>>16;if(N<<16>>16>T<<16>>16){if(!(j<<16>>16>T<<16>>16)){lb=na;mb=kb;break}lb=(pa|0)>(fa|0)?fa:pa;mb=kb;break}else{if(!(T<<16>>16>j<<16>>16)){lb=na;mb=kb;break}lb=(pa|0)>(fa|0)?pa:fa;mb=kb;break}}else{if((aa|0)==1){if(ka){lb=b[f+5312+(fb*160|0)+46>>1]|0;mb=b[P>>1]|0;break}if(qa){lb=b[f+5312+(fb*160|0)+18>>1]|0;mb=b[la>>1]|0;break}else{lb=b[jb+2>>1]|0;mb=b[jb>>1]|0;break}}fa=b[P>>1]|0;pa=fa<<16>>16;if(!(ib<<24>>24!=-2|ua<<24>>24!=-2|ta<<24>>24==-2)){lb=b[f+5312+(fb*160|0)+46>>1]|0;mb=pa;break}na=b[la>>1]|0;j=na<<16>>16;T=b[jb>>1]|0;N=T<<16>>16;do{if(fa<<16>>16>na<<16>>16){if(!(T<<16>>16>na<<16>>16)){nb=j;break}nb=(N|0)>(pa|0)?pa:N}else{if(!(na<<16>>16>T<<16>>16)){nb=j;break}nb=(N|0)>(pa|0)?N:pa}}while(0);pa=b[f+5312+(fb*160|0)+46>>1]|0;N=pa<<16>>16;j=b[f+5312+(fb*160|0)+18>>1]|0;T=j<<16>>16;na=b[jb+2>>1]|0;fa=na<<16>>16;if(pa<<16>>16>j<<16>>16){if(!(na<<16>>16>j<<16>>16)){lb=T;mb=nb;break}lb=(fa|0)>(N|0)?N:fa;mb=nb;break}else{if(!(j<<16>>16>na<<16>>16)){lb=T;mb=nb;break}lb=(fa|0)>(N|0)?fa:N;mb=nb;break}}}while(0);la=(d[f+426592+(fb*80|0)+9|0]|0)+(d[f+426592+(fb*80|0)+23|0]|0)|0;ta=(Lda(f,40,(d[f+426592+(fb*80|0)+8|0]|0)+(d[f+426592+(fb*80|0)+22|0]|0)|0,p)|0)+mb|0;ua=(Lda(f,47,la,q)|0)+lb|0;la=(c[q>>2]<<8&65280|c[p>>2]&255)*65537|0;c[f+426592+(fb*80|0)+24>>2]=la;c[f+426592+(fb*80|0)+28>>2]=la;c[f+426592+(fb*80|0)+40>>2]=la;c[f+426592+(fb*80|0)+44>>2]=la;c[f+426592+(fb*80|0)+56>>2]=la;c[f+426592+(fb*80|0)+60>>2]=la;c[f+426592+(fb*80|0)+72>>2]=la;c[f+426592+(fb*80|0)+76>>2]=la;la=ua<<16|ta&65535;c[f+5312+(fb*160|0)+48>>2]=la;c[f+5312+(fb*160|0)+52>>2]=la;c[f+5312+(fb*160|0)+56>>2]=la;c[f+5312+(fb*160|0)+60>>2]=la;c[f+5312+(fb*160|0)+80>>2]=la;c[f+5312+(fb*160|0)+84>>2]=la;c[f+5312+(fb*160|0)+88>>2]=la;c[f+5312+(fb*160|0)+92>>2]=la;c[f+5312+(fb*160|0)+112>>2]=la;c[f+5312+(fb*160|0)+116>>2]=la;c[f+5312+(fb*160|0)+120>>2]=la;c[f+5312+(fb*160|0)+124>>2]=la;c[f+5312+(fb*160|0)+144>>2]=la;c[f+5312+(fb*160|0)+148>>2]=la;c[f+5312+(fb*160|0)+152>>2]=la;c[f+5312+(fb*160|0)+156>>2]=la;hb=c[R>>2]|0}la=fb+1|0;if(la>>>0<hb>>>0){fb=la;gb=hb}else{La=v;break c}}}R=f+199428|0;la=(c[R>>2]|0)==0;if((va&16|0)!=0){if(la){La=v;break}ta=f+425488|0;ua=0;h:do{P=ua<<1;qa=l+(ua<<2)|0;ka=0;do{if((c[k>>2]&4096<<ka+P|0)==0){aa=ka<<4|12;c[f+5632+(ua*40|0)+aa>>2]=-1;c[aa+8+(f+5632+(ua*40|0))>>2]=-1}else{ob=c[qa>>2]|0;if(ob>>>0>1>>>0){aa=d[473368+(ka<<3)|0]|0;N=aa-1|0;fa=aa-8|0;aa=a[f+5632+(ua*40|0)+fa|0]|0;T=(a[f+5632+(ua*40|0)+N|0]|0)>0;do{if((c[G>>2]|0)==3){if(T){pb=(d[f+426756+N|0]|0)>>>7&255^1}else{pb=0}if(!(aa<<24>>24>0)){qb=pb;rb=0;break}qb=(a[f+426756+fa|0]|0)<0?pb:pb|2;rb=0}else{na=T&1;if(!(aa<<24>>24>0)){qb=na;rb=0;break}qb=na|2;rb=0}}while(0);while(1){if((Mda(ta,qb+54+(f+425536)|0)|0)==0){break}aa=rb+1|0;if((aa|0)>31){sb=-1;I=327;break h}else{qb=(qb>>2)+4|0;rb=aa}}if(rb>>>0<ob>>>0){tb=rb}else{sb=rb;I=327;break h}}else{tb=0}aa=ka<<4|12;T=ba(tb,16843009)|0;c[f+5632+(ua*40|0)+aa>>2]=T;c[aa+8+(f+5632+(ua*40|0))>>2]=T}ka=ka+1|0;}while((ka|0)<2);ua=ua+1|0;ub=c[R>>2]|0;}while(ua>>>0<ub>>>0);if((I|0)==327){yDb(c[f>>2]|0,16,2283728,(Ja=i,i=i+16|0,c[Ja>>2]=sb,c[Ja+8>>2]=ob,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}if((ub|0)==0){La=v;break}ua=f+2524|0;ta=f+4872|0;ka=f+4852|0;qa=f+6100|0;P=f+6108|0;T=0;while(1){aa=T<<1;fa=f+5632+(T*40|0)+4|0;N=f+5312+(T*160|0)+16|0;na=f+5312+(T*160|0)+18|0;j=f+5632+(T*40|0)+11|0;pa=f+5312+(T*160|0)+40|0;U=pa|0;ga=pa;pa=12288<<aa;$=f+5312+(T*160|0)+42|0;da=f+5632+(T*40|0)+27|0;O=f+5312+(T*160|0)+108|0;Z=f+5312+(T*160|0)+110|0;_=0;do{if((c[k>>2]&4096<<_+aa|0)==0){ca=_<<4|12;c[f+426592+(T*80|0)+(ca<<1)>>2]=0;c[f+426592+(T*80|0)+(ca<<1)+4>>2]=0;c[f+426592+(T*80|0)+(ca<<1)+16>>2]=0;c[f+426592+(T*80|0)+(ca<<1)+20>>2]=0;TGb(f+5312+(T*160|0)+(ca<<2)|0,0,16)|0;TGb(f+5312+(T*160|0)+(ca<<2)+32|0,0,16)|0}else{ca=_<<3;h=_<<4|12;ja=a[f+5632+(T*40|0)+h|0]|0;W=ja<<24>>24;do{if((ca|0)==0){if(!((a[fa]|0)==ja<<24>>24)){I=339;break}vb=b[na>>1]|0;wb=b[N>>1]|0}else{if(!((a[da]|0)==ja<<24>>24)){I=339;break}vb=b[Z>>1]|0;wb=b[O>>1]|0}}while(0);do{if((I|0)==339){I=0;L=a[473368+ca|0]|0;Q=L&255;S=Q-8|0;ia=a[f+5632+(T*40|0)+S|0]|0;A=Q-1|0;M=a[f+5632+(T*40|0)+A|0]|0;Y=f+5312+(T*160|0)+(A<<2)|0;ha=f+5312+(T*160|0)+(S<<2)|0;V=Q-4|0;K=a[f+5632+(T*40|0)+V|0]|0;Oa=K<<24>>24;X=K<<24>>24==-2;do{if((c[H>>2]|0)!=0&X&(L&255)>>>0>19>>>0&(Q&7|0)==4){if((a[j]|0)==-2){I=348;break}K=c[ua>>2]|0;ea=c[K+1536>>2]|0;c[ga>>2]=0;Na=(c[ta>>2]&128|0)==0;if((c[ma>>2]|0)==0){if(Na){I=348;break}J=c[D>>2]|0;Ma=J+(c[ka>>2]|0)|0;Ra=(c[B>>2]<<1&2)+(Q>>>5)|0;if((c[ea+((ba(Ra>>>2,J)|0)+Ma<<2)>>2]&pa|0)==0){xb=-1;yb=U;break}J=(c[(c[qa>>2]|0)+(Ma<<2)>>2]|0)+3+(ba(c[P>>2]|0,Ra)|0)|0;zb=c[K+1524+(T<<2)>>2]|0;b[U>>1]=b[zb+(J<<2)>>1]|0;b[$>>1]=b[zb+(J<<2)+2>>1]<<1;xb=a[(c[K+1556+(T<<2)>>2]|0)+((Ra&2147483646)+(Ma<<2|1))|0]>>1;yb=U;break}else{if(!Na){I=348;break}Na=c[f+4852+(((L&255)>>>0>35>>>0)<<2)>>2]|0;Ma=Q>>>2;if((c[ea+(Na<<2)>>2]&pa|0)==0){xb=-1;yb=U;break}ea=(c[(c[qa>>2]|0)+(Na<<2)>>2]|0)+3+(ba(c[P>>2]|0,Ma&3)|0)|0;Ra=c[K+1524+(T<<2)>>2]|0;b[U>>1]=b[Ra+(ea<<2)>>1]|0;b[$>>1]=(b[Ra+(ea<<2)+2>>1]|0)/2|0;xb=a[(c[K+1556+(T<<2)>>2]|0)+(Ma&2|Na<<2|1)|0]<<1;yb=U;break}}else{I=348}}while(0);do{if((I|0)==348){I=0;if(X){L=Q-9|0;xb=a[f+5632+(T*40|0)+L|0]|0;yb=f+5312+(T*160|0)+(L<<2)|0;break}else{xb=Oa;yb=f+5312+(T*160|0)+(V<<2)|0;break}}}while(0);V=ia<<24>>24==ja<<24>>24;Oa=M<<24>>24==ja<<24>>24;Q=(Oa&1)+(V&1)+((xb|0)==(W|0))|0;if((Q|0)>1){X=b[Y>>1]|0;L=X<<16>>16;Na=b[ha>>1]|0;Ma=Na<<16>>16;K=b[yb>>1]|0;ea=K<<16>>16;do{if(X<<16>>16>Na<<16>>16){if(!(K<<16>>16>Na<<16>>16)){Ab=Ma;break}Ab=(ea|0)>(L|0)?L:ea}else{if(!(Na<<16>>16>K<<16>>16)){Ab=Ma;break}Ab=(ea|0)>(L|0)?ea:L}}while(0);L=b[f+5312+(T*160|0)+(A<<2)+2>>1]|0;ea=L<<16>>16;Ma=b[f+5312+(T*160|0)+(S<<2)+2>>1]|0;K=Ma<<16>>16;Na=b[yb+2>>1]|0;X=Na<<16>>16;if(L<<16>>16>Ma<<16>>16){if(!(Na<<16>>16>Ma<<16>>16)){vb=K;wb=Ab;break}vb=(X|0)>(ea|0)?ea:X;wb=Ab;break}else{if(!(Ma<<16>>16>Na<<16>>16)){vb=K;wb=Ab;break}vb=(X|0)>(ea|0)?X:ea;wb=Ab;break}}if((Q|0)==1){if(Oa){vb=b[f+5312+(T*160|0)+(A<<2)+2>>1]|0;wb=b[Y>>1]|0;break}if(V){vb=b[f+5312+(T*160|0)+(S<<2)+2>>1]|0;wb=b[ha>>1]|0;break}else{vb=b[yb+2>>1]|0;wb=b[yb>>1]|0;break}}ea=b[Y>>1]|0;X=ea<<16>>16;if(!((xb|0)!=-2|ia<<24>>24!=-2|M<<24>>24==-2)){vb=b[f+5312+(T*160|0)+(A<<2)+2>>1]|0;wb=X;break}K=b[ha>>1]|0;Na=K<<16>>16;Ma=b[yb>>1]|0;L=Ma<<16>>16;do{if(ea<<16>>16>K<<16>>16){if(!(Ma<<16>>16>K<<16>>16)){Bb=Na;break}Bb=(L|0)>(X|0)?X:L}else{if(!(K<<16>>16>Ma<<16>>16)){Bb=Na;break}Bb=(L|0)>(X|0)?L:X}}while(0);X=b[f+5312+(T*160|0)+(A<<2)+2>>1]|0;L=X<<16>>16;Na=b[f+5312+(T*160|0)+(S<<2)+2>>1]|0;Ma=Na<<16>>16;K=b[yb+2>>1]|0;ea=K<<16>>16;if(X<<16>>16>Na<<16>>16){if(!(K<<16>>16>Na<<16>>16)){vb=Ma;wb=Bb;break}vb=(ea|0)>(L|0)?L:ea;wb=Bb;break}else{if(!(Na<<16>>16>K<<16>>16)){vb=Ma;wb=Bb;break}vb=(ea|0)>(L|0)?ea:L;wb=Bb;break}}}while(0);W=d[473368+ca|0]|0;ja=W-1|0;L=W-8|0;W=(d[f+426592+(T*80|0)+(L<<1)+1|0]|0)+(d[f+426592+(T*80|0)+(ja<<1)+1|0]|0)|0;ea=(Lda(f,40,(d[f+426592+(T*80|0)+(L<<1)|0]|0)+(d[f+426592+(T*80|0)+(ja<<1)|0]|0)|0,r)|0)+wb|0;ja=(Lda(f,47,W,s)|0)+vb|0;W=(c[s>>2]<<8&65280|c[r>>2]&255)*65537|0;c[f+426592+(T*80|0)+(h<<1)>>2]=W;c[f+426592+(T*80|0)+(h<<1)+4>>2]=W;c[f+426592+(T*80|0)+(h<<1)+16>>2]=W;c[f+426592+(T*80|0)+(h<<1)+20>>2]=W;W=ja<<16|ea&65535;c[f+5312+(T*160|0)+(h<<2)>>2]=W;c[f+5312+(T*160|0)+(h<<2)+4>>2]=W;c[f+5312+(T*160|0)+(h<<2)+8>>2]=W;c[f+5312+(T*160|0)+(h<<2)+12>>2]=W;c[f+5312+(T*160|0)+(h<<2)+32>>2]=W;c[f+5312+(T*160|0)+(h<<2)+36>>2]=W;c[f+5312+(T*160|0)+(h<<2)+40>>2]=W;c[f+5312+(T*160|0)+(h<<2)+44>>2]=W}_=_+1|0;}while((_|0)<2);_=T+1|0;if(_>>>0<(c[R>>2]|0)>>>0){T=_}else{La=v;break c}}}if(la){La=v;break}T=f+425488|0;P=0;i:do{qa=P<<1;ka=l+(P<<2)|0;ta=0;do{if((c[k>>2]&4096<<ta+qa|0)==0){ua=ta<<1;b[ua+12+(f+5632+(P*40|0))>>1]=-1;b[ua+20+(f+5632+(P*40|0))>>1]=-1;b[ua+28+(f+5632+(P*40|0))>>1]=-1;b[ua+36+(f+5632+(P*40|0))>>1]=-1}else{Cb=c[ka>>2]|0;if(Cb>>>0>1>>>0){ua=d[473368+(ta<<2)|0]|0;_=ua-1|0;U=ua-8|0;ua=a[f+5632+(P*40|0)+U|0]|0;$=(a[f+5632+(P*40|0)+_|0]|0)>0;do{if((c[G>>2]|0)==3){if($){Db=(d[f+426756+_|0]|0)>>>7&255^1}else{Db=0}if(!(ua<<24>>24>0)){Eb=Db;Fb=0;break}Eb=(a[f+426756+U|0]|0)<0?Db:Db|2;Fb=0}else{pa=$&1;if(!(ua<<24>>24>0)){Eb=pa;Fb=0;break}Eb=pa|2;Fb=0}}while(0);while(1){if((Mda(T,Eb+54+(f+425536)|0)|0)==0){break}ua=Fb+1|0;if((ua|0)>31){Gb=-1;I=399;break i}else{Eb=(Eb>>2)+4|0;Fb=ua}}if(Fb>>>0<Cb>>>0){Hb=Fb}else{Gb=Fb;I=399;break i}}else{Hb=0}ua=ta<<1;$=(Hb*257|0)&65535;b[ua+12+(f+5632+(P*40|0))>>1]=$;b[ua+20+(f+5632+(P*40|0))>>1]=$;b[ua+28+(f+5632+(P*40|0))>>1]=$;b[ua+36+(f+5632+(P*40|0))>>1]=$}ta=ta+1|0;}while((ta|0)<2);P=P+1|0;Ib=c[R>>2]|0;}while(P>>>0<Ib>>>0);if((I|0)==399){yDb(c[f>>2]|0,16,2283728,(Ja=i,i=i+16|0,c[Ja>>2]=Gb,c[Ja+8>>2]=Cb,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}if((Ib|0)==0){La=v;break}P=f+2524|0;T=f+4872|0;la=f+4852|0;ta=f+6100|0;ka=f+6108|0;qa=0;while(1){$=qa<<1;ua=f+5632+(qa*40|0)+11|0;U=f+5312+(qa*160|0)+44|0;_=f+5312+(qa*160|0)+46|0;h=f+5312+(qa*160|0)+40|0;ca=h|0;pa=h;h=12288<<$;ga=f+5312+(qa*160|0)+42|0;j=f+5632+(qa*40|0)+8|0;O=f+5312+(qa*160|0)+20|0;Z=f+5632+(qa*40|0)+5|0;da=f+5312+(qa*160|0)+32|0;N=0;do{if((c[k>>2]&4096<<N+$|0)==0){na=(N<<1)+12|0;c[f+426592+(qa*80|0)+(na<<1)>>2]=0;c[f+426592+(qa*80|0)+(na<<1)+16>>2]=0;c[f+426592+(qa*80|0)+(na<<1)+32>>2]=0;c[f+426592+(qa*80|0)+(na<<1)+48>>2]=0;c[f+5312+(qa*160|0)+(na<<2)>>2]=0;c[f+5312+(qa*160|0)+(na<<2)+4>>2]=0;c[f+5312+(qa*160|0)+(na<<2)+32>>2]=0;c[f+5312+(qa*160|0)+(na<<2)+36>>2]=0;c[f+5312+(qa*160|0)+(na<<2)+64>>2]=0;c[f+5312+(qa*160|0)+(na<<2)+68>>2]=0;c[f+5312+(qa*160|0)+(na<<2)+96>>2]=0;c[f+5312+(qa*160|0)+(na<<2)+100>>2]=0}else{na=N<<2;fa=(N<<1)+12|0;aa=a[f+5632+(qa*40|0)+fa|0]|0;W=aa<<24>>24;do{if((na|0)==0){if(!((a[ua]|0)==aa<<24>>24)){I=413;break}Jb=b[_>>1]|0;Kb=b[U>>1]|0}else{ea=a[j]|0;if(ea<<24>>24==-2){Lb=a[Z]|0;Mb=O}else{Lb=ea;Mb=da}if(!(Lb<<24>>24==aa<<24>>24)){I=413;break}Jb=b[Mb+2>>1]|0;Kb=b[Mb>>1]|0}}while(0);do{if((I|0)==413){I=0;ea=a[473368+na|0]|0;ja=ea&255;L=ja-8|0;Ma=a[f+5632+(qa*40|0)+L|0]|0;K=ja-1|0;Na=a[f+5632+(qa*40|0)+K|0]|0;X=f+5312+(qa*160|0)+(K<<2)|0;ha=f+5312+(qa*160|0)+(L<<2)|0;M=ja-6|0;ia=a[f+5632+(qa*40|0)+M|0]|0;Y=ia<<24>>24;V=ia<<24>>24==-2;do{if((c[H>>2]|0)!=0&V&(ea&255)>>>0>19>>>0&(ja&7|0)==4){if((a[ua]|0)==-2){I=422;break}ia=c[P>>2]|0;Oa=c[ia+1536>>2]|0;c[pa>>2]=0;Q=(c[T>>2]&128|0)==0;if((c[ma>>2]|0)==0){if(Q){I=422;break}Ra=c[D>>2]|0;J=Ra+(c[la>>2]|0)|0;zb=(c[B>>2]<<1&2)+(ja>>>5)|0;if((c[Oa+((ba(zb>>>2,Ra)|0)+J<<2)>>2]&h|0)==0){Nb=-1;Ob=ca;break}Ra=(c[(c[ta>>2]|0)+(J<<2)>>2]|0)+3+(ba(c[ka>>2]|0,zb)|0)|0;Pb=c[ia+1524+(qa<<2)>>2]|0;b[ca>>1]=b[Pb+(Ra<<2)>>1]|0;b[ga>>1]=b[Pb+(Ra<<2)+2>>1]<<1;Nb=a[(c[ia+1556+(qa<<2)>>2]|0)+((zb&2147483646)+(J<<2|1))|0]>>1;Ob=ca;break}else{if(!Q){I=422;break}Q=c[f+4852+(((ea&255)>>>0>35>>>0)<<2)>>2]|0;J=ja>>>2;if((c[Oa+(Q<<2)>>2]&h|0)==0){Nb=-1;Ob=ca;break}Oa=(c[(c[ta>>2]|0)+(Q<<2)>>2]|0)+3+(ba(c[ka>>2]|0,J&3)|0)|0;zb=c[ia+1524+(qa<<2)>>2]|0;b[ca>>1]=b[zb+(Oa<<2)>>1]|0;b[ga>>1]=(b[zb+(Oa<<2)+2>>1]|0)/2|0;Nb=a[(c[ia+1556+(qa<<2)>>2]|0)+(J&2|Q<<2|1)|0]<<1;Ob=ca;break}}else{I=422}}while(0);do{if((I|0)==422){I=0;if(V){ea=ja-9|0;Nb=a[f+5632+(qa*40|0)+ea|0]|0;Ob=f+5312+(qa*160|0)+(ea<<2)|0;break}else{Nb=Y;Ob=f+5312+(qa*160|0)+(M<<2)|0;break}}}while(0);M=Ma<<24>>24==aa<<24>>24;Y=Na<<24>>24==aa<<24>>24;ja=(Y&1)+(M&1)+((Nb|0)==(W|0))|0;if((ja|0)>1){V=b[X>>1]|0;ea=V<<16>>16;S=b[ha>>1]|0;A=S<<16>>16;Q=b[Ob>>1]|0;J=Q<<16>>16;do{if(V<<16>>16>S<<16>>16){if(!(Q<<16>>16>S<<16>>16)){Qb=A;break}Qb=(J|0)>(ea|0)?ea:J}else{if(!(S<<16>>16>Q<<16>>16)){Qb=A;break}Qb=(J|0)>(ea|0)?J:ea}}while(0);ea=b[f+5312+(qa*160|0)+(K<<2)+2>>1]|0;J=ea<<16>>16;A=b[f+5312+(qa*160|0)+(L<<2)+2>>1]|0;Q=A<<16>>16;S=b[Ob+2>>1]|0;V=S<<16>>16;if(ea<<16>>16>A<<16>>16){if(!(S<<16>>16>A<<16>>16)){Jb=Q;Kb=Qb;break}Jb=(V|0)>(J|0)?J:V;Kb=Qb;break}else{if(!(A<<16>>16>S<<16>>16)){Jb=Q;Kb=Qb;break}Jb=(V|0)>(J|0)?V:J;Kb=Qb;break}}if((ja|0)==1){if(Y){Jb=b[f+5312+(qa*160|0)+(K<<2)+2>>1]|0;Kb=b[X>>1]|0;break}if(M){Jb=b[f+5312+(qa*160|0)+(L<<2)+2>>1]|0;Kb=b[ha>>1]|0;break}else{Jb=b[Ob+2>>1]|0;Kb=b[Ob>>1]|0;break}}J=b[X>>1]|0;V=J<<16>>16;if(!((Nb|0)!=-2|Ma<<24>>24!=-2|Na<<24>>24==-2)){Jb=b[f+5312+(qa*160|0)+(K<<2)+2>>1]|0;Kb=V;break}Q=b[ha>>1]|0;S=Q<<16>>16;A=b[Ob>>1]|0;ea=A<<16>>16;do{if(J<<16>>16>Q<<16>>16){if(!(A<<16>>16>Q<<16>>16)){Rb=S;break}Rb=(ea|0)>(V|0)?V:ea}else{if(!(Q<<16>>16>A<<16>>16)){Rb=S;break}Rb=(ea|0)>(V|0)?ea:V}}while(0);V=b[f+5312+(qa*160|0)+(K<<2)+2>>1]|0;ea=V<<16>>16;S=b[f+5312+(qa*160|0)+(L<<2)+2>>1]|0;A=S<<16>>16;Q=b[Ob+2>>1]|0;J=Q<<16>>16;if(V<<16>>16>S<<16>>16){if(!(Q<<16>>16>S<<16>>16)){Jb=A;Kb=Rb;break}Jb=(J|0)>(ea|0)?ea:J;Kb=Rb;break}else{if(!(S<<16>>16>Q<<16>>16)){Jb=A;Kb=Rb;break}Jb=(J|0)>(ea|0)?J:ea;Kb=Rb;break}}}while(0);W=d[473368+na|0]|0;aa=W-1|0;ea=W-8|0;W=(d[f+426592+(qa*80|0)+(ea<<1)+1|0]|0)+(d[f+426592+(qa*80|0)+(aa<<1)+1|0]|0)|0;J=(Lda(f,40,(d[f+426592+(qa*80|0)+(ea<<1)|0]|0)+(d[f+426592+(qa*80|0)+(aa<<1)|0]|0)|0,t)|0)+Kb|0;aa=(Lda(f,47,W,u)|0)+Jb|0;W=(c[u>>2]<<8&65280|c[t>>2]&255)*65537|0;c[f+426592+(qa*80|0)+(fa<<1)>>2]=W;c[f+426592+(qa*80|0)+(fa<<1)+16>>2]=W;c[f+426592+(qa*80|0)+(fa<<1)+32>>2]=W;c[f+426592+(qa*80|0)+(fa<<1)+48>>2]=W;W=aa<<16|J&65535;c[f+5312+(qa*160|0)+(fa<<2)>>2]=W;c[f+5312+(qa*160|0)+(fa<<2)+4>>2]=W;c[f+5312+(qa*160|0)+(fa<<2)+32>>2]=W;c[f+5312+(qa*160|0)+(fa<<2)+36>>2]=W;c[f+5312+(qa*160|0)+(fa<<2)+64>>2]=W;c[f+5312+(qa*160|0)+(fa<<2)+68>>2]=W;c[f+5312+(qa*160|0)+(fa<<2)+96>>2]=W;c[f+5312+(qa*160|0)+(fa<<2)+100>>2]=W}N=N+1|0;}while((N|0)<2);N=qa+1|0;if(N>>>0<(c[R>>2]|0)>>>0){qa=N}else{La=v;break}}}else{do{if((va&1|0)==0){qa=f+4836|0;R=Pca(f,c[qa>>2]|0,0)|0;c[qa>>2]=R;if((R|0)<0){oa=-1}else{break}i=g;return oa|0}else{R=f+425488|0;do{if((v|0)==0){I=129}else{if((Ida(R,(c[f+5712>>2]|0)+399+(f+425536)|0)|0)==0){I=129;break}c[k>>2]=c[k>>2]|16777216;qa=f+425604|0;ka=f+425605|0;ta=0;do{la=d[473368+ta|0]|0;T=a[la-1+(f+4888)|0]|0;P=a[la-8+(f+4888)|0]|0;N=(T|0)>(P|0)?P:T;T=(N|0)<0?2:N;if((Mda(R,qa)|0)==0){N=Mda(R,ka)|0;P=((Mda(R,ka)|0)<<1)+N|0;N=P+((Mda(R,ka)|0)<<2)|0;Sb=((N|0)>=(T|0))+N|0}else{Sb=T}T=(Sb*257|0)&65535;b[f+4888+la>>1]=T;b[la+8+(f+4888)>>1]=T;ta=ta+4|0;}while((ta|0)<16)}}while(0);if((I|0)==129){ta=f+425604|0;ka=f+425605|0;qa=0;do{fa=d[473368+qa|0]|0;na=a[fa-1+(f+4888)|0]|0;T=a[fa-8+(f+4888)|0]|0;la=(na|0)>(T|0)?T:na;na=(la|0)<0?2:la;if((Mda(R,ta)|0)==0){la=Mda(R,ka)|0;T=((Mda(R,ka)|0)<<1)+la|0;la=T+((Mda(R,ka)|0)<<2)|0;Tb=((la|0)>=(na|0))+la&255}else{Tb=na&255}a[f+4888+fa|0]=Tb;qa=qa+1|0;}while((qa|0)<16)}qa=c[f+4928>>2]|0;ka=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;c[qa+ka>>2]=c[f+4924>>2];a[qa+(ka+4)|0]=a[f+4919|0]|0;a[qa+(ka+5)|0]=a[f+4911|0]|0;a[qa+(ka+6)|0]=a[f+4903|0]|0;if((Oca(f)|0)<0){oa=-1}else{break}i=g;return oa|0}}while(0);if(!x){c[f+4832>>2]=6;La=v;break}if((c[f+4872>>2]|0)==0){Ub=0}else{Ub=(a[(c[f+426576>>2]|0)+(c[f+4852>>2]|0)|0]|0)!=0|0}if((c[f+4864>>2]|0)==0){Vb=Ub}else{Vb=((a[(c[f+426576>>2]|0)+(c[f+4844>>2]|0)|0]|0)!=0)+Ub|0}ka=f+425488|0;do{if((Ida(ka,Vb+64+(f+425536)|0)|0)==0){Wb=0}else{qa=f+425603|0;if((Ida(ka,qa)|0)==0){Wb=1;break}R=(Ida(ka,qa)|0)==0;Wb=R?2:3}}while(0);a[(c[f+426576>>2]|0)+E|0]=Wb;ka=Pca(f,Wb,1)|0;if((ka|0)<0){oa=-1;i=g;return oa|0}else{c[f+4832>>2]=ka;La=v;break}}}while(0);do{if((c[k>>2]&120|0)!=0){a[(c[f+426576>>2]|0)+E|0]=0;v=c[k>>2]|0;Wb=c[f+6108>>2]|0;Vb=(ba(Wb<<2,c[B>>2]|0)|0)+(c[z>>2]<<2)|0;Ub=c[F>>2]<<2;if((v&12288|0)==0){Tb=c[f+4084>>2]|0;b[Tb+Ub>>1]=-1;b[Tb+(Ub|2)>>1]=-1}else{Tb=c[f+4052>>2]|0;Sb=f+5360|0;va=c[Sb+4>>2]|0;t=Tb+(Vb<<2)|0;c[t>>2]=c[Sb>>2];c[t+4>>2]=va;va=f+5368|0;t=c[va+4>>2]|0;Sb=Tb+((Vb|2)<<2)|0;c[Sb>>2]=c[va>>2];c[Sb+4>>2]=t;t=f+5392|0;Sb=c[t+4>>2]|0;va=Vb+Wb|0;u=Tb+(va<<2)|0;c[u>>2]=c[t>>2];c[u+4>>2]=Sb;Sb=f+5400|0;u=c[Sb+4>>2]|0;t=Tb+(va+2<<2)|0;c[t>>2]=c[Sb>>2];c[t+4>>2]=u;u=f+5424|0;t=c[u+4>>2]|0;Sb=Vb+(Wb<<1)|0;va=Tb+(Sb<<2)|0;c[va>>2]=c[u>>2];c[va+4>>2]=t;t=f+5432|0;va=c[t+4>>2]|0;u=Tb+(Sb+2<<2)|0;c[u>>2]=c[t>>2];c[u+4>>2]=va;va=f+5456|0;u=c[va+4>>2]|0;t=Vb+(Wb*3|0)|0;Sb=Tb+(t<<2)|0;c[Sb>>2]=c[va>>2];c[Sb+4>>2]=u;u=f+5464|0;Sb=c[u+4>>2]|0;va=Tb+(t+2<<2)|0;c[va>>2]=c[u>>2];c[va+4>>2]=Sb;Sb=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;va=c[f+426584>>2]|0;u=va+(Sb<<1)|0;if((v&2048|0)==0){t=f+426664|0;Tb=c[t+4>>2]|0;Jb=u;c[Jb>>2]=c[t>>2];c[Jb+4>>2]=Tb;b[va+(Sb+6<<1)>>1]=b[f+426622>>1]|0;b[va+(Sb+5<<1)>>1]=b[f+426638>>1]|0;b[va+(Sb+4<<1)>>1]=b[f+426654>>1]|0}else{TGb(u|0,0,16)|0}u=c[f+4084>>2]|0;a[u+Ub|0]=a[f+5644|0]|0;a[u+(Ub|1)|0]=a[f+5646|0]|0;a[u+(Ub|2)|0]=a[f+5660|0]|0;a[u+(Ub|3)|0]=a[f+5662|0]|0}if((v&49152|0)!=0){u=c[f+4056>>2]|0;Sb=f+5520|0;va=c[Sb+4>>2]|0;Tb=u+(Vb<<2)|0;c[Tb>>2]=c[Sb>>2];c[Tb+4>>2]=va;va=f+5528|0;Tb=c[va+4>>2]|0;Sb=u+((Vb|2)<<2)|0;c[Sb>>2]=c[va>>2];c[Sb+4>>2]=Tb;Tb=f+5552|0;Sb=c[Tb+4>>2]|0;va=Vb+Wb|0;Jb=u+(va<<2)|0;c[Jb>>2]=c[Tb>>2];c[Jb+4>>2]=Sb;Sb=f+5560|0;Jb=c[Sb+4>>2]|0;Tb=u+(va+2<<2)|0;c[Tb>>2]=c[Sb>>2];c[Tb+4>>2]=Jb;Jb=f+5584|0;Tb=c[Jb+4>>2]|0;Sb=Vb+(Wb<<1)|0;va=u+(Sb<<2)|0;c[va>>2]=c[Jb>>2];c[va+4>>2]=Tb;Tb=f+5592|0;va=c[Tb+4>>2]|0;Jb=u+(Sb+2<<2)|0;c[Jb>>2]=c[Tb>>2];c[Jb+4>>2]=va;va=f+5616|0;Jb=c[va+4>>2]|0;Tb=Vb+(Wb*3|0)|0;Wb=u+(Tb<<2)|0;c[Wb>>2]=c[va>>2];c[Wb+4>>2]=Jb;Jb=f+5624|0;Wb=c[Jb+4>>2]|0;va=u+(Tb+2<<2)|0;c[va>>2]=c[Jb>>2];c[va+4>>2]=Wb;Wb=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;va=c[f+426588>>2]|0;Jb=va+(Wb<<1)|0;if((v&2048|0)==0){Tb=f+426744|0;u=c[Tb+4>>2]|0;Vb=Jb;c[Vb>>2]=c[Tb>>2];c[Vb+4>>2]=u;b[va+(Wb+6<<1)>>1]=b[f+426702>>1]|0;b[va+(Wb+5<<1)>>1]=b[f+426718>>1]|0;b[va+(Wb+4<<1)>>1]=b[f+426734>>1]|0}else{TGb(Jb|0,0,16)|0}Jb=c[f+4088>>2]|0;a[Jb+Ub|0]=a[f+5684|0]|0;a[Jb+(Ub|1)|0]=a[f+5686|0]|0;a[Jb+(Ub|2)|0]=a[f+5700|0]|0;a[Jb+(Ub|3)|0]=a[f+5702|0]|0}if((c[G>>2]|0)!=3){break}if((v&64|0)==0){break}v=c[F>>2]<<2;Ub=c[f+426752>>2]|0;a[Ub+(v|1)|0]=(e[f+177114>>1]|0)>>>1;a[Ub+(v|2)|0]=(e[f+177116>>1]|0)>>>1;a[Ub+(v|3)|0]=(e[f+177118>>1]|0)>>>1}}while(0);do{if((c[k>>2]&2|0)==0){G=f+426572|0;v=c[G>>2]|0;Ub=f+426568|0;Jb=c[Ub>>2]|0;Wb=f+425488|0;va=Ida(Wb,76-(Jb>>>2<<1&2|v>>>1&1)+(f+425536)|0)|0;u=((Ida(Wb,76-(Jb>>>3<<1&2|va&1)+(f+425536)|0)|0)<<1)+va|0;va=u+((Ida(Wb,76-(u<<1&2|v>>>3&1)+(f+425536)|0)|0)<<2)|0;v=va+((Ida(Wb,76-(va>>>2&1|va&2)+(f+425536)|0)|0)<<3)|0;if(!x){Xb=v;break}va=(c[G>>2]|0)>>>4&3;G=(c[Ub>>2]|0)>>>4&3;Ub=(va|0)!=0|0;if((Ida(Wb,((G|0)==0?Ub:Ub|2)+77+(f+425536)|0)|0)==0){Yb=0}else{Ub=(va|0)==2?5:4;Yb=((Ida(Wb,((G|0)==2?Ub|2:Ub)+77+(f+425536)|0)|0)<<4)+16|0}Xb=Yb|v}else{if(!(sa>>>0>15>>>0&(x^1))){Xb=sa;break}yDb(c[f>>2]|0,16,2324424,(Ja=i,i=i+1|0,i=i+7&-8,c[Ja>>2]=0,Ja)|0);i=Ja;oa=-1094995529;i=g;return oa|0}}while(0);c[f+426564>>2]=Xb;b[(c[f+426560>>2]|0)+(E<<1)>>1]=Xb;do{if((La|0)!=0){if((Xb&15|0)==0){break}if((c[k>>2]&7|0)!=0){break}sa=(Ida(f+425488|0,(c[f+5712>>2]|0)+399+(f+425536)|0)|0)<<24;c[k>>2]=c[k>>2]|sa}}while(0);La=c[k>>2]|0;do{if((c[w>>2]|0)==3){if((La&16777216|0)==0){break}sa=La&7;x=(sa|0)!=0?64:0;Yb=c[f+4872>>2]|0;if((Yb|0)!=0&(Yb&16777216|0)==0){a[f+5283|0]=x;a[f+5275|0]=x;a[f+5243|0]=x;a[f+5235|0]=x;a[f+5203|0]=x;a[f+5195|0]=x}Yb=c[f+4876>>2]|0;if((Yb|0)!=0&(Yb&16777216|0)==0){a[f+5299|0]=x;a[f+5291|0]=x;a[f+5259|0]=x;a[f+5251|0]=x;a[f+5219|0]=x;a[f+5211|0]=x}x=c[f+4864>>2]|0;if(!((x|0)!=0&(x&16777216|0)==0)){break}x=(sa|0)==0?0:1077952576;c[f+5188>>2]=x;c[f+5228>>2]=x;c[f+5268>>2]=x}}while(0);c[(c[f+4064>>2]|0)+(E<<2)>>2]=La;La=c[k>>2]|0;do{if((Xb|0)==0){if((La&2|0)!=0){I=492;break}c[f+5196>>2]=0;c[f+5204>>2]=0;c[f+5212>>2]=0;c[f+5220>>2]=0;c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;c[f+426580>>2]=0;Zb=f+4792|0}else{I=492}}while(0);j:do{if((I|0)==492){x=f+4792|0;sa=(c[x>>2]|0)!=0;if((La&128|0)==0){_b=sa?f+426812|0:f+427100|0;$b=sa?f+426796|0:f+427084|0}else{_b=sa?f+426956|0:f+427244|0;$b=sa?f+426940|0:f+427228|0}sa=_b|0;Yb=$b|0;v=f+425488|0;Ub=f+426580|0;if((Ida(v,((c[Ub>>2]|0)!=0|60)+(f+425536)|0)|0)==0){c[Ub>>2]=0;ac=c[x>>2]|0}else{G=(c[f+7308>>2]|0)*6|0;Wb=G+3|0;va=Wb<<1;u=62;Jb=1;while(1){if((Ida(v,f+425536+u|0)|0)==0){break}Vb=Jb+1|0;if((Vb|0)>(va|0)){I=499;break}else{u=63;Jb=Vb}}if((I|0)==499){u=c[B>>2]|0;yDb(c[f>>2]|0,16,2187800,(Ja=i,i=i+16|0,c[Ja>>2]=c[z>>2],c[Ja+8>>2]=u,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}u=Jb+1>>1;va=(Jb&1|0)==0?-u|0:u;c[Ub>>2]=va;u=(c[x>>2]|0)+va|0;c[x>>2]=u;do{if(u>>>0>Wb>>>0){va=G+4|0;if((u|0)<0){Vb=u+va|0;c[x>>2]=Vb;bc=Vb;break}else{Vb=u-va|0;c[x>>2]=Vb;bc=Vb;break}}else{bc=u}}while(0);c[f+4756>>2]=d[f+7876+bc|0]|0;c[f+4760>>2]=d[f+7964+bc|0]|0;ac=bc}u=c[k>>2]|0;do{if((u&2|0)==0){G=(u&7|0)!=0?0:3;Wb=(u&16777216|0)==0;Ub=f+177020+(G<<2)|0;Jb=f+177044+(G<<2)|0;G=0;do{k:do{if((1<<G&Xb|0)==0){Vb=d[473368+(G<<2)|0]|0;b[f+5184+Vb>>1]=0;b[Vb+8+(f+5184)>>1]=0}else{if(!Wb){Vb=G<<2;va=f+421200+(G<<6<<y<<1)|0;Tb=(c[Jb>>2]|0)+(ac<<8)|0;do{if((c[w>>2]|0)==3){Sb=d[473368+Vb|0]|0;t=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,(((a[Sb-8+(f+5184)|0]|0)!=0?t|2:t)|1012)+(f+425536)|0)|0)!=0){break}b[f+5184+Sb>>1]=0;b[Sb+8+(f+5184)>>1]=0;break k}}while(0);Oda(f,va,5,Vb,sa,Tb,64);break}L=(c[Ub>>2]|0)+(ac<<6)|0;K=G<<2;Sb=0;do{t=Sb+K|0;Kb=d[473368+t|0]|0;Rb=(a[Kb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,((a[Kb-8+(f+5184)|0]|0)!=0?Rb|2:Rb)+93+(f+425536)|0)|0)==0){a[f+5184+Kb|0]=0}else{Oda(f,f+421200+(t<<4<<y<<1)|0,2,t,Yb,L,16)}Sb=Sb+1|0;}while((Sb|0)<4)}}while(0);G=G+1|0;}while((G|0)<4)}else{G=f+424272|0;TGb(G|0,0,64)|0;Ub=(c[f+426572>>2]|0)>>>8&1;if((Mda(v,((c[f+426568>>2]&256|0)!=0?Ub|2:Ub)+85+(f+425536)|0)|0)==0){a[f+5184|0]=0}else{Nda(f,G,0,48,Yb,16)}if((Xb&15|0)==0){c[f+5196>>2]=0;c[f+5204>>2]=0;c[f+5212>>2]=0;c[f+5220>>2]=0;break}G=(c[f+177020>>2]|0)+(ac<<6)|0;Ub=$b+1|0;Jb=0;do{Wb=d[473368+Jb|0]|0;Sb=(a[Wb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,((a[Wb-8+(f+5184)|0]|0)!=0?Sb|2:Sb)+89+(f+425536)|0)|0)==0){a[f+5184+Wb|0]=0}else{Oda(f,f+421200+(Jb<<4<<y<<1)|0,1,Jb,Ub,G,15)}Jb=Jb+1|0;}while((Jb|0)<16)}}while(0);u=c[w>>2]|0;if((u|0)!=3){Jb=(Xb&48|0)!=0;if((u|0)!=2){do{if(Jb){u=f+426572|0;G=f+426568|0;Ub=(c[u>>2]|0)>>>6&1;if((Mda(v,((c[G>>2]&64|0)!=0?Ub|2:Ub)+97+(f+425536)|0)|0)==0){a[f+5224|0]=0}else{Nda(f,f+421200+(256<<y<<1)|0,3,49,1487200,4)}Ub=(c[u>>2]|0)>>>7&1;if((Mda(v,((c[G>>2]&128|0)!=0?Ub|2:Ub)+97+(f+425536)|0)|0)==0){a[f+5264|0]=0;break}else{Nda(f,f+421200+(512<<y<<1)|0,3,50,1487200,4);break}}}while(0);if((Xb&32|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;Zb=x;break}Ub=$b+1|0;G=(c[f+177020+(((c[k>>2]&7|0)!=0?1:4)<<2)>>2]|0)+(c[f+4756>>2]<<6)|0;u=0;do{Wb=u+16|0;Sb=d[473368+Wb|0]|0;L=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,((a[Sb-8+(f+5184)|0]|0)!=0?L|2:L)+101+(f+425536)|0)|0)==0){a[f+5184+Sb|0]=0}else{Oda(f,f+421200+(Wb<<4<<y<<1)|0,4,Wb,Ub,G,15)}u=u+1|0;}while((u|0)<4);u=(c[f+177020+(((c[k>>2]&7|0)!=0?2:5)<<2)>>2]|0)+(c[f+4760>>2]<<6)|0;G=0;while(1){Wb=G+32|0;Sb=d[473368+Wb|0]|0;L=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,((a[Sb-8+(f+5184)|0]|0)!=0?L|2:L)+101+(f+425536)|0)|0)==0){a[f+5184+Sb|0]=0}else{Oda(f,f+421200+(Wb<<4<<y<<1)|0,4,Wb,Ub,u,15)}Wb=G+1|0;if((Wb|0)<4){G=Wb}else{Zb=x;break j}}}do{if(Jb){G=f+426572|0;u=f+426568|0;Ub=(c[G>>2]|0)>>>6&1;if((Mda(v,((c[u>>2]&64|0)!=0?Ub|2:Ub)+97+(f+425536)|0)|0)==0){a[f+5224|0]=0}else{Pda(f,f+421200+(256<<y<<1)|0,49)}Ub=(c[G>>2]|0)>>>7&1;if((Mda(v,((c[u>>2]&128|0)!=0?Ub|2:Ub)+97+(f+425536)|0)|0)==0){a[f+5264|0]=0;break}else{Pda(f,f+421200+(512<<y<<1)|0,50);break}}}while(0);if((Xb&32|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;Zb=x;break}Jb=16<<y;Ub=$b+1|0;u=Jb<<2;G=0;while(1){Wb=(G<<4)+16|0;Sb=G+1|0;L=(c[f+177020+(((c[k>>2]&7|0)!=0?0:3)+Sb<<2)>>2]|0)+(c[f+4756+(G<<2)>>2]<<6)|0;K=0;Tb=f+421200+(Wb<<4<<y<<1)|0;while(1){Vb=(K<<3)+Wb|0;va=d[473368+Vb|0]|0;t=(a[va-1+(f+5184)|0]|0)!=0|0;if((Mda(v,((a[va-8+(f+5184)|0]|0)!=0?t|2:t)+101+(f+425536)|0)|0)==0){a[f+5184+va|0]=0}else{Oda(f,Tb,4,Vb,Ub,L,15)}va=Vb|1;t=d[473368+va|0]|0;Kb=(a[t-1+(f+5184)|0]|0)!=0|0;if((Mda(v,((a[t-8+(f+5184)|0]|0)!=0?Kb|2:Kb)+101+(f+425536)|0)|0)==0){a[f+5184+t|0]=0}else{Oda(f,Tb+(Jb<<1)|0,4,va,Ub,L,15)}va=Jb<<1;t=Vb|2;Kb=d[473368+t|0]|0;Rb=(a[Kb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,((a[Kb-8+(f+5184)|0]|0)!=0?Rb|2:Rb)+101+(f+425536)|0)|0)==0){a[f+5184+Kb|0]=0}else{Oda(f,Tb+(va<<1)|0,4,t,Ub,L,15)}t=Vb|3;Vb=d[473368+t|0]|0;Kb=(a[Vb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,((a[Vb-8+(f+5184)|0]|0)!=0?Kb|2:Kb)+101+(f+425536)|0)|0)==0){a[f+5184+Vb|0]=0}else{Oda(f,Tb+(va+Jb<<1)|0,4,t,Ub,L,15)}t=K+1|0;if((t|0)<2){K=t;Tb=Tb+(u<<1)|0}else{break}}if((Sb|0)<2){G=Sb}else{Zb=x;break j}}}G=c[k>>2]|0;u=c[f+4756>>2]|0;do{if((G&2|0)==0){Ub=(G&7|0)!=0?1:4;Jb=(G&16777216|0)==0;Tb=f+177020+(Ub<<2)|0;K=f+177044+(Ub<<2)|0;Ub=0;do{do{if((1<<Ub&Xb|0)==0){L=d[(Ub<<2)+473384|0]|0;b[f+5184+L>>1]=0;b[L+8+(f+5184)>>1]=0}else{if(!Jb){L=(Ub<<2)+16|0;Wb=c[K>>2]|0;t=d[473368+L|0]|0;va=(a[t-1+(f+5184)|0]|0)!=0|0;if((Mda(v,(((a[t-8+(f+5184)|0]|0)!=0?va|2:va)|1016)+(f+425536)|0)|0)==0){b[f+5184+t>>1]=0;b[t+8+(f+5184)>>1]=0;break}else{Oda(f,f+421200+(L<<4<<y<<1)|0,9,L,sa,Wb+(u<<8)|0,64);break}}Wb=(c[Tb>>2]|0)+(u<<6)|0;L=(Ub<<2)+16|0;t=0;do{va=L+t|0;Vb=d[473368+va|0]|0;Kb=(a[Vb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,(((a[Vb-8+(f+5184)|0]|0)!=0?Kb|2:Kb)|468)+(f+425536)|0)|0)==0){a[f+5184+Vb|0]=0}else{Oda(f,f+421200+(va<<4<<y<<1)|0,8,va,Yb,Wb,16)}t=t+1|0;}while((t|0)<4)}}while(0);Ub=Ub+1|0;}while((Ub|0)<4)}else{Ub=f+424336|0;TGb(Ub|0,0,64)|0;Tb=(c[f+426572>>2]|0)>>>9&1;if((Mda(v,(((c[f+426568>>2]&512|0)!=0?Tb|2:Tb)|460)+(f+425536)|0)|0)==0){a[f+5224|0]=0}else{Nda(f,Ub,6,49,Yb,16)}if((Xb&15|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;break}Ub=(c[f+177024>>2]|0)+(u<<6)|0;Tb=$b+1|0;K=0;do{Jb=K+16|0;Sb=d[473368+Jb|0]|0;t=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,(((a[Sb-8+(f+5184)|0]|0)!=0?t|2:t)|464)+(f+425536)|0)|0)==0){a[f+5184+Sb|0]=0}else{Oda(f,f+421200+(Jb<<4<<y<<1)|0,7,Jb,Tb,Ub,15)}K=K+1|0;}while((K|0)<16)}}while(0);u=c[k>>2]|0;G=c[f+4760>>2]|0;if((u&2|0)!=0){K=f+424400|0;TGb(K|0,0,64)|0;Ub=(c[f+426572>>2]|0)>>>10&1;if((Mda(v,(((c[f+426568>>2]&1024|0)!=0?Ub|2:Ub)|472)+(f+425536)|0)|0)==0){a[f+5264|0]=0}else{Nda(f,K,10,50,Yb,16)}if((Xb&15|0)==0){c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;Zb=x;break}K=(c[f+177028>>2]|0)+(G<<6)|0;Ub=$b+1|0;Tb=0;while(1){Jb=Tb+32|0;Sb=d[473368+Jb|0]|0;t=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,(((a[Sb-8+(f+5184)|0]|0)!=0?t|2:t)|476)+(f+425536)|0)|0)==0){a[f+5184+Sb|0]=0}else{Oda(f,f+421200+(Jb<<4<<y<<1)|0,11,Jb,Ub,K,15)}Jb=Tb+1|0;if((Jb|0)<16){Tb=Jb}else{Zb=x;break j}}}Tb=(u&7|0)!=0?2:5;K=(u&16777216|0)==0;Ub=f+177020+(Tb<<2)|0;Jb=f+177044+(Tb<<2)|0;Tb=0;while(1){do{if((1<<Tb&Xb|0)==0){Sb=d[(Tb<<2)+473400|0]|0;b[f+5184+Sb>>1]=0;b[Sb+8+(f+5184)>>1]=0}else{if(!K){Sb=(Tb<<2)+32|0;t=c[Jb>>2]|0;Wb=d[473368+Sb|0]|0;L=(a[Wb-1+(f+5184)|0]|0)!=0|0;if((Mda(v,(((a[Wb-8+(f+5184)|0]|0)!=0?L|2:L)|1020)+(f+425536)|0)|0)==0){b[f+5184+Wb>>1]=0;b[Wb+8+(f+5184)>>1]=0;break}else{Oda(f,f+421200+(Sb<<4<<y<<1)|0,13,Sb,sa,t+(G<<8)|0,64);break}}t=(c[Ub>>2]|0)+(G<<6)|0;Sb=(Tb<<2)+32|0;Wb=0;do{L=Sb+Wb|0;va=d[473368+L|0]|0;Vb=(a[va-1+(f+5184)|0]|0)!=0|0;if((Mda(v,(((a[va-8+(f+5184)|0]|0)!=0?Vb|2:Vb)|480)+(f+425536)|0)|0)==0){a[f+5184+va|0]=0}else{Oda(f,f+421200+(L<<4<<y<<1)|0,12,L,Yb,t,16)}Wb=Wb+1|0;}while((Wb|0)<4)}}while(0);Wb=Tb+1|0;if((Wb|0)<4){Tb=Wb}else{Zb=x;break}}}}while(0);a[(c[f+4040>>2]|0)+E|0]=c[Zb>>2];Zb=c[F>>2]|0;F=c[f+5304>>2]|0;c[F+(Zb*48|0)>>2]=c[f+5196>>2];c[F+(Zb*48|0)+4>>2]=c[f+5204>>2];c[F+(Zb*48|0)+8>>2]=c[f+5212>>2];c[F+(Zb*48|0)+12>>2]=c[f+5220>>2];c[F+(Zb*48|0)+16>>2]=c[f+5236>>2];c[F+(Zb*48|0)+20>>2]=c[f+5244>>2];c[F+(Zb*48|0)+32>>2]=c[f+5276>>2];c[F+(Zb*48|0)+36>>2]=c[f+5284>>2];if((c[f+4788>>2]|0)!=0){oa=0;i=g;return oa|0}c[F+(Zb*48|0)+24>>2]=c[f+5252>>2];c[F+(Zb*48|0)+28>>2]=c[f+5260>>2];c[F+(Zb*48|0)+40>>2]=c[f+5292>>2];c[F+(Zb*48|0)+44>>2]=c[f+5300>>2];oa=0;i=g;return oa|0}function Gda(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;do{if((c[a+177088>>2]|0)==0){f=c[a+427412>>2]|0;g=f-1|0;h=f-(c[a+427404>>2]<<((c[a+177100>>2]|0)!=3))|0}else{f=c[a+427404>>2]|0;i=(ba(f,d&-2)|0)+b|0;j=i-1|0;k=(d&1|0)!=0;do{if(k){if((e[(c[a+177072>>2]|0)+(j<<1)>>1]|0|0)!=(c[a+177068>>2]|0)){l=j;break}l=((c[a+177092>>2]|0)==((c[(c[a+4064>>2]|0)+(j<<2)>>2]|0)>>>7&1|0)?f:0)+j|0}else{l=j}}while(0);if((c[a+177092>>2]|0)==0){g=l;h=(ba(f,d-1|0)|0)+b|0;break}j=i-f|0;if(k){g=l;h=j;break}if((e[(c[a+177072>>2]|0)+(j<<1)>>1]|0|0)!=(c[a+177068>>2]|0)){g=l;h=j;break}g=l;h=j-((c[(c[a+4064>>2]|0)+(j<<2)>>2]&128|0)==0?0:f)|0}}while(0);l=c[a+177072>>2]|0;b=c[a+177068>>2]|0;if((e[l+(g<<1)>>1]|0|0)==(b|0)){m=(c[(c[a+4064>>2]|0)+(g<<2)>>2]|0)>>>11&1^1}else{m=0}if((e[l+(h<<1)>>1]|0|0)!=(b|0)){n=m;o=a+177080|0;p=c[o>>2]|0;q=(p|0)==3;r=n+13|0;s=q?r:n;t=a+425488|0;u=s+11|0;v=a+425536+u|0;w=Ida(t,v)|0;return w|0}n=((c[(c[a+4064>>2]|0)+(h<<2)>>2]|0)>>>11&1^1)+m|0;o=a+177080|0;p=c[o>>2]|0;q=(p|0)==3;r=n+13|0;s=q?r:n;t=a+425488|0;u=s+11|0;v=a+425536+u|0;w=Ida(t,v)|0;return w|0}function Hda(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[a+427412>>2]|0;f=a+4884|0;c[f>>2]=-1;g=c[a+427404>>2]|0;h=d-(g<<c[a+177092>>2])|0;i=h-1|0;j=h+1|0;k=d-1|0;l=a+4880|0;c[l>>2]=1068680;m=c[a+4064>>2]|0;do{if((c[a+177088>>2]|0)==0){n=i;o=h;p=k;q=k;r=j}else{s=c[m+(k<<2)>>2]&128;t=b&128;if((c[a+427380>>2]&1|0)!=0){if((s|0)==(t|0)){n=i;o=h;p=k;q=k;r=j;break}u=d-g-1|0;if((t|0)==0){c[f>>2]=0;c[l>>2]=1068712;n=g+i|0;o=h;p=u;q=u;r=j;break}else{c[l>>2]=1068776;n=i;o=h;p=u;q=k;r=j;break}}u=(t|0)!=0;if(u){v=(((c[m+(i<<2)>>2]|0)>>>7&1)-1&g)+i|0;w=(((c[m+(h<<2)>>2]|0)>>>7&1)-1&g)+h|0;x=(((c[m+(j<<2)>>2]|0)>>>7&1)-1&g)+j|0}else{v=i;w=h;x=j}if((s|0)==(t|0)){n=v;o=w;p=k;q=k;r=x;break}if(u){c[l>>2]=1068776;n=v;o=w;p=k;q=g+k|0;r=x;break}else{c[l>>2]=1068744;n=v;o=w;p=k;q=k;r=x;break}}}while(0);c[a+4840>>2]=n;c[a+4844>>2]=o;c[a+4848>>2]=r;c[a+4852>>2]=p;c[a+4856>>2]=q;x=a+4860|0;c[x>>2]=c[m+(n<<2)>>2];k=a+4864|0;c[k>>2]=c[m+(o<<2)>>2];w=a+4868|0;c[w>>2]=c[m+(r<<2)>>2];v=a+4872|0;c[v>>2]=c[m+(p<<2)>>2];l=a+4876|0;c[l>>2]=c[m+(q<<2)>>2];q=c[a+177072>>2]|0;m=e[q+(n<<1)>>1]|0;n=c[a+177068>>2]|0;do{if((m|0)==(n|0)){y=m}else{c[x>>2]=0;if((e[q+(o<<1)>>1]|0|0)!=(n|0)){c[k>>2]=0}if((e[q+(p<<1)>>1]|0|0)==(n|0)){y=n;break}c[l>>2]=0;c[v>>2]=0;y=n}}while(0);if((e[q+(r<<1)>>1]|0|0)==(y|0)){return}c[w>>2]=0;return}function Ida(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d[e]|0;g=b+4|0;h=c[g>>2]|0;i=d[1208480+((h<<1&384)+(f|512))|0]|0;j=h-i|0;h=j<<17;k=b|0;l=c[k>>2]|0;m=h-l>>31;c[k>>2]=l-(m&h);c[g>>2]=(m&i-j)+j;j=m^f;a[e]=a[j+1209632|0]|0;e=j&1;j=c[g>>2]|0;f=d[1208480+j|0]|0;c[g>>2]=j<<f;j=c[k>>2]<<f;c[k>>2]=j;if((j&65535|0)!=0){return e|0}f=b+16|0;b=c[f>>2]|0;c[k>>2]=(((d[b+1|0]|0)<<1|(d[b]|0)<<9)-65535<<7-(d[1208480+((j-1^j)>>15)|0]|0))+j;c[f>>2]=b+2;return e|0}function Jda(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=a+425536+b|0;do{if((e|0)==0){if((Ida(a+425488|0,f)|0)==0){g=0}else{h=f;break}return g|0}else{i=(c[a+4872>>2]&6|0)!=0;if((Ida(a+425488|0,((c[a+4864>>2]&6|0)==0?i&1:i?2:1)+b+(a+425536)|0)|0)==0){g=0;return g|0}else{h=b+2+(a+425536)|0;break}}}while(0);b=a+425488|0;f=a+425492|0;i=c[f>>2]|0;j=i-2|0;c[f>>2]=j;k=b|0;l=c[k>>2]|0;do{if((l|0)<(j<<17|0)){m=(i-258|0)>>>31;c[f>>2]=j<<m;n=l<<m;c[k>>2]=n;if((n&65535|0)!=0){break}m=a+425504|0;o=c[m>>2]|0;c[k>>2]=n-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9);c[m>>2]=o+2}else{if((c[a+425504>>2]|0)==(c[a+425500>>2]|0)){break}else{g=25}return g|0}}while(0);a=(Ida(b,h+1|0)|0)*12|0|1;if((Ida(b,h+2|0)|0)==0){p=a}else{p=a+4+((Ida(b,h+(e+2)|0)|0)<<2)|0}a=((Ida(b,h+(e+3)|0)|0)<<1)+p|0;g=a+(Ida(b,h+((e<<1)+3)|0)|0)|0;return g|0}function Kda(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[f+4880>>2]|0;m=c[f+4840>>2]|0;n=c[f+4844>>2]|0;o=c[f+4848>>2]|0;p=c[f+4852>>2]|0;c[j>>2]=p;q=c[f+4856>>2]|0;c[j+4>>2]=q;r=c[f+4860>>2]|0;s=c[f+4864>>2]|0;t=c[f+4868>>2]|0;u=c[f+4872>>2]|0;c[k>>2]=u;v=c[f+4876>>2]|0;c[k+4>>2]=v;do{if((g&2048|0)==0){w=(g&7|0)!=0;do{if(w){x=(c[f+7384>>2]|0)!=0?7:-1;y=f+5172|0;c[y>>2]=65535;z=f+5164|0;c[z>>2]=65535;A=f+5160|0;c[A>>2]=65535;B=f+5168|0;c[B>>2]=61162;C=(x&s|0)!=0;if(C){D=65535;E=60138}else{c[A>>2]=46079;c[z>>2]=13311;c[B>>2]=9962;D=46079;E=8938}z=g&128;do{if((z|0)==(u&128|0)){if((u&x|0)!=0){F=D;break}G=D&57183;c[A>>2]=G;c[y>>2]=24415;F=G}else{if((z|0)==0){if((c[(c[f+4064>>2]|0)+((c[f+427404>>2]|0)+p<<2)>>2]&x|0)!=0){if((u&x|0)!=0){F=D;break}}G=D&57183;c[A>>2]=G;c[y>>2]=24415;F=G;break}if((u&x|0)==0){G=D&57343;c[A>>2]=G;c[y>>2]=24575;H=G;I=24415}else{H=D;I=65375}if((v&x|0)!=0){F=H;break}G=H&65375;c[A>>2]=G;c[y>>2]=I;F=G}}while(0);if((x&r|0)==0){c[A>>2]=F&32767}if((x&t|0)==0){c[B>>2]=E}if((g&1|0)==0){break}if((s&1|0)==0){TGb(f+4892|0,2-(-(C&1^1)&3)&255|0,4)|0;J=f+4928|0;K=f+6104|0}else{y=f+4928|0;z=f+6104|0;c[f+4892>>2]=c[(c[y>>2]|0)+(c[(c[z>>2]|0)+(n<<2)>>2]|0)>>2];J=y;K=z}if((u&1|0)==0){z=2-(-((u&x|0)==0|0)&3)&255;a[f+4907|0]=z;a[f+4899|0]=z}else{z=c[J>>2]|0;y=(c[(c[K>>2]|0)+(p<<2)>>2]|0)+6|0;a[f+4899|0]=a[z+(y-(d[l]|0))|0]|0;a[f+4907|0]=a[z+(y-(d[l+1|0]|0))|0]|0}if((v&1|0)==0){y=2-(-((v&x|0)==0|0)&3)&255;a[f+4923|0]=y;a[f+4915|0]=y;break}else{y=c[J>>2]|0;z=(c[(c[K>>2]|0)+(q<<2)>>2]|0)+6|0;a[f+4915|0]=a[y+(z-(d[l+2|0]|0))|0]|0;a[f+4923|0]=a[y+(z-(d[l+3|0]|0))|0]|0;break}}}while(0);z=(s|0)!=0;do{if(z){y=f+5304|0;G=c[y>>2]|0;c[f+5188>>2]=c[G+(n*48|0)+12>>2];if((c[f+4788>>2]|0)==0){c[f+5228>>2]=c[G+(n*48|0)+28>>2];c[f+5268>>2]=c[G+(n*48|0)+44>>2];L=y;break}else{c[f+5228>>2]=c[G+(n*48|0)+20>>2];c[f+5268>>2]=c[G+(n*48|0)+36>>2];L=y;break}}else{y=w?1077952576:0;c[f+5188>>2]=y;c[f+5228>>2]=y;c[f+5268>>2]=y;L=f+5304|0}}while(0);y=w?64:0;G=f+6136|0;M=0;N=u;while(1){do{if((N|0)==0){O=M<<4;a[O+99+(f+5184)|0]=y;a[O+91+(f+5184)|0]=y;a[O+59+(f+5184)|0]=y;a[O+51+(f+5184)|0]=y;a[O+19+(f+5184)|0]=y;a[(O|11)+(f+5184)|0]=y}else{O=c[j+(M<<2)>>2]|0;P=c[L>>2]|0;Q=M<<1;R=l+(Q+8)|0;S=M<<4;a[(S|11)+(f+5184)|0]=a[(d[R]|0)+(P+(O*48|0))|0]|0;T=l+(Q+9)|0;a[S+19+(f+5184)|0]=a[(d[T]|0)+(P+(O*48|0))|0]|0;U=c[G>>2]|0;if((U|0)==3){a[S+51+(f+5184)|0]=a[(d[R]|0)+16+(P+(O*48|0))|0]|0;a[S+59+(f+5184)|0]=a[(d[T]|0)+16+(P+(O*48|0))|0]|0;a[S+91+(f+5184)|0]=a[(d[R]|0)+32+(P+(O*48|0))|0]|0;a[S+99+(f+5184)|0]=a[(d[T]|0)+32+(P+(O*48|0))|0]|0;break}else if((U|0)==2){a[S+51+(f+5184)|0]=a[(d[R]|0)+14+(P+(O*48|0))|0]|0;a[S+59+(f+5184)|0]=a[(d[T]|0)+14+(P+(O*48|0))|0]|0;a[S+91+(f+5184)|0]=a[(d[R]|0)+30+(P+(O*48|0))|0]|0;a[S+99+(f+5184)|0]=a[(d[T]|0)+30+(P+(O*48|0))|0]|0;break}else{T=M<<3;a[T+51+(f+5184)|0]=a[(d[l+(Q+12)|0]|0)+(P+(O*48|0))|0]|0;a[T+91+(f+5184)|0]=a[(d[l+(Q+13)|0]|0)+(P+(O*48|0))|0]|0;break}}}while(0);x=M+1|0;if((x|0)>=2){break}M=x;N=c[k+(x<<2)>>2]|0}if(z){c[f+426568>>2]=e[(c[f+426560>>2]|0)+(n<<1)>>1]|0}else{c[f+426568>>2]=w?1999:15}if((u|0)==0){c[f+426572>>2]=w?1999:15;break}else{N=c[f+426560>>2]|0;M=e[N+(p<<1)>>1]|0;c[f+426572>>2]=M>>>((a[l]&254)>>>0)&2|M&2032|(e[N+(q<<1)>>1]|0)>>>((a[l+2|0]&254)>>>0)<<2&8;break}}}while(0);do{if((g&120|0)==0){if((g&256|0)==0){V=s>>>24;W=V&1;X=u>>>24;Y=X&1;Z=Y+W|0;_=f+5712|0;c[_>>2]=Z;i=h;return}if((c[f+197872>>2]|0)!=0){break}V=s>>>24;W=V&1;X=u>>>24;Y=X&1;Z=Y+W|0;_=f+5712|0;c[_>>2]=Z;i=h;return}}while(0);k=c[f+6108>>2]|0;L=f+199428|0;if((c[L>>2]|0)==0){V=s>>>24;W=V&1;X=u>>>24;Y=X&1;Z=Y+W|0;_=f+5712|0;c[_>>2]=Z;i=h;return}j=f+6100|0;K=k*3|0;J=n<<2;E=J|2;F=J|3;J=(g&80|0)==0;I=(u|0)!=0?-1:-2;H=p<<2|1;D=(t|0)!=0?-1:-2;N=(r|0)!=0?-1:-2;M=f+4884|0;G=k<<1;y=k+3|0;x=m<<2;C=(g&2304|0)==0;B=f+6104|0;A=f+177080|0;O=f+426752|0;P=f+426768|0;Q=f+426776|0;T=f+426784|0;S=f+426792|0;R=(s&256|0)==0;U=(s&64|0)==0;$=f+426760|0;aa=$;ca=f+426762|0;da=(u&256|0)==0;ea=(u&64|0)==0;fa=f+426767|0;ga=(v&256|0)==0;ha=(v&64|0)==0;ia=f+426783|0;ja=q<<2|1;ka=l+2|0;la=l+3|0;ma=l+1|0;na=f+177088|0;oa=f+177092|0;pa=(r&128|0)!=0;qa=(s&128|0)!=0;ra=(t&128|0)==0;sa=(u&128|0)==0;ta=(v&128|0)==0;ua=o<<2|2;va=(s|0)!=0?-1:-16843010;wa=0;do{xa=c[f+4084+(wa<<2)>>2]|0;ya=c[f+4052+(wa<<2)>>2]|0;za=12288<<(wa<<1);do{if((za&g|0)!=0){Aa=(za&s|0)!=0;if(Aa){Ba=(c[(c[j>>2]|0)+(n<<2)>>2]|0)+K|0;Ca=ya+(Ba<<2)|0;Da=c[Ca+4>>2]|0;Ea=f+5312+(wa*160|0)+16|0;c[Ea>>2]=c[Ca>>2];c[Ea+4>>2]=Da;Da=ya+(Ba<<2)+8|0;Ba=c[Da+4>>2]|0;Ea=f+5312+(wa*160|0)+24|0;c[Ea>>2]=c[Da>>2];c[Ea+4>>2]=Ba;Ba=a[xa+E|0]|0;a[f+5632+(wa*40|0)+5|0]=Ba;a[f+5632+(wa*40|0)+4|0]=Ba;Ba=a[xa+F|0]|0;a[f+5632+(wa*40|0)+7|0]=Ba;a[f+5632+(wa*40|0)+6|0]=Ba}else{TGb(f+5312+(wa*160|0)+16|0,0,16)|0;c[f+5632+(wa*40|0)+4>>2]=va}Ba=(u&za|0)==0;do{if(J){if(Ba){c[f+5312+(wa*160|0)+44>>2]=0;a[f+5632+(wa*40|0)+11|0]=I;break}else{c[f+5312+(wa*160|0)+44>>2]=c[ya+((c[(c[j>>2]|0)+(p<<2)>>2]|0)+3+(ba(d[l]|0,k)|0)<<2)>>2];a[f+5632+(wa*40|0)+11|0]=a[xa+((a[l]&254)+H)|0]|0;break}}else{if(Ba){c[f+5312+(wa*160|0)+44>>2]=0;c[f+5312+(wa*160|0)+76>>2]=0;a[f+5632+(wa*40|0)+19|0]=I;a[f+5632+(wa*40|0)+11|0]=I}else{Ea=(c[(c[j>>2]|0)+(p<<2)>>2]|0)+3|0;c[f+5312+(wa*160|0)+44>>2]=c[ya+((ba(d[l]|0,k)|0)+Ea<<2)>>2];c[f+5312+(wa*160|0)+76>>2]=c[ya+((ba(d[ma]|0,k)|0)+Ea<<2)>>2];a[f+5632+(wa*40|0)+11|0]=a[xa+((a[l]&254)+H)|0]|0;a[f+5632+(wa*40|0)+19|0]=a[xa+((a[ma]&254)+H)|0]|0}if((v&za|0)==0){c[f+5312+(wa*160|0)+108>>2]=0;c[f+5312+(wa*160|0)+140>>2]=0;Ea=(v|0)!=0?-1:-2;a[f+5632+(wa*40|0)+35|0]=Ea;a[f+5632+(wa*40|0)+27|0]=Ea;break}else{Ea=(c[(c[j>>2]|0)+(q<<2)>>2]|0)+3|0;c[f+5312+(wa*160|0)+108>>2]=c[ya+((ba(d[ka]|0,k)|0)+Ea<<2)>>2];c[f+5312+(wa*160|0)+140>>2]=c[ya+((ba(d[la]|0,k)|0)+Ea<<2)>>2];a[f+5632+(wa*40|0)+27|0]=a[xa+((a[ka]&254)+ja)|0]|0;a[f+5632+(wa*40|0)+35|0]=a[xa+((a[la]&254)+ja)|0]|0;break}}}while(0);if((za&t|0)==0){c[f+5312+(wa*160|0)+32>>2]=0;a[f+5632+(wa*40|0)+8|0]=D;Fa=D}else{c[f+5312+(wa*160|0)+32>>2]=c[ya+((c[(c[j>>2]|0)+(o<<2)>>2]|0)+K<<2)>>2];Ba=a[xa+ua|0]|0;a[f+5632+(wa*40|0)+8|0]=Ba;Fa=Ba}Ba=f+5632+(wa*40|0)+6|0;do{if((a[Ba]|Fa)<<24>>24<0){if((za&r|0)==0){c[f+5312+(wa*160|0)+12>>2]=0;a[f+5632+(wa*40|0)+3|0]=N;break}else{Ea=c[M>>2]|0;c[f+5312+(wa*160|0)+12>>2]=c[ya+(y+(c[(c[j>>2]|0)+(m<<2)>>2]|0)+(Ea&G)<<2)>>2];a[f+5632+(wa*40|0)+3|0]=a[xa+(x|Ea&2|1)|0]|0;break}}}while(0);if(C){Ea=c[f+426584+(wa<<2)>>2]|0;a[f+5632+(wa*40|0)+30|0]=-2;a[f+5632+(wa*40|0)+14|0]=-2;c[f+5312+(wa*160|0)+56>>2]=0;c[f+5312+(wa*160|0)+120>>2]=0;if(Aa){Da=Ea+(c[(c[B>>2]|0)+(n<<2)>>2]<<1)|0;Ca=c[Da+4>>2]|0;Ga=f+426592+(wa*80|0)+8|0;c[Ga>>2]=c[Da>>2];c[Ga+4>>2]=Ca}else{Ca=f+426592+(wa*80|0)+8|0;c[Ca>>2]=0;c[Ca+4>>2]=0}if((u&za|0)==0){b[f+426592+(wa*80|0)+22>>1]=0;b[f+426592+(wa*80|0)+38>>1]=0}else{Ca=(c[(c[B>>2]|0)+(p<<2)>>2]|0)+6|0;b[f+426592+(wa*80|0)+22>>1]=b[Ea+(Ca-(d[l]|0)<<1)>>1]|0;b[f+426592+(wa*80|0)+38>>1]=b[Ea+(Ca-(d[ma]|0)<<1)>>1]|0}if((v&za|0)==0){b[f+426592+(wa*80|0)+54>>1]=0;b[f+426592+(wa*80|0)+70>>1]=0}else{Ca=(c[(c[B>>2]|0)+(q<<2)>>2]|0)+6|0;b[f+426592+(wa*80|0)+54>>1]=b[Ea+(Ca-(d[ka]|0)<<1)>>1]|0;b[f+426592+(wa*80|0)+70>>1]=b[Ea+(Ca-(d[la]|0)<<1)>>1]|0}b[f+426592+(wa*80|0)+28>>1]=0;b[f+426592+(wa*80|0)+60>>1]=0;do{if((c[A>>2]|0)==3){Ca=c[O>>2]|0;c[P>>2]=67372036;c[Q>>2]=67372036;c[T>>2]=67372036;c[S>>2]=67372036;do{if(R){if(U){c[aa>>2]=67372036;break}else{a[$]=a[Ca+E|0]|0;a[ca]=a[Ca+F|0]|0;break}}else{c[aa>>2]=-2139062144}}while(0);do{if(da){if(ea){a[fa]=4;break}else{a[fa]=a[Ca+((a[l]&254)+H)|0]|0;break}}else{a[fa]=-128}}while(0);if(!ga){a[ia]=-128;break}if(ha){a[ia]=4;break}else{a[ia]=a[Ca+((a[ka]&254)+ja)|0]|0;break}}}while(0);if((c[na>>2]|0)==0){break}}else{if((c[na>>2]|0)==0){break}}if((c[oa>>2]|0)==0){do{if(pa){Aa=f+5632+(wa*40|0)+3|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+14|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+7|0;a[Ea]=a[Ea]<<1}}while(0);do{if(qa){Ea=f+5632+(wa*40|0)+4|0;Aa=a[Ea]|0;if(Aa<<24>>24>-1){a[Ea]=Aa<<24>>24>>>1;Aa=f+5312+(wa*160|0)+18|0;b[Aa>>1]=b[Aa>>1]<<1;Aa=f+426592+(wa*80|0)+9|0;a[Aa]=a[Aa]<<1}Aa=f+5632+(wa*40|0)+5|0;Ea=a[Aa]|0;if(Ea<<24>>24>-1){a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+22|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+11|0;a[Ea]=a[Ea]<<1}Ea=a[Ba]|0;if(Ea<<24>>24>-1){a[Ba]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+26|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+13|0;a[Ea]=a[Ea]<<1}Ea=f+5632+(wa*40|0)+7|0;Aa=a[Ea]|0;if(!(Aa<<24>>24>-1)){break}a[Ea]=Aa<<24>>24>>>1;Aa=f+5312+(wa*160|0)+30|0;b[Aa>>1]=b[Aa>>1]<<1;Aa=f+426592+(wa*80|0)+15|0;a[Aa]=a[Aa]<<1}}while(0);do{if(!ra){Aa=f+5632+(wa*40|0)+8|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+34|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+17|0;a[Ea]=a[Ea]<<1}}while(0);do{if(!sa){Ea=f+5632+(wa*40|0)+11|0;Aa=a[Ea]|0;if(Aa<<24>>24>-1){a[Ea]=Aa<<24>>24>>>1;Aa=f+5312+(wa*160|0)+46|0;b[Aa>>1]=b[Aa>>1]<<1;Aa=f+426592+(wa*80|0)+23|0;a[Aa]=a[Aa]<<1;if(sa){break}}Aa=f+5632+(wa*40|0)+19|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+78|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+39|0;a[Ea]=a[Ea]<<1}}while(0);if(ta){break}Ea=f+5632+(wa*40|0)+27|0;Aa=a[Ea]|0;if(Aa<<24>>24>-1){a[Ea]=Aa<<24>>24>>>1;Aa=f+5312+(wa*160|0)+110|0;b[Aa>>1]=b[Aa>>1]<<1;Aa=f+426592+(wa*80|0)+55|0;a[Aa]=a[Aa]<<1;if(ta){break}}Aa=f+5632+(wa*40|0)+35|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+142|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+71|0;a[Ea]=a[Ea]<<1;break}else{do{if(!pa){Ea=f+5632+(wa*40|0)+3|0;Aa=a[Ea]|0;if(!(Aa<<24>>24>-1)){break}a[Ea]=Aa<<1;Aa=f+5312+(wa*160|0)+14|0;b[Aa>>1]=(b[Aa>>1]|0)/2|0;Aa=f+426592+(wa*80|0)+7|0;a[Aa]=(d[Aa]|0)>>>1}}while(0);do{if(!qa){Aa=f+5632+(wa*40|0)+4|0;Ea=a[Aa]|0;if(Ea<<24>>24>-1){a[Aa]=Ea<<1;Ea=f+5312+(wa*160|0)+18|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+9|0;a[Ea]=(d[Ea]|0)>>>1}Ea=f+5632+(wa*40|0)+5|0;Aa=a[Ea]|0;if(Aa<<24>>24>-1){a[Ea]=Aa<<1;Aa=f+5312+(wa*160|0)+22|0;b[Aa>>1]=(b[Aa>>1]|0)/2|0;Aa=f+426592+(wa*80|0)+11|0;a[Aa]=(d[Aa]|0)>>>1}Aa=a[Ba]|0;if(Aa<<24>>24>-1){a[Ba]=Aa<<1;Aa=f+5312+(wa*160|0)+26|0;b[Aa>>1]=(b[Aa>>1]|0)/2|0;Aa=f+426592+(wa*80|0)+13|0;a[Aa]=(d[Aa]|0)>>>1}Aa=f+5632+(wa*40|0)+7|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<1;Ea=f+5312+(wa*160|0)+30|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+15|0;a[Ea]=(d[Ea]|0)>>>1}}while(0);do{if(ra){Ba=f+5632+(wa*40|0)+8|0;Ea=a[Ba]|0;if(!(Ea<<24>>24>-1)){break}a[Ba]=Ea<<1;Ea=f+5312+(wa*160|0)+34|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+17|0;a[Ea]=(d[Ea]|0)>>>1}}while(0);do{if(sa){Ea=f+5632+(wa*40|0)+11|0;Ba=a[Ea]|0;if(Ba<<24>>24>-1){a[Ea]=Ba<<1;Ba=f+5312+(wa*160|0)+46|0;b[Ba>>1]=(b[Ba>>1]|0)/2|0;Ba=f+426592+(wa*80|0)+23|0;a[Ba]=(d[Ba]|0)>>>1}Ba=f+5632+(wa*40|0)+19|0;Ea=a[Ba]|0;if(!(Ea<<24>>24>-1)){break}a[Ba]=Ea<<1;Ea=f+5312+(wa*160|0)+78|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+39|0;a[Ea]=(d[Ea]|0)>>>1}}while(0);if(!ta){break}Ea=f+5632+(wa*40|0)+27|0;Ba=a[Ea]|0;if(Ba<<24>>24>-1){a[Ea]=Ba<<1;Ba=f+5312+(wa*160|0)+110|0;b[Ba>>1]=(b[Ba>>1]|0)/2|0;Ba=f+426592+(wa*80|0)+55|0;a[Ba]=(d[Ba]|0)>>>1}Ba=f+5632+(wa*40|0)+35|0;Ea=a[Ba]|0;if(!(Ea<<24>>24>-1)){break}a[Ba]=Ea<<1;Ea=f+5312+(wa*160|0)+142|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+71|0;a[Ea]=(d[Ea]|0)>>>1;break}}}while(0);wa=wa+1|0;}while(wa>>>0<(c[L>>2]|0)>>>0);V=s>>>24;W=V&1;X=u>>>24;Y=X&1;Z=Y+W|0;_=f+5712|0;c[_>>2]=Z;i=h;return}function Lda(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;h=a+425488|0;if((Mda(h,b+2+(e-3>>31)+(e-33>>31)+(a+425536)|0)|0)==0){c[f>>2]=0;j=0;i=g;return j|0}do{if((Mda(h,b+3+(a+425536)|0)|0)==0){k=1;l=17}else{if((Mda(h,b+4+(a+425536)|0)|0)==0){k=2;l=17;break}if((Mda(h,b+5+(a+425536)|0)|0)==0){k=3;l=17;break}e=b+6+(a+425536)|0;if((Mda(h,e)|0)==0){k=4;l=17;break}if((Mda(h,e)|0)==0){k=5;l=17;break}if((Mda(h,e)|0)==0){k=6;l=17;break}if((Mda(h,e)|0)==0){k=7;l=17;break}if((Mda(h,e)|0)==0){k=8;l=17;break}e=h|0;m=a+425504|0;n=a+425492|0;o=3;p=9;q=c[e>>2]|0;while(1){r=q<<1;c[e>>2]=r;if((r&65534|0)==0){s=c[m>>2]|0;t=r-65535+((d[s+1|0]|0)<<1|(d[s]|0)<<9)|0;c[e>>2]=t;c[m>>2]=s+2;u=t}else{u=r}v=c[n>>2]<<17;if((u|0)<(v|0)){break}r=u-v|0;c[e>>2]=r;t=(1<<o)+p|0;s=o+1|0;if((s|0)>24){l=10;break}else{o=s;p=t;q=r}}if((l|0)==10){yDb(c[a>>2]|0,16,2110464,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=-2147483648;i=g;return j|0}if((o|0)==0){w=p}else{q=p;n=o;r=u;while(1){t=n-1|0;s=r<<1;c[e>>2]=s;if((s&65534|0)==0){x=c[m>>2]|0;y=s-65535+((d[x+1|0]|0)<<1|(d[x]|0)<<9)|0;c[e>>2]=y;c[m>>2]=x+2;z=y}else{z=s}if((z|0)<(v|0)){A=0;B=z}else{s=z-v|0;c[e>>2]=s;A=1;B=s}s=(A<<t)+q|0;if((t|0)==0){w=s;break}else{q=s;n=t;r=B}}}C=w;D=(w|0)<70?w:70;E=e}}while(0);if((l|0)==17){C=k;D=k;E=h|0}c[f>>2]=D;D=c[E>>2]<<1;c[E>>2]=D;if((D&65534|0)==0){f=a+425504|0;h=c[f>>2]|0;k=D-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[E>>2]=k;c[f>>2]=h+2;F=k}else{F=D}D=c[a+425492>>2]<<17;a=F-D|0;F=a>>31;c[E>>2]=(F&D)+a;j=(F^-C)-F|0;i=g;return j|0}function Mda(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d[e]|0;g=b+4|0;h=c[g>>2]|0;i=d[1208480+((h<<1&384)+(f|512))|0]|0;j=h-i|0;h=j<<17;k=b|0;l=c[k>>2]|0;m=h-l>>31;c[k>>2]=l-(m&h);c[g>>2]=(m&i-j)+j;j=m^f;a[e]=a[j+1209632|0]|0;e=j&1;j=c[g>>2]|0;f=d[1208480+j|0]|0;c[g>>2]=j<<f;j=c[k>>2]<<f;c[k>>2]=j;if((j&65535|0)!=0){return e|0}f=b+16|0;b=c[f>>2]|0;c[k>>2]=(((d[b+1|0]|0)<<1|(d[b]|0)<<9)-65535<<7-(d[1208480+((j-1^j)>>15)|0]|0))+j;c[f>>2]=b+2;return e|0}function Nda(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;m=i;i=i+256|0;n=m|0;o=f+425492|0;p=c[o>>2]|0;q=f+425488|0;r=c[q>>2]|0;s=f+425504|0;t=c[s>>2]|0;u=c[f+177092>>2]|0;v=c[1403560+(u*56|0)+(h<<2)>>2]|0;w=c[1403680+(u*56|0)+(h<<2)>>2]|0;u=c[1403824+(h<<2)>>2]|0;x=l-1|0;a:do{if((x|0)>0){l=t;y=p;z=r;A=0;B=0;while(1){C=B+v+(f+425536)|0;D=d[C]|0;E=d[1208480+((D|512)+(y<<1&384))|0]|0;F=y-E|0;G=F<<17;H=G-z>>31;I=(H&E-F)+F|0;F=H^D;a[C]=a[F+1209632|0]|0;C=d[1208480+I|0]|0;D=I<<C;I=z-(H&G)<<C;if((I&65535|0)==0){J=(((d[l+1|0]|0)<<1|(d[l]|0)<<9)-65535<<7-(d[1208480+((I-1^I)>>15)|0]|0))+I|0;K=l+2|0}else{J=I;K=l}if((F&1|0)==0){L=A;M=J;N=D;O=K}else{F=B+w+(f+425536)|0;I=A+1|0;c[n+(A<<2)>>2]=B;C=d[F]|0;G=d[1208480+((C|512)+(D<<1&384))|0]|0;H=D-G|0;D=H<<17;E=D-J>>31;P=(E&G-H)+H|0;H=E^C;a[F]=a[H+1209632|0]|0;F=d[1208480+P|0]|0;C=P<<F;P=J-(E&D)<<F;if((P&65535|0)==0){Q=(((d[K+1|0]|0)<<1|(d[K]|0)<<9)-65535<<7-(d[1208480+((P-1^P)>>15)|0]|0))+P|0;R=K+2|0}else{Q=P;R=K}if((H&1|0)==0){L=I;M=Q;N=C;O=R}else{S=I;T=Q;U=C;V=R;break a}}C=B+1|0;if((C|0)<(x|0)){l=O;y=N;z=M;A=L;B=C}else{W=O;X=N;Y=M;Z=L;_=C;$=9;break}}}else{W=t;X=p;Y=r;Z=0;_=0;$=9}}while(0);do{if(($|0)==9){if((_|0)!=(x|0)){S=Z;T=Y;U=X;V=W;break}c[n+(Z<<2)>>2]=x;S=Z+1|0;T=Y;U=X;V=W}}while(0);if((h|0)==3){h=(c[f+426560>>2]|0)+(c[f+427412>>2]<<1)|0;b[h>>1]=e[h>>1]|0|64<<j-49}else{h=(c[f+426560>>2]|0)+(c[f+427412>>2]<<1)|0;b[h>>1]=e[h>>1]|0|256<<j-48}a[(d[473368+j|0]|0)+(f+5184)|0]=S;if((c[f+4752>>2]|0)==0){j=S;h=0;W=T;X=U;Y=V;while(1){Z=(d[1403880+h|0]|0)+u+(f+425536)|0;x=j-1|0;_=d[k+(c[n+(x<<2)>>2]|0)|0]|0;r=d[Z]|0;p=d[1208480+((r|512)+(X<<1&384))|0]|0;t=X-p|0;L=t<<17;M=L-W>>31;N=(M&p-t)+t|0;t=M^r;a[Z]=a[t+1209632|0]|0;Z=d[1208480+N|0]|0;r=N<<Z;N=W-(M&L)<<Z;if((N&65535|0)==0){aa=(((d[Y+1|0]|0)<<1|(d[Y]|0)<<9)-65535<<7-(d[1208480+((N-1^N)>>15)|0]|0))+N|0;ba=Y+2|0}else{aa=N;ba=Y}if((t&1|0)==0){t=a[1403808+h|0]|0;N=aa<<1;if((N&65534|0)==0){ca=N-65535+((d[ba+1|0]|0)<<1|(d[ba]|0)<<9)|0;da=ba+2|0}else{ca=N;da=ba}N=r<<17;Z=ca-N|0;L=Z>>31;b[g+(_<<1)>>1]=(L^65535)-L;ea=t;fa=(L&N)+Z|0;ga=r;ha=da}else{Z=(d[1403792+h|0]|0)+u+(f+425536)|0;N=a[1403816+h|0]|0;L=2;t=aa;M=r;r=ba;while(1){if((L|0)>=15){ia=t;ja=r;ka=M;$=54;break}p=d[Z]|0;O=d[1208480+((p|512)+(M<<1&384))|0]|0;R=M-O|0;Q=R<<17;K=Q-t>>31;J=(K&O-R)+R|0;R=K^p;a[Z]=a[R+1209632|0]|0;p=d[1208480+J|0]|0;la=J<<p;J=t-(K&Q)<<p;if((J&65535|0)==0){ma=(((d[r+1|0]|0)<<1|(d[r]|0)<<9)-65535<<7-(d[1208480+((J-1^J)>>15)|0]|0))+J|0;na=r+2|0}else{ma=J;na=r}if((R&1|0)==0){$=53;break}else{L=L+1|0;t=ma;M=la;r=na}}if(($|0)==53){$=0;if((L|0)>14){ia=ma;ja=na;ka=la;$=54}else{oa=L;pa=ma;qa=na;ra=la}}do{if(($|0)==54){$=0;r=ka<<17;M=0;t=ia;Z=ja;while(1){R=t<<1;if((R&65534|0)==0){sa=R-65535+((d[Z+1|0]|0)<<1|(d[Z]|0)<<9)|0;ta=Z+2|0}else{sa=R;ta=Z}if((sa|0)<(r|0)){$=59;break}R=sa-r|0;if((M|0)<30){M=M+1|0;t=R;Z=ta}else{ua=ta;va=R;wa=1;xa=M;break}}if(($|0)==59){$=0;if((M|0)==0){oa=15;pa=sa;qa=ta;ra=ka;break}else{ua=ta;va=sa;wa=1;xa=M}}while(1){Z=xa-1|0;t=va<<1;if((t&65534|0)==0){ya=t-65535+((d[ua+1|0]|0)<<1|(d[ua]|0)<<9)|0;za=ua+2|0}else{ya=t;za=ua}t=(ya|0)<(r|0);Aa=ya-(t?0:r)|0;Ba=(t&1|wa<<1)^1;if((Z|0)==0){break}else{ua=za;va=Aa;wa=Ba;xa=Z}}oa=Ba+14|0;pa=Aa;qa=za;ra=ka}}while(0);L=pa<<1;if((L&65534|0)==0){Ca=L-65535+((d[qa+1|0]|0)<<1|(d[qa]|0)<<9)|0;Da=qa+2|0}else{Ca=L;Da=qa}L=ra<<17;r=Ca-L|0;M=r>>31;b[g+(_<<1)>>1]=(M^-oa)-M;ea=N;fa=(M&L)+r|0;ga=ra;ha=Da}if((x|0)==0){Ea=fa;Fa=ga;Ga=ha;break}else{j=x;h=ea&255;W=fa;X=ga;Y=ha}}c[o>>2]=Fa;c[q>>2]=Ea;c[s>>2]=Ga;i=m;return}ha=g;g=S;S=0;Y=T;T=U;U=V;while(1){V=(d[1403880+S|0]|0)+u+(f+425536)|0;ga=g-1|0;X=d[k+(c[n+(ga<<2)>>2]|0)|0]|0;fa=d[V]|0;W=d[1208480+((fa|512)+(T<<1&384))|0]|0;ea=T-W|0;h=ea<<17;j=h-Y>>31;Da=(j&W-ea)+ea|0;ea=j^fa;a[V]=a[ea+1209632|0]|0;V=d[1208480+Da|0]|0;fa=Da<<V;Da=Y-(j&h)<<V;if((Da&65535|0)==0){Ha=(((d[U+1|0]|0)<<1|(d[U]|0)<<9)-65535<<7-(d[1208480+((Da-1^Da)>>15)|0]|0))+Da|0;Ia=U+2|0}else{Ha=Da;Ia=U}if((ea&1|0)==0){ea=a[1403808+S|0]|0;Da=Ha<<1;if((Da&65534|0)==0){Ja=Da-65535+((d[Ia+1|0]|0)<<1|(d[Ia]|0)<<9)|0;Ka=Ia+2|0}else{Ja=Da;Ka=Ia}Da=fa<<17;V=Ja-Da|0;h=V>>31;c[ha+(X<<2)>>2]=~h-h;La=ea;Ma=(h&Da)+V|0;Na=fa;Oa=Ka}else{V=(d[1403792+S|0]|0)+u+(f+425536)|0;Da=a[1403816+S|0]|0;h=2;ea=Ha;j=fa;fa=Ia;while(1){if((h|0)>=15){Pa=ea;Qa=fa;Ra=j;$=28;break}W=d[V]|0;ra=d[1208480+((W|512)+(j<<1&384))|0]|0;oa=j-ra|0;Ca=oa<<17;qa=Ca-ea>>31;pa=(qa&ra-oa)+oa|0;oa=qa^W;a[V]=a[oa+1209632|0]|0;W=d[1208480+pa|0]|0;Sa=pa<<W;pa=ea-(qa&Ca)<<W;if((pa&65535|0)==0){Ta=(((d[fa+1|0]|0)<<1|(d[fa]|0)<<9)-65535<<7-(d[1208480+((pa-1^pa)>>15)|0]|0))+pa|0;Ua=fa+2|0}else{Ta=pa;Ua=fa}if((oa&1|0)==0){$=27;break}else{h=h+1|0;ea=Ta;j=Sa;fa=Ua}}if(($|0)==27){$=0;if((h|0)>14){Pa=Ta;Qa=Ua;Ra=Sa;$=28}else{Va=h;Wa=Ta;Xa=Ua;Ya=Sa}}do{if(($|0)==28){$=0;fa=Ra<<17;j=0;ea=Pa;V=Qa;while(1){x=ea<<1;if((x&65534|0)==0){Za=x-65535+((d[V+1|0]|0)<<1|(d[V]|0)<<9)|0;_a=V+2|0}else{Za=x;_a=V}if((Za|0)<(fa|0)){$=33;break}x=Za-fa|0;if((j|0)<30){j=j+1|0;ea=x;V=_a}else{$a=_a;ab=x;bb=1;cb=j;break}}if(($|0)==33){$=0;if((j|0)==0){Va=15;Wa=Za;Xa=_a;Ya=Ra;break}else{$a=_a;ab=Za;bb=1;cb=j}}while(1){V=cb-1|0;ea=ab<<1;if((ea&65534|0)==0){db=ea-65535+((d[$a+1|0]|0)<<1|(d[$a]|0)<<9)|0;eb=$a+2|0}else{db=ea;eb=$a}ea=(db|0)<(fa|0);fb=db-(ea?0:fa)|0;gb=(ea&1|bb<<1)^1;if((V|0)==0){break}else{$a=eb;ab=fb;bb=gb;cb=V}}Va=gb+14|0;Wa=fb;Xa=eb;Ya=Ra}}while(0);h=Wa<<1;if((h&65534|0)==0){hb=h-65535+((d[Xa+1|0]|0)<<1|(d[Xa]|0)<<9)|0;ib=Xa+2|0}else{hb=h;ib=Xa}h=Ya<<17;fa=hb-h|0;j=fa>>31;c[ha+(X<<2)>>2]=(j^-Va)-j;La=Da;Ma=(j&h)+fa|0;Na=Ya;Oa=ib}if((ga|0)==0){Ea=Ma;Fa=Na;Ga=Oa;break}else{g=ga;S=La&255;Y=Ma;T=Na;U=Oa}}c[o>>2]=Fa;c[q>>2]=Ea;c[s>>2]=Ga;i=m;return}function Oda(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0;m=i;i=i+256|0;n=m|0;o=e+425492|0;p=c[o>>2]|0;q=e+425488|0;r=c[q>>2]|0;s=e+425504|0;t=c[s>>2]|0;u=c[e+177092>>2]|0;v=c[1403560+(u*56|0)+(g<<2)>>2]|0;w=c[1403680+(u*56|0)+(g<<2)>>2]|0;x=c[1403824+(g<<2)>>2]|0;g=(l|0)==64;a:do{if(g){y=t;z=p;A=r;B=0;C=0;while(1){D=(d[1403432+(u*63|0)+C|0]|0)+v+(e+425536)|0;E=d[D]|0;F=d[1208480+((E|512)+(z<<1&384))|0]|0;G=z-F|0;H=G<<17;I=H-A>>31;J=(I&F-G)+G|0;G=I^E;a[D]=a[G+1209632|0]|0;D=d[1208480+J|0]|0;E=J<<D;J=A-(I&H)<<D;if((J&65535|0)==0){K=(((d[y+1|0]|0)<<1|(d[y]|0)<<9)-65535<<7-(d[1208480+((J-1^J)>>15)|0]|0))+J|0;L=y+2|0}else{K=J;L=y}if((G&1|0)==0){M=B;N=K;O=E;P=L}else{G=(d[C+1209760|0]|0)+w+(e+425536)|0;J=B+1|0;c[n+(B<<2)>>2]=C;D=d[G]|0;H=d[1208480+((D|512)+(E<<1&384))|0]|0;I=E-H|0;E=I<<17;F=E-K>>31;Q=(F&H-I)+I|0;I=F^D;a[G]=a[I+1209632|0]|0;G=d[1208480+Q|0]|0;D=Q<<G;Q=K-(F&E)<<G;if((Q&65535|0)==0){R=(((d[L+1|0]|0)<<1|(d[L]|0)<<9)-65535<<7-(d[1208480+((Q-1^Q)>>15)|0]|0))+Q|0;S=L+2|0}else{R=Q;S=L}if((I&1|0)==0){M=J;N=R;O=D;P=S}else{T=J;U=R;V=D;W=S;break a}}X=C+1|0;if((X|0)<63){y=P;z=O;A=N;B=M;C=X}else{break}}if((X|0)!=63){T=M;U=N;V=O;W=P;break}c[n+(M<<2)>>2]=63;T=M+1|0;U=N;V=O;W=P}else{C=l-1|0;if((C|0)>0){B=t;A=p;z=r;y=0;D=0;while(1){J=D+v+(e+425536)|0;I=d[J]|0;Q=d[1208480+((I|512)+(A<<1&384))|0]|0;G=A-Q|0;E=G<<17;F=E-z>>31;H=(F&Q-G)+G|0;G=F^I;a[J]=a[G+1209632|0]|0;J=d[1208480+H|0]|0;I=H<<J;H=z-(F&E)<<J;if((H&65535|0)==0){Y=(((d[B+1|0]|0)<<1|(d[B]|0)<<9)-65535<<7-(d[1208480+((H-1^H)>>15)|0]|0))+H|0;Z=B+2|0}else{Y=H;Z=B}if((G&1|0)==0){_=y;$=Y;aa=I;ca=Z}else{G=D+w+(e+425536)|0;H=y+1|0;c[n+(y<<2)>>2]=D;J=d[G]|0;E=d[1208480+((J|512)+(I<<1&384))|0]|0;F=I-E|0;I=F<<17;Q=I-Y>>31;da=(Q&E-F)+F|0;F=Q^J;a[G]=a[F+1209632|0]|0;G=d[1208480+da|0]|0;J=da<<G;da=Y-(Q&I)<<G;if((da&65535|0)==0){ea=(((d[Z+1|0]|0)<<1|(d[Z]|0)<<9)-65535<<7-(d[1208480+((da-1^da)>>15)|0]|0))+da|0;fa=Z+2|0}else{ea=da;fa=Z}if((F&1|0)==0){_=H;$=ea;aa=J;ca=fa}else{T=H;U=ea;V=J;W=fa;break a}}J=D+1|0;if((J|0)<(C|0)){B=ca;A=aa;z=$;y=_;D=J}else{ga=ca;ha=aa;ia=$;ja=_;ka=J;break}}}else{ga=t;ha=p;ia=r;ja=0;ka=0}if((ka|0)!=(C|0)){T=ja;U=ia;V=ha;W=ga;break}c[n+(ja<<2)>>2]=C;T=ja+1|0;U=ia;V=ha;W=ga}}while(0);if(g){g=d[473368+h|0]|0;ga=(T*257|0)&65535;b[e+5184+g>>1]=ga;b[g+8+(e+5184)>>1]=ga}else{a[(d[473368+h|0]|0)+(e+5184)|0]=T}if((c[e+4752>>2]|0)==0){h=T;ga=0;g=U;ha=V;ia=W;while(1){ja=(d[1403880+ga|0]|0)+x+(e+425536)|0;ka=h-1|0;r=d[j+(c[n+(ka<<2)>>2]|0)|0]|0;p=d[ja]|0;t=d[1208480+((p|512)+(ha<<1&384))|0]|0;_=ha-t|0;$=_<<17;aa=$-g>>31;ca=(aa&t-_)+_|0;_=aa^p;a[ja]=a[_+1209632|0]|0;ja=d[1208480+ca|0]|0;p=ca<<ja;ca=g-(aa&$)<<ja;if((ca&65535|0)==0){la=(((d[ia+1|0]|0)<<1|(d[ia]|0)<<9)-65535<<7-(d[1208480+((ca-1^ca)>>15)|0]|0))+ca|0;ma=ia+2|0}else{la=ca;ma=ia}if((_&1|0)==0){_=a[1403808+ga|0]|0;ca=la<<1;if((ca&65534|0)==0){na=ca-65535+((d[ma+1|0]|0)<<1|(d[ma]|0)<<9)|0;oa=ma+2|0}else{na=ca;oa=ma}ca=p<<17;ja=na-ca|0;$=ja>>31;b[f+(r<<1)>>1]=((ja>>>31|32)+($^-(c[k+(r<<2)>>2]|0))|0)>>>6;pa=_;qa=($&ca)+ja|0;ra=p;sa=oa}else{ja=(d[1403792+ga|0]|0)+x+(e+425536)|0;ca=a[1403816+ga|0]|0;$=2;_=la;aa=p;p=ma;while(1){if(($|0)>=15){ta=_;ua=p;va=aa;wa=64;break}t=d[ja]|0;fa=d[1208480+((t|512)+(aa<<1&384))|0]|0;ea=aa-fa|0;Z=ea<<17;Y=Z-_>>31;w=(Y&fa-ea)+ea|0;ea=Y^t;a[ja]=a[ea+1209632|0]|0;t=d[1208480+w|0]|0;xa=w<<t;w=_-(Y&Z)<<t;if((w&65535|0)==0){ya=(((d[p+1|0]|0)<<1|(d[p]|0)<<9)-65535<<7-(d[1208480+((w-1^w)>>15)|0]|0))+w|0;za=p+2|0}else{ya=w;za=p}if((ea&1|0)==0){wa=63;break}else{$=$+1|0;_=ya;aa=xa;p=za}}if((wa|0)==63){wa=0;if(($|0)>14){ta=ya;ua=za;va=xa;wa=64}else{Aa=$;Ba=ya;Ca=za;Da=xa}}do{if((wa|0)==64){wa=0;p=va<<17;aa=0;_=ta;ja=ua;while(1){C=_<<1;if((C&65534|0)==0){Ea=C-65535+((d[ja+1|0]|0)<<1|(d[ja]|0)<<9)|0;Fa=ja+2|0}else{Ea=C;Fa=ja}if((Ea|0)<(p|0)){wa=69;break}C=Ea-p|0;if((aa|0)<30){aa=aa+1|0;_=C;ja=Fa}else{Ga=Fa;Ha=C;Ia=1;Ja=aa;break}}if((wa|0)==69){wa=0;if((aa|0)==0){Aa=15;Ba=Ea;Ca=Fa;Da=va;break}else{Ga=Fa;Ha=Ea;Ia=1;Ja=aa}}while(1){ja=Ja-1|0;_=Ha<<1;if((_&65534|0)==0){Ka=_-65535+((d[Ga+1|0]|0)<<1|(d[Ga]|0)<<9)|0;La=Ga+2|0}else{Ka=_;La=Ga}_=(Ka|0)<(p|0);Ma=Ka-(_?0:p)|0;Na=(_&1|Ia<<1)^1;if((ja|0)==0){break}else{Ga=La;Ha=Ma;Ia=Na;Ja=ja}}Aa=Na+14|0;Ba=Ma;Ca=La;Da=va}}while(0);$=Ba<<1;if(($&65534|0)==0){Oa=$-65535+((d[Ca+1|0]|0)<<1|(d[Ca]|0)<<9)|0;Pa=Ca+2|0}else{Oa=$;Pa=Ca}$=Da<<17;p=Oa-$|0;aa=p>>31;b[f+(r<<1)>>1]=((ba((aa^-Aa)-aa|0,c[k+(r<<2)>>2]|0)|0)+32|0)>>>6;pa=ca;qa=(aa&$)+p|0;ra=Da;sa=Pa}if((ka|0)==0){Qa=qa;Ra=ra;Sa=sa;break}else{h=ka;ga=pa&255;g=qa;ha=ra;ia=sa}}c[o>>2]=Ra;c[q>>2]=Qa;c[s>>2]=Sa;i=m;return}sa=f;f=T;T=0;ia=U;U=V;V=W;while(1){W=(d[1403880+T|0]|0)+x+(e+425536)|0;ra=f-1|0;ha=d[j+(c[n+(ra<<2)>>2]|0)|0]|0;qa=d[W]|0;g=d[1208480+((qa|512)+(U<<1&384))|0]|0;pa=U-g|0;ga=pa<<17;h=ga-ia>>31;Pa=(h&g-pa)+pa|0;pa=h^qa;a[W]=a[pa+1209632|0]|0;W=d[1208480+Pa|0]|0;qa=Pa<<W;Pa=ia-(h&ga)<<W;if((Pa&65535|0)==0){Ta=(((d[V+1|0]|0)<<1|(d[V]|0)<<9)-65535<<7-(d[1208480+((Pa-1^Pa)>>15)|0]|0))+Pa|0;Ua=V+2|0}else{Ta=Pa;Ua=V}if((pa&1|0)==0){pa=a[1403808+T|0]|0;Pa=Ta<<1;if((Pa&65534|0)==0){Va=Pa-65535+((d[Ua+1|0]|0)<<1|(d[Ua]|0)<<9)|0;Wa=Ua+2|0}else{Va=Pa;Wa=Ua}Pa=qa<<17;W=Va-Pa|0;ga=W>>31;c[sa+(ha<<2)>>2]=(W>>>31|32)+(ga^-(c[k+(ha<<2)>>2]|0))>>6;Xa=pa;Ya=(ga&Pa)+W|0;Za=qa;_a=Wa}else{W=(d[1403792+T|0]|0)+x+(e+425536)|0;Pa=a[1403816+T|0]|0;ga=2;pa=Ta;h=qa;qa=Ua;while(1){if((ga|0)>=15){$a=pa;ab=qa;bb=h;wa=38;break}g=d[W]|0;Da=d[1208480+((g|512)+(h<<1&384))|0]|0;Aa=h-Da|0;Oa=Aa<<17;Ca=Oa-pa>>31;Ba=(Ca&Da-Aa)+Aa|0;Aa=Ca^g;a[W]=a[Aa+1209632|0]|0;g=d[1208480+Ba|0]|0;cb=Ba<<g;Ba=pa-(Ca&Oa)<<g;if((Ba&65535|0)==0){db=(((d[qa+1|0]|0)<<1|(d[qa]|0)<<9)-65535<<7-(d[1208480+((Ba-1^Ba)>>15)|0]|0))+Ba|0;eb=qa+2|0}else{db=Ba;eb=qa}if((Aa&1|0)==0){wa=37;break}else{ga=ga+1|0;pa=db;h=cb;qa=eb}}if((wa|0)==37){wa=0;if((ga|0)>14){$a=db;ab=eb;bb=cb;wa=38}else{fb=ga;gb=db;hb=eb;ib=cb}}do{if((wa|0)==38){wa=0;qa=bb<<17;h=0;pa=$a;W=ab;while(1){ka=pa<<1;if((ka&65534|0)==0){jb=ka-65535+((d[W+1|0]|0)<<1|(d[W]|0)<<9)|0;kb=W+2|0}else{jb=ka;kb=W}if((jb|0)<(qa|0)){wa=43;break}ka=jb-qa|0;if((h|0)<30){h=h+1|0;pa=ka;W=kb}else{lb=kb;mb=ka;nb=1;ob=h;break}}if((wa|0)==43){wa=0;if((h|0)==0){fb=15;gb=jb;hb=kb;ib=bb;break}else{lb=kb;mb=jb;nb=1;ob=h}}while(1){W=ob-1|0;pa=mb<<1;if((pa&65534|0)==0){pb=pa-65535+((d[lb+1|0]|0)<<1|(d[lb]|0)<<9)|0;qb=lb+2|0}else{pb=pa;qb=lb}pa=(pb|0)<(qa|0);rb=pb-(pa?0:qa)|0;sb=(pa&1|nb<<1)^1;if((W|0)==0){break}else{lb=qb;mb=rb;nb=sb;ob=W}}fb=sb+14|0;gb=rb;hb=qb;ib=bb}}while(0);ga=gb<<1;if((ga&65534|0)==0){tb=ga-65535+((d[hb+1|0]|0)<<1|(d[hb]|0)<<9)|0;ub=hb+2|0}else{tb=ga;ub=hb}ga=ib<<17;qa=tb-ga|0;h=qa>>31;c[sa+(ha<<2)>>2]=(ba((h^-fb)-h|0,c[k+(ha<<2)>>2]|0)|0)+32>>6;Xa=Pa;Ya=(h&ga)+qa|0;Za=ib;_a=ub}if((ra|0)==0){Qa=Ya;Ra=Za;Sa=_a;break}else{f=ra;T=Xa&255;ia=Ya;U=Za;V=_a}}c[o>>2]=Ra;c[q>>2]=Qa;c[s>>2]=Sa;i=m;return}function Pda(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;j=i;i=i+256|0;k=j|0;l=f+425492|0;m=f+425488|0;n=f+425504|0;o=c[f+177092>>2]|0;p=c[1403572+(o*56|0)>>2]|0;q=c[1403692+(o*56|0)>>2]|0;o=c[n>>2]|0;r=c[l>>2]|0;s=c[m>>2]|0;t=0;u=0;while(1){v=d[1403672+u|0]|0;w=v+p+(f+425536)|0;x=d[w]|0;y=d[1208480+((x|512)+(r<<1&384))|0]|0;z=r-y|0;A=z<<17;B=A-s>>31;C=(B&y-z)+z|0;z=B^x;a[w]=a[z+1209632|0]|0;w=d[1208480+C|0]|0;x=C<<w;C=s-(B&A)<<w;if((C&65535|0)==0){D=(((d[o+1|0]|0)<<1|(d[o]|0)<<9)-65535<<7-(d[1208480+((C-1^C)>>15)|0]|0))+C|0;E=o+2|0}else{D=C;E=o}if((z&1|0)==0){F=t;G=D;H=x;I=E}else{z=v+q+(f+425536)|0;v=t+1|0;c[k+(t<<2)>>2]=u;C=d[z]|0;w=d[1208480+((C|512)+(x<<1&384))|0]|0;A=x-w|0;x=A<<17;B=x-D>>31;y=(B&w-A)+A|0;A=B^C;a[z]=a[A+1209632|0]|0;z=d[1208480+y|0]|0;C=y<<z;y=D-(B&x)<<z;if((y&65535|0)==0){J=(((d[E+1|0]|0)<<1|(d[E]|0)<<9)-65535<<7-(d[1208480+((y-1^y)>>15)|0]|0))+y|0;K=E+2|0}else{J=y;K=E}if((A&1|0)==0){F=v;G=J;H=C;I=K}else{L=v;M=J;N=C;O=K;break}}P=u+1|0;if((P|0)<7){o=I;r=H;s=G;t=F;u=P}else{Q=9;break}}do{if((Q|0)==9){if((P|0)!=7){L=F;M=G;N=H;O=I;break}c[k+(F<<2)>>2]=7;L=F+1|0;M=G;N=H;O=I}}while(0);I=(c[f+426560>>2]|0)+(c[f+427412>>2]<<1)|0;b[I>>1]=e[I>>1]|0|64<<h-49;a[(d[473368+h|0]|0)+(f+5184)|0]=L;if((c[f+4752>>2]|0)==0){h=L;I=0;H=M;G=N;F=O;while(1){P=(d[1403880+I|0]|0)+257+(f+425536)|0;u=h-1|0;t=d[1487408+(c[k+(u<<2)>>2]|0)|0]|0;s=d[P]|0;r=d[1208480+((s|512)+(G<<1&384))|0]|0;o=G-r|0;K=o<<17;J=K-H>>31;E=(J&r-o)+o|0;o=J^s;a[P]=a[o+1209632|0]|0;P=d[1208480+E|0]|0;s=E<<P;E=H-(J&K)<<P;if((E&65535|0)==0){R=(((d[F+1|0]|0)<<1|(d[F]|0)<<9)-65535<<7-(d[1208480+((E-1^E)>>15)|0]|0))+E|0;S=F+2|0}else{R=E;S=F}if((o&1|0)==0){o=a[1403808+I|0]|0;E=R<<1;if((E&65534|0)==0){T=E-65535+((d[S+1|0]|0)<<1|(d[S]|0)<<9)|0;U=S+2|0}else{T=E;U=S}E=s<<17;P=T-E|0;K=P>>31;b[g+(t<<1)>>1]=(K^65535)-K;V=o;W=(K&E)+P|0;X=s;Y=U}else{P=(d[1403800+I|0]|0)+257+(f+425536)|0;E=a[1403816+I|0]|0;K=2;o=R;J=s;s=S;while(1){if((K|0)>=15){Z=o;_=s;$=J;Q=51;break}r=d[P]|0;D=d[1208480+((r|512)+(J<<1&384))|0]|0;q=J-D|0;p=q<<17;C=p-o>>31;v=(C&D-q)+q|0;q=C^r;a[P]=a[q+1209632|0]|0;r=d[1208480+v|0]|0;aa=v<<r;v=o-(C&p)<<r;if((v&65535|0)==0){ba=(((d[s+1|0]|0)<<1|(d[s]|0)<<9)-65535<<7-(d[1208480+((v-1^v)>>15)|0]|0))+v|0;ca=s+2|0}else{ba=v;ca=s}if((q&1|0)==0){Q=50;break}else{K=K+1|0;o=ba;J=aa;s=ca}}if((Q|0)==50){Q=0;if((K|0)>14){Z=ba;_=ca;$=aa;Q=51}else{da=K;ea=ba;fa=ca;ga=aa}}do{if((Q|0)==51){Q=0;s=$<<17;J=0;o=Z;P=_;while(1){q=o<<1;if((q&65534|0)==0){ha=q-65535+((d[P+1|0]|0)<<1|(d[P]|0)<<9)|0;ia=P+2|0}else{ha=q;ia=P}if((ha|0)<(s|0)){Q=56;break}q=ha-s|0;if((J|0)<30){J=J+1|0;o=q;P=ia}else{ja=ia;ka=q;la=1;ma=J;break}}if((Q|0)==56){Q=0;if((J|0)==0){da=15;ea=ha;fa=ia;ga=$;break}else{ja=ia;ka=ha;la=1;ma=J}}while(1){P=ma-1|0;o=ka<<1;if((o&65534|0)==0){na=o-65535+((d[ja+1|0]|0)<<1|(d[ja]|0)<<9)|0;oa=ja+2|0}else{na=o;oa=ja}o=(na|0)<(s|0);pa=na-(o?0:s)|0;qa=(o&1|la<<1)^1;if((P|0)==0){break}else{ja=oa;ka=pa;la=qa;ma=P}}da=qa+14|0;ea=pa;fa=oa;ga=$}}while(0);K=ea<<1;if((K&65534|0)==0){ra=K-65535+((d[fa+1|0]|0)<<1|(d[fa]|0)<<9)|0;sa=fa+2|0}else{ra=K;sa=fa}K=ga<<17;s=ra-K|0;J=s>>31;b[g+(t<<1)>>1]=(J^-da)-J;V=E;W=(J&K)+s|0;X=ga;Y=sa}if((u|0)==0){ta=W;ua=X;va=Y;break}else{h=u;I=V&255;H=W;G=X;F=Y}}c[l>>2]=ua;c[m>>2]=ta;c[n>>2]=va;i=j;return}Y=g;g=L;L=0;F=M;M=N;N=O;while(1){O=(d[1403880+L|0]|0)+257+(f+425536)|0;X=g-1|0;G=d[1487408+(c[k+(X<<2)>>2]|0)|0]|0;W=d[O]|0;H=d[1208480+((W|512)+(M<<1&384))|0]|0;V=M-H|0;I=V<<17;h=I-F>>31;sa=(h&H-V)+V|0;V=h^W;a[O]=a[V+1209632|0]|0;O=d[1208480+sa|0]|0;W=sa<<O;sa=F-(h&I)<<O;if((sa&65535|0)==0){wa=(((d[N+1|0]|0)<<1|(d[N]|0)<<9)-65535<<7-(d[1208480+((sa-1^sa)>>15)|0]|0))+sa|0;xa=N+2|0}else{wa=sa;xa=N}if((V&1|0)==0){V=a[1403808+L|0]|0;sa=wa<<1;if((sa&65534|0)==0){ya=sa-65535+((d[xa+1|0]|0)<<1|(d[xa]|0)<<9)|0;za=xa+2|0}else{ya=sa;za=xa}sa=W<<17;O=ya-sa|0;I=O>>31;c[Y+(G<<2)>>2]=~I-I;Aa=V;Ba=(I&sa)+O|0;Ca=W;Da=za}else{O=(d[1403800+L|0]|0)+257+(f+425536)|0;sa=a[1403816+L|0]|0;I=2;V=wa;h=W;W=xa;while(1){if((I|0)>=15){Ea=V;Fa=W;Ga=h;Q=25;break}H=d[O]|0;ga=d[1208480+((H|512)+(h<<1&384))|0]|0;da=h-ga|0;ra=da<<17;fa=ra-V>>31;ea=(fa&ga-da)+da|0;da=fa^H;a[O]=a[da+1209632|0]|0;H=d[1208480+ea|0]|0;Ha=ea<<H;ea=V-(fa&ra)<<H;if((ea&65535|0)==0){Ia=(((d[W+1|0]|0)<<1|(d[W]|0)<<9)-65535<<7-(d[1208480+((ea-1^ea)>>15)|0]|0))+ea|0;Ja=W+2|0}else{Ia=ea;Ja=W}if((da&1|0)==0){Q=24;break}else{I=I+1|0;V=Ia;h=Ha;W=Ja}}if((Q|0)==24){Q=0;if((I|0)>14){Ea=Ia;Fa=Ja;Ga=Ha;Q=25}else{Ka=I;La=Ia;Ma=Ja;Na=Ha}}do{if((Q|0)==25){Q=0;W=Ga<<17;h=0;V=Ea;O=Fa;while(1){u=V<<1;if((u&65534|0)==0){Oa=u-65535+((d[O+1|0]|0)<<1|(d[O]|0)<<9)|0;Pa=O+2|0}else{Oa=u;Pa=O}if((Oa|0)<(W|0)){Q=30;break}u=Oa-W|0;if((h|0)<30){h=h+1|0;V=u;O=Pa}else{Qa=Pa;Ra=u;Sa=1;Ta=h;break}}if((Q|0)==30){Q=0;if((h|0)==0){Ka=15;La=Oa;Ma=Pa;Na=Ga;break}else{Qa=Pa;Ra=Oa;Sa=1;Ta=h}}while(1){O=Ta-1|0;V=Ra<<1;if((V&65534|0)==0){Ua=V-65535+((d[Qa+1|0]|0)<<1|(d[Qa]|0)<<9)|0;Va=Qa+2|0}else{Ua=V;Va=Qa}V=(Ua|0)<(W|0);Wa=Ua-(V?0:W)|0;Xa=(V&1|Sa<<1)^1;if((O|0)==0){break}else{Qa=Va;Ra=Wa;Sa=Xa;Ta=O}}Ka=Xa+14|0;La=Wa;Ma=Va;Na=Ga}}while(0);I=La<<1;if((I&65534|0)==0){Ya=I-65535+((d[Ma+1|0]|0)<<1|(d[Ma]|0)<<9)|0;Za=Ma+2|0}else{Ya=I;Za=Ma}I=Na<<17;W=Ya-I|0;h=W>>31;c[Y+(G<<2)>>2]=(h^-Ka)-h;Aa=sa;Ba=(h&I)+W|0;Ca=Na;Da=Za}if((X|0)==0){ta=Ba;ua=Ca;va=Da;break}else{g=X;L=Aa&255;F=Ba;M=Ca;N=Da}}c[l>>2]=ua;c[m>>2]=ta;c[n>>2]=va;i=j;return}function Qda(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(a[1207808]|0){return}a[1207808]=1;c[2194377]=8776480;c[2194379]=256;N_(8777504,8,20,1487208,1,1,1487232,1,1,0,0,0,4)|0;c[2202835]=8778568;c[2202837]=8192;N_(8811336,13,36,1487416,1,1,1487456,1,1,0,0,0,4)|0;c[2194039]=8770600;c[2194041]=520;N_(8776152,8,68,1426344,1,1,1426616,1,1,0,0,0,4)|0;c[2194044]=8772680;c[2194046]=332;N_(8776172,8,68,1426412,1,1,1426684,1,1,0,0,0,4)|0;c[2194049]=8774008;c[2194051]=280;N_(8776192,8,68,1426480,1,1,1426752,1,1,0,0,0,4)|0;c[2194054]=8775128;c[2194056]=256;N_(8776212,8,68,1426548,1,1,1426820,1,1,0,0,0,4)|0;c[2194105]=8776320;c[2194107]=8;N_(8776416,3,4,1487152,1,1,1487168,1,1,0,0,0,4)|0;c[2194110]=8776352;c[2194112]=8;N_(8776436,3,4,1487156,1,1,1487172,1,1,0,0,0,4)|0;c[2194115]=8776384;c[2194117]=8;N_(8776456,3,4,1487160,1,1,1487176,1,1,0,0,0,4)|0;b=0;while(1){c[8778428+(b*20|0)>>2]=8777528+(b<<7);c[8778436+(b*20|0)>>2]=32;N_(8778424+(b*20|0)|0,5,8,1487288+(b<<3)|0,1,1,1487344+(b<<3)|0,1,1,0,0,0,4)|0;e=b+1|0;if((e|0)<7){b=e}else{f=0;break}}do{c[2858084+(f*20|0)>>2]=2827360+(f<<11);c[2858092+(f*20|0)>>2]=512;N_(2858080+(f*20|0)|0,9,16,185536+(f<<4)|0,1,1,185792+(f<<4)|0,1,1,0,0,0,4)|0;f=f+1|0;}while((f|0)<15);c[1136395]=4545384;c[1136397]=8;N_(4545576,3,7,545592,1,1,545704,1,1,0,0,0,4)|0;c[1136400]=4545416;c[1136402]=8;N_(4545596,3,7,545608,1,1,545720,1,1,0,0,0,4)|0;c[1136405]=4545448;c[1136407]=8;N_(4545616,3,7,545624,1,1,545736,1,1,0,0,0,4)|0;c[1136410]=4545480;c[1136412]=8;N_(4545636,3,7,545640,1,1,545752,1,1,0,0,0,4)|0;c[1136415]=4545512;c[1136417]=8;N_(4545656,3,7,545656,1,1,545768,1,1,0,0,0,4)|0;c[1136420]=4545544;c[1136422]=8;N_(4545676,3,7,545672,1,1,545784,1,1,0,0,0,4)|0;c[1136521]=4545696;c[1136523]=96;N_(4546080,6,16,545688,1,1,545800,1,1,0,0,0,4)|0;f=0;do{b=-1<<f;e=0;do{g=e<<1;if((g&65280|0)==0){h=0;i=g}else{h=8;i=e>>>7&16777215}g=8-h-(d[1191992+i|0]|0)|0;j=g+1|0;k=j+f|0;do{if((k|0)<9){l=(e&65280|0)==0;m=(g<<f)+b+(e>>>(((l?0:8)-f+(d[1191992+(l?e:e>>>8)|0]|0)|0)>>>0))|0;l=m&1;a[8853472+(f<<9)+(e<<1)|0]=((m+2|0)>>>1^-l)+l;a[8853472+(f<<9)+(e<<1)+1|0]=k}else{if((j|0)<9){a[8853472+(f<<9)+(e<<1)|0]=g+100;a[8853472+(f<<9)+(e<<1)+1|0]=j;break}else{a[8853472+(f<<9)+(e<<1)|0]=108;a[8853472+(f<<9)+(e<<1)+1|0]=8;break}}}while(0);e=e+1|0;}while(e>>>0<256>>>0);f=f+1|0;}while((f|0)<7);return}function Rda(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0;g=i;i=i+88|0;h=g|0;j=g+16|0;k=g+24|0;l=g+32|0;m=g+40|0;n=g+56|0;o=c[f+7392>>2]|0;p=f+6136|0;q=c[p>>2]|0;r=(q-1|0)>>>0<2>>>0;s=c[f+4752>>2]|0;t=f+427376|0;u=f+427380|0;v=c[u>>2]|0;w=f+427404|0;x=(ba(c[w>>2]|0,v)|0)+(c[t>>2]|0)|0;y=f+427412|0;c[y>>2]=x;z=f+177080|0;A=c[z>>2]|0;do{if((A|0)!=1){B=f+427392|0;C=c[B>>2]|0;if((C|0)==-1){D=c[f+1088>>2]|0;E=f+1096|0;F=c[E>>2]|0;G=D+(F>>>3)|0;H=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(F&7);G=F+16|0;I=D+(G>>>3)|0;J=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(G&7)>>>16|H&-65536;G=J>>>0>65535>>>0;I=G?H>>>16:J;J=G?16:0;if((I&65280|0)==0){K=J;L=I}else{K=J|8;L=I>>>8}I=(d[1191992+L|0]|0)+K|0;J=31-I|0;G=J+F|0;c[E>>2]=G;F=J+1|0;do{if((F|0)==0){M=0}else{H=D+(G>>>3)|0;N=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(G&7);if((F|0)<26){c[E>>2]=G+F;M=N>>>(I>>>0);break}else{H=G+16|0;c[E>>2]=H;O=D+(H>>>3)|0;P=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(H&7)>>>((47-J|0)>>>0);c[E>>2]=G+F;M=P|N>>>16<<J-15;break}}}while(0);J=M-1|0;c[B>>2]=J;Q=J}else{Q=C}J=Q-1|0;c[B>>2]=J;if((Q|0)==0){break}F=f+177088|0;do{if((c[F>>2]|0)!=0){if((v&1|J|0)!=0){break}G=f+1096|0;E=c[G>>2]|0;D=d[(c[f+1088>>2]|0)+(E>>>3)|0]<<(E&7)>>>7;c[G>>2]=E+1;E=D&1;c[f+177092>>2]=E;c[f+177096>>2]=E}}while(0);c[j>>2]=0;TGb((c[f+5304>>2]|0)+(x*48|0)|0,0,48)|0;J=f+177092|0;if((c[J>>2]|0)==0){R=0}else{c[j>>2]=128;R=128}a:do{if((c[z>>2]|0)==3){B=R|63744;c[j>>2]=B;if((c[f+197872>>2]|0)!=0){Sda(f,B);Tda(f,c[j>>2]|0)}Yda(f,j);c[j>>2]=c[j>>2]|2048;S=c[f+6108>>2]|0}else{B=R|14344;c[j>>2]=B;Sda(f,B);B=h;C=c[f+4084>>2]|0;E=c[f+4052>>2]|0;D=c[f+6108>>2]|0;c[f+5644>>2]=0;c[f+5652>>2]=0;c[f+5660>>2]=0;c[f+5668>>2]=0;G=c[f+4872>>2]|0;if((G&12288|0)==0){if((G|0)!=0){T=4641e3;U=-1;V=29}}else{I=c[f+4852>>2]|0;N=d[c[f+4880>>2]|0]|0;P=a[C+((N&254)+(I<<2|1))|0]|0;H=E+((ba(N,D)|0)+3+(c[(c[f+6100>>2]|0)+(I<<2)>>2]|0)<<2)|0;do{if((c[F>>2]|0)==0){W=H;X=P}else{I=(G&128|0)!=0;if((c[J>>2]|0)==0){if(!I){W=H;X=P;break}N=c[H>>2]|0;c[h>>2]=N;b[h+2>>1]=N>>>16<<1;W=h;X=P>>1;break}else{if(I){W=H;X=P;break}I=c[H>>2]|0;c[h>>2]=I;b[h+2>>1]=(I>>16|0)/2|0;W=h;X=P<<1;break}}}while(0);if((c[W>>2]|X|0)!=0){T=W;U=X;V=29}}do{if((V|0)==29){P=c[f+4864>>2]|0;if((P&12288|0)==0){if((P|0)==0){break}else{Y=-1;Z=4641e3}}else{H=c[f+4844>>2]|0;G=a[C+(H<<2|2)|0]|0;I=E+((c[(c[f+6100>>2]|0)+(H<<2)>>2]|0)+(D*3|0)<<2)|0;do{if((c[F>>2]|0)==0){_=G;$=I}else{H=(P&128|0)!=0;if((c[J>>2]|0)==0){if(!H){_=G;$=I;break}N=c[I>>2]|0;O=h+4|0;c[O>>2]=N;b[B+6>>1]=N>>>16<<1;_=G>>1;$=O;break}else{if(H){_=G;$=I;break}H=c[I>>2]|0;O=h+4|0;c[O>>2]=H;b[B+6>>1]=(H>>16|0)/2|0;_=G<<1;$=O;break}}}while(0);if((c[$>>2]|_|0)==0){break}else{Y=_;Z=$}}G=c[f+4868>>2]|0;do{if((G&12288|0)==0){if((G|0)!=0){aa=4641e3;ca=-1;break}I=c[f+4860>>2]|0;if((I&12288|0)==0){aa=4641e3;ca=(I|0)==0?-2:-1;break}P=c[f+4840>>2]|0;O=c[f+4884>>2]|0;H=a[C+(P<<2|O&2|1)|0]|0;N=E+(D+3+(O&D<<1)+(c[(c[f+6100>>2]|0)+(P<<2)>>2]|0)<<2)|0;if((c[F>>2]|0)==0){aa=N;ca=H;break}P=(I&128|0)!=0;if((c[J>>2]|0)==0){if(!P){aa=N;ca=H;break}I=c[N>>2]|0;O=h+8|0;c[O>>2]=I;b[B+10>>1]=I>>>16<<1;aa=O;ca=H>>1;break}else{if(P){aa=N;ca=H;break}P=c[N>>2]|0;N=h+8|0;c[N>>2]=P;b[B+10>>1]=(P>>16|0)/2|0;aa=N;ca=H<<1;break}}else{H=c[f+4848>>2]|0;N=a[C+(H<<2|2)|0]|0;P=E+((c[(c[f+6100>>2]|0)+(H<<2)>>2]|0)+(D*3|0)<<2)|0;if((c[F>>2]|0)==0){aa=P;ca=N;break}H=(G&128|0)!=0;if((c[J>>2]|0)==0){if(!H){aa=P;ca=N;break}O=c[P>>2]|0;I=h+8|0;c[I>>2]=O;b[B+10>>1]=O>>>16<<1;aa=I;ca=N>>1;break}else{if(H){aa=P;ca=N;break}H=c[P>>2]|0;P=h+8|0;c[P>>2]=H;b[B+10>>1]=(H>>16|0)/2|0;aa=P;ca=N<<1;break}}}while(0);G=(Y|0)!=0;N=(U|0)!=0;P=(G&1^1)+(N&1^1)+((ca|0)==0)|0;do{if((P|0)>1){H=b[T>>1]|0;I=H<<16>>16;O=b[Z>>1]|0;da=O<<16>>16;ea=b[aa>>1]|0;fa=ea<<16>>16;do{if(H<<16>>16>O<<16>>16){if(!(ea<<16>>16>O<<16>>16)){ga=da;break}ga=(fa|0)>(I|0)?I:fa}else{if(!(O<<16>>16>ea<<16>>16)){ga=da;break}ga=(fa|0)>(I|0)?fa:I}}while(0);I=b[T+2>>1]|0;fa=I<<16>>16;da=b[Z+2>>1]|0;ea=da<<16>>16;O=b[aa+2>>1]|0;H=O<<16>>16;if(I<<16>>16>da<<16>>16){if(!(O<<16>>16>da<<16>>16)){ha=ea;ia=ga;break}ha=(H|0)>(fa|0)?fa:H;ia=ga;break}else{if(!(da<<16>>16>O<<16>>16)){ha=ea;ia=ga;break}ha=(H|0)>(fa|0)?H:fa;ia=ga;break}}else{if((P|0)==1){if(!N){ha=b[T+2>>1]|0;ia=b[T>>1]|0;break}if(G){ha=b[aa+2>>1]|0;ia=b[aa>>1]|0;break}else{ha=b[Z+2>>1]|0;ia=b[Z>>1]|0;break}}fa=b[T>>1]|0;H=fa<<16>>16;ea=b[Z>>1]|0;O=ea<<16>>16;da=b[aa>>1]|0;I=da<<16>>16;do{if(fa<<16>>16>ea<<16>>16){if(!(da<<16>>16>ea<<16>>16)){ja=O;break}ja=(I|0)>(H|0)?H:I}else{if(!(ea<<16>>16>da<<16>>16)){ja=O;break}ja=(I|0)>(H|0)?I:H}}while(0);H=b[T+2>>1]|0;I=H<<16>>16;O=b[Z+2>>1]|0;da=O<<16>>16;ea=b[aa+2>>1]|0;fa=ea<<16>>16;if(H<<16>>16>O<<16>>16){if(!(ea<<16>>16>O<<16>>16)){ha=da;ia=ja;break}ha=(fa|0)>(I|0)?I:fa;ia=ja;break}else{if(!(O<<16>>16>ea<<16>>16)){ha=da;ia=ja;break}ha=(fa|0)>(I|0)?fa:I;ia=ja;break}}}while(0);G=ha<<16|ia&65535;c[f+5360>>2]=G;c[f+5364>>2]=G;c[f+5368>>2]=G;c[f+5372>>2]=G;c[f+5392>>2]=G;c[f+5396>>2]=G;c[f+5400>>2]=G;c[f+5404>>2]=G;c[f+5424>>2]=G;c[f+5428>>2]=G;c[f+5432>>2]=G;c[f+5436>>2]=G;c[f+5456>>2]=G;c[f+5460>>2]=G;c[f+5464>>2]=G;c[f+5468>>2]=G;S=D;break a}}while(0);TGb(f+5360|0,0,16)|0;TGb(f+5392|0,0,16)|0;TGb(f+5424|0,0,16)|0;TGb(f+5456|0,0,16)|0;S=D}}while(0);J=c[j>>2]|0;F=(ba(S<<2,c[u>>2]|0)|0)+(c[t>>2]<<2)|0;B=c[y>>2]<<2;if((J&12288|0)==0){E=c[f+4084>>2]|0;b[E+B>>1]=-1;b[E+(B|2)>>1]=-1}else{E=c[f+4052>>2]|0;C=f+5360|0;G=c[C+4>>2]|0;N=E+(F<<2)|0;c[N>>2]=c[C>>2];c[N+4>>2]=G;G=f+5368|0;N=c[G+4>>2]|0;C=E+((F|2)<<2)|0;c[C>>2]=c[G>>2];c[C+4>>2]=N;N=f+5392|0;C=c[N+4>>2]|0;G=F+S|0;P=E+(G<<2)|0;c[P>>2]=c[N>>2];c[P+4>>2]=C;C=f+5400|0;P=c[C+4>>2]|0;N=E+(G+2<<2)|0;c[N>>2]=c[C>>2];c[N+4>>2]=P;P=f+5424|0;N=c[P+4>>2]|0;C=F+(S<<1)|0;G=E+(C<<2)|0;c[G>>2]=c[P>>2];c[G+4>>2]=N;N=f+5432|0;G=c[N+4>>2]|0;P=E+(C+2<<2)|0;c[P>>2]=c[N>>2];c[P+4>>2]=G;G=f+5456|0;P=c[G+4>>2]|0;N=F+(S*3|0)|0;C=E+(N<<2)|0;c[C>>2]=c[G>>2];c[C+4>>2]=P;P=f+5464|0;C=c[P+4>>2]|0;G=E+(N+2<<2)|0;c[G>>2]=c[P>>2];c[G+4>>2]=C;C=c[f+4084>>2]|0;a[C+B|0]=a[f+5644|0]|0;a[C+(B|1)|0]=a[f+5646|0]|0;a[C+(B|2)|0]=a[f+5660|0]|0;a[C+(B|3)|0]=a[f+5662|0]|0}if((J&49152|0)!=0){J=c[f+4056>>2]|0;C=f+5520|0;G=c[C+4>>2]|0;P=J+(F<<2)|0;c[P>>2]=c[C>>2];c[P+4>>2]=G;G=f+5528|0;P=c[G+4>>2]|0;C=J+((F|2)<<2)|0;c[C>>2]=c[G>>2];c[C+4>>2]=P;P=f+5552|0;C=c[P+4>>2]|0;G=F+S|0;N=J+(G<<2)|0;c[N>>2]=c[P>>2];c[N+4>>2]=C;C=f+5560|0;N=c[C+4>>2]|0;P=J+(G+2<<2)|0;c[P>>2]=c[C>>2];c[P+4>>2]=N;N=f+5584|0;P=c[N+4>>2]|0;C=F+(S<<1)|0;G=J+(C<<2)|0;c[G>>2]=c[N>>2];c[G+4>>2]=P;P=f+5592|0;G=c[P+4>>2]|0;N=J+(C+2<<2)|0;c[N>>2]=c[P>>2];c[N+4>>2]=G;G=f+5616|0;N=c[G+4>>2]|0;P=F+(S*3|0)|0;F=J+(P<<2)|0;c[F>>2]=c[G>>2];c[F+4>>2]=N;N=f+5624|0;F=c[N+4>>2]|0;G=J+(P+2<<2)|0;c[G>>2]=c[N>>2];c[G+4>>2]=F;F=c[f+4088>>2]|0;a[F+B|0]=a[f+5684|0]|0;a[F+(B|1)|0]=a[f+5686|0]|0;a[F+(B|2)|0]=a[f+5700|0]|0;a[F+(B|3)|0]=a[f+5702|0]|0}c[(c[f+4064>>2]|0)+(x<<2)>>2]=c[j>>2];a[(c[f+4040>>2]|0)+x|0]=c[f+4792>>2];b[(c[f+177072>>2]|0)+(x<<1)>>1]=c[f+177068>>2];c[f+4824>>2]=1;ka=0;i=g;return ka|0}}while(0);j=f+177088|0;do{if((c[j>>2]|0)!=0){if((v&1|0)!=0){break}S=f+1096|0;ia=c[S>>2]|0;ha=d[(c[f+1088>>2]|0)+(ia>>>3)|0]<<(ia&7)>>>7;c[S>>2]=ia+1;ia=ha&1;c[f+177092>>2]=ia;c[f+177096>>2]=ia}}while(0);c[f+4824>>2]=0;v=f+1096|0;ia=c[v>>2]|0;ha=f+1088|0;S=c[ha>>2]|0;ja=S+(ia>>>3)|0;aa=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ia&7);if(aa>>>0>134217727>>>0){ja=aa>>>23;Z=(d[1213744+ja|0]|0)+ia|0;c[v>>2]=Z;la=d[1108392+ja|0]|0;ma=Z}else{Z=aa>>>0>65535>>>0;ja=Z?aa>>>16:aa;T=Z?16:0;if((ja&65280|0)==0){na=T;oa=ja}else{na=T|8;oa=ja>>>8}ja=(d[1191992+oa|0]|0)+na<<1;na=ia+63-ja|0;c[v>>2]=na;la=(aa>>>((ja-31|0)>>>0))-1|0;ma=na}c[k>>2]=la;do{if((A|0)==3){if(la>>>0<23>>>0){na=d[1739018+(la<<2)|0]|0;ja=e[1739016+(la<<2)>>1]|0;c[k>>2]=ja;pa=na;qa=0;ra=ja;break}else{ja=la-23|0;c[k>>2]=ja;sa=ja;V=106;break}}else if((A|0)==2){if(la>>>0<5>>>0){ja=d[593994+(la<<2)|0]|0;na=e[593992+(la<<2)>>1]|0;c[k>>2]=na;pa=ja;qa=0;ra=na;break}else{na=la-5|0;c[k>>2]=na;sa=na;V=106;break}}else{if((c[f+177076>>2]|0)!=5|(la|0)==0){sa=la;V=106;break}na=la-1|0;c[k>>2]=na;sa=na;V=106}}while(0);do{if((V|0)==106){if(!(sa>>>0>25>>>0)){la=d[918611+(sa<<2)|0]|0;c[f+4836>>2]=d[918610+(sa<<2)|0]|0;A=e[918608+(sa<<2)>>1]|0;c[k>>2]=A;pa=0;qa=la;ra=A;break}A=c[f>>2]|0;la=(mGb(c[f+177076>>2]|0)|0)<<24>>24;na=c[t>>2]|0;ja=c[u>>2]|0;yDb(A,16,2110416,(ta=i,i=i+32|0,c[ta>>2]=sa,c[ta+8>>2]=la,c[ta+16>>2]=na,c[ta+24>>2]=ja,ta)|0);i=ta;ka=-1;i=g;return ka|0}}while(0);sa=f+177092|0;if((c[sa>>2]|0)==0){ua=ra}else{ja=ra|128;c[k>>2]=ja;ua=ja}b[(c[f+177072>>2]|0)+(x<<1)>>1]=c[f+177068>>2];if((ua&4|0)!=0){ja=ba(e[1207552+(q<<1)>>1]|0,c[f+7308>>2]|0)|0;q=-ma&7;if((q|0)==0){va=ma}else{ra=q+ma|0;c[v>>2]=ra;va=ra}c[f+421184>>2]=S+(va>>3);if(((c[f+1100>>2]|0)-va|0)<(ja|0)){yDb(c[f>>2]|0,16,2052064,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;ka=-1094995529;i=g;return ka|0}else{c[v>>2]=va+ja;a[(c[f+4040>>2]|0)+x|0]=0;TGb((c[f+5304>>2]|0)+(x*48|0)|0,16,48)|0;c[(c[f+4064>>2]|0)+(x<<2)>>2]=c[k>>2];ka=0;i=g;return ka|0}}ja=c[f+177096>>2]|0;c[l>>2]=c[f+199420>>2]<<ja;c[l+4>>2]=c[f+199424>>2]<<ja;Sda(f,ua);Tda(f,c[k>>2]|0);ua=c[k>>2]|0;b:do{if((ua&7|0)==0){if((pa|0)==4){ja=(c[z>>2]|0)==3;va=c[v>>2]|0;S=c[ha>>2]|0;ra=S+(va>>>3)|0;ma=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(va&7)>>>23;ra=(d[1213744+ma|0]|0)+va|0;c[v>>2]=ra;va=a[1108392+ma|0]|0;ma=va&255;q=f+177112|0;b[q>>1]=va&255;c:do{if(ja){do{if((va&255)>>>0>12>>>0){wa=ma}else{c[m>>2]=d[1738906+(ma<<2)|0]|0;na=b[1738904+((va&255)<<2)>>1]|0;b[q>>1]=na;la=S+(ra>>>3)|0;A=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ra&7)>>>23;la=(d[1213744+A|0]|0)+ra|0;c[v>>2]=la;aa=a[1108392+A|0]|0;A=aa&255;ia=f+177114|0;b[ia>>1]=aa&255;if((aa&255)>>>0>12>>>0){wa=A;break}c[m+4>>2]=d[1738906+(A<<2)|0]|0;A=b[1738904+((aa&255)<<2)>>1]|0;b[ia>>1]=A;ia=S+(la>>>3)|0;aa=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(la&7)>>>23;ia=(d[1213744+aa|0]|0)+la|0;c[v>>2]=ia;la=a[1108392+aa|0]|0;aa=la&255;oa=f+177116|0;b[oa>>1]=la&255;if((la&255)>>>0>12>>>0){wa=aa;break}c[m+8>>2]=d[1738906+(aa<<2)|0]|0;aa=b[1738904+((la&255)<<2)>>1]|0;b[oa>>1]=aa;oa=S+(ia>>>3)|0;la=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ia&7)>>>23;c[v>>2]=(d[1213744+la|0]|0)+ia;ia=a[1108392+la|0]|0;la=ia&255;oa=f+177118|0;b[oa>>1]=ia&255;if((ia&255)>>>0>12>>>0){wa=la;break}c[m+12>>2]=d[1738906+(la<<2)|0]|0;la=b[1738904+((ia&255)<<2)>>1]|0;b[oa>>1]=la;if(((A|na|aa|la)&256)==0){break c}Yda(f,k);a[f+5702|0]=-2;a[f+5662|0]=-2;a[f+5686|0]=-2;a[f+5646|0]=-2;break c}}while(0);D=c[t>>2]|0;la=c[u>>2]|0;yDb(c[f>>2]|0,16,2006720,(ta=i,i=i+24|0,c[ta>>2]=wa,c[ta+8>>2]=D,c[ta+16>>2]=la,ta)|0);i=ta;ka=-1;i=g;return ka|0}else{do{if((va&255)>>>0>3>>>0){xa=ma}else{c[m>>2]=d[593962+(ma<<2)|0]|0;b[q>>1]=b[593960+((va&255)<<2)>>1]|0;la=S+(ra>>>3)|0;D=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ra&7)>>>23;la=(d[1213744+D|0]|0)+ra|0;c[v>>2]=la;aa=a[1108392+D|0]|0;D=aa&255;na=f+177114|0;b[na>>1]=aa&255;if((aa&255)>>>0>3>>>0){xa=D;break}c[m+4>>2]=d[593962+(D<<2)|0]|0;b[na>>1]=b[593960+((aa&255)<<2)>>1]|0;aa=S+(la>>>3)|0;na=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(la&7)>>>23;aa=(d[1213744+na|0]|0)+la|0;c[v>>2]=aa;la=a[1108392+na|0]|0;na=la&255;D=f+177116|0;b[D>>1]=la&255;if((la&255)>>>0>3>>>0){xa=na;break}c[m+8>>2]=d[593962+(na<<2)|0]|0;b[D>>1]=b[593960+((la&255)<<2)>>1]|0;la=S+(aa>>>3)|0;D=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(aa&7)>>>23;c[v>>2]=(d[1213744+D|0]|0)+aa;aa=a[1108392+D|0]|0;D=aa&255;la=f+177118|0;b[la>>1]=aa&255;if((aa&255)>>>0>3>>>0){xa=D;break}c[m+12>>2]=d[593962+(D<<2)|0]|0;b[la>>1]=b[593960+((aa&255)<<2)>>1]|0;break c}}while(0);aa=c[t>>2]|0;la=c[u>>2]|0;yDb(c[f>>2]|0,16,1968840,(ta=i,i=i+24|0,c[ta>>2]=xa,c[ta+8>>2]=aa,c[ta+16>>2]=la,ta)|0);i=ta;ka=-1;i=g;return ka|0}}while(0);S=f+199428|0;ra=c[S>>2]|0;d:do{if((ra|0)==0){ya=0}else{va=c[k>>2]|0;q=0;e:while(1){if((va&512|0)==0){za=c[l+(q<<2)>>2]|0}else{za=1}ma=4096<<(q<<1);ja=0;do{la=e[f+177112+(ja<<1)>>1]|0;do{if((la&256|0)==0){if((la&ma|0)==0){c[n+(q<<4)+(ja<<2)>>2]=-1;break}if((za|0)==2){aa=c[v>>2]|0;D=d[(c[ha>>2]|0)+(aa>>>3)|0]<<(aa&7)>>>7;c[v>>2]=aa+1;Aa=D&1^1}else if((za|0)==1){Aa=0}else{D=c[v>>2]|0;aa=(c[ha>>2]|0)+(D>>>3)|0;na=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(D&7)>>>23;c[v>>2]=(d[1213744+na|0]|0)+D;Ba=d[1108392+na|0]|0;if(Ba>>>0<za>>>0){Aa=Ba}else{break e}}c[n+(q<<4)+(ja<<2)>>2]=Aa}}while(0);ja=ja+1|0;}while((ja|0)<4);ja=q+1|0;if(ja>>>0<ra>>>0){q=ja}else{ya=ra;break d}}yDb(c[f>>2]|0,16,1940328,(ta=i,i=i+8|0,c[ta>>2]=Ba,ta)|0);i=ta;ka=-1;i=g;return ka|0}}while(0);if((o|0)==0){Ca=0}else{ra=(c[f+6196>>2]|0)==0;q=f+177112|0;Ca=((ra?24117616:7340144)&c[q>>2]|0)==0&((ra?24117616:7340144)&c[q+4>>2]|0)==0&1}if((ya|0)==0){Da=Ca;break}q=f+2524|0;ra=f+4872|0;va=f+4852|0;ja=f+6100|0;ma=f+6108|0;la=0;while(1){na=la<<1;D=4096<<na;aa=f+5632+(la*40|0)+11|0;A=f+5312+(la*160|0)+40|0;oa=A|0;ia=A;A=12288<<na;na=f+5312+(la*160|0)+42|0;T=0;do{Z=f+177112+(T<<1)|0;do{if((b[Z>>1]&256)==0){ga=c[n+(la<<4)+(T<<2)>>2]&255;ca=T<<2;U=d[473312+ca|0]|0;a[U+9+(f+5632+(la*40|0))|0]=ga;a[U+8+(f+5632+(la*40|0))|0]=ga;a[U+1+(f+5632+(la*40|0))|0]=ga;a[f+5632+(la*40|0)+U|0]=ga;ga=e[Z>>1]|0;if((ga&D|0)==0){c[f+5312+(la*160|0)+(U<<2)+36>>2]=0;c[f+5312+(la*160|0)+(U<<2)+32>>2]=0;c[f+5312+(la*160|0)+(U<<2)+4>>2]=0;c[f+5312+(la*160|0)+(U<<2)>>2]=0;break}U=(ga&24|0)!=0?2:1;Y=c[m+(T<<2)>>2]|0;if((Y|0)<=0){break}h=(ga&8|0)==0;$=(ga&16|0)==0;_=(ga&32|0)==0;ga=0;do{X=a[473312+((ba(ga,U)|0)+ca)|0]|0;W=X&255;R=a[f+5632+(la*40|0)+W|0]|0;Q=R<<24>>24;M=W-8|0;K=a[f+5632+(la*40|0)+M|0]|0;L=W-1|0;B=a[f+5632+(la*40|0)+L|0]|0;F=f+5312+(la*160|0)+(L<<2)|0;G=f+5312+(la*160|0)+(M<<2)|0;N=M+U|0;P=a[f+5632+(la*40|0)+N|0]|0;J=P<<24>>24;C=P<<24>>24==-2;do{if((c[j>>2]|0)!=0&C&(X&255)>>>0>19>>>0&(W&7|0)==4){if((a[aa]|0)==-2){V=178;break}P=c[q>>2]|0;E=c[P+1536>>2]|0;c[ia>>2]=0;I=(c[ra>>2]&128|0)==0;if((c[sa>>2]|0)==0){if(I){V=178;break}fa=c[w>>2]|0;da=fa+(c[va>>2]|0)|0;ea=(c[u>>2]<<1&2)+(W>>>5)|0;if((c[E+((ba(ea>>>2,fa)|0)+da<<2)>>2]&A|0)==0){Ea=-1;Fa=oa;break}fa=(c[(c[ja>>2]|0)+(da<<2)>>2]|0)+3+(ba(c[ma>>2]|0,ea)|0)|0;O=c[P+1524+(la<<2)>>2]|0;b[oa>>1]=b[O+(fa<<2)>>1]|0;b[na>>1]=b[O+(fa<<2)+2>>1]<<1;Ea=a[(c[P+1556+(la<<2)>>2]|0)+((ea&2147483646)+(da<<2|1))|0]>>1;Fa=oa;break}else{if(!I){V=178;break}I=c[f+4852+(((X&255)>>>0>35>>>0)<<2)>>2]|0;da=W>>>2;if((c[E+(I<<2)>>2]&A|0)==0){Ea=-1;Fa=oa;break}E=(c[(c[ja>>2]|0)+(I<<2)>>2]|0)+3+(ba(c[ma>>2]|0,da&3)|0)|0;ea=c[P+1524+(la<<2)>>2]|0;b[oa>>1]=b[ea+(E<<2)>>1]|0;b[na>>1]=(b[ea+(E<<2)+2>>1]|0)/2|0;Ea=a[(c[P+1556+(la<<2)>>2]|0)+(da&2|I<<2|1)|0]<<1;Fa=oa;break}}else{V=178}}while(0);do{if((V|0)==178){V=0;if(C){X=W-9|0;Ea=a[f+5632+(la*40|0)+X|0]|0;Fa=f+5312+(la*160|0)+(X<<2)|0;break}else{Ea=J;Fa=f+5312+(la*160|0)+(N<<2)|0;break}}}while(0);N=K<<24>>24==R<<24>>24;J=B<<24>>24==R<<24>>24;C=(J&1)+(N&1)+((Ea|0)==(Q|0))|0;do{if((C|0)>1){X=b[F>>1]|0;I=X<<16>>16;da=b[G>>1]|0;P=da<<16>>16;E=b[Fa>>1]|0;ea=E<<16>>16;do{if(X<<16>>16>da<<16>>16){if(!(E<<16>>16>da<<16>>16)){Ga=P;break}Ga=(ea|0)>(I|0)?I:ea}else{if(!(da<<16>>16>E<<16>>16)){Ga=P;break}Ga=(ea|0)>(I|0)?ea:I}}while(0);I=b[f+5312+(la*160|0)+(L<<2)+2>>1]|0;ea=I<<16>>16;P=b[f+5312+(la*160|0)+(M<<2)+2>>1]|0;E=P<<16>>16;da=b[Fa+2>>1]|0;X=da<<16>>16;if(I<<16>>16>P<<16>>16){if(!(da<<16>>16>P<<16>>16)){Ha=E;Ia=Ga;break}Ha=(X|0)>(ea|0)?ea:X;Ia=Ga;break}else{if(!(P<<16>>16>da<<16>>16)){Ha=E;Ia=Ga;break}Ha=(X|0)>(ea|0)?X:ea;Ia=Ga;break}}else{if((C|0)==1){if(J){Ha=b[f+5312+(la*160|0)+(L<<2)+2>>1]|0;Ia=b[F>>1]|0;break}if(N){Ha=b[f+5312+(la*160|0)+(M<<2)+2>>1]|0;Ia=b[G>>1]|0;break}else{Ha=b[Fa+2>>1]|0;Ia=b[Fa>>1]|0;break}}ea=b[F>>1]|0;X=ea<<16>>16;if(!((Ea|0)!=-2|K<<24>>24!=-2|B<<24>>24==-2)){Ha=b[f+5312+(la*160|0)+(L<<2)+2>>1]|0;Ia=X;break}E=b[G>>1]|0;da=E<<16>>16;P=b[Fa>>1]|0;I=P<<16>>16;do{if(ea<<16>>16>E<<16>>16){if(!(P<<16>>16>E<<16>>16)){Ja=da;break}Ja=(I|0)>(X|0)?X:I}else{if(!(E<<16>>16>P<<16>>16)){Ja=da;break}Ja=(I|0)>(X|0)?I:X}}while(0);X=b[f+5312+(la*160|0)+(L<<2)+2>>1]|0;I=X<<16>>16;da=b[f+5312+(la*160|0)+(M<<2)+2>>1]|0;P=da<<16>>16;E=b[Fa+2>>1]|0;ea=E<<16>>16;if(X<<16>>16>da<<16>>16){if(!(E<<16>>16>da<<16>>16)){Ha=P;Ia=Ja;break}Ha=(ea|0)>(I|0)?I:ea;Ia=Ja;break}else{if(!(da<<16>>16>E<<16>>16)){Ha=P;Ia=Ja;break}Ha=(ea|0)>(I|0)?ea:I;Ia=Ja;break}}}while(0);M=c[v>>2]|0;L=c[ha>>2]|0;G=L+(M>>>3)|0;B=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(M&7);if(B>>>0>134217727>>>0){G=B>>>23;K=(d[1213744+G|0]|0)+M|0;c[v>>2]=K;Ka=a[1139096+G|0]|0;La=K}else{K=B>>>0>65535>>>0;G=K?B>>>16:B;B=K?16:0;if((G&65280|0)==0){Ma=B;Na=G}else{Ma=B|8;Na=G>>>8}G=(d[1191992+Na|0]|0)+Ma|0;B=31-G+M|0;M=L+(B>>>3)|0;K=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(B&7)>>>(G>>>0);M=32-G+B|0;c[v>>2]=M;B=K>>>1;Ka=(K&1|0)==0?B:-B|0;La=M}M=Ka+Ia|0;B=L+(La>>>3)|0;K=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(La&7);if(K>>>0>134217727>>>0){B=K>>>23;c[v>>2]=(d[1213744+B|0]|0)+La;Oa=a[1139096+B|0]|0}else{B=K>>>0>65535>>>0;G=B?K>>>16:K;K=B?16:0;if((G&65280|0)==0){Pa=K;Qa=G}else{Pa=K|8;Qa=G>>>8}G=(d[1191992+Qa|0]|0)+Pa|0;K=31-G+La|0;B=L+(K>>>3)|0;L=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(K&7)>>>(G>>>0);c[v>>2]=32-G+K;K=L>>>1;Oa=(L&1|0)==0?K:-K|0}K=Oa+Ha|0;L=M&65535;do{if(h){if(!$){M=W+1|0;b[f+5312+(la*160|0)+(M<<2)>>1]=L;G=K&65535;b[f+5312+(la*160|0)+(M<<2)+2>>1]=G;Ra=G;break}if(_){Ra=K&65535;break}else{G=W+8|0;b[f+5312+(la*160|0)+(G<<2)>>1]=L;M=K&65535;b[f+5312+(la*160|0)+(G<<2)+2>>1]=M;Ra=M;break}}else{M=W+9|0;b[f+5312+(la*160|0)+(M<<2)>>1]=L;G=W+8|0;b[f+5312+(la*160|0)+(G<<2)>>1]=L;B=W+1|0;b[f+5312+(la*160|0)+(B<<2)>>1]=L;F=K&65535;b[f+5312+(la*160|0)+(M<<2)+2>>1]=F;b[f+5312+(la*160|0)+(G<<2)+2>>1]=F;b[f+5312+(la*160|0)+(B<<2)+2>>1]=F;Ra=F}}while(0);b[f+5312+(la*160|0)+(W<<2)>>1]=L;b[f+5312+(la*160|0)+(W<<2)+2>>1]=Ra;ga=ga+1|0;}while((ga|0)<(Y|0))}else{Y=d[473312+(T<<2)|0]|0;a[f+5632+(la*40|0)+Y|0]=a[Y+1+(f+5632+(la*40|0))|0]|0}}while(0);T=T+1|0;}while((T|0)<4);T=la+1|0;if(T>>>0<(c[S>>2]|0)>>>0){la=T}else{Da=Ca;break b}}}if((ua&256|0)!=0){Yda(f,k);Da=c[f+6196>>2]&o;break}if((ua&8|0)!=0){la=f+199428|0;S=c[la>>2]|0;if((S|0)==0){Da=o;break}else{Sa=0;Ta=S}while(1){if((ua&4096<<(Sa<<1)|0)==0){Ua=Ta}else{S=c[l+(Sa<<2)>>2]|0;if((S|0)==1){Va=0}else if((S|0)==2){ma=c[v>>2]|0;ja=d[(c[ha>>2]|0)+(ma>>>3)|0]<<(ma&7)>>>7;c[v>>2]=ma+1;Va=ja&1^1}else{ja=c[v>>2]|0;ma=(c[ha>>2]|0)+(ja>>>3)|0;va=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(ja&7)>>>23;c[v>>2]=(d[1213744+va|0]|0)+ja;Wa=d[1108392+va|0]|0;if(Wa>>>0<S>>>0){Va=Wa}else{V=240;break}}S=ba(Va,16843009)|0;c[f+5632+(Sa*40|0)+12>>2]=S;c[f+5632+(Sa*40|0)+20>>2]=S;c[f+5632+(Sa*40|0)+28>>2]=S;c[f+5632+(Sa*40|0)+36>>2]=S;Ua=c[la>>2]|0}S=Sa+1|0;if(S>>>0<Ua>>>0){Sa=S;Ta=Ua}else{break}}if((V|0)==240){yDb(c[f>>2]|0,16,1940328,(ta=i,i=i+8|0,c[ta>>2]=Wa,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((Ua|0)==0){Da=o;break}else{Xa=0}while(1){if((ua&4096<<(Xa<<1)|0)!=0){la=a[f+5632+(Xa*40|0)+12|0]|0;S=a[f+5632+(Xa*40|0)+4|0]|0;va=a[f+5632+(Xa*40|0)+11|0]|0;ja=f+5312+(Xa*160|0)+44|0;ma=f+5312+(Xa*160|0)+16|0;ra=a[f+5632+(Xa*40|0)+8|0]|0;if(ra<<24>>24==-2){Ya=a[f+5632+(Xa*40|0)+3|0]|0;Za=f+5312+(Xa*160|0)+12|0}else{Ya=ra;Za=f+5312+(Xa*160|0)+32|0}ra=S<<24>>24==la<<24>>24;q=va<<24>>24==la<<24>>24;T=(q&1)+(ra&1)+(Ya<<24>>24==la<<24>>24)|0;do{if((T|0)>1){la=b[ja>>1]|0;oa=la<<16>>16;na=b[ma>>1]|0;A=na<<16>>16;ia=b[Za>>1]|0;aa=ia<<16>>16;do{if(la<<16>>16>na<<16>>16){if(!(ia<<16>>16>na<<16>>16)){_a=A;break}_a=(aa|0)>(oa|0)?oa:aa}else{if(!(na<<16>>16>ia<<16>>16)){_a=A;break}_a=(aa|0)>(oa|0)?aa:oa}}while(0);oa=b[f+5312+(Xa*160|0)+46>>1]|0;aa=oa<<16>>16;A=b[f+5312+(Xa*160|0)+18>>1]|0;ia=A<<16>>16;na=b[Za+2>>1]|0;la=na<<16>>16;if(oa<<16>>16>A<<16>>16){if(!(na<<16>>16>A<<16>>16)){$a=ia;ab=_a;break}$a=(la|0)>(aa|0)?aa:la;ab=_a;break}else{if(!(A<<16>>16>na<<16>>16)){$a=ia;ab=_a;break}$a=(la|0)>(aa|0)?la:aa;ab=_a;break}}else{if((T|0)==1){if(q){$a=b[f+5312+(Xa*160|0)+46>>1]|0;ab=b[ja>>1]|0;break}if(ra){$a=b[f+5312+(Xa*160|0)+18>>1]|0;ab=b[ma>>1]|0;break}else{$a=b[Za+2>>1]|0;ab=b[Za>>1]|0;break}}aa=b[ja>>1]|0;la=aa<<16>>16;if(!(Ya<<24>>24!=-2|S<<24>>24!=-2|va<<24>>24==-2)){$a=b[f+5312+(Xa*160|0)+46>>1]|0;ab=la;break}ia=b[ma>>1]|0;na=ia<<16>>16;A=b[Za>>1]|0;oa=A<<16>>16;do{if(aa<<16>>16>ia<<16>>16){if(!(A<<16>>16>ia<<16>>16)){bb=na;break}bb=(oa|0)>(la|0)?la:oa}else{if(!(ia<<16>>16>A<<16>>16)){bb=na;break}bb=(oa|0)>(la|0)?oa:la}}while(0);la=b[f+5312+(Xa*160|0)+46>>1]|0;oa=la<<16>>16;na=b[f+5312+(Xa*160|0)+18>>1]|0;A=na<<16>>16;ia=b[Za+2>>1]|0;aa=ia<<16>>16;if(la<<16>>16>na<<16>>16){if(!(ia<<16>>16>na<<16>>16)){$a=A;ab=bb;break}$a=(aa|0)>(oa|0)?oa:aa;ab=bb;break}else{if(!(na<<16>>16>ia<<16>>16)){$a=A;ab=bb;break}$a=(aa|0)>(oa|0)?aa:oa;ab=bb;break}}}while(0);ma=c[v>>2]|0;va=c[ha>>2]|0;S=va+(ma>>>3)|0;ja=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(ma&7);if(ja>>>0>134217727>>>0){S=ja>>>23;ra=(d[1213744+S|0]|0)+ma|0;c[v>>2]=ra;cb=a[1139096+S|0]|0;db=ra}else{ra=ja>>>0>65535>>>0;S=ra?ja>>>16:ja;ja=ra?16:0;if((S&65280|0)==0){eb=ja;fb=S}else{eb=ja|8;fb=S>>>8}S=(d[1191992+fb|0]|0)+eb|0;ja=31-S+ma|0;ma=va+(ja>>>3)|0;ra=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(ja&7)>>>(S>>>0);ma=32-S+ja|0;c[v>>2]=ma;ja=ra>>>1;cb=(ra&1|0)==0?ja:-ja|0;db=ma}ma=cb+ab|0;ja=va+(db>>>3)|0;ra=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(db&7);if(ra>>>0>134217727>>>0){ja=ra>>>23;c[v>>2]=(d[1213744+ja|0]|0)+db;gb=a[1139096+ja|0]|0}else{ja=ra>>>0>65535>>>0;S=ja?ra>>>16:ra;ra=ja?16:0;if((S&65280|0)==0){hb=ra;ib=S}else{hb=ra|8;ib=S>>>8}S=(d[1191992+ib|0]|0)+hb|0;ra=31-S+db|0;ja=va+(ra>>>3)|0;va=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ra&7)>>>(S>>>0);c[v>>2]=32-S+ra;ra=va>>>1;gb=(va&1|0)==0?ra:-ra|0}ra=gb+$a<<16|ma&65535;c[f+5312+(Xa*160|0)+48>>2]=ra;c[f+5312+(Xa*160|0)+52>>2]=ra;c[f+5312+(Xa*160|0)+56>>2]=ra;c[f+5312+(Xa*160|0)+60>>2]=ra;c[f+5312+(Xa*160|0)+80>>2]=ra;c[f+5312+(Xa*160|0)+84>>2]=ra;c[f+5312+(Xa*160|0)+88>>2]=ra;c[f+5312+(Xa*160|0)+92>>2]=ra;c[f+5312+(Xa*160|0)+112>>2]=ra;c[f+5312+(Xa*160|0)+116>>2]=ra;c[f+5312+(Xa*160|0)+120>>2]=ra;c[f+5312+(Xa*160|0)+124>>2]=ra;c[f+5312+(Xa*160|0)+144>>2]=ra;c[f+5312+(Xa*160|0)+148>>2]=ra;c[f+5312+(Xa*160|0)+152>>2]=ra;c[f+5312+(Xa*160|0)+156>>2]=ra}ra=Xa+1|0;if(ra>>>0<Ua>>>0){Xa=ra}else{Da=o;break b}}}ra=f+199428|0;ma=(c[ra>>2]|0)==0;if((ua&16|0)!=0){if(ma){Da=o;break}else{jb=0}f:do{va=jb<<1;S=l+(jb<<2)|0;do{if((ua&4096<<va|0)==0){kb=255}else{ja=c[S>>2]|0;if((ja|0)==1){kb=0;break}else if((ja|0)==2){q=c[v>>2]|0;T=d[(c[ha>>2]|0)+(q>>>3)|0]<<(q&7)>>>7;c[v>>2]=q+1;kb=T&1^1;break}else{T=c[v>>2]|0;q=(c[ha>>2]|0)+(T>>>3)|0;oa=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(T&7)>>>23;c[v>>2]=(d[1213744+oa|0]|0)+T;T=d[1108392+oa|0]|0;if(T>>>0<ja>>>0){kb=T;break}else{lb=T;V=297;break f}}}}while(0);T=ba(kb,16843009)|0;c[f+5632+(jb*40|0)+12>>2]=T;c[f+5632+(jb*40|0)+20>>2]=T;do{if((ua&4096<<(va|1)|0)==0){mb=255}else{T=c[S>>2]|0;if((T|0)==2){ja=c[v>>2]|0;oa=d[(c[ha>>2]|0)+(ja>>>3)|0]<<(ja&7)>>>7;c[v>>2]=ja+1;mb=oa&1^1;break}else if((T|0)==1){mb=0;break}else{oa=c[v>>2]|0;ja=(c[ha>>2]|0)+(oa>>>3)|0;q=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(oa&7)>>>23;c[v>>2]=(d[1213744+q|0]|0)+oa;oa=d[1108392+q|0]|0;if(oa>>>0<T>>>0){mb=oa;break}else{lb=oa;V=297;break f}}}}while(0);S=ba(mb,16843009)|0;c[f+5632+(jb*40|0)+28>>2]=S;c[f+5632+(jb*40|0)+36>>2]=S;jb=jb+1|0;nb=c[ra>>2]|0;}while(jb>>>0<nb>>>0);if((V|0)==297){yDb(c[f>>2]|0,16,1940328,(ta=i,i=i+8|0,c[ta>>2]=lb,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((nb|0)==0){Da=o;break}S=f+2524|0;va=f+4872|0;oa=f+4852|0;T=f+6100|0;q=f+6108|0;ja=0;while(1){aa=ja<<1;A=f+5632+(ja*40|0)+4|0;ia=f+5312+(ja*160|0)+16|0;na=f+5312+(ja*160|0)+18|0;la=f+5632+(ja*40|0)+11|0;D=f+5312+(ja*160|0)+40|0;Z=D|0;Y=D;D=12288<<aa;ga=f+5312+(ja*160|0)+42|0;_=f+5632+(ja*40|0)+27|0;$=f+5312+(ja*160|0)+108|0;h=f+5312+(ja*160|0)+110|0;U=0;do{if((ua&4096<<U+aa|0)==0){ob=0;pb=U<<4|12}else{ca=U<<3;K=U<<4|12;F=a[f+5632+(ja*40|0)+K|0]|0;B=F<<24>>24;do{if((ca|0)==0){if(!((a[A]|0)==F<<24>>24)){V=307;break}qb=b[na>>1]|0;rb=b[ia>>1]|0}else{if(!((a[_]|0)==F<<24>>24)){V=307;break}qb=b[h>>1]|0;rb=b[$>>1]|0}}while(0);do{if((V|0)==307){V=0;G=a[473312+ca|0]|0;M=G&255;N=M-8|0;J=a[f+5632+(ja*40|0)+N|0]|0;C=M-1|0;Q=a[f+5632+(ja*40|0)+C|0]|0;R=f+5312+(ja*160|0)+(C<<2)|0;I=f+5312+(ja*160|0)+(N<<2)|0;ea=M-4|0;P=a[f+5632+(ja*40|0)+ea|0]|0;E=P<<24>>24;da=P<<24>>24==-2;do{if((c[j>>2]|0)!=0&da&(G&255)>>>0>19>>>0&(M&7|0)==4){if((a[la]|0)==-2){V=316;break}P=c[S>>2]|0;X=c[P+1536>>2]|0;c[Y>>2]=0;fa=(c[va>>2]&128|0)==0;if((c[sa>>2]|0)==0){if(fa){V=316;break}O=c[w>>2]|0;H=O+(c[oa>>2]|0)|0;sb=(c[u>>2]<<1&2)+(M>>>5)|0;if((c[X+((ba(sb>>>2,O)|0)+H<<2)>>2]&D|0)==0){tb=-1;ub=Z;break}O=(c[(c[T>>2]|0)+(H<<2)>>2]|0)+3+(ba(c[q>>2]|0,sb)|0)|0;vb=c[P+1524+(ja<<2)>>2]|0;b[Z>>1]=b[vb+(O<<2)>>1]|0;b[ga>>1]=b[vb+(O<<2)+2>>1]<<1;tb=a[(c[P+1556+(ja<<2)>>2]|0)+((sb&2147483646)+(H<<2|1))|0]>>1;ub=Z;break}else{if(!fa){V=316;break}fa=c[f+4852+(((G&255)>>>0>35>>>0)<<2)>>2]|0;H=M>>>2;if((c[X+(fa<<2)>>2]&D|0)==0){tb=-1;ub=Z;break}X=(c[(c[T>>2]|0)+(fa<<2)>>2]|0)+3+(ba(c[q>>2]|0,H&3)|0)|0;sb=c[P+1524+(ja<<2)>>2]|0;b[Z>>1]=b[sb+(X<<2)>>1]|0;b[ga>>1]=(b[sb+(X<<2)+2>>1]|0)/2|0;tb=a[(c[P+1556+(ja<<2)>>2]|0)+(H&2|fa<<2|1)|0]<<1;ub=Z;break}}else{V=316}}while(0);do{if((V|0)==316){V=0;if(da){G=M-9|0;tb=a[f+5632+(ja*40|0)+G|0]|0;ub=f+5312+(ja*160|0)+(G<<2)|0;break}else{tb=E;ub=f+5312+(ja*160|0)+(ea<<2)|0;break}}}while(0);ea=J<<24>>24==F<<24>>24;E=Q<<24>>24==F<<24>>24;M=(E&1)+(ea&1)+((tb|0)==(B|0))|0;if((M|0)>1){da=b[R>>1]|0;G=da<<16>>16;fa=b[I>>1]|0;H=fa<<16>>16;P=b[ub>>1]|0;X=P<<16>>16;do{if(da<<16>>16>fa<<16>>16){if(!(P<<16>>16>fa<<16>>16)){wb=H;break}wb=(X|0)>(G|0)?G:X}else{if(!(fa<<16>>16>P<<16>>16)){wb=H;break}wb=(X|0)>(G|0)?X:G}}while(0);G=b[f+5312+(ja*160|0)+(C<<2)+2>>1]|0;X=G<<16>>16;H=b[f+5312+(ja*160|0)+(N<<2)+2>>1]|0;P=H<<16>>16;fa=b[ub+2>>1]|0;da=fa<<16>>16;if(G<<16>>16>H<<16>>16){if(!(fa<<16>>16>H<<16>>16)){qb=P;rb=wb;break}qb=(da|0)>(X|0)?X:da;rb=wb;break}else{if(!(H<<16>>16>fa<<16>>16)){qb=P;rb=wb;break}qb=(da|0)>(X|0)?da:X;rb=wb;break}}if((M|0)==1){if(E){qb=b[f+5312+(ja*160|0)+(C<<2)+2>>1]|0;rb=b[R>>1]|0;break}if(ea){qb=b[f+5312+(ja*160|0)+(N<<2)+2>>1]|0;rb=b[I>>1]|0;break}else{qb=b[ub+2>>1]|0;rb=b[ub>>1]|0;break}}X=b[R>>1]|0;da=X<<16>>16;if(!((tb|0)!=-2|J<<24>>24!=-2|Q<<24>>24==-2)){qb=b[f+5312+(ja*160|0)+(C<<2)+2>>1]|0;rb=da;break}P=b[I>>1]|0;fa=P<<16>>16;H=b[ub>>1]|0;G=H<<16>>16;do{if(X<<16>>16>P<<16>>16){if(!(H<<16>>16>P<<16>>16)){xb=fa;break}xb=(G|0)>(da|0)?da:G}else{if(!(P<<16>>16>H<<16>>16)){xb=fa;break}xb=(G|0)>(da|0)?G:da}}while(0);da=b[f+5312+(ja*160|0)+(C<<2)+2>>1]|0;G=da<<16>>16;fa=b[f+5312+(ja*160|0)+(N<<2)+2>>1]|0;H=fa<<16>>16;P=b[ub+2>>1]|0;X=P<<16>>16;if(da<<16>>16>fa<<16>>16){if(!(P<<16>>16>fa<<16>>16)){qb=H;rb=xb;break}qb=(X|0)>(G|0)?G:X;rb=xb;break}else{if(!(fa<<16>>16>P<<16>>16)){qb=H;rb=xb;break}qb=(X|0)>(G|0)?X:G;rb=xb;break}}}while(0);B=c[v>>2]|0;F=c[ha>>2]|0;ca=F+(B>>>3)|0;G=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(B&7);if(G>>>0>134217727>>>0){ca=G>>>23;X=(d[1213744+ca|0]|0)+B|0;c[v>>2]=X;yb=a[1139096+ca|0]|0;zb=X}else{X=G>>>0>65535>>>0;ca=X?G>>>16:G;G=X?16:0;if((ca&65280|0)==0){Ab=G;Bb=ca}else{Ab=G|8;Bb=ca>>>8}ca=(d[1191992+Bb|0]|0)+Ab|0;G=31-ca+B|0;B=F+(G>>>3)|0;X=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(G&7)>>>(ca>>>0);B=32-ca+G|0;c[v>>2]=B;G=X>>>1;yb=(X&1|0)==0?G:-G|0;zb=B}B=yb+rb|0;G=F+(zb>>>3)|0;X=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(zb&7);if(X>>>0>134217727>>>0){G=X>>>23;c[v>>2]=(d[1213744+G|0]|0)+zb;Cb=a[1139096+G|0]|0}else{G=X>>>0>65535>>>0;ca=G?X>>>16:X;X=G?16:0;if((ca&65280|0)==0){Db=X;Eb=ca}else{Db=X|8;Eb=ca>>>8}ca=(d[1191992+Eb|0]|0)+Db|0;X=31-ca+zb|0;G=F+(X>>>3)|0;F=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(X&7)>>>(ca>>>0);c[v>>2]=32-ca+X;X=F>>>1;Cb=(F&1|0)==0?X:-X|0}ob=Cb+qb<<16|B&65535;pb=K}c[f+5312+(ja*160|0)+(pb<<2)>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+4>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+8>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+12>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+32>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+36>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+40>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+44>>2]=ob;U=U+1|0;}while((U|0)<2);U=ja+1|0;if(U>>>0<nb>>>0){ja=U}else{Da=o;break b}}}if(ma){Da=o;break}else{Fb=0}g:do{ja=Fb<<1;q=l+(Fb<<2)|0;do{if((ua&4096<<ja|0)==0){Gb=255}else{T=c[q>>2]|0;if((T|0)==2){oa=c[v>>2]|0;va=d[(c[ha>>2]|0)+(oa>>>3)|0]<<(oa&7)>>>7;c[v>>2]=oa+1;Gb=va&1^1;break}else if((T|0)==1){Gb=0;break}else{va=c[v>>2]|0;oa=(c[ha>>2]|0)+(va>>>3)|0;S=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(va&7)>>>23;c[v>>2]=(d[1213744+S|0]|0)+va;va=d[1108392+S|0]|0;if(va>>>0<T>>>0){Gb=va;break}else{Hb=va;V=367;break g}}}}while(0);va=(Gb*257|0)&65535;b[f+5632+(Fb*40|0)+12>>1]=va;b[f+5632+(Fb*40|0)+20>>1]=va;b[f+5632+(Fb*40|0)+28>>1]=va;b[f+5632+(Fb*40|0)+36>>1]=va;do{if((ua&4096<<(ja|1)|0)==0){Ib=255}else{va=c[q>>2]|0;if((va|0)==2){T=c[v>>2]|0;S=d[(c[ha>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[v>>2]=T+1;Ib=S&1^1;break}else if((va|0)==1){Ib=0;break}else{S=c[v>>2]|0;T=(c[ha>>2]|0)+(S>>>3)|0;oa=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(S&7)>>>23;c[v>>2]=(d[1213744+oa|0]|0)+S;S=d[1108392+oa|0]|0;if(S>>>0<va>>>0){Ib=S;break}else{Hb=S;V=367;break g}}}}while(0);q=(Ib*257|0)&65535;b[f+5632+(Fb*40|0)+14>>1]=q;b[f+5632+(Fb*40|0)+22>>1]=q;b[f+5632+(Fb*40|0)+30>>1]=q;b[f+5632+(Fb*40|0)+38>>1]=q;Fb=Fb+1|0;Jb=c[ra>>2]|0;}while(Fb>>>0<Jb>>>0);if((V|0)==367){yDb(c[f>>2]|0,16,1940328,(ta=i,i=i+8|0,c[ta>>2]=Hb,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((Jb|0)==0){Da=o;break}ma=f+2524|0;q=f+4872|0;ja=f+4852|0;S=f+6100|0;va=f+6108|0;oa=0;while(1){T=oa<<1;U=f+5632+(oa*40|0)+11|0;Z=f+5312+(oa*160|0)+44|0;ga=f+5312+(oa*160|0)+46|0;D=f+5312+(oa*160|0)+40|0;Y=D|0;la=D;D=12288<<T;$=f+5312+(oa*160|0)+42|0;h=f+5632+(oa*40|0)+8|0;_=f+5312+(oa*160|0)+20|0;ia=f+5632+(oa*40|0)+5|0;na=f+5312+(oa*160|0)+32|0;A=0;do{if((ua&4096<<A+T|0)==0){Kb=0;Lb=(A<<1)+12|0}else{aa=A<<2;B=(A<<1)+12|0;X=a[f+5632+(oa*40|0)+B|0]|0;F=X<<24>>24;do{if((aa|0)==0){if(!((a[U]|0)==X<<24>>24)){V=379;break}Mb=b[ga>>1]|0;Nb=b[Z>>1]|0}else{ca=a[h]|0;if(ca<<24>>24==-2){Ob=a[ia]|0;Pb=_}else{Ob=ca;Pb=na}if(!(Ob<<24>>24==X<<24>>24)){V=379;break}Mb=b[Pb+2>>1]|0;Nb=b[Pb>>1]|0}}while(0);do{if((V|0)==379){V=0;K=a[473312+aa|0]|0;ca=K&255;G=ca-8|0;H=a[f+5632+(oa*40|0)+G|0]|0;P=ca-1|0;fa=a[f+5632+(oa*40|0)+P|0]|0;da=f+5312+(oa*160|0)+(P<<2)|0;I=f+5312+(oa*160|0)+(G<<2)|0;Q=ca-6|0;J=a[f+5632+(oa*40|0)+Q|0]|0;R=J<<24>>24;ea=J<<24>>24==-2;do{if((c[j>>2]|0)!=0&ea&(K&255)>>>0>19>>>0&(ca&7|0)==4){if((a[U]|0)==-2){V=388;break}J=c[ma>>2]|0;E=c[J+1536>>2]|0;c[la>>2]=0;M=(c[q>>2]&128|0)==0;if((c[sa>>2]|0)==0){if(M){V=388;break}sb=c[w>>2]|0;O=sb+(c[ja>>2]|0)|0;vb=(c[u>>2]<<1&2)+(ca>>>5)|0;if((c[E+((ba(vb>>>2,sb)|0)+O<<2)>>2]&D|0)==0){Qb=-1;Rb=Y;break}sb=(c[(c[S>>2]|0)+(O<<2)>>2]|0)+3+(ba(c[va>>2]|0,vb)|0)|0;Sb=c[J+1524+(oa<<2)>>2]|0;b[Y>>1]=b[Sb+(sb<<2)>>1]|0;b[$>>1]=b[Sb+(sb<<2)+2>>1]<<1;Qb=a[(c[J+1556+(oa<<2)>>2]|0)+((vb&2147483646)+(O<<2|1))|0]>>1;Rb=Y;break}else{if(!M){V=388;break}M=c[f+4852+(((K&255)>>>0>35>>>0)<<2)>>2]|0;O=ca>>>2;if((c[E+(M<<2)>>2]&D|0)==0){Qb=-1;Rb=Y;break}E=(c[(c[S>>2]|0)+(M<<2)>>2]|0)+3+(ba(c[va>>2]|0,O&3)|0)|0;vb=c[J+1524+(oa<<2)>>2]|0;b[Y>>1]=b[vb+(E<<2)>>1]|0;b[$>>1]=(b[vb+(E<<2)+2>>1]|0)/2|0;Qb=a[(c[J+1556+(oa<<2)>>2]|0)+(O&2|M<<2|1)|0]<<1;Rb=Y;break}}else{V=388}}while(0);do{if((V|0)==388){V=0;if(ea){K=ca-9|0;Qb=a[f+5632+(oa*40|0)+K|0]|0;Rb=f+5312+(oa*160|0)+(K<<2)|0;break}else{Qb=R;Rb=f+5312+(oa*160|0)+(Q<<2)|0;break}}}while(0);Q=H<<24>>24==X<<24>>24;R=fa<<24>>24==X<<24>>24;ca=(R&1)+(Q&1)+((Qb|0)==(F|0))|0;if((ca|0)>1){ea=b[da>>1]|0;K=ea<<16>>16;N=b[I>>1]|0;C=N<<16>>16;M=b[Rb>>1]|0;O=M<<16>>16;do{if(ea<<16>>16>N<<16>>16){if(!(M<<16>>16>N<<16>>16)){Tb=C;break}Tb=(O|0)>(K|0)?K:O}else{if(!(N<<16>>16>M<<16>>16)){Tb=C;break}Tb=(O|0)>(K|0)?O:K}}while(0);K=b[f+5312+(oa*160|0)+(P<<2)+2>>1]|0;O=K<<16>>16;C=b[f+5312+(oa*160|0)+(G<<2)+2>>1]|0;M=C<<16>>16;N=b[Rb+2>>1]|0;ea=N<<16>>16;if(K<<16>>16>C<<16>>16){if(!(N<<16>>16>C<<16>>16)){Mb=M;Nb=Tb;break}Mb=(ea|0)>(O|0)?O:ea;Nb=Tb;break}else{if(!(C<<16>>16>N<<16>>16)){Mb=M;Nb=Tb;break}Mb=(ea|0)>(O|0)?ea:O;Nb=Tb;break}}if((ca|0)==1){if(R){Mb=b[f+5312+(oa*160|0)+(P<<2)+2>>1]|0;Nb=b[da>>1]|0;break}if(Q){Mb=b[f+5312+(oa*160|0)+(G<<2)+2>>1]|0;Nb=b[I>>1]|0;break}else{Mb=b[Rb+2>>1]|0;Nb=b[Rb>>1]|0;break}}O=b[da>>1]|0;ea=O<<16>>16;if(!((Qb|0)!=-2|H<<24>>24!=-2|fa<<24>>24==-2)){Mb=b[f+5312+(oa*160|0)+(P<<2)+2>>1]|0;Nb=ea;break}M=b[I>>1]|0;N=M<<16>>16;C=b[Rb>>1]|0;K=C<<16>>16;do{if(O<<16>>16>M<<16>>16){if(!(C<<16>>16>M<<16>>16)){Ub=N;break}Ub=(K|0)>(ea|0)?ea:K}else{if(!(M<<16>>16>C<<16>>16)){Ub=N;break}Ub=(K|0)>(ea|0)?K:ea}}while(0);ea=b[f+5312+(oa*160|0)+(P<<2)+2>>1]|0;K=ea<<16>>16;N=b[f+5312+(oa*160|0)+(G<<2)+2>>1]|0;C=N<<16>>16;M=b[Rb+2>>1]|0;O=M<<16>>16;if(ea<<16>>16>N<<16>>16){if(!(M<<16>>16>N<<16>>16)){Mb=C;Nb=Ub;break}Mb=(O|0)>(K|0)?K:O;Nb=Ub;break}else{if(!(N<<16>>16>M<<16>>16)){Mb=C;Nb=Ub;break}Mb=(O|0)>(K|0)?O:K;Nb=Ub;break}}}while(0);F=c[v>>2]|0;X=c[ha>>2]|0;aa=X+(F>>>3)|0;K=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(F&7);if(K>>>0>134217727>>>0){aa=K>>>23;O=(d[1213744+aa|0]|0)+F|0;c[v>>2]=O;Vb=a[1139096+aa|0]|0;Wb=O}else{O=K>>>0>65535>>>0;aa=O?K>>>16:K;K=O?16:0;if((aa&65280|0)==0){Xb=K;Yb=aa}else{Xb=K|8;Yb=aa>>>8}aa=(d[1191992+Yb|0]|0)+Xb|0;K=31-aa+F|0;F=X+(K>>>3)|0;O=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(K&7)>>>(aa>>>0);F=32-aa+K|0;c[v>>2]=F;K=O>>>1;Vb=(O&1|0)==0?K:-K|0;Wb=F}F=Vb+Nb|0;K=X+(Wb>>>3)|0;O=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(Wb&7);if(O>>>0>134217727>>>0){K=O>>>23;c[v>>2]=(d[1213744+K|0]|0)+Wb;Zb=a[1139096+K|0]|0}else{K=O>>>0>65535>>>0;aa=K?O>>>16:O;O=K?16:0;if((aa&65280|0)==0){_b=O;$b=aa}else{_b=O|8;$b=aa>>>8}aa=(d[1191992+$b|0]|0)+_b|0;O=31-aa+Wb|0;K=X+(O>>>3)|0;X=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(O&7)>>>(aa>>>0);c[v>>2]=32-aa+O;O=X>>>1;Zb=(X&1|0)==0?O:-O|0}Kb=Zb+Mb<<16|F&65535;Lb=B}c[f+5312+(oa*160|0)+(Lb<<2)>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+4>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+32>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+36>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+64>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+68>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+96>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+100>>2]=Kb;A=A+1|0;}while((A|0)<2);A=oa+1|0;if(A>>>0<(c[ra>>2]|0)>>>0){oa=A}else{Da=o;break}}}else{do{if((ua&1|0)==0){oa=f+4836|0;ra=Pca(f,c[oa>>2]|0,0)|0;c[oa>>2]=ra;if((ra|0)<0){ka=-1}else{break}i=g;return ka|0}else{do{if((o|0)==0){ac=1}else{ra=c[v>>2]|0;oa=d[(c[ha>>2]|0)+(ra>>>3)|0]|0;c[v>>2]=ra+1;if((oa&128>>>((ra&7)>>>0)|0)==0){ac=1;break}c[k>>2]=ua|16777216;ac=4}}while(0);ra=(ac|0)==4;oa=0;do{va=d[473312+oa|0]|0;S=a[va-1+(f+4888)|0]|0;ja=a[va-8+(f+4888)|0]|0;q=(S|0)>(ja|0)?ja:S;S=(q|0)<0?2:q;q=c[v>>2]|0;ja=c[ha>>2]|0;ma=d[ja+(q>>>3)|0]|0;A=q+1|0;c[v>>2]=A;if((ma&128>>>((q&7)>>>0)|0)==0){ma=ja+(A>>>3)|0;ja=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(A&7)>>>29;c[v>>2]=q+4;bc=((ja|0)>=(S|0))+ja|0}else{bc=S}if(ra){S=(bc*257|0)&65535;b[f+4888+va>>1]=S;b[va+8+(f+4888)>>1]=S}else{a[f+4888+va|0]=bc}oa=oa+ac|0;}while((oa|0)<16);oa=c[f+4928>>2]|0;ra=c[(c[f+6104>>2]|0)+(c[y>>2]<<2)>>2]|0;c[oa+ra>>2]=c[f+4924>>2];a[oa+(ra+4)|0]=a[f+4919|0]|0;a[oa+(ra+5)|0]=a[f+4911|0]|0;a[oa+(ra+6)|0]=a[f+4903|0]|0;if((Oca(f)|0)<0){ka=-1}else{break}i=g;return ka|0}}while(0);if(!r){c[f+4832>>2]=6;Da=o;break}ra=c[v>>2]|0;oa=(c[ha>>2]|0)+(ra>>>3)|0;va=(fe(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ra&7)>>>23;c[v>>2]=(d[1213744+va|0]|0)+ra;ra=Pca(f,d[1108392+va|0]|0,1)|0;if((ra|0)<0){ka=-1;i=g;return ka|0}else{c[f+4832>>2]=ra;Da=o;break}}}while(0);o=c[k>>2]|0;do{if((o&120|0)!=0){ac=c[f+6108>>2]|0;bc=(ba(ac<<2,c[u>>2]|0)|0)+(c[t>>2]<<2)|0;ua=c[y>>2]<<2;if((o&12288|0)==0){Kb=c[f+4084>>2]|0;b[Kb+ua>>1]=-1;b[Kb+(ua|2)>>1]=-1}else{Kb=c[f+4052>>2]|0;Lb=f+5360|0;Mb=c[Lb+4>>2]|0;Zb=Kb+(bc<<2)|0;c[Zb>>2]=c[Lb>>2];c[Zb+4>>2]=Mb;Mb=f+5368|0;Zb=c[Mb+4>>2]|0;Lb=Kb+((bc|2)<<2)|0;c[Lb>>2]=c[Mb>>2];c[Lb+4>>2]=Zb;Zb=f+5392|0;Lb=c[Zb+4>>2]|0;Mb=bc+ac|0;Wb=Kb+(Mb<<2)|0;c[Wb>>2]=c[Zb>>2];c[Wb+4>>2]=Lb;Lb=f+5400|0;Wb=c[Lb+4>>2]|0;Zb=Kb+(Mb+2<<2)|0;c[Zb>>2]=c[Lb>>2];c[Zb+4>>2]=Wb;Wb=f+5424|0;Zb=c[Wb+4>>2]|0;Lb=bc+(ac<<1)|0;Mb=Kb+(Lb<<2)|0;c[Mb>>2]=c[Wb>>2];c[Mb+4>>2]=Zb;Zb=f+5432|0;Mb=c[Zb+4>>2]|0;Wb=Kb+(Lb+2<<2)|0;c[Wb>>2]=c[Zb>>2];c[Wb+4>>2]=Mb;Mb=f+5456|0;Wb=c[Mb+4>>2]|0;Zb=bc+(ac*3|0)|0;Lb=Kb+(Zb<<2)|0;c[Lb>>2]=c[Mb>>2];c[Lb+4>>2]=Wb;Wb=f+5464|0;Lb=c[Wb+4>>2]|0;Mb=Kb+(Zb+2<<2)|0;c[Mb>>2]=c[Wb>>2];c[Mb+4>>2]=Lb;Lb=c[f+4084>>2]|0;a[Lb+ua|0]=a[f+5644|0]|0;a[Lb+(ua|1)|0]=a[f+5646|0]|0;a[Lb+(ua|2)|0]=a[f+5660|0]|0;a[Lb+(ua|3)|0]=a[f+5662|0]|0}if((o&49152|0)==0){break}Lb=c[f+4056>>2]|0;Mb=f+5520|0;Wb=c[Mb+4>>2]|0;Zb=Lb+(bc<<2)|0;c[Zb>>2]=c[Mb>>2];c[Zb+4>>2]=Wb;Wb=f+5528|0;Zb=c[Wb+4>>2]|0;Mb=Lb+((bc|2)<<2)|0;c[Mb>>2]=c[Wb>>2];c[Mb+4>>2]=Zb;Zb=f+5552|0;Mb=c[Zb+4>>2]|0;Wb=bc+ac|0;Kb=Lb+(Wb<<2)|0;c[Kb>>2]=c[Zb>>2];c[Kb+4>>2]=Mb;Mb=f+5560|0;Kb=c[Mb+4>>2]|0;Zb=Lb+(Wb+2<<2)|0;c[Zb>>2]=c[Mb>>2];c[Zb+4>>2]=Kb;Kb=f+5584|0;Zb=c[Kb+4>>2]|0;Mb=bc+(ac<<1)|0;Wb=Lb+(Mb<<2)|0;c[Wb>>2]=c[Kb>>2];c[Wb+4>>2]=Zb;Zb=f+5592|0;Wb=c[Zb+4>>2]|0;Kb=Lb+(Mb+2<<2)|0;c[Kb>>2]=c[Zb>>2];c[Kb+4>>2]=Wb;Wb=f+5616|0;Kb=c[Wb+4>>2]|0;Zb=bc+(ac*3|0)|0;ac=Lb+(Zb<<2)|0;c[ac>>2]=c[Wb>>2];c[ac+4>>2]=Kb;Kb=f+5624|0;ac=c[Kb+4>>2]|0;Wb=Lb+(Zb+2<<2)|0;c[Wb>>2]=c[Kb>>2];c[Wb+4>>2]=ac;ac=c[f+4088>>2]|0;a[ac+ua|0]=a[f+5684|0]|0;a[ac+(ua|1)|0]=a[f+5686|0]|0;a[ac+(ua|2)|0]=a[f+5700|0]|0;a[ac+(ua|3)|0]=a[f+5702|0]|0}}while(0);o=c[k>>2]|0;do{if((o&2|0)==0){ua=c[v>>2]|0;ac=(c[ha>>2]|0)+(ua>>>3)|0;Wb=(fe(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(ua&7);if(Wb>>>0>134217727>>>0){ac=Wb>>>23;c[v>>2]=(d[1213744+ac|0]|0)+ua;cc=d[1108392+ac|0]|0}else{ac=Wb>>>0>65535>>>0;Kb=ac?Wb>>>16:Wb;Zb=ac?16:0;if((Kb&65280|0)==0){dc=Zb;ec=Kb}else{dc=Zb|8;ec=Kb>>>8}Kb=(d[1191992+ec|0]|0)+dc<<1;c[v>>2]=ua+63-Kb;cc=(Wb>>>((Kb-31|0)>>>0))-1|0}if(r){if(cc>>>0>47>>>0){Kb=c[t>>2]|0;Wb=c[u>>2]|0;yDb(c[f>>2]|0,16,1916104,(ta=i,i=i+24|0,c[ta>>2]=cc,c[ta+8>>2]=Kb,c[ta+16>>2]=Wb,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((o&1|0)==0){fc=d[986552+cc|0]|0;break}else{fc=d[986440+cc|0]|0;break}}else{if(cc>>>0>15>>>0){Wb=c[t>>2]|0;Kb=c[u>>2]|0;yDb(c[f>>2]|0,16,1916104,(ta=i,i=i+24|0,c[ta>>2]=cc,c[ta+8>>2]=Wb,c[ta+16>>2]=Kb,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((o&1|0)==0){fc=d[986488+cc|0]|0;break}else{fc=d[986376+cc|0]|0;break}}}else{if(!(qa>>>0>15>>>0&(r^1))){fc=qa;break}yDb(c[f>>2]|0,16,1895528,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;ka=-1094995529;i=g;return ka|0}}while(0);do{if((Da|0)==0){gc=o}else{if((fc&15|0)==0){gc=o;break}if((o&7|0)!=0){gc=o;break}qa=c[v>>2]|0;r=d[(c[ha>>2]|0)+(qa>>>3)|0]<<(qa&7)>>>7;c[v>>2]=qa+1;qa=r<<24&16777216|o;c[k>>2]=qa;gc=qa}}while(0);o=f+426560|0;b[(c[o>>2]|0)+(x<<1)>>1]=fc;c[f+426564>>2]=fc&65535;c[(c[f+4064>>2]|0)+(x<<2)>>2]=gc;gc=c[k>>2]|0;do{if((fc|0)==0){if((gc&2|0)!=0){V=464;break}c[f+5196>>2]=0;c[f+5204>>2]=0;c[f+5212>>2]=0;c[f+5220>>2]=0;c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;hc=f+4792|0}else{V=464}}while(0);h:do{if((V|0)==464){Da=gc&7;qa=f+421176|0;r=c[((Da|0)==0?f+421180|0:qa)>>2]|0;cc=(c[f+7308>>2]|0)*6|0;dc=cc+3|0;ec=f+4792|0;Kb=c[ec>>2]|0;Wb=(Kb|0)!=0;if((gc&128|0)==0){ic=Wb?f+426876|0:f+427164|0;jc=Wb?f+426796|0:f+427084|0}else{ic=Wb?f+427020|0:f+427308|0;jc=Wb?f+426940|0:f+427228|0}Wb=jc|0;ua=c[v>>2]|0;Zb=c[ha>>2]|0;ac=Zb+(ua>>>3)|0;Lb=(fe(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(ua&7);if(Lb>>>0>134217727>>>0){ac=Lb>>>23;c[v>>2]=(d[1213744+ac|0]|0)+ua;kc=a[1139096+ac|0]|0}else{ac=Lb>>>0>65535>>>0;bc=ac?Lb>>>16:Lb;Lb=ac?16:0;if((bc&65280|0)==0){lc=Lb;mc=bc}else{lc=Lb|8;mc=bc>>>8}bc=(d[1191992+mc|0]|0)+lc|0;Lb=31-bc+ua|0;ua=Zb+(Lb>>>3)|0;Zb=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(Lb&7)>>>(bc>>>0);c[v>>2]=32-bc+Lb;Lb=Zb>>>1;kc=(Zb&1|0)==0?Lb:-Lb|0}Lb=Kb+kc|0;c[ec>>2]=Lb;do{if(Lb>>>0>dc>>>0){Kb=((Lb|0)<0?cc+4|0:-4-cc|0)+Lb|0;c[ec>>2]=Kb;if(!(Kb>>>0>dc>>>0)){nc=Kb;break}Kb=c[t>>2]|0;Zb=c[u>>2]|0;yDb(c[f>>2]|0,16,2352784,(ta=i,i=i+24|0,c[ta>>2]=kc,c[ta+8>>2]=Kb,c[ta+16>>2]=Zb,ta)|0);i=ta;ka=-1;i=g;return ka|0}else{nc=Lb}}while(0);Lb=f+4756|0;c[Lb>>2]=d[f+7876+nc|0]|0;dc=f+4760|0;c[dc>>2]=d[f+7964+nc|0]|0;i:do{if((gc&2|0)==0){cc=(Da|0)!=0?0:3;Zb=f+177044+(cc<<2)|0;Kb=f+177020+(cc<<2)|0;j:do{if((gc&16777216|0)==0){cc=0;bc=0;while(1){ua=bc<<2;if((1<<bc&fc|0)==0){ac=d[473312+ua|0]|0;a[ac+9+(f+5184)|0]=0;a[ac+8+(f+5184)|0]=0;a[ac+1+(f+5184)|0]=0;a[f+5184+ac|0]=0;oc=cc}else{if((Uda(f,r,f+421200+(bc<<6<<s<<1)|0,ua,Wb,(c[Kb>>2]|0)+(nc<<6)|0,16)|0)<0){ka=-1;V=579;break}ac=a[(d[473312+ua|0]|0)+(f+5184)|0]|0;Mb=ua|1;if((Uda(f,r,f+421200+(Mb<<4<<s<<1)|0,Mb,Wb,(c[Kb>>2]|0)+(nc<<6)|0,16)|0)<0){ka=-1;V=579;break}_b=a[(d[473312+Mb|0]|0)+(f+5184)|0]|0;Mb=ua|2;if((Uda(f,r,f+421200+(Mb<<4<<s<<1)|0,Mb,Wb,(c[Kb>>2]|0)+(nc<<6)|0,16)|0)<0){ka=-1;V=579;break}$b=a[(d[473312+Mb|0]|0)+(f+5184)|0]|0;Mb=ua|3;if((Uda(f,r,f+421200+(Mb<<4<<s<<1)|0,Mb,Wb,(c[Kb>>2]|0)+(nc<<6)|0,16)|0)<0){ka=-1;V=579;break}oc=(ac&255)<<bc|cc|(_b&255)<<bc|($b&255)<<bc|d[(d[473312+Mb|0]|0)+(f+5184)|0]<<bc}Mb=bc+1|0;if((Mb|0)<4){cc=oc;bc=Mb}else{pc=oc;break j}}if((V|0)==579){i=g;return ka|0}}else{bc=0;cc=0;k:while(1){if((1<<cc&fc|0)==0){B=d[473312+(cc<<2)|0]|0;a[B+9+(f+5184)|0]=0;a[B+8+(f+5184)|0]=0;a[B+1+(f+5184)|0]=0;a[f+5184+B|0]=0;qc=bc}else{B=f+421200+(cc<<6<<s<<1)|0;Mb=cc<<2;$b=0;while(1){if(($b|0)>=4){break}if((Uda(f,r,B,$b+Mb|0,ic+($b<<4)|0,(c[Zb>>2]|0)+(nc<<8)|0,16)|0)<0){ka=-1;break k}else{$b=$b+1|0}}$b=d[473312+Mb|0]|0;B=f+5184+$b|0;G=(((a[$b+8+(f+5184)|0]|0)+(a[$b+1+(f+5184)|0]|0)&255)+(a[$b+9+(f+5184)|0]|0)&255)+(a[B]|0)&255;a[B]=G;qc=(G<<24>>24!=0)<<cc|bc}G=cc+1|0;if((G|0)<4){bc=qc;cc=G}else{pc=qc;break j}}i=g;return ka|0}}while(0);if((pc|0)<0){ka=-1}else{rc=pc;break}i=g;return ka|0}else{Zb=f+424272|0;TGb(Zb|0,0,64)|0;if((Uda(f,c[qa>>2]|0,Zb,48,Wb,0,16)|0)<0){ka=-1;i=g;return ka|0}if((fc&15|0)==0){c[f+5196>>2]=0;c[f+5204>>2]=0;c[f+5212>>2]=0;c[f+5220>>2]=0;rc=0;break}Zb=jc+1|0;Kb=f+177020|0;cc=0;while(1){if((cc|0)>=4){sc=0;break}if((Uda(f,c[qa>>2]|0,f+421200+(cc<<4<<s<<1)|0,cc,Zb,(c[Kb>>2]|0)+(nc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{cc=cc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((sc|0)>=4){tc=0;break}cc=sc+4|0;if((Uda(f,c[qa>>2]|0,f+421200+(cc<<4<<s<<1)|0,cc,Zb,(c[Kb>>2]|0)+(nc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{sc=sc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((tc|0)>=4){uc=0;break}cc=tc+8|0;if((Uda(f,c[qa>>2]|0,f+421200+(cc<<4<<s<<1)|0,cc,Zb,(c[Kb>>2]|0)+(nc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{tc=tc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((uc|0)>=4){rc=15;break i}cc=uc+12|0;if((Uda(f,c[qa>>2]|0,f+421200+(cc<<4<<s<<1)|0,cc,Zb,(c[Kb>>2]|0)+(nc<<6)|0,15)|0)<0){ka=-1;break}else{uc=uc+1|0}}i=g;return ka|0}}while(0);Da=(c[o>>2]|0)+(x<<1)|0;b[Da>>1]=e[Da>>1]|rc<<12;Da=c[p>>2]|0;if((Da|0)!=3){l:do{if((fc&48|0)!=0){Kb=Da<<2;Zb=0;while(1){if((Zb|0)>=2){break l}if((Uda(f,r,f+421200+((Zb<<8)+256<<s<<1)|0,Zb+49|0,(c[p>>2]|0)==2?1487400:1487192,0,Kb)|0)<0){ka=-1;break}else{Zb=Zb+1|0}}i=g;return ka|0}}while(0);if((fc&32|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;hc=ec;break}Zb=jc+1|0;Kb=16<<s;if((Da|0)<=0){hc=ec;break}cc=(c[f+177020+(((c[k>>2]&7|0)!=0?1:4)<<2)>>2]|0)+(c[Lb>>2]<<6)|0;bc=0;G=f+421200+(256<<s<<1)|0;while(1){B=bc<<3;if((Uda(f,r,G,B+16|0,Zb,cc,15)|0)<0){ka=-1;V=579;break}if((Uda(f,r,G+(Kb<<1)|0,B+17|0,Zb,cc,15)|0)<0){ka=-1;V=579;break}$b=Kb<<1;if((Uda(f,r,G+($b<<1)|0,B+18|0,Zb,cc,15)|0)<0){ka=-1;V=579;break}P=$b+Kb|0;if((Uda(f,r,G+(P<<1)|0,B+19|0,Zb,cc,15)|0)<0){ka=-1;V=579;break}B=bc+1|0;if((B|0)<(Da|0)){bc=B;G=G+(P+Kb<<1)|0}else{V=597;break}}if((V|0)==579){i=g;return ka|0}else if((V|0)==597){G=(c[f+177020+(((c[k>>2]&7|0)!=0?2:5)<<2)>>2]|0)+(c[dc>>2]<<6)|0;bc=0;cc=f+421200+(512<<s<<1)|0;while(1){P=bc<<3;if((Uda(f,r,cc,P+32|0,Zb,G,15)|0)<0){ka=-1;V=579;break}if((Uda(f,r,cc+(Kb<<1)|0,P+33|0,Zb,G,15)|0)<0){ka=-1;V=579;break}B=Kb<<1;if((Uda(f,r,cc+(B<<1)|0,P+34|0,Zb,G,15)|0)<0){ka=-1;V=579;break}$b=B+Kb|0;if((Uda(f,r,cc+($b<<1)|0,P+35|0,Zb,G,15)|0)<0){ka=-1;V=579;break}P=bc+1|0;if((P|0)<(Da|0)){bc=P;cc=cc+($b+Kb<<1)|0}else{hc=ec;break h}}if((V|0)==579){i=g;return ka|0}}}Kb=c[k>>2]|0;cc=c[Lb>>2]|0;m:do{if((Kb&2|0)==0){bc=(Kb&7|0)!=0?1:4;Da=f+177044+(bc<<2)|0;G=f+177020+(bc<<2)|0;n:do{if((Kb&16777216|0)==0){bc=0;Zb=0;while(1){$b=(Zb<<2)+16|0;if((1<<Zb&fc|0)==0){P=d[473312+$b|0]|0;a[P+9+(f+5184)|0]=0;a[P+8+(f+5184)|0]=0;a[P+1+(f+5184)|0]=0;a[f+5184+P|0]=0;vc=bc}else{if((Uda(f,r,f+421200+($b<<4<<s<<1)|0,$b,Wb,(c[G>>2]|0)+(cc<<6)|0,16)|0)<0){ka=-1;V=579;break}P=a[(d[473312+$b|0]|0)+(f+5184)|0]|0;B=$b|1;if((Uda(f,r,f+421200+(B<<4<<s<<1)|0,B,Wb,(c[G>>2]|0)+(cc<<6)|0,16)|0)<0){ka=-1;V=579;break}_b=a[(d[473312+B|0]|0)+(f+5184)|0]|0;B=$b|2;if((Uda(f,r,f+421200+(B<<4<<s<<1)|0,B,Wb,(c[G>>2]|0)+(cc<<6)|0,16)|0)<0){ka=-1;V=579;break}ac=a[(d[473312+B|0]|0)+(f+5184)|0]|0;B=$b|3;if((Uda(f,r,f+421200+(B<<4<<s<<1)|0,B,Wb,(c[G>>2]|0)+(cc<<6)|0,16)|0)<0){ka=-1;V=579;break}vc=(P&255)<<Zb|bc|(_b&255)<<Zb|(ac&255)<<Zb|d[(d[473312+B|0]|0)+(f+5184)|0]<<Zb}B=Zb+1|0;if((B|0)<4){bc=vc;Zb=B}else{wc=vc;break n}}if((V|0)==579){i=g;return ka|0}}else{Zb=0;bc=0;o:while(1){if((1<<bc&fc|0)==0){B=d[(bc<<2)+473328|0]|0;a[B+9+(f+5184)|0]=0;a[B+8+(f+5184)|0]=0;a[B+1+(f+5184)|0]=0;a[f+5184+B|0]=0;xc=Zb}else{B=f+421200+((bc<<6)+256<<s<<1)|0;ac=(bc<<2)+16|0;_b=0;while(1){if((_b|0)>=4){break}if((Uda(f,r,B,_b+ac|0,ic+(_b<<4)|0,(c[Da>>2]|0)+(cc<<8)|0,16)|0)<0){ka=-1;break o}else{_b=_b+1|0}}_b=d[473312+ac|0]|0;B=f+5184+_b|0;Mb=(((a[_b+8+(f+5184)|0]|0)+(a[_b+1+(f+5184)|0]|0)&255)+(a[_b+9+(f+5184)|0]|0)&255)+(a[B]|0)&255;a[B]=Mb;xc=(Mb<<24>>24!=0)<<bc|Zb}Mb=bc+1|0;if((Mb|0)<4){Zb=xc;bc=Mb}else{wc=xc;break n}}i=g;return ka|0}}while(0);if((wc|0)<0){ka=-1}else{break}i=g;return ka|0}else{Da=f+424336|0;TGb(Da|0,0,64)|0;if((Uda(f,c[qa>>2]|0,Da,49,Wb,0,16)|0)<0){ka=-1;i=g;return ka|0}if((fc&15|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;break}Da=jc+1|0;G=f+177024|0;bc=0;while(1){if((bc|0)>=4){yc=0;break}Zb=bc+16|0;if((Uda(f,c[qa>>2]|0,f+421200+(Zb<<4<<s<<1)|0,Zb,Da,(c[G>>2]|0)+(cc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{bc=bc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((yc|0)>=4){zc=0;break}bc=yc+20|0;if((Uda(f,c[qa>>2]|0,f+421200+(bc<<4<<s<<1)|0,bc,Da,(c[G>>2]|0)+(cc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{yc=yc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((zc|0)>=4){Ac=0;break}bc=zc+24|0;if((Uda(f,c[qa>>2]|0,f+421200+(bc<<4<<s<<1)|0,bc,Da,(c[G>>2]|0)+(cc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{zc=zc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((Ac|0)>=4){break m}bc=Ac+28|0;if((Uda(f,c[qa>>2]|0,f+421200+(bc<<4<<s<<1)|0,bc,Da,(c[G>>2]|0)+(cc<<6)|0,15)|0)<0){ka=-1;break}else{Ac=Ac+1|0}}i=g;return ka|0}}while(0);cc=c[k>>2]|0;Kb=c[dc>>2]|0;if((cc&2|0)!=0){Lb=f+424400|0;TGb(Lb|0,0,64)|0;if((Uda(f,c[qa>>2]|0,Lb,50,Wb,0,16)|0)<0){ka=-1;i=g;return ka|0}if((fc&15|0)==0){c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;hc=ec;break}Lb=jc+1|0;G=f+177028|0;Da=0;while(1){if((Da|0)>=4){Bc=0;break}bc=Da+32|0;if((Uda(f,c[qa>>2]|0,f+421200+(bc<<4<<s<<1)|0,bc,Lb,(c[G>>2]|0)+(Kb<<6)|0,15)|0)<0){ka=-1;V=579;break}else{Da=Da+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((Bc|0)>=4){Cc=0;break}Da=Bc+36|0;if((Uda(f,c[qa>>2]|0,f+421200+(Da<<4<<s<<1)|0,Da,Lb,(c[G>>2]|0)+(Kb<<6)|0,15)|0)<0){ka=-1;V=579;break}else{Bc=Bc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((Cc|0)>=4){Dc=0;break}Da=Cc+40|0;if((Uda(f,c[qa>>2]|0,f+421200+(Da<<4<<s<<1)|0,Da,Lb,(c[G>>2]|0)+(Kb<<6)|0,15)|0)<0){ka=-1;V=579;break}else{Cc=Cc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((Dc|0)>=4){hc=ec;break h}Da=Dc+44|0;if((Uda(f,c[qa>>2]|0,f+421200+(Da<<4<<s<<1)|0,Da,Lb,(c[G>>2]|0)+(Kb<<6)|0,15)|0)<0){ka=-1;break}else{Dc=Dc+1|0}}i=g;return ka|0}G=(cc&7|0)!=0?2:5;Lb=f+177044+(G<<2)|0;qa=f+177020+(G<<2)|0;p:do{if((cc&16777216|0)==0){G=0;Da=0;while(1){dc=(Da<<2)+32|0;if((1<<Da&fc|0)==0){bc=d[473312+dc|0]|0;a[bc+9+(f+5184)|0]=0;a[bc+8+(f+5184)|0]=0;a[bc+1+(f+5184)|0]=0;a[f+5184+bc|0]=0;Ec=G}else{if((Uda(f,r,f+421200+(dc<<4<<s<<1)|0,dc,Wb,(c[qa>>2]|0)+(Kb<<6)|0,16)|0)<0){ka=-1;V=579;break}bc=a[(d[473312+dc|0]|0)+(f+5184)|0]|0;Zb=dc|1;if((Uda(f,r,f+421200+(Zb<<4<<s<<1)|0,Zb,Wb,(c[qa>>2]|0)+(Kb<<6)|0,16)|0)<0){ka=-1;V=579;break}Mb=a[(d[473312+Zb|0]|0)+(f+5184)|0]|0;Zb=dc|2;if((Uda(f,r,f+421200+(Zb<<4<<s<<1)|0,Zb,Wb,(c[qa>>2]|0)+(Kb<<6)|0,16)|0)<0){ka=-1;V=579;break}B=a[(d[473312+Zb|0]|0)+(f+5184)|0]|0;Zb=dc|3;if((Uda(f,r,f+421200+(Zb<<4<<s<<1)|0,Zb,Wb,(c[qa>>2]|0)+(Kb<<6)|0,16)|0)<0){ka=-1;V=579;break}Ec=(bc&255)<<Da|G|(Mb&255)<<Da|(B&255)<<Da|d[(d[473312+Zb|0]|0)+(f+5184)|0]<<Da}Zb=Da+1|0;if((Zb|0)<4){G=Ec;Da=Zb}else{Fc=Ec;break p}}if((V|0)==579){i=g;return ka|0}}else{Da=0;G=0;q:while(1){if((1<<G&fc|0)==0){Zb=d[(G<<2)+473344|0]|0;a[Zb+9+(f+5184)|0]=0;a[Zb+8+(f+5184)|0]=0;a[Zb+1+(f+5184)|0]=0;a[f+5184+Zb|0]=0;Gc=Da}else{Zb=f+421200+((G<<6)+512<<s<<1)|0;B=(G<<2)+32|0;Mb=0;while(1){if((Mb|0)>=4){break}if((Uda(f,r,Zb,Mb+B|0,ic+(Mb<<4)|0,(c[Lb>>2]|0)+(Kb<<8)|0,16)|0)<0){ka=-1;break q}else{Mb=Mb+1|0}}Mb=d[473312+B|0]|0;Zb=f+5184+Mb|0;bc=(((a[Mb+8+(f+5184)|0]|0)+(a[Mb+1+(f+5184)|0]|0)&255)+(a[Mb+9+(f+5184)|0]|0)&255)+(a[Zb]|0)&255;a[Zb]=bc;Gc=(bc<<24>>24!=0)<<G|Da}bc=G+1|0;if((bc|0)<4){Da=Gc;G=bc}else{Fc=Gc;break p}}i=g;return ka|0}}while(0);if((Fc|0)<0){ka=-1}else{hc=ec;break}i=g;return ka|0}}while(0);a[(c[f+4040>>2]|0)+x|0]=c[hc>>2];hc=c[y>>2]|0;y=c[f+5304>>2]|0;c[y+(hc*48|0)>>2]=c[f+5196>>2];c[y+(hc*48|0)+4>>2]=c[f+5204>>2];c[y+(hc*48|0)+8>>2]=c[f+5212>>2];c[y+(hc*48|0)+12>>2]=c[f+5220>>2];c[y+(hc*48|0)+16>>2]=c[f+5236>>2];c[y+(hc*48|0)+20>>2]=c[f+5244>>2];c[y+(hc*48|0)+32>>2]=c[f+5276>>2];c[y+(hc*48|0)+36>>2]=c[f+5284>>2];if((c[f+4788>>2]|0)!=0){ka=0;i=g;return ka|0}c[y+(hc*48|0)+24>>2]=c[f+5252>>2];c[y+(hc*48|0)+28>>2]=c[f+5260>>2];c[y+(hc*48|0)+40>>2]=c[f+5292>>2];c[y+(hc*48|0)+44>>2]=c[f+5300>>2];ka=0;i=g;return ka|0}function Sda(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[a+427412>>2]|0;f=a+4884|0;c[f>>2]=-1;g=c[a+427404>>2]|0;h=d-(g<<c[a+177092>>2])|0;i=h-1|0;j=h+1|0;k=d-1|0;l=a+4880|0;c[l>>2]=1068552;m=c[a+4064>>2]|0;do{if((c[a+177088>>2]|0)==0){n=i;o=h;p=k;q=k;r=j}else{s=c[m+(k<<2)>>2]&128;t=b&128;if((c[a+427380>>2]&1|0)!=0){if((s|0)==(t|0)){n=i;o=h;p=k;q=k;r=j;break}u=d-g-1|0;if((t|0)==0){c[f>>2]=0;c[l>>2]=1068584;n=g+i|0;o=h;p=u;q=u;r=j;break}else{c[l>>2]=1068648;n=i;o=h;p=u;q=k;r=j;break}}u=(t|0)!=0;if(u){v=(((c[m+(i<<2)>>2]|0)>>>7&1)-1&g)+i|0;w=(((c[m+(h<<2)>>2]|0)>>>7&1)-1&g)+h|0;x=(((c[m+(j<<2)>>2]|0)>>>7&1)-1&g)+j|0}else{v=i;w=h;x=j}if((s|0)==(t|0)){n=v;o=w;p=k;q=k;r=x;break}if(u){c[l>>2]=1068648;n=v;o=w;p=k;q=g+k|0;r=x;break}else{c[l>>2]=1068616;n=v;o=w;p=k;q=k;r=x;break}}}while(0);c[a+4840>>2]=n;c[a+4844>>2]=o;c[a+4848>>2]=r;c[a+4852>>2]=p;c[a+4856>>2]=q;x=a+4860|0;c[x>>2]=c[m+(n<<2)>>2];k=a+4864|0;c[k>>2]=c[m+(o<<2)>>2];w=a+4868|0;c[w>>2]=c[m+(r<<2)>>2];v=a+4872|0;c[v>>2]=c[m+(p<<2)>>2];l=a+4876|0;c[l>>2]=c[m+(q<<2)>>2];q=c[a+177072>>2]|0;m=e[q+(n<<1)>>1]|0;n=c[a+177068>>2]|0;do{if((m|0)==(n|0)){y=m}else{c[x>>2]=0;if((e[q+(o<<1)>>1]|0|0)!=(n|0)){c[k>>2]=0}if((e[q+(p<<1)>>1]|0|0)==(n|0)){y=n;break}c[l>>2]=0;c[v>>2]=0;y=n}}while(0);if((e[q+(r<<1)>>1]|0|0)==(y|0)){return}c[w>>2]=0;return}function Tda(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[e+4880>>2]|0;l=c[e+4840>>2]|0;m=c[e+4844>>2]|0;n=c[e+4848>>2]|0;o=c[e+4852>>2]|0;c[h>>2]=o;p=c[e+4856>>2]|0;c[h+4>>2]=p;q=c[e+4860>>2]|0;r=c[e+4864>>2]|0;s=c[e+4868>>2]|0;t=c[e+4872>>2]|0;c[j>>2]=t;u=c[e+4876>>2]|0;c[j+4>>2]=u;a:do{if((f&2048|0)==0){do{if((f&7|0)!=0){v=(c[e+7384>>2]|0)!=0?7:-1;w=e+5172|0;c[w>>2]=65535;x=e+5164|0;c[x>>2]=65535;y=e+5160|0;c[y>>2]=65535;z=e+5168|0;c[z>>2]=61162;A=(v&r|0)!=0;if(A){B=65535;C=60138}else{c[y>>2]=46079;c[x>>2]=13311;c[z>>2]=9962;B=46079;C=8938}x=f&128;do{if((x|0)==(t&128|0)){if((t&v|0)!=0){D=B;break}E=B&57183;c[y>>2]=E;c[w>>2]=24415;D=E}else{if((x|0)==0){if((c[(c[e+4064>>2]|0)+((c[e+427404>>2]|0)+o<<2)>>2]&v|0)!=0){if((t&v|0)!=0){D=B;break}}E=B&57183;c[y>>2]=E;c[w>>2]=24415;D=E;break}if((t&v|0)==0){E=B&57343;c[y>>2]=E;c[w>>2]=24575;F=E;G=24415}else{F=B;G=65375}if((u&v|0)!=0){D=F;break}E=F&65375;c[y>>2]=E;c[w>>2]=G;D=E}}while(0);if((v&q|0)==0){c[y>>2]=D&32767}if((v&s|0)==0){c[z>>2]=C}if((f&1|0)==0){break}if((r&1|0)==0){TGb(e+4892|0,2-(-(A&1^1)&3)&255|0,4)|0;H=e+4928|0;I=e+6104|0}else{w=e+4928|0;x=e+6104|0;c[e+4892>>2]=c[(c[w>>2]|0)+(c[(c[x>>2]|0)+(m<<2)>>2]|0)>>2];H=w;I=x}if((t&1|0)==0){x=2-(-((t&v|0)==0|0)&3)&255;a[e+4907|0]=x;a[e+4899|0]=x}else{x=c[H>>2]|0;w=(c[(c[I>>2]|0)+(o<<2)>>2]|0)+6|0;a[e+4899|0]=a[x+(w-(d[k]|0))|0]|0;a[e+4907|0]=a[x+(w-(d[k+1|0]|0))|0]|0}if((u&1|0)==0){w=2-(-((u&v|0)==0|0)&3)&255;a[e+4923|0]=w;a[e+4915|0]=w;break}else{w=c[H>>2]|0;x=(c[(c[I>>2]|0)+(p<<2)>>2]|0)+6|0;a[e+4915|0]=a[w+(x-(d[k+2|0]|0))|0]|0;a[e+4923|0]=a[w+(x-(d[k+3|0]|0))|0]|0;break}}}while(0);do{if((r|0)==0){c[e+5188>>2]=1077952576;c[e+5228>>2]=1077952576;c[e+5268>>2]=1077952576;J=e+5304|0}else{x=e+5304|0;w=c[x>>2]|0;c[e+5188>>2]=c[w+(m*48|0)+12>>2];if((c[e+4788>>2]|0)==0){c[e+5228>>2]=c[w+(m*48|0)+28>>2];c[e+5268>>2]=c[w+(m*48|0)+44>>2];J=x;break}else{c[e+5228>>2]=c[w+(m*48|0)+20>>2];c[e+5268>>2]=c[w+(m*48|0)+36>>2];J=x;break}}}while(0);x=e+6136|0;w=0;E=t;while(1){do{if((E|0)==0){K=w<<4;a[K+99+(e+5184)|0]=64;a[K+91+(e+5184)|0]=64;a[K+59+(e+5184)|0]=64;a[K+51+(e+5184)|0]=64;a[K+19+(e+5184)|0]=64;a[(K|11)+(e+5184)|0]=64}else{K=c[h+(w<<2)>>2]|0;L=c[J>>2]|0;M=w<<1;N=k+(M+8)|0;O=w<<4;a[(O|11)+(e+5184)|0]=a[(d[N]|0)+(L+(K*48|0))|0]|0;P=k+(M+9)|0;a[O+19+(e+5184)|0]=a[(d[P]|0)+(L+(K*48|0))|0]|0;Q=c[x>>2]|0;if((Q|0)==3){a[O+51+(e+5184)|0]=a[(d[N]|0)+16+(L+(K*48|0))|0]|0;a[O+59+(e+5184)|0]=a[(d[P]|0)+16+(L+(K*48|0))|0]|0;a[O+91+(e+5184)|0]=a[(d[N]|0)+32+(L+(K*48|0))|0]|0;a[O+99+(e+5184)|0]=a[(d[P]|0)+32+(L+(K*48|0))|0]|0;break}else if((Q|0)==2){a[O+51+(e+5184)|0]=a[(d[N]|0)+14+(L+(K*48|0))|0]|0;a[O+59+(e+5184)|0]=a[(d[P]|0)+14+(L+(K*48|0))|0]|0;a[O+91+(e+5184)|0]=a[(d[N]|0)+30+(L+(K*48|0))|0]|0;a[O+99+(e+5184)|0]=a[(d[P]|0)+30+(L+(K*48|0))|0]|0;break}else{P=w<<3;a[P+51+(e+5184)|0]=a[(d[k+(M+12)|0]|0)+(L+(K*48|0))|0]|0;a[P+91+(e+5184)|0]=a[(d[k+(M+13)|0]|0)+(L+(K*48|0))|0]|0;break}}}while(0);v=w+1|0;if((v|0)>=2){break a}w=v;E=c[j+(v<<2)>>2]|0}}}while(0);do{if((f&120|0)==0){if((f&256|0)==0){R=r>>>24;S=R&1;T=t>>>24;U=T&1;V=U+S|0;W=e+5712|0;c[W>>2]=V;i=g;return}if((c[e+197872>>2]|0)!=0){break}R=r>>>24;S=R&1;T=t>>>24;U=T&1;V=U+S|0;W=e+5712|0;c[W>>2]=V;i=g;return}}while(0);j=c[e+6108>>2]|0;J=e+199428|0;if((c[J>>2]|0)==0){R=r>>>24;S=R&1;T=t>>>24;U=T&1;V=U+S|0;W=e+5712|0;c[W>>2]=V;i=g;return}h=(r|0)!=0?-1:-16843010;I=(f&80|0)==0;H=(t|0)!=0?-1:-2;C=e+6100|0;D=o<<2|1;G=(s|0)!=0?-1:-2;F=(q|0)!=0?-1:-2;B=e+4884|0;E=j<<1;w=j+3|0;x=l<<2;v=(f&2304|0)==0;A=e+177088|0;z=e+177092|0;y=(q&128|0)!=0;K=(r&128|0)!=0;L=(s&128|0)==0;M=(t&128|0)==0;P=(u&128|0)==0;O=j*3|0;N=n<<2|2;Q=m<<2;X=Q|2;Y=Q|3;Q=0;do{Z=c[e+4084+(Q<<2)>>2]|0;_=c[e+4052+(Q<<2)>>2]|0;$=12288<<(Q<<1);do{if(($&f|0)!=0){if(($&r|0)==0){TGb(e+5312+(Q*160|0)+16|0,0,16)|0;c[e+5632+(Q*40|0)+4>>2]=h}else{aa=(c[(c[C>>2]|0)+(m<<2)>>2]|0)+O|0;ca=_+(aa<<2)|0;da=c[ca+4>>2]|0;ea=e+5312+(Q*160|0)+16|0;c[ea>>2]=c[ca>>2];c[ea+4>>2]=da;da=_+(aa<<2)+8|0;aa=c[da+4>>2]|0;ea=e+5312+(Q*160|0)+24|0;c[ea>>2]=c[da>>2];c[ea+4>>2]=aa;aa=a[Z+X|0]|0;a[e+5632+(Q*40|0)+5|0]=aa;a[e+5632+(Q*40|0)+4|0]=aa;aa=a[Z+Y|0]|0;a[e+5632+(Q*40|0)+7|0]=aa;a[e+5632+(Q*40|0)+6|0]=aa}aa=(t&$|0)==0;do{if(I){if(aa){c[e+5312+(Q*160|0)+44>>2]=0;a[e+5632+(Q*40|0)+11|0]=H;break}else{c[e+5312+(Q*160|0)+44>>2]=c[_+((c[(c[C>>2]|0)+(o<<2)>>2]|0)+3+(ba(d[k]|0,j)|0)<<2)>>2];a[e+5632+(Q*40|0)+11|0]=a[Z+((a[k]&254)+D)|0]|0;break}}else{if(aa){c[e+5312+(Q*160|0)+44>>2]=0;c[e+5312+(Q*160|0)+76>>2]=0;a[e+5632+(Q*40|0)+19|0]=H;a[e+5632+(Q*40|0)+11|0]=H}else{ea=(c[(c[C>>2]|0)+(o<<2)>>2]|0)+3|0;c[e+5312+(Q*160|0)+44>>2]=c[_+((ba(d[k]|0,j)|0)+ea<<2)>>2];da=k+1|0;c[e+5312+(Q*160|0)+76>>2]=c[_+((ba(d[da]|0,j)|0)+ea<<2)>>2];a[e+5632+(Q*40|0)+11|0]=a[Z+((a[k]&254)+D)|0]|0;a[e+5632+(Q*40|0)+19|0]=a[Z+((a[da]&254)+D)|0]|0}if((u&$|0)==0){c[e+5312+(Q*160|0)+108>>2]=0;c[e+5312+(Q*160|0)+140>>2]=0;da=(u|0)!=0?-1:-2;a[e+5632+(Q*40|0)+35|0]=da;a[e+5632+(Q*40|0)+27|0]=da;break}else{da=(c[(c[C>>2]|0)+(p<<2)>>2]|0)+3|0;ea=p<<2|1;ca=k+2|0;c[e+5312+(Q*160|0)+108>>2]=c[_+((ba(d[ca]|0,j)|0)+da<<2)>>2];fa=k+3|0;c[e+5312+(Q*160|0)+140>>2]=c[_+((ba(d[fa]|0,j)|0)+da<<2)>>2];a[e+5632+(Q*40|0)+27|0]=a[Z+((a[ca]&254)+ea)|0]|0;a[e+5632+(Q*40|0)+35|0]=a[Z+((a[fa]&254)+ea)|0]|0;break}}}while(0);if(($&s|0)==0){c[e+5312+(Q*160|0)+32>>2]=0;a[e+5632+(Q*40|0)+8|0]=G;ga=G}else{c[e+5312+(Q*160|0)+32>>2]=c[_+((c[(c[C>>2]|0)+(n<<2)>>2]|0)+O<<2)>>2];aa=a[Z+N|0]|0;a[e+5632+(Q*40|0)+8|0]=aa;ga=aa}aa=e+5632+(Q*40|0)+6|0;do{if((a[aa]|ga)<<24>>24<0){if(($&q|0)==0){c[e+5312+(Q*160|0)+12>>2]=0;a[e+5632+(Q*40|0)+3|0]=F;break}else{ea=c[B>>2]|0;c[e+5312+(Q*160|0)+12>>2]=c[_+(w+(c[(c[C>>2]|0)+(l<<2)>>2]|0)+(ea&E)<<2)>>2];a[e+5632+(Q*40|0)+3|0]=a[Z+(x|ea&2|1)|0]|0;break}}}while(0);if(v){a[e+5632+(Q*40|0)+30|0]=-2;a[e+5632+(Q*40|0)+14|0]=-2;c[e+5312+(Q*160|0)+56>>2]=0;c[e+5312+(Q*160|0)+120>>2]=0;if((c[A>>2]|0)==0){break}}else{if((c[A>>2]|0)==0){break}}if((c[z>>2]|0)==0){do{if(y){ea=e+5632+(Q*40|0)+3|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+14|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+7|0;a[fa]=a[fa]<<1}}while(0);do{if(K){fa=e+5632+(Q*40|0)+4|0;ea=a[fa]|0;if(ea<<24>>24>-1){a[fa]=ea<<24>>24>>>1;ea=e+5312+(Q*160|0)+18|0;b[ea>>1]=b[ea>>1]<<1;ea=e+426592+(Q*80|0)+9|0;a[ea]=a[ea]<<1}ea=e+5632+(Q*40|0)+5|0;fa=a[ea]|0;if(fa<<24>>24>-1){a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+22|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+11|0;a[fa]=a[fa]<<1}fa=a[aa]|0;if(fa<<24>>24>-1){a[aa]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+26|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+13|0;a[fa]=a[fa]<<1}fa=e+5632+(Q*40|0)+7|0;ea=a[fa]|0;if(!(ea<<24>>24>-1)){break}a[fa]=ea<<24>>24>>>1;ea=e+5312+(Q*160|0)+30|0;b[ea>>1]=b[ea>>1]<<1;ea=e+426592+(Q*80|0)+15|0;a[ea]=a[ea]<<1}}while(0);do{if(!L){ea=e+5632+(Q*40|0)+8|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+34|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+17|0;a[fa]=a[fa]<<1}}while(0);do{if(!M){fa=e+5632+(Q*40|0)+11|0;ea=a[fa]|0;if(ea<<24>>24>-1){a[fa]=ea<<24>>24>>>1;ea=e+5312+(Q*160|0)+46|0;b[ea>>1]=b[ea>>1]<<1;ea=e+426592+(Q*80|0)+23|0;a[ea]=a[ea]<<1;if(M){break}}ea=e+5632+(Q*40|0)+19|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+78|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+39|0;a[fa]=a[fa]<<1}}while(0);if(P){break}fa=e+5632+(Q*40|0)+27|0;ea=a[fa]|0;if(ea<<24>>24>-1){a[fa]=ea<<24>>24>>>1;ea=e+5312+(Q*160|0)+110|0;b[ea>>1]=b[ea>>1]<<1;ea=e+426592+(Q*80|0)+55|0;a[ea]=a[ea]<<1;if(P){break}}ea=e+5632+(Q*40|0)+35|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+142|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+71|0;a[fa]=a[fa]<<1;break}else{do{if(!y){fa=e+5632+(Q*40|0)+3|0;ea=a[fa]|0;if(!(ea<<24>>24>-1)){break}a[fa]=ea<<1;ea=e+5312+(Q*160|0)+14|0;b[ea>>1]=(b[ea>>1]|0)/2|0;ea=e+426592+(Q*80|0)+7|0;a[ea]=(d[ea]|0)>>>1}}while(0);do{if(!K){ea=e+5632+(Q*40|0)+4|0;fa=a[ea]|0;if(fa<<24>>24>-1){a[ea]=fa<<1;fa=e+5312+(Q*160|0)+18|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+9|0;a[fa]=(d[fa]|0)>>>1}fa=e+5632+(Q*40|0)+5|0;ea=a[fa]|0;if(ea<<24>>24>-1){a[fa]=ea<<1;ea=e+5312+(Q*160|0)+22|0;b[ea>>1]=(b[ea>>1]|0)/2|0;ea=e+426592+(Q*80|0)+11|0;a[ea]=(d[ea]|0)>>>1}ea=a[aa]|0;if(ea<<24>>24>-1){a[aa]=ea<<1;ea=e+5312+(Q*160|0)+26|0;b[ea>>1]=(b[ea>>1]|0)/2|0;ea=e+426592+(Q*80|0)+13|0;a[ea]=(d[ea]|0)>>>1}ea=e+5632+(Q*40|0)+7|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<1;fa=e+5312+(Q*160|0)+30|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+15|0;a[fa]=(d[fa]|0)>>>1}}while(0);do{if(L){aa=e+5632+(Q*40|0)+8|0;fa=a[aa]|0;if(!(fa<<24>>24>-1)){break}a[aa]=fa<<1;fa=e+5312+(Q*160|0)+34|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+17|0;a[fa]=(d[fa]|0)>>>1}}while(0);do{if(M){fa=e+5632+(Q*40|0)+11|0;aa=a[fa]|0;if(aa<<24>>24>-1){a[fa]=aa<<1;aa=e+5312+(Q*160|0)+46|0;b[aa>>1]=(b[aa>>1]|0)/2|0;aa=e+426592+(Q*80|0)+23|0;a[aa]=(d[aa]|0)>>>1}aa=e+5632+(Q*40|0)+19|0;fa=a[aa]|0;if(!(fa<<24>>24>-1)){break}a[aa]=fa<<1;fa=e+5312+(Q*160|0)+78|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+39|0;a[fa]=(d[fa]|0)>>>1}}while(0);if(!P){break}fa=e+5632+(Q*40|0)+27|0;aa=a[fa]|0;if(aa<<24>>24>-1){a[fa]=aa<<1;aa=e+5312+(Q*160|0)+110|0;b[aa>>1]=(b[aa>>1]|0)/2|0;aa=e+426592+(Q*80|0)+55|0;a[aa]=(d[aa]|0)>>>1}aa=e+5632+(Q*40|0)+35|0;fa=a[aa]|0;if(!(fa<<24>>24>-1)){break}a[aa]=fa<<1;fa=e+5312+(Q*160|0)+142|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+71|0;a[fa]=(d[fa]|0)>>>1;break}}}while(0);Q=Q+1|0;}while(Q>>>0<(c[J>>2]|0)>>>0);R=r>>>24;S=R&1;T=t>>>24;U=T&1;V=U+S|0;W=e+5712|0;c[W>>2]=V;i=g;return}function Uda(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0;m=i;i=i+64|0;n=m|0;o=(l|0)<9;do{if(o){if((l|0)==4){p=c[2194377]|0;q=f+8|0;r=c[q>>2]|0;s=(c[f>>2]|0)+(r>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>24;s=b[p+(t<<2)>>1]|0;c[q>>2]=(b[p+(t<<2)+2>>1]|0)+r;u=s;break}else{s=c[2202835]|0;r=f+8|0;t=c[r>>2]|0;p=(c[f>>2]|0)+(t>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(t&7)>>>19;p=b[s+(q<<2)>>1]|0;c[r>>2]=(b[s+(q<<2)+2>>1]|0)+t;u=p;break}}else{if((h|0)>47){p=d[473312+((h<<4)-768)|0]|0;t=(d[p-8+(e+5184)|0]|0)+(d[p-1+(e+5184)|0]|0)|0;if((t|0)<64){v=(t+1|0)>>>1}else{v=t}t=c[8776156+((c[1402896+((v&31)<<2)>>2]|0)*20|0)>>2]|0;p=f+8|0;q=c[p>>2]|0;s=c[f>>2]|0;r=s+(q>>>3)|0;w=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)>>>24;r=b[t+(w<<2)>>1]|0;x=b[t+(w<<2)+2>>1]|0;w=x<<16>>16;if(x<<16>>16<0){x=q+8|0;y=s+(x>>>3)|0;s=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(x&7)>>>((w+32|0)>>>0))+r|0;z=b[t+(s<<2)+2>>1]|0;A=x;B=b[t+(s<<2)>>1]|0}else{z=w;A=q;B=r}c[p>>2]=z+A;u=B;break}else{p=d[473312+h|0]|0;r=(d[p-8+(e+5184)|0]|0)+(d[p-1+(e+5184)|0]|0)|0;if((r|0)<64){C=(r+1|0)>>>1}else{C=r}r=c[8776156+((c[1402896+((C&31)<<2)>>2]|0)*20|0)>>2]|0;p=f+8|0;q=c[p>>2]|0;w=c[f>>2]|0;s=w+(q>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(q&7)>>>24;s=b[r+(t<<2)>>1]|0;x=b[r+(t<<2)+2>>1]|0;t=x<<16>>16;if(x<<16>>16<0){x=q+8|0;y=w+(x>>>3)|0;w=((fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(x&7)>>>((t+32|0)>>>0))+s|0;D=b[r+(w<<2)+2>>1]|0;E=x;F=b[r+(w<<2)>>1]|0}else{D=t;E=q;F=s}c[p>>2]=D+E;u=F;break}}}while(0);F=u>>2;a[(d[473312+h|0]|0)+(e+5184)|0]=F;if((F|0)==0){G=0;i=m;return G|0}if(F>>>0>l>>>0){E=c[e+427380>>2]|0;yDb(c[e>>2]|0,16,2332632,(H=i,i=i+24|0,c[H>>2]=c[e+427376>>2],c[H+8>>2]=E,c[H+16>>2]=F,H)|0);i=H;G=-1;i=m;return G|0}E=u&3;u=c[f>>2]|0;D=f+8|0;f=c[D>>2]|0;C=u+(f>>>3)|0;B=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(f&7);C=B>>>29;A=f+E|0;c[D>>2]=A;f=n|0;c[f>>2]=1-(B>>>30&2);c[n+4>>2]=1-(C&2);c[n+8>>2]=1-(C<<1&2);a:do{if((E|0)<(F|0)){C=(E|0)!=3;B=(F|0)>10&C;z=B&1;v=u+(A>>>3)|0;p=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(A&7)>>>24;v=a[8853472+(z<<9)+(p<<1)|0]|0;s=v<<24>>24;q=A+(a[8853472+(z<<9)+(p<<1)+1|0]|0)|0;c[D>>2]=q;if(v<<24>>24>99){v=s-100|0;if((v|0)==8){p=u+(q>>>3)|0;z=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(q&7);p=z>>>0>65535>>>0;t=p?z>>>16:z;z=p?16:0;if((t&65280|0)==0){I=z;J=t}else{I=z|8;J=t>>>8}t=32-I-(d[1191992+J|0]|0)|0;z=t+q|0;c[D>>2]=z;K=s-101+t|0;L=z}else{K=v;L=q}do{if((K|0)<14){if(!B){M=K;N=L;break}v=d[u+(L>>>3)|0]<<(L&7)>>>7;z=L+1|0;c[D>>2]=z;M=v&1|K<<1;N=z}else{if((K|0)==14){z=u+(L>>>3)|0;if(B){v=d[z]<<(L&7)>>>7;t=L+1|0;c[D>>2]=t;M=v&1|28;N=t;break}else{t=z;z=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(L&7)>>>28;t=L+4|0;c[D>>2]=t;M=z+14|0;N=t;break}}do{if((K|0)>15){if((K|0)<=28){t=K-3|0;O=(1<<t)-4066|0;P=t;break}yDb(c[e>>2]|0,16,2308328,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;G=-1;i=m;return G|0}else{O=30;P=K-3|0}}while(0);t=u+(L>>>3)|0;z=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(L&7)>>>((35-K|0)>>>0);t=P+L|0;c[D>>2]=t;M=z+O|0;N=t}}while(0);B=C?M+2|0:M;t=B&1;c[n+(E<<2)>>2]=(B+2>>1^-t)+t;Q=2;R=N}else{t=((s>>31|1)&-(C&1))+s|0;c[n+(E<<2)>>2]=t;Q=(t+3|0)>>>0>6>>>0?2:1;R=q}t=E+1|0;if((t|0)<(F|0)){S=Q;T=t;U=R}else{V=R;break}while(1){t=u+(U>>>3)|0;B=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(U&7)>>>24;t=a[8853472+(S<<9)+(B<<1)|0]|0;z=t<<24>>24;v=U+(a[8853472+(S<<9)+(B<<1)+1|0]|0)|0;c[D>>2]=v;if(t<<24>>24>99){t=z-100|0;if((t|0)==8){B=u+(v>>>3)|0;p=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7);B=p>>>0>65535>>>0;w=B?p>>>16:p;p=B?16:0;if((w&65280|0)==0){W=p;X=w}else{W=p|8;X=w>>>8}w=32-W-(d[1191992+X|0]|0)|0;p=w+v|0;c[D>>2]=p;Y=z-101+w|0;Z=p}else{Y=t;Z=v}if((Y|0)<15){t=u+(Z>>>3)|0;p=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(Z&7)>>>((32-S|0)>>>0);t=Z+S|0;c[D>>2]=t;_=p+(Y<<S)|0;$=t}else{t=15<<S;if((Y|0)>15){if((Y|0)>28){break}p=Y-3|0;aa=t-4096+(1<<p)|0;ca=p}else{aa=t;ca=Y-3|0}t=u+(Z>>>3)|0;p=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(Z&7)>>>((35-Y|0)>>>0);t=ca+Z|0;c[D>>2]=t;_=p+aa|0;$=t}t=_&1;da=(_+2>>1^-t)+t|0;ea=$}else{da=z;ea=v}c[n+(T<<2)>>2]=da;v=c[1402864+(S<<2)>>2]|0;z=T+1|0;if((z|0)<(F|0)){S=((v+da|0)>>>0>v<<1>>>0)+S|0;T=z;U=ea}else{V=ea;break a}}yDb(c[e>>2]|0,16,2308328,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;G=-1094995529;i=m;return G|0}else{V=A}}while(0);do{if((F|0)==(l|0)){fa=0;ga=V;ha=F-1|0}else{if(!o){A=F-1|0;ea=c[2858084+(A*20|0)>>2]|0;U=u+(V>>>3)|0;T=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(V&7)>>>23;U=b[ea+(T<<2)>>1]|0;S=(b[ea+(T<<2)+2>>1]|0)+V|0;c[D>>2]=S;fa=U;ga=S;ha=A;break}A=F-1|0;if((l|0)==4){S=c[8776420+(A*20|0)>>2]|0;U=u+(V>>>3)|0;T=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(V&7)>>>29;U=b[S+(T<<2)>>1]|0;ea=(b[S+(T<<2)+2>>1]|0)+V|0;c[D>>2]=ea;fa=U;ga=ea;ha=A;break}else{ea=c[8778428+(A*20|0)>>2]|0;U=u+(V>>>3)|0;T=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(V&7)>>>27;U=b[ea+(T<<2)>>1]|0;S=(b[ea+(T<<2)+2>>1]|0)+V|0;c[D>>2]=S;fa=U;ga=S;ha=A;break}}}while(0);V=j+(ha+fa)|0;ha=(h|0)>47;h=c[f>>2]|0;do{if((c[e+4752>>2]|0)==0){if(ha){b[g+(d[V]<<1)>>1]=h;if((F|0)>1&(fa|0)>0){f=1;j=fa;l=V;o=ga;while(1){if((j|0)<7){A=c[4545580+((j-1|0)*20|0)>>2]|0;S=u+(o>>>3)|0;U=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(o&7)>>>29;ia=b[A+(U<<2)>>1]|0;ja=(b[A+(U<<2)+2>>1]|0)+o|0}else{U=c[1136521]|0;A=u+(o>>>3)|0;S=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(o&7)>>>26;A=b[U+(S<<2)>>1]|0;T=b[U+(S<<2)+2>>1]|0;S=T<<16>>16;if(T<<16>>16<0){T=o+6|0;ea=u+(T>>>3)|0;da=((fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(T&7)>>>((S+32|0)>>>0))+A|0;ka=b[U+(da<<2)+2>>1]|0;la=T;ma=b[U+(da<<2)>>1]|0}else{ka=S;la=o;ma=A}ia=ma;ja=ka+la|0}c[D>>2]=ja;A=j-ia|0;S=l+~ia|0;b[g+(d[S]<<1)>>1]=c[n+(f<<2)>>2];da=f+1|0;if((da|0)<(F|0)&(A|0)>0){f=da;j=A;l=S;o=ja}else{na=da;oa=A;pa=S;break}}}else{na=1;oa=fa;pa=V}if((na|0)<(F|0)){qa=na;ra=pa}else{sa=oa;break}while(1){o=ra-1|0;b[g+(d[o]<<1)>>1]=c[n+(qa<<2)>>2];l=qa+1|0;if((l|0)<(F|0)){qa=l;ra=o}else{sa=oa;break}}}else{o=d[V]|0;b[g+(o<<1)>>1]=((ba(c[k+(o<<2)>>2]|0,h)|0)+32|0)>>>6;if((F|0)>1&(fa|0)>0){o=1;l=fa;j=V;f=ga;while(1){if((l|0)<7){S=c[4545580+((l-1|0)*20|0)>>2]|0;A=u+(f>>>3)|0;da=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(f&7)>>>29;ta=b[S+(da<<2)>>1]|0;ua=(b[S+(da<<2)+2>>1]|0)+f|0}else{da=c[1136521]|0;S=u+(f>>>3)|0;A=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(f&7)>>>26;S=b[da+(A<<2)>>1]|0;U=b[da+(A<<2)+2>>1]|0;A=U<<16>>16;if(U<<16>>16<0){U=f+6|0;T=u+(U>>>3)|0;ea=((fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(U&7)>>>((A+32|0)>>>0))+S|0;va=b[da+(ea<<2)+2>>1]|0;wa=U;xa=b[da+(ea<<2)>>1]|0}else{va=A;wa=f;xa=S}ta=xa;ua=va+wa|0}c[D>>2]=ua;S=l-ta|0;A=j+~ta|0;ea=d[A]|0;b[g+(ea<<1)>>1]=((ba(c[k+(ea<<2)>>2]|0,c[n+(o<<2)>>2]|0)|0)+32|0)>>>6;ea=o+1|0;if((ea|0)<(F|0)&(S|0)>0){o=ea;l=S;j=A;f=ua}else{ya=ea;za=S;Aa=A;break}}}else{ya=1;za=fa;Aa=V}if((ya|0)<(F|0)){Ba=ya;Ca=Aa}else{sa=za;break}while(1){f=Ca-1|0;j=d[f]|0;b[g+(j<<1)>>1]=((ba(c[k+(j<<2)>>2]|0,c[n+(Ba<<2)>>2]|0)|0)+32|0)>>>6;j=Ba+1|0;if((j|0)<(F|0)){Ba=j;Ca=f}else{sa=za;break}}}}else{f=d[V]|0;if(ha){j=g;c[j+(f<<2)>>2]=h;if((F|0)>1&(fa|0)>0){l=1;o=fa;A=V;while(1){if((o|0)<7){S=c[4545580+((o-1|0)*20|0)>>2]|0;ea=c[D>>2]|0;da=u+(ea>>>3)|0;U=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ea&7)>>>29;Da=b[S+(U<<2)>>1]|0;Ea=(b[S+(U<<2)+2>>1]|0)+ea|0}else{ea=c[1136521]|0;U=c[D>>2]|0;S=u+(U>>>3)|0;da=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(U&7)>>>26;S=b[ea+(da<<2)>>1]|0;T=b[ea+(da<<2)+2>>1]|0;da=T<<16>>16;if(T<<16>>16<0){T=U+6|0;$=u+(T>>>3)|0;_=((fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(T&7)>>>((da+32|0)>>>0))+S|0;Fa=b[ea+(_<<2)+2>>1]|0;Ga=T;Ha=b[ea+(_<<2)>>1]|0}else{Fa=da;Ga=U;Ha=S}Da=Ha;Ea=Fa+Ga|0}c[D>>2]=Ea;S=o-Da|0;U=A+~Da|0;c[j+(d[U]<<2)>>2]=c[n+(l<<2)>>2];da=l+1|0;if((da|0)<(F|0)&(S|0)>0){l=da;o=S;A=U}else{Ia=da;Ja=S;Ka=U;break}}}else{Ia=1;Ja=fa;Ka=V}if((Ia|0)<(F|0)){La=Ia;Ma=Ka}else{sa=Ja;break}while(1){A=Ma-1|0;c[j+(d[A]<<2)>>2]=c[n+(La<<2)>>2];o=La+1|0;if((o|0)<(F|0)){La=o;Ma=A}else{sa=Ja;break}}}else{j=g;c[j+(f<<2)>>2]=(ba(c[k+(f<<2)>>2]|0,h)|0)+32>>6;if((F|0)>1&(fa|0)>0){A=1;o=fa;l=V;while(1){if((o|0)<7){U=c[4545580+((o-1|0)*20|0)>>2]|0;S=c[D>>2]|0;da=u+(S>>>3)|0;_=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(S&7)>>>29;Na=b[U+(_<<2)>>1]|0;Oa=(b[U+(_<<2)+2>>1]|0)+S|0}else{S=c[1136521]|0;_=c[D>>2]|0;U=u+(_>>>3)|0;da=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(_&7)>>>26;U=b[S+(da<<2)>>1]|0;ea=b[S+(da<<2)+2>>1]|0;da=ea<<16>>16;if(ea<<16>>16<0){ea=_+6|0;T=u+(ea>>>3)|0;$=((fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(ea&7)>>>((da+32|0)>>>0))+U|0;Pa=b[S+($<<2)+2>>1]|0;Qa=ea;Ra=b[S+($<<2)>>1]|0}else{Pa=da;Qa=_;Ra=U}Na=Ra;Oa=Pa+Qa|0}c[D>>2]=Oa;U=o-Na|0;_=l+~Na|0;da=d[_]|0;c[j+(da<<2)>>2]=(ba(c[k+(da<<2)>>2]|0,c[n+(A<<2)>>2]|0)|0)+32>>6;da=A+1|0;if((da|0)<(F|0)&(U|0)>0){A=da;o=U;l=_}else{Sa=da;Ta=U;Ua=_;break}}}else{Sa=1;Ta=fa;Ua=V}if((Sa|0)<(F|0)){Va=Sa;Wa=Ua}else{sa=Ta;break}while(1){l=Wa-1|0;o=d[l]|0;c[j+(o<<2)>>2]=(ba(c[k+(o<<2)>>2]|0,c[n+(Va<<2)>>2]|0)|0)+32>>6;o=Va+1|0;if((o|0)<(F|0)){Va=o;Wa=l}else{sa=Ta;break}}}}}while(0);if((sa|0)>=0){G=0;i=m;return G|0}sa=c[e+427380>>2]|0;yDb(c[e>>2]|0,16,2289696,(H=i,i=i+16|0,c[H>>2]=c[e+427376>>2],c[H+8>>2]=sa,H)|0);i=H;G=-1;i=m;return G|0}function Vda(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=a+2524|0;d=c[b>>2]|0;e=c[d+1604+(((c[a+177100>>2]|0)==2)<<2)>>2]|0;f=c[a+307804>>2]|0;g=a+199420|0;do{if((c[a+177088>>2]|0)==0){h=c[g>>2]|0}else{i=c[d+1604>>2]|0;j=c[a+307796>>2]|0;k=c[g>>2]|0;if((k&2147483647|0)==0){l=d;m=k}else{k=0;do{n=k+16|0;o=c[a+199440+(n*2224|0)+1612>>2]|0;p=j-o|0;if((p|0)<-128){q=-128;r=7}else{s=(p|0)>127?127:p;if((s|0)==0){t=256}else{q=s;r=7}}do{if((r|0)==7){r=0;if((c[a+199440+(n*2224|0)+1628>>2]|0)!=0){t=256;break}s=i-o|0;if((s|0)<-128){u=-128}else{u=(s|0)>127?127:s}s=(ba(((((q|0)>-1?q:-q|0)>>1)+16384|0)/(q|0)|0,u)|0)+32>>6;if((s|0)<-1024){t=-1024;break}t=(s|0)>1023?1023:s}}while(0);c[a+198012+(k<<2)>>2]=t;k=k+1|0;v=c[g>>2]|0;}while(k>>>0<v<<1>>>0);l=c[b>>2]|0;m=v}k=c[l+1608>>2]|0;i=c[a+307800>>2]|0;if((m&2147483647|0)==0){h=m;break}else{w=0}while(1){j=w+16|0;o=c[a+199440+(j*2224|0)+1612>>2]|0;n=i-o|0;if((n|0)<-128){x=-128;r=26}else{s=(n|0)>127?127:n;if((s|0)==0){y=256}else{x=s;r=26}}do{if((r|0)==26){r=0;if((c[a+199440+(j*2224|0)+1628>>2]|0)!=0){y=256;break}s=k-o|0;if((s|0)<-128){z=-128}else{z=(s|0)>127?127:s}s=(ba(((((x|0)>-1?x:-x|0)>>1)+16384|0)/(x|0)|0,z)|0)+32>>6;if((s|0)<-1024){y=-1024;break}y=(s|0)>1023?1023:s}}while(0);c[a+198140+((w^1)<<2)>>2]=y;o=w+1|0;j=c[g>>2]|0;if(o>>>0<j<<1>>>0){w=o}else{h=j;break}}}}while(0);w=a+199420|0;if((h|0)==0){return}else{A=0}do{h=c[a+199440+(A*2224|0)+1612>>2]|0;g=f-h|0;if((g|0)<-128){B=-128;r=17}else{y=(g|0)>127?127:g;if((y|0)==0){C=256}else{B=y;r=17}}do{if((r|0)==17){r=0;if((c[a+199440+(A*2224|0)+1628>>2]|0)!=0){C=256;break}y=e-h|0;if((y|0)<-128){D=-128}else{D=(y|0)>127?127:y}y=(ba(((((B|0)>-1?B:-B|0)>>1)+16384|0)/(B|0)|0,D)|0)+32>>6;if((y|0)<-1024){C=-1024;break}C=(y|0)>1023?1023:y}}while(0);c[a+197884+(A<<2)>>2]=C;A=A+1|0;}while(A>>>0<(c[w>>2]|0)>>>0);return}function Wda(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+2524|0;d=c[b>>2]|0;e=a+177100|0;f=c[e>>2]&1^1;g=a+308384|0;h=c[g>>2]&1;i=a+199420|0;c[d+2144+(f<<3)>>2]=c[i>>2];if((c[i>>2]|0)!=0){j=0;do{c[d+1632+(f<<8)+(j<<2)>>2]=c[a+199440+(j*2224|0)+2192>>2]&3|c[a+199440+(j*2224|0)+1616>>2]<<2;j=j+1|0;}while(j>>>0<(c[i>>2]|0)>>>0)}i=a+199424|0;c[d+2144+(f<<3)+4>>2]=c[i>>2];if((c[i>>2]|0)!=0){j=0;do{c[d+1632+(f<<8)+128+(j<<2)>>2]=c[a+306192+(j*2224|0)+2192>>2]&3|c[a+306192+(j*2224|0)+1616>>2]<<2;j=j+1|0;}while(j>>>0<(c[i>>2]|0)>>>0)}i=h^1;if((c[e>>2]|0)==3){h=d+2144|0;j=d+2152|0;k=c[h+4>>2]|0;c[j>>2]=c[h>>2];c[j+4>>2]=k;UGb(d+1888|0,d+1632|0,256)|0}k=a+177088|0;c[d+2160>>2]=c[k>>2];d=a+197880|0;c[d>>2]=0;j=c[e>>2]|0;do{if((j|0)==3){e=c[(c[b>>2]|0)+1612>>2]|0;h=(c[a+307796>>2]|0)-e|0;l=(c[a+307800>>2]|0)-e|0;e=(((h|0)>-1?h:-h|0)|0)>=(((l|0)>-1?l:-l|0)|0)|0;c[a+197876>>2]=e;m=e;n=e}else{e=c[g>>2]|0;if((e&j|0)!=0){m=i;n=f;break}if((c[a+308352>>2]|0)!=0){m=i;n=f;break}c[d>>2]=(e<<1)-3;m=i;n=f}}while(0);if((c[a+177080>>2]|0)!=3){return}if((c[a+197872>>2]|0)!=0){return}f=a+198268|0;Xda(a,f,0,n,m,0);if((c[k>>2]|0)!=0){Xda(a,a+198652|0,0,0,0,1);Xda(a,a+199036|0,0,1,1,1)}Xda(a,f,1,n,m,0);if((c[k>>2]|0)==0){return}Xda(a,a+198652|0,1,0,0,1);Xda(a,a+199036|0,1,1,1,1);return}function Xda(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=(g|0)!=0;g=h?16:0;i=c[a+199420>>2]|0;if(h){j=1;k=(i<<1)+16|0}else{j=(c[a+177100>>2]|0)!=3;k=i}TGb(b+(d*192|0)|0,0,192)|0;i=a+308336+(f<<3)+(d<<2)|0;l=a+308352|0;m=j^1;n=0;o=c[i>>2]|0;while(1){p=n+1|0;a:do{if((o|0)>0){q=(n|0)==(e|0)|m;r=(n^e)+16|0;if(j){s=0;while(1){t=c[a+307824+(f<<8)+(d<<7)+(s<<2)>>2]|0;if((t&3|0)==3){u=p+(t&-4)|0}else{u=t}t=g;while(1){if((t|0)>=(k|0)){break}if((c[a+199440+(t*2224|0)+2192>>2]&3|c[a+199440+(t*2224|0)+1616>>2]<<2|0)==(u|0)){v=13;break}else{t=t+1|0}}do{if((v|0)==13){v=0;if(h){w=t-16^e}else{w=t}if((c[l>>2]|0)!=0){c[b+(d*192|0)+(r+(s<<1)<<2)>>2]=w}if(!q){break}c[b+(d*192|0)+(s<<2)>>2]=w}}while(0);t=s+1|0;x=c[i>>2]|0;if((t|0)<(x|0)){s=t}else{y=x;break a}}}if(h){s=0;while(1){x=c[a+307824+(f<<8)+(d<<7)+(s<<2)>>2]|3;t=g;while(1){if((t|0)>=(k|0)){break}if((c[a+199440+(t*2224|0)+2192>>2]&3|c[a+199440+(t*2224|0)+1616>>2]<<2|0)==(x|0)){v=23;break}else{t=t+1|0}}do{if((v|0)==23){v=0;x=t-16^e;if((c[l>>2]|0)!=0){c[b+(d*192|0)+(r+(s<<1)<<2)>>2]=x}if(!q){break}c[b+(d*192|0)+(s<<2)>>2]=x}}while(0);t=s+1|0;x=c[i>>2]|0;if((t|0)<(x|0)){s=t}else{y=x;break}}}else{s=0;while(1){x=c[a+307824+(f<<8)+(d<<7)+(s<<2)>>2]|3;t=g;while(1){if((t|0)>=(k|0)){break}if((c[a+199440+(t*2224|0)+2192>>2]&3|c[a+199440+(t*2224|0)+1616>>2]<<2|0)==(x|0)){v=31;break}else{t=t+1|0}}do{if((v|0)==31){v=0;if((c[l>>2]|0)!=0){c[b+(d*192|0)+(r+(s<<1)<<2)>>2]=t}if(!q){break}c[b+(d*192|0)+(s<<2)>>2]=t}}while(0);t=s+1|0;x=c[i>>2]|0;if((t|0)<(x|0)){s=t}else{y=x;break}}}}else{y=o}}while(0);if((p|0)<2){n=p;o=y}else{break}}return}function Yda(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;if((c[f+197872>>2]|0)==0){m=c[f+6108>>2]|0;n=c[f+427412>>2]|0;o=f+427380|0;p=c[g>>2]|0;q=p&64;r=c[f+307728>>2]|0;s=(p&128|0)!=0;a:do{if((c[r+(n<<2)>>2]&128|0)==0){if(!s){t=2;u=n;v=130;break}w=c[f+427404>>2]|0;x=(ba(w,c[o>>2]&-2)|0)+(c[f+427376>>2]|0)|0;y=c[r+(x<<2)>>2]|0;z=j|0;c[z>>2]=y;A=c[r+(x+w<<2)>>2]|0;B=j+4|0;c[B>>2]=A;C=w<<2|2;w=m*6|0;if(((A^y)&128|0)==0){D=y;E=A}else{F=y&-129;c[z>>2]=F;z=A&-129;c[B>>2]=z;D=F;E=z}do{if((D&15|0)!=0){if(!((E&15|0)!=0&(q|0)==0)){break}z=p|61712;c[g>>2]=z;G=C;H=w;I=x;J=20744;K=D;L=z;break a}}while(0);z=p|61504;c[g>>2]=z;G=C;H=w;I=x;J=20744;K=D;L=z}else{if(s){t=2;u=(ba(c[f+427404>>2]|0,c[f+197880>>2]|0)|0)+n|0;v=130;break}else{t=0;u=(ba(c[f+427404>>2]|0,(c[o>>2]&-2)+(c[f+197876>>2]|0)|0)|0)+(c[f+427376>>2]|0)|0;v=130;break}}}while(0);b:do{if((v|0)==130){n=c[r+(u<<2)>>2]|0;c[j+4>>2]=n;c[j>>2]=n;do{if((q|0)==0){if((n&15|0)!=0){s=p|20744;c[g>>2]=s;G=t;H=m;I=u;J=20744;K=n;L=s;break b}s=n&48;if((s|0)==0){break}D=p|s|61696;c[g>>2]=D;G=t;H=m;I=u;J=20744;K=n;L=D;break b}}while(0);x=(c[f+6196>>2]|0)==0?20800:20744;w=p|61504;c[g>>2]=w;G=t;H=m;I=u;J=x;K=n;L=w}}while(0);u=c[(c[f+6100>>2]|0)+(I<<2)>>2]|0;m=c[f+307716>>2]|0;t=m+(u<<2)|0;p=c[f+307720>>2]|0;r=p+(u<<2)|0;w=I<<2;I=c[f+307748>>2]|0;x=I+w|0;C=c[f+307752>>2]|0;D=C+w|0;do{if((G|0)==0){if((c[o>>2]&1|0)==0){M=t;N=r;O=x;P=D;break}s=w|2;E=u+(H<<1)|0;M=m+(E<<2)|0;N=p+(E<<2)|0;O=I+s|0;P=C+s|0}else{M=t;N=r;O=x;P=D}}while(0);D=f+198268|0;x=f+198460|0;r=f+197884|0;t=L&128;do{if((c[f+177088>>2]|0)==0){Q=x;R=D;S=r;T=t}else{if((t|0)==0){Q=x;R=D;S=r;T=0;break}C=c[o>>2]&1;Q=f+198652+(C*384|0)+192|0;R=f+198652+(C*384|0)|0;S=f+198012+(C<<7)|0;T=t}}while(0);t=c[f+308352>>2]<<4&K>>3;if((T|0)!=(K&128|0)){o=T>>>6^2;T=(q|0)==0;r=J&65535;D=0;do{x=D&1;C=D>>1;I=f+177112+(D<<1)|0;if(T){v=146}else{if(!((b[I>>1]&256)==0)){v=146}}do{if((v|0)==146){v=0;b[I>>1]=r;p=d[473256+(D<<2)|0]|0;b[f+5672+p>>1]=0;m=p+8|0;b[f+5672+m>>1]=0;if((c[j+(C<<2)>>2]&7|0)!=0){b[f+5632+p>>1]=0;b[f+5632+m>>1]=0;c[f+5312+(p<<2)>>2]=0;u=p+1|0;c[f+5312+(u<<2)>>2]=0;c[f+5312+(m<<2)>>2]=0;w=p+9|0;c[f+5312+(w<<2)>>2]=0;c[f+5472+(p<<2)>>2]=0;c[f+5472+(u<<2)>>2]=0;c[f+5472+(m<<2)>>2]=0;c[f+5472+(w<<2)>>2]=0;break}w=(ba(C,G)|0)+x|0;u=a[O+w|0]|0;if(u<<24>>24>-1){U=R+((u<<24>>24)+t<<2)|0;V=M}else{U=Q+((a[P+w|0]|0)+t<<2)|0;V=N}w=c[U>>2]|0;u=c[S+(w<<2)>>2]|0;s=(w*257|0)&65535;b[f+5632+p>>1]=s;b[f+5632+m>>1]=s;s=(-x&3)+(ba(C,H)|0)|0;w=(b[V+(s<<2)+2>>1]<<o|0)/2|0;E=b[V+(s<<2)>>1]|0;s=(ba(E<<16>>16,u)|0)+128>>8;z=(ba(w,u)|0)+128>>8;u=s&65535|z<<16;c[f+5312+(p<<2)>>2]=u;F=p+1|0;c[f+5312+(F<<2)>>2]=u;c[f+5312+(m<<2)>>2]=u;B=p+9|0;c[f+5312+(B<<2)>>2]=u;u=s-(E&65535)&65535|z-w<<16;c[f+5472+(p<<2)>>2]=u;c[f+5472+(F<<2)>>2]=u;c[f+5472+(m<<2)>>2]=u;c[f+5472+(B<<2)>>2]=u}}while(0);D=D+1|0;}while((D|0)<4);i=h;return}if((L&8|0)!=0){c[f+5684>>2]=0;c[f+5692>>2]=0;c[f+5700>>2]=0;c[f+5708>>2]=0;if((K&7|0)==0){L=a[O]|0;D=L<<24>>24>-1;if(D){W=R+((L<<24>>24)+t<<2)|0}else{W=Q+((a[P]|0)+t<<2)|0}L=c[W>>2]|0;W=c[S+(L<<2)>>2]|0;V=D?M:N;D=b[V>>1]|0;o=(ba(D,W)|0)+128>>8;U=b[V+2>>1]|0;V=(ba(U,W)|0)+128>>8;X=V-U<<16|o-D&65535;Y=V<<16|o&65535;Z=ba(L,16843009)|0}else{X=0;Y=0;Z=0}c[f+5644>>2]=Z;c[f+5652>>2]=Z;c[f+5660>>2]=Z;c[f+5668>>2]=Z;c[f+5360>>2]=Y;c[f+5364>>2]=Y;c[f+5368>>2]=Y;c[f+5372>>2]=Y;c[f+5392>>2]=Y;c[f+5396>>2]=Y;c[f+5400>>2]=Y;c[f+5404>>2]=Y;c[f+5424>>2]=Y;c[f+5428>>2]=Y;c[f+5432>>2]=Y;c[f+5436>>2]=Y;c[f+5456>>2]=Y;c[f+5460>>2]=Y;c[f+5464>>2]=Y;c[f+5468>>2]=Y;c[f+5520>>2]=X;c[f+5524>>2]=X;c[f+5528>>2]=X;c[f+5532>>2]=X;c[f+5552>>2]=X;c[f+5556>>2]=X;c[f+5560>>2]=X;c[f+5564>>2]=X;c[f+5584>>2]=X;c[f+5588>>2]=X;c[f+5592>>2]=X;c[f+5596>>2]=X;c[f+5616>>2]=X;c[f+5620>>2]=X;c[f+5624>>2]=X;c[f+5628>>2]=X;i=h;return}X=(q|0)==0;q=J&65535;Y=(K&7|0)==0;K=(J&8|0)==0;J=H*3|0;Z=0;do{L=Z&1;o=Z>>1;V=f+177112+(Z<<1)|0;if(X){v=163}else{if(!((b[V>>1]&256)==0)){v=163}}do{if((v|0)==163){v=0;b[V>>1]=q;D=Z<<2;U=d[473256+D|0]|0;b[f+5672+U>>1]=0;W=U+8|0;b[f+5672+W>>1]=0;if(!Y){b[f+5632+U>>1]=0;b[f+5632+W>>1]=0;c[f+5312+(U<<2)>>2]=0;G=U+1|0;c[f+5312+(G<<2)>>2]=0;c[f+5312+(W<<2)>>2]=0;r=U+9|0;c[f+5312+(r<<2)>>2]=0;c[f+5472+(U<<2)>>2]=0;c[f+5472+(G<<2)>>2]=0;c[f+5472+(W<<2)>>2]=0;c[f+5472+(r<<2)>>2]=0;break}r=a[O+Z|0]|0;if(r<<24>>24>-1){_=M;$=R+((r<<24>>24)+t<<2)|0}else{_=N;$=Q+((a[P+Z|0]|0)+t<<2)|0}r=c[$>>2]|0;G=c[S+(r<<2)>>2]|0;T=(r*257|0)&65535;b[f+5632+U>>1]=T;b[f+5632+W>>1]=T;if(!K){T=(-L&3)+(ba(J,o)|0)|0;r=b[_+(T<<2)>>1]|0;C=(ba(r<<16>>16,G)|0)+128>>8;x=b[_+(T<<2)+2>>1]|0;T=(ba(x<<16>>16,G)|0)+128>>8;I=T<<16|C&65535;c[f+5312+(U<<2)>>2]=I;n=U+1|0;c[f+5312+(n<<2)>>2]=I;c[f+5312+(W<<2)>>2]=I;u=U+9|0;c[f+5312+(u<<2)>>2]=I;I=T-(x&65535)<<16|C-(r&65535)&65535;c[f+5472+(U<<2)>>2]=I;c[f+5472+(n<<2)>>2]=I;c[f+5472+(W<<2)>>2]=I;c[f+5472+(u<<2)>>2]=I;break}I=L<<1;u=o<<1;W=0;do{n=(ba((W>>1)+u|0,H)|0)+(W&1|I)|0;U=_+(n<<2)|0;r=d[473256+(W+D)|0]|0;C=((ba(b[U>>1]|0,G)|0)+128|0)>>>8;b[f+5312+(r<<2)>>1]=C;x=_+(n<<2)+2|0;n=((ba(b[x>>1]|0,G)|0)+128|0)>>>8;b[f+5312+(r<<2)+2>>1]=n;c[f+5472+(r<<2)>>2]=n-(e[x>>1]|0)<<16|C-(e[U>>1]|0)&65535;W=W+1|0;}while((W|0)<4)}}while(0);Z=Z+1|0;}while((Z|0)<4);i=h;return}Z=c[f+6108>>2]|0;_=c[f+427412>>2]|0;H=c[g>>2]|0;J=H&64;K=(J|0)==0;S=0;$=61440;t=H;while(1){H=a[f+5632+(S*40|0)+11|0]|0;P=a[f+5632+(S*40|0)+4|0]|0;Q=a[f+5632+(S*40|0)+8|0]|0;if(Q<<24>>24==-2){aa=a[f+5632+(S*40|0)+3|0]|0;ca=f+5312+(S*160|0)+12|0}else{aa=Q;ca=f+5312+(S*160|0)+32|0}Q=aa<<24>>24;N=H>>>0>P>>>0?P:H;R=N>>>0>Q>>>0?Q:N;N=k+(S<<2)|0;c[N>>2]=R;do{if((R|0)>-1){M=f+5312+(S*160|0)+44|0;O=f+5312+(S*160|0)+16|0;Y=(H|0)==(R|0);q=(P|0)==(R|0);if(((Y&1)+(q&1)+((Q|0)==(R|0))|0)<=1){if(Y){c[l+(S<<2)>>2]=c[M>>2];da=$;ea=t;break}if(q){c[l+(S<<2)>>2]=c[O>>2];da=$;ea=t;break}else{c[l+(S<<2)>>2]=c[ca>>2];da=$;ea=t;break}}q=b[M>>1]|0;M=q<<16>>16;Y=b[O>>1]|0;O=Y<<16>>16;X=b[ca>>1]|0;o=X<<16>>16;do{if(q<<16>>16>Y<<16>>16){if(!(X<<16>>16>Y<<16>>16)){fa=O;break}fa=(o|0)>(M|0)?M:o}else{if(!(Y<<16>>16>X<<16>>16)){fa=O;break}fa=(o|0)>(M|0)?o:M}}while(0);M=b[f+5312+(S*160|0)+46>>1]|0;o=M<<16>>16;O=b[f+5312+(S*160|0)+18>>1]|0;X=O<<16>>16;Y=b[ca+2>>1]|0;q=Y<<16>>16;do{if(M<<16>>16>O<<16>>16){if(!(Y<<16>>16>O<<16>>16)){ga=X;break}ga=(q|0)>(o|0)?o:q}else{if(!(O<<16>>16>Y<<16>>16)){ga=X;break}ga=(q|0)>(o|0)?q:o}}while(0);c[l+(S<<2)>>2]=ga<<16|fa&65535;da=$;ea=t}else{o=~(12288<<(S<<1));c[l+(S<<2)>>2]=0;c[N>>2]=-1;if(K){q=t&o;c[g>>2]=q;ha=q}else{ha=t}da=$&o;ea=ha}}while(0);N=S+1|0;if((N|0)<2){S=N;$=da;t=ea}else{break}}t=f+427380|0;$=k|0;S=c[$>>2]|0;do{if((S|0)<0){ha=k+4|0;if((c[ha>>2]|0)>=0){ia=da;ja=S;ka=ea;break}c[ha>>2]=0;c[$>>2]=0;if(K){ha=ea|61440;c[g>>2]=ha;la=ha}else{la=ea}ia=da|61440;ja=0;ka=la}else{ia=da;ja=S;ka=ea}}while(0);ea=c[l>>2]|0;S=c[l+4>>2]|0;if((ea|J|S|0)==0){J=ba(ja&255,16843009)|0;c[f+5644>>2]=J;c[f+5652>>2]=J;c[f+5660>>2]=J;c[f+5668>>2]=J;J=ba(c[k+4>>2]&255,16843009)|0;c[f+5684>>2]=J;c[f+5692>>2]=J;c[f+5700>>2]=J;c[f+5708>>2]=J;TGb(f+5360|0,0,16)|0;TGb(f+5392|0,0,16)|0;TGb(f+5424|0,0,16)|0;TGb(f+5456|0,0,16)|0;TGb(f+5520|0,0,16)|0;TGb(f+5552|0,0,16)|0;TGb(f+5584|0,0,16)|0;TGb(f+5616|0,0,16)|0;c[g>>2]=c[g>>2]&-41337|264;i=h;return}J=c[f+307728>>2]|0;l=(ka&128|0)!=0;c:do{if((c[J+(_<<2)>>2]&128|0)==0){if(!l){ma=2;na=_;v=45;break}da=c[f+427404>>2]|0;la=(ba(da,c[t>>2]&-2)|0)+(c[f+427376>>2]|0)|0;$=c[J+(la<<2)>>2]|0;ha=j|0;c[ha>>2]=$;fa=c[J+(la+da<<2)>>2]|0;ga=j+4|0;c[ga>>2]=fa;ca=da<<2|2;da=Z*6|0;if(((fa^$)&128|0)==0){oa=$;pa=fa}else{aa=$&-129;c[ha>>2]=aa;ha=fa&-129;c[ga>>2]=ha;oa=aa;pa=ha}ha=ia|264;do{if((oa&15|0)!=0){if(!((pa&15|0)!=0&K)){break}aa=ka|272;c[g>>2]=aa;qa=ca;ra=da;sa=la;ta=ha;ua=aa;va=oa;break c}}while(0);aa=ka|64;c[g>>2]=aa;qa=ca;ra=da;sa=la;ta=ha;ua=aa;va=oa}else{if(l){ma=2;na=(ba(c[f+427404>>2]|0,c[f+197880>>2]|0)|0)+_|0;v=45;break}else{ma=0;na=(ba(c[f+427404>>2]|0,(c[t>>2]&-2)+(c[f+197876>>2]|0)|0)|0)+(c[f+427376>>2]|0)|0;v=45;break}}}while(0);d:do{if((v|0)==45){_=c[J+(na<<2)>>2]|0;c[j+4>>2]=_;c[j>>2]=_;l=ia|264;do{if(K){if((_&15|0)!=0){oa=ka|264;c[g>>2]=oa;qa=ma;ra=Z;sa=na;ta=l;ua=oa;va=_;break d}oa=_&48;if((oa|0)==0){break}pa=ka|oa|256;c[g>>2]=pa;qa=ma;ra=Z;sa=na;ta=l;ua=pa;va=_;break d}}while(0);ha=(c[f+6196>>2]|0)==0?l+56|0:l;la=ka|64;c[g>>2]=la;qa=ma;ra=Z;sa=na;ta=ha;ua=la;va=_}}while(0);na=c[(c[f+6100>>2]|0)+(sa<<2)>>2]|0;Z=c[f+307716>>2]|0;ma=Z+(na<<2)|0;ka=c[f+307720>>2]|0;ia=ka+(na<<2)|0;J=sa<<2;sa=c[f+307748>>2]|0;la=sa+J|0;ha=c[f+307752>>2]|0;da=ha+J|0;do{if((qa|0)==0){if((c[t>>2]&1|0)==0){wa=ma;xa=ia;ya=la;za=da;break}ca=J|2;pa=na+(ra<<1)|0;wa=Z+(pa<<2)|0;xa=ka+(pa<<2)|0;ya=sa+ca|0;za=ha+ca|0}else{wa=ma;xa=ia;ya=la;za=da}}while(0);if(((ua^va)&128|0)!=0){da=ta&65535;la=((ja&255)*257|0)&65535;ia=c[k+4>>2]|0;ma=((ia&255)*257|0)&65535;ha=f+307820|0;sa=(ja|0)>0?ea:0;ka=(ia|0)>0?S:0;ia=0;Z=0;while(1){na=ia&1;J=ia>>1;t=(ba(J,qa)|0)+na|0;ca=(-na&3)+(ba(J,ra)|0)|0;na=f+177112+(ia<<1)|0;if(K){v=58}else{if((b[na>>1]&256)==0){Aa=Z}else{v=58}}if((v|0)==58){v=0;b[na>>1]=da;na=d[473256+(ia<<2)|0]|0;b[f+5632+na>>1]=la;pa=na+8|0;b[f+5632+pa>>1]=la;b[f+5672+na>>1]=ma;b[f+5672+pa>>1]=ma;do{if((c[j+(J<<2)>>2]&7|0)==0){if((c[ha>>2]|0)!=0){Ba=S;Ca=ea;Da=Z;break}oa=a[ya+t|0]|0;if(oa<<24>>24==0){aa=b[wa+(ca<<2)>>1]|0;ga=aa<<16>>16;if(((aa<<16>>16>-1?ga:-ga|0)|0)>=2){Ba=S;Ca=ea;Da=Z;break}ga=b[wa+(ca<<2)+2>>1]|0;aa=ga<<16>>16;if(((ga<<16>>16>-1?aa:-aa|0)|0)>=2){v=63}}else{v=63}if((v|0)==63){v=0;if(!(oa<<24>>24<0)){Ba=S;Ca=ea;Da=Z;break}if((a[za+t|0]|0)!=0){Ba=S;Ca=ea;Da=Z;break}oa=b[xa+(ca<<2)>>1]|0;aa=oa<<16>>16;if(((oa<<16>>16>-1?aa:-aa|0)|0)>=2){Ba=S;Ca=ea;Da=Z;break}aa=b[xa+(ca<<2)+2>>1]|0;oa=aa<<16>>16;if(((aa<<16>>16>-1?oa:-oa|0)|0)>=2){Ba=S;Ca=ea;Da=Z;break}}Ba=ka;Ca=sa;Da=Z+1|0}else{Ba=S;Ca=ea;Da=Z}}while(0);c[f+5312+(na<<2)>>2]=Ca;ca=na+1|0;c[f+5312+(ca<<2)>>2]=Ca;c[f+5312+(pa<<2)>>2]=Ca;t=na+9|0;c[f+5312+(t<<2)>>2]=Ca;c[f+5472+(na<<2)>>2]=Ba;c[f+5472+(ca<<2)>>2]=Ba;c[f+5472+(pa<<2)>>2]=Ba;c[f+5472+(t<<2)>>2]=Ba;Aa=Da}t=ia+1|0;if((t|0)<4){ia=t;Z=Aa}else{break}}if(!K){i=h;return}if((Aa&3|0)!=0){i=h;return}c[g>>2]=c[g>>2]&-41337|264;i=h;return}if((ua&8|0)!=0){ua=ba(ja&255,16843009)|0;c[f+5644>>2]=ua;c[f+5652>>2]=ua;c[f+5660>>2]=ua;c[f+5668>>2]=ua;ua=c[k+4>>2]|0;Aa=ba(ua&255,16843009)|0;c[f+5684>>2]=Aa;c[f+5692>>2]=Aa;c[f+5700>>2]=Aa;c[f+5708>>2]=Aa;do{if((va&7|0)==0){if((c[f+307820>>2]|0)!=0){Ea=S;Fa=ea;break}Aa=a[ya]|0;if(Aa<<24>>24==0){Z=b[wa>>1]|0;ia=Z<<16>>16;if(((Z<<16>>16>-1?ia:-ia|0)|0)>=2){Ea=S;Fa=ea;break}ia=b[wa+2>>1]|0;Z=ia<<16>>16;if(((ia<<16>>16>-1?Z:-Z|0)|0)>=2){v=80}}else{v=80}if((v|0)==80){if(!(Aa<<24>>24<0)){Ea=S;Fa=ea;break}if((a[za]|0)!=0){Ea=S;Fa=ea;break}Aa=b[xa>>1]|0;Z=Aa<<16>>16;if(((Aa<<16>>16>-1?Z:-Z|0)|0)>=2){Ea=S;Fa=ea;break}Z=b[xa+2>>1]|0;Aa=Z<<16>>16;if(((Z<<16>>16>-1?Aa:-Aa|0)|0)>=2){Ea=S;Fa=ea;break}if(!((c[f+427372>>2]|0)>>>0>33>>>0)){Ea=S;Fa=ea;break}}Ea=(ua|0)>0?S:0;Fa=(ja|0)>0?ea:0}else{Ea=S;Fa=ea}}while(0);c[f+5360>>2]=Fa;c[f+5364>>2]=Fa;c[f+5368>>2]=Fa;c[f+5372>>2]=Fa;c[f+5392>>2]=Fa;c[f+5396>>2]=Fa;c[f+5400>>2]=Fa;c[f+5404>>2]=Fa;c[f+5424>>2]=Fa;c[f+5428>>2]=Fa;c[f+5432>>2]=Fa;c[f+5436>>2]=Fa;c[f+5456>>2]=Fa;c[f+5460>>2]=Fa;c[f+5464>>2]=Fa;c[f+5468>>2]=Fa;c[f+5520>>2]=Ea;c[f+5524>>2]=Ea;c[f+5528>>2]=Ea;c[f+5532>>2]=Ea;c[f+5552>>2]=Ea;c[f+5556>>2]=Ea;c[f+5560>>2]=Ea;c[f+5564>>2]=Ea;c[f+5584>>2]=Ea;c[f+5588>>2]=Ea;c[f+5592>>2]=Ea;c[f+5596>>2]=Ea;c[f+5616>>2]=Ea;c[f+5620>>2]=Ea;c[f+5624>>2]=Ea;c[f+5628>>2]=Ea;i=h;return}Ea=ta&65535;Fa=((ja&255)*257|0)&65535;ua=c[k+4>>2]|0;k=((ua&255)*257|0)&65535;Aa=(va&7|0)==0;va=f+307820|0;Z=(ta&8|0)==0;ta=ra*3|0;ia=(ja|0)==0;ja=(ua|0)==0;ua=f+427372|0;Da=0;Ba=0;while(1){Ca=Da&1;sa=Da>>1;ka=f+177112+(Da<<1)|0;if(K){v=89}else{if((b[ka>>1]&256)==0){Ga=Ba}else{v=89}}do{if((v|0)==89){v=0;b[ka>>1]=Ea;ha=Da<<2;j=d[473256+ha|0]|0;ma=f+5312+(j<<2)|0;c[ma>>2]=ea;la=j+1|0;da=f+5312+(la<<2)|0;c[da>>2]=ea;qa=j+8|0;t=f+5312+(qa<<2)|0;c[t>>2]=ea;ca=j+9|0;J=f+5312+(ca<<2)|0;c[J>>2]=ea;_=f+5472+(j<<2)|0;c[_>>2]=S;l=f+5472+(la<<2)|0;c[l>>2]=S;la=f+5472+(qa<<2)|0;c[la>>2]=S;oa=f+5472+(ca<<2)|0;c[oa>>2]=S;b[f+5632+j>>1]=Fa;b[f+5632+qa>>1]=Fa;b[f+5672+j>>1]=k;b[f+5672+qa>>1]=k;if(!Aa){Ga=Ba;break}if((c[va>>2]|0)!=0){Ga=Ba;break}qa=a[ya+Da|0]|0;j=qa<<24>>24==0;if(!j){if(!(qa<<24>>24<0)){Ga=Ba;break}if((a[za+Da|0]|0)!=0){Ga=Ba;break}if(!((c[ua>>2]|0)>>>0>33>>>0)){Ga=Ba;break}}qa=j?wa:xa;if(!Z){j=(-Ca&3)+(ba(ta,sa)|0)|0;ca=b[qa+(j<<2)>>1]|0;aa=ca<<16>>16;if(((ca<<16>>16>-1?aa:-aa|0)|0)>=2){Ga=Ba;break}aa=b[qa+(j<<2)+2>>1]|0;j=aa<<16>>16;if(((aa<<16>>16>-1?j:-j|0)|0)>=2){Ga=Ba;break}if(ia){c[ma>>2]=0;c[da>>2]=0;c[t>>2]=0;c[J>>2]=0}if(ja){c[_>>2]=0;c[l>>2]=0;c[la>>2]=0;c[oa>>2]=0}Ga=Ba+4|0;break}oa=Ca<<1;la=sa<<1;l=0;_=0;while(1){J=(ba((l>>1)+la|0,ra)|0)+(l&1|oa)|0;t=b[qa+(J<<2)>>1]|0;da=t<<16>>16;do{if(((t<<16>>16>-1?da:-da|0)|0)<2){ma=b[qa+(J<<2)+2>>1]|0;j=ma<<16>>16;if(((ma<<16>>16>-1?j:-j|0)|0)>=2){Ha=_;break}if(ia){c[f+5312+(d[473256+(l+ha)|0]<<2)>>2]=0}if(ja){c[f+5472+(d[473256+(l+ha)|0]<<2)>>2]=0}Ha=_+1|0}else{Ha=_}}while(0);J=l+1|0;if((J|0)<4){l=J;_=Ha}else{break}}if((Ha&3|0)==0){b[ka>>1]=(b[ka>>1]|0)-56}Ga=Ha+Ba|0}}while(0);ka=Da+1|0;if((ka|0)<4){Da=ka;Ba=Ga}else{break}}if(!K){i=h;return}if((Ga&15|0)!=0){i=h;return}c[g>>2]=c[g>>2]&-41337|264;i=h;return}function Zda(e,f,g,h,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;n=i;i=i+72|0;o=n|0;p=n+8|0;q=c[e+92>>2]|0;do{if((q|0)!=0){if((c[e+8052>>2]|0)!=0){break}r=c[e+6136>>2]|0;s=(r|0)!=0;t=(r|0)==3;u=(r|0)==2;r=c[e+427412>>2]|0;v=c[e+4872>>2]|0;w=c[e+4864>>2]|0;x=((c[e+7308>>2]|0)*-6|0)+48|0;y=(c[e+427424>>2]|0)+52+x|0;z=(c[e+427428>>2]|0)+52+x|0;x=c[(c[e+4064>>2]|0)+(r<<2)>>2]|0;A=c[e+4040>>2]|0;B=a[A+r|0]|0;C=a[A+(r-1)|0]|0;r=a[A+(c[e+4844>>2]|0)|0]|0;A=d[e+7876+B|0]|0;D=B+1|0;E=D+C>>1;F=r+D>>1;D=A+1|0;G=(D+(d[e+7876+C|0]|0)|0)>>>1;C=((d[e+7876+r|0]|0)+D|0)>>>1;D=(x&7|0)==0;if((c[e+4752>>2]|0)==0){if(!D){r=(c[e+177100>>2]|0)!=3?983552:983544;H=(v|0)!=0;do{if(H){I=E+y|0;J=E+z|0;if(I>>>0<68>>>0|J>>>0<68>>>0){break}cf[c[e+60>>2]&1023](h,l,d[1797040+I|0]|0,d[1732768+J|0]|0)}}while(0);J=(x&16777216|0)!=0;I=o|0;K=B+y|0;L=1797040+K|0;M=B+z|0;N=1732768+M|0;O=K>>>0<68>>>0|M>>>0<68>>>0;do{if(J){if(!O){M=d[N]|0;P=d[L]|0;TGb(I|0,a[189203+(K<<2)|0]|0,4)|0;le[c[e+48>>2]&1023](h+8|0,l,P,M,I)}do{if((w|0)!=0){M=F+y|0;P=d[1797040+M|0]|0;Q=F+z|0;R=d[1732768+Q|0]|0;if(M>>>0<68>>>0|Q>>>0<68>>>0){break}Q=b[r>>1]|0;if(Q<<16>>16<4){a[I]=a[(Q<<16>>16)+(189200+(M<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(189200+(M<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(189200+(M<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(189200+(M<<2))|0]|0;le[c[e+44>>2]&1023](h,l,P,R,I);break}else{cf[c[e+56>>2]&1023](h,l,P,R);break}}}while(0);if(O){break}R=d[N]|0;P=d[L]|0;TGb(I|0,a[189203+(K<<2)|0]|0,4)|0;le[c[e+44>>2]&1023](h+(l<<3)|0,l,P,R,I)}else{if(!O){R=d[N]|0;P=d[L]|0;M=a[189203+(K<<2)|0]|0;Q=e+48|0;TGb(I|0,M|0,4)|0;le[c[Q>>2]&1023](h+4|0,l,P,R,I);TGb(I|0,M|0,4)|0;le[c[Q>>2]&1023](h+8|0,l,P,R,I);TGb(I|0,M|0,4)|0;le[c[Q>>2]&1023](h+12|0,l,P,R,I)}do{if((w|0)!=0){R=F+y|0;P=d[1797040+R|0]|0;Q=F+z|0;M=d[1732768+Q|0]|0;if(R>>>0<68>>>0|Q>>>0<68>>>0){break}Q=b[r>>1]|0;if(Q<<16>>16<4){a[I]=a[(Q<<16>>16)+(189200+(R<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(189200+(R<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(189200+(R<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(189200+(R<<2))|0]|0;le[c[e+44>>2]&1023](h,l,P,M,I);break}else{cf[c[e+56>>2]&1023](h,l,P,M);break}}}while(0);if(O){break}M=d[N]|0;P=d[L]|0;R=a[189203+(K<<2)|0]|0;Q=e+44|0;TGb(I|0,R|0,4)|0;le[c[Q>>2]&1023](h+(l<<2)|0,l,P,M,I);TGb(I|0,R|0,4)|0;le[c[Q>>2]&1023](h+(l<<3)|0,l,P,M,I);TGb(I|0,R|0,4)|0;le[c[Q>>2]&1023](h+(l*12|0)|0,l,P,M,I)}}while(0);if(!s){i=n;return}if(t){do{if(H){K=G+y|0;L=G+z|0;if(K>>>0<68>>>0|L>>>0<68>>>0){break}N=d[1732768+L|0]|0;L=d[1797040+K|0]|0;K=e+60|0;cf[c[K>>2]&1023](j,l,L,N);cf[c[K>>2]&1023](k,l,L,N)}}while(0);N=A+y|0;L=1797040+N|0;K=A+z|0;O=1732768+K|0;M=N>>>0<68>>>0|K>>>0<68>>>0;if(J){if(!M){K=d[O]|0;P=d[L]|0;Q=a[189203+(N<<2)|0]|0;R=e+48|0;TGb(I|0,Q|0,4)|0;le[c[R>>2]&1023](j+8|0,l,P,K,I);TGb(I|0,Q|0,4)|0;le[c[R>>2]&1023](k+8|0,l,P,K,I)}do{if((w|0)!=0){K=C+y|0;P=d[1797040+K|0]|0;R=C+z|0;Q=d[1732768+R|0]|0;if(K>>>0<68>>>0|R>>>0<68>>>0){break}R=b[r>>1]|0;if(R<<16>>16<4){a[I]=a[(R<<16>>16)+(189200+(K<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(189200+(K<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(189200+(K<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(189200+(K<<2))|0]|0;le[c[e+44>>2]&1023](j,l,P,Q,I);a[I]=a[(R<<16>>16)+(189200+(K<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(189200+(K<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(189200+(K<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(189200+(K<<2))|0]|0;le[c[e+44>>2]&1023](k,l,P,Q,I);break}else{cf[c[e+56>>2]&1023](j,l,P,Q);cf[c[e+56>>2]&1023](k,l,P,Q);break}}}while(0);J=l<<3;if(M){i=n;return}Q=d[O]|0;P=d[L]|0;K=a[189203+(N<<2)|0]|0;R=e+44|0;TGb(I|0,K|0,4)|0;le[c[R>>2]&1023](j+J|0,l,P,Q,I);TGb(I|0,K|0,4)|0;le[c[R>>2]&1023](k+J|0,l,P,Q,I);i=n;return}else{if(!M){Q=d[O]|0;P=d[L]|0;J=a[189203+(N<<2)|0]|0;R=e+48|0;TGb(I|0,J|0,4)|0;le[c[R>>2]&1023](j+4|0,l,P,Q,I);TGb(I|0,J|0,4)|0;le[c[R>>2]&1023](k+4|0,l,P,Q,I);TGb(I|0,J|0,4)|0;le[c[R>>2]&1023](j+8|0,l,P,Q,I);TGb(I|0,J|0,4)|0;le[c[R>>2]&1023](k+8|0,l,P,Q,I);TGb(I|0,J|0,4)|0;le[c[R>>2]&1023](j+12|0,l,P,Q,I);TGb(I|0,J|0,4)|0;le[c[R>>2]&1023](k+12|0,l,P,Q,I)}do{if((w|0)!=0){Q=C+y|0;P=d[1797040+Q|0]|0;R=C+z|0;J=d[1732768+R|0]|0;if(Q>>>0<68>>>0|R>>>0<68>>>0){break}R=b[r>>1]|0;if(R<<16>>16<4){a[I]=a[(R<<16>>16)+(189200+(Q<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(189200+(Q<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(189200+(Q<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(189200+(Q<<2))|0]|0;le[c[e+44>>2]&1023](j,l,P,J,I);a[I]=a[(R<<16>>16)+(189200+(Q<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(189200+(Q<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(189200+(Q<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(189200+(Q<<2))|0]|0;le[c[e+44>>2]&1023](k,l,P,J,I);break}else{cf[c[e+56>>2]&1023](j,l,P,J);cf[c[e+56>>2]&1023](k,l,P,J);break}}}while(0);J=l<<2;if(M){i=n;return}P=d[O]|0;Q=d[L]|0;R=a[189203+(N<<2)|0]|0;K=e+44|0;TGb(I|0,R|0,4)|0;le[c[K>>2]&1023](j+J|0,l,Q,P,I);TGb(I|0,R|0,4)|0;le[c[K>>2]&1023](k+J|0,l,Q,P,I);J=l<<3;TGb(I|0,R|0,4)|0;le[c[K>>2]&1023](j+J|0,l,Q,P,I);TGb(I|0,R|0,4)|0;le[c[K>>2]&1023](k+J|0,l,Q,P,I);J=l*12|0;TGb(I|0,R|0,4)|0;le[c[K>>2]&1023](j+J|0,l,Q,P,I);TGb(I|0,R|0,4)|0;le[c[K>>2]&1023](k+J|0,l,Q,P,I);i=n;return}}if(u){do{if(H){P=G+y|0;Q=G+z|0;if(P>>>0<68>>>0|Q>>>0<68>>>0){break}J=d[1732768+Q|0]|0;Q=d[1797040+P|0]|0;P=e+84|0;cf[c[P>>2]&1023](j,m,Q,J);cf[c[P>>2]&1023](k,m,Q,J)}}while(0);N=A+y|0;L=1797040+N|0;O=A+z|0;M=1732768+O|0;J=N>>>0<68>>>0|O>>>0<68>>>0;if(!J){O=d[M]|0;Q=d[L]|0;P=(a[189203+(N<<2)|0]|0)+1&255;K=e+72|0;TGb(I|0,P|0,4)|0;le[c[K>>2]&1023](j+4|0,m,Q,O,I);TGb(I|0,P|0,4)|0;le[c[K>>2]&1023](k+4|0,m,Q,O,I)}do{if((w|0)!=0){O=C+y|0;Q=d[1797040+O|0]|0;K=C+z|0;P=d[1732768+K|0]|0;if(O>>>0<68>>>0|K>>>0<68>>>0){break}K=b[r>>1]|0;if(K<<16>>16<4){a[I]=(a[(K<<16>>16)+(189200+(O<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(189200+(O<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(189200+(O<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(189200+(O<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,Q,P,I);a[I]=(a[(K<<16>>16)+(189200+(O<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(189200+(O<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(189200+(O<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(189200+(O<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,Q,P,I);break}else{cf[c[e+80>>2]&1023](j,m,Q,P);cf[c[e+80>>2]&1023](k,m,Q,P);break}}}while(0);P=m<<2;if(J){i=n;return}Q=d[M]|0;O=d[L]|0;K=(a[189203+(N<<2)|0]|0)+1&255;R=e+68|0;TGb(I|0,K|0,4)|0;le[c[R>>2]&1023](j+P|0,m,O,Q,I);TGb(I|0,K|0,4)|0;le[c[R>>2]&1023](k+P|0,m,O,Q,I);P=m<<3;TGb(I|0,K|0,4)|0;le[c[R>>2]&1023](j+P|0,m,O,Q,I);TGb(I|0,K|0,4)|0;le[c[R>>2]&1023](k+P|0,m,O,Q,I);P=m*12|0;TGb(I|0,K|0,4)|0;le[c[R>>2]&1023](j+P|0,m,O,Q,I);TGb(I|0,K|0,4)|0;le[c[R>>2]&1023](k+P|0,m,O,Q,I);i=n;return}else{do{if(H){Q=G+y|0;O=G+z|0;if(Q>>>0<68>>>0|O>>>0<68>>>0){break}P=d[1732768+O|0]|0;O=d[1797040+Q|0]|0;Q=e+84|0;cf[c[Q>>2]&1023](j,m,O,P);cf[c[Q>>2]&1023](k,m,O,P)}}while(0);H=A+y|0;N=1797040+H|0;L=A+z|0;M=1732768+L|0;J=H>>>0<68>>>0|L>>>0<68>>>0;if(!J){L=d[M]|0;P=d[N]|0;O=(a[189203+(H<<2)|0]|0)+1&255;Q=e+72|0;TGb(I|0,O|0,4)|0;le[c[Q>>2]&1023](j+4|0,m,P,L,I);TGb(I|0,O|0,4)|0;le[c[Q>>2]&1023](k+4|0,m,P,L,I)}do{if((w|0)!=0){L=C+y|0;P=d[1797040+L|0]|0;Q=C+z|0;O=d[1732768+Q|0]|0;if(L>>>0<68>>>0|Q>>>0<68>>>0){break}Q=b[r>>1]|0;if(Q<<16>>16<4){a[I]=(a[(Q<<16>>16)+(189200+(L<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(189200+(L<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(189200+(L<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(189200+(L<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,P,O,I);a[I]=(a[(Q<<16>>16)+(189200+(L<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(189200+(L<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(189200+(L<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(189200+(L<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,P,O,I);break}else{cf[c[e+80>>2]&1023](j,m,P,O);cf[c[e+80>>2]&1023](k,m,P,O);break}}}while(0);r=m<<2;if(J){i=n;return}O=d[M]|0;P=d[N]|0;L=(a[189203+(H<<2)|0]|0)+1&255;Q=e+68|0;TGb(I|0,L|0,4)|0;le[c[Q>>2]&1023](j+r|0,m,P,O,I);TGb(I|0,L|0,4)|0;le[c[Q>>2]&1023](k+r|0,m,P,O,I);i=n;return}}O=p;P=(x&16777216|0)!=0;r=c[e+426564>>2]|0;do{if(P){if((r&7|0)!=7|t){S=310;break}Q=p|0;c[Q>>2]=131074;c[Q+4>>2]=131074;Q=p+16|0;c[Q>>2]=131074;c[Q+4>>2]=131074;Q=p+32|0;c[Q>>2]=131074;c[Q+4>>2]=131074;Q=p+48|0;c[Q>>2]=131074;c[Q+4>>2]=131074;T=4}else{S=310}}while(0);if((S|0)==310){I=-((x*5|0)>>>5&1)&3|x>>4;H=4-(-((r&15|0)==0&x>>>3)&3)|0;Ne[q&127](O,e+5184|0,e+5632|0,e+5312|0,(c[e+199428>>2]|0)==2|0,H,(x>>24)+1|0,-((v*5|0)>>>5&1&I>>>1)&3,I,(c[e+177100>>2]|0)!=3|0);T=H}if((v&7|0)!=0){H=p|0;c[H>>2]=262148;c[H+4>>2]=262148}if((w&7|0)!=0){H=(c[e+177100>>2]|0)!=3;I=p+32|0;c[I>>2]=H?196611:262148;c[I+4>>2]=H?196611:262148}do{if((v|0)!=0){H=p;I=p|0;N=c[I>>2]|0;M=N&65535;if((N|0)==0&(c[I+4>>2]|0)==0){break}I=o|0;N=E+y|0;J=d[1797040+N|0]|0;Q=E+z|0;L=d[1732768+Q|0]|0;do{if(!(N>>>0<68>>>0|Q>>>0<68>>>0)){if(M<<16>>16<4){a[I]=a[(M<<16>>16)+(189200+(N<<2))|0]|0;a[o+1|0]=a[(b[H+2>>1]|0)+(189200+(N<<2))|0]|0;a[o+2|0]=a[(b[H+4>>1]|0)+(189200+(N<<2))|0]|0;a[o+3|0]=a[(b[H+6>>1]|0)+(189200+(N<<2))|0]|0;le[c[e+48>>2]&1023](h,l,J,L,I);break}else{cf[c[e+60>>2]&1023](h,l,J,L);break}}}while(0);if(!s){break}L=G+y|0;J=d[1797040+L|0]|0;N=G+z|0;M=d[1732768+N|0]|0;Q=L>>>0<68>>>0|N>>>0<68>>>0;if(t){if(Q){break}N=b[H>>1]|0;if(N<<16>>16<4){a[I]=a[(N<<16>>16)+(189200+(L<<2))|0]|0;a[o+1|0]=a[(b[H+2>>1]|0)+(189200+(L<<2))|0]|0;a[o+2|0]=a[(b[H+4>>1]|0)+(189200+(L<<2))|0]|0;a[o+3|0]=a[(b[H+6>>1]|0)+(189200+(L<<2))|0]|0;le[c[e+48>>2]&1023](j,l,J,M,I)}else{cf[c[e+60>>2]&1023](j,l,J,M)}N=b[H>>1]|0;if(N<<16>>16<4){a[I]=a[(N<<16>>16)+(189200+(L<<2))|0]|0;a[o+1|0]=a[(b[H+2>>1]|0)+(189200+(L<<2))|0]|0;a[o+2|0]=a[(b[H+4>>1]|0)+(189200+(L<<2))|0]|0;a[o+3|0]=a[(b[H+6>>1]|0)+(189200+(L<<2))|0]|0;le[c[e+48>>2]&1023](k,l,J,M,I);break}else{cf[c[e+60>>2]&1023](k,l,J,M);break}}else{if(Q){break}Q=b[H>>1]|0;if(Q<<16>>16<4){a[I]=(a[(Q<<16>>16)+(189200+(L<<2))|0]|0)+1;a[o+1|0]=(a[(b[H+2>>1]|0)+(189200+(L<<2))|0]|0)+1;a[o+2|0]=(a[(b[H+4>>1]|0)+(189200+(L<<2))|0]|0)+1;a[o+3|0]=(a[(b[H+6>>1]|0)+(189200+(L<<2))|0]|0)+1;le[c[e+72>>2]&1023](j,m,J,M,I)}else{cf[c[e+84>>2]&1023](j,m,J,M)}Q=b[H>>1]|0;if(Q<<16>>16<4){a[I]=(a[(Q<<16>>16)+(189200+(L<<2))|0]|0)+1;a[o+1|0]=(a[(b[H+2>>1]|0)+(189200+(L<<2))|0]|0)+1;a[o+2|0]=(a[(b[H+4>>1]|0)+(189200+(L<<2))|0]|0)+1;a[o+3|0]=(a[(b[H+6>>1]|0)+(189200+(L<<2))|0]|0)+1;le[c[e+72>>2]&1023](k,m,J,M,I);break}else{cf[c[e+84>>2]&1023](k,m,J,M);break}}}}while(0);if((T|0)==1){if((w|0)==0){i=n;return}O=p+32|0;r=O;M=O|0;O=c[M>>2]|0;J=O&65535;if((O|0)==0&(c[M+4>>2]|0)==0){i=n;return}M=o|0;O=F+y|0;L=d[1797040+O|0]|0;Q=F+z|0;N=d[1732768+Q|0]|0;do{if(!(O>>>0<68>>>0|Q>>>0<68>>>0)){if(J<<16>>16<4){a[M]=a[(J<<16>>16)+(189200+(O<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(189200+(O<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(189200+(O<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(189200+(O<<2))|0]|0;le[c[e+44>>2]&1023](h,l,L,N,M);break}else{cf[c[e+56>>2]&1023](h,l,L,N);break}}}while(0);if(!s){i=n;return}N=C+y|0;L=d[1797040+N|0]|0;O=C+z|0;J=d[1732768+O|0]|0;Q=N>>>0<68>>>0|O>>>0<68>>>0;if(t){if(Q){i=n;return}O=b[r>>1]|0;if(O<<16>>16<4){a[M]=a[(O<<16>>16)+(189200+(N<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(189200+(N<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(189200+(N<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(189200+(N<<2))|0]|0;le[c[e+44>>2]&1023](j,l,L,J,M)}else{cf[c[e+56>>2]&1023](j,l,L,J)}O=b[r>>1]|0;if(O<<16>>16<4){a[M]=a[(O<<16>>16)+(189200+(N<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(189200+(N<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(189200+(N<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(189200+(N<<2))|0]|0;le[c[e+44>>2]&1023](k,l,L,J,M);i=n;return}else{cf[c[e+56>>2]&1023](k,l,L,J);i=n;return}}else{if(Q){i=n;return}Q=b[r>>1]|0;if(Q<<16>>16<4){a[M]=(a[(Q<<16>>16)+(189200+(N<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(189200+(N<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(189200+(N<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(189200+(N<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,L,J,M)}else{cf[c[e+80>>2]&1023](j,m,L,J)}Q=b[r>>1]|0;if(Q<<16>>16<4){a[M]=(a[(Q<<16>>16)+(189200+(N<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(189200+(N<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(189200+(N<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(189200+(N<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,L,J,M);i=n;return}else{cf[c[e+80>>2]&1023](k,m,L,J);i=n;return}}}if(P){J=p+16|0;L=J;N=J|0;J=c[N>>2]|0;Q=J&65535;do{if(!((J|0)==0&(c[N+4>>2]|0)==0)){O=o|0;R=B+y|0;K=B+z|0;if(!(R>>>0<68>>>0|K>>>0<68>>>0)){U=d[1732768+K|0]|0;K=d[1797040+R|0]|0;a[O]=a[(Q<<16>>16)+(189200+(R<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(189200+(R<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(189200+(R<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(189200+(R<<2))|0]|0;le[c[e+48>>2]&1023](h+8|0,l,K,U,O)}if(!s){break}U=A+y|0;K=A+z|0;R=U>>>0<68>>>0|K>>>0<68>>>0;if(t){if(R){break}V=d[1732768+K|0]|0;W=d[1797040+U|0]|0;a[O]=a[(b[L>>1]|0)+(189200+(U<<2))|0]|0;X=L+2|0;Y=o+1|0;a[Y]=a[(b[X>>1]|0)+(189200+(U<<2))|0]|0;Z=L+4|0;_=o+2|0;a[_]=a[(b[Z>>1]|0)+(189200+(U<<2))|0]|0;$=L+6|0;aa=o+3|0;a[aa]=a[(b[$>>1]|0)+(189200+(U<<2))|0]|0;ba=e+48|0;le[c[ba>>2]&1023](j+8|0,l,W,V,O);a[O]=a[(b[L>>1]|0)+(189200+(U<<2))|0]|0;a[Y]=a[(b[X>>1]|0)+(189200+(U<<2))|0]|0;a[_]=a[(b[Z>>1]|0)+(189200+(U<<2))|0]|0;a[aa]=a[(b[$>>1]|0)+(189200+(U<<2))|0]|0;le[c[ba>>2]&1023](k+8|0,l,W,V,O);break}else{if(R){break}R=d[1732768+K|0]|0;K=d[1797040+U|0]|0;a[O]=(a[(b[L>>1]|0)+(189200+(U<<2))|0]|0)+1;V=L+2|0;W=o+1|0;a[W]=(a[(b[V>>1]|0)+(189200+(U<<2))|0]|0)+1;ba=L+4|0;$=o+2|0;a[$]=(a[(b[ba>>1]|0)+(189200+(U<<2))|0]|0)+1;aa=L+6|0;Z=o+3|0;a[Z]=(a[(b[aa>>1]|0)+(189200+(U<<2))|0]|0)+1;_=e+72|0;le[c[_>>2]&1023](j+4|0,m,K,R,O);a[O]=(a[(b[L>>1]|0)+(189200+(U<<2))|0]|0)+1;a[W]=(a[(b[V>>1]|0)+(189200+(U<<2))|0]|0)+1;a[$]=(a[(b[ba>>1]|0)+(189200+(U<<2))|0]|0)+1;a[Z]=(a[(b[aa>>1]|0)+(189200+(U<<2))|0]|0)+1;le[c[_>>2]&1023](k+4|0,m,K,R,O);break}}}while(0);do{if((w|0)!=0){L=p+32|0;Q=L;N=L|0;L=c[N>>2]|0;J=L&65535;if((L|0)==0&(c[N+4>>2]|0)==0){break}N=o|0;L=F+y|0;P=d[1797040+L|0]|0;M=F+z|0;r=d[1732768+M|0]|0;do{if(!(L>>>0<68>>>0|M>>>0<68>>>0)){if(J<<16>>16<4){a[N]=a[(J<<16>>16)+(189200+(L<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(189200+(L<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(189200+(L<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(189200+(L<<2))|0]|0;le[c[e+44>>2]&1023](h,l,P,r,N);break}else{cf[c[e+56>>2]&1023](h,l,P,r);break}}}while(0);if(!s){break}r=C+y|0;P=d[1797040+r|0]|0;L=C+z|0;J=d[1732768+L|0]|0;M=r>>>0<68>>>0|L>>>0<68>>>0;if(t){if(M){break}L=b[Q>>1]|0;if(L<<16>>16<4){a[N]=a[(L<<16>>16)+(189200+(r<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(189200+(r<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(189200+(r<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(189200+(r<<2))|0]|0;le[c[e+44>>2]&1023](j,l,P,J,N)}else{cf[c[e+56>>2]&1023](j,l,P,J)}L=b[Q>>1]|0;if(L<<16>>16<4){a[N]=a[(L<<16>>16)+(189200+(r<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(189200+(r<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(189200+(r<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(189200+(r<<2))|0]|0;le[c[e+44>>2]&1023](k,l,P,J,N);break}else{cf[c[e+56>>2]&1023](k,l,P,J);break}}else{if(M){break}M=b[Q>>1]|0;if(M<<16>>16<4){a[N]=(a[(M<<16>>16)+(189200+(r<<2))|0]|0)+1;a[o+1|0]=(a[(b[Q+2>>1]|0)+(189200+(r<<2))|0]|0)+1;a[o+2|0]=(a[(b[Q+4>>1]|0)+(189200+(r<<2))|0]|0)+1;a[o+3|0]=(a[(b[Q+6>>1]|0)+(189200+(r<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,P,J,N)}else{cf[c[e+80>>2]&1023](j,m,P,J)}M=b[Q>>1]|0;if(M<<16>>16<4){a[N]=(a[(M<<16>>16)+(189200+(r<<2))|0]|0)+1;a[o+1|0]=(a[(b[Q+2>>1]|0)+(189200+(r<<2))|0]|0)+1;a[o+2|0]=(a[(b[Q+4>>1]|0)+(189200+(r<<2))|0]|0)+1;a[o+3|0]=(a[(b[Q+6>>1]|0)+(189200+(r<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,P,J,N);break}else{cf[c[e+80>>2]&1023](k,m,P,J);break}}}}while(0);J=p+48|0;P=J;r=J|0;J=c[r>>2]|0;if((J|0)==0&(c[r+4>>2]|0)==0){i=n;return}r=l<<3;M=o|0;L=B+y|0;I=B+z|0;if(!(L>>>0<68>>>0|I>>>0<68>>>0)){H=d[1732768+I|0]|0;I=d[1797040+L|0]|0;a[M]=a[((J&65535)<<16>>16)+(189200+(L<<2))|0]|0;a[o+1|0]=a[(b[P+2>>1]|0)+(189200+(L<<2))|0]|0;a[o+2|0]=a[(b[P+4>>1]|0)+(189200+(L<<2))|0]|0;a[o+3|0]=a[(b[P+6>>1]|0)+(189200+(L<<2))|0]|0;le[c[e+44>>2]&1023](h+r|0,l,I,H,M)}if(!s){i=n;return}if(t){H=A+y|0;I=A+z|0;if(H>>>0<68>>>0|I>>>0<68>>>0){i=n;return}L=d[1732768+I|0]|0;I=d[1797040+H|0]|0;a[M]=a[(b[P>>1]|0)+(189200+(H<<2))|0]|0;J=P+2|0;O=o+1|0;a[O]=a[(b[J>>1]|0)+(189200+(H<<2))|0]|0;R=P+4|0;K=o+2|0;a[K]=a[(b[R>>1]|0)+(189200+(H<<2))|0]|0;_=P+6|0;U=o+3|0;a[U]=a[(b[_>>1]|0)+(189200+(H<<2))|0]|0;aa=e+44|0;le[c[aa>>2]&1023](j+r|0,l,I,L,M);a[M]=a[(b[P>>1]|0)+(189200+(H<<2))|0]|0;a[O]=a[(b[J>>1]|0)+(189200+(H<<2))|0]|0;a[K]=a[(b[R>>1]|0)+(189200+(H<<2))|0]|0;a[U]=a[(b[_>>1]|0)+(189200+(H<<2))|0]|0;le[c[aa>>2]&1023](k+r|0,l,I,L,M);i=n;return}else{L=m<<2;I=A+y|0;r=A+z|0;if(I>>>0<68>>>0|r>>>0<68>>>0){i=n;return}aa=d[1732768+r|0]|0;r=d[1797040+I|0]|0;a[M]=(a[(b[P>>1]|0)+(189200+(I<<2))|0]|0)+1;H=P+2|0;_=o+1|0;a[_]=(a[(b[H>>1]|0)+(189200+(I<<2))|0]|0)+1;U=P+4|0;R=o+2|0;a[R]=(a[(b[U>>1]|0)+(189200+(I<<2))|0]|0)+1;K=P+6|0;J=o+3|0;a[J]=(a[(b[K>>1]|0)+(189200+(I<<2))|0]|0)+1;O=e+68|0;le[c[O>>2]&1023](j+L|0,m,r,aa,M);a[M]=(a[(b[P>>1]|0)+(189200+(I<<2))|0]|0)+1;a[_]=(a[(b[H>>1]|0)+(189200+(I<<2))|0]|0)+1;a[R]=(a[(b[U>>1]|0)+(189200+(I<<2))|0]|0)+1;a[J]=(a[(b[K>>1]|0)+(189200+(I<<2))|0]|0)+1;le[c[O>>2]&1023](k+L|0,m,r,aa,M);i=n;return}}M=p+8|0;aa=M;r=M|0;M=c[r>>2]|0;L=M&65535;do{if(!((M|0)==0&(c[r+4>>2]|0)==0)){O=o|0;I=B+y|0;K=B+z|0;if(!(I>>>0<68>>>0|K>>>0<68>>>0)){J=d[1732768+K|0]|0;K=d[1797040+I|0]|0;a[O]=a[(L<<16>>16)+(189200+(I<<2))|0]|0;a[o+1|0]=a[(b[aa+2>>1]|0)+(189200+(I<<2))|0]|0;a[o+2|0]=a[(b[aa+4>>1]|0)+(189200+(I<<2))|0]|0;a[o+3|0]=a[(b[aa+6>>1]|0)+(189200+(I<<2))|0]|0;le[c[e+48>>2]&1023](h+4|0,l,K,J,O)}if(!t){break}J=A+y|0;K=A+z|0;if(J>>>0<68>>>0|K>>>0<68>>>0){break}I=d[1732768+K|0]|0;K=d[1797040+J|0]|0;a[O]=a[(b[aa>>1]|0)+(189200+(J<<2))|0]|0;U=aa+2|0;R=o+1|0;a[R]=a[(b[U>>1]|0)+(189200+(J<<2))|0]|0;H=aa+4|0;_=o+2|0;a[_]=a[(b[H>>1]|0)+(189200+(J<<2))|0]|0;P=aa+6|0;Z=o+3|0;a[Z]=a[(b[P>>1]|0)+(189200+(J<<2))|0]|0;ba=e+48|0;le[c[ba>>2]&1023](j+4|0,l,K,I,O);a[O]=a[(b[aa>>1]|0)+(189200+(J<<2))|0]|0;a[R]=a[(b[U>>1]|0)+(189200+(J<<2))|0]|0;a[_]=a[(b[H>>1]|0)+(189200+(J<<2))|0]|0;a[Z]=a[(b[P>>1]|0)+(189200+(J<<2))|0]|0;le[c[ba>>2]&1023](k+4|0,l,K,I,O)}}while(0);aa=p+16|0;L=aa;r=aa|0;aa=c[r>>2]|0;M=aa&65535;do{if(!((aa|0)==0&(c[r+4>>2]|0)==0)){O=o|0;I=B+y|0;K=B+z|0;if(!(I>>>0<68>>>0|K>>>0<68>>>0)){ba=d[1732768+K|0]|0;K=d[1797040+I|0]|0;a[O]=a[(M<<16>>16)+(189200+(I<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(189200+(I<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(189200+(I<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(189200+(I<<2))|0]|0;le[c[e+48>>2]&1023](h+8|0,l,K,ba,O)}if(!s){break}ba=A+y|0;K=A+z|0;I=ba>>>0<68>>>0|K>>>0<68>>>0;if(t){if(I){break}J=d[1732768+K|0]|0;P=d[1797040+ba|0]|0;a[O]=a[(b[L>>1]|0)+(189200+(ba<<2))|0]|0;Z=L+2|0;H=o+1|0;a[H]=a[(b[Z>>1]|0)+(189200+(ba<<2))|0]|0;_=L+4|0;U=o+2|0;a[U]=a[(b[_>>1]|0)+(189200+(ba<<2))|0]|0;R=L+6|0;$=o+3|0;a[$]=a[(b[R>>1]|0)+(189200+(ba<<2))|0]|0;V=e+48|0;le[c[V>>2]&1023](j+8|0,l,P,J,O);a[O]=a[(b[L>>1]|0)+(189200+(ba<<2))|0]|0;a[H]=a[(b[Z>>1]|0)+(189200+(ba<<2))|0]|0;a[U]=a[(b[_>>1]|0)+(189200+(ba<<2))|0]|0;a[$]=a[(b[R>>1]|0)+(189200+(ba<<2))|0]|0;le[c[V>>2]&1023](k+8|0,l,P,J,O);break}else{if(I){break}I=d[1732768+K|0]|0;K=d[1797040+ba|0]|0;a[O]=(a[(b[L>>1]|0)+(189200+(ba<<2))|0]|0)+1;J=L+2|0;P=o+1|0;a[P]=(a[(b[J>>1]|0)+(189200+(ba<<2))|0]|0)+1;V=L+4|0;R=o+2|0;a[R]=(a[(b[V>>1]|0)+(189200+(ba<<2))|0]|0)+1;$=L+6|0;_=o+3|0;a[_]=(a[(b[$>>1]|0)+(189200+(ba<<2))|0]|0)+1;U=e+72|0;le[c[U>>2]&1023](j+4|0,m,K,I,O);a[O]=(a[(b[L>>1]|0)+(189200+(ba<<2))|0]|0)+1;a[P]=(a[(b[J>>1]|0)+(189200+(ba<<2))|0]|0)+1;a[R]=(a[(b[V>>1]|0)+(189200+(ba<<2))|0]|0)+1;a[_]=(a[(b[$>>1]|0)+(189200+(ba<<2))|0]|0)+1;le[c[U>>2]&1023](k+4|0,m,K,I,O);break}}}while(0);L=p+24|0;M=L;r=L|0;L=c[r>>2]|0;aa=L&65535;do{if(!((L|0)==0&(c[r+4>>2]|0)==0)){O=o|0;I=B+y|0;K=B+z|0;if(!(I>>>0<68>>>0|K>>>0<68>>>0)){U=d[1732768+K|0]|0;K=d[1797040+I|0]|0;a[O]=a[(aa<<16>>16)+(189200+(I<<2))|0]|0;a[o+1|0]=a[(b[M+2>>1]|0)+(189200+(I<<2))|0]|0;a[o+2|0]=a[(b[M+4>>1]|0)+(189200+(I<<2))|0]|0;a[o+3|0]=a[(b[M+6>>1]|0)+(189200+(I<<2))|0]|0;le[c[e+48>>2]&1023](h+12|0,l,K,U,O)}if(!t){break}U=A+y|0;K=A+z|0;if(U>>>0<68>>>0|K>>>0<68>>>0){break}I=d[1732768+K|0]|0;K=d[1797040+U|0]|0;a[O]=a[(b[M>>1]|0)+(189200+(U<<2))|0]|0;ba=M+2|0;$=o+1|0;a[$]=a[(b[ba>>1]|0)+(189200+(U<<2))|0]|0;_=M+4|0;V=o+2|0;a[V]=a[(b[_>>1]|0)+(189200+(U<<2))|0]|0;R=M+6|0;J=o+3|0;a[J]=a[(b[R>>1]|0)+(189200+(U<<2))|0]|0;P=e+48|0;le[c[P>>2]&1023](j+12|0,l,K,I,O);a[O]=a[(b[M>>1]|0)+(189200+(U<<2))|0]|0;a[$]=a[(b[ba>>1]|0)+(189200+(U<<2))|0]|0;a[V]=a[(b[_>>1]|0)+(189200+(U<<2))|0]|0;a[J]=a[(b[R>>1]|0)+(189200+(U<<2))|0]|0;le[c[P>>2]&1023](k+12|0,l,K,I,O)}}while(0);do{if((w|0)!=0){M=p+32|0;aa=M;r=M|0;M=c[r>>2]|0;L=M&65535;if((M|0)==0&(c[r+4>>2]|0)==0){break}r=o|0;M=F+y|0;O=d[1797040+M|0]|0;I=F+z|0;K=d[1732768+I|0]|0;do{if(!(M>>>0<68>>>0|I>>>0<68>>>0)){if(L<<16>>16<4){a[r]=a[(L<<16>>16)+(189200+(M<<2))|0]|0;a[o+1|0]=a[(b[aa+2>>1]|0)+(189200+(M<<2))|0]|0;a[o+2|0]=a[(b[aa+4>>1]|0)+(189200+(M<<2))|0]|0;a[o+3|0]=a[(b[aa+6>>1]|0)+(189200+(M<<2))|0]|0;le[c[e+44>>2]&1023](h,l,O,K,r);break}else{cf[c[e+56>>2]&1023](h,l,O,K);break}}}while(0);if(!s){break}K=C+y|0;O=d[1797040+K|0]|0;M=C+z|0;L=d[1732768+M|0]|0;I=K>>>0<68>>>0|M>>>0<68>>>0;if(t){if(I){break}M=b[aa>>1]|0;if(M<<16>>16<4){a[r]=a[(M<<16>>16)+(189200+(K<<2))|0]|0;a[o+1|0]=a[(b[aa+2>>1]|0)+(189200+(K<<2))|0]|0;a[o+2|0]=a[(b[aa+4>>1]|0)+(189200+(K<<2))|0]|0;a[o+3|0]=a[(b[aa+6>>1]|0)+(189200+(K<<2))|0]|0;le[c[e+44>>2]&1023](j,l,O,L,r)}else{cf[c[e+56>>2]&1023](j,l,O,L)}M=b[aa>>1]|0;if(M<<16>>16<4){a[r]=a[(M<<16>>16)+(189200+(K<<2))|0]|0;a[o+1|0]=a[(b[aa+2>>1]|0)+(189200+(K<<2))|0]|0;a[o+2|0]=a[(b[aa+4>>1]|0)+(189200+(K<<2))|0]|0;a[o+3|0]=a[(b[aa+6>>1]|0)+(189200+(K<<2))|0]|0;le[c[e+44>>2]&1023](k,l,O,L,r);break}else{cf[c[e+56>>2]&1023](k,l,O,L);break}}else{if(I){break}I=b[aa>>1]|0;if(I<<16>>16<4){a[r]=(a[(I<<16>>16)+(189200+(K<<2))|0]|0)+1;a[o+1|0]=(a[(b[aa+2>>1]|0)+(189200+(K<<2))|0]|0)+1;a[o+2|0]=(a[(b[aa+4>>1]|0)+(189200+(K<<2))|0]|0)+1;a[o+3|0]=(a[(b[aa+6>>1]|0)+(189200+(K<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,O,L,r)}else{cf[c[e+80>>2]&1023](j,m,O,L)}I=b[aa>>1]|0;if(I<<16>>16<4){a[r]=(a[(I<<16>>16)+(189200+(K<<2))|0]|0)+1;a[o+1|0]=(a[(b[aa+2>>1]|0)+(189200+(K<<2))|0]|0)+1;a[o+2|0]=(a[(b[aa+4>>1]|0)+(189200+(K<<2))|0]|0)+1;a[o+3|0]=(a[(b[aa+6>>1]|0)+(189200+(K<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,O,L,r);break}else{cf[c[e+80>>2]&1023](k,m,O,L);break}}}}while(0);L=p+40|0;O=L;K=L|0;L=c[K>>2]|0;I=L&65535;do{if(!((L|0)==0&(c[K+4>>2]|0)==0)){M=l<<2;N=o|0;Q=B+y|0;P=B+z|0;if(!(Q>>>0<68>>>0|P>>>0<68>>>0)){U=d[1732768+P|0]|0;P=d[1797040+Q|0]|0;a[N]=a[(I<<16>>16)+(189200+(Q<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(Q<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(Q<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(Q<<2))|0]|0;le[c[e+44>>2]&1023](h+M|0,l,P,U,N)}if(!t){break}U=A+y|0;P=A+z|0;if(U>>>0<68>>>0|P>>>0<68>>>0){break}Q=d[1732768+P|0]|0;P=d[1797040+U|0]|0;a[N]=a[(b[O>>1]|0)+(189200+(U<<2))|0]|0;R=O+2|0;J=o+1|0;a[J]=a[(b[R>>1]|0)+(189200+(U<<2))|0]|0;_=O+4|0;V=o+2|0;a[V]=a[(b[_>>1]|0)+(189200+(U<<2))|0]|0;ba=O+6|0;$=o+3|0;a[$]=a[(b[ba>>1]|0)+(189200+(U<<2))|0]|0;Z=e+44|0;le[c[Z>>2]&1023](j+M|0,l,P,Q,N);a[N]=a[(b[O>>1]|0)+(189200+(U<<2))|0]|0;a[J]=a[(b[R>>1]|0)+(189200+(U<<2))|0]|0;a[V]=a[(b[_>>1]|0)+(189200+(U<<2))|0]|0;a[$]=a[(b[ba>>1]|0)+(189200+(U<<2))|0]|0;le[c[Z>>2]&1023](k+M|0,l,P,Q,N)}}while(0);O=p+48|0;I=O;K=O|0;O=c[K>>2]|0;L=O&65535;do{if(!((O|0)==0&(c[K+4>>2]|0)==0)){N=l<<3;Q=o|0;P=B+y|0;M=B+z|0;if(!(P>>>0<68>>>0|M>>>0<68>>>0)){Z=d[1732768+M|0]|0;M=d[1797040+P|0]|0;a[Q]=a[(L<<16>>16)+(189200+(P<<2))|0]|0;a[o+1|0]=a[(b[I+2>>1]|0)+(189200+(P<<2))|0]|0;a[o+2|0]=a[(b[I+4>>1]|0)+(189200+(P<<2))|0]|0;a[o+3|0]=a[(b[I+6>>1]|0)+(189200+(P<<2))|0]|0;le[c[e+44>>2]&1023](h+N|0,l,M,Z,Q)}if(!s){break}if(t){Z=A+y|0;M=A+z|0;if(Z>>>0<68>>>0|M>>>0<68>>>0){break}P=d[1732768+M|0]|0;M=d[1797040+Z|0]|0;a[Q]=a[(b[I>>1]|0)+(189200+(Z<<2))|0]|0;U=I+2|0;ba=o+1|0;a[ba]=a[(b[U>>1]|0)+(189200+(Z<<2))|0]|0;$=I+4|0;_=o+2|0;a[_]=a[(b[$>>1]|0)+(189200+(Z<<2))|0]|0;V=I+6|0;R=o+3|0;a[R]=a[(b[V>>1]|0)+(189200+(Z<<2))|0]|0;J=e+44|0;le[c[J>>2]&1023](j+N|0,l,M,P,Q);a[Q]=a[(b[I>>1]|0)+(189200+(Z<<2))|0]|0;a[ba]=a[(b[U>>1]|0)+(189200+(Z<<2))|0]|0;a[_]=a[(b[$>>1]|0)+(189200+(Z<<2))|0]|0;a[R]=a[(b[V>>1]|0)+(189200+(Z<<2))|0]|0;le[c[J>>2]&1023](k+N|0,l,M,P,Q);break}else{P=m<<2;M=A+y|0;N=A+z|0;if(M>>>0<68>>>0|N>>>0<68>>>0){break}J=d[1732768+N|0]|0;N=d[1797040+M|0]|0;a[Q]=(a[(b[I>>1]|0)+(189200+(M<<2))|0]|0)+1;Z=I+2|0;V=o+1|0;a[V]=(a[(b[Z>>1]|0)+(189200+(M<<2))|0]|0)+1;R=I+4|0;$=o+2|0;a[$]=(a[(b[R>>1]|0)+(189200+(M<<2))|0]|0)+1;_=I+6|0;U=o+3|0;a[U]=(a[(b[_>>1]|0)+(189200+(M<<2))|0]|0)+1;ba=e+68|0;le[c[ba>>2]&1023](j+P|0,m,N,J,Q);a[Q]=(a[(b[I>>1]|0)+(189200+(M<<2))|0]|0)+1;a[V]=(a[(b[Z>>1]|0)+(189200+(M<<2))|0]|0)+1;a[$]=(a[(b[R>>1]|0)+(189200+(M<<2))|0]|0)+1;a[U]=(a[(b[_>>1]|0)+(189200+(M<<2))|0]|0)+1;le[c[ba>>2]&1023](k+P|0,m,N,J,Q);break}}}while(0);I=p+56|0;L=I;K=I|0;I=c[K>>2]|0;if((I|0)==0&(c[K+4>>2]|0)==0){i=n;return}K=l*12|0;O=o|0;Q=B+y|0;J=B+z|0;if(!(Q>>>0<68>>>0|J>>>0<68>>>0)){N=d[1732768+J|0]|0;J=d[1797040+Q|0]|0;a[O]=a[((I&65535)<<16>>16)+(189200+(Q<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(189200+(Q<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(189200+(Q<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(189200+(Q<<2))|0]|0;le[c[e+44>>2]&1023](h+K|0,l,J,N,O)}if(!t){i=n;return}N=A+y|0;J=A+z|0;if(N>>>0<68>>>0|J>>>0<68>>>0){i=n;return}Q=d[1732768+J|0]|0;J=d[1797040+N|0]|0;a[O]=a[(b[L>>1]|0)+(189200+(N<<2))|0]|0;I=L+2|0;P=o+1|0;a[P]=a[(b[I>>1]|0)+(189200+(N<<2))|0]|0;ba=L+4|0;M=o+2|0;a[M]=a[(b[ba>>1]|0)+(189200+(N<<2))|0]|0;_=L+6|0;U=o+3|0;a[U]=a[(b[_>>1]|0)+(189200+(N<<2))|0]|0;R=e+44|0;le[c[R>>2]&1023](j+K|0,l,J,Q,O);a[O]=a[(b[L>>1]|0)+(189200+(N<<2))|0]|0;a[P]=a[(b[I>>1]|0)+(189200+(N<<2))|0]|0;a[M]=a[(b[ba>>1]|0)+(189200+(N<<2))|0]|0;a[U]=a[(b[_>>1]|0)+(189200+(N<<2))|0]|0;le[c[R>>2]&1023](k+K|0,l,J,Q,O);i=n;return}else{if(!D){O=(c[e+177100>>2]|0)!=3?983552:983544;Q=(v|0)!=0;do{if(Q){J=E+y|0;K=E+z|0;if(J>>>0<68>>>0|K>>>0<68>>>0){break}cf[c[e+60>>2]&1023](h,l,d[1797040+J|0]|0,d[1732768+K|0]|0)}}while(0);D=(x&16777216|0)!=0;K=o|0;J=B+y|0;R=1797040+J|0;N=B+z|0;_=1732768+N|0;U=J>>>0<68>>>0|N>>>0<68>>>0;do{if(D){if(!U){N=d[_]|0;ba=d[R]|0;TGb(K|0,a[189203+(J<<2)|0]|0,4)|0;le[c[e+48>>2]&1023](h+16|0,l,ba,N,K)}do{if((w|0)!=0){N=F+y|0;ba=d[1797040+N|0]|0;M=F+z|0;I=d[1732768+M|0]|0;if(N>>>0<68>>>0|M>>>0<68>>>0){break}M=b[O>>1]|0;if(M<<16>>16<4){a[K]=a[(M<<16>>16)+(189200+(N<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(N<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(N<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(N<<2))|0]|0;le[c[e+44>>2]&1023](h,l,ba,I,K);break}else{cf[c[e+56>>2]&1023](h,l,ba,I);break}}}while(0);if(U){break}r=d[_]|0;aa=d[R]|0;TGb(K|0,a[189203+(J<<2)|0]|0,4)|0;le[c[e+44>>2]&1023](h+(l<<3)|0,l,aa,r,K)}else{if(!U){r=d[_]|0;aa=d[R]|0;I=a[189203+(J<<2)|0]|0;ba=e+48|0;TGb(K|0,I|0,4)|0;le[c[ba>>2]&1023](h+8|0,l,aa,r,K);TGb(K|0,I|0,4)|0;le[c[ba>>2]&1023](h+16|0,l,aa,r,K);TGb(K|0,I|0,4)|0;le[c[ba>>2]&1023](h+24|0,l,aa,r,K)}do{if((w|0)!=0){r=F+y|0;aa=d[1797040+r|0]|0;ba=F+z|0;I=d[1732768+ba|0]|0;if(r>>>0<68>>>0|ba>>>0<68>>>0){break}ba=b[O>>1]|0;if(ba<<16>>16<4){a[K]=a[(ba<<16>>16)+(189200+(r<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(r<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(r<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(r<<2))|0]|0;le[c[e+44>>2]&1023](h,l,aa,I,K);break}else{cf[c[e+56>>2]&1023](h,l,aa,I);break}}}while(0);if(U){break}I=d[_]|0;aa=d[R]|0;r=a[189203+(J<<2)|0]|0;ba=e+44|0;TGb(K|0,r|0,4)|0;le[c[ba>>2]&1023](h+(l<<2)|0,l,aa,I,K);TGb(K|0,r|0,4)|0;le[c[ba>>2]&1023](h+(l<<3)|0,l,aa,I,K);TGb(K|0,r|0,4)|0;le[c[ba>>2]&1023](h+(l*12|0)|0,l,aa,I,K)}}while(0);if(!s){i=n;return}if(t){do{if(Q){J=G+y|0;R=G+z|0;if(J>>>0<68>>>0|R>>>0<68>>>0){break}_=d[1732768+R|0]|0;R=d[1797040+J|0]|0;J=e+60|0;cf[c[J>>2]&1023](j,l,R,_);cf[c[J>>2]&1023](k,l,R,_)}}while(0);_=A+y|0;R=1797040+_|0;J=A+z|0;U=1732768+J|0;I=_>>>0<68>>>0|J>>>0<68>>>0;if(D){if(!I){J=d[U]|0;aa=d[R]|0;ba=a[189203+(_<<2)|0]|0;r=e+48|0;TGb(K|0,ba|0,4)|0;le[c[r>>2]&1023](j+16|0,l,aa,J,K);TGb(K|0,ba|0,4)|0;le[c[r>>2]&1023](k+16|0,l,aa,J,K)}do{if((w|0)!=0){J=C+y|0;aa=d[1797040+J|0]|0;r=C+z|0;ba=d[1732768+r|0]|0;if(J>>>0<68>>>0|r>>>0<68>>>0){break}r=b[O>>1]|0;if(r<<16>>16<4){a[K]=a[(r<<16>>16)+(189200+(J<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(J<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(J<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(J<<2))|0]|0;le[c[e+44>>2]&1023](j,l,aa,ba,K);a[K]=a[(r<<16>>16)+(189200+(J<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(J<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(J<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(J<<2))|0]|0;le[c[e+44>>2]&1023](k,l,aa,ba,K);break}else{cf[c[e+56>>2]&1023](j,l,aa,ba);cf[c[e+56>>2]&1023](k,l,aa,ba);break}}}while(0);D=l<<3;if(I){i=n;return}ba=d[U]|0;aa=d[R]|0;J=a[189203+(_<<2)|0]|0;r=e+44|0;TGb(K|0,J|0,4)|0;le[c[r>>2]&1023](j+D|0,l,aa,ba,K);TGb(K|0,J|0,4)|0;le[c[r>>2]&1023](k+D|0,l,aa,ba,K);i=n;return}else{if(!I){ba=d[U]|0;aa=d[R]|0;D=a[189203+(_<<2)|0]|0;r=e+48|0;TGb(K|0,D|0,4)|0;le[c[r>>2]&1023](j+8|0,l,aa,ba,K);TGb(K|0,D|0,4)|0;le[c[r>>2]&1023](k+8|0,l,aa,ba,K);TGb(K|0,D|0,4)|0;le[c[r>>2]&1023](j+16|0,l,aa,ba,K);TGb(K|0,D|0,4)|0;le[c[r>>2]&1023](k+16|0,l,aa,ba,K);TGb(K|0,D|0,4)|0;le[c[r>>2]&1023](j+24|0,l,aa,ba,K);TGb(K|0,D|0,4)|0;le[c[r>>2]&1023](k+24|0,l,aa,ba,K)}do{if((w|0)!=0){ba=C+y|0;aa=d[1797040+ba|0]|0;r=C+z|0;D=d[1732768+r|0]|0;if(ba>>>0<68>>>0|r>>>0<68>>>0){break}r=b[O>>1]|0;if(r<<16>>16<4){a[K]=a[(r<<16>>16)+(189200+(ba<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(ba<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(ba<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(ba<<2))|0]|0;le[c[e+44>>2]&1023](j,l,aa,D,K);a[K]=a[(r<<16>>16)+(189200+(ba<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(ba<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(ba<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(ba<<2))|0]|0;le[c[e+44>>2]&1023](k,l,aa,D,K);break}else{cf[c[e+56>>2]&1023](j,l,aa,D);cf[c[e+56>>2]&1023](k,l,aa,D);break}}}while(0);D=l<<2;if(I){i=n;return}aa=d[U]|0;ba=d[R]|0;r=a[189203+(_<<2)|0]|0;J=e+44|0;TGb(K|0,r|0,4)|0;le[c[J>>2]&1023](j+D|0,l,ba,aa,K);TGb(K|0,r|0,4)|0;le[c[J>>2]&1023](k+D|0,l,ba,aa,K);D=l<<3;TGb(K|0,r|0,4)|0;le[c[J>>2]&1023](j+D|0,l,ba,aa,K);TGb(K|0,r|0,4)|0;le[c[J>>2]&1023](k+D|0,l,ba,aa,K);D=l*12|0;TGb(K|0,r|0,4)|0;le[c[J>>2]&1023](j+D|0,l,ba,aa,K);TGb(K|0,r|0,4)|0;le[c[J>>2]&1023](k+D|0,l,ba,aa,K);i=n;return}}if(u){do{if(Q){aa=G+y|0;ba=G+z|0;if(aa>>>0<68>>>0|ba>>>0<68>>>0){break}D=d[1732768+ba|0]|0;ba=d[1797040+aa|0]|0;aa=e+84|0;cf[c[aa>>2]&1023](j,m,ba,D);cf[c[aa>>2]&1023](k,m,ba,D)}}while(0);u=A+y|0;_=1797040+u|0;R=A+z|0;U=1732768+R|0;I=u>>>0<68>>>0|R>>>0<68>>>0;if(!I){R=d[U]|0;D=d[_]|0;ba=(a[189203+(u<<2)|0]|0)+1&255;aa=e+72|0;TGb(K|0,ba|0,4)|0;le[c[aa>>2]&1023](j+8|0,m,D,R,K);TGb(K|0,ba|0,4)|0;le[c[aa>>2]&1023](k+8|0,m,D,R,K)}do{if((w|0)!=0){R=C+y|0;D=d[1797040+R|0]|0;aa=C+z|0;ba=d[1732768+aa|0]|0;if(R>>>0<68>>>0|aa>>>0<68>>>0){break}aa=b[O>>1]|0;if(aa<<16>>16<4){a[K]=(a[(aa<<16>>16)+(189200+(R<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(189200+(R<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(189200+(R<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(189200+(R<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,D,ba,K);a[K]=(a[(aa<<16>>16)+(189200+(R<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(189200+(R<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(189200+(R<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(189200+(R<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,D,ba,K);break}else{cf[c[e+80>>2]&1023](j,m,D,ba);cf[c[e+80>>2]&1023](k,m,D,ba);break}}}while(0);ba=m<<2;if(I){i=n;return}D=d[U]|0;R=d[_]|0;aa=(a[189203+(u<<2)|0]|0)+1&255;J=e+68|0;TGb(K|0,aa|0,4)|0;le[c[J>>2]&1023](j+ba|0,m,R,D,K);TGb(K|0,aa|0,4)|0;le[c[J>>2]&1023](k+ba|0,m,R,D,K);ba=m<<3;TGb(K|0,aa|0,4)|0;le[c[J>>2]&1023](j+ba|0,m,R,D,K);TGb(K|0,aa|0,4)|0;le[c[J>>2]&1023](k+ba|0,m,R,D,K);ba=m*12|0;TGb(K|0,aa|0,4)|0;le[c[J>>2]&1023](j+ba|0,m,R,D,K);TGb(K|0,aa|0,4)|0;le[c[J>>2]&1023](k+ba|0,m,R,D,K);i=n;return}else{do{if(Q){D=G+y|0;R=G+z|0;if(D>>>0<68>>>0|R>>>0<68>>>0){break}ba=d[1732768+R|0]|0;R=d[1797040+D|0]|0;D=e+84|0;cf[c[D>>2]&1023](j,m,R,ba);cf[c[D>>2]&1023](k,m,R,ba)}}while(0);Q=A+y|0;u=1797040+Q|0;_=A+z|0;U=1732768+_|0;I=Q>>>0<68>>>0|_>>>0<68>>>0;if(!I){_=d[U]|0;ba=d[u]|0;R=(a[189203+(Q<<2)|0]|0)+1&255;D=e+72|0;TGb(K|0,R|0,4)|0;le[c[D>>2]&1023](j+8|0,m,ba,_,K);TGb(K|0,R|0,4)|0;le[c[D>>2]&1023](k+8|0,m,ba,_,K)}do{if((w|0)!=0){_=C+y|0;ba=d[1797040+_|0]|0;D=C+z|0;R=d[1732768+D|0]|0;if(_>>>0<68>>>0|D>>>0<68>>>0){break}D=b[O>>1]|0;if(D<<16>>16<4){a[K]=(a[(D<<16>>16)+(189200+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(189200+(_<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,ba,R,K);a[K]=(a[(D<<16>>16)+(189200+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(189200+(_<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,ba,R,K);break}else{cf[c[e+80>>2]&1023](j,m,ba,R);cf[c[e+80>>2]&1023](k,m,ba,R);break}}}while(0);O=m<<2;if(I){i=n;return}R=d[U]|0;ba=d[u]|0;_=(a[189203+(Q<<2)|0]|0)+1&255;D=e+68|0;TGb(K|0,_|0,4)|0;le[c[D>>2]&1023](j+O|0,m,ba,R,K);TGb(K|0,_|0,4)|0;le[c[D>>2]&1023](k+O|0,m,ba,R,K);i=n;return}}R=p;ba=(x&16777216|0)!=0;O=c[e+426564>>2]|0;do{if(ba){if((O&7|0)!=7|t){S=80;break}D=p|0;c[D>>2]=131074;c[D+4>>2]=131074;D=p+16|0;c[D>>2]=131074;c[D+4>>2]=131074;D=p+32|0;c[D>>2]=131074;c[D+4>>2]=131074;D=p+48|0;c[D>>2]=131074;c[D+4>>2]=131074;ca=4}else{S=80}}while(0);if((S|0)==80){K=-((x*5|0)>>>5&1)&3|x>>4;Q=4-(-((O&15|0)==0&x>>>3)&3)|0;Ne[q&127](R,e+5184|0,e+5632|0,e+5312|0,(c[e+199428>>2]|0)==2|0,Q,(x>>24)+1|0,-((v*5|0)>>>5&1&K>>>1)&3,K,(c[e+177100>>2]|0)!=3|0);ca=Q}if((v&7|0)!=0){Q=p|0;c[Q>>2]=262148;c[Q+4>>2]=262148}if((w&7|0)!=0){Q=(c[e+177100>>2]|0)!=3;K=p+32|0;c[K>>2]=Q?196611:262148;c[K+4>>2]=Q?196611:262148}do{if((v|0)!=0){Q=p;K=p|0;u=c[K>>2]|0;U=u&65535;if((u|0)==0&(c[K+4>>2]|0)==0){break}K=o|0;u=E+y|0;I=d[1797040+u|0]|0;D=E+z|0;_=d[1732768+D|0]|0;do{if(!(u>>>0<68>>>0|D>>>0<68>>>0)){if(U<<16>>16<4){a[K]=a[(U<<16>>16)+(189200+(u<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(189200+(u<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(189200+(u<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(189200+(u<<2))|0]|0;le[c[e+48>>2]&1023](h,l,I,_,K);break}else{cf[c[e+60>>2]&1023](h,l,I,_);break}}}while(0);if(!s){break}_=G+y|0;I=d[1797040+_|0]|0;u=G+z|0;U=d[1732768+u|0]|0;D=_>>>0<68>>>0|u>>>0<68>>>0;if(t){if(D){break}u=b[Q>>1]|0;if(u<<16>>16<4){a[K]=a[(u<<16>>16)+(189200+(_<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(189200+(_<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(189200+(_<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(189200+(_<<2))|0]|0;le[c[e+48>>2]&1023](j,l,I,U,K)}else{cf[c[e+60>>2]&1023](j,l,I,U)}u=b[Q>>1]|0;if(u<<16>>16<4){a[K]=a[(u<<16>>16)+(189200+(_<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(189200+(_<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(189200+(_<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(189200+(_<<2))|0]|0;le[c[e+48>>2]&1023](k,l,I,U,K);break}else{cf[c[e+60>>2]&1023](k,l,I,U);break}}else{if(D){break}D=b[Q>>1]|0;if(D<<16>>16<4){a[K]=(a[(D<<16>>16)+(189200+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[Q+2>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[Q+4>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[Q+6>>1]|0)+(189200+(_<<2))|0]|0)+1;le[c[e+72>>2]&1023](j,m,I,U,K)}else{cf[c[e+84>>2]&1023](j,m,I,U)}D=b[Q>>1]|0;if(D<<16>>16<4){a[K]=(a[(D<<16>>16)+(189200+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[Q+2>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[Q+4>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[Q+6>>1]|0)+(189200+(_<<2))|0]|0)+1;le[c[e+72>>2]&1023](k,m,I,U,K);break}else{cf[c[e+84>>2]&1023](k,m,I,U);break}}}}while(0);if((ca|0)==1){if((w|0)==0){i=n;return}G=p+32|0;E=G;v=G|0;G=c[v>>2]|0;x=G&65535;if((G|0)==0&(c[v+4>>2]|0)==0){i=n;return}v=o|0;G=F+y|0;R=d[1797040+G|0]|0;O=F+z|0;U=d[1732768+O|0]|0;do{if(!(G>>>0<68>>>0|O>>>0<68>>>0)){if(x<<16>>16<4){a[v]=a[(x<<16>>16)+(189200+(G<<2))|0]|0;a[o+1|0]=a[(b[E+2>>1]|0)+(189200+(G<<2))|0]|0;a[o+2|0]=a[(b[E+4>>1]|0)+(189200+(G<<2))|0]|0;a[o+3|0]=a[(b[E+6>>1]|0)+(189200+(G<<2))|0]|0;le[c[e+44>>2]&1023](h,l,R,U,v);break}else{cf[c[e+56>>2]&1023](h,l,R,U);break}}}while(0);if(!s){i=n;return}U=C+y|0;R=d[1797040+U|0]|0;G=C+z|0;x=d[1732768+G|0]|0;O=U>>>0<68>>>0|G>>>0<68>>>0;if(t){if(O){i=n;return}G=b[E>>1]|0;if(G<<16>>16<4){a[v]=a[(G<<16>>16)+(189200+(U<<2))|0]|0;a[o+1|0]=a[(b[E+2>>1]|0)+(189200+(U<<2))|0]|0;a[o+2|0]=a[(b[E+4>>1]|0)+(189200+(U<<2))|0]|0;a[o+3|0]=a[(b[E+6>>1]|0)+(189200+(U<<2))|0]|0;le[c[e+44>>2]&1023](j,l,R,x,v)}else{cf[c[e+56>>2]&1023](j,l,R,x)}G=b[E>>1]|0;if(G<<16>>16<4){a[v]=a[(G<<16>>16)+(189200+(U<<2))|0]|0;a[o+1|0]=a[(b[E+2>>1]|0)+(189200+(U<<2))|0]|0;a[o+2|0]=a[(b[E+4>>1]|0)+(189200+(U<<2))|0]|0;a[o+3|0]=a[(b[E+6>>1]|0)+(189200+(U<<2))|0]|0;le[c[e+44>>2]&1023](k,l,R,x,v);i=n;return}else{cf[c[e+56>>2]&1023](k,l,R,x);i=n;return}}else{if(O){i=n;return}O=b[E>>1]|0;if(O<<16>>16<4){a[v]=(a[(O<<16>>16)+(189200+(U<<2))|0]|0)+1;a[o+1|0]=(a[(b[E+2>>1]|0)+(189200+(U<<2))|0]|0)+1;a[o+2|0]=(a[(b[E+4>>1]|0)+(189200+(U<<2))|0]|0)+1;a[o+3|0]=(a[(b[E+6>>1]|0)+(189200+(U<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,R,x,v)}else{cf[c[e+80>>2]&1023](j,m,R,x)}O=b[E>>1]|0;if(O<<16>>16<4){a[v]=(a[(O<<16>>16)+(189200+(U<<2))|0]|0)+1;a[o+1|0]=(a[(b[E+2>>1]|0)+(189200+(U<<2))|0]|0)+1;a[o+2|0]=(a[(b[E+4>>1]|0)+(189200+(U<<2))|0]|0)+1;a[o+3|0]=(a[(b[E+6>>1]|0)+(189200+(U<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,R,x,v);i=n;return}else{cf[c[e+80>>2]&1023](k,m,R,x);i=n;return}}}if(ba){x=p+16|0;R=x;U=x|0;x=c[U>>2]|0;O=x&65535;do{if(!((x|0)==0&(c[U+4>>2]|0)==0)){G=o|0;I=B+y|0;_=B+z|0;if(!(I>>>0<68>>>0|_>>>0<68>>>0)){D=d[1732768+_|0]|0;_=d[1797040+I|0]|0;a[G]=a[(O<<16>>16)+(189200+(I<<2))|0]|0;a[o+1|0]=a[(b[R+2>>1]|0)+(189200+(I<<2))|0]|0;a[o+2|0]=a[(b[R+4>>1]|0)+(189200+(I<<2))|0]|0;a[o+3|0]=a[(b[R+6>>1]|0)+(189200+(I<<2))|0]|0;le[c[e+48>>2]&1023](h+16|0,l,_,D,G)}if(!s){break}D=A+y|0;_=A+z|0;I=D>>>0<68>>>0|_>>>0<68>>>0;if(t){if(I){break}u=d[1732768+_|0]|0;J=d[1797040+D|0]|0;a[G]=a[(b[R>>1]|0)+(189200+(D<<2))|0]|0;aa=R+2|0;r=o+1|0;a[r]=a[(b[aa>>1]|0)+(189200+(D<<2))|0]|0;N=R+4|0;M=o+2|0;a[M]=a[(b[N>>1]|0)+(189200+(D<<2))|0]|0;P=R+6|0;L=o+3|0;a[L]=a[(b[P>>1]|0)+(189200+(D<<2))|0]|0;$=e+48|0;le[c[$>>2]&1023](j+16|0,l,J,u,G);a[G]=a[(b[R>>1]|0)+(189200+(D<<2))|0]|0;a[r]=a[(b[aa>>1]|0)+(189200+(D<<2))|0]|0;a[M]=a[(b[N>>1]|0)+(189200+(D<<2))|0]|0;a[L]=a[(b[P>>1]|0)+(189200+(D<<2))|0]|0;le[c[$>>2]&1023](k+16|0,l,J,u,G);break}else{if(I){break}I=d[1732768+_|0]|0;_=d[1797040+D|0]|0;a[G]=(a[(b[R>>1]|0)+(189200+(D<<2))|0]|0)+1;u=R+2|0;J=o+1|0;a[J]=(a[(b[u>>1]|0)+(189200+(D<<2))|0]|0)+1;$=R+4|0;P=o+2|0;a[P]=(a[(b[$>>1]|0)+(189200+(D<<2))|0]|0)+1;L=R+6|0;N=o+3|0;a[N]=(a[(b[L>>1]|0)+(189200+(D<<2))|0]|0)+1;M=e+72|0;le[c[M>>2]&1023](j+8|0,m,_,I,G);a[G]=(a[(b[R>>1]|0)+(189200+(D<<2))|0]|0)+1;a[J]=(a[(b[u>>1]|0)+(189200+(D<<2))|0]|0)+1;a[P]=(a[(b[$>>1]|0)+(189200+(D<<2))|0]|0)+1;a[N]=(a[(b[L>>1]|0)+(189200+(D<<2))|0]|0)+1;le[c[M>>2]&1023](k+8|0,m,_,I,G);break}}}while(0);do{if((w|0)!=0){R=p+32|0;O=R;U=R|0;R=c[U>>2]|0;x=R&65535;if((R|0)==0&(c[U+4>>2]|0)==0){break}U=o|0;R=F+y|0;ba=d[1797040+R|0]|0;v=F+z|0;E=d[1732768+v|0]|0;do{if(!(R>>>0<68>>>0|v>>>0<68>>>0)){if(x<<16>>16<4){a[U]=a[(x<<16>>16)+(189200+(R<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(R<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(R<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(R<<2))|0]|0;le[c[e+44>>2]&1023](h,l,ba,E,U);break}else{cf[c[e+56>>2]&1023](h,l,ba,E);break}}}while(0);if(!s){break}E=C+y|0;ba=d[1797040+E|0]|0;R=C+z|0;x=d[1732768+R|0]|0;v=E>>>0<68>>>0|R>>>0<68>>>0;if(t){if(v){break}R=b[O>>1]|0;if(R<<16>>16<4){a[U]=a[(R<<16>>16)+(189200+(E<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(E<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(E<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(E<<2))|0]|0;le[c[e+44>>2]&1023](j,l,ba,x,U)}else{cf[c[e+56>>2]&1023](j,l,ba,x)}R=b[O>>1]|0;if(R<<16>>16<4){a[U]=a[(R<<16>>16)+(189200+(E<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(189200+(E<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(189200+(E<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(189200+(E<<2))|0]|0;le[c[e+44>>2]&1023](k,l,ba,x,U);break}else{cf[c[e+56>>2]&1023](k,l,ba,x);break}}else{if(v){break}v=b[O>>1]|0;if(v<<16>>16<4){a[U]=(a[(v<<16>>16)+(189200+(E<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(189200+(E<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(189200+(E<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(189200+(E<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,ba,x,U)}else{cf[c[e+80>>2]&1023](j,m,ba,x)}v=b[O>>1]|0;if(v<<16>>16<4){a[U]=(a[(v<<16>>16)+(189200+(E<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(189200+(E<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(189200+(E<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(189200+(E<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,ba,x,U);break}else{cf[c[e+80>>2]&1023](k,m,ba,x);break}}}}while(0);x=p+48|0;ba=x;E=x|0;x=c[E>>2]|0;if((x|0)==0&(c[E+4>>2]|0)==0){i=n;return}E=l<<3;v=o|0;R=B+y|0;K=B+z|0;if(!(R>>>0<68>>>0|K>>>0<68>>>0)){Q=d[1732768+K|0]|0;K=d[1797040+R|0]|0;a[v]=a[((x&65535)<<16>>16)+(189200+(R<<2))|0]|0;a[o+1|0]=a[(b[ba+2>>1]|0)+(189200+(R<<2))|0]|0;a[o+2|0]=a[(b[ba+4>>1]|0)+(189200+(R<<2))|0]|0;a[o+3|0]=a[(b[ba+6>>1]|0)+(189200+(R<<2))|0]|0;le[c[e+44>>2]&1023](h+E|0,l,K,Q,v)}if(!s){i=n;return}if(t){Q=A+y|0;K=A+z|0;if(Q>>>0<68>>>0|K>>>0<68>>>0){i=n;return}R=d[1732768+K|0]|0;K=d[1797040+Q|0]|0;a[v]=a[(b[ba>>1]|0)+(189200+(Q<<2))|0]|0;x=ba+2|0;G=o+1|0;a[G]=a[(b[x>>1]|0)+(189200+(Q<<2))|0]|0;I=ba+4|0;_=o+2|0;a[_]=a[(b[I>>1]|0)+(189200+(Q<<2))|0]|0;M=ba+6|0;D=o+3|0;a[D]=a[(b[M>>1]|0)+(189200+(Q<<2))|0]|0;L=e+44|0;le[c[L>>2]&1023](j+E|0,l,K,R,v);a[v]=a[(b[ba>>1]|0)+(189200+(Q<<2))|0]|0;a[G]=a[(b[x>>1]|0)+(189200+(Q<<2))|0]|0;a[_]=a[(b[I>>1]|0)+(189200+(Q<<2))|0]|0;a[D]=a[(b[M>>1]|0)+(189200+(Q<<2))|0]|0;le[c[L>>2]&1023](k+E|0,l,K,R,v);i=n;return}else{R=m<<2;K=A+y|0;E=A+z|0;if(K>>>0<68>>>0|E>>>0<68>>>0){i=n;return}L=d[1732768+E|0]|0;E=d[1797040+K|0]|0;a[v]=(a[(b[ba>>1]|0)+(189200+(K<<2))|0]|0)+1;Q=ba+2|0;M=o+1|0;a[M]=(a[(b[Q>>1]|0)+(189200+(K<<2))|0]|0)+1;D=ba+4|0;I=o+2|0;a[I]=(a[(b[D>>1]|0)+(189200+(K<<2))|0]|0)+1;_=ba+6|0;x=o+3|0;a[x]=(a[(b[_>>1]|0)+(189200+(K<<2))|0]|0)+1;G=e+68|0;le[c[G>>2]&1023](j+R|0,m,E,L,v);a[v]=(a[(b[ba>>1]|0)+(189200+(K<<2))|0]|0)+1;a[M]=(a[(b[Q>>1]|0)+(189200+(K<<2))|0]|0)+1;a[I]=(a[(b[D>>1]|0)+(189200+(K<<2))|0]|0)+1;a[x]=(a[(b[_>>1]|0)+(189200+(K<<2))|0]|0)+1;le[c[G>>2]&1023](k+R|0,m,E,L,v);i=n;return}}v=p+8|0;L=v;E=v|0;v=c[E>>2]|0;R=v&65535;do{if(!((v|0)==0&(c[E+4>>2]|0)==0)){G=o|0;K=B+y|0;_=B+z|0;if(!(K>>>0<68>>>0|_>>>0<68>>>0)){x=d[1732768+_|0]|0;_=d[1797040+K|0]|0;a[G]=a[(R<<16>>16)+(189200+(K<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(189200+(K<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(189200+(K<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(189200+(K<<2))|0]|0;le[c[e+48>>2]&1023](h+8|0,l,_,x,G)}if(!t){break}x=A+y|0;_=A+z|0;if(x>>>0<68>>>0|_>>>0<68>>>0){break}K=d[1732768+_|0]|0;_=d[1797040+x|0]|0;a[G]=a[(b[L>>1]|0)+(189200+(x<<2))|0]|0;D=L+2|0;I=o+1|0;a[I]=a[(b[D>>1]|0)+(189200+(x<<2))|0]|0;Q=L+4|0;M=o+2|0;a[M]=a[(b[Q>>1]|0)+(189200+(x<<2))|0]|0;ba=L+6|0;N=o+3|0;a[N]=a[(b[ba>>1]|0)+(189200+(x<<2))|0]|0;$=e+48|0;le[c[$>>2]&1023](j+8|0,l,_,K,G);a[G]=a[(b[L>>1]|0)+(189200+(x<<2))|0]|0;a[I]=a[(b[D>>1]|0)+(189200+(x<<2))|0]|0;a[M]=a[(b[Q>>1]|0)+(189200+(x<<2))|0]|0;a[N]=a[(b[ba>>1]|0)+(189200+(x<<2))|0]|0;le[c[$>>2]&1023](k+8|0,l,_,K,G)}}while(0);L=p+16|0;R=L;E=L|0;L=c[E>>2]|0;v=L&65535;do{if(!((L|0)==0&(c[E+4>>2]|0)==0)){G=o|0;K=B+y|0;_=B+z|0;if(!(K>>>0<68>>>0|_>>>0<68>>>0)){$=d[1732768+_|0]|0;_=d[1797040+K|0]|0;a[G]=a[(v<<16>>16)+(189200+(K<<2))|0]|0;a[o+1|0]=a[(b[R+2>>1]|0)+(189200+(K<<2))|0]|0;a[o+2|0]=a[(b[R+4>>1]|0)+(189200+(K<<2))|0]|0;a[o+3|0]=a[(b[R+6>>1]|0)+(189200+(K<<2))|0]|0;le[c[e+48>>2]&1023](h+16|0,l,_,$,G)}if(!s){break}$=A+y|0;_=A+z|0;K=$>>>0<68>>>0|_>>>0<68>>>0;if(t){if(K){break}x=d[1732768+_|0]|0;ba=d[1797040+$|0]|0;a[G]=a[(b[R>>1]|0)+(189200+($<<2))|0]|0;N=R+2|0;Q=o+1|0;a[Q]=a[(b[N>>1]|0)+(189200+($<<2))|0]|0;M=R+4|0;D=o+2|0;a[D]=a[(b[M>>1]|0)+(189200+($<<2))|0]|0;I=R+6|0;P=o+3|0;a[P]=a[(b[I>>1]|0)+(189200+($<<2))|0]|0;u=e+48|0;le[c[u>>2]&1023](j+16|0,l,ba,x,G);a[G]=a[(b[R>>1]|0)+(189200+($<<2))|0]|0;a[Q]=a[(b[N>>1]|0)+(189200+($<<2))|0]|0;a[D]=a[(b[M>>1]|0)+(189200+($<<2))|0]|0;a[P]=a[(b[I>>1]|0)+(189200+($<<2))|0]|0;le[c[u>>2]&1023](k+16|0,l,ba,x,G);break}else{if(K){break}K=d[1732768+_|0]|0;_=d[1797040+$|0]|0;a[G]=(a[(b[R>>1]|0)+(189200+($<<2))|0]|0)+1;x=R+2|0;ba=o+1|0;a[ba]=(a[(b[x>>1]|0)+(189200+($<<2))|0]|0)+1;u=R+4|0;I=o+2|0;a[I]=(a[(b[u>>1]|0)+(189200+($<<2))|0]|0)+1;P=R+6|0;M=o+3|0;a[M]=(a[(b[P>>1]|0)+(189200+($<<2))|0]|0)+1;D=e+72|0;le[c[D>>2]&1023](j+8|0,m,_,K,G);a[G]=(a[(b[R>>1]|0)+(189200+($<<2))|0]|0)+1;a[ba]=(a[(b[x>>1]|0)+(189200+($<<2))|0]|0)+1;a[I]=(a[(b[u>>1]|0)+(189200+($<<2))|0]|0)+1;a[M]=(a[(b[P>>1]|0)+(189200+($<<2))|0]|0)+1;le[c[D>>2]&1023](k+8|0,m,_,K,G);break}}}while(0);R=p+24|0;v=R;E=R|0;R=c[E>>2]|0;L=R&65535;do{if(!((R|0)==0&(c[E+4>>2]|0)==0)){G=o|0;K=B+y|0;_=B+z|0;if(!(K>>>0<68>>>0|_>>>0<68>>>0)){D=d[1732768+_|0]|0;_=d[1797040+K|0]|0;a[G]=a[(L<<16>>16)+(189200+(K<<2))|0]|0;a[o+1|0]=a[(b[v+2>>1]|0)+(189200+(K<<2))|0]|0;a[o+2|0]=a[(b[v+4>>1]|0)+(189200+(K<<2))|0]|0;a[o+3|0]=a[(b[v+6>>1]|0)+(189200+(K<<2))|0]|0;le[c[e+48>>2]&1023](h+24|0,l,_,D,G)}if(!t){break}D=A+y|0;_=A+z|0;if(D>>>0<68>>>0|_>>>0<68>>>0){break}K=d[1732768+_|0]|0;_=d[1797040+D|0]|0;a[G]=a[(b[v>>1]|0)+(189200+(D<<2))|0]|0;$=v+2|0;P=o+1|0;a[P]=a[(b[$>>1]|0)+(189200+(D<<2))|0]|0;M=v+4|0;u=o+2|0;a[u]=a[(b[M>>1]|0)+(189200+(D<<2))|0]|0;I=v+6|0;x=o+3|0;a[x]=a[(b[I>>1]|0)+(189200+(D<<2))|0]|0;ba=e+48|0;le[c[ba>>2]&1023](j+24|0,l,_,K,G);a[G]=a[(b[v>>1]|0)+(189200+(D<<2))|0]|0;a[P]=a[(b[$>>1]|0)+(189200+(D<<2))|0]|0;a[u]=a[(b[M>>1]|0)+(189200+(D<<2))|0]|0;a[x]=a[(b[I>>1]|0)+(189200+(D<<2))|0]|0;le[c[ba>>2]&1023](k+24|0,l,_,K,G)}}while(0);do{if((w|0)!=0){v=p+32|0;L=v;E=v|0;v=c[E>>2]|0;R=v&65535;if((v|0)==0&(c[E+4>>2]|0)==0){break}E=o|0;v=F+y|0;G=d[1797040+v|0]|0;K=F+z|0;_=d[1732768+K|0]|0;do{if(!(v>>>0<68>>>0|K>>>0<68>>>0)){if(R<<16>>16<4){a[E]=a[(R<<16>>16)+(189200+(v<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(189200+(v<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(189200+(v<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(189200+(v<<2))|0]|0;le[c[e+44>>2]&1023](h,l,G,_,E);break}else{cf[c[e+56>>2]&1023](h,l,G,_);break}}}while(0);if(!s){break}_=C+y|0;G=d[1797040+_|0]|0;v=C+z|0;R=d[1732768+v|0]|0;K=_>>>0<68>>>0|v>>>0<68>>>0;if(t){if(K){break}v=b[L>>1]|0;if(v<<16>>16<4){a[E]=a[(v<<16>>16)+(189200+(_<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(189200+(_<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(189200+(_<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(189200+(_<<2))|0]|0;le[c[e+44>>2]&1023](j,l,G,R,E)}else{cf[c[e+56>>2]&1023](j,l,G,R)}v=b[L>>1]|0;if(v<<16>>16<4){a[E]=a[(v<<16>>16)+(189200+(_<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(189200+(_<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(189200+(_<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(189200+(_<<2))|0]|0;le[c[e+44>>2]&1023](k,l,G,R,E);break}else{cf[c[e+56>>2]&1023](k,l,G,R);break}}else{if(K){break}K=b[L>>1]|0;if(K<<16>>16<4){a[E]=(a[(K<<16>>16)+(189200+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[L+2>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[L+4>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[L+6>>1]|0)+(189200+(_<<2))|0]|0)+1;le[c[e+68>>2]&1023](j,m,G,R,E)}else{cf[c[e+80>>2]&1023](j,m,G,R)}K=b[L>>1]|0;if(K<<16>>16<4){a[E]=(a[(K<<16>>16)+(189200+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[L+2>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[L+4>>1]|0)+(189200+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[L+6>>1]|0)+(189200+(_<<2))|0]|0)+1;le[c[e+68>>2]&1023](k,m,G,R,E);break}else{cf[c[e+80>>2]&1023](k,m,G,R);break}}}}while(0);C=p+40|0;F=C;w=C|0;C=c[w>>2]|0;R=C&65535;do{if(!((C|0)==0&(c[w+4>>2]|0)==0)){G=l<<2;_=o|0;K=B+y|0;v=B+z|0;if(!(K>>>0<68>>>0|v>>>0<68>>>0)){U=d[1732768+v|0]|0;v=d[1797040+K|0]|0;a[_]=a[(R<<16>>16)+(189200+(K<<2))|0]|0;a[o+1|0]=a[(b[F+2>>1]|0)+(189200+(K<<2))|0]|0;a[o+2|0]=a[(b[F+4>>1]|0)+(189200+(K<<2))|0]|0;a[o+3|0]=a[(b[F+6>>1]|0)+(189200+(K<<2))|0]|0;le[c[e+44>>2]&1023](h+G|0,l,v,U,_)}if(!t){break}U=A+y|0;v=A+z|0;if(U>>>0<68>>>0|v>>>0<68>>>0){break}K=d[1732768+v|0]|0;v=d[1797040+U|0]|0;a[_]=a[(b[F>>1]|0)+(189200+(U<<2))|0]|0;O=F+2|0;ba=o+1|0;a[ba]=a[(b[O>>1]|0)+(189200+(U<<2))|0]|0;D=F+4|0;I=o+2|0;a[I]=a[(b[D>>1]|0)+(189200+(U<<2))|0]|0;x=F+6|0;M=o+3|0;a[M]=a[(b[x>>1]|0)+(189200+(U<<2))|0]|0;u=e+44|0;le[c[u>>2]&1023](j+G|0,l,v,K,_);a[_]=a[(b[F>>1]|0)+(189200+(U<<2))|0]|0;a[ba]=a[(b[O>>1]|0)+(189200+(U<<2))|0]|0;a[I]=a[(b[D>>1]|0)+(189200+(U<<2))|0]|0;a[M]=a[(b[x>>1]|0)+(189200+(U<<2))|0]|0;le[c[u>>2]&1023](k+G|0,l,v,K,_)}}while(0);F=p+48|0;R=F;w=F|0;F=c[w>>2]|0;C=F&65535;do{if(!((F|0)==0&(c[w+4>>2]|0)==0)){_=l<<3;K=o|0;v=B+y|0;G=B+z|0;if(!(v>>>0<68>>>0|G>>>0<68>>>0)){u=d[1732768+G|0]|0;G=d[1797040+v|0]|0;a[K]=a[(C<<16>>16)+(189200+(v<<2))|0]|0;a[o+1|0]=a[(b[R+2>>1]|0)+(189200+(v<<2))|0]|0;a[o+2|0]=a[(b[R+4>>1]|0)+(189200+(v<<2))|0]|0;a[o+3|0]=a[(b[R+6>>1]|0)+(189200+(v<<2))|0]|0;le[c[e+44>>2]&1023](h+_|0,l,G,u,K)}if(!s){break}if(t){u=A+y|0;G=A+z|0;if(u>>>0<68>>>0|G>>>0<68>>>0){break}v=d[1732768+G|0]|0;G=d[1797040+u|0]|0;a[K]=a[(b[R>>1]|0)+(189200+(u<<2))|0]|0;U=R+2|0;x=o+1|0;a[x]=a[(b[U>>1]|0)+(189200+(u<<2))|0]|0;M=R+4|0;D=o+2|0;a[D]=a[(b[M>>1]|0)+(189200+(u<<2))|0]|0;I=R+6|0;O=o+3|0;a[O]=a[(b[I>>1]|0)+(189200+(u<<2))|0]|0;ba=e+44|0;le[c[ba>>2]&1023](j+_|0,l,G,v,K);a[K]=a[(b[R>>1]|0)+(189200+(u<<2))|0]|0;a[x]=a[(b[U>>1]|0)+(189200+(u<<2))|0]|0;a[D]=a[(b[M>>1]|0)+(189200+(u<<2))|0]|0;a[O]=a[(b[I>>1]|0)+(189200+(u<<2))|0]|0;le[c[ba>>2]&1023](k+_|0,l,G,v,K);break}else{v=m<<2;G=A+y|0;_=A+z|0;if(G>>>0<68>>>0|_>>>0<68>>>0){break}ba=d[1732768+_|0]|0;_=d[1797040+G|0]|0;a[K]=(a[(b[R>>1]|0)+(189200+(G<<2))|0]|0)+1;u=R+2|0;I=o+1|0;a[I]=(a[(b[u>>1]|0)+(189200+(G<<2))|0]|0)+1;O=R+4|0;M=o+2|0;a[M]=(a[(b[O>>1]|0)+(189200+(G<<2))|0]|0)+1;D=R+6|0;U=o+3|0;a[U]=(a[(b[D>>1]|0)+(189200+(G<<2))|0]|0)+1;x=e+68|0;le[c[x>>2]&1023](j+v|0,m,_,ba,K);a[K]=(a[(b[R>>1]|0)+(189200+(G<<2))|0]|0)+1;a[I]=(a[(b[u>>1]|0)+(189200+(G<<2))|0]|0)+1;a[M]=(a[(b[O>>1]|0)+(189200+(G<<2))|0]|0)+1;a[U]=(a[(b[D>>1]|0)+(189200+(G<<2))|0]|0)+1;le[c[x>>2]&1023](k+v|0,m,_,ba,K);break}}}while(0);R=p+56|0;s=R;C=R|0;R=c[C>>2]|0;if((R|0)==0&(c[C+4>>2]|0)==0){i=n;return}C=l*12|0;w=o|0;F=B+y|0;K=B+z|0;if(!(F>>>0<68>>>0|K>>>0<68>>>0)){ba=d[1732768+K|0]|0;K=d[1797040+F|0]|0;a[w]=a[((R&65535)<<16>>16)+(189200+(F<<2))|0]|0;a[o+1|0]=a[(b[s+2>>1]|0)+(189200+(F<<2))|0]|0;a[o+2|0]=a[(b[s+4>>1]|0)+(189200+(F<<2))|0]|0;a[o+3|0]=a[(b[s+6>>1]|0)+(189200+(F<<2))|0]|0;le[c[e+44>>2]&1023](h+C|0,l,K,ba,w)}if(!t){i=n;return}ba=A+y|0;K=A+z|0;if(ba>>>0<68>>>0|K>>>0<68>>>0){i=n;return}F=d[1732768+K|0]|0;K=d[1797040+ba|0]|0;a[w]=a[(b[s>>1]|0)+(189200+(ba<<2))|0]|0;R=s+2|0;_=o+1|0;a[_]=a[(b[R>>1]|0)+(189200+(ba<<2))|0]|0;v=s+4|0;x=o+2|0;a[x]=a[(b[v>>1]|0)+(189200+(ba<<2))|0]|0;G=s+6|0;D=o+3|0;a[D]=a[(b[G>>1]|0)+(189200+(ba<<2))|0]|0;U=e+44|0;le[c[U>>2]&1023](j+C|0,l,K,F,w);a[w]=a[(b[s>>1]|0)+(189200+(ba<<2))|0]|0;a[_]=a[(b[R>>1]|0)+(189200+(ba<<2))|0]|0;a[x]=a[(b[v>>1]|0)+(189200+(ba<<2))|0]|0;a[D]=a[(b[G>>1]|0)+(189200+(ba<<2))|0]|0;le[c[U>>2]&1023](k+C|0,l,K,F,w);i=n;return}}}while(0);_da(e,f,g,h,j,k,l,m);i=n;return}function _da(f,g,h,j,k,l,m,n){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0;o=i;i=i+24|0;p=o|0;q=o+8|0;r=q;s=f+427404|0;t=(ba(c[s>>2]|0,h)|0)+g|0;g=f+4064|0;u=c[(c[g>>2]|0)+(t<<2)>>2]|0;v=(u>>>6&2^2)+2|0;w=f+6136|0;x=(c[w>>2]|0)!=0;y=((c[f+7308>>2]|0)*-6|0)+48|0;z=(c[f+427424>>2]|0)+52+y|0;A=(c[f+427428>>2]|0)+52+y|0;y=f+177088|0;B=f+4872|0;do{if((c[y>>2]|0)==0){C=0}else{D=c[B>>2]|0;if(((D^u)&128|0)==0|(D|0)==0){C=0;break}if((u&7|0)==0){D=h&1;E=c[f+177092>>2]|0;F=(E|0)!=0;G=f+7332|0;H=f+426560|0;I=f+5304|0;J=0;while(1){K=F?J>>2:J&1;L=c[f+4852+(K<<2)>>2]|0;M=c[f+4872+(K<<2)>>2]|0;if((M&7|0)==0){K=d[(J>>>1<<3)+12+(f+5184)|0]|0;do{if((c[G>>2]|0)==0){if((M&16777216|0)==0){N=11;break}O=e[(c[H>>2]|0)+(L<<1)>>1]&(((F?J&2:D)|0)!=0?32768:8192)}else{N=11}}while(0);if((N|0)==11){N=0;O=d[(d[1207568+(E<<4)+(D<<3)+J|0]|0)+((c[I>>2]|0)+(L*48|0))|0]|0}b[r+(J<<1)>>1]=(O|K|0)!=0?2:1}else{b[r+(J<<1)>>1]=4}M=J+1|0;if((M|0)<8){J=M}else{P=E;break}}}else{E=q|0;c[E>>2]=262148;c[E+4>>2]=262148;E=q+8|0;c[E>>2]=262148;c[E+4>>2]=262148;P=c[f+177092>>2]|0}E=c[f+4040>>2]|0;J=a[E+t|0]|0;I=a[E+(c[f+4852>>2]|0)|0]|0;D=a[E+(c[f+4856>>2]|0)|0]|0;E=J+1|0;F=(d[f+7876+J|0]|0)+1|0;H=(d[f+7964+J|0]|0)+1|0;J=E+I>>1;G=(F+(d[f+7876+I|0]|0)|0)>>>1;M=(H+(d[f+7964+I|0]|0)|0)>>>1;I=E+D>>1;E=(F+(d[f+7876+D|0]|0)|0)>>>1;F=(H+(d[f+7964+D|0]|0)|0)>>>1;if((P|0)==0){D=m<<1;H=q;Q=p|0;R=J+z|0;S=d[1797040+R|0]|0;T=J+A|0;U=d[1732768+T|0]|0;do{if(!(R>>>0<68>>>0|T>>>0<68>>>0)){V=b[H>>1]|0;if(V<<16>>16<4){a[Q]=a[(V<<16>>16)+(189200+(R<<2))|0]|0;a[p+1|0]=a[(b[H+4>>1]|0)+(189200+(R<<2))|0]|0;a[p+2|0]=a[(b[q+8>>1]|0)+(189200+(R<<2))|0]|0;a[p+3|0]=a[(b[H+12>>1]|0)+(189200+(R<<2))|0]|0;le[c[f+52>>2]&1023](j,D,S,U,Q);break}else{cf[c[f+64>>2]&1023](j,D,S,U);break}}}while(0);U=j+m|0;S=r+2|0;R=I+z|0;T=d[1797040+R|0]|0;V=I+A|0;W=d[1732768+V|0]|0;do{if(!(R>>>0<68>>>0|V>>>0<68>>>0)){X=b[S>>1]|0;if(X<<16>>16<4){a[Q]=a[(X<<16>>16)+(189200+(R<<2))|0]|0;a[p+1|0]=a[(b[r+6>>1]|0)+(189200+(R<<2))|0]|0;a[p+2|0]=a[(b[r+10>>1]|0)+(189200+(R<<2))|0]|0;a[p+3|0]=a[(b[r+14>>1]|0)+(189200+(R<<2))|0]|0;le[c[f+52>>2]&1023](U,D,T,W,Q);break}else{cf[c[f+64>>2]&1023](U,D,T,W);break}}}while(0);if(!x){C=1;break}W=n<<1;T=G+z|0;D=d[1797040+T|0]|0;U=G+A|0;R=d[1732768+U|0]|0;V=T>>>0<68>>>0|U>>>0<68>>>0;if((c[w>>2]|0)==3){do{if(!V){U=b[H>>1]|0;if(U<<16>>16<4){a[Q]=a[(U<<16>>16)+(189200+(T<<2))|0]|0;a[p+1|0]=a[(b[H+4>>1]|0)+(189200+(T<<2))|0]|0;a[p+2|0]=a[(b[q+8>>1]|0)+(189200+(T<<2))|0]|0;a[p+3|0]=a[(b[H+12>>1]|0)+(189200+(T<<2))|0]|0;le[c[f+52>>2]&1023](k,W,D,R,Q);break}else{cf[c[f+64>>2]&1023](k,W,D,R);break}}}while(0);U=k+n|0;X=E+z|0;Y=d[1797040+X|0]|0;Z=E+A|0;_=d[1732768+Z|0]|0;do{if(!(X>>>0<68>>>0|Z>>>0<68>>>0)){$=b[S>>1]|0;if($<<16>>16<4){a[Q]=a[($<<16>>16)+(189200+(X<<2))|0]|0;a[p+1|0]=a[(b[r+6>>1]|0)+(189200+(X<<2))|0]|0;a[p+2|0]=a[(b[r+10>>1]|0)+(189200+(X<<2))|0]|0;a[p+3|0]=a[(b[r+14>>1]|0)+(189200+(X<<2))|0]|0;le[c[f+52>>2]&1023](U,W,Y,_,Q);break}else{cf[c[f+64>>2]&1023](U,W,Y,_);break}}}while(0);_=M+z|0;Y=d[1797040+_|0]|0;U=M+A|0;X=d[1732768+U|0]|0;do{if(!(_>>>0<68>>>0|U>>>0<68>>>0)){Z=b[H>>1]|0;if(Z<<16>>16<4){a[Q]=a[(Z<<16>>16)+(189200+(_<<2))|0]|0;a[p+1|0]=a[(b[H+4>>1]|0)+(189200+(_<<2))|0]|0;a[p+2|0]=a[(b[q+8>>1]|0)+(189200+(_<<2))|0]|0;a[p+3|0]=a[(b[H+12>>1]|0)+(189200+(_<<2))|0]|0;le[c[f+52>>2]&1023](l,W,Y,X,Q);break}else{cf[c[f+64>>2]&1023](l,W,Y,X);break}}}while(0);X=l+n|0;Y=F+z|0;_=d[1797040+Y|0]|0;U=F+A|0;Z=d[1732768+U|0]|0;if(Y>>>0<68>>>0|U>>>0<68>>>0){C=1;break}U=b[S>>1]|0;if(U<<16>>16<4){a[Q]=a[(U<<16>>16)+(189200+(Y<<2))|0]|0;a[p+1|0]=a[(b[r+6>>1]|0)+(189200+(Y<<2))|0]|0;a[p+2|0]=a[(b[r+10>>1]|0)+(189200+(Y<<2))|0]|0;a[p+3|0]=a[(b[r+14>>1]|0)+(189200+(Y<<2))|0]|0;le[c[f+52>>2]&1023](X,W,_,Z,Q);C=1;break}else{cf[c[f+64>>2]&1023](X,W,_,Z);C=1;break}}else{do{if(!V){Z=b[H>>1]|0;if(Z<<16>>16<4){a[Q]=(a[(Z<<16>>16)+(189200+(T<<2))|0]|0)+1;a[p+1|0]=(a[(b[H+4>>1]|0)+(189200+(T<<2))|0]|0)+1;a[p+2|0]=(a[(b[q+8>>1]|0)+(189200+(T<<2))|0]|0)+1;a[p+3|0]=(a[(b[H+12>>1]|0)+(189200+(T<<2))|0]|0)+1;le[c[f+76>>2]&1023](k,W,D,R,Q);break}else{cf[c[f+88>>2]&1023](k,W,D,R);break}}}while(0);R=k+n|0;D=E+z|0;T=d[1797040+D|0]|0;V=E+A|0;Z=d[1732768+V|0]|0;do{if(!(D>>>0<68>>>0|V>>>0<68>>>0)){_=b[S>>1]|0;if(_<<16>>16<4){a[Q]=(a[(_<<16>>16)+(189200+(D<<2))|0]|0)+1;a[p+1|0]=(a[(b[r+6>>1]|0)+(189200+(D<<2))|0]|0)+1;a[p+2|0]=(a[(b[r+10>>1]|0)+(189200+(D<<2))|0]|0)+1;a[p+3|0]=(a[(b[r+14>>1]|0)+(189200+(D<<2))|0]|0)+1;le[c[f+76>>2]&1023](R,W,T,Z,Q);break}else{cf[c[f+88>>2]&1023](R,W,T,Z);break}}}while(0);Z=M+z|0;T=d[1797040+Z|0]|0;R=M+A|0;D=d[1732768+R|0]|0;do{if(!(Z>>>0<68>>>0|R>>>0<68>>>0)){V=b[H>>1]|0;if(V<<16>>16<4){a[Q]=(a[(V<<16>>16)+(189200+(Z<<2))|0]|0)+1;a[p+1|0]=(a[(b[H+4>>1]|0)+(189200+(Z<<2))|0]|0)+1;a[p+2|0]=(a[(b[q+8>>1]|0)+(189200+(Z<<2))|0]|0)+1;a[p+3|0]=(a[(b[H+12>>1]|0)+(189200+(Z<<2))|0]|0)+1;le[c[f+76>>2]&1023](l,W,T,D,Q);break}else{cf[c[f+88>>2]&1023](l,W,T,D);break}}}while(0);D=l+n|0;T=F+z|0;Z=d[1797040+T|0]|0;H=F+A|0;R=d[1732768+H|0]|0;if(T>>>0<68>>>0|H>>>0<68>>>0){C=1;break}H=b[S>>1]|0;if(H<<16>>16<4){a[Q]=(a[(H<<16>>16)+(189200+(T<<2))|0]|0)+1;a[p+1|0]=(a[(b[r+6>>1]|0)+(189200+(T<<2))|0]|0)+1;a[p+2|0]=(a[(b[r+10>>1]|0)+(189200+(T<<2))|0]|0)+1;a[p+3|0]=(a[(b[r+14>>1]|0)+(189200+(T<<2))|0]|0)+1;le[c[f+76>>2]&1023](D,W,Z,R,Q);C=1;break}else{cf[c[f+88>>2]&1023](D,W,Z,R);C=1;break}}}R=q;Z=p|0;D=J+z|0;T=d[1797040+D|0]|0;H=J+A|0;V=d[1732768+H|0]|0;do{if(!(D>>>0<68>>>0|H>>>0<68>>>0)){_=b[R>>1]|0;if(_<<16>>16<4){a[Z]=a[(_<<16>>16)+(189200+(D<<2))|0]|0;a[p+1|0]=a[(b[R+2>>1]|0)+(189200+(D<<2))|0]|0;a[p+2|0]=a[(b[R+4>>1]|0)+(189200+(D<<2))|0]|0;a[p+3|0]=a[(b[R+6>>1]|0)+(189200+(D<<2))|0]|0;le[c[f+52>>2]&1023](j,m,T,V,Z);break}else{cf[c[f+64>>2]&1023](j,m,T,V);break}}}while(0);V=j+(m<<3)|0;T=q+8|0;D=I+z|0;H=d[1797040+D|0]|0;J=I+A|0;W=d[1732768+J|0]|0;do{if(!(D>>>0<68>>>0|J>>>0<68>>>0)){Q=b[T>>1]|0;if(Q<<16>>16<4){a[Z]=a[(Q<<16>>16)+(189200+(D<<2))|0]|0;a[p+1|0]=a[(b[T+2>>1]|0)+(189200+(D<<2))|0]|0;a[p+2|0]=a[(b[T+4>>1]|0)+(189200+(D<<2))|0]|0;a[p+3|0]=a[(b[T+6>>1]|0)+(189200+(D<<2))|0]|0;le[c[f+52>>2]&1023](V,m,H,W,Z);break}else{cf[c[f+64>>2]&1023](V,m,H,W);break}}}while(0);if(!x){C=1;break}W=c[w>>2]|0;if((W|0)==3){H=G+z|0;V=d[1797040+H|0]|0;D=G+A|0;J=d[1732768+D|0]|0;do{if(!(H>>>0<68>>>0|D>>>0<68>>>0)){I=b[R>>1]|0;if(I<<16>>16<4){a[Z]=a[(I<<16>>16)+(189200+(H<<2))|0]|0;a[p+1|0]=a[(b[R+2>>1]|0)+(189200+(H<<2))|0]|0;a[p+2|0]=a[(b[R+4>>1]|0)+(189200+(H<<2))|0]|0;a[p+3|0]=a[(b[R+6>>1]|0)+(189200+(H<<2))|0]|0;le[c[f+52>>2]&1023](k,n,V,J,Z);break}else{cf[c[f+64>>2]&1023](k,n,V,J);break}}}while(0);J=n<<3;V=k+J|0;H=E+z|0;D=d[1797040+H|0]|0;I=E+A|0;Q=d[1732768+I|0]|0;do{if(!(H>>>0<68>>>0|I>>>0<68>>>0)){S=b[T>>1]|0;if(S<<16>>16<4){a[Z]=a[(S<<16>>16)+(189200+(H<<2))|0]|0;a[p+1|0]=a[(b[T+2>>1]|0)+(189200+(H<<2))|0]|0;a[p+2|0]=a[(b[T+4>>1]|0)+(189200+(H<<2))|0]|0;a[p+3|0]=a[(b[T+6>>1]|0)+(189200+(H<<2))|0]|0;le[c[f+52>>2]&1023](V,n,D,Q,Z);break}else{cf[c[f+64>>2]&1023](V,n,D,Q);break}}}while(0);Q=M+z|0;D=d[1797040+Q|0]|0;V=M+A|0;H=d[1732768+V|0]|0;do{if(!(Q>>>0<68>>>0|V>>>0<68>>>0)){I=b[R>>1]|0;if(I<<16>>16<4){a[Z]=a[(I<<16>>16)+(189200+(Q<<2))|0]|0;a[p+1|0]=a[(b[R+2>>1]|0)+(189200+(Q<<2))|0]|0;a[p+2|0]=a[(b[R+4>>1]|0)+(189200+(Q<<2))|0]|0;a[p+3|0]=a[(b[R+6>>1]|0)+(189200+(Q<<2))|0]|0;le[c[f+52>>2]&1023](l,n,D,H,Z);break}else{cf[c[f+64>>2]&1023](l,n,D,H);break}}}while(0);H=l+J|0;D=F+z|0;Q=d[1797040+D|0]|0;V=F+A|0;I=d[1732768+V|0]|0;if(D>>>0<68>>>0|V>>>0<68>>>0){C=1;break}V=b[T>>1]|0;if(V<<16>>16<4){a[Z]=a[(V<<16>>16)+(189200+(D<<2))|0]|0;a[p+1|0]=a[(b[T+2>>1]|0)+(189200+(D<<2))|0]|0;a[p+2|0]=a[(b[T+4>>1]|0)+(189200+(D<<2))|0]|0;a[p+3|0]=a[(b[T+6>>1]|0)+(189200+(D<<2))|0]|0;le[c[f+52>>2]&1023](H,n,Q,I,Z);C=1;break}else{cf[c[f+64>>2]&1023](H,n,Q,I);C=1;break}}I=(W|0)==2;Q=G+z|0;H=d[1797040+Q|0]|0;D=G+A|0;V=d[1732768+D|0]|0;do{if(!(Q>>>0<68>>>0|D>>>0<68>>>0)){S=b[R>>1]|0;if(S<<16>>16<4){a[Z]=(a[(S<<16>>16)+(189200+(Q<<2))|0]|0)+1;a[p+1|0]=(a[(b[R+2>>1]|0)+(189200+(Q<<2))|0]|0)+1;a[p+2|0]=(a[(b[R+4>>1]|0)+(189200+(Q<<2))|0]|0)+1;a[p+3|0]=(a[(b[R+6>>1]|0)+(189200+(Q<<2))|0]|0)+1;le[c[f+76>>2]&1023](k,n,H,V,Z);break}else{cf[c[f+88>>2]&1023](k,n,H,V);break}}}while(0);if(I){V=n<<3;H=k+V|0;Q=E+z|0;D=d[1797040+Q|0]|0;G=E+A|0;W=d[1732768+G|0]|0;do{if(!(Q>>>0<68>>>0|G>>>0<68>>>0)){J=b[T>>1]|0;if(J<<16>>16<4){a[Z]=(a[(J<<16>>16)+(189200+(Q<<2))|0]|0)+1;a[p+1|0]=(a[(b[T+2>>1]|0)+(189200+(Q<<2))|0]|0)+1;a[p+2|0]=(a[(b[T+4>>1]|0)+(189200+(Q<<2))|0]|0)+1;a[p+3|0]=(a[(b[T+6>>1]|0)+(189200+(Q<<2))|0]|0)+1;le[c[f+76>>2]&1023](H,n,D,W,Z);break}else{cf[c[f+88>>2]&1023](H,n,D,W);break}}}while(0);W=M+z|0;D=d[1797040+W|0]|0;H=M+A|0;Q=d[1732768+H|0]|0;do{if(!(W>>>0<68>>>0|H>>>0<68>>>0)){G=b[R>>1]|0;if(G<<16>>16<4){a[Z]=(a[(G<<16>>16)+(189200+(W<<2))|0]|0)+1;a[p+1|0]=(a[(b[R+2>>1]|0)+(189200+(W<<2))|0]|0)+1;a[p+2|0]=(a[(b[R+4>>1]|0)+(189200+(W<<2))|0]|0)+1;a[p+3|0]=(a[(b[R+6>>1]|0)+(189200+(W<<2))|0]|0)+1;le[c[f+76>>2]&1023](l,n,D,Q,Z);break}else{cf[c[f+88>>2]&1023](l,n,D,Q);break}}}while(0);Q=l+V|0;D=F+z|0;W=d[1797040+D|0]|0;H=F+A|0;G=d[1732768+H|0]|0;if(D>>>0<68>>>0|H>>>0<68>>>0){C=1;break}H=b[T>>1]|0;if(H<<16>>16<4){a[Z]=(a[(H<<16>>16)+(189200+(D<<2))|0]|0)+1;a[p+1|0]=(a[(b[T+2>>1]|0)+(189200+(D<<2))|0]|0)+1;a[p+2|0]=(a[(b[T+4>>1]|0)+(189200+(D<<2))|0]|0)+1;a[p+3|0]=(a[(b[T+6>>1]|0)+(189200+(D<<2))|0]|0)+1;le[c[f+76>>2]&1023](Q,n,W,G,Z);C=1;break}else{cf[c[f+88>>2]&1023](Q,n,W,G);C=1;break}}else{G=n<<2;W=k+G|0;Q=E+z|0;D=d[1797040+Q|0]|0;H=E+A|0;I=d[1732768+H|0]|0;do{if(!(Q>>>0<68>>>0|H>>>0<68>>>0)){J=b[T>>1]|0;if(J<<16>>16<4){a[Z]=(a[(J<<16>>16)+(189200+(Q<<2))|0]|0)+1;a[p+1|0]=(a[(b[T+2>>1]|0)+(189200+(Q<<2))|0]|0)+1;a[p+2|0]=(a[(b[T+4>>1]|0)+(189200+(Q<<2))|0]|0)+1;a[p+3|0]=(a[(b[T+6>>1]|0)+(189200+(Q<<2))|0]|0)+1;le[c[f+76>>2]&1023](W,n,D,I,Z);break}else{cf[c[f+88>>2]&1023](W,n,D,I);break}}}while(0);I=M+z|0;D=d[1797040+I|0]|0;W=M+A|0;Q=d[1732768+W|0]|0;do{if(!(I>>>0<68>>>0|W>>>0<68>>>0)){H=b[R>>1]|0;if(H<<16>>16<4){a[Z]=(a[(H<<16>>16)+(189200+(I<<2))|0]|0)+1;a[p+1|0]=(a[(b[R+2>>1]|0)+(189200+(I<<2))|0]|0)+1;a[p+2|0]=(a[(b[R+4>>1]|0)+(189200+(I<<2))|0]|0)+1;a[p+3|0]=(a[(b[R+6>>1]|0)+(189200+(I<<2))|0]|0)+1;le[c[f+76>>2]&1023](l,n,D,Q,Z);break}else{cf[c[f+88>>2]&1023](l,n,D,Q);break}}}while(0);Q=l+G|0;D=F+z|0;I=d[1797040+D|0]|0;R=F+A|0;W=d[1732768+R|0]|0;if(D>>>0<68>>>0|R>>>0<68>>>0){C=1;break}R=b[T>>1]|0;if(R<<16>>16<4){a[Z]=(a[(R<<16>>16)+(189200+(D<<2))|0]|0)+1;a[p+1|0]=(a[(b[T+2>>1]|0)+(189200+(D<<2))|0]|0)+1;a[p+2|0]=(a[(b[T+4>>1]|0)+(189200+(D<<2))|0]|0)+1;a[p+3|0]=(a[(b[T+6>>1]|0)+(189200+(D<<2))|0]|0)+1;le[c[f+76>>2]&1023](Q,n,I,W,Z);C=1;break}else{cf[c[f+88>>2]&1023](Q,n,I,W);C=1;break}}}}while(0);q=(c[w>>2]|0)==3;r=t-1|0;P=c[B>>2]|0;B=u>>>3&7;O=a[1060224+B|0]|0;W=O&255;if(O<<24>>24==3){aa=(c[f+426564>>2]&15|0)!=0?4:1}else{aa=4}O=u&40;do{if((P|0)!=0&(C|0)==0){I=P|u;do{if((I&7|0)==0){do{if((O|0)==0){ca=1;da=0}else{if((P&40|0)==0){ca=1;da=0;break}ca=0;da=($da(f,12,11,v)|0)&65535}}while(0);K=(a[f+5195|0]|a[f+5196|0])<<24>>24!=0;L=ca^1;if(K|L){ea=K?2:da}else{ea=($da(f,12,11,v)|0)&65535}K=(a[f+5203|0]|a[f+5204|0])<<24>>24!=0;if(K|L){fa=K?2:da}else{fa=($da(f,20,19,v)|0)&65535}K=(a[f+5211|0]|a[f+5212|0])<<24>>24!=0;if(K|L){ga=K?2:da}else{ga=($da(f,28,27,v)|0)&65535}if(!((a[f+5219|0]|a[f+5220|0])<<24>>24==0)){ha=ea;ia=fa;ja=ga;ka=2;break}if(!ca){ha=ea;ia=fa;ja=ga;ka=da;break}ha=ea;ia=fa;ja=ga;ka=($da(f,36,35,v)|0)&65535}else{if((I&128|0)!=0&(c[y>>2]|0)==0){if((c[f+177100>>2]|0)==3){ha=3;ia=3;ja=3;ka=3;break}}ha=4;ia=4;ja=4;ka=4}}while(0);I=ha<<16>>16;Z=ia<<16>>16;T=ja<<16>>16;F=ka<<16>>16;if((Z+T+I|0)==(-F|0)){break}G=c[f+4040>>2]|0;K=a[G+r|0]|0;L=(a[G+t|0]|0)+1+K>>1;G=(c[f+4756>>2]|0)+1+(d[f+7876+K|0]|0)>>1;Q=(c[f+4760>>2]|0)+1+(d[f+7964+K|0]|0)>>1;K=p|0;D=L+z|0;R=d[1797040+D|0]|0;M=L+A|0;L=d[1732768+M|0]|0;do{if(!(D>>>0<68>>>0|M>>>0<68>>>0)){if(ha<<16>>16<4){a[K]=a[189200+(D<<2)+I|0]|0;a[p+1|0]=a[189200+(D<<2)+Z|0]|0;a[p+2|0]=a[189200+(D<<2)+T|0]|0;a[p+3|0]=a[189200+(D<<2)+F|0]|0;le[c[f+48>>2]&1023](j,m,R,L,K);break}else{cf[c[f+60>>2]&1023](j,m,R,L);break}}}while(0);if(!x){break}L=G+z|0;R=d[1797040+L|0]|0;D=G+A|0;M=d[1732768+D|0]|0;H=L>>>0<68>>>0|D>>>0<68>>>0;if(q){do{if(!H){if(ha<<16>>16<4){a[K]=a[189200+(L<<2)+I|0]|0;a[p+1|0]=a[189200+(L<<2)+Z|0]|0;a[p+2|0]=a[189200+(L<<2)+T|0]|0;a[p+3|0]=a[189200+(L<<2)+F|0]|0;le[c[f+48>>2]&1023](k,n,R,M,K);break}else{cf[c[f+60>>2]&1023](k,n,R,M);break}}}while(0);G=Q+z|0;D=d[1797040+G|0]|0;E=Q+A|0;V=d[1732768+E|0]|0;if(G>>>0<68>>>0|E>>>0<68>>>0){break}if(ha<<16>>16<4){a[K]=a[189200+(G<<2)+I|0]|0;a[p+1|0]=a[189200+(G<<2)+Z|0]|0;a[p+2|0]=a[189200+(G<<2)+T|0]|0;a[p+3|0]=a[189200+(G<<2)+F|0]|0;le[c[f+48>>2]&1023](l,n,D,V,K);break}else{cf[c[f+60>>2]&1023](l,n,D,V);break}}else{do{if(!H){if(ha<<16>>16<4){a[K]=(a[189200+(L<<2)+I|0]|0)+1;a[p+1|0]=(a[189200+(L<<2)+Z|0]|0)+1;a[p+2|0]=(a[189200+(L<<2)+T|0]|0)+1;a[p+3|0]=(a[189200+(L<<2)+F|0]|0)+1;le[c[f+72>>2]&1023](k,n,R,M,K);break}else{cf[c[f+84>>2]&1023](k,n,R,M);break}}}while(0);M=Q+z|0;R=d[1797040+M|0]|0;L=Q+A|0;H=d[1732768+L|0]|0;if(M>>>0<68>>>0|L>>>0<68>>>0){break}if(ha<<16>>16<4){a[K]=(a[189200+(M<<2)+I|0]|0)+1;a[p+1|0]=(a[189200+(M<<2)+Z|0]|0)+1;a[p+2|0]=(a[189200+(M<<2)+T|0]|0)+1;a[p+3|0]=(a[189200+(M<<2)+F|0]|0)+1;le[c[f+72>>2]&1023](l,n,R,H,K);break}else{cf[c[f+84>>2]&1023](l,n,R,H);break}}}}while(0);if(aa>>>0>1>>>0){ha=u&16777216;r=(u&7|0)==0;ka=(O|0)==0;O=f+4040|0;ja=f+4752|0;ia=p|0;ga=f+4756|0;fa=f+4760|0;ea=p+1|0;da=p+2|0;ca=p+3|0;P=f+48|0;C=f+72|0;H=1;R=0;M=0;L=0;V=0;D=0;G=0;E=0;J=0;S=0;_=0;X=0;Y=0;while(1){do{if((ha&H<<24|0)==0){if(r){do{if((H&W|0)==0){if(ka){la=1;ma=R;na=M;oa=L;pa=V;qa=D;ra=G;sa=E;ta=J;ua=S;va=_;wa=X;xa=Y;break}U=($da(f,H+12|0,H+11|0,v)|0)&65535;la=0;ma=U;na=U;oa=U;pa=U;qa=U;ra=U;sa=U;ta=U;ua=U;va=U;wa=U;xa=U}else{la=0;ma=0;na=0;oa=0;pa=0;qa=0;ra=0;sa=0;ta=0;ua=0;va=0;wa=0;xa=0}}while(0);U=H+12|0;$=H+11|0;ya=(a[f+5184+$|0]|a[f+5184+U|0])<<24>>24==0;do{if(la){if(ya){za=($da(f,U,$,v)|0)&65535}else{za=2}Aa=H+20|0;Ba=H+19|0;if((a[f+5184+Ba|0]|a[f+5184+Aa|0])<<24>>24==0){Ca=($da(f,Aa,Ba,v)|0)&65535}else{Ca=2}Ba=H+28|0;Aa=H+27|0;if((a[f+5184+Aa|0]|a[f+5184+Ba|0])<<24>>24==0){Da=($da(f,Ba,Aa,v)|0)&65535}else{Da=2}Aa=H+36|0;Ba=H+35|0;if(!((a[f+5184+Ba|0]|a[f+5184+Aa|0])<<24>>24==0)){Ea=za;Fa=Ca;Ga=Da;Ha=2;Ia=za;Ja=Ca;Ka=Da;La=2;Ma=za;Na=Ca;Oa=Da;Pa=2;break}Qa=($da(f,Aa,Ba,v)|0)&65535;Ea=za;Fa=Ca;Ga=Da;Ha=Qa;Ia=za;Ja=Ca;Ka=Da;La=Qa;Ma=za;Na=Ca;Oa=Da;Pa=Qa}else{Qa=(a[H+19+(f+5184)|0]|a[H+20+(f+5184)|0])<<24>>24==0;Ba=(a[H+27+(f+5184)|0]|a[H+28+(f+5184)|0])<<24>>24==0;Aa=(a[H+35+(f+5184)|0]|a[H+36+(f+5184)|0])<<24>>24==0;Ea=ya?ma:2;Fa=Qa?na:2;Ga=Ba?oa:2;Ha=Aa?pa:2;Ia=ya?qa:2;Ja=Qa?ra:2;Ka=Ba?sa:2;La=Aa?ta:2;Ma=ya?ua:2;Na=Qa?va:2;Oa=Ba?wa:2;Pa=Aa?xa:2}}while(0);if(((Fa<<16>>16)+(Ga<<16>>16)+(Ea<<16>>16)|0)==(-(Ha<<16>>16)|0)){Ra=Ea;Sa=Fa;Ta=Ga;Ua=Ha;Va=Ia;Wa=Ja;Xa=Ka;Ya=La;Za=Ma;_a=Na;$a=Oa;ab=Pa;break}else{bb=Ea;cb=Fa;db=Ga;eb=Ha;fb=Ia;gb=Ja;hb=Ka;ib=La;jb=Ma;kb=Na;lb=Oa;mb=Pa}}else{bb=3;cb=3;db=3;eb=3;fb=3;gb=3;hb=3;ib=3;jb=3;kb=3;lb=3;mb=3}ya=a[(c[O>>2]|0)+t|0]|0;$=H<<2;U=ya+z|0;Aa=ya+A|0;if(U>>>0<68>>>0|Aa>>>0<68>>>0){nb=bb;ob=cb;pb=db;qb=eb;rb=fb;sb=gb;tb=hb;ub=ib}else{ya=d[1732768+Aa|0]|0;Aa=d[1797040+U|0]|0;Ba=j+($<<c[ja>>2])|0;a[ia]=a[(jb<<16>>16)+(189200+(U<<2))|0]|0;a[ea]=a[(kb<<16>>16)+(189200+(U<<2))|0]|0;a[da]=a[(lb<<16>>16)+(189200+(U<<2))|0]|0;a[ca]=a[(mb<<16>>16)+(189200+(U<<2))|0]|0;le[c[P>>2]&1023](Ba,m,Aa,ya,ia);nb=jb;ob=kb;pb=lb;qb=mb;rb=jb;sb=kb;tb=lb;ub=mb}if(!x){Ra=nb;Sa=ob;Ta=pb;Ua=qb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}if(q){ya=c[ja>>2]|0;Aa=c[ga>>2]|0;Ba=Aa+z|0;U=Aa+A|0;if(Ba>>>0<68>>>0|U>>>0<68>>>0){vb=ya}else{Aa=d[1732768+U|0]|0;U=d[1797040+Ba|0]|0;a[ia]=a[(nb<<16>>16)+(189200+(Ba<<2))|0]|0;a[ea]=a[(ob<<16>>16)+(189200+(Ba<<2))|0]|0;a[da]=a[(pb<<16>>16)+(189200+(Ba<<2))|0]|0;a[ca]=a[(qb<<16>>16)+(189200+(Ba<<2))|0]|0;le[c[P>>2]&1023](k+($<<ya)|0,n,U,Aa,ia);vb=c[ja>>2]|0}Aa=c[fa>>2]|0;U=Aa+z|0;ya=Aa+A|0;if(U>>>0<68>>>0|ya>>>0<68>>>0){Ra=nb;Sa=ob;Ta=pb;Ua=qb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}Aa=d[1732768+ya|0]|0;ya=d[1797040+U|0]|0;a[ia]=a[(nb<<16>>16)+(189200+(U<<2))|0]|0;a[ea]=a[(ob<<16>>16)+(189200+(U<<2))|0]|0;a[da]=a[(pb<<16>>16)+(189200+(U<<2))|0]|0;a[ca]=a[(qb<<16>>16)+(189200+(U<<2))|0]|0;le[c[P>>2]&1023](l+($<<vb)|0,n,ya,Aa,ia);Ra=nb;Sa=ob;Ta=pb;Ua=qb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}if((H&1|0)!=0){Ra=nb;Sa=ob;Ta=pb;Ua=qb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}Aa=H<<1;ya=c[ja>>2]|0;$=c[ga>>2]|0;U=$+z|0;Ba=$+A|0;if(U>>>0<68>>>0|Ba>>>0<68>>>0){wb=nb;xb=ob;yb=pb;zb=qb;Ab=ya}else{$=d[1732768+Ba|0]|0;Ba=d[1797040+U|0]|0;a[ia]=(a[(rb<<16>>16)+(189200+(U<<2))|0]|0)+1;a[ea]=(a[(sb<<16>>16)+(189200+(U<<2))|0]|0)+1;a[da]=(a[(tb<<16>>16)+(189200+(U<<2))|0]|0)+1;a[ca]=(a[(ub<<16>>16)+(189200+(U<<2))|0]|0)+1;le[c[C>>2]&1023](k+(Aa<<ya)|0,n,Ba,$,ia);wb=rb;xb=sb;yb=tb;zb=ub;Ab=c[ja>>2]|0}$=c[fa>>2]|0;Ba=$+z|0;ya=$+A|0;if(Ba>>>0<68>>>0|ya>>>0<68>>>0){Ra=wb;Sa=xb;Ta=yb;Ua=zb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}$=d[1732768+ya|0]|0;ya=d[1797040+Ba|0]|0;a[ia]=(a[(rb<<16>>16)+(189200+(Ba<<2))|0]|0)+1;a[ea]=(a[(sb<<16>>16)+(189200+(Ba<<2))|0]|0)+1;a[da]=(a[(tb<<16>>16)+(189200+(Ba<<2))|0]|0)+1;a[ca]=(a[(ub<<16>>16)+(189200+(Ba<<2))|0]|0)+1;le[c[C>>2]&1023](l+(Aa<<Ab)|0,n,ya,$,ia);Ra=rb;Sa=sb;Ta=tb;Ua=ub;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb}else{Ra=R;Sa=M;Ta=L;Ua=V;Va=D;Wa=G;Xa=E;Ya=J;Za=S;_a=_;$a=X;ab=Y}}while(0);K=H+1|0;if((K|0)<(aa|0)){H=K;R=Ra;M=Sa;L=Ta;V=Ua;D=Va;G=Wa;E=Xa;J=Ya;S=Za;_=_a;X=$a;Y=ab}else{break}}}ab=c[w>>2]|0;w=(ab|0)==3;Y=(ab|0)==2;ab=c[f+4844>>2]|0;$a=c[f+4864>>2]|0;X=a[1060232+B|0]|0;B=X&255;if(X<<24>>24==3){Bb=(c[f+426564>>2]&15|0)!=0?4:1}else{Bb=4}X=u&24;a:do{if(($a|0)!=0){_a=(c[y>>2]|0)==0;do{if(!_a){if((h&1|0)!=0){break}if(($a&(u&128^128)|0)==0){break}_=m<<1;Za=n<<1;S=f+7332|0;Ya=f+426560|0;J=f+5196|0;Xa=f+5197|0;E=f+5199|0;Wa=f+5198|0;G=f+5304|0;Va=f+4040|0;D=p|0;Ua=f+4756|0;V=f+4760|0;Ta=p+1|0;L=p+2|0;Sa=p+3|0;M=f+44|0;Ra=f+68|0;R=0;H=t-(c[s>>2]<<1)|0;while(1){aa=c[(c[g>>2]|0)+(H<<2)>>2]|0;b:do{if(((aa|u)&7|0)==0){do{if((c[S>>2]|0)==0){if((aa&16777216|0)==0){break}mb=b[(c[Ya>>2]|0)+(H<<1)>>1]|0;if((mb&16384)==0){Cb=(a[Xa]|0)!=0?2:1;Db=(a[J]|0)!=0?2:1}else{Cb=2;Db=2}if(mb<<16>>16<0){Eb=Db;Fb=Cb;Gb=2;Hb=2;break b}Eb=Db;Fb=Cb;Gb=(a[Wa]|0)!=0?2:1;Hb=(a[E]|0)!=0?2:1;break b}}while(0);mb=c[G>>2]|0;Eb=(a[mb+(H*48|0)+12|0]|a[J])<<24>>24!=0?2:1;Fb=(a[mb+(H*48|0)+13|0]|a[Xa])<<24>>24!=0?2:1;Gb=(a[mb+(H*48|0)+14|0]|a[Wa])<<24>>24!=0?2:1;Hb=(a[mb+(H*48|0)+15|0]|a[E])<<24>>24!=0?2:1}else{Eb=3;Fb=3;Gb=3;Hb=3}}while(0);aa=c[Va>>2]|0;mb=(a[aa+t|0]|0)+1+(a[aa+H|0]|0)>>1;lb=mb+z|0;kb=mb+A|0;if(lb>>>0<68>>>0|kb>>>0<68>>>0){Ib=aa}else{aa=d[1732768+kb|0]|0;kb=d[1797040+lb|0]|0;mb=j+(ba(R,m)|0)|0;a[D]=a[(Eb<<16>>16)+(189200+(lb<<2))|0]|0;a[Ta]=a[(Fb<<16>>16)+(189200+(lb<<2))|0]|0;a[L]=a[(Gb&65535)+(189200+(lb<<2))|0]|0;a[Sa]=a[(Hb&65535)+(189200+(lb<<2))|0]|0;le[c[M>>2]&1023](mb,_,kb,aa,D);Ib=c[Va>>2]|0}aa=a[Ib+H|0]|0;kb=(c[Ua>>2]|0)+1+(d[f+7876+aa|0]|0)>>1;mb=(c[V>>2]|0)+1+(d[f+7964+aa|0]|0)>>1;do{if(x){aa=ba(R,n)|0;lb=k+aa|0;jb=kb+z|0;ub=d[1797040+jb|0]|0;tb=kb+A|0;sb=d[1732768+tb|0]|0;rb=jb>>>0<68>>>0|tb>>>0<68>>>0;if(w){if(!rb){a[D]=a[(Eb<<16>>16)+(189200+(jb<<2))|0]|0;a[Ta]=a[(Fb<<16>>16)+(189200+(jb<<2))|0]|0;a[L]=a[(Gb&65535)+(189200+(jb<<2))|0]|0;a[Sa]=a[(Hb&65535)+(189200+(jb<<2))|0]|0;le[c[M>>2]&1023](lb,Za,ub,sb,D)}tb=mb+z|0;ia=mb+A|0;if(tb>>>0<68>>>0|ia>>>0<68>>>0){break}Ab=d[1732768+ia|0]|0;ia=d[1797040+tb|0]|0;a[D]=a[(Eb<<16>>16)+(189200+(tb<<2))|0]|0;a[Ta]=a[(Fb<<16>>16)+(189200+(tb<<2))|0]|0;a[L]=a[(Gb&65535)+(189200+(tb<<2))|0]|0;a[Sa]=a[(Hb&65535)+(189200+(tb<<2))|0]|0;le[c[M>>2]&1023](l+aa|0,Za,ia,Ab,D);break}else{if(!rb){a[D]=(a[(Eb<<16>>16)+(189200+(jb<<2))|0]|0)+1;a[Ta]=(a[(Fb<<16>>16)+(189200+(jb<<2))|0]|0)+1;a[L]=(a[(Gb&65535)+(189200+(jb<<2))|0]|0)+1;a[Sa]=(a[(Hb&65535)+(189200+(jb<<2))|0]|0)+1;le[c[Ra>>2]&1023](lb,Za,ub,sb,D)}sb=mb+z|0;ub=mb+A|0;if(sb>>>0<68>>>0|ub>>>0<68>>>0){break}lb=d[1732768+ub|0]|0;ub=d[1797040+sb|0]|0;a[D]=(a[(Eb<<16>>16)+(189200+(sb<<2))|0]|0)+1;a[Ta]=(a[(Fb<<16>>16)+(189200+(sb<<2))|0]|0)+1;a[L]=(a[(Gb&65535)+(189200+(sb<<2))|0]|0)+1;a[Sa]=(a[(Hb&65535)+(189200+(sb<<2))|0]|0)+1;le[c[Ra>>2]&1023](l+aa|0,Za,ub,lb,D);break}}}while(0);mb=R+1|0;if((mb|0)>=2){break a}R=mb;H=(c[s>>2]|0)+H|0}}}while(0);H=$a|u;do{if((H&7|0)==0){if(_a){N=219}else{if((($a^u)&128|0)==0){N=219}else{Jb=0;Kb=1}}do{if((N|0)==219){if((X|0)==0){Jb=1;Kb=0;break}if(($a&24|0)==0){Jb=1;Kb=0;break}Jb=0;Kb=($da(f,12,4,v)|0)&65535}}while(0);R=(a[f+5188|0]|a[f+5196|0])<<24>>24!=0;D=Jb^1;if(R|D){Lb=R?2:Kb}else{Lb=($da(f,12,4,v)|0)&65535}R=(a[f+5189|0]|a[f+5197|0])<<24>>24!=0;if(R|D){Mb=R?2:Kb}else{Mb=($da(f,13,5,v)|0)&65535}R=(a[f+5190|0]|a[f+5198|0])<<24>>24!=0;if(R|D){Nb=R?2:Kb}else{Nb=($da(f,14,6,v)|0)&65535}if(!((a[f+5191|0]|a[f+5199|0])<<24>>24==0)){Ob=Lb;Pb=Mb;Qb=Nb;Rb=2;break}if(!Jb){Ob=Lb;Pb=Mb;Qb=Nb;Rb=Kb;break}Ob=Lb;Pb=Mb;Qb=Nb;Rb=($da(f,15,7,v)|0)&65535}else{R=(H&128|0)==0?4:3;Ob=R;Pb=R;Qb=R;Rb=R}}while(0);H=Ob<<16>>16;_a=Pb<<16>>16;R=Qb<<16>>16;D=Rb<<16>>16;if((_a+R+H|0)==(-D|0)){break}Za=c[f+4040>>2]|0;Ra=a[Za+ab|0]|0;Sa=(a[Za+t|0]|0)+1+Ra>>1;Za=(c[f+4756>>2]|0)+1+(d[f+7876+Ra|0]|0)>>1;L=(c[f+4760>>2]|0)+1+(d[f+7964+Ra|0]|0)>>1;Ra=p|0;Ta=Sa+z|0;M=d[1797040+Ta|0]|0;V=Sa+A|0;Sa=d[1732768+V|0]|0;do{if(!(Ta>>>0<68>>>0|V>>>0<68>>>0)){if(Ob<<16>>16<4){a[Ra]=a[189200+(Ta<<2)+H|0]|0;a[p+1|0]=a[189200+(Ta<<2)+_a|0]|0;a[p+2|0]=a[189200+(Ta<<2)+R|0]|0;a[p+3|0]=a[189200+(Ta<<2)+D|0]|0;le[c[f+44>>2]&1023](j,m,M,Sa,Ra);break}else{cf[c[f+56>>2]&1023](j,m,M,Sa);break}}}while(0);if(!x){break}Sa=Za+z|0;M=d[1797040+Sa|0]|0;Ta=Za+A|0;V=d[1732768+Ta|0]|0;Ua=Sa>>>0<68>>>0|Ta>>>0<68>>>0;if(w){do{if(!Ua){if(Ob<<16>>16<4){a[Ra]=a[189200+(Sa<<2)+H|0]|0;a[p+1|0]=a[189200+(Sa<<2)+_a|0]|0;a[p+2|0]=a[189200+(Sa<<2)+R|0]|0;a[p+3|0]=a[189200+(Sa<<2)+D|0]|0;le[c[f+44>>2]&1023](k,n,M,V,Ra);break}else{cf[c[f+56>>2]&1023](k,n,M,V);break}}}while(0);Za=L+z|0;Ta=d[1797040+Za|0]|0;Va=L+A|0;_=d[1732768+Va|0]|0;if(Za>>>0<68>>>0|Va>>>0<68>>>0){break}if(Ob<<16>>16<4){a[Ra]=a[189200+(Za<<2)+H|0]|0;a[p+1|0]=a[189200+(Za<<2)+_a|0]|0;a[p+2|0]=a[189200+(Za<<2)+R|0]|0;a[p+3|0]=a[189200+(Za<<2)+D|0]|0;le[c[f+44>>2]&1023](l,n,Ta,_,Ra);break}else{cf[c[f+56>>2]&1023](l,n,Ta,_);break}}else{do{if(!Ua){if(Ob<<16>>16<4){a[Ra]=(a[189200+(Sa<<2)+H|0]|0)+1;a[p+1|0]=(a[189200+(Sa<<2)+_a|0]|0)+1;a[p+2|0]=(a[189200+(Sa<<2)+R|0]|0)+1;a[p+3|0]=(a[189200+(Sa<<2)+D|0]|0)+1;le[c[f+68>>2]&1023](k,n,M,V,Ra);break}else{cf[c[f+80>>2]&1023](k,n,M,V);break}}}while(0);V=L+z|0;M=d[1797040+V|0]|0;Sa=L+A|0;Ua=d[1732768+Sa|0]|0;if(V>>>0<68>>>0|Sa>>>0<68>>>0){break}if(Ob<<16>>16<4){a[Ra]=(a[189200+(V<<2)+H|0]|0)+1;a[p+1|0]=(a[189200+(V<<2)+_a|0]|0)+1;a[p+2|0]=(a[189200+(V<<2)+R|0]|0)+1;a[p+3|0]=(a[189200+(V<<2)+D|0]|0)+1;le[c[f+68>>2]&1023](l,n,M,Ua,Ra);break}else{cf[c[f+80>>2]&1023](l,n,M,Ua);break}}}}while(0);if(!(Bb>>>0>1>>>0)){i=o;return}Ob=u&16777216;ab=(u&7|0)==0;u=(X|0)==0;X=f+4040|0;Rb=p|0;Qb=f+4756|0;Pb=f+4760|0;Nb=p+1|0;Mb=p+2|0;Lb=p+3|0;p=m<<2;Kb=f+44|0;Jb=f+68|0;$a=1;N=0;s=0;Hb=0;Gb=0;Fb=0;Eb=0;Ib=0;Cb=0;Db=0;g=0;h=0;y=0;Ua=0;M=0;V=0;Sa=0;_=0;Ta=0;Za=0;Va=0;while(1){E=(Ob&$a<<24|0)==0;do{if(E|Y){if(ab){do{if(($a&B|0)==0){if(u){Sb=1;Tb=N;Ub=s;Vb=Hb;Wb=Gb;Xb=Fb;Yb=Eb;Zb=Ib;_b=Cb;$b=Db;ac=g;bc=h;cc=y;dc=Ua;ec=M;fc=V;gc=Sa;hc=_;ic=Ta;jc=Za;kc=Va;break}Wa=$a<<3;Xa=($da(f,Wa+12|0,Wa|4,v)|0)&65535;Sb=0;Tb=Xa;Ub=Xa;Vb=Xa;Wb=Xa;Xb=Xa;Yb=Xa;Zb=Xa;_b=Xa;$b=Xa;ac=Xa;bc=Xa;cc=Xa;dc=Xa;ec=Xa;fc=Xa;gc=Xa;hc=Xa;ic=Xa;jc=Xa;kc=Xa}else{Sb=0;Tb=0;Ub=0;Vb=0;Wb=0;Xb=0;Yb=0;Zb=0;_b=0;$b=0;ac=0;bc=0;cc=0;dc=0;ec=0;fc=0;gc=0;hc=0;ic=0;jc=0;kc=0}}while(0);Xa=$a<<3;Wa=Xa+12|0;J=Xa|4;G=(a[f+5184+J|0]|a[f+5184+Wa|0])<<24>>24==0;do{if(Sb){if(G){lc=($da(f,Wa,J,v)|0)&65535}else{lc=2}Ya=Xa+13|0;S=Xa|5;if((a[f+5184+S|0]|a[f+5184+Ya|0])<<24>>24==0){mc=($da(f,Ya,S,v)|0)&65535}else{mc=2}S=Xa+14|0;Ya=Xa|6;if((a[f+5184+Ya|0]|a[f+5184+S|0])<<24>>24==0){nc=($da(f,S,Ya,v)|0)&65535}else{nc=2}Ya=Xa+15|0;S=Xa|7;if(!((a[f+5184+S|0]|a[f+5184+Ya|0])<<24>>24==0)){oc=lc;pc=mc;qc=nc;rc=2;sc=lc;tc=mc;uc=nc;vc=2;wc=lc;xc=mc;yc=nc;zc=2;Ac=lc;Bc=mc;Cc=nc;Dc=2;Ec=lc;Fc=mc;Gc=nc;Hc=2;break}mb=($da(f,Ya,S,v)|0)&65535;oc=lc;pc=mc;qc=nc;rc=mb;sc=lc;tc=mc;uc=nc;vc=mb;wc=lc;xc=mc;yc=nc;zc=mb;Ac=lc;Bc=mc;Cc=nc;Dc=mb;Ec=lc;Fc=mc;Gc=nc;Hc=mb}else{mb=(a[(Xa|5)+(f+5184)|0]|a[Xa+13+(f+5184)|0])<<24>>24==0;S=(a[(Xa|6)+(f+5184)|0]|a[Xa+14+(f+5184)|0])<<24>>24==0;Ya=(a[(Xa|7)+(f+5184)|0]|a[Xa+15+(f+5184)|0])<<24>>24==0;oc=G?Tb:2;pc=mb?Ub:2;qc=S?Vb:2;rc=Ya?Wb:2;sc=G?Xb:2;tc=mb?Yb:2;uc=S?Zb:2;vc=Ya?_b:2;wc=G?$b:2;xc=mb?ac:2;yc=S?bc:2;zc=Ya?cc:2;Ac=G?dc:2;Bc=mb?ec:2;Cc=S?fc:2;Dc=Ya?gc:2;Ec=G?hc:2;Fc=mb?ic:2;Gc=S?jc:2;Hc=Ya?kc:2}}while(0);if(((pc<<16>>16)+(qc<<16>>16)+(oc<<16>>16)|0)==(-(rc<<16>>16)|0)){Ic=oc;Jc=pc;Kc=qc;Lc=rc;Mc=sc;Nc=tc;Oc=uc;Pc=vc;Qc=wc;Rc=xc;Sc=yc;Tc=zc;Uc=Ac;Vc=Bc;Wc=Cc;Xc=Dc;Yc=Ec;Zc=Fc;_c=Gc;$c=Hc;break}else{ad=oc;bd=pc;cd=qc;dd=rc;ed=sc;fd=tc;gd=uc;hd=vc;id=wc;jd=xc;kd=yc;ld=zc;md=Ac;nd=Bc;od=Cc;pd=Dc;qd=Ec;rd=Fc;sd=Gc;td=Hc}}else{ad=3;bd=3;cd=3;dd=3;ed=3;fd=3;gd=3;hd=3;id=3;jd=3;kd=3;ld=3;md=3;nd=3;od=3;pd=3;qd=3;rd=3;sd=3;td=3}G=a[(c[X>>2]|0)+t|0]|0;if(Y){do{if(E){Xa=G+z|0;J=G+A|0;if(Xa>>>0<68>>>0|J>>>0<68>>>0){ud=ad;vd=bd;wd=cd;xd=dd;break}Wa=d[1732768+J|0]|0;J=d[1797040+Xa|0]|0;Ya=j+(ba(p,$a)|0)|0;a[Rb]=a[(ed<<16>>16)+(189200+(Xa<<2))|0]|0;a[Nb]=a[(fd<<16>>16)+(189200+(Xa<<2))|0]|0;a[Mb]=a[(gd<<16>>16)+(189200+(Xa<<2))|0]|0;a[Lb]=a[(hd<<16>>16)+(189200+(Xa<<2))|0]|0;le[c[Kb>>2]&1023](Ya,m,J,Wa,Rb);ud=ed;vd=fd;wd=gd;xd=hd}else{ud=ad;vd=bd;wd=cd;xd=dd}}while(0);if(!x){Ic=ud;Jc=vd;Kc=wd;Lc=xd;Mc=ed;Nc=fd;Oc=gd;Pc=hd;Qc=id;Rc=jd;Sc=kd;Tc=ld;Uc=md;Vc=nd;Wc=od;Xc=pd;Yc=qd;Zc=rd;_c=sd;$c=td;break}Wa=ba($a<<2,n)|0;J=c[Qb>>2]|0;Ya=J+z|0;Xa=J+A|0;if(Ya>>>0<68>>>0|Xa>>>0<68>>>0){yd=ud;zd=vd;Ad=wd;Bd=xd}else{J=d[1732768+Xa|0]|0;Xa=d[1797040+Ya|0]|0;a[Rb]=(a[(ed<<16>>16)+(189200+(Ya<<2))|0]|0)+1;a[Nb]=(a[(fd<<16>>16)+(189200+(Ya<<2))|0]|0)+1;a[Mb]=(a[(gd<<16>>16)+(189200+(Ya<<2))|0]|0)+1;a[Lb]=(a[(hd<<16>>16)+(189200+(Ya<<2))|0]|0)+1;le[c[Jb>>2]&1023](k+Wa|0,n,Xa,J,Rb);yd=ed;zd=fd;Ad=gd;Bd=hd}J=c[Pb>>2]|0;Xa=J+z|0;Ya=J+A|0;if(Xa>>>0<68>>>0|Ya>>>0<68>>>0){Ic=yd;Jc=zd;Kc=Ad;Lc=Bd;Mc=ed;Nc=fd;Oc=gd;Pc=hd;Qc=id;Rc=jd;Sc=kd;Tc=ld;Uc=md;Vc=nd;Wc=od;Xc=pd;Yc=qd;Zc=rd;_c=sd;$c=td;break}J=d[1732768+Ya|0]|0;Ya=d[1797040+Xa|0]|0;a[Rb]=(a[(ed<<16>>16)+(189200+(Xa<<2))|0]|0)+1;a[Nb]=(a[(fd<<16>>16)+(189200+(Xa<<2))|0]|0)+1;a[Mb]=(a[(gd<<16>>16)+(189200+(Xa<<2))|0]|0)+1;a[Lb]=(a[(hd<<16>>16)+(189200+(Xa<<2))|0]|0)+1;le[c[Jb>>2]&1023](l+Wa|0,n,Ya,J,Rb);Ic=ed;Jc=fd;Kc=gd;Lc=hd;Mc=ed;Nc=fd;Oc=gd;Pc=hd;Qc=id;Rc=jd;Sc=kd;Tc=ld;Uc=md;Vc=nd;Wc=od;Xc=pd;Yc=qd;Zc=rd;_c=sd;$c=td;break}J=$a<<2;Ya=G+z|0;Wa=G+A|0;if(Ya>>>0<68>>>0|Wa>>>0<68>>>0){Cd=ad;Dd=bd;Ed=cd;Fd=dd;Gd=ed;Hd=fd;Id=gd;Jd=hd;Kd=id;Ld=jd;Md=kd;Nd=ld;Od=md;Pd=nd;Qd=od;Rd=pd}else{Xa=d[1732768+Wa|0]|0;Wa=d[1797040+Ya|0]|0;S=j+(ba(J,m)|0)|0;a[Rb]=a[(qd<<16>>16)+(189200+(Ya<<2))|0]|0;a[Nb]=a[(rd<<16>>16)+(189200+(Ya<<2))|0]|0;a[Mb]=a[(sd<<16>>16)+(189200+(Ya<<2))|0]|0;a[Lb]=a[(td<<16>>16)+(189200+(Ya<<2))|0]|0;le[c[Kb>>2]&1023](S,m,Wa,Xa,Rb);Cd=qd;Dd=rd;Ed=sd;Fd=td;Gd=qd;Hd=rd;Id=sd;Jd=td;Kd=qd;Ld=rd;Md=sd;Nd=td;Od=qd;Pd=rd;Qd=sd;Rd=td}if(!x){Ic=Cd;Jc=Dd;Kc=Ed;Lc=Fd;Mc=Gd;Nc=Hd;Oc=Id;Pc=Jd;Qc=Kd;Rc=Ld;Sc=Md;Tc=Nd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}if(w){Xa=ba(J,n)|0;J=c[Qb>>2]|0;Wa=J+z|0;S=J+A|0;if(Wa>>>0<68>>>0|S>>>0<68>>>0){Sd=Cd;Td=Dd;Ud=Ed;Vd=Fd;Wd=Gd;Xd=Hd;Yd=Id;Zd=Jd}else{J=d[1732768+S|0]|0;S=d[1797040+Wa|0]|0;a[Rb]=a[(Kd<<16>>16)+(189200+(Wa<<2))|0]|0;a[Nb]=a[(Ld<<16>>16)+(189200+(Wa<<2))|0]|0;a[Mb]=a[(Md<<16>>16)+(189200+(Wa<<2))|0]|0;a[Lb]=a[(Nd<<16>>16)+(189200+(Wa<<2))|0]|0;le[c[Kb>>2]&1023](k+Xa|0,n,S,J,Rb);Sd=Kd;Td=Ld;Ud=Md;Vd=Nd;Wd=Kd;Xd=Ld;Yd=Md;Zd=Nd}J=c[Pb>>2]|0;S=J+z|0;Wa=J+A|0;if(S>>>0<68>>>0|Wa>>>0<68>>>0){Ic=Sd;Jc=Td;Kc=Ud;Lc=Vd;Mc=Wd;Nc=Xd;Oc=Yd;Pc=Zd;Qc=Kd;Rc=Ld;Sc=Md;Tc=Nd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}J=d[1732768+Wa|0]|0;Wa=d[1797040+S|0]|0;a[Rb]=a[(Kd<<16>>16)+(189200+(S<<2))|0]|0;a[Nb]=a[(Ld<<16>>16)+(189200+(S<<2))|0]|0;a[Mb]=a[(Md<<16>>16)+(189200+(S<<2))|0]|0;a[Lb]=a[(Nd<<16>>16)+(189200+(S<<2))|0]|0;le[c[Kb>>2]&1023](l+Xa|0,n,Wa,J,Rb);Ic=Kd;Jc=Ld;Kc=Md;Lc=Nd;Mc=Kd;Nc=Ld;Oc=Md;Pc=Nd;Qc=Kd;Rc=Ld;Sc=Md;Tc=Nd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}if(($a&1|0)!=0){Ic=Cd;Jc=Dd;Kc=Ed;Lc=Fd;Mc=Gd;Nc=Hd;Oc=Id;Pc=Jd;Qc=Kd;Rc=Ld;Sc=Md;Tc=Nd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}J=ba($a<<1,n)|0;Wa=c[Qb>>2]|0;Xa=Wa+z|0;S=Wa+A|0;if(Xa>>>0<68>>>0|S>>>0<68>>>0){_d=Cd;$d=Dd;ae=Ed;be=Fd;ce=Gd;de=Hd;ee=Id;fe=Jd;ge=Kd;he=Ld;ie=Md;je=Nd}else{Wa=d[1732768+S|0]|0;S=d[1797040+Xa|0]|0;a[Rb]=(a[(Od<<16>>16)+(189200+(Xa<<2))|0]|0)+1;a[Nb]=(a[(Pd<<16>>16)+(189200+(Xa<<2))|0]|0)+1;a[Mb]=(a[(Qd<<16>>16)+(189200+(Xa<<2))|0]|0)+1;a[Lb]=(a[(Rd<<16>>16)+(189200+(Xa<<2))|0]|0)+1;le[c[Jb>>2]&1023](k+J|0,n,S,Wa,Rb);_d=Od;$d=Pd;ae=Qd;be=Rd;ce=Od;de=Pd;ee=Qd;fe=Rd;ge=Od;he=Pd;ie=Qd;je=Rd}Wa=c[Pb>>2]|0;S=Wa+z|0;Xa=Wa+A|0;if(S>>>0<68>>>0|Xa>>>0<68>>>0){Ic=_d;Jc=$d;Kc=ae;Lc=be;Mc=ce;Nc=de;Oc=ee;Pc=fe;Qc=ge;Rc=he;Sc=ie;Tc=je;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}Wa=d[1732768+Xa|0]|0;Xa=d[1797040+S|0]|0;a[Rb]=(a[(Od<<16>>16)+(189200+(S<<2))|0]|0)+1;a[Nb]=(a[(Pd<<16>>16)+(189200+(S<<2))|0]|0)+1;a[Mb]=(a[(Qd<<16>>16)+(189200+(S<<2))|0]|0)+1;a[Lb]=(a[(Rd<<16>>16)+(189200+(S<<2))|0]|0)+1;le[c[Jb>>2]&1023](l+J|0,n,Xa,Wa,Rb);Ic=Od;Jc=Pd;Kc=Qd;Lc=Rd;Mc=Od;Nc=Pd;Oc=Qd;Pc=Rd;Qc=Od;Rc=Pd;Sc=Qd;Tc=Rd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td}else{Ic=N;Jc=s;Kc=Hb;Lc=Gb;Mc=Fb;Nc=Eb;Oc=Ib;Pc=Cb;Qc=Db;Rc=g;Sc=h;Tc=y;Uc=Ua;Vc=M;Wc=V;Xc=Sa;Yc=_;Zc=Ta;_c=Za;$c=Va}}while(0);E=$a+1|0;if((E|0)<(Bb|0)){$a=E;N=Ic;s=Jc;Hb=Kc;Gb=Lc;Fb=Mc;Eb=Nc;Ib=Oc;Cb=Pc;Db=Qc;g=Rc;h=Sc;y=Tc;Ua=Uc;M=Vc;V=Wc;Sa=Xc;_=Yc;Ta=Zc;Za=_c;Va=$c}else{break}}i=o;return}function $da(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=a[d+5632+e|0]|0;i=a[d+5632+f|0]|0;j=h<<24>>24!=i<<24>>24;if(j|h<<24>>24==-1){k=j&1}else{j=(b[d+5312+(e<<2)+2>>1]|0)-(b[d+5312+(f<<2)+2>>1]|0)|0;k=(((j|0)>-1?j:-j|0)|0)>=(g|0)|((b[d+5312+(e<<2)>>1]|0)+3-(b[d+5312+(f<<2)>>1]|0)|0)>>>0>6>>>0}if((c[d+199428>>2]|0)!=2){l=k;return l|0}do{if((k|0)==0){j=a[d+5672+e|0]|0;m=a[d+5672+f|0]|0;n=(b[d+5472+(e<<2)+2>>1]|0)-(b[d+5472+(f<<2)+2>>1]|0)|0;if((((b[d+5472+(e<<2)>>1]|0)+3-(b[d+5472+(f<<2)>>1]|0)|0)>>>0>6>>>0|j<<24>>24!=m<<24>>24|(((n|0)>-1?n:-n|0)|0)>=(g|0)|0)==0){l=0}else{o=m;p=j;break}return l|0}else{o=a[d+5672+f|0]|0;p=a[d+5672+e|0]|0}}while(0);if((p<<24>>24!=i<<24>>24|h<<24>>24!=o<<24>>24|0)!=0){l=1;return l|0}o=(b[d+5312+(e<<2)+2>>1]|0)-(b[d+5472+(f<<2)+2>>1]|0)|0;h=(b[d+5472+(e<<2)+2>>1]|0)-(b[d+5312+(f<<2)+2>>1]|0)|0;l=(((o|0)>-1?o:-o|0)|0)>=(g|0)|((b[d+5312+(e<<2)>>1]|0)+3-(b[d+5472+(f<<2)>>1]|0)|0)>>>0>6>>>0|((b[d+5472+(e<<2)>>1]|0)+3-(b[d+5312+(f<<2)>>1]|0)|0)>>>0>6>>>0|(((h|0)>-1?h:-h|0)|0)>=(g|0);return l|0}function aea(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0;f=i;g=e+1096|0;h=c[g>>2]|0;j=e+1104|0;k=c[j>>2]|0;l=e+1088|0;m=c[l>>2]|0;n=m+(h>>>3)|0;o=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>24;n=h+8|0;h=k>>>0>n>>>0?n:k;c[g>>2]=h;n=d[m+(h>>>3)|0]<<(h&7)>>>7;p=((h|0)<(k|0))+h|0;c[g>>2]=p;h=d[m+(p>>>3)|0]<<(p&7)>>>7;q=((p|0)<(k|0))+p|0;c[g>>2]=q;p=d[m+(q>>>3)|0]<<(q&7)>>>7;r=((q|0)<(k|0))+q|0;c[g>>2]=r;q=d[m+(r>>>3)|0]<<(r&7)>>>7;s=((r|0)<(k|0))+r|0;c[g>>2]=s;r=d[m+(s>>>3)|0]<<(s&7)>>>7;t=((s|0)<(k|0))+s|0;c[g>>2]=t;s=h<<1&2|n&1|p<<2&4|q<<3&8|r<<4&16|d[m+(t>>>3)|0]<<(t&7)>>>7<<5&32;r=((t|0)<(k|0))+t+2|0;t=k>>>0>r>>>0?r:k;c[g>>2]=t;r=m+(t>>>3)|0;q=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7)>>>24;r=t+8|0;t=k>>>0>r>>>0?r:k;c[g>>2]=t;r=m+(t>>>3)|0;m=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7)>>>23;r=(d[1213744+m|0]|0)+t|0;c[g>>2]=k>>>0>r>>>0?r:k;k=a[1108392+m|0]|0;m=k&255;if((k&255)>>>0>31>>>0){yDb(c[e>>2]|0,16,2283208,(u=i,i=i+8|0,c[u>>2]=m,u)|0);i=u;v=-1094995529;i=f;return v|0}k=cEb(1204)|0;r=k;if((k|0)==0){v=-12;i=f;return v|0}c[k>>2]=m;c[k+1164>>2]=24;t=k+4|0;c[t>>2]=o;c[k+1196>>2]=s;s=k+8|0;c[s>>2]=q;q=k+112|0;c[q>>2]=-1;p=k+672|0;n=k+768|0;TGb(p|0,16,480)|0;c[k+668>>2]=0;h=k+128|0;c[h>>2]=2;a:do{switch(o|0){case 100:case 110:case 122:case 244:case 44:case 83:case 86:case 118:case 128:case 144:{w=c[g>>2]|0;x=c[j>>2]|0;y=c[l>>2]|0;z=y+(w>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7)>>>23;z=(d[1213744+A|0]|0)+w|0;w=x>>>0>z>>>0?z:x;c[g>>2]=w;z=a[1108392+A|0]|0;A=z&255;c[k+12>>2]=A;if((z&255)>>>0>3>>>0){DDb(c[e>>2]|0,2324336,(u=i,i=i+8|0,c[u>>2]=A,u)|0);i=u;break a}do{if(z<<24>>24==3){A=d[y+(w>>>3)|0]<<(w&7)>>>7;B=((w|0)<(x|0))+w|0;c[g>>2]=B;C=A&1;c[k+1192>>2]=C;if((C|0)==0){D=B;break}yDb(c[e>>2]|0,16,2187728,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break a}else{D=w}}while(0);w=y+(D>>>3)|0;z=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(D&7);if(z>>>0>134217727>>>0){w=z>>>23;B=(d[1213744+w|0]|0)+D|0;C=x>>>0>B>>>0?B:x;c[g>>2]=C;E=d[1108392+w|0]|0;F=C}else{C=z>>>0>65535>>>0;w=C?z>>>16:z;B=C?16:0;if((w&65280|0)==0){G=B;H=w}else{G=B|8;H=w>>>8}w=(d[1191992+H|0]|0)+G<<1;B=63-w+D|0;C=x>>>0>B>>>0?B:x;c[g>>2]=C;E=(z>>>((w-31|0)>>>0))-1|0;F=C}C=E+8|0;c[k+1184>>2]=C;w=y+(F>>>3)|0;z=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(F&7);if(z>>>0>134217727>>>0){w=z>>>23;B=(d[1213744+w|0]|0)+F|0;A=x>>>0>B>>>0?B:x;c[g>>2]=A;I=d[1108392+w|0]|0;J=A}else{A=z>>>0>65535>>>0;w=A?z>>>16:z;B=A?16:0;if((w&65280|0)==0){K=B;L=w}else{K=B|8;L=w>>>8}w=(d[1191992+L|0]|0)+K<<1;B=63-w+F|0;A=x>>>0>B>>>0?B:x;c[g>>2]=A;I=(z>>>((w-31|0)>>>0))-1|0;J=A}A=I+8|0;c[k+1188>>2]=A;if((A|0)!=(C|0)){DDb(c[e>>2]|0,2110376,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break a}if(C>>>0>14>>>0){yDb(c[e>>2]|0,16,2052024,(u=i,i=i+16|0,c[u>>2]=C,c[u+8>>2]=C,u)|0);i=u;break a}else{C=d[y+(J>>>3)|0]<<(J&7)>>>7;c[g>>2]=((J|0)<(x|0))+J;c[k+16>>2]=C&1;bea(e,r,0,1,p,n);M=26;break a}break};default:{c[k+12>>2]=1;c[k+1184>>2]=8;c[k+1188>>2]=8;M=26}}}while(0);b:do{if((M|0)==26){n=c[g>>2]|0;p=c[j>>2]|0;J=c[l>>2]|0;I=J+(n>>>3)|0;F=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(n&7);if(F>>>0>134217727>>>0){I=F>>>23;K=(d[1213744+I|0]|0)+n|0;L=p>>>0>K>>>0?K:p;c[g>>2]=L;N=d[1108392+I|0]|0;O=L}else{L=F>>>0>65535>>>0;I=L?F>>>16:F;K=L?16:0;if((I&65280|0)==0){P=K;Q=I}else{P=K|8;Q=I>>>8}I=(d[1191992+Q|0]|0)+P<<1;K=63-I+n|0;n=p>>>0>K>>>0?K:p;c[g>>2]=n;N=(F>>>((I-31|0)>>>0))-1|0;O=n}if(N>>>0>12>>>0){yDb(c[e>>2]|0,16,2006624,(u=i,i=i+8|0,c[u>>2]=N,u)|0);i=u;break}c[k+20>>2]=N+4;n=J+(O>>>3)|0;I=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(O&7)>>>23;n=(d[1213744+I|0]|0)+O|0;F=p>>>0>n>>>0?n:p;c[g>>2]=F;n=d[1108392+I|0]|0;I=k+24|0;c[I>>2]=n;do{if((n|0)==1){K=d[J+(F>>>3)|0]<<(F&7)>>>7;L=((F|0)<(p|0))+F|0;c[g>>2]=L;c[k+32>>2]=K&1;K=J+(L>>>3)|0;E=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(L&7);if(E>>>0>134217727>>>0){K=E>>>23;D=(d[1213744+K|0]|0)+L|0;G=p>>>0>D>>>0?D:p;c[g>>2]=G;R=a[1139096+K|0]|0;S=G}else{G=E>>>0>65535>>>0;K=G?E>>>16:E;E=G?16:0;if((K&65280|0)==0){T=E;U=K}else{T=E|8;U=K>>>8}K=(d[1191992+U|0]|0)+T|0;E=31-K+L|0;L=p>>>0>E>>>0?E:p;E=J+(L>>>3)|0;G=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(L&7)>>>(K>>>0);E=L+(32-K)|0;K=p>>>0>E>>>0?E:p;c[g>>2]=K;E=G>>>1;R=(G&1|0)==0?E:-E|0;S=K}c[k+36>>2]=R;K=J+(S>>>3)|0;E=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(S&7);if(E>>>0>134217727>>>0){K=E>>>23;G=(d[1213744+K|0]|0)+S|0;L=p>>>0>G>>>0?G:p;c[g>>2]=L;V=a[1139096+K|0]|0;W=L}else{L=E>>>0>65535>>>0;K=L?E>>>16:E;E=L?16:0;if((K&65280|0)==0){X=E;Y=K}else{X=E|8;Y=K>>>8}K=(d[1191992+Y|0]|0)+X|0;E=31-K+S|0;L=p>>>0>E>>>0?E:p;E=J+(L>>>3)|0;G=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(L&7)>>>(K>>>0);E=L+(32-K)|0;K=p>>>0>E>>>0?E:p;c[g>>2]=K;E=G>>>1;V=(G&1|0)==0?E:-E|0;W=K}c[k+40>>2]=V;K=J+(W>>>3)|0;E=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(W&7);do{if(E>>>0>134217727>>>0){K=E>>>23;G=(d[1213744+K|0]|0)+W|0;L=p>>>0>G>>>0?G:p;c[g>>2]=L;G=d[1108392+K|0]|0;K=k+44|0;c[K>>2]=G;Z=K;_=L;$=G}else{G=E>>>0>65535>>>0;L=G?E>>>16:E;K=G?16:0;if((L&65280|0)==0){aa=K;ca=L}else{aa=K|8;ca=L>>>8}L=(d[1191992+ca|0]|0)+aa<<1;K=63-L+W|0;G=p>>>0>K>>>0?K:p;c[g>>2]=G;K=(E>>>((L-31|0)>>>0))-1|0;L=k+44|0;c[L>>2]=K;if(!(K>>>0>255>>>0)){Z=L;_=G;$=K;break}yDb(c[e>>2]|0,16,1940280,(u=i,i=i+8|0,c[u>>2]=K,u)|0);i=u;break b}}while(0);if(($|0)<=0){da=_;break}E=k+148|0;K=0;G=_;while(1){L=J+(G>>>3)|0;D=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(G&7);if(D>>>0>134217727>>>0){L=D>>>23;H=(d[1213744+L|0]|0)+G|0;o=p>>>0>H>>>0?H:p;c[g>>2]=o;ea=a[1139096+L|0]|0;fa=o}else{o=D>>>0>65535>>>0;L=o?D>>>16:D;D=o?16:0;if((L&65280|0)==0){ga=D;ha=L}else{ga=D|8;ha=L>>>8}L=(d[1191992+ha|0]|0)+ga|0;D=31-L+G|0;o=p>>>0>D>>>0?D:p;D=J+(o>>>3)|0;H=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(o&7)>>>(L>>>0);D=o+(32-L)|0;L=p>>>0>D>>>0?D:p;c[g>>2]=L;D=H>>>1;ea=((H&1|0)==0?D:-D|0)&65535;fa=L}b[E+(K<<1)>>1]=ea;L=K+1|0;if((L|0)<(c[Z>>2]|0)){K=L;G=fa}else{da=fa;break}}}else if((n|0)==0){G=J+(F>>>3)|0;K=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(F&7);if(K>>>0>134217727>>>0){G=K>>>23;E=(d[1213744+G|0]|0)+F|0;L=p>>>0>E>>>0?E:p;c[g>>2]=L;ia=d[1108392+G|0]|0;ja=L}else{L=K>>>0>65535>>>0;G=L?K>>>16:K;E=L?16:0;if((G&65280|0)==0){ka=E;la=G}else{ka=E|8;la=G>>>8}G=(d[1191992+la|0]|0)+ka<<1;E=63-G+F|0;L=p>>>0>E>>>0?E:p;c[g>>2]=L;ia=(K>>>((G-31|0)>>>0))-1|0;ja=L}if(ia>>>0>12>>>0){yDb(c[e>>2]|0,16,1968792,(u=i,i=i+8|0,c[u>>2]=ia,u)|0);i=u;break b}else{c[k+28>>2]=ia+4;da=ja;break}}else if((n|0)==2){da=F}else{yDb(c[e>>2]|0,16,1916080,(u=i,i=i+8|0,c[u>>2]=n,u)|0);i=u;break b}}while(0);n=J+(da>>>3)|0;F=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(da&7)>>>23;n=(d[1213744+F|0]|0)+da|0;x=p>>>0>n>>>0?n:p;c[g>>2]=x;n=d[1108392+F|0]|0;F=k+48|0;c[F>>2]=n;y=e|0;L=c[y>>2]|0;if((c[L+52>>2]|0)==844516691){G=n>>>0<2>>>0?2:n;c[F>>2]=G;ma=G}else{ma=n}if((ma|0)>34|ma>>>0>16>>>0){yDb(L,16,1895496,(u=i,i=i+8|0,c[u>>2]=ma,u)|0);i=u;break}n=d[J+(x>>>3)|0]<<(x&7)>>>7;G=((x|0)<(p|0))+x|0;c[g>>2]=G;c[k+52>>2]=n&1;n=J+(G>>>3)|0;x=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(G&7);if(x>>>0>134217727>>>0){n=x>>>23;K=(d[1213744+n|0]|0)+G|0;E=p>>>0>K>>>0?K:p;c[g>>2]=E;na=d[1108392+n|0]|0;oa=E}else{E=x>>>0>65535>>>0;n=E?x>>>16:x;K=E?16:0;if((n&65280|0)==0){pa=K;qa=n}else{pa=K|8;qa=n>>>8}n=(d[1191992+qa|0]|0)+pa<<1;K=63-n+G|0;G=p>>>0>K>>>0?K:p;c[g>>2]=G;na=(x>>>((n-31|0)>>>0))-1|0;oa=G}G=na+1|0;n=k+56|0;c[n>>2]=G;x=J+(oa>>>3)|0;K=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(oa&7);if(K>>>0>134217727>>>0){x=K>>>23;E=(d[1213744+x|0]|0)+oa|0;c[g>>2]=p>>>0>E>>>0?E:p;ra=d[1108392+x|0]|0}else{x=K>>>0>65535>>>0;E=x?K>>>16:K;D=x?16:0;if((E&65280|0)==0){sa=D;ta=E}else{sa=D|8;ta=E>>>8}E=(d[1191992+ta|0]|0)+sa<<1;D=63-E+oa|0;c[g>>2]=p>>>0>D>>>0?D:p;ra=(K>>>((E-31|0)>>>0))-1|0}E=ra+1|0;K=k+60|0;c[K>>2]=E;do{if(G>>>0>134217726>>>0|E>>>0>134217726>>>0){ua=L}else{if((hDb(G<<4,E<<4,0,L)|0)!=0){ua=c[y>>2]|0;break}D=c[g>>2]|0;x=c[l>>2]|0;H=d[x+(D>>>3)|0]<<(D&7)>>>7;o=c[j>>2]|0;C=((D|0)<(o|0))+D|0;c[g>>2]=C;D=H&1;H=k+64|0;c[H>>2]=D;if((D|0)==0){A=d[x+(C>>>3)|0]<<(C&7)>>>7;w=((C|0)<(o|0))+C|0;c[g>>2]=w;c[k+68>>2]=A&1;va=w}else{c[k+68>>2]=0;va=C}C=d[x+(va>>>3)|0]<<(va&7)>>>7;w=((va|0)<(o|0))+va|0;c[g>>2]=w;A=k+72|0;c[A>>2]=C&1;C=d[x+(w>>>3)|0]<<(w&7)>>>7;z=((w|0)<(o|0))+w|0;c[g>>2]=z;w=C&1;C=k+76|0;c[C>>2]=w;c:do{if((w|0)==0){TGb(C|0,0,20)|0}else{B=x+(z>>>3)|0;wa=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7);if(wa>>>0>134217727>>>0){B=wa>>>23;xa=(d[1213744+B|0]|0)+z|0;ya=o>>>0>xa>>>0?xa:o;c[g>>2]=ya;za=d[1108392+B|0]|0;Aa=ya}else{ya=wa>>>0>65535>>>0;B=ya?wa>>>16:wa;xa=ya?16:0;if((B&65280|0)==0){Ba=xa;Ca=B}else{Ba=xa|8;Ca=B>>>8}B=(d[1191992+Ca|0]|0)+Ba<<1;xa=63-B+z|0;ya=o>>>0>xa>>>0?xa:o;c[g>>2]=ya;za=(wa>>>((B-31|0)>>>0))-1|0;Aa=ya}ya=x+(Aa>>>3)|0;B=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(Aa&7);if(B>>>0>134217727>>>0){ya=B>>>23;wa=(d[1213744+ya|0]|0)+Aa|0;xa=o>>>0>wa>>>0?wa:o;c[g>>2]=xa;Da=d[1108392+ya|0]|0;Ea=xa}else{xa=B>>>0>65535>>>0;ya=xa?B>>>16:B;wa=xa?16:0;if((ya&65280|0)==0){Fa=wa;Ga=ya}else{Fa=wa|8;Ga=ya>>>8}ya=(d[1191992+Ga|0]|0)+Fa<<1;wa=63-ya+Aa|0;xa=o>>>0>wa>>>0?wa:o;c[g>>2]=xa;Da=(B>>>((ya-31|0)>>>0))-1|0;Ea=xa}xa=x+(Ea>>>3)|0;ya=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ea&7);if(ya>>>0>134217727>>>0){xa=ya>>>23;B=(d[1213744+xa|0]|0)+Ea|0;wa=o>>>0>B>>>0?B:o;c[g>>2]=wa;Ha=d[1108392+xa|0]|0;Ia=wa}else{wa=ya>>>0>65535>>>0;xa=wa?ya>>>16:ya;B=wa?16:0;if((xa&65280|0)==0){Ja=B;Ka=xa}else{Ja=B|8;Ka=xa>>>8}xa=(d[1191992+Ka|0]|0)+Ja<<1;B=63-xa+Ea|0;wa=o>>>0>B>>>0?B:o;c[g>>2]=wa;Ha=(ya>>>((xa-31|0)>>>0))-1|0;Ia=wa}wa=x+(Ia>>>3)|0;xa=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Ia&7);if(xa>>>0>134217727>>>0){wa=xa>>>23;ya=(d[1213744+wa|0]|0)+Ia|0;c[g>>2]=o>>>0>ya>>>0?ya:o;La=d[1108392+wa|0]|0}else{wa=xa>>>0>65535>>>0;ya=wa?xa>>>16:xa;B=wa?16:0;if((ya&65280|0)==0){Ma=B;Na=ya}else{Ma=B|8;Na=ya>>>8}ya=(d[1191992+Na|0]|0)+Ma<<1;B=63-ya+Ia|0;c[g>>2]=o>>>0>B>>>0?B:o;La=(xa>>>((ya-31|0)>>>0))-1|0}ya=c[n>>2]<<4;xa=2-D|0;B=ba(xa,c[K>>2]<<4)|0;wa=c[y>>2]|0;if((c[wa+92>>2]&65536|0)!=0){yDb(wa,48,2332520,(u=i,i=i+32|0,c[u>>2]=za,c[u+8>>2]=Da,c[u+16>>2]=Ha,c[u+24>>2]=La,u)|0);i=u;TGb(k+80|0,0,16)|0;break}Oa=c[k+12>>2]|0;Pa=(Oa|0)==1;if(Pa){Qa=1}else{Qa=(Oa|0)==2|0}Oa=xa<<(Pa&1);Pa=31>>>(((c[k+1184>>2]|0)>8|0)>>>0);do{if((Pa&za|0)==0){Ra=za}else{if((c[wa+88>>2]&1|0)!=0){Ra=za;break}xa=za&~Pa;yDb(wa,24,2308232,(u=i,i=i+8|0,c[u>>2]=xa,u)|0);i=u;Ra=xa}}while(0);wa=536870911>>>(Qa>>>0);do{if(!(Ra>>>0>wa>>>0|Da>>>0>wa>>>0)){Pa=536870911/(Oa>>>0)|0;if(Ha>>>0>Pa>>>0|La>>>0>Pa>>>0){break}if((Ra+Da<<Qa|0)>=(ya|0)){break}if((ba(Oa,La+Ha|0)|0)>=(B|0)){break}c[k+80>>2]=Ra<<Qa;c[k+84>>2]=Da<<Qa;c[k+88>>2]=ba(Oa,Ha)|0;c[k+92>>2]=ba(Oa,La)|0;break c}}while(0);yDb(c[y>>2]|0,16,2289648,(u=i,i=i+48|0,c[u>>2]=Ra,c[u+8>>2]=Da,c[u+16>>2]=Ha,c[u+24>>2]=La,c[u+32>>2]=ya,c[u+40>>2]=B,u)|0);i=u;break b}}while(0);D=c[g>>2]|0;o=c[l>>2]|0;x=d[o+(D>>>3)|0]<<(D&7)>>>7;z=c[j>>2]|0;C=((D|0)<(z|0))+D|0;c[g>>2]=C;D=x&1;x=k+96|0;c[x>>2]=D;d:do{if((D|0)!=0){w=d[o+(C>>>3)|0]|0;Oa=((C|0)<(z|0))+C|0;c[g>>2]=Oa;do{if((w&128>>>((C&7)>>>0)|0)==0){c[k+104>>2]=0;c[k+100>>2]=0;Sa=Oa}else{wa=o+(Oa>>>3)|0;Pa=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Oa&7);wa=Pa>>>24;xa=Oa+8|0;Ta=z>>>0>xa>>>0?xa:z;c[g>>2]=Ta;if((wa|0)==255){xa=o+(Ta>>>3)|0;Ua=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ta&7)>>>16;xa=Ta+16|0;Va=z>>>0>xa>>>0?xa:z;c[g>>2]=Va;c[k+100>>2]=Ua;Ua=o+(Va>>>3)|0;xa=(fe(d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0)|0)<<(Va&7)>>>16;Ua=Va+16|0;Va=z>>>0>Ua>>>0?Ua:z;c[g>>2]=Va;c[k+104>>2]=xa;Sa=Va;break}if(Pa>>>0<285212672>>>0){Pa=588368+(wa<<3)|0;wa=k+100|0;Va=c[Pa+4>>2]|0;c[wa>>2]=c[Pa>>2];c[wa+4>>2]=Va;Sa=Ta;break}else{yDb(c[y>>2]|0,16,2083904,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break b}}}while(0);Oa=((Sa|0)<(z|0))+Sa|0;if((d[o+(Sa>>>3)|0]&128>>>((Sa&7)>>>0)|0)==0){Wa=Oa}else{Wa=((Oa|0)<(z|0))+Oa|0}c[g>>2]=Wa;Oa=d[o+(Wa>>>3)|0]<<(Wa&7)>>>7;w=((Wa|0)<(z|0))+Wa|0;c[g>>2]=w;B=Oa&1;c[k+108>>2]=B;do{if((B|0)==0){Xa=w}else{Oa=w+3|0;ya=z>>>0>Oa>>>0?Oa:z;c[g>>2]=ya;Oa=d[o+(ya>>>3)|0]<<(ya&7)>>>7;Ta=((ya|0)<(z|0))+ya|0;c[g>>2]=Ta;c[q>>2]=Oa&1;Oa=d[o+(Ta>>>3)|0]<<(Ta&7)>>>7;ya=((Ta|0)<(z|0))+Ta|0;c[g>>2]=ya;Ta=Oa&1;c[k+116>>2]=Ta;if((Ta|0)==0){Xa=ya;break}Ta=o+(ya>>>3)|0;Oa=(fe(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(ya&7);Ta=ya+8|0;ya=z>>>0>Ta>>>0?Ta:z;c[g>>2]=ya;Ta=k+120|0;c[Ta>>2]=Oa>>>24;Va=o+(ya>>>3)|0;wa=(fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(ya&7);Va=ya+8|0;ya=z>>>0>Va>>>0?Va:z;c[g>>2]=ya;Va=k+124|0;c[Va>>2]=wa>>>24;Pa=o+(ya>>>3)|0;xa=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(ya&7);Pa=ya+8|0;ya=z>>>0>Pa>>>0?Pa:z;c[g>>2]=ya;c[h>>2]=xa>>>24;if(Oa>>>0>167772159>>>0){c[Ta>>2]=2}if(wa>>>0>268435455>>>0){c[Va>>2]=2}if(!(xa>>>0>184549375>>>0)){Xa=ya;break}c[h>>2]=2;Xa=ya}}while(0);w=d[o+(Xa>>>3)|0]|0;B=((Xa|0)<(z|0))+Xa|0;c[g>>2]=B;do{if((w&128>>>((Xa&7)>>>0)|0)==0){Ya=B}else{ya=o+(B>>>3)|0;xa=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(B&7);if(xa>>>0>134217727>>>0){ya=xa>>>23;Va=(d[1213744+ya|0]|0)+B|0;wa=z>>>0>Va>>>0?Va:z;c[g>>2]=wa;Za=d[1108392+ya|0]|0;_a=wa}else{wa=xa>>>0>65535>>>0;ya=wa?xa>>>16:xa;Va=wa?16:0;if((ya&65280|0)==0){$a=Va;ab=ya}else{$a=Va|8;ab=ya>>>8}ya=(d[1191992+ab|0]|0)+$a<<1;Va=63-ya+B|0;wa=z>>>0>Va>>>0?Va:z;c[g>>2]=wa;Za=(xa>>>((ya-31|0)>>>0))-1|0;_a=wa}c[(c[y>>2]|0)+400>>2]=Za+1;wa=o+(_a>>>3)|0;ya=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(_a&7);if(ya>>>0>134217727>>>0){wa=(d[1213744+(ya>>>23)|0]|0)+_a|0;xa=z>>>0>wa>>>0?wa:z;c[g>>2]=xa;Ya=xa;break}xa=ya>>>0>65535>>>0;wa=xa?ya>>>16:ya;ya=xa?16:0;if((wa&65280|0)==0){bb=ya;cb=wa}else{bb=ya|8;cb=wa>>>8}wa=63-((d[1191992+cb|0]|0)+bb<<1)+_a|0;ya=z>>>0>wa>>>0?wa:z;c[g>>2]=ya;Ya=ya}}while(0);B=o+(Ya>>>3)|0;w=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=Ya&7;do{if(((fe(w|0)|0)&-2147483648>>>(B>>>0)|0)!=0){if(((c[e+1100>>2]|0)-Ya|0)>=10){break}yDb(c[y>>2]|0,24,2078408,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break d}}while(0);ya=((Ya|0)<(z|0))+Ya|0;c[g>>2]=ya;wa=(w&255)<<B>>>7&1;c[k+132>>2]=wa;do{if((wa|0)==0){db=ya}else{xa=o+(ya>>>3)|0;Va=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(ya&7)&-65536;xa=ya+16|0;Ta=z>>>0>xa>>>0?xa:z;c[g>>2]=Ta;xa=o+(Ta>>>3)|0;Oa=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ta&7)>>>16;xa=Ta+16|0;Ta=z>>>0>xa>>>0?xa:z;c[g>>2]=Ta;xa=Oa|Va;c[k+136>>2]=xa;Va=o+(Ta>>>3)|0;Oa=(fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)&-65536;Va=Ta+16|0;Ta=z>>>0>Va>>>0?Va:z;c[g>>2]=Ta;Va=o+(Ta>>>3)|0;Pa=(fe(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)>>>16;Va=Ta+16|0;Ta=z>>>0>Va>>>0?Va:z;c[g>>2]=Ta;Va=Pa|Oa;c[k+140>>2]=Va;if((xa|0)==0|(Va|0)==0){yDb(c[y>>2]|0,16,2073448,(u=i,i=i+16|0,c[u>>2]=Va,c[u+8>>2]=xa,u)|0);i=u;break b}else{xa=d[o+(Ta>>>3)|0]<<(Ta&7)>>>7;Va=((Ta|0)<(z|0))+Ta|0;c[g>>2]=Va;c[k+144>>2]=xa&1;db=Va;break}}}while(0);ya=d[o+(db>>>3)|0]<<(db&7)>>>7;wa=((db|0)<(z|0))+db|0;c[g>>2]=wa;B=ya&1;ya=k+1152|0;c[ya>>2]=B;if((B|0)==0){eb=o;fb=wa;gb=z}else{if((dea(e,r)|0)<0){break b}eb=c[l>>2]|0;fb=c[g>>2]|0;gb=c[j>>2]|0}wa=d[eb+(fb>>>3)|0]<<(fb&7)>>>7;c[g>>2]=((fb|0)<(gb|0))+fb;B=wa&1;wa=k+1156|0;c[wa>>2]=B;if((B|0)!=0){if((dea(e,r)|0)<0){break b}}do{if((c[ya>>2]|0)==0){if((c[wa>>2]|0)!=0){M=167;break}hb=c[g>>2]|0;ib=c[j>>2]|0}else{M=167}}while(0);if((M|0)==167){wa=c[g>>2]|0;ya=c[j>>2]|0;B=((wa|0)<(ya|0))+wa|0;c[g>>2]=B;hb=B;ib=ya}ya=c[l>>2]|0;B=d[ya+(hb>>>3)|0]<<(hb&7)>>>7;wa=((hb|0)<(ib|0))+hb|0;c[g>>2]=wa;c[k+1160>>2]=B&1;B=c[e+1100>>2]|0;if((B|0)==(wa|0)){break}w=d[ya+(wa>>>3)|0]<<(wa&7)>>>7;Va=((wa|0)<(ib|0))+wa|0;c[g>>2]=Va;wa=w&1;w=k+660|0;c[w>>2]=wa;do{if((wa|0)==0){jb=Va}else{xa=((Va|0)<(ib|0))+Va|0;c[g>>2]=xa;Ta=ya+(xa>>>3)|0;Oa=(fe(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(xa&7);if(Oa>>>0>134217727>>>0){Ta=(d[1213744+(Oa>>>23)|0]|0)+xa|0;kb=ib>>>0>Ta>>>0?Ta:ib}else{Ta=Oa>>>0>65535>>>0;Pa=Ta?Oa>>>16:Oa;Oa=Ta?16:0;if((Pa&65280|0)==0){lb=Oa;mb=Pa}else{lb=Oa|8;mb=Pa>>>8}Pa=63-((d[1191992+mb|0]|0)+lb<<1)+xa|0;kb=ib>>>0>Pa>>>0?Pa:ib}c[g>>2]=kb;Pa=ya+(kb>>>3)|0;xa=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(kb&7);if(xa>>>0>134217727>>>0){Pa=(d[1213744+(xa>>>23)|0]|0)+kb|0;nb=ib>>>0>Pa>>>0?Pa:ib}else{Pa=xa>>>0>65535>>>0;Oa=Pa?xa>>>16:xa;xa=Pa?16:0;if((Oa&65280|0)==0){ob=xa;pb=Oa}else{ob=xa|8;pb=Oa>>>8}Oa=63-((d[1191992+pb|0]|0)+ob<<1)+kb|0;nb=ib>>>0>Oa>>>0?Oa:ib}c[g>>2]=nb;Oa=ya+(nb>>>3)|0;xa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(nb&7);if(xa>>>0>134217727>>>0){Oa=(d[1213744+(xa>>>23)|0]|0)+nb|0;qb=ib>>>0>Oa>>>0?Oa:ib}else{Oa=xa>>>0>65535>>>0;Pa=Oa?xa>>>16:xa;xa=Oa?16:0;if((Pa&65280|0)==0){rb=xa;sb=Pa}else{rb=xa|8;sb=Pa>>>8}Pa=63-((d[1191992+sb|0]|0)+rb<<1)+nb|0;qb=ib>>>0>Pa>>>0?Pa:ib}c[g>>2]=qb;Pa=ya+(qb>>>3)|0;xa=(fe(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(qb&7);if(xa>>>0>134217727>>>0){Pa=(d[1213744+(xa>>>23)|0]|0)+qb|0;tb=ib>>>0>Pa>>>0?Pa:ib}else{Pa=xa>>>0>65535>>>0;Oa=Pa?xa>>>16:xa;xa=Pa?16:0;if((Oa&65280|0)==0){ub=xa;vb=Oa}else{ub=xa|8;vb=Oa>>>8}Oa=63-((d[1191992+vb|0]|0)+ub<<1)+qb|0;tb=ib>>>0>Oa>>>0?Oa:ib}c[g>>2]=tb;Oa=ya+(tb>>>3)|0;xa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(tb&7);if(xa>>>0>134217727>>>0){Oa=xa>>>23;Pa=(d[1213744+Oa|0]|0)+tb|0;Ta=ib>>>0>Pa>>>0?Pa:ib;c[g>>2]=Ta;wb=d[1108392+Oa|0]|0;xb=Ta}else{Ta=xa>>>0>65535>>>0;Oa=Ta?xa>>>16:xa;Pa=Ta?16:0;if((Oa&65280|0)==0){yb=Pa;zb=Oa}else{yb=Pa|8;zb=Oa>>>8}Oa=(d[1191992+zb|0]|0)+yb<<1;Pa=63-Oa+tb|0;Ta=ib>>>0>Pa>>>0?Pa:ib;c[g>>2]=Ta;wb=(xa>>>((Oa-31|0)>>>0))-1|0;xb=Ta}Ta=k+664|0;c[Ta>>2]=wb;Oa=ya+(xb>>>3)|0;xa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(xb&7);if(xa>>>0>134217727>>>0){Oa=(d[1213744+(xa>>>23)|0]|0)+xb|0;Ab=ib>>>0>Oa>>>0?Oa:ib}else{Oa=xa>>>0>65535>>>0;Pa=Oa?xa>>>16:xa;xa=Oa?16:0;if((Pa&65280|0)==0){Bb=xa;Cb=Pa}else{Bb=xa|8;Cb=Pa>>>8}Pa=63-((d[1191992+Cb|0]|0)+Bb<<1)+xb|0;Ab=ib>>>0>Pa>>>0?Pa:ib}c[g>>2]=Ab;if((B-Ab|0)<0){c[Ta>>2]=0;c[w>>2]=0;jb=Ab;break}if(!(wb>>>0>16>>>0)){jb=Ab;break}yDb(c[y>>2]|0,16,2068944,(u=i,i=i+8|0,c[u>>2]=wb,u)|0);i=u;c[Ta>>2]=16;break b}}while(0);w=B-jb|0;if((w|0)>=0){break}yDb(c[y>>2]|0,16,2064360,(u=i,i=i+8|0,c[u>>2]=-w,u)|0);i=u;break b}}while(0);z=k+104|0;if((c[z>>2]|0)==0){c[z>>2]=1}z=c[y>>2]|0;if((c[z+688>>2]&1|0)!=0){o=c[t>>2]|0;C=c[s>>2]|0;D=c[I>>2]|0;w=c[F>>2]|0;ya=c[n>>2]|0;Va=c[K>>2]|0;if((c[H>>2]|0)==0){Db=(c[k+68>>2]|0)!=0?2243856:2231336}else{Db=2258056}wa=(c[A>>2]|0)!=0?2219192:9203456;Ta=c[k+80>>2]|0;Pa=c[k+84>>2]|0;xa=c[k+88>>2]|0;Oa=c[k+92>>2]|0;Ua=(c[x>>2]|0)!=0?2201192:9203456;Eb=1207784+((c[k+12>>2]|0)*5|0)|0;if((c[k+132>>2]|0)==0){Fb=0;Gb=0}else{Fb=c[k+140>>2]|0;Gb=c[k+136>>2]|0}Hb=c[k+1184>>2]|0;if((c[k+660>>2]|0)==0){Ib=-1}else{Ib=c[k+664>>2]|0}yDb(z,48,2273664,(u=i,i=i+152|0,c[u>>2]=m,c[u+8>>2]=o,c[u+16>>2]=C,c[u+24>>2]=D,c[u+32>>2]=w,c[u+40>>2]=ya,c[u+48>>2]=Va,c[u+56>>2]=Db,c[u+64>>2]=wa,c[u+72>>2]=Ta,c[u+80>>2]=Pa,c[u+88>>2]=xa,c[u+96>>2]=Oa,c[u+104>>2]=Ua,c[u+112>>2]=Eb,c[u+120>>2]=Gb,c[u+128>>2]=Fb,c[u+136>>2]=Hb,c[u+144>>2]=Ib,u)|0);i=u}c[k+1200>>2]=1;Hb=e+427476+(m<<2)|0;ZDb(c[Hb>>2]|0);c[Hb>>2]=r;v=0;i=f;return v|0}}while(0);yDb(ua,16,2352752,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u}}while(0);ZDb(k);v=-1;i=f;return v|0}function bea(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;j=(g|0)!=0;if(j){k=0}else{k=(c[e+668>>2]|0)!=0}l=k?e+720|0:1402144;m=k?e+768|0:1402e3;n=k?e+960|0:1402064;o=b+1096|0;p=c[o>>2]|0;q=b+1088|0;r=c[q>>2]|0;s=d[r+(p>>>3)|0]|0;t=b+1104|0;c[o>>2]=((p|0)<(c[t>>2]|0))+p;if((s&128>>>((p&7)>>>0)|0)==0){return}p=e+668|0;c[p>>2]=c[p>>2]|g;g=h|0;p=c[o>>2]|0;s=d[r+(p>>>3)|0]|0;c[o>>2]=((p|0)<(c[t>>2]|0))+p;a:do{if((s&128>>>((p&7)>>>0)|0)==0){UGb(g|0,(k?e+672|0:1402128)|0,16)|0}else{r=8;b=8;u=0;while(1){if((b|0)==0){v=0}else{w=c[o>>2]|0;x=c[t>>2]|0;y=c[q>>2]|0;z=y+(w>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7);if(A>>>0>134217727>>>0){z=A>>>23;B=(d[1213744+z|0]|0)+w|0;c[o>>2]=x>>>0>B>>>0?B:x;C=a[1139096+z|0]|0}else{z=A>>>0>65535>>>0;B=z?A>>>16:A;A=z?16:0;if((B&65280|0)==0){D=A;E=B}else{D=A|8;E=B>>>8}B=(d[1191992+E|0]|0)+D|0;A=31-B+w|0;w=x>>>0>A>>>0?A:x;A=y+(w>>>3)|0;y=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(w&7)>>>(B>>>0);A=w+(32-B)|0;c[o>>2]=x>>>0>A>>>0?A:x;x=y>>>1;C=(y&1|0)==0?x:-x|0}v=C+r&255}if((v|u|0)==0){break}x=(v|0)!=0?v:r;a[h+(d[120+u|0]|0)|0]=x;y=u+1|0;if((y|0)<16){r=x;b=v;u=y}else{break a}}UGb(g|0,1402128,16)|0}}while(0);v=h+16|0;C=c[o>>2]|0;D=d[(c[q>>2]|0)+(C>>>3)|0]|0;c[o>>2]=((C|0)<(c[t>>2]|0))+C;b:do{if((D&128>>>((C&7)>>>0)|0)==0){UGb(v|0,g|0,16)|0}else{E=8;k=8;p=0;while(1){if((k|0)==0){F=0}else{s=c[o>>2]|0;u=c[t>>2]|0;b=c[q>>2]|0;r=b+(s>>>3)|0;y=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7);if(y>>>0>134217727>>>0){r=y>>>23;x=(d[1213744+r|0]|0)+s|0;c[o>>2]=u>>>0>x>>>0?x:u;G=a[1139096+r|0]|0}else{r=y>>>0>65535>>>0;x=r?y>>>16:y;y=r?16:0;if((x&65280|0)==0){H=y;I=x}else{H=y|8;I=x>>>8}x=(d[1191992+I|0]|0)+H|0;y=31-x+s|0;s=u>>>0>y>>>0?y:u;y=b+(s>>>3)|0;b=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(s&7)>>>(x>>>0);y=s+(32-x)|0;c[o>>2]=u>>>0>y>>>0?y:u;u=b>>>1;G=(b&1|0)==0?u:-u|0}F=G+E&255}if((F|p|0)==0){break}u=(F|0)!=0?F:E;a[(d[120+p|0]|0)+(h+16)|0]=u;b=p+1|0;if((b|0)<16){E=u;k=F;p=b}else{break b}}UGb(v|0,1402128,16)|0}}while(0);F=h+32|0;G=c[o>>2]|0;H=d[(c[q>>2]|0)+(G>>>3)|0]|0;c[o>>2]=((G|0)<(c[t>>2]|0))+G;c:do{if((H&128>>>((G&7)>>>0)|0)==0){UGb(F|0,v|0,16)|0}else{I=8;g=8;C=0;while(1){if((g|0)==0){J=0}else{D=c[o>>2]|0;p=c[t>>2]|0;k=c[q>>2]|0;E=k+(D>>>3)|0;b=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7);if(b>>>0>134217727>>>0){E=b>>>23;u=(d[1213744+E|0]|0)+D|0;c[o>>2]=p>>>0>u>>>0?u:p;K=a[1139096+E|0]|0}else{E=b>>>0>65535>>>0;u=E?b>>>16:b;b=E?16:0;if((u&65280|0)==0){L=b;M=u}else{L=b|8;M=u>>>8}u=(d[1191992+M|0]|0)+L|0;b=31-u+D|0;D=p>>>0>b>>>0?b:p;b=k+(D>>>3)|0;k=(fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(D&7)>>>(u>>>0);b=D+(32-u)|0;c[o>>2]=p>>>0>b>>>0?b:p;p=k>>>1;K=(k&1|0)==0?p:-p|0}J=K+I&255}if((J|C|0)==0){break}p=(J|0)!=0?J:I;a[(d[120+C|0]|0)+(h+32)|0]=p;k=C+1|0;if((k|0)<16){I=p;g=J;C=k}else{break c}}UGb(F|0,1402128,16)|0}}while(0);F=h+48|0;J=c[o>>2]|0;K=d[(c[q>>2]|0)+(J>>>3)|0]|0;c[o>>2]=((J|0)<(c[t>>2]|0))+J;d:do{if((K&128>>>((J&7)>>>0)|0)==0){UGb(F|0,l|0,16)|0}else{L=8;M=8;v=0;while(1){if((M|0)==0){N=0}else{G=c[o>>2]|0;H=c[t>>2]|0;C=c[q>>2]|0;g=C+(G>>>3)|0;I=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(G&7);if(I>>>0>134217727>>>0){g=I>>>23;k=(d[1213744+g|0]|0)+G|0;c[o>>2]=H>>>0>k>>>0?k:H;O=a[1139096+g|0]|0}else{g=I>>>0>65535>>>0;k=g?I>>>16:I;I=g?16:0;if((k&65280|0)==0){P=I;Q=k}else{P=I|8;Q=k>>>8}k=(d[1191992+Q|0]|0)+P|0;I=31-k+G|0;G=H>>>0>I>>>0?I:H;I=C+(G>>>3)|0;C=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(G&7)>>>(k>>>0);I=G+(32-k)|0;c[o>>2]=H>>>0>I>>>0?I:H;H=C>>>1;O=(C&1|0)==0?H:-H|0}N=O+L&255}if((N|v|0)==0){break}H=(N|0)!=0?N:L;a[(d[120+v|0]|0)+(h+48)|0]=H;C=v+1|0;if((C|0)<16){L=H;M=N;v=C}else{break d}}UGb(F|0,1402144,16)|0}}while(0);N=h+64|0;O=c[o>>2]|0;P=d[(c[q>>2]|0)+(O>>>3)|0]|0;c[o>>2]=((O|0)<(c[t>>2]|0))+O;e:do{if((P&128>>>((O&7)>>>0)|0)==0){UGb(N|0,F|0,16)|0}else{Q=8;l=8;J=0;while(1){if((l|0)==0){R=0}else{K=c[o>>2]|0;v=c[t>>2]|0;M=c[q>>2]|0;L=M+(K>>>3)|0;C=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(K&7);if(C>>>0>134217727>>>0){L=C>>>23;H=(d[1213744+L|0]|0)+K|0;c[o>>2]=v>>>0>H>>>0?H:v;S=a[1139096+L|0]|0}else{L=C>>>0>65535>>>0;H=L?C>>>16:C;C=L?16:0;if((H&65280|0)==0){T=C;U=H}else{T=C|8;U=H>>>8}H=(d[1191992+U|0]|0)+T|0;C=31-H+K|0;K=v>>>0>C>>>0?C:v;C=M+(K>>>3)|0;M=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(K&7)>>>(H>>>0);C=K+(32-H)|0;c[o>>2]=v>>>0>C>>>0?C:v;v=M>>>1;S=(M&1|0)==0?v:-v|0}R=S+Q&255}if((R|J|0)==0){break}v=(R|0)!=0?R:Q;a[(d[120+J|0]|0)+(h+64)|0]=v;M=J+1|0;if((M|0)<16){Q=v;l=R;J=M}else{break e}}UGb(N|0,1402144,16)|0}}while(0);R=h+80|0;S=c[o>>2]|0;T=d[(c[q>>2]|0)+(S>>>3)|0]|0;c[o>>2]=((S|0)<(c[t>>2]|0))+S;f:do{if((T&128>>>((S&7)>>>0)|0)==0){UGb(R|0,N|0,16)|0}else{U=8;F=8;O=0;while(1){if((F|0)==0){V=0}else{P=c[o>>2]|0;J=c[t>>2]|0;l=c[q>>2]|0;Q=l+(P>>>3)|0;M=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(P&7);if(M>>>0>134217727>>>0){Q=M>>>23;v=(d[1213744+Q|0]|0)+P|0;c[o>>2]=J>>>0>v>>>0?v:J;W=a[1139096+Q|0]|0}else{Q=M>>>0>65535>>>0;v=Q?M>>>16:M;M=Q?16:0;if((v&65280|0)==0){X=M;Y=v}else{X=M|8;Y=v>>>8}v=(d[1191992+Y|0]|0)+X|0;M=31-v+P|0;P=J>>>0>M>>>0?M:J;M=l+(P>>>3)|0;l=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(P&7)>>>(v>>>0);M=P+(32-v)|0;c[o>>2]=J>>>0>M>>>0?M:J;J=l>>>1;W=(l&1|0)==0?J:-J|0}V=W+U&255}if((V|O|0)==0){break}J=(V|0)!=0?V:U;a[(d[120+O|0]|0)+(h+80)|0]=J;l=O+1|0;if((l|0)<16){U=J;F=V;O=l}else{break f}}UGb(R|0,1402144,16)|0}}while(0);do{if(!j){if((c[f+64>>2]|0)!=0){break}return}}while(0);f=i|0;j=c[o>>2]|0;R=d[(c[q>>2]|0)+(j>>>3)|0]|0;c[o>>2]=((j|0)<(c[t>>2]|0))+j;g:do{if((R&128>>>((j&7)>>>0)|0)==0){UGb(f|0,m|0,64)|0}else{V=8;h=8;W=0;while(1){if((h|0)==0){Z=0}else{X=c[o>>2]|0;Y=c[t>>2]|0;N=c[q>>2]|0;S=N+(X>>>3)|0;T=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(X&7);if(T>>>0>134217727>>>0){S=T>>>23;O=(d[1213744+S|0]|0)+X|0;c[o>>2]=Y>>>0>O>>>0?O:Y;_=a[1139096+S|0]|0}else{S=T>>>0>65535>>>0;O=S?T>>>16:T;T=S?16:0;if((O&65280|0)==0){$=T;aa=O}else{$=T|8;aa=O>>>8}O=(d[1191992+aa|0]|0)+$|0;T=31-O+X|0;X=Y>>>0>T>>>0?T:Y;T=N+(X>>>3)|0;N=(fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(X&7)>>>(O>>>0);T=X+(32-O)|0;c[o>>2]=Y>>>0>T>>>0?T:Y;Y=N>>>1;_=(N&1|0)==0?Y:-Y|0}Z=_+V&255}if((Z|W|0)==0){break}Y=(Z|0)!=0?Z:V;a[i+(d[1075976+W|0]|0)|0]=Y;N=W+1|0;if((N|0)<64){V=Y;h=Z;W=N}else{break g}}UGb(f|0,1402e3,64)|0}}while(0);Z=i+192|0;_=c[o>>2]|0;$=d[(c[q>>2]|0)+(_>>>3)|0]|0;c[o>>2]=((_|0)<(c[t>>2]|0))+_;h:do{if(($&128>>>((_&7)>>>0)|0)==0){UGb(Z|0,n|0,64)|0}else{aa=8;m=8;j=0;while(1){if((m|0)==0){ba=0}else{R=c[o>>2]|0;W=c[t>>2]|0;h=c[q>>2]|0;V=h+(R>>>3)|0;N=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(R&7);if(N>>>0>134217727>>>0){V=N>>>23;Y=(d[1213744+V|0]|0)+R|0;c[o>>2]=W>>>0>Y>>>0?Y:W;ca=a[1139096+V|0]|0}else{V=N>>>0>65535>>>0;Y=V?N>>>16:N;N=V?16:0;if((Y&65280|0)==0){da=N;ea=Y}else{da=N|8;ea=Y>>>8}Y=(d[1191992+ea|0]|0)+da|0;N=31-Y+R|0;R=W>>>0>N>>>0?N:W;N=h+(R>>>3)|0;h=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(R&7)>>>(Y>>>0);N=R+(32-Y)|0;c[o>>2]=W>>>0>N>>>0?N:W;W=h>>>1;ca=(h&1|0)==0?W:-W|0}ba=ca+aa&255}if((ba|j|0)==0){break}W=(ba|0)!=0?ba:aa;a[(d[1075976+j|0]|0)+(i+192)|0]=W;h=j+1|0;if((h|0)<64){aa=W;m=ba;j=h}else{break h}}UGb(Z|0,1402064,64)|0}}while(0);if((c[e+12>>2]|0)!=3){return}e=i+64|0;ba=c[o>>2]|0;ca=d[(c[q>>2]|0)+(ba>>>3)|0]|0;c[o>>2]=((ba|0)<(c[t>>2]|0))+ba;i:do{if((ca&128>>>((ba&7)>>>0)|0)==0){UGb(e|0,f|0,64)|0}else{da=8;ea=8;n=0;while(1){if((ea|0)==0){fa=0}else{_=c[o>>2]|0;$=c[t>>2]|0;j=c[q>>2]|0;m=j+(_>>>3)|0;aa=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(_&7);if(aa>>>0>134217727>>>0){m=aa>>>23;h=(d[1213744+m|0]|0)+_|0;c[o>>2]=$>>>0>h>>>0?h:$;ga=a[1139096+m|0]|0}else{m=aa>>>0>65535>>>0;h=m?aa>>>16:aa;aa=m?16:0;if((h&65280|0)==0){ha=aa;ia=h}else{ha=aa|8;ia=h>>>8}h=(d[1191992+ia|0]|0)+ha|0;aa=31-h+_|0;_=$>>>0>aa>>>0?aa:$;aa=j+(_>>>3)|0;j=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(_&7)>>>(h>>>0);aa=_+(32-h)|0;c[o>>2]=$>>>0>aa>>>0?aa:$;$=j>>>1;ga=(j&1|0)==0?$:-$|0}fa=ga+da&255}if((fa|n|0)==0){break}$=(fa|0)!=0?fa:da;a[(d[1075976+n|0]|0)+(i+64)|0]=$;j=n+1|0;if((j|0)<64){da=$;ea=fa;n=j}else{break i}}UGb(e|0,1402e3,64)|0}}while(0);fa=i+256|0;ga=c[o>>2]|0;ha=d[(c[q>>2]|0)+(ga>>>3)|0]|0;c[o>>2]=((ga|0)<(c[t>>2]|0))+ga;j:do{if((ha&128>>>((ga&7)>>>0)|0)==0){UGb(fa|0,Z|0,64)|0}else{ia=8;f=8;ba=0;while(1){if((f|0)==0){ja=0}else{ca=c[o>>2]|0;n=c[t>>2]|0;ea=c[q>>2]|0;da=ea+(ca>>>3)|0;j=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ca&7);if(j>>>0>134217727>>>0){da=j>>>23;$=(d[1213744+da|0]|0)+ca|0;c[o>>2]=n>>>0>$>>>0?$:n;ka=a[1139096+da|0]|0}else{da=j>>>0>65535>>>0;$=da?j>>>16:j;j=da?16:0;if(($&65280|0)==0){la=j;ma=$}else{la=j|8;ma=$>>>8}$=(d[1191992+ma|0]|0)+la|0;j=31-$+ca|0;ca=n>>>0>j>>>0?j:n;j=ea+(ca>>>3)|0;ea=(fe(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(ca&7)>>>($>>>0);j=ca+(32-$)|0;c[o>>2]=n>>>0>j>>>0?j:n;n=ea>>>1;ka=(ea&1|0)==0?n:-n|0}ja=ka+ia&255}if((ja|ba|0)==0){break}n=(ja|0)!=0?ja:ia;a[(d[1075976+ba|0]|0)+(i+256)|0]=n;ea=ba+1|0;if((ea|0)<64){ia=n;f=ja;ba=ea}else{break j}}UGb(fa|0,1402064,64)|0}}while(0);ja=i+128|0;ka=c[o>>2]|0;la=d[(c[q>>2]|0)+(ka>>>3)|0]|0;c[o>>2]=((ka|0)<(c[t>>2]|0))+ka;k:do{if((la&128>>>((ka&7)>>>0)|0)==0){UGb(ja|0,e|0,64)|0}else{ma=8;Z=8;ga=0;while(1){if((Z|0)==0){na=0}else{ha=c[o>>2]|0;ba=c[t>>2]|0;f=c[q>>2]|0;ia=f+(ha>>>3)|0;ea=(fe(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(ha&7);if(ea>>>0>134217727>>>0){ia=ea>>>23;n=(d[1213744+ia|0]|0)+ha|0;c[o>>2]=ba>>>0>n>>>0?n:ba;oa=a[1139096+ia|0]|0}else{ia=ea>>>0>65535>>>0;n=ia?ea>>>16:ea;ea=ia?16:0;if((n&65280|0)==0){pa=ea;qa=n}else{pa=ea|8;qa=n>>>8}n=(d[1191992+qa|0]|0)+pa|0;ea=31-n+ha|0;ha=ba>>>0>ea>>>0?ea:ba;ea=f+(ha>>>3)|0;f=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ha&7)>>>(n>>>0);ea=ha+(32-n)|0;c[o>>2]=ba>>>0>ea>>>0?ea:ba;ba=f>>>1;oa=(f&1|0)==0?ba:-ba|0}na=oa+ma&255}if((na|ga|0)==0){break}ba=(na|0)!=0?na:ma;a[(d[1075976+ga|0]|0)+(i+128)|0]=ba;f=ga+1|0;if((f|0)<64){ma=ba;Z=na;ga=f}else{break k}}UGb(ja|0,1402e3,64)|0}}while(0);ja=i+320|0;na=c[o>>2]|0;oa=d[(c[q>>2]|0)+(na>>>3)|0]|0;c[o>>2]=((na|0)<(c[t>>2]|0))+na;if((oa&128>>>((na&7)>>>0)|0)==0){UGb(ja|0,fa|0,64)|0;return}else{ra=8;sa=8;ta=0}while(1){if((sa|0)==0){ua=0}else{fa=c[o>>2]|0;na=c[t>>2]|0;oa=c[q>>2]|0;pa=oa+(fa>>>3)|0;qa=(fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(fa&7);if(qa>>>0>134217727>>>0){pa=qa>>>23;e=(d[1213744+pa|0]|0)+fa|0;c[o>>2]=na>>>0>e>>>0?e:na;va=a[1139096+pa|0]|0}else{pa=qa>>>0>65535>>>0;e=pa?qa>>>16:qa;qa=pa?16:0;if((e&65280|0)==0){wa=qa;xa=e}else{wa=qa|8;xa=e>>>8}e=(d[1191992+xa|0]|0)+wa|0;qa=31-e+fa|0;fa=na>>>0>qa>>>0?qa:na;qa=oa+(fa>>>3)|0;oa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(fa&7)>>>(e>>>0);qa=fa+(32-e)|0;c[o>>2]=na>>>0>qa>>>0?qa:na;na=oa>>>1;va=(oa&1|0)==0?na:-na|0}ua=va+ra&255}if((ua|ta|0)==0){break}na=(ua|0)!=0?ua:ra;a[(d[1075976+ta|0]|0)+(i+320)|0]=na;oa=ta+1|0;if((oa|0)<64){ra=na;sa=ua;ta=oa}else{ya=151;break}}if((ya|0)==151){return}UGb(ja|0,1402064,64)|0;return}function cea(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;f=i;g=b+1096|0;h=c[g>>2]|0;j=b+1104|0;k=c[j>>2]|0;l=b+1088|0;m=(c[l>>2]|0)+(h>>>3)|0;n=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(h&7);do{if(n>>>0>134217727>>>0){m=n>>>23;o=(d[1213744+m|0]|0)+h|0;c[g>>2]=k>>>0>o>>>0?o:k;p=d[1108392+m|0]|0}else{m=n>>>0>65535>>>0;o=m?n>>>16:n;q=m?16:0;if((o&65280|0)==0){r=q;s=o}else{r=q|8;s=o>>>8}o=(d[1191992+s|0]|0)+r<<1;q=63-o+h|0;c[g>>2]=k>>>0>q>>>0?q:k;q=(n>>>((o-31|0)>>>0))-1|0;if(!(q>>>0>255>>>0)){p=q;break}yDb(c[b>>2]|0,16,2192720,(t=i,i=i+8|0,c[t>>2]=q,t)|0);i=t;u=-1094995529;i=f;return u|0}}while(0);n=cEb(728)|0;k=n;if((n|0)==0){u=-12;i=f;return u|0}h=c[g>>2]|0;r=c[j>>2]|0;s=c[l>>2]|0;q=s+(h>>>3)|0;o=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(h&7)>>>23;q=(d[1213744+o|0]|0)+h|0;h=r>>>0>q>>>0?q:r;c[g>>2]=h;q=a[1108392+o|0]|0;o=q&255;m=n;c[m>>2]=o;do{if((q&255)>>>0>31>>>0){v=10}else{w=c[b+427476+(o<<2)>>2]|0;if((w|0)==0){v=10;break}x=w+1184|0;w=c[x>>2]|0;y=w*6|0;if((w|0)>14){yDb(c[b>>2]|0,16,2176368,(t=i,i=i+8|0,c[t>>2]=w,t)|0);i=t;break}if((w|0)==11|(w|0)==13){yDb(c[b>>2]|0,16,2165712,(t=i,i=i+8|0,c[t>>2]=w,t)|0);i=t;break}w=d[s+(h>>>3)|0]<<(h&7)>>>7;z=((h|0)<(r|0))+h|0;c[g>>2]=z;A=n+4|0;c[A>>2]=w&1;w=d[s+(z>>>3)|0]<<(z&7)>>>7;B=((z|0)<(r|0))+z|0;c[g>>2]=B;c[n+8>>2]=w&1;w=s+(B>>>3)|0;z=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(B&7);if(z>>>0>134217727>>>0){w=z>>>23;C=(d[1213744+w|0]|0)+B|0;D=r>>>0>C>>>0?C:r;c[g>>2]=D;E=d[1108392+w|0]|0;F=D}else{D=z>>>0>65535>>>0;w=D?z>>>16:z;C=D?16:0;if((w&65280|0)==0){G=C;H=w}else{G=C|8;H=w>>>8}w=(d[1191992+H|0]|0)+G<<1;C=63-w+B|0;B=r>>>0>C>>>0?C:r;c[g>>2]=B;E=(z>>>((w-31|0)>>>0))-1|0;F=B}B=n+12|0;c[B>>2]=E+1;if((E|0)>0){w=s+(F>>>3)|0;z=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(F&7);if(z>>>0>134217727>>>0){w=z>>>23;C=(d[1213744+w|0]|0)+F|0;c[g>>2]=r>>>0>C>>>0?C:r;I=d[1108392+w|0]|0}else{w=z>>>0>65535>>>0;C=w?z>>>16:z;D=w?16:0;if((C&65280|0)==0){J=D;K=C}else{J=D|8;K=C>>>8}C=(d[1191992+K|0]|0)+J<<1;D=63-C+F|0;c[g>>2]=r>>>0>D>>>0?D:r;I=(z>>>((C-31|0)>>>0))-1|0}c[n+16>>2]=I;yDb(c[b>>2]|0,16,2159112,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;L=c[g>>2]|0;M=c[j>>2]|0;N=c[l>>2]|0}else{L=F;M=r;N=s}C=N+(L>>>3)|0;z=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(L&7);if(z>>>0>134217727>>>0){C=z>>>23;D=(d[1213744+C|0]|0)+L|0;w=M>>>0>D>>>0?D:M;c[g>>2]=w;O=d[1108392+C|0]|0;P=w}else{w=z>>>0>65535>>>0;C=w?z>>>16:z;D=w?16:0;if((C&65280|0)==0){Q=D;R=C}else{Q=D|8;R=C>>>8}C=(d[1191992+R|0]|0)+Q<<1;D=63-C+L|0;w=M>>>0>D>>>0?D:M;c[g>>2]=w;O=(z>>>((C-31|0)>>>0))-1|0;P=w}w=n+20|0;c[w>>2]=O+1;C=N+(P>>>3)|0;z=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(P&7);if(z>>>0>134217727>>>0){C=z>>>23;D=(d[1213744+C|0]|0)+P|0;S=M>>>0>D>>>0?D:M;c[g>>2]=S;T=d[1108392+C|0]|0;U=S}else{S=z>>>0>65535>>>0;C=S?z>>>16:z;D=S?16:0;if((C&65280|0)==0){V=D;W=C}else{V=D|8;W=C>>>8}C=(d[1191992+W|0]|0)+V<<1;D=63-C+P|0;S=M>>>0>D>>>0?D:M;c[g>>2]=S;T=(z>>>((C-31|0)>>>0))-1|0;U=S}S=n+24|0;c[S>>2]=T+1;if(O>>>0>31>>>0|T>>>0>31>>>0){yDb(c[b>>2]|0,16,2152032,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}C=d[N+(U>>>3)|0]<<(U&7)>>>7;z=((U|0)<(M|0))+U|0;c[g>>2]=z;D=n+28|0;c[D>>2]=C&1;C=N+(z>>>3)|0;X=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(z&7)>>>30;C=z+2|0;z=M>>>0>C>>>0?C:M;c[g>>2]=z;c[n+32>>2]=X;X=N+(z>>>3)|0;C=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(z&7);if(C>>>0>134217727>>>0){X=C>>>23;Y=(d[1213744+X|0]|0)+z|0;Z=M>>>0>Y>>>0?Y:M;c[g>>2]=Z;_=a[1139096+X|0]|0;$=Z}else{Z=C>>>0>65535>>>0;X=Z?C>>>16:C;C=Z?16:0;if((X&65280|0)==0){aa=C;ba=X}else{aa=C|8;ba=X>>>8}X=(d[1191992+ba|0]|0)+aa|0;C=31-X+z|0;z=M>>>0>C>>>0?C:M;C=N+(z>>>3)|0;Z=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(z&7)>>>(X>>>0);C=z+(32-X)|0;X=M>>>0>C>>>0?C:M;c[g>>2]=X;C=Z>>>1;_=(Z&1|0)==0?C:-C|0;$=X}X=y-22|0;y=n+36|0;c[y>>2]=X+_;C=N+($>>>3)|0;Z=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<($&7);if(Z>>>0>134217727>>>0){C=Z>>>23;z=(d[1213744+C|0]|0)+$|0;Y=M>>>0>z>>>0?z:M;c[g>>2]=Y;ca=a[1139096+C|0]|0;da=Y}else{Y=Z>>>0>65535>>>0;C=Y?Z>>>16:Z;Z=Y?16:0;if((C&65280|0)==0){ea=Z;fa=C}else{ea=Z|8;fa=C>>>8}C=(d[1191992+fa|0]|0)+ea|0;Z=31-C+$|0;Y=M>>>0>Z>>>0?Z:M;Z=N+(Y>>>3)|0;z=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(Y&7)>>>(C>>>0);Z=Y+(32-C)|0;C=M>>>0>Z>>>0?Z:M;c[g>>2]=C;Z=z>>>1;ca=(z&1|0)==0?Z:-Z|0;da=C}C=n+40|0;c[C>>2]=X+ca;X=N+(da>>>3)|0;Z=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(da&7);if(Z>>>0>134217727>>>0){X=Z>>>23;z=(d[1213744+X|0]|0)+da|0;Y=M>>>0>z>>>0?z:M;c[g>>2]=Y;ga=a[1139096+X|0]|0;ha=Y}else{Y=Z>>>0>65535>>>0;X=Y?Z>>>16:Z;Z=Y?16:0;if((X&65280|0)==0){ia=Z;ja=X}else{ia=Z|8;ja=X>>>8}X=(d[1191992+ja|0]|0)+ia|0;Z=31-X+da|0;Y=M>>>0>Z>>>0?Z:M;Z=N+(Y>>>3)|0;z=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(Y&7)>>>(X>>>0);Z=Y+(32-X)|0;X=M>>>0>Z>>>0?Z:M;c[g>>2]=X;Z=z>>>1;ga=(z&1|0)==0?Z:-Z|0;ha=X}X=n+44|0;c[X>>2]=ga;Z=d[N+(ha>>>3)|0]<<(ha&7)>>>7;z=((ha|0)<(M|0))+ha|0;c[g>>2]=z;Y=n+52|0;c[Y>>2]=Z&1;Z=d[N+(z>>>3)|0]<<(z&7)>>>7;ka=((z|0)<(M|0))+z|0;c[g>>2]=ka;z=n+56|0;c[z>>2]=Z&1;Z=d[N+(ka>>>3)|0]<<(ka&7)>>>7;la=((ka|0)<(M|0))+ka|0;c[g>>2]=la;ka=n+60|0;c[ka>>2]=Z&1;Z=n+64|0;c[Z>>2]=0;c[b+428628>>2]=-1;ma=n+68|0;na=b+427476+(c[m>>2]<<2)|0;oa=c[na>>2]|0;UGb(ma|0,oa+672|0,96)|0;pa=n+164|0;UGb(pa|0,oa+768|0,384)|0;a:do{if((e-la|0)>0){qa=c[oa+4>>2]|0;do{if((qa|0)==88|(qa|0)==77|(qa|0)==66){if((c[oa+1196>>2]&7|0)==0){break}yDb(c[b>>2]|0,40,2088608,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ra=c[X>>2]|0;v=64;break a}}while(0);qa=d[N+(la>>>3)|0]<<(la&7)>>>7;c[g>>2]=((la|0)<(M|0))+la;c[Z>>2]=qa&1;bea(b,c[na>>2]|0,k,0,ma,pa);qa=c[g>>2]|0;sa=c[j>>2]|0;ta=c[l>>2]|0;ua=ta+(qa>>>3)|0;va=(fe(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(qa&7);if(va>>>0>134217727>>>0){ua=va>>>23;wa=(d[1213744+ua|0]|0)+qa|0;c[g>>2]=sa>>>0>wa>>>0?wa:sa;xa=a[1139096+ua|0]|0}else{ua=va>>>0>65535>>>0;wa=ua?va>>>16:va;va=ua?16:0;if((wa&65280|0)==0){ya=va;za=wa}else{ya=va|8;za=wa>>>8}wa=(d[1191992+za|0]|0)+ya|0;va=31-wa+qa|0;qa=sa>>>0>va>>>0?va:sa;va=ta+(qa>>>3)|0;ta=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(qa&7)>>>(wa>>>0);va=qa+(32-wa)|0;c[g>>2]=sa>>>0>va>>>0?va:sa;sa=ta>>>1;xa=(ta&1|0)==0?sa:-sa|0}c[n+48>>2]=xa;Aa=c[X>>2]|0;Ba=xa}else{ra=ga;v=64}}while(0);if((v|0)==64){c[n+48>>2]=ra;Aa=ra;Ba=ra}pa=c[x>>2]|0;ma=pa-8|0;na=ma*6|0;la=na+51|0;oa=na+52|0;if((oa|0)>0){na=0;do{sa=na+Aa|0;if((sa|0)<0){Ca=0}else{Ca=(sa|0)>(la|0)?la:sa}a[k+548+na|0]=a[1207816+(ma*88|0)+Ca|0]|0;na=na+1|0;}while((na|0)<(oa|0));oa=n+48|0;Da=c[oa>>2]|0;Ea=c[x>>2]|0;Fa=oa}else{Da=Ba;Ea=pa;Fa=n+48|0}oa=Ea-8|0;na=oa*6|0;ma=na+51|0;la=na+52|0;if((la|0)>0){na=0;do{sa=na+Da|0;if((sa|0)<0){Ga=0}else{Ga=(sa|0)>(ma|0)?ma:sa}a[k+636+na|0]=a[1207816+(oa*88|0)+Ga|0]|0;na=na+1|0;}while((na|0)<(la|0))}la=c[X>>2]|0;na=c[Fa>>2]|0;if((la|0)!=(na|0)){c[n+724>>2]=1}oa=c[b>>2]|0;if((c[oa+688>>2]&1|0)!=0){ma=c[m>>2]|0;pa=(c[A>>2]|0)!=0?2139368:2133080;x=c[B>>2]|0;sa=c[w>>2]|0;ta=c[S>>2]|0;va=(c[D>>2]|0)!=0?2126656:9203456;wa=c[y>>2]|0;qa=c[C>>2]|0;ua=(c[Y>>2]|0)!=0?2120832:9203456;Ha=(c[z>>2]|0)!=0?2114704:9203456;Ia=(c[ka>>2]|0)!=0?2100504:9203456;Ja=(c[Z>>2]|0)!=0?2093816:9203456;yDb(oa,48,2145152,(t=i,i=i+120|0,c[t>>2]=p,c[t+8>>2]=ma,c[t+16>>2]=pa,c[t+24>>2]=x,c[t+32>>2]=sa,c[t+40>>2]=ta,c[t+48>>2]=va,c[t+56>>2]=wa,c[t+64>>2]=qa,c[t+72>>2]=la,c[t+80>>2]=na,c[t+88>>2]=ua,c[t+96>>2]=Ha,c[t+104>>2]=Ia,c[t+112>>2]=Ja,t)|0);i=t}Ja=b+427604+(p<<2)|0;ZDb(c[Ja>>2]|0);c[Ja>>2]=k;u=0;i=f;return u|0}}while(0);if((v|0)==10){yDb(c[b>>2]|0,16,2283208,(t=i,i=i+8|0,c[t>>2]=o,t)|0);i=t}ZDb(n);u=-1;i=f;return u|0}function dea(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=a+1096|0;g=c[f>>2]|0;h=a+1104|0;j=c[h>>2]|0;k=c[a+1088>>2]|0;l=k+(g>>>3)|0;m=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(g&7)>>>23;l=(d[1213744+m|0]|0)+g|0;g=j>>>0>l>>>0?l:j;c[f>>2]=g;l=(d[1108392+m|0]|0)+1|0;if(l>>>0>32>>>0){yDb(c[a>>2]|0,16,2060456,(a=i,i=i+8|0,c[a>>2]=l,a)|0);i=a;n=-1094995529;i=e;return n|0}a=g+4|0;g=(j>>>0>a>>>0?a:j)+4|0;a=j>>>0>g>>>0?g:j;c[f>>2]=a;g=0;m=a;do{a=k+(m>>>3)|0;o=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(m&7);a=m+16|0;p=j>>>0>a>>>0?a:j;a=k+(p>>>3)|0;q=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(p&7)>>>16|o&-65536;p=q>>>0>65535>>>0;a=p?o>>>16:q;q=p?16:0;if((a&65280|0)==0){r=q;s=a}else{r=q|8;s=a>>>8}a=31-r-(d[1191992+s|0]|0)|0;q=-m|0;p=j-m|0;if((a|0)<(q|0)){t=q}else{t=(p|0)<(a|0)?p:a}p=t+m|0;c[f>>2]=p;q=a+1|0;do{if((q|0)==0){u=p}else{if((q|0)<26){o=p+q|0;v=j>>>0>o>>>0?o:j;c[f>>2]=v;u=v;break}else{v=p+16|0;o=a-15+(j>>>0>v>>>0?v:j)|0;v=j>>>0>o>>>0?o:j;c[f>>2]=v;u=v;break}}}while(0);a=k+(u>>>3)|0;p=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(u&7);a=u+16|0;q=j>>>0>a>>>0?a:j;a=k+(q>>>3)|0;v=(fe(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(q&7)>>>16|p&-65536;q=v>>>0>65535>>>0;a=q?p>>>16:v;v=q?16:0;if((a&65280|0)==0){w=v;x=a}else{w=v|8;x=a>>>8}a=31-w-(d[1191992+x|0]|0)|0;v=-u|0;q=j-u|0;if((a|0)<(v|0)){y=v}else{y=(q|0)<(a|0)?q:a}q=y+u|0;c[f>>2]=q;v=a+1|0;do{if((v|0)==0){z=q}else{if((v|0)<26){p=q+v|0;o=j>>>0>p>>>0?p:j;c[f>>2]=o;z=o;break}else{o=q+16|0;p=a-15+(j>>>0>o>>>0?o:j)|0;o=j>>>0>p>>>0?p:j;c[f>>2]=o;z=o;break}}}while(0);m=((z|0)<(j|0))+z|0;c[f>>2]=m;g=g+1|0;}while((g|0)<(l|0));g=k+(m>>>3)|0;z=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(m&7)>>>27;g=m+5|0;c[f>>2]=j>>>0>g>>>0?g:j;c[b+1172>>2]=z+1;z=c[f>>2]|0;j=c[h>>2]|0;g=k+(z>>>3)|0;m=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(z&7)>>>27;g=z+5|0;c[f>>2]=j>>>0>g>>>0?g:j;c[b+1176>>2]=m+1;m=c[f>>2]|0;j=c[h>>2]|0;g=k+(m>>>3)|0;z=(fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(m&7)>>>27;g=m+5|0;c[f>>2]=j>>>0>g>>>0?g:j;c[b+1180>>2]=z+1;z=c[f>>2]|0;j=c[h>>2]|0;h=k+(z>>>3)|0;k=(fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(z&7)>>>27;h=z+5|0;c[f>>2]=j>>>0>h>>>0?h:j;c[b+1164>>2]=k;c[b+1168>>2]=l;n=0;i=e;return n|0}function eea(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;i=i+2360|0;d=b|0;e=b+128|0;f=b+136|0;if((c[a+177080>>2]|0)!=3){g=a+177100|0;h=fea(a+428696|0,32,a+571032|0,c[a+572240>>2]|0,0,c[g>>2]|0)|0;j=(fea(a+428696+(h*2224|0)|0,32-h|0,a+571160|0,16,1,c[g>>2]|0)|0)+h|0;if((j|0)>=33){yDb(0,0,2282312,(k=i,i=i+24|0,c[k>>2]=2324288,c[k+8>>2]=2187616,c[k+16>>2]=167,k)|0);i=k;Cd();return 0}h=c[a+199420>>2]|0;if(!(j>>>0<h>>>0)){i=b;return 0}TGb(a+428696+(j*2224|0)|0,0,(h-j|0)*2224|0|0)|0;i=b;return 0}j=a+177100|0;h=c[j>>2]|0;if((h|0)==3){l=(c[a+2524>>2]|0)+1612|0}else{l=(c[a+2524>>2]|0)+1604+(((h|0)==2)<<2)|0}h=c[l>>2]|0;l=d|0;g=a+572240|0;m=a+571160|0;n=0;while(1){o=c[g>>2]|0;p=n^1;q=(n|0)!=1?-2147483648:2147483647;a:do{if((o|0)>0){r=h;s=0;while(1){t=d+(s<<2)|0;u=0;v=q;while(1){w=c[a+571032+(u<<2)>>2]|0;x=c[w+1612>>2]|0;do{if(((x|0)>(r|0)|0)==(p|0)){y=v}else{if(((x|0)<(v|0)|0)==(p|0)){y=v;break}c[t>>2]=w;y=x}}while(0);x=u+1|0;if((x|0)<(o|0)){u=x;v=y}else{break}}if((y|0)==(q|0)){break}r=(c[(c[t>>2]|0)+1612>>2]|0)-p|0;s=s+1|0}r=(n|0)!=0?-2147483648:2147483647;v=h;u=0;while(1){x=d+(u+s<<2)|0;w=0;z=r;while(1){A=c[a+571032+(w<<2)>>2]|0;B=c[A+1612>>2]|0;do{if(((B|0)>(v|0)|0)==(n|0)){C=z}else{if(((B|0)<(z|0)|0)==(n|0)){C=z;break}c[x>>2]=A;C=B}}while(0);B=w+1|0;if((B|0)<(o|0)){w=B;z=C}else{break}}if((C|0)==(r|0)){D=u;E=s;break a}v=(c[(c[x>>2]|0)+1612>>2]|0)-n|0;u=u+1|0}}else{D=0;E=0}}while(0);o=D+E|0;if((o|0)>=33){F=23;break}p=fea(a+428696+(n*71168|0)|0,32,l,o,0,c[j>>2]|0)|0;o=(fea(a+428696+(n*71168|0)+(p*2224|0)|0,32-p|0,m,16,1,c[j>>2]|0)|0)+p|0;if((o|0)>=33){F=25;break}p=c[a+199420+(n<<2)>>2]|0;if(o>>>0<p>>>0){TGb(a+428696+(n*71168|0)+(o*2224|0)|0,0,(p-o|0)*2224|0|0)|0}c[e+(n<<2)>>2]=o;o=n+1|0;if((o|0)<2){n=o}else{F=29;break}}if((F|0)==23){yDb(0,0,2282312,(k=i,i=i+24|0,c[k>>2]=2324288,c[k+8>>2]=2187616,c[k+16>>2]=136,k)|0);i=k;Cd();return 0}else if((F|0)==25){yDb(0,0,2282312,(k=i,i=i+24|0,c[k>>2]=2324288,c[k+8>>2]=2187616,c[k+16>>2]=143,k)|0);i=k;Cd();return 0}else if((F|0)==29){F=c[e>>2]|0;k=c[e+4>>2]|0;if((F|0)==(k|0)&(k|0)>1){G=0}else{i=b;return 0}while(1){if((G|0)>=(F|0)){break}if((c[c[a+428696+(G*2224|0)+360>>2]>>2]|0)==(c[c[a+499864+(G*2224|0)+360>>2]>>2]|0)){G=G+1|0}else{break}}if((G|0)!=(F|0)){i=b;return 0}F=a+499864|0;G=f;k=F;UGb(G|0,k|0,2224)|0;c[f+64>>2]=f;c[f+1496>>2]=f;f=a+502088|0;e=f;UGb(k|0,e|0,2224)|0;c[a+499928>>2]=F;c[a+501360>>2]=F;UGb(e|0,G|0,2224)|0;c[a+502152>>2]=f;c[a+503584>>2]=f;i=b;return 0}return 0}function fea(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;if((e|0)<=0){j=0;i=h;return j|0}k=(f|0)==0;f=(g|0)==3;l=(g|0)==2;m=l&1;n=g^3;o=(g|0)==0;p=(g|0)==1;q=p&1;r=0;s=0;t=0;a:while(1){b:do{if((s|0)<(e|0)){u=s;while(1){v=c[d+(u<<2)>>2]|0;if((v|0)!=0){if((c[v+2192>>2]&g|0)!=0){w=u;x=1;break b}}v=u+1|0;if((v|0)<(e|0)){u=v}else{w=v;x=0;break}}}else{w=s;x=0}}while(0);c:do{if((r|0)<(e|0)){u=r;while(1){v=c[d+(u<<2)>>2]|0;if((v|0)!=0){if((c[v+2192>>2]&n|0)!=0){y=u;z=1;break c}}v=u+1|0;if((v|0)<(e|0)){u=v}else{y=v;z=0;break}}}else{y=r;z=0}}while(0);do{if(x){if((t|0)>=(b|0)){A=13;break a}u=c[d+(w<<2)>>2]|0;if(k){B=c[u+1616>>2]|0}else{B=w}c[u+1624>>2]=B;v=t+1|0;C=a+(t*2224|0)|0;D=w+1|0;if((c[u+2192>>2]&g|0)==0){E=v;F=D;break}UGb(C|0,u|0,2224)|0;u=C|0;c[a+(t*2224|0)+64>>2]=u;c[a+(t*2224|0)+1496>>2]=C;if(f){E=v;F=D;break}C=a+(t*2224|0)+2192|0;G=a+(t*2224|0)+32|0;H=c[G>>2]|0;if(l){c[u>>2]=(c[u>>2]|0)+H;c[G>>2]=H<<1;u=a+(t*2224|0)+36|0;I=c[u>>2]|0;J=a+(t*2224|0)+4|0;c[J>>2]=(c[J>>2]|0)+I;c[u>>2]=I<<1;I=a+(t*2224|0)+40|0;u=c[I>>2]|0;J=a+(t*2224|0)+8|0;c[J>>2]=(c[J>>2]|0)+u;c[I>>2]=u<<1;u=a+(t*2224|0)+44|0;I=c[u>>2]|0;J=a+(t*2224|0)+12|0;c[J>>2]=(c[J>>2]|0)+I;c[C>>2]=2;c[u>>2]=I<<1}else{c[G>>2]=H<<1;H=a+(t*2224|0)+36|0;c[H>>2]=c[H>>2]<<1;H=a+(t*2224|0)+40|0;c[H>>2]=c[H>>2]<<1;c[C>>2]=g;C=a+(t*2224|0)+44|0;c[C>>2]=c[C>>2]<<1}c[a+(t*2224|0)+1612>>2]=c[a+(t*2224|0)+1604+(m<<2)>>2];C=a+(t*2224|0)+1624|0;c[C>>2]=c[C>>2]<<1|1;E=v;F=D}else{E=t;F=w}}while(0);do{if(z){if((E|0)>=(b|0)){A=25;break a}D=c[d+(y<<2)>>2]|0;if(k){K=c[D+1616>>2]|0}else{K=y}c[D+1624>>2]=K;v=E+1|0;C=a+(E*2224|0)|0;H=y+1|0;if((c[D+2192>>2]&n|0)==0){L=v;M=H;break}UGb(C|0,D|0,2224)|0;D=C|0;c[a+(E*2224|0)+64>>2]=D;c[a+(E*2224|0)+1496>>2]=C;if(o){L=v;M=H;break}C=a+(E*2224|0)+2192|0;G=a+(E*2224|0)+32|0;I=c[G>>2]|0;if(p){c[D>>2]=(c[D>>2]|0)+I;c[G>>2]=I<<1;D=a+(E*2224|0)+36|0;u=c[D>>2]|0;J=a+(E*2224|0)+4|0;c[J>>2]=(c[J>>2]|0)+u;c[D>>2]=u<<1;u=a+(E*2224|0)+40|0;D=c[u>>2]|0;J=a+(E*2224|0)+8|0;c[J>>2]=(c[J>>2]|0)+D;c[u>>2]=D<<1;D=a+(E*2224|0)+44|0;u=c[D>>2]|0;J=a+(E*2224|0)+12|0;c[J>>2]=(c[J>>2]|0)+u;c[C>>2]=2;c[D>>2]=u<<1}else{c[G>>2]=I<<1;I=a+(E*2224|0)+36|0;c[I>>2]=c[I>>2]<<1;I=a+(E*2224|0)+40|0;c[I>>2]=c[I>>2]<<1;c[C>>2]=n;C=a+(E*2224|0)+44|0;c[C>>2]=c[C>>2]<<1}c[a+(E*2224|0)+1612>>2]=c[a+(E*2224|0)+1604+(q<<2)>>2];C=a+(E*2224|0)+1624|0;c[C>>2]=c[C>>2]<<1;L=v;M=H}else{L=E;M=y}}while(0);if((F|0)<(e|0)|(M|0)<(e|0)){r=M;s=F;t=L}else{j=L;A=34;break}}if((A|0)==13){yDb(0,0,2282312,(N=i,i=i+24|0,c[N>>2]=2120816,c[N+8>>2]=2187616,c[N+16>>2]=83,N)|0);i=N;Cd();return 0}else if((A|0)==25){yDb(0,0,2282312,(N=i,i=i+24|0,c[N>>2]=2120816,c[N+8>>2]=2187616,c[N+16>>2]=88,N)|0);i=N;Cd();return 0}else if((A|0)==34){i=h;return j|0}return 0}function gea(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;e=i;f=b|0;g=c[f>>2]|0;do{if((c[g+688>>2]&2048|0)!=0){yDb(g,48,2126632,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=b+572240|0;if((c[j>>2]|0)==0){break}else{k=0}do{l=c[b+571032+(k<<2)>>2]|0;m=c[l+1616>>2]|0;n=c[l+1612>>2]|0;o=c[l>>2]|0;yDb(c[f>>2]|0,48,2133056,(h=i,i=i+32|0,c[h>>2]=k,c[h+8>>2]=m,c[h+16>>2]=n,c[h+24>>2]=o,h)|0);i=h;k=k+1|0;}while(k>>>0<(c[j>>2]|0)>>>0)}}while(0);k=c[f>>2]|0;if((c[k+688>>2]&2048|0)!=0){yDb(k,48,2139344,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;k=0;do{g=c[b+571160+(k<<2)>>2]|0;if((g|0)!=0){j=c[g+1616>>2]|0;o=c[g+1612>>2]|0;n=c[g>>2]|0;yDb(c[f>>2]|0,48,2133056,(h=i,i=i+32|0,c[h>>2]=k,c[h+8>>2]=j,c[h+16>>2]=o,c[h+24>>2]=n,h)|0);i=h}k=k+1|0;}while(k>>>0<16>>>0)}k=b+199428|0;if((c[k>>2]|0)==0){p=0;i=e;return p|0}n=b+1096|0;o=b+1088|0;j=b+1104|0;g=b+428680|0;m=b+428684|0;l=b+177100|0;q=b+572240|0;r=0;a:while(1){s=b+199420+(r<<2)|0;if((c[s>>2]|0)!=0){t=0;do{u=b+199440+(r*106752|0)+(t*2224|0)|0;UGb(u|0,b+428696+(r*71168|0)+(t*2224|0)|0,2224)|0;c[b+199440+(r*106752|0)+(t*2224|0)+64>>2]=u;c[b+199440+(r*106752|0)+(t*2224|0)+1496>>2]=u;t=t+1|0;}while(t>>>0<(c[s>>2]|0)>>>0)}t=c[n>>2]|0;u=c[o>>2]|0;v=d[u+(t>>>3)|0]|0;w=c[j>>2]|0;x=((t|0)<(w|0))+t|0;c[n>>2]=x;b:do{if((v&128>>>((t&7)>>>0)|0)!=0){y=0;z=c[g>>2]|0;A=x;B=w;C=u;while(1){D=C+(A>>>3)|0;E=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(A&7)>>>23;D=(d[1213744+E|0]|0)+A|0;F=B>>>0>D>>>0?D:B;c[n>>2]=F;D=a[1108392+E|0]|0;E=D&255;if(D<<24>>24==3){break b}if(!(y>>>0<(c[s>>2]|0)>>>0)){G=19;break a}do{if((E|0)==2){H=C+(F>>>3)|0;I=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7);if(I>>>0>134217727>>>0){H=I>>>23;J=(d[1213744+H|0]|0)+F|0;c[n>>2]=B>>>0>J>>>0?J:B;K=d[1108392+H|0]|0}else{H=I>>>0>65535>>>0;J=H?I>>>16:I;L=H?16:0;if((J&65280|0)==0){M=L;N=J}else{M=L|8;N=J>>>8}J=(d[1191992+N|0]|0)+M<<1;L=63-J+F|0;c[n>>2]=B>>>0>L>>>0?L:B;K=(I>>>((J-31|0)>>>0))-1|0}J=c[l>>2]|0;if((J|0)==3){O=K;P=3}else{O=K>>1;P=(K&1|0)==0?J^3:J}if((O|0)>31){G=43;break a}J=c[b+571160+(O<<2)>>2]|0;if((J|0)==0){Q=z;G=51;break}if((c[J+2192>>2]&P|0)==0){Q=z;G=51;break}c[J+1624>>2]=K;R=P;S=z;T=J;G=47}else if((E|0)==0|(E|0)==1){J=C+(F>>>3)|0;I=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(F&7);if(I>>>0>134217727>>>0){J=I>>>23;L=(d[1213744+J|0]|0)+F|0;c[n>>2]=B>>>0>L>>>0?L:B;U=d[1108392+J|0]|0}else{J=I>>>0>65535>>>0;L=J?I>>>16:I;H=J?16:0;if((L&65280|0)==0){V=H;W=L}else{V=H|8;W=L>>>8}L=(d[1191992+W|0]|0)+V<<1;H=63-L+F|0;c[n>>2]=B>>>0>H>>>0?H:B;U=(I>>>((L-31|0)>>>0))-1|0}L=U+1|0;I=c[m>>2]|0;if(L>>>0>I>>>0){G=27;break a}H=(D<<24>>24==0?~U:L)+z&I-1;I=c[l>>2]|0;if((I|0)==3){X=H;Y=3}else{X=H>>1;Y=(H&1|0)==0?I^3:I}I=c[q>>2]|0;L=I-1|0;c:do{if((I|0)>0){J=L;while(1){Z=c[b+571032+(J<<2)>>2]|0;if((c[Z+1616>>2]|0)==(X|0)){if((c[Z+2192>>2]&Y|0)!=0){break}}_=J-1|0;if((J|0)>0){J=_}else{$=Z;aa=_;break c}}c[Z+1624>>2]=H;$=Z;aa=J}else{$=0;aa=L}}while(0);if((aa|0)<0){Q=H;G=51}else{R=Y;S=H;T=$;G=47}}else{G=49;break a}}while(0);do{if((G|0)==47){G=0;D=T+1624|0;F=y+1|0;E=c[s>>2]|0;do{if(F>>>0<E>>>0){L=c[T+1628>>2]|0;I=y;_=F;while(1){if((L|0)==(c[b+199440+(r*106752|0)+(I*2224|0)+1628>>2]|0)){if((c[D>>2]|0)==(c[b+199440+(r*106752|0)+(I*2224|0)+1624>>2]|0)){ba=I;break}}ca=_+1|0;if(ca>>>0<E>>>0){I=_;_=ca}else{ba=_;break}}if((ba|0)>(y|0)){da=ba}else{break}while(1){_=b+199440+(r*106752|0)+(da*2224|0)|0;I=da-1|0;UGb(_|0,b+199440+(r*106752|0)+(I*2224|0)|0,2224)|0;c[b+199440+(r*106752|0)+(da*2224|0)+64>>2]=_;c[b+199440+(r*106752|0)+(da*2224|0)+1496>>2]=_;if((I|0)>(y|0)){da=I}else{break}}}}while(0);E=b+199440+(r*106752|0)+(y*2224|0)|0;UGb(E|0,T|0,2224)|0;D=E|0;c[b+199440+(r*106752|0)+(y*2224|0)+64>>2]=D;c[b+199440+(r*106752|0)+(y*2224|0)+1496>>2]=E;if((c[l>>2]|0)==3){ea=S;fa=F;break}E=(R|0)==2;H=b+199440+(r*106752|0)+(y*2224|0)+2192|0;I=b+199440+(r*106752|0)+(y*2224|0)+32|0;_=c[I>>2]|0;if(E){c[D>>2]=(c[D>>2]|0)+_;c[I>>2]=_<<1;D=b+199440+(r*106752|0)+(y*2224|0)+36|0;L=c[D>>2]|0;J=b+199440+(r*106752|0)+(y*2224|0)+4|0;c[J>>2]=(c[J>>2]|0)+L;c[D>>2]=L<<1;L=b+199440+(r*106752|0)+(y*2224|0)+40|0;D=c[L>>2]|0;J=b+199440+(r*106752|0)+(y*2224|0)+8|0;c[J>>2]=(c[J>>2]|0)+D;c[L>>2]=D<<1;D=b+199440+(r*106752|0)+(y*2224|0)+44|0;L=c[D>>2]|0;J=b+199440+(r*106752|0)+(y*2224|0)+12|0;c[J>>2]=(c[J>>2]|0)+L;c[H>>2]=2;c[D>>2]=L<<1}else{c[I>>2]=_<<1;_=b+199440+(r*106752|0)+(y*2224|0)+36|0;c[_>>2]=c[_>>2]<<1;_=b+199440+(r*106752|0)+(y*2224|0)+40|0;c[_>>2]=c[_>>2]<<1;c[H>>2]=R;H=b+199440+(r*106752|0)+(y*2224|0)+44|0;c[H>>2]=c[H>>2]<<1}c[b+199440+(r*106752|0)+(y*2224|0)+1612>>2]=c[b+199440+(r*106752|0)+(y*2224|0)+1604+((E&1)<<2)>>2];ea=S;fa=F}else if((G|0)==51){G=0;yDb(c[f>>2]|0,16,1940232,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;TGb(b+199440+(r*106752|0)+(y*2224|0)|0,0,2224)|0;ea=Q;fa=y+1|0}}while(0);y=fa;z=ea;A=c[n>>2]|0;B=c[j>>2]|0;C=c[o>>2]|0}}}while(0);s=r+1|0;ga=c[k>>2]|0;if(s>>>0<ga>>>0){r=s}else{G=12;break}}if((G|0)==12){if((ga|0)==0){p=0;i=e;return p|0}ga=b+177100|0;r=0;d:while(1){o=b+199420+(r<<2)|0;j=b+428696+(r*71168|0)+1612|0;n=b+428696+(r*71168|0)+360|0;ea=b+428696+(r*71168|0)+2192|0;fa=b+428696+(r*71168|0)|0;Q=0;while(1){if(!(Q>>>0<(c[o>>2]|0)>>>0)){break}S=b+199440+(r*106752|0)+(Q*2224|0)|0;R=S|0;l=b+199440+(r*106752|0)+(Q*2224|0)+360|0;T=c[l>>2]|0;do{if((T|0)==0){G=69}else{if((c[ga>>2]|0)!=3){ha=T;break}if((c[b+199440+(r*106752|0)+(Q*2224|0)+2192>>2]&3|0)==3){ha=T}else{G=69}}}while(0);if((G|0)==69){G=0;yDb(c[f>>2]|0,16,1916024,(h=i,i=i+8|0,c[h>>2]=c[j>>2],h)|0);i=h;c[b+571360>>2]=-2147483648;c[b+571364>>2]=-2147483648;c[b+571368>>2]=-2147483648;c[b+571372>>2]=-2147483648;c[b+571376>>2]=-2147483648;c[b+571380>>2]=-2147483648;c[b+571384>>2]=-2147483648;c[b+571388>>2]=-2147483648;c[b+571392>>2]=-2147483648;c[b+571396>>2]=-2147483648;c[b+571400>>2]=-2147483648;c[b+571404>>2]=-2147483648;c[b+571408>>2]=-2147483648;c[b+571412>>2]=-2147483648;c[b+571416>>2]=-2147483648;c[b+571420>>2]=-2147483648;if((c[n>>2]|0)==0){p=-1;G=76;break d}if((c[ga>>2]|0)==3){if((c[ea>>2]&3|0)!=3){p=-1;G=76;break d}}UGb(S|0,fa|0,2224)|0;c[b+199440+(r*106752|0)+(Q*2224|0)+64>>2]=S;c[b+199440+(r*106752|0)+(Q*2224|0)+1496>>2]=R;ha=c[l>>2]|0}if((ZAb(ha)|0)>0){Q=Q+1|0}else{G=74;break d}}Q=r+1|0;if(Q>>>0<(c[k>>2]|0)>>>0){r=Q}else{p=0;G=76;break}}if((G|0)==74){yDb(0,0,2282312,(h=i,i=i+24|0,c[h>>2]=1895424,c[h+8>>2]=2187616,c[h+16>>2]=340,h)|0);i=h;Cd();return 0}else if((G|0)==76){i=e;return p|0}}else if((G|0)==19){yDb(c[f>>2]|0,16,2110344,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-1;i=e;return p|0}else if((G|0)==27){yDb(c[f>>2]|0,16,2051992,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-1094995529;i=e;return p|0}else if((G|0)==43){yDb(c[f>>2]|0,16,2006592,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-1094995529;i=e;return p|0}else if((G|0)==49){yDb(c[f>>2]|0,16,1968744,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-1094995529;i=e;return p|0}return 0}function hea(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+199428|0;d=c[b>>2]|0;if((d|0)==0){return}else{e=0;f=d}while(1){d=a+199420+(e<<2)|0;if((c[d>>2]|0)==0){g=f}else{h=0;do{i=h<<1;j=i+16|0;k=a+199440+(e*106752|0)+(j*2224|0)|0;l=k;UGb(l|0,a+199440+(e*106752|0)+(h*2224|0)|0,2224)|0;c[a+199440+(e*106752|0)+(j*2224|0)+64>>2]=k;c[a+199440+(e*106752|0)+(j*2224|0)+1496>>2]=k;k=a+199440+(e*106752|0)+(j*2224|0)+32|0;c[k>>2]=c[k>>2]<<1;k=a+199440+(e*106752|0)+(j*2224|0)+36|0;c[k>>2]=c[k>>2]<<1;k=a+199440+(e*106752|0)+(j*2224|0)+40|0;c[k>>2]=c[k>>2]<<1;c[a+199440+(e*106752|0)+(j*2224|0)+2192>>2]=1;c[a+199440+(e*106752|0)+(j*2224|0)+1612>>2]=c[a+199440+(e*106752|0)+(j*2224|0)+1604>>2];k=i+17|0;i=a+199440+(e*106752|0)+(k*2224|0)|0;UGb(i|0,l|0,2224)|0;c[a+199440+(e*106752|0)+(k*2224|0)+64>>2]=i;c[a+199440+(e*106752|0)+(k*2224|0)+1496>>2]=i;i=a+199440+(e*106752|0)+(k*2224|0)|0;c[i>>2]=(c[i>>2]|0)+(c[a+199440+(e*106752|0)+(h*2224|0)+32>>2]|0);i=a+199440+(e*106752|0)+(k*2224|0)+4|0;c[i>>2]=(c[i>>2]|0)+(c[a+199440+(e*106752|0)+(h*2224|0)+36>>2]|0);i=a+199440+(e*106752|0)+(k*2224|0)+8|0;c[i>>2]=(c[i>>2]|0)+(c[a+199440+(e*106752|0)+(h*2224|0)+40>>2]|0);c[a+199440+(e*106752|0)+(k*2224|0)+2192>>2]=2;c[a+199440+(e*106752|0)+(k*2224|0)+1612>>2]=c[a+199440+(e*106752|0)+(k*2224|0)+1608>>2];i=c[a+177136+(h<<4)+(e<<3)>>2]|0;c[a+177136+(k<<4)+(e<<3)>>2]=i;c[a+177136+(j<<4)+(e<<3)>>2]=i;i=c[a+177136+(h<<4)+(e<<3)+4>>2]|0;c[a+177136+(k<<4)+(e<<3)+4>>2]=i;c[a+177136+(j<<4)+(e<<3)+4>>2]=i;i=c[a+177904+(h<<5)+(e<<4)>>2]|0;c[a+177904+(k<<5)+(e<<4)>>2]=i;c[a+177904+(j<<5)+(e<<4)>>2]=i;i=c[a+177904+(h<<5)+(e<<4)+4>>2]|0;c[a+177904+(k<<5)+(e<<4)+4>>2]=i;c[a+177904+(j<<5)+(e<<4)+4>>2]=i;i=c[a+177904+(h<<5)+(e<<4)+8>>2]|0;c[a+177904+(k<<5)+(e<<4)+8>>2]=i;c[a+177904+(j<<5)+(e<<4)+8>>2]=i;i=c[a+177904+(h<<5)+(e<<4)+12>>2]|0;c[a+177904+(k<<5)+(e<<4)+12>>2]=i;c[a+177904+(j<<5)+(e<<4)+12>>2]=i;h=h+1|0;}while(h>>>0<(c[d>>2]|0)>>>0);g=c[b>>2]|0}d=e+1|0;if(d>>>0<g>>>0){e=d;f=g}else{break}}return}function iea(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=a+572236|0;d=0;do{e=a+571160+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){g=f+2192|0;c[g>>2]=0;h=0;while(1){i=c[a+571288+(h<<2)>>2]|0;if((i|0)==0){break}if((i|0)==(f|0)){j=7;break}else{h=h+1|0}}if((j|0)==7){j=0;c[g>>2]=4}c[f+1628>>2]=0;c[e>>2]=0;c[b>>2]=(c[b>>2]|0)-1}d=d+1|0;}while((d|0)<16);d=a+572240|0;if((c[d>>2]|0)>0){k=0}else{c[d>>2]=0;l=a+428696|0;m=l;TGb(m|0,0,142336)|0;n=a+199440|0;o=n;TGb(o|0,0,213504)|0;return}do{b=a+571032+(k<<2)|0;h=c[b>>2]|0;i=h+2192|0;c[i>>2]=0;p=0;while(1){q=c[a+571288+(p<<2)>>2]|0;if((q|0)==0){break}if((q|0)==(h|0)){j=13;break}else{p=p+1|0}}if((j|0)==13){j=0;c[i>>2]=4}c[b>>2]=0;k=k+1|0;}while((k|0)<(c[d>>2]|0));c[d>>2]=0;l=a+428696|0;m=l;TGb(m|0,0,142336)|0;n=a+199440|0;o=n;TGb(o|0,0,213504)|0;return}function jea(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+792|0;e=d|0;f=(b|0)!=0;b=f?a+571436|0:e;g=c[a+572240>>2]|0;a:do{if((g|0)==0){h=0}else{if(((c[a+572236>>2]|0)+g|0)<(c[a+6172>>2]|0)){h=0;break}j=a+177100|0;do{if((c[j>>2]|0)!=3){if((c[a+177104>>2]|0)!=0){break}if((c[(c[a+2524>>2]|0)+2192>>2]|0)!=0){h=0;break a}}}while(0);c[b>>2]=1;k=c[(c[a+571032+(g-1<<2)>>2]|0)+1616>>2]|0;l=b+4|0;c[l>>2]=k;if((c[j>>2]|0)==3){h=1;break}m=k<<1;c[l>>2]=m;c[b+12>>2]=1;c[b+16>>2]=m|1;h=2}}while(0);b=a+572228|0;if(f){c[b>>2]=h;n=0;i=d;return n|0}f=c[b>>2]|0;do{if((h|0)==(f|0)){g=0;while(1){if((g|0)>=(h|0)){n=0;o=15;break}p=c[a+571436+(g*12|0)>>2]|0;q=c[e+(g*12|0)>>2]|0;if((p|0)==(q|0)){g=g+1|0}else{o=13;break}}if((o|0)==13){yDb(0,16,2145096,(r=i,i=i+24|0,c[r>>2]=p,c[r+8>>2]=q,c[r+16>>2]=g,r)|0);i=r;s=c[b>>2]|0;break}else if((o|0)==15){i=d;return n|0}}else{s=f}}while(0);yDb(c[a>>2]|0,16,2352672,(r=i,i=i+16|0,c[r>>2]=h,c[r+8>>2]=s,r)|0);i=r;n=-1094995529;i=d;return n|0}function kea(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0;e=i;f=a|0;g=c[f>>2]|0;if((c[g+688>>2]&2048|0)!=0&(d|0)==0){yDb(g,48,2332488,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}do{if((d|0)>0){g=a+572240|0;j=a+572236|0;k=a+177100|0;l=a+571032|0;m=a+2524|0;n=l;o=a+571036|0;p=a+428656|0;q=a+572232|0;r=0;s=0;t=0;u=0;v=0;w=0;x=0;a:while(1){y=c[f>>2]|0;if((c[y+688>>2]&2048|0)!=0){z=c[a+571436+(x*12|0)+4>>2]|0;A=c[a+571436+(x*12|0)+8>>2]|0;yDb(y,48,2308192,(h=i,i=i+24|0,c[h>>2]=c[a+571436+(x*12|0)>>2],c[h+8>>2]=z,c[h+16>>2]=A,h)|0);i=h}A=b+(x*12|0)|0;z=c[A>>2]|0;b:do{if((z|0)==1|(z|0)==3){y=c[b+(x*12|0)+4>>2]|0;B=c[k>>2]|0;if((B|0)==3){C=y;D=3}else{C=y>>1;D=(y&1|0)==0?B^3:B}B=0;while(1){if((B|0)>=(c[g>>2]|0)){E=r;break}F=c[a+571032+(B<<2)>>2]|0;y=c[f>>2]|0;if((c[y+688>>2]&2048|0)==0){G=F+1616|0}else{H=F+1616|0;I=c[H>>2]|0;yDb(y,48,2152016,(h=i,i=i+24|0,c[h>>2]=B,c[h+8>>2]=I,c[h+16>>2]=F,h)|0);i=h;G=H}if((c[G>>2]|0)==(C|0)){J=17;break}B=B+1|0}do{if((J|0)==17){J=0;if((F|0)==0){E=B;break}K=C;L=F;M=D;N=B;O=c[A>>2]|0;J=23;break b}}while(0);do{if((c[A>>2]|0)==3){B=c[a+571160+(c[b+(x*12|0)+8>>2]<<2)>>2]|0;if((B|0)==0){break}if((c[B+1616>>2]|0)==(C|0)){P=C;Q=0;R=u;S=t;T=D;U=E;break b}}}while(0);yDb(c[f>>2]|0,(c[g>>2]|0)!=0?16:48,2289616,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;P=C;Q=0;R=-1094995529;S=t;T=D;U=E}else{K=w;L=v;M=s;N=r;O=z;J=23}}while(0);c:do{if((J|0)==23){J=0;switch(O|0){case 5:{z=c[g>>2]|0;d:do{if((z|0)==0){V=0}else{A=z;while(1){B=c[(c[l>>2]|0)+1616>>2]|0;H=c[f>>2]|0;if((c[H+688>>2]&2048|0)==0){W=0}else{yDb(H,48,2159080,(h=i,i=i+16|0,c[h>>2]=B,c[h+8>>2]=A,h)|0);i=h;W=0}while(1){H=c[g>>2]|0;if((W|0)>=(H|0)){X=H;break}Y=a+571032+(W<<2)|0;Z=c[Y>>2]|0;H=c[f>>2]|0;if((c[H+688>>2]&2048|0)==0){_=Z+1616|0}else{I=Z+1616|0;y=c[I>>2]|0;yDb(H,48,2152016,(h=i,i=i+24|0,c[h>>2]=W,c[h+8>>2]=y,c[h+16>>2]=Z,h)|0);i=h;_=I}$=W+1|0;if((c[_>>2]|0)==(B|0)){J=100;break}else{W=$}}if((J|0)==100){J=0;if((Z|0)!=0){B=Z+2192|0;c[B>>2]=0;I=0;while(1){y=c[a+571288+(I<<2)>>2]|0;if((y|0)==0){break}if((y|0)==(Z|0)){J=104;break}else{I=I+1|0}}if((J|0)==104){J=0;c[B>>2]=4}c[Y>>2]=0;I=(c[g>>2]|0)-1|0;c[g>>2]=I;if((I|0)==0){V=0;break d}VGb(Y|0,a+571032+($<<2)|0,I-W<<2|0)|0}X=c[g>>2]|0}if((X|0)==0){V=0;break}else{A=X}}}}while(0);do{z=a+571160+(V<<2)|0;A=c[z>>2]|0;if((A|0)!=0){I=A+2192|0;c[I>>2]=0;y=0;while(1){H=c[a+571288+(y<<2)>>2]|0;if((H|0)==0){break}if((H|0)==(A|0)){J=113;break}else{y=y+1|0}}if((J|0)==113){J=0;c[I>>2]=4}c[A+1628>>2]=0;c[z>>2]=0;c[j>>2]=(c[j>>2]|0)-1}V=V+1|0;}while((V|0)<16);y=c[m>>2]|0;c[y+1616>>2]=0;c[p>>2]=0;c[q>>2]=1;c[y+1620>>2]=1;c[a+571360>>2]=-2147483648;c[a+571364>>2]=-2147483648;c[a+571368>>2]=-2147483648;c[a+571372>>2]=-2147483648;c[a+571376>>2]=-2147483648;c[a+571380>>2]=-2147483648;c[a+571384>>2]=-2147483648;c[a+571388>>2]=-2147483648;c[a+571392>>2]=-2147483648;c[a+571396>>2]=-2147483648;c[a+571400>>2]=-2147483648;c[a+571404>>2]=-2147483648;c[a+571408>>2]=-2147483648;c[a+571412>>2]=-2147483648;c[a+571416>>2]=-2147483648;c[a+571420>>2]=-2147483648;P=K;Q=L;R=u;S=t;T=M;U=16;break c;break};case 4:{y=c[b+(x*12|0)+8>>2]|0;if((y|0)<16){aa=y}else{P=K;Q=L;R=u;S=t;T=M;U=y;break c}while(1){y=a+571160+(aa<<2)|0;H=c[y>>2]|0;if((H|0)!=0){ba=H+2192|0;c[ba>>2]=0;ca=0;while(1){da=c[a+571288+(ca<<2)>>2]|0;if((da|0)==0){break}if((da|0)==(H|0)){J=90;break}else{ca=ca+1|0}}if((J|0)==90){J=0;c[ba>>2]=4}c[H+1628>>2]=0;c[y>>2]=0;c[j>>2]=(c[j>>2]|0)-1}ca=aa+1|0;if((ca|0)<16){aa=ca}else{P=K;Q=L;R=u;S=t;T=M;U=16;break}}break};case 2:{ca=c[b+(x*12|0)+8>>2]|0;z=c[k>>2]|0;if((z|0)==3){ea=ca;fa=3}else{ea=ca>>1;fa=(ca&1|0)==0?z^3:z}z=a+571160+(ea<<2)|0;ca=c[z>>2]|0;if((ca|0)==0){A=c[f>>2]|0;if((c[A+688>>2]&2048|0)==0){P=K;Q=0;R=u;S=t;T=fa;U=ea;break c}yDb(A,48,2258024,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;P=K;Q=0;R=u;S=t;T=fa;U=ea;break c}A=ca+2192|0;I=c[A>>2]&(fa^3);c[A>>2]=I;if((I|0)==0){ga=0}else{P=K;Q=ca;R=u;S=t;T=fa;U=ea;break c}while(1){I=c[a+571288+(ga<<2)>>2]|0;if((I|0)==0){break}if((I|0)==(ca|0)){J=57;break}else{ga=ga+1|0}}if((J|0)==57){J=0;c[A>>2]=4}c[ca+1628>>2]=0;c[z>>2]=0;c[j>>2]=(c[j>>2]|0)-1;P=K;Q=ca;R=u;S=t;T=fa;U=ea;break c;break};case 1:{I=c[f>>2]|0;da=c[I+688>>2]|0;if((da&2048|0)==0){ha=I;ia=da}else{da=c[g>>2]|0;yDb(I,48,2273632,(h=i,i=i+16|0,c[h>>2]=c[a+571436+(x*12|0)+4>>2],c[h+8>>2]=da,h)|0);i=h;da=c[f>>2]|0;ha=da;ia=c[da+688>>2]|0}da=M^3;if((ia&2048|0)==0){ja=0}else{I=c[g>>2]|0;yDb(ha,48,2159080,(h=i,i=i+16|0,c[h>>2]=K,c[h+8>>2]=I,h)|0);i=h;ja=0}while(1){if((ja|0)>=(c[g>>2]|0)){P=K;Q=L;R=u;S=t;T=M;U=N;break c}ka=a+571032+(ja<<2)|0;la=c[ka>>2]|0;I=c[f>>2]|0;if((c[I+688>>2]&2048|0)==0){ma=la+1616|0}else{na=la+1616|0;oa=c[na>>2]|0;yDb(I,48,2152016,(h=i,i=i+24|0,c[h>>2]=ja,c[h+8>>2]=oa,c[h+16>>2]=la,h)|0);i=h;ma=na}pa=ja+1|0;if((c[ma>>2]|0)==(K|0)){break}else{ja=pa}}if((la|0)==0){P=K;Q=L;R=u;S=t;T=M;U=N;break c}ca=la+2192|0;z=c[ca>>2]&da;c[ca>>2]=z;if((z|0)==0){qa=0}else{P=K;Q=L;R=u;S=t;T=M;U=N;break c}while(1){z=c[a+571288+(qa<<2)>>2]|0;if((z|0)==0){break}if((z|0)==(la|0)){J=38;break}else{qa=qa+1|0}}if((J|0)==38){J=0;c[ca>>2]=4}c[ka>>2]=0;da=(c[g>>2]|0)-1|0;c[g>>2]=da;if((da|0)==0){P=K;Q=L;R=u;S=t;T=M;U=N;break c}VGb(ka|0,a+571032+(pa<<2)|0,da-ja<<2|0)|0;P=K;Q=L;R=u;S=t;T=M;U=N;break c;break};case 3:{da=b+(x*12|0)+8|0;z=a+571160+(c[da>>2]<<2)|0;A=c[z>>2]|0;if(!((A|0)==(L|0)|(A|0)==0)){na=A+2192|0;c[na>>2]=0;oa=0;while(1){I=c[a+571288+(oa<<2)>>2]|0;if((I|0)==0){break}if((I|0)==(A|0)){J=45;break}else{oa=oa+1|0}}if((J|0)==45){J=0;c[na>>2]=4}c[A+1628>>2]=0;c[z>>2]=0;c[j>>2]=(c[j>>2]|0)-1}oa=a+571032+(N<<2)|0;c[oa>>2]=0;ca=(c[g>>2]|0)-1|0;c[g>>2]=ca;if((ca|0)!=0){VGb(oa|0,a+571032+(N+1<<2)|0,ca-N<<2|0)|0}c[a+571160+(c[da>>2]<<2)>>2]=L;if((L|0)==0){P=K;Q=0;R=u;S=t;T=M;U=N;break c}c[L+1628>>2]=1;c[j>>2]=(c[j>>2]|0)+1;P=K;Q=L;R=u;S=t;T=M;U=N;break c;break};case 6:{do{if((c[l>>2]|0)==(c[m>>2]|0)){yDb(c[f>>2]|0,16,2243784,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;c[l>>2]=0;ca=(c[g>>2]|0)-1|0;c[g>>2]=ca;if((ca|0)==0){break}VGb(n|0,o|0,ca<<2|0)|0}}while(0);da=b+(x*12|0)+8|0;z=c[a+571160+(c[da>>2]<<2)>>2]|0;A=c[m>>2]|0;if((z|0)==(A|0)){ra=N;sa=z}else{if((c[A+1628>>2]|0)==0){ta=A;ua=N}else{z=0;na=A;do{A=a+571160+(z<<2)|0;if((c[A>>2]|0)==(na|0)){if((na|0)!=0){ca=na+2192|0;c[ca>>2]=0;oa=0;while(1){I=c[a+571288+(oa<<2)>>2]|0;if((I|0)==0){break}if((I|0)==(na|0)){J=71;break}else{oa=oa+1|0}}if((J|0)==71){J=0;c[ca>>2]=4}c[na+1628>>2]=0;c[A>>2]=0;c[j>>2]=(c[j>>2]|0)-1}yDb(c[f>>2]|0,16,2231272,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}z=z+1|0;na=c[m>>2]|0}while((z|0)<16);if((c[na+1628>>2]|0)==0){ta=na;ua=16}else{J=76;break a}}z=c[da>>2]|0;oa=a+571160+(z<<2)|0;y=c[oa>>2]|0;if((y|0)==0){va=ta;wa=z}else{z=y+2192|0;c[z>>2]=0;H=0;while(1){ba=c[a+571288+(H<<2)>>2]|0;if((ba|0)==0){break}if((ba|0)==(y|0)){J=81;break}else{H=H+1|0}}if((J|0)==81){J=0;c[z>>2]=4}c[y+1628>>2]=0;c[oa>>2]=0;c[j>>2]=(c[j>>2]|0)-1;va=c[m>>2]|0;wa=c[da>>2]|0}c[a+571160+(wa<<2)>>2]=va;c[va+1628>>2]=1;c[j>>2]=(c[j>>2]|0)+1;ra=ua;sa=c[m>>2]|0}H=sa+2192|0;c[H>>2]=c[H>>2]|c[k>>2];P=K;Q=L;R=u;S=1;T=M;U=ra;break c;break};default:{P=K;Q=L;R=u;S=t;T=M;U=N;break c}}}}while(0);H=x+1|0;if((H|0)<(d|0)){r=U;s=T;t=S;u=R;v=Q;w=P;x=H}else{break}}if((J|0)==76){yDb(0,0,2282312,(h=i,i=i+24|0,c[h>>2]=2219160,c[h+8>>2]=2187616,c[h+16>>2]=662,h)|0);i=h;Cd();return 0}if((S|0)==0){xa=R;J=120;break}ya=R;za=a+572240|0}else{xa=0;J=120}}while(0);e:do{if((J|0)==120){R=a+572240|0;S=c[R>>2]|0;do{if((S|0)==0){Aa=c[a+2524>>2]|0}else{P=c[a+571032>>2]|0;Q=c[a+2524>>2]|0;if((P|0)!=(Q|0)){Aa=Q;break}c[P+2192>>2]=3;ya=xa;za=R;break e}}while(0);P=a+2524|0;if((c[Aa+1628>>2]|0)!=0){yDb(c[f>>2]|0,16,2209784,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;ya=-1094995529;za=R;break}Q=c[Aa+1616>>2]|0;T=c[f>>2]|0;if((c[T+688>>2]&2048|0)==0){Ba=0}else{yDb(T,48,2159080,(h=i,i=i+16|0,c[h>>2]=Q,c[h+8>>2]=S,h)|0);i=h;Ba=0}while(1){T=c[R>>2]|0;if((Ba|0)>=(T|0)){Ca=xa;Da=T;break}Ea=a+571032+(Ba<<2)|0;Fa=c[Ea>>2]|0;T=c[f>>2]|0;if((c[T+688>>2]&2048|0)==0){Ga=Fa+1616|0}else{U=Fa+1616|0;d=c[U>>2]|0;yDb(T,48,2152016,(h=i,i=i+24|0,c[h>>2]=Ba,c[h+8>>2]=d,c[h+16>>2]=Fa,h)|0);i=h;Ga=U}Ha=Ba+1|0;if((c[Ga>>2]|0)==(Q|0)){J=133;break}else{Ba=Ha}}if((J|0)==133){if((Fa|0)==0){Ia=xa}else{Q=Fa+2192|0;c[Q>>2]=0;S=0;while(1){U=c[a+571288+(S<<2)>>2]|0;if((U|0)==0){break}if((U|0)==(Fa|0)){J=137;break}else{S=S+1|0}}if((J|0)==137){c[Q>>2]=4}c[Ea>>2]=0;S=(c[R>>2]|0)-1|0;c[R>>2]=S;if((S|0)!=0){VGb(Ea|0,a+571032+(Ha<<2)|0,S-Ba<<2|0)|0}yDb(c[f>>2]|0,16,2201144,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;Ia=-1094995529}Ca=Ia;Da=c[R>>2]|0}if((Da|0)==0){Ja=Da;Ka=a+571032|0}else{S=a+571032|0;VGb(a+571036|0,S|0,Da<<2|0)|0;Ja=c[R>>2]|0;Ka=S}S=c[P>>2]|0;c[Ka>>2]=S;c[R>>2]=Ja+1;U=S+2192|0;c[U>>2]=c[U>>2]|c[a+177100>>2];ya=Ca;za=R}}while(0);Ca=a+572236|0;Ja=c[Ca>>2]|0;Ka=c[za>>2]|0;Da=a+6172|0;Ia=c[Da>>2]|0;f:do{if((Ka+Ja|0)>(((Ia|0)>1?Ia:1)|0)){yDb(c[f>>2]|0,16,2192592,(h=i,i=i+24|0,c[h>>2]=Ja,c[h+8>>2]=Ka,c[h+16>>2]=Ia,h)|0);i=h;Ba=c[za>>2]|0;if((c[Ca>>2]|0)!=0&(Ba|0)==0){Ha=0;while(1){La=c[a+571160+(Ha<<2)>>2]|0;if((Ha|0)>=16){J=151;break}if((La|0)==0){Ha=Ha+1|0}else{J=150;break}}if((J|0)!=150)if((J|0)==151){if((La|0)==0){Ma=-1094995529;J=171;break}}R=a+571160+(Ha<<2)|0;P=La+2192|0;c[P>>2]=0;Q=0;while(1){Ea=c[a+571288+(Q<<2)>>2]|0;if((Ea|0)==0){break}if((Ea|0)==(La|0)){J=155;break}else{Q=Q+1|0}}if((J|0)==155){c[P>>2]=4}c[La+1628>>2]=0;c[R>>2]=0;c[Ca>>2]=(c[Ca>>2]|0)-1;Ma=-1094995529;J=171;break}Q=c[(c[a+571032+(Ba-1<<2)>>2]|0)+1616>>2]|0;Ha=c[f>>2]|0;if((c[Ha+688>>2]&2048|0)==0){Na=0}else{yDb(Ha,48,2159080,(h=i,i=i+16|0,c[h>>2]=Q,c[h+8>>2]=Ba,h)|0);i=h;Na=0}while(1){Ha=c[za>>2]|0;if((Na|0)>=(Ha|0)){Oa=-1094995529;Pa=Ha;J=172;break f}Qa=a+571032+(Na<<2)|0;Ra=c[Qa>>2]|0;Ha=c[f>>2]|0;if((c[Ha+688>>2]&2048|0)==0){Sa=Ra+1616|0}else{Ea=Ra+1616|0;Fa=c[Ea>>2]|0;yDb(Ha,48,2152016,(h=i,i=i+24|0,c[h>>2]=Na,c[h+8>>2]=Fa,c[h+16>>2]=Ra,h)|0);i=h;Sa=Ea}Ta=Na+1|0;if((c[Sa>>2]|0)==(Q|0)){break}else{Na=Ta}}if((Ra|0)==0){Ma=-1094995529;J=171;break}Q=Ra+2192|0;c[Q>>2]=0;Ba=0;while(1){R=c[a+571288+(Ba<<2)>>2]|0;if((R|0)==0){break}if((R|0)==(Ra|0)){J=168;break}else{Ba=Ba+1|0}}if((J|0)==168){c[Q>>2]=4}c[Qa>>2]=0;Ba=(c[za>>2]|0)-1|0;c[za>>2]=Ba;if((Ba|0)==0){Ua=-1094995529;break}VGb(Qa|0,a+571032+(Ta<<2)|0,Ba-Na<<2|0)|0;Ma=-1094995529;J=171}else{Ma=ya;J=171}}while(0);if((J|0)==171){Oa=Ma;Pa=c[za>>2]|0;J=172}do{if((J|0)==172){if((Pa|0)<=0){Ua=Oa;break}Ma=a+2524|0;ya=a+6144|0;Na=0;Ta=Pa;while(1){Qa=c[a+571032+(Na<<2)>>2]|0;g:do{if((c[Qa+2204>>2]|0)!=0){Ra=c[Qa+1616>>2]|0;if(((1<<c[ya>>2])-1&(c[(c[Ma>>2]|0)+1616>>2]|0)-Ra|0)<=(c[Da>>2]|0)){break}Sa=c[f>>2]|0;if((c[Sa+688>>2]&2048|0)==0){Va=0}else{yDb(Sa,48,2159080,(h=i,i=i+16|0,c[h>>2]=Ra,c[h+8>>2]=Ta,h)|0);i=h;Va=0}while(1){if((Va|0)>=(c[za>>2]|0)){break g}Wa=a+571032+(Va<<2)|0;Xa=c[Wa>>2]|0;Sa=c[f>>2]|0;if((c[Sa+688>>2]&2048|0)==0){Ya=Xa+1616|0}else{La=Xa+1616|0;Ia=c[La>>2]|0;yDb(Sa,48,2152016,(h=i,i=i+24|0,c[h>>2]=Va,c[h+8>>2]=Ia,c[h+16>>2]=Xa,h)|0);i=h;Ya=La}Za=Va+1|0;if((c[Ya>>2]|0)==(Ra|0)){break}else{Va=Za}}if((Xa|0)==0){break}Ra=Xa+2192|0;c[Ra>>2]=0;da=0;while(1){oa=c[a+571288+(da<<2)>>2]|0;if((oa|0)==0){break}if((oa|0)==(Xa|0)){J=187;break}else{da=da+1|0}}if((J|0)==187){J=0;c[Ra>>2]=4}c[Wa>>2]=0;da=(c[za>>2]|0)-1|0;c[za>>2]=da;if((da|0)==0){break}VGb(Wa|0,a+571032+(Za<<2)|0,da-Va<<2|0)|0}}while(0);Qa=Na+1|0;da=c[za>>2]|0;if((Qa|0)<(da|0)){Na=Qa;Ta=da}else{Ua=Oa;break}}}}while(0);Oa=c[f>>2]|0;do{if((c[Oa+688>>2]&2048|0)!=0){yDb(Oa,48,2126632,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;if((c[za>>2]|0)==0){break}else{_a=0}do{Va=c[a+571032+(_a<<2)>>2]|0;Za=c[Va+1616>>2]|0;Wa=c[Va+1612>>2]|0;J=c[Va>>2]|0;yDb(c[f>>2]|0,48,2133056,(h=i,i=i+32|0,c[h>>2]=_a,c[h+8>>2]=Za,c[h+16>>2]=Wa,c[h+24>>2]=J,h)|0);i=h;_a=_a+1|0;}while(_a>>>0<(c[za>>2]|0)>>>0)}}while(0);_a=c[f>>2]|0;if((c[_a+688>>2]&2048|0)==0){$a=0;ab=0}else{yDb(_a,48,2139344,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;_a=0;while(1){Oa=c[a+571160+(_a<<2)>>2]|0;if((Oa|0)!=0){J=c[Oa+1616>>2]|0;Wa=c[Oa+1612>>2]|0;Za=c[Oa>>2]|0;yDb(c[f>>2]|0,48,2133056,(h=i,i=i+32|0,c[h>>2]=_a,c[h+8>>2]=J,c[h+16>>2]=Wa,c[h+24>>2]=Za,h)|0);i=h}Za=_a+1|0;if(Za>>>0<16>>>0){_a=Za}else{$a=0;ab=0;break}}}do{$a=((c[a+427604+(ab<<2)>>2]|0)!=0)+$a|0;ab=ab+1|0;}while(ab>>>0<256>>>0);if(!((Ua|0)>-1)){bb=c[f>>2]|0;cb=bb+696|0;db=c[cb>>2]|0;eb=db&8;fb=(eb|0)!=0;gb=fb?Ua:0;i=e;return gb|0}if((c[Ca>>2]|0)!=0){bb=c[f>>2]|0;cb=bb+696|0;db=c[cb>>2]|0;eb=db&8;fb=(eb|0)!=0;gb=fb?Ua:0;i=e;return gb|0}Ca=c[a+7348>>2]|0;do{if((c[za>>2]|0)>=3){if(!(Ca>>>0<2>>>0)){bb=c[f>>2]|0;cb=bb+696|0;db=c[cb>>2]|0;eb=db&8;fb=(eb|0)!=0;gb=fb?Ua:0;i=e;return gb|0}if((c[a+7352>>2]|0)>>>0<2>>>0&($a|0)==1){break}bb=c[f>>2]|0;cb=bb+696|0;db=c[cb>>2]|0;eb=db&8;fb=(eb|0)!=0;gb=fb?Ua:0;i=e;return gb|0}}while(0);if(Ca>>>0>((c[a+177100>>2]|0)!=3|2)>>>0){bb=c[f>>2]|0;cb=bb+696|0;db=c[cb>>2]|0;eb=db&8;fb=(eb|0)!=0;gb=fb?Ua:0;i=e;return gb|0}Ca=c[a+2524>>2]|0;if((c[Ca+88>>2]|0)!=1){bb=c[f>>2]|0;cb=bb+696|0;db=c[cb>>2]|0;eb=db&8;fb=(eb|0)!=0;gb=fb?Ua:0;i=e;return gb|0}$a=Ca+2200|0;c[$a>>2]=c[$a>>2]|1;if((c[(c[f>>2]|0)+176>>2]|0)!=0){bb=c[f>>2]|0;cb=bb+696|0;db=c[cb>>2]|0;eb=db&8;fb=(eb|0)!=0;gb=fb?Ua:0;i=e;return gb|0}$a=a+572480|0;c[$a>>2]=c[$a>>2]|2;bb=c[f>>2]|0;cb=bb+696|0;db=c[cb>>2]|0;eb=db&8;fb=(eb|0)!=0;gb=fb?Ua:0;i=e;return gb|0}function lea(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;i=i+792|0;h=g|0;j=e+8|0;k=c[j>>2]|0;a:do{if((c[b+427436>>2]|0)==5){l=c[e+16>>2]|0;m=k+1|0;n=l>>>0>m>>>0?m:l;c[j>>2]=n;m=d[(c[e>>2]|0)+(n>>>3)|0]|0;c[j>>2]=((n|0)<(l|0))+n;if((128>>>((n&7)>>>0)&m|0)==0){o=0;break}c[h>>2]=6;c[h+8>>2]=0;o=1}else{m=c[e>>2]|0;n=d[m+(k>>>3)|0]|0;l=c[e+16>>2]|0;p=((k|0)<(l|0))+k|0;c[j>>2]=p;if((n&128>>>((k&7)>>>0)|0)==0){do{if((f|0)!=0){n=jea(b,f)|0;if((n|0)>=0){break}if((c[(c[b>>2]|0)+696>>2]&8|0)==0){break}else{q=n}i=g;return q|0}}while(0);q=0;i=g;return q|0}n=b+177100|0;r=b+428680|0;s=b+428684|0;t=0;u=p;while(1){if((t|0)>=66){o=t;break a}v=m+(u>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(u&7)>>>23;v=(d[1213744+w|0]|0)+u|0;x=l>>>0>v>>>0?v:l;c[j>>2]=x;v=a[1108392+w|0]|0;y=v&255;c[h+(t*12|0)>>2]=y;if((y|0)==3|(y|0)==1){w=c[r>>2]|0;z=m+(x>>>3)|0;A=(fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7);if(A>>>0>134217727>>>0){z=A>>>23;B=(d[1213744+z|0]|0)+x|0;C=l>>>0>B>>>0?B:l;c[j>>2]=C;D=d[1108392+z|0]|0;E=C}else{C=A>>>0>65535>>>0;z=C?A>>>16:A;B=C?16:0;if((z&65280|0)==0){F=B;G=z}else{F=B|8;G=z>>>8}z=(d[1191992+G|0]|0)+F<<1;B=63-z+x|0;C=l>>>0>B>>>0?B:l;c[j>>2]=C;D=(A>>>((z-31|0)>>>0))-1|0;E=C}c[h+(t*12|0)+4>>2]=(c[s>>2]|0)-1&w-1-D;H=E}else{H=x}x=v<<24>>24==2;w=v<<24>>24==4;if((y-2|0)>>>0<2>>>0|v<<24>>24==6|w){C=m+(H>>>3)|0;z=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(H&7)>>>23;C=(d[1213744+z|0]|0)+H|0;A=l>>>0>C>>>0?C:l;c[j>>2]=A;C=a[1108392+z|0]|0;z=C&255;if((C&255)>>>0>31>>>0){I=19;break}if(!((C&255)>>>0<16>>>0|w&C<<24>>24==16)){if(!x){I=19;break}if((c[n>>2]|0)==3){I=19;break}}c[h+(t*12|0)+8>>2]=z;J=A}else{J=H}if((v&255)>>>0>6>>>0){I=22;break}if(v<<24>>24==0){o=t;break a}else{t=t+1|0;u=J}}if((I|0)==19){yDb(c[b>>2]|0,16,2176304,(K=i,i=i+8|0,c[K>>2]=y,K)|0);i=K;q=-1;i=g;return q|0}else if((I|0)==22){yDb(c[b>>2]|0,16,2165664,(K=i,i=i+8|0,c[K>>2]=y,K)|0);i=K;q=-1;i=g;return q|0}}}while(0);y=(f|0)==0;if(!(y|(o|0)==-1)){UGb(b+571436|0,h|0,792)|0;c[b+572228>>2]=o;q=0;i=g;return q|0}if(!(y&(o|0)>-1)){q=0;i=g;return q|0}y=b+572228|0;f=c[y>>2]|0;do{if((o|0)==(f|0)){J=0;while(1){if((J|0)>=(o|0)){q=0;I=36;break}L=c[b+571436+(J*12|0)>>2]|0;M=c[h+(J*12|0)>>2]|0;if((L|0)==(M|0)){J=J+1|0}else{I=34;break}}if((I|0)==34){yDb(0,16,2145096,(K=i,i=i+24|0,c[K>>2]=L,c[K+8>>2]=M,c[K+16>>2]=J,K)|0);i=K;N=c[y>>2]|0;break}else if((I|0)==36){i=g;return q|0}}else{N=f}}while(0);yDb(c[b>>2]|0,16,2352672,(K=i,i=i+16|0,c[K>>2]=o,c[K+8>>2]=N,K)|0);i=K;q=-1094995529;i=g;return q|0}function mea(a){a=a|0;c[a+572444>>2]=-1;c[a+572436>>2]=0;c[a+572440>>2]=-1;c[a+572500>>2]=0;c[a+572416>>2]=0;return}function nea(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;e=i;i=i+280|0;f=e|0;g=e+272|0;h=b+1096|0;j=c[h>>2]|0;k=b+1100|0;l=c[k>>2]|0;if((l-j|0)<=16){m=0;i=e;return m|0}n=b+1088|0;o=b+1104|0;p=b|0;q=b+6124|0;r=b+1088|0;s=b+572408|0;t=b+572432|0;u=b+572440|0;v=b+572436|0;w=f+16|0;x=b+427372|0;y=b+572444|0;z=b+572500|0;A=b+572452|0;B=b+572456|0;C=b+572416|0;D=b+572420|0;E=b+572460|0;F=b+572428|0;G=b+572472|0;H=b+572424|0;I=b+572468|0;J=b+572464|0;K=j;j=l;a:while(1){l=0;L=K;while(1){if((j-L|0)<8){m=-1094995529;M=112;break a}N=c[n>>2]|0;O=N+(L>>>3)|0;P=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7);Q=(P>>>24)+l|0;R=c[o>>2]|0;O=L+8|0;S=R>>>0>O>>>0?O:R;c[h>>2]=S;if((P&-16777216|0)==-16777216){l=Q;L=S}else{T=0;U=S;break}}do{if((j-U|0)<8){m=-1094995529;M=112;break a}L=N+(U>>>3)|0;l=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(U&7);T=(l>>>24)+T|0;L=U+8|0;U=R>>>0>L>>>0?L:R;c[h>>2]=U;}while((l&-16777216|0)==-16777216);l=c[p>>2]|0;if((c[l+688>>2]&256|0)==0){V=U;W=j}else{yDb(l,48,2281824,(X=i,i=i+16|0,c[X>>2]=Q,c[X+8>>2]=T,X)|0);i=X;V=c[h>>2]|0;W=c[k>>2]|0}Y=W-V|0;if(T>>>0>((Y|0)/8|0)>>>0){M=11;break}l=V+(T<<3)|0;b:do{switch(Q|0){case 1:{L=0;S=q;while(1){if((c[S+20>>2]|0)==0){P=c[b+427476+(L<<2)>>2]|0;Z=(P|0)==0?S:P}else{Z=S}P=L+1|0;if((P|0)<32){L=P;S=Z}else{break}}if((c[Z+1152>>2]|0)==0){if((c[Z+1156>>2]|0)==0){_=V}else{M=18}}else{M=18}if((M|0)==18){M=0;S=c[Z+1176>>2]|0;do{if((S|0)==0){$=0;aa=V}else{L=c[o>>2]|0;P=c[n>>2]|0;O=P+(V>>>3)|0;ba=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(V&7);if((S|0)<26){O=V+S|0;ca=L>>>0>O>>>0?O:L;c[h>>2]=ca;$=ba>>>((32-S|0)>>>0);aa=ca;break}else{ca=V+16|0;O=L>>>0>ca>>>0?ca:L;c[h>>2]=O;ca=S-16|0;da=P+(O>>>3)|0;P=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(O&7)>>>((48-S|0)>>>0);da=O+ca|0;O=L>>>0>da>>>0?da:L;c[h>>2]=O;$=P|ba>>>16<<ca;aa=O;break}}}while(0);c[u>>2]=$;S=c[Z+1180>>2]|0;do{if((S|0)==0){ea=0;fa=aa}else{O=c[o>>2]|0;ca=c[n>>2]|0;ba=ca+(aa>>>3)|0;P=(fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(aa&7);if((S|0)<26){ba=aa+S|0;L=O>>>0>ba>>>0?ba:O;c[h>>2]=L;ea=P>>>((32-S|0)>>>0);fa=L;break}else{L=aa+16|0;ba=O>>>0>L>>>0?L:O;c[h>>2]=ba;L=S-16|0;da=ca+(ba>>>3)|0;ca=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ba&7)>>>((48-S|0)>>>0);da=ba+L|0;ba=O>>>0>da>>>0?da:O;c[h>>2]=ba;ea=ca|P>>>16<<L;fa=ba;break}}}while(0);c[v>>2]=ea;_=fa}if((c[Z+1160>>2]|0)==0){break b}S=c[o>>2]|0;ba=c[r>>2]|0;L=ba+(_>>>3)|0;P=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(_&7);L=P>>>28;ca=_+4|0;O=S>>>0>ca>>>0?ca:S;c[h>>2]=O;c[s>>2]=L;c[t>>2]=0;if(P>>>0>2415919103>>>0){m=-1094995529;M=112;break a}P=d[473e3+L|0]|0;ca=Z+1164|0;da=0;ga=0;ha=O;while(1){O=ba+(ha>>>3)|0;ia=fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;O=ha+1|0;ja=S>>>0>O>>>0?O:S;c[h>>2]=ja;do{if((ia&-2147483648>>>((ha&7)>>>0)|0)==0){ka=ga;la=ja}else{O=ba+(ja>>>3)|0;ma=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(ja&7)>>>30;O=ja+2|0;na=1<<ma|ga;c[t>>2]=na;ma=(S>>>0>O>>>0?O:S)+1|0;O=(S>>>0>ma>>>0?ma:S)+5|0;ma=S>>>0>O>>>0?O:S;c[h>>2]=ma;O=ba+(ma>>>3)|0;oa=fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;O=ma+1|0;pa=(S>>>0>O>>>0?O:S)+1|0;O=(S>>>0>pa>>>0?pa:S)+1|0;pa=(S>>>0>O>>>0?O:S)+8|0;O=S>>>0>pa>>>0?pa:S;c[h>>2]=O;do{if((oa&-2147483648>>>((ma&7)>>>0)|0)==0){pa=ba+(O>>>3)|0;qa=fe(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0;pa=O+1|0;ra=S>>>0>pa>>>0?pa:S;c[h>>2]=ra;if((qa&-2147483648>>>((O&7)>>>0)|0)==0){sa=ra;break}qa=ra+6|0;ra=S>>>0>qa>>>0?qa:S;c[h>>2]=ra;qa=ba+(ra>>>3)|0;pa=fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0;qa=ra+1|0;ta=S>>>0>qa>>>0?qa:S;c[h>>2]=ta;if((pa&-2147483648>>>((ra&7)>>>0)|0)==0){sa=ta;break}ra=ta+6|0;ta=S>>>0>ra>>>0?ra:S;c[h>>2]=ta;ra=ba+(ta>>>3)|0;pa=fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0;ra=ta+1|0;qa=S>>>0>ra>>>0?ra:S;c[h>>2]=qa;if((pa&-2147483648>>>((ta&7)>>>0)|0)==0){sa=qa;break}ta=qa+5|0;qa=S>>>0>ta>>>0?ta:S;c[h>>2]=qa;sa=qa}else{qa=O+6|0;ta=(S>>>0>qa>>>0?qa:S)+6|0;qa=(S>>>0>ta>>>0?ta:S)+5|0;ta=S>>>0>qa>>>0?qa:S;c[h>>2]=ta;sa=ta}}while(0);O=c[ca>>2]|0;if((O|0)<=0){ka=na;la=sa;break}ma=O+sa|0;O=S>>>0>ma>>>0?ma:S;c[h>>2]=O;ka=na;la=O}}while(0);ja=da+1|0;if(ja>>>0<P>>>0){da=ja;ga=ka;ha=la}else{break}}ha=c[p>>2]|0;if((c[ha+688>>2]&1|0)==0){break b}yDb(ha,48,2176272,(X=i,i=i+16|0,c[X>>2]=ka,c[X+8>>2]=L,X)|0);i=X;break};case 5:{if((T|0)<16){m=-1094995529;M=112;break a}ha=-T|0;ga=c[o>>2]|0;da=c[r>>2]|0;P=0;S=V;do{ca=da+(S>>>3)|0;ba=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(S&7)>>>24;ca=S+8|0;S=ga>>>0>ca>>>0?ca:ga;c[h>>2]=S;a[f+P|0]=ba;P=P+1|0;}while(P>>>0<271>>>0&(P|0)<(T|0));P=ha>>>0>4294967025>>>0?T:271;a[f+P|0]=0;S=xd(w|0,2209768,(X=i,i=i+8|0,c[X>>2]=g,X)|0)|0;i=X;do{if((S|0)==1){ga=c[g>>2]|0;if((ga|0)<=0){break}c[x>>2]=ga;if((ga|0)!=1){break}if((RGb(w,2201120,16)|0)!=0){break}c[x>>2]=67}}while(0);S=c[p>>2]|0;if((c[S+688>>2]&4096|0)!=0){yDb(S,48,2192560,(X=i,i=i+8|0,c[X>>2]=w,X)|0);i=X}if((P|0)>=(T|0)){break b}S=c[o>>2]|0;ha=P;ga=c[h>>2]|0;do{da=ga+8|0;ga=S>>>0>da>>>0?da:S;ha=ha+1|0;}while((ha|0)<(T|0));c[h>>2]=ga;break};case 6:{ha=c[o>>2]|0;S=(c[r>>2]|0)+(V>>>3)|0;P=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(V&7);if(P>>>0>134217727>>>0){S=P>>>23;da=(d[1213744+S|0]|0)+V|0;L=ha>>>0>da>>>0?da:ha;c[h>>2]=L;ua=d[1108392+S|0]|0;va=L}else{L=P>>>0>65535>>>0;S=L?P>>>16:P;da=L?16:0;if((S&65280|0)==0){wa=da;xa=S}else{wa=da|8;xa=S>>>8}S=(d[1191992+xa|0]|0)+wa<<1;da=63-S+V|0;L=ha>>>0>da>>>0?da:ha;c[h>>2]=L;ua=(P>>>((S-31|0)>>>0))-1|0;va=L}c[y>>2]=ua;L=va+4|0;c[h>>2]=ha>>>0>L>>>0?L:ha;ha=c[p>>2]|0;if((c[ha+688>>2]&1|0)==0){break b}yDb(ha,48,2219128,(X=i,i=i+8|0,c[X>>2]=ua,X)|0);i=X;break};case 4:{if((T|0)<7){m=-1;M=112;break a}ha=T-7|0;L=c[o>>2]|0;S=V+8|0;P=(L>>>0>S>>>0?S:L)+16|0;S=L>>>0>P>>>0?P:L;c[h>>2]=S;P=c[r>>2]|0;da=P+(S>>>3)|0;ba=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(S&7)&-65536;da=S+16|0;S=L>>>0>da>>>0?da:L;c[h>>2]=S;da=P+(S>>>3)|0;ca=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(S&7)>>>16;da=S+16|0;S=L>>>0>da>>>0?da:L;c[h>>2]=S;if((ca|ba|0)!=1146373937){ba=S+(ha<<3)|0;c[h>>2]=L>>>0>ba>>>0?ba:L;break b}if((ha|0)<1){m=-1;M=112;break a}ba=S+1|0;S=L>>>0>ba>>>0?ba:L;c[h>>2]=S;ba=P+(S>>>3)|0;ca=fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0;ba=S+1|0;da=(L>>>0>ba>>>0?ba:L)+6|0;ba=L>>>0>da>>>0?da:L;c[h>>2]=ba;if((ca&-2147483648>>>((S&7)>>>0)|0)==0){break b}if((ha|0)<2){m=-1;M=112;break a}ha=ba+4|0;ba=L>>>0>ha>>>0?ha:L;c[h>>2]=ba;ha=P+(ba>>>3)|0;P=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ba&7)>>>28;ha=ba+4|0;c[h>>2]=L>>>0>ha>>>0?ha:L;c[(c[p>>2]|0)+272>>2]=P;break};case 45:{P=c[o>>2]|0;L=c[r>>2]|0;ha=L+(V>>>3)|0;ba=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(V&7);if(ba>>>0>134217727>>>0){ha=ba>>>23;S=(d[1213744+ha|0]|0)+V|0;ca=P>>>0>S>>>0?S:P;c[h>>2]=ca;ya=d[1108392+ha|0]|0;za=ca}else{ca=ba>>>0>65535>>>0;ha=ca?ba>>>16:ba;S=ca?16:0;if((ha&65280|0)==0){Aa=S;Ba=ha}else{Aa=S|8;Ba=ha>>>8}ha=(d[1191992+Ba|0]|0)+Aa<<1;S=63-ha+V|0;ca=P>>>0>S>>>0?S:P;c[h>>2]=ca;ya=(ba>>>((ha-31|0)>>>0))-1|0;za=ca}c[A>>2]=ya;ca=(d[L+(za>>>3)|0]|0)<<(za&7)>>>7;ha=((za|0)<(P|0))+za|0;c[h>>2]=ha;ba=ca&1;c[B>>2]=ba;c[C>>2]=ba^1;if((ba|0)==0){ca=L+(ha>>>3)|0;S=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(ha&7)>>>25;ca=ha+7|0;da=P>>>0>ca>>>0?ca:P;c[h>>2]=da;c[D>>2]=S;c[E>>2]=S;ca=(d[L+(da>>>3)|0]|0)<<(da&7)>>>7;ja=((da|0)<(P|0))+da|0;c[h>>2]=ja;da=ca&1;c[F>>2]=da;c[G>>2]=da;ca=L+(ja>>>3)|0;ia=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(ja&7)>>>26;ca=ja+6|0;c[H>>2]=ia;c[I>>2]=ia;ia=(P>>>0>ca>>>0?ca:P)+6|0;ca=P>>>0>ia>>>0?ia:P;if((da|0)!=0|(S|0)==5){Ca=ca}else{S=ca+16|0;Ca=P>>>0>S>>>0?S:P}S=Ca+8|0;ca=P>>>0>S>>>0?S:P;c[h>>2]=ca;S=L+(ca>>>3)|0;L=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(ca&7);if(L>>>0>134217727>>>0){S=L>>>23;da=(d[1213744+S|0]|0)+ca|0;ia=P>>>0>da>>>0?da:P;c[h>>2]=ia;Da=d[1108392+S|0]|0;Ea=ia}else{ia=L>>>0>65535>>>0;S=ia?L>>>16:L;da=ia?16:0;if((S&65280|0)==0){Fa=da;Ga=S}else{Fa=da|8;Ga=S>>>8}S=(d[1191992+Ga|0]|0)+Fa<<1;da=63-S+ca|0;ca=P>>>0>da>>>0?da:P;c[h>>2]=ca;Da=(L>>>((S-31|0)>>>0))-1|0;Ea=ca}c[J>>2]=Da;Ha=Ea}else{Ha=ha}ha=Ha+1|0;c[h>>2]=P>>>0>ha>>>0?ha:P;P=c[p>>2]|0;if((c[P+688>>2]&1|0)==0){break b}ha=c[E>>2]|0;ca=c[G>>2]|0;S=c[I>>2]|0;L=c[J>>2]|0;yDb(P,48,2243736,(X=i,i=i+48|0,c[X>>2]=ya,c[X+8>>2]=ba,c[X+16>>2]=ha,c[X+24>>2]=ca,c[X+32>>2]=S,c[X+40>>2]=L,X)|0);i=X;break};case 0:{L=c[o>>2]|0;S=(c[r>>2]|0)+(V>>>3)|0;ca=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(V&7)>>>23;S=(d[1213744+ca|0]|0)+V|0;ha=L>>>0>S>>>0?S:L;c[h>>2]=ha;S=a[1108392+ca|0]|0;Ia=S&255;if((S&255)>>>0>31>>>0){M=72;break a}S=c[b+427476+(Ia<<2)>>2]|0;if((S|0)==0){M=72;break a}do{if((c[S+1152>>2]|0)==0){Ja=ha;Ka=L}else{ca=S+1168|0;if((c[ca>>2]|0)<=0){Ja=ha;Ka=L;break}ba=S+1172|0;P=0;da=ha;ia=L;while(1){ja=c[ba>>2]|0;do{if((ja|0)==0){La=0}else{O=c[r>>2]|0;ma=O+(da>>>3)|0;oa=(fe(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(da&7);if((ja|0)<26){ma=ja+da|0;c[h>>2]=ia>>>0>ma>>>0?ma:ia;La=oa>>>((32-ja|0)>>>0);break}else{ma=da+16|0;ta=ia>>>0>ma>>>0?ma:ia;c[h>>2]=ta;ma=ja-16|0;qa=O+(ta>>>3)|0;O=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ta&7)>>>((48-ja|0)>>>0);qa=ta+ma|0;c[h>>2]=ia>>>0>qa>>>0?qa:ia;La=O|oa>>>16<<ma;break}}}while(0);c[b+572504+(P<<2)>>2]=La;ja=c[o>>2]|0;na=(c[h>>2]|0)+(c[ba>>2]|0)|0;ma=ja>>>0>na>>>0?na:ja;c[h>>2]=ma;na=P+1|0;if((na|0)<(c[ca>>2]|0)){P=na;da=ma;ia=ja}else{Ja=ma;Ka=ja;break}}}}while(0);do{if((c[S+1156>>2]|0)!=0){L=S+1168|0;if((c[L>>2]|0)<=0){break}ha=S+1172|0;ga=0;ia=Ja;da=Ka;do{P=c[ha>>2]|0;do{if((P|0)==0){Ma=0}else{ca=c[r>>2]|0;ba=ca+(ia>>>3)|0;ja=(fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(ia&7);if((P|0)<26){ba=P+ia|0;c[h>>2]=da>>>0>ba>>>0?ba:da;Ma=ja>>>((32-P|0)>>>0);break}else{ba=ia+16|0;ma=da>>>0>ba>>>0?ba:da;c[h>>2]=ma;ba=P-16|0;na=ca+(ma>>>3)|0;ca=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ma&7)>>>((48-P|0)>>>0);na=ma+ba|0;c[h>>2]=da>>>0>na>>>0?na:da;Ma=ca|ja>>>16<<ba;break}}}while(0);c[b+572504+(ga<<2)>>2]=Ma;da=c[o>>2]|0;P=(c[h>>2]|0)+(c[ha>>2]|0)|0;ia=da>>>0>P>>>0?P:da;c[h>>2]=ia;ga=ga+1|0;}while((ga|0)<(c[L>>2]|0))}}while(0);c[z>>2]=1;break};default:{yDb(c[p>>2]|0,48,2187584,(X=i,i=i+8|0,c[X>>2]=Q,X)|0);i=X}}}while(0);S=c[h>>2]|0;L=-S|0;ga=l-S|0;ia=c[o>>2]|0;da=ia-S|0;if((ga|0)<(L|0)){Na=L}else{Na=(da|0)<(ga|0)?da:ga}ga=Na+S|0;S=-ga&7;if((S|0)==0){Oa=ga;Pa=ga}else{da=S+ga|0;ga=ia>>>0>da>>>0?da:ia;Oa=ga;Pa=ga}c[h>>2]=Pa;ga=c[k>>2]|0;if((ga-Oa|0)>16){K=Oa;j=ga}else{m=0;M=112;break}}if((M|0)==11){yDb(c[p>>2]|0,16,2324224,(X=i,i=i+24|0,c[X>>2]=Q,c[X+8>>2]=T<<3,c[X+16>>2]=Y,X)|0);i=X;m=-1094995529;i=e;return m|0}else if((M|0)==72){yDb(c[p>>2]|0,16,2231200,(X=i,i=i+8|0,c[X>>2]=Ia,X)|0);i=X;m=-1094995529;i=e;return m|0}else if((M|0)==112){i=e;return m|0}return 0}function oea(a){a=a|0;var b=0,d=0;b=c[a+572456>>2]|0;a:do{if((b|0)==1){d=2258008}else if((b|0)==0){switch(c[a+572460>>2]|0){case 2:{d=(c[a+572468>>2]|0)==2?1940208:1916e3;break a;break};case 1:{d=(c[a+572468>>2]|0)==2?2006568:1968720;break a;break};case 0:{d=(c[a+572468>>2]|0)==2?2110328:2051976;break a;break};case 5:{d=(c[a+572468>>2]|0)==2?2289592:2273608;break a;break};case 3:{d=(c[a+572468>>2]|0)==2?1895408:2352656;break a;break};case 4:{d=(c[a+572468>>2]|0)==2?2332456:2308176;break a;break};default:{d=2258008;break a}}}else{d=0}}while(0);return d|0}function pea(a,b){a=a|0;b=b|0;var d=0;d=a|0;if((b-9|0)>>>0<8>>>0){c[d>>2]=196;c[a+4>>2]=152;c[a+8>>2]=6;c[a+12>>2]=94;c[a+16>>2]=74;c[a+20>>2]=130;c[a+24>>2]=108;c[a+28>>2]=34;return}else{c[d>>2]=226;c[a+4>>2]=96;c[a+8>>2]=90;c[a+12>>2]=76;c[a+16>>2]=36;c[a+20>>2]=58;c[a+24>>2]=46;c[a+28>>2]=52;return}}function qea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ba(j,c)|0;l=ba(j,g)|0;j=ba(c,h)|0;c=ba(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=g+3|0;n=g+4|0;o=g+5|0;p=g+6|0;q=g+7|0;r=g+8|0;s=a;t=0;u=i;while(1){v=ba(e[s>>1]|0,k)|0;w=s+2|0;x=ba(e[w>>1]|0,l)|0;y=s+(g<<1)|0;z=ba(e[y>>1]|0,j)|0;A=s+(d<<1)|0;b[u>>1]=(v+32+x+z+(ba(e[A>>1]|0,c)|0)|0)>>>6;z=ba(e[w>>1]|0,k)|0;w=s+4|0;x=ba(e[w>>1]|0,l)|0;v=ba(e[A>>1]|0,j)|0;A=s+(h<<1)|0;b[u+2>>1]=(z+32+x+v+(ba(e[A>>1]|0,c)|0)|0)>>>6;v=ba(e[w>>1]|0,k)|0;w=s+6|0;x=ba(e[w>>1]|0,l)|0;z=ba(e[A>>1]|0,j)|0;A=s+(m<<1)|0;b[u+4>>1]=(v+32+x+z+(ba(e[A>>1]|0,c)|0)|0)>>>6;z=ba(e[w>>1]|0,k)|0;w=s+8|0;x=ba(e[w>>1]|0,l)|0;v=ba(e[A>>1]|0,j)|0;A=s+(n<<1)|0;b[u+6>>1]=(z+32+x+v+(ba(e[A>>1]|0,c)|0)|0)>>>6;v=ba(e[w>>1]|0,k)|0;w=s+10|0;x=ba(e[w>>1]|0,l)|0;z=ba(e[A>>1]|0,j)|0;A=s+(o<<1)|0;b[u+8>>1]=(v+32+x+z+(ba(e[A>>1]|0,c)|0)|0)>>>6;z=ba(e[w>>1]|0,k)|0;w=s+12|0;x=ba(e[w>>1]|0,l)|0;v=ba(e[A>>1]|0,j)|0;A=s+(p<<1)|0;b[u+10>>1]=(z+32+x+v+(ba(e[A>>1]|0,c)|0)|0)>>>6;v=ba(e[w>>1]|0,k)|0;w=s+14|0;x=ba(e[w>>1]|0,l)|0;z=ba(e[A>>1]|0,j)|0;A=s+(q<<1)|0;b[u+12>>1]=(v+32+x+z+(ba(e[A>>1]|0,c)|0)|0)>>>6;z=ba(e[w>>1]|0,k)|0;w=ba(e[s+16>>1]|0,l)|0;x=ba(e[A>>1]|0,j)|0;b[u+14>>1]=(z+32+w+x+(ba(e[s+(r<<1)>>1]|0,c)|0)|0)>>>6;x=t+1|0;if((x|0)<(f|0)){s=y;t=x;u=u+(g<<1)|0}else{break}}return}u=l+j|0;if((u|0)==0){if((f|0)>0){B=a;C=0;D=i}else{return}while(1){b[D>>1]=((ba(e[B>>1]|0,k)|0)+32|0)>>>6;b[D+2>>1]=((ba(e[B+2>>1]|0,k)|0)+32|0)>>>6;b[D+4>>1]=((ba(e[B+4>>1]|0,k)|0)+32|0)>>>6;b[D+6>>1]=((ba(e[B+6>>1]|0,k)|0)+32|0)>>>6;b[D+8>>1]=((ba(e[B+8>>1]|0,k)|0)+32|0)>>>6;b[D+10>>1]=((ba(e[B+10>>1]|0,k)|0)+32|0)>>>6;b[D+12>>1]=((ba(e[B+12>>1]|0,k)|0)+32|0)>>>6;b[D+14>>1]=((ba(e[B+14>>1]|0,k)|0)+32|0)>>>6;l=C+1|0;if((l|0)<(f|0)){B=B+(g<<1)|0;C=l;D=D+(g<<1)|0}else{break}}return}D=(j|0)!=0?g:1;if((f|0)<=0){return}j=D+1|0;C=D+2|0;B=D+3|0;l=D+4|0;t=D+5|0;s=D+6|0;c=D+7|0;r=a;a=0;q=i;while(1){i=ba(e[r>>1]|0,k)|0;b[q>>1]=(i+32+(ba(e[r+(D<<1)>>1]|0,u)|0)|0)>>>6;i=ba(e[r+2>>1]|0,k)|0;b[q+2>>1]=(i+32+(ba(e[r+(j<<1)>>1]|0,u)|0)|0)>>>6;i=ba(e[r+4>>1]|0,k)|0;b[q+4>>1]=(i+32+(ba(e[r+(C<<1)>>1]|0,u)|0)|0)>>>6;i=ba(e[r+6>>1]|0,k)|0;b[q+6>>1]=(i+32+(ba(e[r+(B<<1)>>1]|0,u)|0)|0)>>>6;i=ba(e[r+8>>1]|0,k)|0;b[q+8>>1]=(i+32+(ba(e[r+(l<<1)>>1]|0,u)|0)|0)>>>6;i=ba(e[r+10>>1]|0,k)|0;b[q+10>>1]=(i+32+(ba(e[r+(t<<1)>>1]|0,u)|0)|0)>>>6;i=ba(e[r+12>>1]|0,k)|0;b[q+12>>1]=(i+32+(ba(e[r+(s<<1)>>1]|0,u)|0)|0)>>>6;i=ba(e[r+14>>1]|0,k)|0;b[q+14>>1]=(i+32+(ba(e[r+(c<<1)>>1]|0,u)|0)|0)>>>6;i=a+1|0;if((i|0)<(f|0)){r=r+(g<<1)|0;a=i;q=q+(g<<1)|0}else{break}}return}function rea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ba(j,c)|0;l=ba(j,g)|0;j=ba(c,h)|0;c=ba(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=g+3|0;n=g+4|0;o=a;p=0;q=i;while(1){r=ba(e[o>>1]|0,k)|0;s=o+2|0;t=ba(e[s>>1]|0,l)|0;u=o+(g<<1)|0;v=ba(e[u>>1]|0,j)|0;w=o+(d<<1)|0;b[q>>1]=(r+32+t+v+(ba(e[w>>1]|0,c)|0)|0)>>>6;v=ba(e[s>>1]|0,k)|0;s=o+4|0;t=ba(e[s>>1]|0,l)|0;r=ba(e[w>>1]|0,j)|0;w=o+(h<<1)|0;b[q+2>>1]=(v+32+t+r+(ba(e[w>>1]|0,c)|0)|0)>>>6;r=ba(e[s>>1]|0,k)|0;s=o+6|0;t=ba(e[s>>1]|0,l)|0;v=ba(e[w>>1]|0,j)|0;w=o+(m<<1)|0;b[q+4>>1]=(r+32+t+v+(ba(e[w>>1]|0,c)|0)|0)>>>6;v=ba(e[s>>1]|0,k)|0;s=ba(e[o+8>>1]|0,l)|0;t=ba(e[w>>1]|0,j)|0;b[q+6>>1]=(v+32+s+t+(ba(e[o+(n<<1)>>1]|0,c)|0)|0)>>>6;t=p+1|0;if((t|0)<(f|0)){o=u;p=t;q=q+(g<<1)|0}else{break}}return}q=l+j|0;if((q|0)==0){if((f|0)>0){x=a;y=0;z=i}else{return}while(1){b[z>>1]=((ba(e[x>>1]|0,k)|0)+32|0)>>>6;b[z+2>>1]=((ba(e[x+2>>1]|0,k)|0)+32|0)>>>6;b[z+4>>1]=((ba(e[x+4>>1]|0,k)|0)+32|0)>>>6;b[z+6>>1]=((ba(e[x+6>>1]|0,k)|0)+32|0)>>>6;l=y+1|0;if((l|0)<(f|0)){x=x+(g<<1)|0;y=l;z=z+(g<<1)|0}else{break}}return}z=(j|0)!=0?g:1;if((f|0)<=0){return}j=z+1|0;y=z+2|0;x=z+3|0;l=a;a=0;p=i;while(1){i=ba(e[l>>1]|0,k)|0;b[p>>1]=(i+32+(ba(e[l+(z<<1)>>1]|0,q)|0)|0)>>>6;i=ba(e[l+2>>1]|0,k)|0;b[p+2>>1]=(i+32+(ba(e[l+(j<<1)>>1]|0,q)|0)|0)>>>6;i=ba(e[l+4>>1]|0,k)|0;b[p+4>>1]=(i+32+(ba(e[l+(y<<1)>>1]|0,q)|0)|0)>>>6;i=ba(e[l+6>>1]|0,k)|0;b[p+6>>1]=(i+32+(ba(e[l+(x<<1)>>1]|0,q)|0)|0)>>>6;i=a+1|0;if((i|0)<(f|0)){l=l+(g<<1)|0;a=i;p=p+(g<<1)|0}else{break}}return}function sea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ba(j,c)|0;l=ba(j,g)|0;j=ba(c,h)|0;c=ba(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=a;n=0;o=i;while(1){p=ba(e[m>>1]|0,k)|0;q=m+2|0;r=ba(e[q>>1]|0,l)|0;s=m+(g<<1)|0;t=ba(e[s>>1]|0,j)|0;u=m+(d<<1)|0;b[o>>1]=(p+32+r+t+(ba(e[u>>1]|0,c)|0)|0)>>>6;t=ba(e[q>>1]|0,k)|0;q=ba(e[m+4>>1]|0,l)|0;r=ba(e[u>>1]|0,j)|0;b[o+2>>1]=(t+32+q+r+(ba(e[m+(h<<1)>>1]|0,c)|0)|0)>>>6;r=n+1|0;if((r|0)<(f|0)){m=s;n=r;o=o+(g<<1)|0}else{break}}return}o=l+j|0;if((o|0)==0){if((f|0)>0){v=a;w=0;x=i}else{return}while(1){b[x>>1]=((ba(e[v>>1]|0,k)|0)+32|0)>>>6;b[x+2>>1]=((ba(e[v+2>>1]|0,k)|0)+32|0)>>>6;l=w+1|0;if((l|0)<(f|0)){v=v+(g<<1)|0;w=l;x=x+(g<<1)|0}else{break}}return}x=(j|0)!=0?g:1;if((f|0)<=0){return}j=x+1|0;w=a;a=0;v=i;while(1){i=ba(e[w>>1]|0,k)|0;b[v>>1]=(i+32+(ba(e[w+(x<<1)>>1]|0,o)|0)|0)>>>6;i=ba(e[w+2>>1]|0,k)|0;b[v+2>>1]=(i+32+(ba(e[w+(j<<1)>>1]|0,o)|0)|0)>>>6;i=a+1|0;if((i|0)<(f|0)){w=w+(g<<1)|0;a=i;v=v+(g<<1)|0}else{break}}return}function tea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ba(j,c)|0;l=ba(j,g)|0;j=ba(c,h)|0;c=ba(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=a;m=0;n=i;while(1){o=ba(e[h>>1]|0,k)|0;p=ba(e[h+2>>1]|0,l)|0;q=h+(g<<1)|0;r=ba(e[q>>1]|0,j)|0;b[n>>1]=(o+32+p+r+(ba(e[h+(d<<1)>>1]|0,c)|0)|0)>>>6;r=m+1|0;if((r|0)<(f|0)){h=q;m=r;n=n+(g<<1)|0}else{break}}return}n=l+j|0;if((n|0)==0){if((f|0)>0){s=a;t=0;u=i}else{return}while(1){b[u>>1]=((ba(e[s>>1]|0,k)|0)+32|0)>>>6;l=t+1|0;if((l|0)<(f|0)){s=s+(g<<1)|0;t=l;u=u+(g<<1)|0}else{break}}return}else{u=(j|0)!=0?g:1;if((f|0)>0){v=a;w=0;x=i}else{return}while(1){i=ba(e[v>>1]|0,k)|0;b[x>>1]=(i+32+(ba(e[v+(u<<1)>>1]|0,n)|0)|0)>>>6;i=w+1|0;if((i|0)<(f|0)){v=v+(g<<1)|0;w=i;x=x+(g<<1)|0}else{break}}return}}function uea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ba(j,c)|0;l=ba(j,g)|0;j=ba(c,h)|0;c=ba(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=g+3|0;n=g+4|0;o=g+5|0;p=g+6|0;q=g+7|0;r=g+8|0;s=a;t=0;u=i;while(1){v=ba(e[s>>1]|0,k)|0;w=s+2|0;x=ba(e[w>>1]|0,l)|0;y=s+(g<<1)|0;z=ba(e[y>>1]|0,j)|0;A=s+(d<<1)|0;b[u>>1]=((e[u>>1]|0)+1+((v+32+x+z+(ba(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;z=u+2|0;x=ba(e[w>>1]|0,k)|0;w=s+4|0;v=ba(e[w>>1]|0,l)|0;B=ba(e[A>>1]|0,j)|0;A=s+(h<<1)|0;b[z>>1]=((e[z>>1]|0)+1+((x+32+v+B+(ba(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;B=u+4|0;v=ba(e[w>>1]|0,k)|0;w=s+6|0;x=ba(e[w>>1]|0,l)|0;z=ba(e[A>>1]|0,j)|0;A=s+(m<<1)|0;b[B>>1]=((e[B>>1]|0)+1+((v+32+x+z+(ba(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;z=u+6|0;x=ba(e[w>>1]|0,k)|0;w=s+8|0;v=ba(e[w>>1]|0,l)|0;B=ba(e[A>>1]|0,j)|0;A=s+(n<<1)|0;b[z>>1]=((e[z>>1]|0)+1+((x+32+v+B+(ba(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;B=u+8|0;v=ba(e[w>>1]|0,k)|0;w=s+10|0;x=ba(e[w>>1]|0,l)|0;z=ba(e[A>>1]|0,j)|0;A=s+(o<<1)|0;b[B>>1]=((e[B>>1]|0)+1+((v+32+x+z+(ba(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;z=u+10|0;x=ba(e[w>>1]|0,k)|0;w=s+12|0;v=ba(e[w>>1]|0,l)|0;B=ba(e[A>>1]|0,j)|0;A=s+(p<<1)|0;b[z>>1]=((e[z>>1]|0)+1+((x+32+v+B+(ba(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;B=u+12|0;v=ba(e[w>>1]|0,k)|0;w=s+14|0;x=ba(e[w>>1]|0,l)|0;z=ba(e[A>>1]|0,j)|0;A=s+(q<<1)|0;b[B>>1]=((e[B>>1]|0)+1+((v+32+x+z+(ba(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;z=u+14|0;x=ba(e[w>>1]|0,k)|0;w=ba(e[s+16>>1]|0,l)|0;v=ba(e[A>>1]|0,j)|0;b[z>>1]=((e[z>>1]|0)+1+((x+32+w+v+(ba(e[s+(r<<1)>>1]|0,c)|0)|0)>>>6)|0)>>>1;v=t+1|0;if((v|0)<(f|0)){s=y;t=v;u=u+(g<<1)|0}else{break}}return}u=l+j|0;if((u|0)==0){if((f|0)>0){C=a;D=0;E=i}else{return}while(1){b[E>>1]=((e[E>>1]|0)+1+(((ba(e[C>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+2|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[C+2>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+4|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[C+4>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+6|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[C+6>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+8|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[C+8>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+10|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[C+10>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+12|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[C+12>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+14|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[C+14>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=D+1|0;if((l|0)<(f|0)){C=C+(g<<1)|0;D=l;E=E+(g<<1)|0}else{break}}return}E=(j|0)!=0?g:1;if((f|0)<=0){return}j=E+1|0;D=E+2|0;C=E+3|0;l=E+4|0;t=E+5|0;s=E+6|0;c=E+7|0;r=a;a=0;q=i;while(1){i=ba(e[r>>1]|0,k)|0;b[q>>1]=((e[q>>1]|0)+1+((i+32+(ba(e[r+(E<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;i=q+2|0;p=ba(e[r+2>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((p+32+(ba(e[r+(j<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;p=q+4|0;i=ba(e[r+4>>1]|0,k)|0;b[p>>1]=((e[p>>1]|0)+1+((i+32+(ba(e[r+(D<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;i=q+6|0;p=ba(e[r+6>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((p+32+(ba(e[r+(C<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;p=q+8|0;i=ba(e[r+8>>1]|0,k)|0;b[p>>1]=((e[p>>1]|0)+1+((i+32+(ba(e[r+(l<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;i=q+10|0;p=ba(e[r+10>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((p+32+(ba(e[r+(t<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;p=q+12|0;i=ba(e[r+12>>1]|0,k)|0;b[p>>1]=((e[p>>1]|0)+1+((i+32+(ba(e[r+(s<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;i=q+14|0;p=ba(e[r+14>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((p+32+(ba(e[r+(c<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;p=a+1|0;if((p|0)<(f|0)){r=r+(g<<1)|0;a=p;q=q+(g<<1)|0}else{break}}return}function vea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ba(j,c)|0;l=ba(j,g)|0;j=ba(c,h)|0;c=ba(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=g+3|0;n=g+4|0;o=a;p=0;q=i;while(1){r=ba(e[o>>1]|0,k)|0;s=o+2|0;t=ba(e[s>>1]|0,l)|0;u=o+(g<<1)|0;v=ba(e[u>>1]|0,j)|0;w=o+(d<<1)|0;b[q>>1]=((e[q>>1]|0)+1+((r+32+t+v+(ba(e[w>>1]|0,c)|0)|0)>>>6)|0)>>>1;v=q+2|0;t=ba(e[s>>1]|0,k)|0;s=o+4|0;r=ba(e[s>>1]|0,l)|0;x=ba(e[w>>1]|0,j)|0;w=o+(h<<1)|0;b[v>>1]=((e[v>>1]|0)+1+((t+32+r+x+(ba(e[w>>1]|0,c)|0)|0)>>>6)|0)>>>1;x=q+4|0;r=ba(e[s>>1]|0,k)|0;s=o+6|0;t=ba(e[s>>1]|0,l)|0;v=ba(e[w>>1]|0,j)|0;w=o+(m<<1)|0;b[x>>1]=((e[x>>1]|0)+1+((r+32+t+v+(ba(e[w>>1]|0,c)|0)|0)>>>6)|0)>>>1;v=q+6|0;t=ba(e[s>>1]|0,k)|0;s=ba(e[o+8>>1]|0,l)|0;r=ba(e[w>>1]|0,j)|0;b[v>>1]=((e[v>>1]|0)+1+((t+32+s+r+(ba(e[o+(n<<1)>>1]|0,c)|0)|0)>>>6)|0)>>>1;r=p+1|0;if((r|0)<(f|0)){o=u;p=r;q=q+(g<<1)|0}else{break}}return}q=l+j|0;if((q|0)==0){if((f|0)>0){y=a;z=0;A=i}else{return}while(1){b[A>>1]=((e[A>>1]|0)+1+(((ba(e[y>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+2|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[y+2>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+4|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[y+4>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+6|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[y+6>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=z+1|0;if((l|0)<(f|0)){y=y+(g<<1)|0;z=l;A=A+(g<<1)|0}else{break}}return}A=(j|0)!=0?g:1;if((f|0)<=0){return}j=A+1|0;z=A+2|0;y=A+3|0;l=a;a=0;p=i;while(1){i=ba(e[l>>1]|0,k)|0;b[p>>1]=((e[p>>1]|0)+1+((i+32+(ba(e[l+(A<<1)>>1]|0,q)|0)|0)>>>6)|0)>>>1;i=p+2|0;o=ba(e[l+2>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((o+32+(ba(e[l+(j<<1)>>1]|0,q)|0)|0)>>>6)|0)>>>1;o=p+4|0;i=ba(e[l+4>>1]|0,k)|0;b[o>>1]=((e[o>>1]|0)+1+((i+32+(ba(e[l+(z<<1)>>1]|0,q)|0)|0)>>>6)|0)>>>1;i=p+6|0;o=ba(e[l+6>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((o+32+(ba(e[l+(y<<1)>>1]|0,q)|0)|0)>>>6)|0)>>>1;o=a+1|0;if((o|0)<(f|0)){l=l+(g<<1)|0;a=o;p=p+(g<<1)|0}else{break}}return}function wea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ba(j,c)|0;l=ba(j,g)|0;j=ba(c,h)|0;c=ba(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=a;n=0;o=i;while(1){p=ba(e[m>>1]|0,k)|0;q=m+2|0;r=ba(e[q>>1]|0,l)|0;s=m+(g<<1)|0;t=ba(e[s>>1]|0,j)|0;u=m+(d<<1)|0;b[o>>1]=((e[o>>1]|0)+1+((p+32+r+t+(ba(e[u>>1]|0,c)|0)|0)>>>6)|0)>>>1;t=o+2|0;r=ba(e[q>>1]|0,k)|0;q=ba(e[m+4>>1]|0,l)|0;p=ba(e[u>>1]|0,j)|0;b[t>>1]=((e[t>>1]|0)+1+((r+32+q+p+(ba(e[m+(h<<1)>>1]|0,c)|0)|0)>>>6)|0)>>>1;p=n+1|0;if((p|0)<(f|0)){m=s;n=p;o=o+(g<<1)|0}else{break}}return}o=l+j|0;if((o|0)==0){if((f|0)>0){v=a;w=0;x=i}else{return}while(1){b[x>>1]=((e[x>>1]|0)+1+(((ba(e[v>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=x+2|0;b[l>>1]=((e[l>>1]|0)+1+(((ba(e[v+2>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=w+1|0;if((l|0)<(f|0)){v=v+(g<<1)|0;w=l;x=x+(g<<1)|0}else{break}}return}x=(j|0)!=0?g:1;if((f|0)<=0){return}j=x+1|0;w=a;a=0;v=i;while(1){i=ba(e[w>>1]|0,k)|0;b[v>>1]=((e[v>>1]|0)+1+((i+32+(ba(e[w+(x<<1)>>1]|0,o)|0)|0)>>>6)|0)>>>1;i=v+2|0;l=ba(e[w+2>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((l+32+(ba(e[w+(j<<1)>>1]|0,o)|0)|0)>>>6)|0)>>>1;l=a+1|0;if((l|0)<(f|0)){w=w+(g<<1)|0;a=l;v=v+(g<<1)|0}else{break}}return}function xea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ba(j,c)|0;l=ba(j,g)|0;j=ba(c,h)|0;c=ba(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=a;m=0;n=i;while(1){o=ba(e[h>>1]|0,k)|0;p=ba(e[h+2>>1]|0,l)|0;q=h+(g<<1)|0;r=ba(e[q>>1]|0,j)|0;b[n>>1]=((e[n>>1]|0)+1+((o+32+p+r+(ba(e[h+(d<<1)>>1]|0,c)|0)|0)>>>6)|0)>>>1;r=m+1|0;if((r|0)<(f|0)){h=q;m=r;n=n+(g<<1)|0}else{break}}return}n=l+j|0;if((n|0)==0){if((f|0)>0){s=a;t=0;u=i}else{return}while(1){b[u>>1]=((e[u>>1]|0)+1+(((ba(e[s>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=t+1|0;if((l|0)<(f|0)){s=s+(g<<1)|0;t=l;u=u+(g<<1)|0}else{break}}return}else{u=(j|0)!=0?g:1;if((f|0)>0){v=a;w=0;x=i}else{return}while(1){i=ba(e[v>>1]|0,k)|0;b[x>>1]=((e[x>>1]|0)+1+((i+32+(ba(e[v+(u<<1)>>1]|0,n)|0)|0)>>>6)|0)>>>1;i=w+1|0;if((i|0)<(f|0)){v=v+(g<<1)|0;w=i;x=x+(g<<1)|0}else{break}}return}}function yea(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=e+5|0;p=e+6|0;q=e+7|0;r=e+8|0;s=c;t=0;u=b;while(1){v=ba(d[s]|0,k)|0;w=s+1|0;x=ba(d[w]|0,l)|0;y=s+e|0;z=ba(d[y]|0,j)|0;A=s+g|0;a[u]=(v+32+x+z+(ba(d[A]|0,i)|0)|0)>>>6;z=ba(d[w]|0,k)|0;w=s+2|0;x=ba(d[w]|0,l)|0;v=ba(d[A]|0,j)|0;A=s+h|0;a[u+1|0]=(z+32+x+v+(ba(d[A]|0,i)|0)|0)>>>6;v=ba(d[w]|0,k)|0;w=s+3|0;x=ba(d[w]|0,l)|0;z=ba(d[A]|0,j)|0;A=s+m|0;a[u+2|0]=(v+32+x+z+(ba(d[A]|0,i)|0)|0)>>>6;z=ba(d[w]|0,k)|0;w=s+4|0;x=ba(d[w]|0,l)|0;v=ba(d[A]|0,j)|0;A=s+n|0;a[u+3|0]=(z+32+x+v+(ba(d[A]|0,i)|0)|0)>>>6;v=ba(d[w]|0,k)|0;w=s+5|0;x=ba(d[w]|0,l)|0;z=ba(d[A]|0,j)|0;A=s+o|0;a[u+4|0]=(v+32+x+z+(ba(d[A]|0,i)|0)|0)>>>6;z=ba(d[w]|0,k)|0;w=s+6|0;x=ba(d[w]|0,l)|0;v=ba(d[A]|0,j)|0;A=s+p|0;a[u+5|0]=(z+32+x+v+(ba(d[A]|0,i)|0)|0)>>>6;v=ba(d[w]|0,k)|0;w=s+7|0;x=ba(d[w]|0,l)|0;z=ba(d[A]|0,j)|0;A=s+q|0;a[u+6|0]=(v+32+x+z+(ba(d[A]|0,i)|0)|0)>>>6;z=ba(d[w]|0,k)|0;w=ba(d[s+8|0]|0,l)|0;x=ba(d[A]|0,j)|0;a[u+7|0]=(z+32+w+x+(ba(d[s+r|0]|0,i)|0)|0)>>>6;x=t+1|0;if((x|0)<(f|0)){s=y;t=x;u=u+e|0}else{break}}return}u=l+j|0;if((u|0)==0){if((f|0)>0){B=c;C=0;D=b}else{return}while(1){a[D]=((ba(d[B]|0,k)|0)+32|0)>>>6;a[D+1|0]=((ba(d[B+1|0]|0,k)|0)+32|0)>>>6;a[D+2|0]=((ba(d[B+2|0]|0,k)|0)+32|0)>>>6;a[D+3|0]=((ba(d[B+3|0]|0,k)|0)+32|0)>>>6;a[D+4|0]=((ba(d[B+4|0]|0,k)|0)+32|0)>>>6;a[D+5|0]=((ba(d[B+5|0]|0,k)|0)+32|0)>>>6;a[D+6|0]=((ba(d[B+6|0]|0,k)|0)+32|0)>>>6;a[D+7|0]=((ba(d[B+7|0]|0,k)|0)+32|0)>>>6;l=C+1|0;if((l|0)<(f|0)){B=B+e|0;C=l;D=D+e|0}else{break}}return}D=(j|0)!=0?e:1;if((f|0)<=0){return}j=D+1|0;C=D+2|0;B=D+3|0;l=D+4|0;t=D+5|0;s=D+6|0;i=D+7|0;r=c;c=0;q=b;while(1){b=ba(d[r]|0,k)|0;a[q]=(b+32+(ba(d[r+D|0]|0,u)|0)|0)>>>6;b=ba(d[r+1|0]|0,k)|0;a[q+1|0]=(b+32+(ba(d[r+j|0]|0,u)|0)|0)>>>6;b=ba(d[r+2|0]|0,k)|0;a[q+2|0]=(b+32+(ba(d[r+C|0]|0,u)|0)|0)>>>6;b=ba(d[r+3|0]|0,k)|0;a[q+3|0]=(b+32+(ba(d[r+B|0]|0,u)|0)|0)>>>6;b=ba(d[r+4|0]|0,k)|0;a[q+4|0]=(b+32+(ba(d[r+l|0]|0,u)|0)|0)>>>6;b=ba(d[r+5|0]|0,k)|0;a[q+5|0]=(b+32+(ba(d[r+t|0]|0,u)|0)|0)>>>6;b=ba(d[r+6|0]|0,k)|0;a[q+6|0]=(b+32+(ba(d[r+s|0]|0,u)|0)|0)>>>6;b=ba(d[r+7|0]|0,k)|0;a[q+7|0]=(b+32+(ba(d[r+i|0]|0,u)|0)|0)>>>6;b=c+1|0;if((b|0)<(f|0)){r=r+e|0;c=b;q=q+e|0}else{break}}return}function zea(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=c;p=0;q=b;while(1){r=ba(d[o]|0,k)|0;s=o+1|0;t=ba(d[s]|0,l)|0;u=o+e|0;v=ba(d[u]|0,j)|0;w=o+g|0;a[q]=(r+32+t+v+(ba(d[w]|0,i)|0)|0)>>>6;v=ba(d[s]|0,k)|0;s=o+2|0;t=ba(d[s]|0,l)|0;r=ba(d[w]|0,j)|0;w=o+h|0;a[q+1|0]=(v+32+t+r+(ba(d[w]|0,i)|0)|0)>>>6;r=ba(d[s]|0,k)|0;s=o+3|0;t=ba(d[s]|0,l)|0;v=ba(d[w]|0,j)|0;w=o+m|0;a[q+2|0]=(r+32+t+v+(ba(d[w]|0,i)|0)|0)>>>6;v=ba(d[s]|0,k)|0;s=ba(d[o+4|0]|0,l)|0;t=ba(d[w]|0,j)|0;a[q+3|0]=(v+32+s+t+(ba(d[o+n|0]|0,i)|0)|0)>>>6;t=p+1|0;if((t|0)<(f|0)){o=u;p=t;q=q+e|0}else{break}}return}q=l+j|0;if((q|0)==0){if((f|0)>0){x=c;y=0;z=b}else{return}while(1){a[z]=((ba(d[x]|0,k)|0)+32|0)>>>6;a[z+1|0]=((ba(d[x+1|0]|0,k)|0)+32|0)>>>6;a[z+2|0]=((ba(d[x+2|0]|0,k)|0)+32|0)>>>6;a[z+3|0]=((ba(d[x+3|0]|0,k)|0)+32|0)>>>6;l=y+1|0;if((l|0)<(f|0)){x=x+e|0;y=l;z=z+e|0}else{break}}return}z=(j|0)!=0?e:1;if((f|0)<=0){return}j=z+1|0;y=z+2|0;x=z+3|0;l=c;c=0;p=b;while(1){b=ba(d[l]|0,k)|0;a[p]=(b+32+(ba(d[l+z|0]|0,q)|0)|0)>>>6;b=ba(d[l+1|0]|0,k)|0;a[p+1|0]=(b+32+(ba(d[l+j|0]|0,q)|0)|0)>>>6;b=ba(d[l+2|0]|0,k)|0;a[p+2|0]=(b+32+(ba(d[l+y|0]|0,q)|0)|0)>>>6;b=ba(d[l+3|0]|0,k)|0;a[p+3|0]=(b+32+(ba(d[l+x|0]|0,q)|0)|0)>>>6;b=c+1|0;if((b|0)<(f|0)){l=l+e|0;c=b;p=p+e|0}else{break}}return}function Aea(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=c;n=0;o=b;while(1){p=ba(d[m]|0,k)|0;q=m+1|0;r=ba(d[q]|0,l)|0;s=m+e|0;t=ba(d[s]|0,j)|0;u=m+g|0;a[o]=(p+32+r+t+(ba(d[u]|0,i)|0)|0)>>>6;t=ba(d[q]|0,k)|0;q=ba(d[m+2|0]|0,l)|0;r=ba(d[u]|0,j)|0;a[o+1|0]=(t+32+q+r+(ba(d[m+h|0]|0,i)|0)|0)>>>6;r=n+1|0;if((r|0)<(f|0)){m=s;n=r;o=o+e|0}else{break}}return}o=l+j|0;if((o|0)==0){if((f|0)>0){v=c;w=0;x=b}else{return}while(1){a[x]=((ba(d[v]|0,k)|0)+32|0)>>>6;a[x+1|0]=((ba(d[v+1|0]|0,k)|0)+32|0)>>>6;l=w+1|0;if((l|0)<(f|0)){v=v+e|0;w=l;x=x+e|0}else{break}}return}x=(j|0)!=0?e:1;if((f|0)<=0){return}j=x+1|0;w=c;c=0;v=b;while(1){b=ba(d[w]|0,k)|0;a[v]=(b+32+(ba(d[w+x|0]|0,o)|0)|0)>>>6;b=ba(d[w+1|0]|0,k)|0;a[v+1|0]=(b+32+(ba(d[w+j|0]|0,o)|0)|0)>>>6;b=c+1|0;if((b|0)<(f|0)){w=w+e|0;c=b;v=v+e|0}else{break}}return}function Bea(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=c;m=0;n=b;while(1){o=ba(d[h]|0,k)|0;p=ba(d[h+1|0]|0,l)|0;q=h+e|0;r=ba(d[q]|0,j)|0;a[n]=(o+32+p+r+(ba(d[h+g|0]|0,i)|0)|0)>>>6;r=m+1|0;if((r|0)<(f|0)){h=q;m=r;n=n+e|0}else{break}}return}n=l+j|0;if((n|0)==0){if((f|0)>0){s=c;t=0;u=b}else{return}while(1){a[u]=((ba(d[s]|0,k)|0)+32|0)>>>6;l=t+1|0;if((l|0)<(f|0)){s=s+e|0;t=l;u=u+e|0}else{break}}return}else{u=(j|0)!=0?e:1;if((f|0)>0){v=c;w=0;x=b}else{return}while(1){b=ba(d[v]|0,k)|0;a[x]=(b+32+(ba(d[v+u|0]|0,n)|0)|0)>>>6;b=w+1|0;if((b|0)<(f|0)){v=v+e|0;w=b;x=x+e|0}else{break}}return}}function Cea(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=e+5|0;p=e+6|0;q=e+7|0;r=e+8|0;s=c;t=0;u=b;while(1){v=ba(d[s]|0,k)|0;w=s+1|0;x=ba(d[w]|0,l)|0;y=s+e|0;z=ba(d[y]|0,j)|0;A=s+g|0;a[u]=((d[u]|0)+1+((v+32+x+z+(ba(d[A]|0,i)|0)|0)>>>6)|0)>>>1;z=u+1|0;x=ba(d[w]|0,k)|0;w=s+2|0;v=ba(d[w]|0,l)|0;B=ba(d[A]|0,j)|0;A=s+h|0;a[z]=((d[z]|0)+1+((x+32+v+B+(ba(d[A]|0,i)|0)|0)>>>6)|0)>>>1;B=u+2|0;v=ba(d[w]|0,k)|0;w=s+3|0;x=ba(d[w]|0,l)|0;z=ba(d[A]|0,j)|0;A=s+m|0;a[B]=((d[B]|0)+1+((v+32+x+z+(ba(d[A]|0,i)|0)|0)>>>6)|0)>>>1;z=u+3|0;x=ba(d[w]|0,k)|0;w=s+4|0;v=ba(d[w]|0,l)|0;B=ba(d[A]|0,j)|0;A=s+n|0;a[z]=((d[z]|0)+1+((x+32+v+B+(ba(d[A]|0,i)|0)|0)>>>6)|0)>>>1;B=u+4|0;v=ba(d[w]|0,k)|0;w=s+5|0;x=ba(d[w]|0,l)|0;z=ba(d[A]|0,j)|0;A=s+o|0;a[B]=((d[B]|0)+1+((v+32+x+z+(ba(d[A]|0,i)|0)|0)>>>6)|0)>>>1;z=u+5|0;x=ba(d[w]|0,k)|0;w=s+6|0;v=ba(d[w]|0,l)|0;B=ba(d[A]|0,j)|0;A=s+p|0;a[z]=((d[z]|0)+1+((x+32+v+B+(ba(d[A]|0,i)|0)|0)>>>6)|0)>>>1;B=u+6|0;v=ba(d[w]|0,k)|0;w=s+7|0;x=ba(d[w]|0,l)|0;z=ba(d[A]|0,j)|0;A=s+q|0;a[B]=((d[B]|0)+1+((v+32+x+z+(ba(d[A]|0,i)|0)|0)>>>6)|0)>>>1;z=u+7|0;x=ba(d[w]|0,k)|0;w=ba(d[s+8|0]|0,l)|0;v=ba(d[A]|0,j)|0;a[z]=((d[z]|0)+1+((x+32+w+v+(ba(d[s+r|0]|0,i)|0)|0)>>>6)|0)>>>1;v=t+1|0;if((v|0)<(f|0)){s=y;t=v;u=u+e|0}else{break}}return}u=l+j|0;if((u|0)==0){if((f|0)>0){C=c;D=0;E=b}else{return}while(1){a[E]=((d[E]|0)+1+(((ba(d[C]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+1|0;a[l]=((d[l]|0)+1+(((ba(d[C+1|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+2|0;a[l]=((d[l]|0)+1+(((ba(d[C+2|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+3|0;a[l]=((d[l]|0)+1+(((ba(d[C+3|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+4|0;a[l]=((d[l]|0)+1+(((ba(d[C+4|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+5|0;a[l]=((d[l]|0)+1+(((ba(d[C+5|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+6|0;a[l]=((d[l]|0)+1+(((ba(d[C+6|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+7|0;a[l]=((d[l]|0)+1+(((ba(d[C+7|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=D+1|0;if((l|0)<(f|0)){C=C+e|0;D=l;E=E+e|0}else{break}}return}E=(j|0)!=0?e:1;if((f|0)<=0){return}j=E+1|0;D=E+2|0;C=E+3|0;l=E+4|0;t=E+5|0;s=E+6|0;i=E+7|0;r=c;c=0;q=b;while(1){b=ba(d[r]|0,k)|0;a[q]=((d[q]|0)+1+((b+32+(ba(d[r+E|0]|0,u)|0)|0)>>>6)|0)>>>1;b=q+1|0;p=ba(d[r+1|0]|0,k)|0;a[b]=((d[b]|0)+1+((p+32+(ba(d[r+j|0]|0,u)|0)|0)>>>6)|0)>>>1;p=q+2|0;b=ba(d[r+2|0]|0,k)|0;a[p]=((d[p]|0)+1+((b+32+(ba(d[r+D|0]|0,u)|0)|0)>>>6)|0)>>>1;b=q+3|0;p=ba(d[r+3|0]|0,k)|0;a[b]=((d[b]|0)+1+((p+32+(ba(d[r+C|0]|0,u)|0)|0)>>>6)|0)>>>1;p=q+4|0;b=ba(d[r+4|0]|0,k)|0;a[p]=((d[p]|0)+1+((b+32+(ba(d[r+l|0]|0,u)|0)|0)>>>6)|0)>>>1;b=q+5|0;p=ba(d[r+5|0]|0,k)|0;a[b]=((d[b]|0)+1+((p+32+(ba(d[r+t|0]|0,u)|0)|0)>>>6)|0)>>>1;p=q+6|0;b=ba(d[r+6|0]|0,k)|0;a[p]=((d[p]|0)+1+((b+32+(ba(d[r+s|0]|0,u)|0)|0)>>>6)|0)>>>1;b=q+7|0;p=ba(d[r+7|0]|0,k)|0;a[b]=((d[b]|0)+1+((p+32+(ba(d[r+i|0]|0,u)|0)|0)>>>6)|0)>>>1;p=c+1|0;if((p|0)<(f|0)){r=r+e|0;c=p;q=q+e|0}else{break}}return}function Dea(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=c;p=0;q=b;while(1){r=ba(d[o]|0,k)|0;s=o+1|0;t=ba(d[s]|0,l)|0;u=o+e|0;v=ba(d[u]|0,j)|0;w=o+g|0;a[q]=((d[q]|0)+1+((r+32+t+v+(ba(d[w]|0,i)|0)|0)>>>6)|0)>>>1;v=q+1|0;t=ba(d[s]|0,k)|0;s=o+2|0;r=ba(d[s]|0,l)|0;x=ba(d[w]|0,j)|0;w=o+h|0;a[v]=((d[v]|0)+1+((t+32+r+x+(ba(d[w]|0,i)|0)|0)>>>6)|0)>>>1;x=q+2|0;r=ba(d[s]|0,k)|0;s=o+3|0;t=ba(d[s]|0,l)|0;v=ba(d[w]|0,j)|0;w=o+m|0;a[x]=((d[x]|0)+1+((r+32+t+v+(ba(d[w]|0,i)|0)|0)>>>6)|0)>>>1;v=q+3|0;t=ba(d[s]|0,k)|0;s=ba(d[o+4|0]|0,l)|0;r=ba(d[w]|0,j)|0;a[v]=((d[v]|0)+1+((t+32+s+r+(ba(d[o+n|0]|0,i)|0)|0)>>>6)|0)>>>1;r=p+1|0;if((r|0)<(f|0)){o=u;p=r;q=q+e|0}else{break}}return}q=l+j|0;if((q|0)==0){if((f|0)>0){y=c;z=0;A=b}else{return}while(1){a[A]=((d[A]|0)+1+(((ba(d[y]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+1|0;a[l]=((d[l]|0)+1+(((ba(d[y+1|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+2|0;a[l]=((d[l]|0)+1+(((ba(d[y+2|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+3|0;a[l]=((d[l]|0)+1+(((ba(d[y+3|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=z+1|0;if((l|0)<(f|0)){y=y+e|0;z=l;A=A+e|0}else{break}}return}A=(j|0)!=0?e:1;if((f|0)<=0){return}j=A+1|0;z=A+2|0;y=A+3|0;l=c;c=0;p=b;while(1){b=ba(d[l]|0,k)|0;a[p]=((d[p]|0)+1+((b+32+(ba(d[l+A|0]|0,q)|0)|0)>>>6)|0)>>>1;b=p+1|0;o=ba(d[l+1|0]|0,k)|0;a[b]=((d[b]|0)+1+((o+32+(ba(d[l+j|0]|0,q)|0)|0)>>>6)|0)>>>1;o=p+2|0;b=ba(d[l+2|0]|0,k)|0;a[o]=((d[o]|0)+1+((b+32+(ba(d[l+z|0]|0,q)|0)|0)>>>6)|0)>>>1;b=p+3|0;o=ba(d[l+3|0]|0,k)|0;a[b]=((d[b]|0)+1+((o+32+(ba(d[l+y|0]|0,q)|0)|0)>>>6)|0)>>>1;o=c+1|0;if((o|0)<(f|0)){l=l+e|0;c=o;p=p+e|0}else{break}}return}function Eea(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=c;n=0;o=b;while(1){p=ba(d[m]|0,k)|0;q=m+1|0;r=ba(d[q]|0,l)|0;s=m+e|0;t=ba(d[s]|0,j)|0;u=m+g|0;a[o]=((d[o]|0)+1+((p+32+r+t+(ba(d[u]|0,i)|0)|0)>>>6)|0)>>>1;t=o+1|0;r=ba(d[q]|0,k)|0;q=ba(d[m+2|0]|0,l)|0;p=ba(d[u]|0,j)|0;a[t]=((d[t]|0)+1+((r+32+q+p+(ba(d[m+h|0]|0,i)|0)|0)>>>6)|0)>>>1;p=n+1|0;if((p|0)<(f|0)){m=s;n=p;o=o+e|0}else{break}}return}o=l+j|0;if((o|0)==0){if((f|0)>0){v=c;w=0;x=b}else{return}while(1){a[x]=((d[x]|0)+1+(((ba(d[v]|0,k)|0)+32|0)>>>6)|0)>>>1;l=x+1|0;a[l]=((d[l]|0)+1+(((ba(d[v+1|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=w+1|0;if((l|0)<(f|0)){v=v+e|0;w=l;x=x+e|0}else{break}}return}x=(j|0)!=0?e:1;if((f|0)<=0){return}j=x+1|0;w=c;c=0;v=b;while(1){b=ba(d[w]|0,k)|0;a[v]=((d[v]|0)+1+((b+32+(ba(d[w+x|0]|0,o)|0)|0)>>>6)|0)>>>1;b=v+1|0;l=ba(d[w+1|0]|0,k)|0;a[b]=((d[b]|0)+1+((l+32+(ba(d[w+j|0]|0,o)|0)|0)>>>6)|0)>>>1;l=c+1|0;if((l|0)<(f|0)){w=w+e|0;c=l;v=v+e|0}else{break}}return}function Fea(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=8-g|0;j=8-h|0;k=ba(j,i)|0;l=ba(j,g)|0;j=ba(i,h)|0;i=ba(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=c;m=0;n=b;while(1){o=ba(d[h]|0,k)|0;p=ba(d[h+1|0]|0,l)|0;q=h+e|0;r=ba(d[q]|0,j)|0;a[n]=((d[n]|0)+1+((o+32+p+r+(ba(d[h+g|0]|0,i)|0)|0)>>>6)|0)>>>1;r=m+1|0;if((r|0)<(f|0)){h=q;m=r;n=n+e|0}else{break}}return}n=l+j|0;if((n|0)==0){if((f|0)>0){s=c;t=0;u=b}else{return}while(1){a[u]=((d[u]|0)+1+(((ba(d[s]|0,k)|0)+32|0)>>>6)|0)>>>1;l=t+1|0;if((l|0)<(f|0)){s=s+e|0;t=l;u=u+e|0}else{break}}return}else{u=(j|0)!=0?e:1;if((f|0)>0){v=c;w=0;x=b}else{return}while(1){b=ba(d[v]|0,k)|0;a[x]=((d[x]|0)+1+((b+32+(ba(d[v+u|0]|0,n)|0)|0)>>>6)|0)>>>1;b=w+1|0;if((b|0)<(f|0)){v=v+e|0;w=b;x=x+e|0}else{break}}return}}function Gea(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a+128|0;if((b-9|0)>>>0<8>>>0){c[f>>2]=250;c[a+124>>2]=1910}else{c[f>>2]=794;c[a+124>>2]=1352}if((b|0)==9){c[a+84>>2]=544;c[a+88>>2]=28;c[a+92>>2]=1648;c[a+96>>2]=1512;c[a+100>>2]=206;c[a+104>>2]=368;f=(d|0)<2;c[a+108>>2]=f?208:214;c[a+112>>2]=528;c[a+116>>2]=1164;c[a+120>>2]=f?134:124;c[a>>2]=258;c[a+4>>2]=180;c[a+8>>2]=92;c[a+12>>2]=142;c[a+16>>2]=26;c[a+20>>2]=64;c[a+24>>2]=8;c[a+28>>2]=82;c[a+32>>2]=354;c[a+36>>2]=426;c[a+40>>2]=542;c[a+44>>2]=202;c[a+48>>2]=456;c[a+52>>2]=404;c[a+56>>2]=432;c[a+60>>2]=f?320:236;c[a+64>>2]=f?342:524;c[a+68>>2]=764;c[a+72>>2]=f?616:842;c[a+76>>2]=f?504:724;c[a+80>>2]=0;g=a+132|0;c[g>>2]=102;i=e;return}else if((b|0)==12){c[a+84>>2]=1620;c[a+88>>2]=1770;c[a+92>>2]=1528;c[a+96>>2]=1490;c[a+100>>2]=136;c[a+104>>2]=244;f=(d|0)<2;c[a+108>>2]=f?504:120;c[a+112>>2]=366;c[a+116>>2]=1348;c[a+120>>2]=f?484:304;c[a>>2]=10;c[a+4>>2]=192;c[a+8>>2]=246;c[a+12>>2]=202;c[a+16>>2]=76;c[a+20>>2]=104;c[a+24>>2]=122;c[a+28>>2]=16;c[a+32>>2]=410;c[a+36>>2]=388;c[a+40>>2]=454;c[a+44>>2]=22;c[a+48>>2]=42;c[a+52>>2]=472;c[a+56>>2]=162;c[a+60>>2]=f?156:502;c[a+64>>2]=f?10:278;c[a+68>>2]=568;c[a+72>>2]=f?806:546;c[a+76>>2]=f?272:818;c[a+80>>2]=0;g=a+132|0;c[g>>2]=102;i=e;return}else if((b|0)==14){c[a+84>>2]=1924;c[a+88>>2]=2070;c[a+92>>2]=944;c[a+96>>2]=1160;c[a+100>>2]=12;c[a+104>>2]=164;f=(d|0)<2;c[a+108>>2]=f?32:242;c[a+112>>2]=456;c[a+116>>2]=1198;c[a+120>>2]=f?532:456;c[a>>2]=104;c[a+4>>2]=158;c[a+8>>2]=50;c[a+12>>2]=270;c[a+16>>2]=96;c[a+20>>2]=4;c[a+24>>2]=18;c[a+28>>2]=110;c[a+32>>2]=172;c[a+36>>2]=522;c[a+40>>2]=34;c[a+44>>2]=778;c[a+48>>2]=684;c[a+52>>2]=392;c[a+56>>2]=312;c[a+60>>2]=f?36:88;c[a+64>>2]=f?442:372;c[a+68>>2]=350;c[a+72>>2]=f?36:336;c[a+76>>2]=f?476:552;c[a+80>>2]=0;g=a+132|0;c[g>>2]=102;i=e;return}else if((b|0)==10){c[a+84>>2]=1026;c[a+88>>2]=882;c[a+92>>2]=2126;c[a+96>>2]=924;c[a+100>>2]=274;c[a+104>>2]=122;f=(d|0)<2;c[a+108>>2]=f?184:526;c[a+112>>2]=510;c[a+116>>2]=40;c[a+120>>2]=f?282:182;c[a>>2]=240;c[a+4>>2]=264;c[a+8>>2]=16;c[a+12>>2]=136;c[a+16>>2]=36;c[a+20>>2]=62;c[a+24>>2]=68;c[a+28>>2]=54;c[a+32>>2]=536;c[a+36>>2]=228;c[a+40>>2]=302;c[a+44>>2]=672;c[a+48>>2]=222;c[a+52>>2]=730;c[a+56>>2]=42;c[a+60>>2]=f?308:360;c[a+64>>2]=f?82:146;c[a+68>>2]=826;c[a+72>>2]=f?440:224;c[a+76>>2]=f?78:136;c[a+80>>2]=0;g=a+132|0;c[g>>2]=102;i=e;return}else{if((b|0)>=9){yDb(0,0,2281424,(b=i,i=i+24|0,c[b>>2]=2324184,c[b+8>>2]=2187560,c[b+16>>2]=177,b)|0);i=b;Cd()}c[a+84>>2]=2010;c[a+88>>2]=1470;c[a+92>>2]=742;c[a+96>>2]=1844;c[a+100>>2]=134;c[a+104>>2]=452;b=(d|0)<2;c[a+108>>2]=b?280:448;c[a+112>>2]=262;c[a+116>>2]=2088;c[a+120>>2]=b?462:458;c[a>>2]=182;c[a+4>>2]=110;c[a+8>>2]=44;c[a+12>>2]=88;c[a+16>>2]=92;c[a+20>>2]=66;c[a+24>>2]=86;c[a+28>>2]=106;c[a+32>>2]=22;c[a+36>>2]=332;c[a+40>>2]=324;c[a+44>>2]=308;c[a+48>>2]=756;c[a+52>>2]=762;c[a+56>>2]=494;c[a+60>>2]=b?110:112;c[a+64>>2]=b?486:298;c[a+68>>2]=608;c[a+72>>2]=b?702:166;c[a+76>>2]=b?636:854;c[a+80>>2]=0;g=a+132|0;c[g>>2]=102;i=e;return}}function Hea(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0;g=a;h=f>>>1;b[g>>1]=(e[g>>1]|0)+(c[d>>2]|0);f=a+2|0;b[f>>1]=(e[f>>1]|0)+(c[d+4>>2]|0);f=a+4|0;b[f>>1]=(e[f>>1]|0)+(c[d+8>>2]|0);f=a+6|0;b[f>>1]=(e[f>>1]|0)+(c[d+12>>2]|0);f=g+(h<<1)|0;b[f>>1]=(e[f>>1]|0)+(c[d+16>>2]|0);f=g+(h+1<<1)|0;b[f>>1]=(e[f>>1]|0)+(c[d+20>>2]|0);f=g+(h+2<<1)|0;b[f>>1]=(e[f>>1]|0)+(c[d+24>>2]|0);f=g+(h+3<<1)|0;b[f>>1]=(e[f>>1]|0)+(c[d+28>>2]|0);f=h<<1;a=g+(f<<1)|0;b[a>>1]=(e[a>>1]|0)+(c[d+32>>2]|0);a=g+((f|1)<<1)|0;b[a>>1]=(e[a>>1]|0)+(c[d+36>>2]|0);a=g+(f+2<<1)|0;b[a>>1]=(e[a>>1]|0)+(c[d+40>>2]|0);a=g+(f+3<<1)|0;b[a>>1]=(e[a>>1]|0)+(c[d+44>>2]|0);a=f+h|0;h=g+(a<<1)|0;b[h>>1]=(e[h>>1]|0)+(c[d+48>>2]|0);h=g+(a+1<<1)|0;b[h>>1]=(e[h>>1]|0)+(c[d+52>>2]|0);h=g+(a+2<<1)|0;b[h>>1]=(e[h>>1]|0)+(c[d+56>>2]|0);h=g+(a+3<<1)|0;b[h>>1]=(e[h>>1]|0)+(c[d+60>>2]|0);TGb(d|0,0,64)|0;return}function Iea(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=f>>>1;f=0;h=a;a=d;while(1){b[h>>1]=(e[h>>1]|0)+(c[a>>2]|0);i=h+2|0;b[i>>1]=(e[i>>1]|0)+(c[a+4>>2]|0);i=h+4|0;b[i>>1]=(e[i>>1]|0)+(c[a+8>>2]|0);i=h+6|0;b[i>>1]=(e[i>>1]|0)+(c[a+12>>2]|0);i=h+8|0;b[i>>1]=(e[i>>1]|0)+(c[a+16>>2]|0);i=h+10|0;b[i>>1]=(e[i>>1]|0)+(c[a+20>>2]|0);i=h+12|0;b[i>>1]=(e[i>>1]|0)+(c[a+24>>2]|0);i=h+14|0;b[i>>1]=(e[i>>1]|0)+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}TGb(d|0,0,256)|0;return}function Jea(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0;a[c]=(a[c]|0)+(b[d>>1]&255);f=c+1|0;a[f]=(a[f]|0)+(b[d+2>>1]&255);f=c+2|0;a[f]=(a[f]|0)+(b[d+4>>1]&255);f=c+3|0;a[f]=(a[f]|0)+(b[d+6>>1]&255);f=c+e|0;a[f]=(a[f]|0)+(b[d+8>>1]&255);f=c+(e+1)|0;a[f]=(a[f]|0)+(b[d+10>>1]&255);f=c+(e+2)|0;a[f]=(a[f]|0)+(b[d+12>>1]&255);f=c+(e+3)|0;a[f]=(a[f]|0)+(b[d+14>>1]&255);f=e<<1;g=c+f|0;a[g]=(a[g]|0)+(b[d+16>>1]&255);g=c+(f|1)|0;a[g]=(a[g]|0)+(b[d+18>>1]&255);g=c+(f+2)|0;a[g]=(a[g]|0)+(b[d+20>>1]&255);g=c+(f+3)|0;a[g]=(a[g]|0)+(b[d+22>>1]&255);g=f+e|0;e=c+g|0;a[e]=(a[e]|0)+(b[d+24>>1]&255);e=c+(g+1)|0;a[e]=(a[e]|0)+(b[d+26>>1]&255);e=c+(g+2)|0;a[e]=(a[e]|0)+(b[d+28>>1]&255);e=c+(g+3)|0;a[e]=(a[e]|0)+(b[d+30>>1]&255);TGb(d|0,0,32)|0;return}function Kea(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=0;g=c;c=d;while(1){a[g]=(a[g]|0)+(b[c>>1]&255);h=g+1|0;a[h]=(a[h]|0)+(b[c+2>>1]&255);h=g+2|0;a[h]=(a[h]|0)+(b[c+4>>1]&255);h=g+3|0;a[h]=(a[h]|0)+(b[c+6>>1]&255);h=g+4|0;a[h]=(a[h]|0)+(b[c+8>>1]&255);h=g+5|0;a[h]=(a[h]|0)+(b[c+10>>1]&255);h=g+6|0;a[h]=(a[h]|0)+(b[c+12>>1]&255);h=g+7|0;a[h]=(a[h]|0)+(b[c+14>>1]&255);h=f+1|0;if((h|0)<8){f=h;g=g+e|0;c=c+16|0}else{break}}TGb(d|0,0,128)|0;return}function Lea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c>>1;c=h<<f+1;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<512>>>0){m=a&65535}else{m=-a>>31&511}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){n=c&65535}else{n=-c>>31&511}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){o=c&65535}else{o=-c>>31&511}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){p=c&65535}else{p=-c>>31&511}b[a>>1]=p;a=l+8|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){q=c&65535}else{q=-c>>31&511}b[a>>1]=q;a=l+10|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[a>>1]=r;a=l+12|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){s=c&65535}else{s=-c>>31&511}b[a>>1]=s;a=l+14|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){t=c&65535}else{t=-c>>31&511}b[a>>1]=t;a=l+16|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){u=c&65535}else{u=-c>>31&511}b[a>>1]=u;a=l+18|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){v=c&65535}else{v=-c>>31&511}b[a>>1]=v;a=l+20|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){w=c&65535}else{w=-c>>31&511}b[a>>1]=w;a=l+22|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){x=c&65535}else{x=-c>>31&511}b[a>>1]=x;a=l+24|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){y=c&65535}else{y=-c>>31&511}b[a>>1]=y;a=l+26|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){z=c&65535}else{z=-c>>31&511}b[a>>1]=z;a=l+28|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){A=c&65535}else{A=-c>>31&511}b[a>>1]=A;a=l+30|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){B=c&65535}else{B=-c>>31&511}b[a>>1]=B;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Mea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c>>1;c=h<<f+1;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<512>>>0){m=a&65535}else{m=-a>>31&511}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){n=c&65535}else{n=-c>>31&511}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){o=c&65535}else{o=-c>>31&511}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){p=c&65535}else{p=-c>>31&511}b[a>>1]=p;a=l+8|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){q=c&65535}else{q=-c>>31&511}b[a>>1]=q;a=l+10|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[a>>1]=r;a=l+12|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){s=c&65535}else{s=-c>>31&511}b[a>>1]=s;a=l+14|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){t=c&65535}else{t=-c>>31&511}b[a>>1]=t;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Nea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=c>>1;c=h<<f+1;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<512>>>0){m=a&65535}else{m=-a>>31&511}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){n=c&65535}else{n=-c>>31&511}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){o=c&65535}else{o=-c>>31&511}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){p=c&65535}else{p=-c>>31&511}b[a>>1]=p;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Oea(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c>>1;c=h<<f+1;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<512>>>0){m=a&65535}else{m=-a>>31&511}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){n=c&65535}else{n=-c>>31&511}b[a>>1]=n;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Pea(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=d>>1;d=(j<<1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){q=m&65535}else{q=-m>>31&511}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[m>>1]=r;m=ba(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){s=o&65535}else{s=-o>>31&511}b[c>>1]=s;c=ba(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){t=m&65535}else{t=-m>>31&511}b[o>>1]=t;o=ba(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){u=c&65535}else{u=-c>>31&511}b[m>>1]=u;m=ba(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){v=o&65535}else{v=-o>>31&511}b[c>>1]=v;c=ba(e[a+16>>1]|0,i)|0;o=l+16|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){w=m&65535}else{w=-m>>31&511}b[o>>1]=w;o=ba(e[a+18>>1]|0,i)|0;m=l+18|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){x=c&65535}else{x=-c>>31&511}b[m>>1]=x;m=ba(e[a+20>>1]|0,i)|0;c=l+20|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){y=o&65535}else{y=-o>>31&511}b[c>>1]=y;c=ba(e[a+22>>1]|0,i)|0;o=l+22|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){z=m&65535}else{z=-m>>31&511}b[o>>1]=z;o=ba(e[a+24>>1]|0,i)|0;m=l+24|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){A=c&65535}else{A=-c>>31&511}b[m>>1]=A;m=ba(e[a+26>>1]|0,i)|0;c=l+26|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){B=o&65535}else{B=-o>>31&511}b[c>>1]=B;c=ba(e[a+28>>1]|0,i)|0;o=l+28|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){C=m&65535}else{C=-m>>31&511}b[o>>1]=C;o=ba(e[a+30>>1]|0,i)|0;m=l+30|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){D=c&65535}else{D=-c>>31&511}b[m>>1]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Qea(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=d>>1;d=(j<<1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){q=m&65535}else{q=-m>>31&511}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[m>>1]=r;m=ba(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){s=o&65535}else{s=-o>>31&511}b[c>>1]=s;c=ba(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){t=m&65535}else{t=-m>>31&511}b[o>>1]=t;o=ba(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){u=c&65535}else{u=-c>>31&511}b[m>>1]=u;m=ba(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){v=o&65535}else{v=-o>>31&511}b[c>>1]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Rea(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=d>>1;d=(j<<1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){q=m&65535}else{q=-m>>31&511}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[m>>1]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Sea(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=d>>1;d=(j<<1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[c>>1]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Tea(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=d>>1;d=f<<1;f=g<<1;g=-i|0;j=i*-2|0;k=i*-3|0;l=i<<1;m=0;n=c;while(1){c=a[h+m|0]<<1;if((c|0)>=0){o=(c|0)==0;p=c|1;q=-c|0;r=0;s=n;while(1){t=s+(g<<1)|0;u=e[t>>1]|0;v=s+(j<<1)|0;w=e[v>>1]|0;x=e[s+(k<<1)>>1]|0;y=e[s>>1]|0;z=s+(i<<1)|0;A=e[z>>1]|0;B=e[s+(l<<1)>>1]|0;C=u-y|0;do{if((((C|0)>-1?C:-C|0)|0)<(d|0)){D=w-u|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=A-y|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=x-u|0;E=(((D|0)>-1?D:-D|0)|0)>=(f|0);if(E|o){F=E?c:p}else{E=((((u+1+y|0)>>>1)+x|0)>>>1)-w|0;if((E|0)<(q|0)){G=q}else{G=(E|0)>(c|0)?c:E}b[v>>1]=G+w;F=p}E=B-y|0;if((((E|0)>-1?E:-E|0)|0)<(f|0)){if(!o){E=((B+((u+1+y|0)>>>1)|0)>>>1)-A|0;if((E|0)<(q|0)){H=q}else{H=(E|0)>(c|0)?c:E}b[z>>1]=H+A}I=F+1|0}else{I=F}E=w+4-A+(y-u<<2)>>3;D=-I|0;if((E|0)<(D|0)){J=D}else{J=(E|0)>(I|0)?I:E}E=J+u|0;if(E>>>0<512>>>0){K=E&65535}else{K=-E>>31&511}b[t>>1]=K;E=y-J|0;if(E>>>0<512>>>0){L=E&65535}else{L=-E>>31&511}b[s>>1]=L}}while(0);y=r+1|0;if((y|0)<4){r=y;s=s+2|0}else{break}}}s=m+1|0;if((s|0)<4){m=s;n=n+8|0}else{break}}return}function Uea(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<1;f=g<<1;g=i<<2;j=0;k=c;while(1){c=a[h+j|0]<<1;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<512>>>0){H=B&65535}else{H=-B>>31&511}b[q>>1]=H;B=v-G|0;if(B>>>0<512>>>0){I=B&65535}else{I=-B>>31&511}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<4){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function Vea(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<1;f=g<<1;g=i<<1;j=0;k=c;while(1){c=a[h+j|0]<<1;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<512>>>0){H=B&65535}else{H=-B>>31&511}b[q>>1]=H;B=v-G|0;if(B>>>0<512>>>0){I=B&65535}else{I=-B>>31&511}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<2){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function Wea(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c>>1;c=d<<1;d=f<<1;f=g*-3|0;h=g*-2|0;i=-g|0;j=g<<1;k=(c>>2)+2|0;l=g*-4|0;m=g*3|0;n=0;o=a;while(1){a=o+(f<<1)|0;p=e[a>>1]|0;q=o+(h<<1)|0;r=e[q>>1]|0;s=o+(i<<1)|0;t=e[s>>1]|0;u=e[o>>1]|0;v=o+(g<<1)|0;w=e[v>>1]|0;x=o+(j<<1)|0;y=e[x>>1]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(c|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}if((A|0)>=(k|0)){b[s>>1]=(t+2+(r<<1)+w|0)>>>2;b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(l<<1)>>1]|0;b[s>>1]=(p+4+w+(t+r+u<<1)|0)>>>3;b[q>>1]=(p+2+r+t+u|0)>>>2;b[a>>1]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{b[s>>1]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(m<<1)>>1]|0;b[o>>1]=(r+4+y+(u+t+w<<1)|0)>>>3;b[v>>1]=(t+2+u+w+y|0)>>>2;b[x>>1]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+2|0}else{break}}return}function Xea(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<1;d=f<<1;f=(c>>2)+2|0;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+(g<<1)|0}else{break}}return}function Yea(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<1;d=f<<1;f=(c>>2)+2|0;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+(g<<1)|0}else{break}}return}function Zea(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=f<<1;f=g<<1;g=d>>1;d=-g|0;j=g*-2|0;k=0;l=c;while(1){c=a[h+k|0]<<1;m=c-1|0;do{if((m|0)>=1){n=1-c|0;o=l+(d<<1)|0;p=e[o>>1]|0;q=e[l+(j<<1)>>1]|0;r=e[l>>1]|0;s=e[l+(g<<1)>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(n|0)){v=n}else{v=(u|0)>(m|0)?m:u}u=v+p|0;if(u>>>0<512>>>0){w=u&65535}else{w=-u>>31&511}b[o>>1]=w;u=r-v|0;if(u>>>0<512>>>0){x=u&65535}else{x=-u>>31&511}b[l>>1]=x}}while(0);r=l+2|0;o=l+(1-g<<1)|0;p=e[o>>1]|0;s=e[l+((j|1)<<1)>>1]|0;q=e[r>>1]|0;t=e[l+(g+1<<1)>>1]|0;u=p-q|0;if((((u|0)>-1?u:-u|0)|0)>=(i|0)){break}u=s-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=t-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s+4-t+(q-p<<2)>>3;if((u|0)<(n|0)){y=n}else{y=(u|0)>(m|0)?m:u}u=y+p|0;if(u>>>0<512>>>0){z=u&65535}else{z=-u>>31&511}b[o>>1]=z;o=q-y|0;if(o>>>0<512>>>0){A=o&65535}else{A=-o>>31&511}b[r>>1]=A}}while(0);m=k+1|0;if((m|0)<4){k=m;l=l+4|0}else{break}}return}function _ea(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<1;f=g<<1;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<1;l=c-1|0;do{if((l|0)>=1){m=1-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<512>>>0){v=t&65535}else{v=-t>>31&511}b[n>>1]=v;t=q-u|0;if(t>>>0<512>>>0){w=t&65535}else{w=-t>>31&511}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<512>>>0){y=t&65535}else{y=-t>>31&511}b[n>>1]=y;n=p-x|0;if(n>>>0<512>>>0){z=n&65535}else{z=-n>>31&511}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function $ea(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=f<<1;f=g<<1;g=d>>1;d=g<<2;j=0;k=c;while(1){c=a[h+j|0]<<1;l=c-1|0;if((l|0)>=1){m=1-c|0;c=0;n=k;while(1){o=n-2|0;p=e[o>>1]|0;q=e[n-4>>1]|0;r=e[n>>1]|0;s=e[n+2>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}u=v+p|0;if(u>>>0<512>>>0){w=u&65535}else{w=-u>>31&511}b[o>>1]=w;u=r-v|0;if(u>>>0<512>>>0){x=u&65535}else{x=-u>>31&511}b[n>>1]=x}}while(0);r=c+1|0;if((r|0)<4){c=r;n=n+(g<<1)|0}else{break}}}n=j+1|0;if((n|0)<4){j=n;k=k+(d<<1)|0}else{break}}return}function afa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=f<<1;f=g<<1;g=d>>1;d=0;j=c;while(1){c=a[h+d|0]<<1;k=c-1|0;do{if((k|0)>=1){l=1-c|0;m=j-2|0;n=e[m>>1]|0;o=e[j-4>>1]|0;p=e[j>>1]|0;q=e[j+2>>1]|0;r=n-p|0;if((((r|0)>-1?r:-r|0)|0)>=(i|0)){break}r=o-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=q-p|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=o+4-q+(p-n<<2)>>3;if((r|0)<(l|0)){s=l}else{s=(r|0)>(k|0)?k:r}r=s+n|0;if(r>>>0<512>>>0){t=r&65535}else{t=-r>>31&511}b[m>>1]=t;m=p-s|0;if(m>>>0<512>>>0){u=m&65535}else{u=-m>>31&511}b[j>>1]=u}}while(0);k=d+1|0;if((k|0)<4){d=k;j=j+(g<<1)|0}else{break}}return}function bfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<1;f=g<<1;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<1;l=c-1|0;do{if((l|0)>=1){m=1-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<512>>>0){v=t&65535}else{v=-t>>31&511}b[n>>1]=v;t=q-u|0;if(t>>>0<512>>>0){w=t&65535}else{w=-t>>31&511}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<512>>>0){y=t&65535}else{y=-t>>31&511}b[n>>1]=y;n=p-x|0;if(n>>>0<512>>>0){z=n&65535}else{z=-n>>31&511}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function cfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c>>1;c=d<<1;d=f<<1;f=-g|0;h=g*-2|0;i=a;a=0;while(1){j=i+(f<<1)|0;k=e[j>>1]|0;l=e[i+(h<<1)>>1]|0;m=e[i>>1]|0;n=e[i+(g<<1)>>1]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(c|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}b[j>>1]=(k+2+(l<<1)+n|0)>>>2;b[i>>1]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=a+1|0;if((n|0)<8){i=i+2|0;a=n}else{break}}return}function dfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<1;d=f<<1;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function efa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<1;d=f<<1;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<16){f=f+(g<<1)|0;a=l}else{break}}return}function ffa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<1;d=f<<1;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<4){f=f+(g<<1)|0;a=l}else{break}}return}function gfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<1;d=f<<1;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function hfa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c>>1;c=h<<f+2;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<1024>>>0){m=a&65535}else{m=-a>>31&1023}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){n=c&65535}else{n=-c>>31&1023}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){o=c&65535}else{o=-c>>31&1023}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){p=c&65535}else{p=-c>>31&1023}b[a>>1]=p;a=l+8|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){q=c&65535}else{q=-c>>31&1023}b[a>>1]=q;a=l+10|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[a>>1]=r;a=l+12|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){s=c&65535}else{s=-c>>31&1023}b[a>>1]=s;a=l+14|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){t=c&65535}else{t=-c>>31&1023}b[a>>1]=t;a=l+16|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){u=c&65535}else{u=-c>>31&1023}b[a>>1]=u;a=l+18|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){v=c&65535}else{v=-c>>31&1023}b[a>>1]=v;a=l+20|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){w=c&65535}else{w=-c>>31&1023}b[a>>1]=w;a=l+22|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){x=c&65535}else{x=-c>>31&1023}b[a>>1]=x;a=l+24|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){y=c&65535}else{y=-c>>31&1023}b[a>>1]=y;a=l+26|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){z=c&65535}else{z=-c>>31&1023}b[a>>1]=z;a=l+28|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){A=c&65535}else{A=-c>>31&1023}b[a>>1]=A;a=l+30|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){B=c&65535}else{B=-c>>31&1023}b[a>>1]=B;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function ifa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c>>1;c=h<<f+2;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<1024>>>0){m=a&65535}else{m=-a>>31&1023}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){n=c&65535}else{n=-c>>31&1023}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){o=c&65535}else{o=-c>>31&1023}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){p=c&65535}else{p=-c>>31&1023}b[a>>1]=p;a=l+8|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){q=c&65535}else{q=-c>>31&1023}b[a>>1]=q;a=l+10|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[a>>1]=r;a=l+12|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){s=c&65535}else{s=-c>>31&1023}b[a>>1]=s;a=l+14|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){t=c&65535}else{t=-c>>31&1023}b[a>>1]=t;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function jfa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=c>>1;c=h<<f+2;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<1024>>>0){m=a&65535}else{m=-a>>31&1023}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){n=c&65535}else{n=-c>>31&1023}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){o=c&65535}else{o=-c>>31&1023}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){p=c&65535}else{p=-c>>31&1023}b[a>>1]=p;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function kfa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c>>1;c=h<<f+2;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<1024>>>0){m=a&65535}else{m=-a>>31&1023}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){n=c&65535}else{n=-c>>31&1023}b[a>>1]=n;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function lfa(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=d>>1;d=(j<<2|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){q=m&65535}else{q=-m>>31&1023}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[m>>1]=r;m=ba(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){s=o&65535}else{s=-o>>31&1023}b[c>>1]=s;c=ba(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){t=m&65535}else{t=-m>>31&1023}b[o>>1]=t;o=ba(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){u=c&65535}else{u=-c>>31&1023}b[m>>1]=u;m=ba(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){v=o&65535}else{v=-o>>31&1023}b[c>>1]=v;c=ba(e[a+16>>1]|0,i)|0;o=l+16|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){w=m&65535}else{w=-m>>31&1023}b[o>>1]=w;o=ba(e[a+18>>1]|0,i)|0;m=l+18|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){x=c&65535}else{x=-c>>31&1023}b[m>>1]=x;m=ba(e[a+20>>1]|0,i)|0;c=l+20|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){y=o&65535}else{y=-o>>31&1023}b[c>>1]=y;c=ba(e[a+22>>1]|0,i)|0;o=l+22|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){z=m&65535}else{z=-m>>31&1023}b[o>>1]=z;o=ba(e[a+24>>1]|0,i)|0;m=l+24|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){A=c&65535}else{A=-c>>31&1023}b[m>>1]=A;m=ba(e[a+26>>1]|0,i)|0;c=l+26|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){B=o&65535}else{B=-o>>31&1023}b[c>>1]=B;c=ba(e[a+28>>1]|0,i)|0;o=l+28|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){C=m&65535}else{C=-m>>31&1023}b[o>>1]=C;o=ba(e[a+30>>1]|0,i)|0;m=l+30|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){D=c&65535}else{D=-c>>31&1023}b[m>>1]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function mfa(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=d>>1;d=(j<<2|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){q=m&65535}else{q=-m>>31&1023}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[m>>1]=r;m=ba(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){s=o&65535}else{s=-o>>31&1023}b[c>>1]=s;c=ba(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){t=m&65535}else{t=-m>>31&1023}b[o>>1]=t;o=ba(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){u=c&65535}else{u=-c>>31&1023}b[m>>1]=u;m=ba(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){v=o&65535}else{v=-o>>31&1023}b[c>>1]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function nfa(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=d>>1;d=(j<<2|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){q=m&65535}else{q=-m>>31&1023}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[m>>1]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function ofa(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=d>>1;d=(j<<2|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[c>>1]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function pfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=d>>1;d=f<<2;f=g<<2;g=-i|0;j=i*-2|0;k=i*-3|0;l=i<<1;m=0;n=c;while(1){c=a[h+m|0]<<2;if((c|0)>=0){o=(c|0)==0;p=c|1;q=-c|0;r=0;s=n;while(1){t=s+(g<<1)|0;u=e[t>>1]|0;v=s+(j<<1)|0;w=e[v>>1]|0;x=e[s+(k<<1)>>1]|0;y=e[s>>1]|0;z=s+(i<<1)|0;A=e[z>>1]|0;B=e[s+(l<<1)>>1]|0;C=u-y|0;do{if((((C|0)>-1?C:-C|0)|0)<(d|0)){D=w-u|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=A-y|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=x-u|0;E=(((D|0)>-1?D:-D|0)|0)>=(f|0);if(E|o){F=E?c:p}else{E=((((u+1+y|0)>>>1)+x|0)>>>1)-w|0;if((E|0)<(q|0)){G=q}else{G=(E|0)>(c|0)?c:E}b[v>>1]=G+w;F=p}E=B-y|0;if((((E|0)>-1?E:-E|0)|0)<(f|0)){if(!o){E=((B+((u+1+y|0)>>>1)|0)>>>1)-A|0;if((E|0)<(q|0)){H=q}else{H=(E|0)>(c|0)?c:E}b[z>>1]=H+A}I=F+1|0}else{I=F}E=w+4-A+(y-u<<2)>>3;D=-I|0;if((E|0)<(D|0)){J=D}else{J=(E|0)>(I|0)?I:E}E=J+u|0;if(E>>>0<1024>>>0){K=E&65535}else{K=-E>>31&1023}b[t>>1]=K;E=y-J|0;if(E>>>0<1024>>>0){L=E&65535}else{L=-E>>31&1023}b[s>>1]=L}}while(0);y=r+1|0;if((y|0)<4){r=y;s=s+2|0}else{break}}}s=m+1|0;if((s|0)<4){m=s;n=n+8|0}else{break}}return}function qfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<2;f=g<<2;g=i<<2;j=0;k=c;while(1){c=a[h+j|0]<<2;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<1024>>>0){H=B&65535}else{H=-B>>31&1023}b[q>>1]=H;B=v-G|0;if(B>>>0<1024>>>0){I=B&65535}else{I=-B>>31&1023}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<4){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function rfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<2;f=g<<2;g=i<<1;j=0;k=c;while(1){c=a[h+j|0]<<2;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<1024>>>0){H=B&65535}else{H=-B>>31&1023}b[q>>1]=H;B=v-G|0;if(B>>>0<1024>>>0){I=B&65535}else{I=-B>>31&1023}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<2){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function sfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c>>1;c=d<<2;d=f<<2;f=g*-3|0;h=g*-2|0;i=-g|0;j=g<<1;k=(c>>2)+2|0;l=g*-4|0;m=g*3|0;n=0;o=a;while(1){a=o+(f<<1)|0;p=e[a>>1]|0;q=o+(h<<1)|0;r=e[q>>1]|0;s=o+(i<<1)|0;t=e[s>>1]|0;u=e[o>>1]|0;v=o+(g<<1)|0;w=e[v>>1]|0;x=o+(j<<1)|0;y=e[x>>1]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(c|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}if((A|0)>=(k|0)){b[s>>1]=(t+2+(r<<1)+w|0)>>>2;b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(l<<1)>>1]|0;b[s>>1]=(p+4+w+(t+r+u<<1)|0)>>>3;b[q>>1]=(p+2+r+t+u|0)>>>2;b[a>>1]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{b[s>>1]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(m<<1)>>1]|0;b[o>>1]=(r+4+y+(u+t+w<<1)|0)>>>3;b[v>>1]=(t+2+u+w+y|0)>>>2;b[x>>1]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+2|0}else{break}}return}function tfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<2;d=f<<2;f=(c>>2)+2|0;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+(g<<1)|0}else{break}}return}function ufa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<2;d=f<<2;f=(c>>2)+2|0;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+(g<<1)|0}else{break}}return}function vfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=f<<2;f=g<<2;g=d>>1;d=-g|0;j=g*-2|0;k=0;l=c;while(1){c=a[h+k|0]<<2;m=c-3|0;do{if((m|0)>=1){n=3-c|0;o=l+(d<<1)|0;p=e[o>>1]|0;q=e[l+(j<<1)>>1]|0;r=e[l>>1]|0;s=e[l+(g<<1)>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(n|0)){v=n}else{v=(u|0)>(m|0)?m:u}u=v+p|0;if(u>>>0<1024>>>0){w=u&65535}else{w=-u>>31&1023}b[o>>1]=w;u=r-v|0;if(u>>>0<1024>>>0){x=u&65535}else{x=-u>>31&1023}b[l>>1]=x}}while(0);r=l+2|0;o=l+(1-g<<1)|0;p=e[o>>1]|0;s=e[l+((j|1)<<1)>>1]|0;q=e[r>>1]|0;t=e[l+(g+1<<1)>>1]|0;u=p-q|0;if((((u|0)>-1?u:-u|0)|0)>=(i|0)){break}u=s-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=t-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s+4-t+(q-p<<2)>>3;if((u|0)<(n|0)){y=n}else{y=(u|0)>(m|0)?m:u}u=y+p|0;if(u>>>0<1024>>>0){z=u&65535}else{z=-u>>31&1023}b[o>>1]=z;o=q-y|0;if(o>>>0<1024>>>0){A=o&65535}else{A=-o>>31&1023}b[r>>1]=A}}while(0);m=k+1|0;if((m|0)<4){k=m;l=l+4|0}else{break}}return}function wfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<2;f=g<<2;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<2;l=c-3|0;do{if((l|0)>=1){m=3-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<1024>>>0){v=t&65535}else{v=-t>>31&1023}b[n>>1]=v;t=q-u|0;if(t>>>0<1024>>>0){w=t&65535}else{w=-t>>31&1023}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<1024>>>0){y=t&65535}else{y=-t>>31&1023}b[n>>1]=y;n=p-x|0;if(n>>>0<1024>>>0){z=n&65535}else{z=-n>>31&1023}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function xfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=f<<2;f=g<<2;g=d>>1;d=g<<2;j=0;k=c;while(1){c=a[h+j|0]<<2;l=c-3|0;if((l|0)>=1){m=3-c|0;c=0;n=k;while(1){o=n-2|0;p=e[o>>1]|0;q=e[n-4>>1]|0;r=e[n>>1]|0;s=e[n+2>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}u=v+p|0;if(u>>>0<1024>>>0){w=u&65535}else{w=-u>>31&1023}b[o>>1]=w;u=r-v|0;if(u>>>0<1024>>>0){x=u&65535}else{x=-u>>31&1023}b[n>>1]=x}}while(0);r=c+1|0;if((r|0)<4){c=r;n=n+(g<<1)|0}else{break}}}n=j+1|0;if((n|0)<4){j=n;k=k+(d<<1)|0}else{break}}return}function yfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=f<<2;f=g<<2;g=d>>1;d=0;j=c;while(1){c=a[h+d|0]<<2;k=c-3|0;do{if((k|0)>=1){l=3-c|0;m=j-2|0;n=e[m>>1]|0;o=e[j-4>>1]|0;p=e[j>>1]|0;q=e[j+2>>1]|0;r=n-p|0;if((((r|0)>-1?r:-r|0)|0)>=(i|0)){break}r=o-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=q-p|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=o+4-q+(p-n<<2)>>3;if((r|0)<(l|0)){s=l}else{s=(r|0)>(k|0)?k:r}r=s+n|0;if(r>>>0<1024>>>0){t=r&65535}else{t=-r>>31&1023}b[m>>1]=t;m=p-s|0;if(m>>>0<1024>>>0){u=m&65535}else{u=-m>>31&1023}b[j>>1]=u}}while(0);k=d+1|0;if((k|0)<4){d=k;j=j+(g<<1)|0}else{break}}return}function zfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<2;f=g<<2;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<2;l=c-3|0;do{if((l|0)>=1){m=3-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<1024>>>0){v=t&65535}else{v=-t>>31&1023}b[n>>1]=v;t=q-u|0;if(t>>>0<1024>>>0){w=t&65535}else{w=-t>>31&1023}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<1024>>>0){y=t&65535}else{y=-t>>31&1023}b[n>>1]=y;n=p-x|0;if(n>>>0<1024>>>0){z=n&65535}else{z=-n>>31&1023}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function Afa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c>>1;c=d<<2;d=f<<2;f=-g|0;h=g*-2|0;i=a;a=0;while(1){j=i+(f<<1)|0;k=e[j>>1]|0;l=e[i+(h<<1)>>1]|0;m=e[i>>1]|0;n=e[i+(g<<1)>>1]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(c|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}b[j>>1]=(k+2+(l<<1)+n|0)>>>2;b[i>>1]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=a+1|0;if((n|0)<8){i=i+2|0;a=n}else{break}}return}function Bfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<2;d=f<<2;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function Cfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<2;d=f<<2;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<16){f=f+(g<<1)|0;a=l}else{break}}return}function Dfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<2;d=f<<2;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<4){f=f+(g<<1)|0;a=l}else{break}}return}function Efa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<2;d=f<<2;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function Ffa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c>>1;c=h<<f+4;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<4096>>>0){m=a&65535}else{m=-a>>31&4095}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){n=c&65535}else{n=-c>>31&4095}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){o=c&65535}else{o=-c>>31&4095}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){p=c&65535}else{p=-c>>31&4095}b[a>>1]=p;a=l+8|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){q=c&65535}else{q=-c>>31&4095}b[a>>1]=q;a=l+10|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[a>>1]=r;a=l+12|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){s=c&65535}else{s=-c>>31&4095}b[a>>1]=s;a=l+14|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){t=c&65535}else{t=-c>>31&4095}b[a>>1]=t;a=l+16|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){u=c&65535}else{u=-c>>31&4095}b[a>>1]=u;a=l+18|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){v=c&65535}else{v=-c>>31&4095}b[a>>1]=v;a=l+20|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){w=c&65535}else{w=-c>>31&4095}b[a>>1]=w;a=l+22|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){x=c&65535}else{x=-c>>31&4095}b[a>>1]=x;a=l+24|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){y=c&65535}else{y=-c>>31&4095}b[a>>1]=y;a=l+26|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){z=c&65535}else{z=-c>>31&4095}b[a>>1]=z;a=l+28|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){A=c&65535}else{A=-c>>31&4095}b[a>>1]=A;a=l+30|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){B=c&65535}else{B=-c>>31&4095}b[a>>1]=B;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Gfa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c>>1;c=h<<f+4;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<4096>>>0){m=a&65535}else{m=-a>>31&4095}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){n=c&65535}else{n=-c>>31&4095}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){o=c&65535}else{o=-c>>31&4095}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){p=c&65535}else{p=-c>>31&4095}b[a>>1]=p;a=l+8|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){q=c&65535}else{q=-c>>31&4095}b[a>>1]=q;a=l+10|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[a>>1]=r;a=l+12|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){s=c&65535}else{s=-c>>31&4095}b[a>>1]=s;a=l+14|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){t=c&65535}else{t=-c>>31&4095}b[a>>1]=t;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Hfa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=c>>1;c=h<<f+4;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<4096>>>0){m=a&65535}else{m=-a>>31&4095}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){n=c&65535}else{n=-c>>31&4095}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){o=c&65535}else{o=-c>>31&4095}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){p=c&65535}else{p=-c>>31&4095}b[a>>1]=p;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Ifa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c>>1;c=h<<f+4;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<4096>>>0){m=a&65535}else{m=-a>>31&4095}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){n=c&65535}else{n=-c>>31&4095}b[a>>1]=n;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Jfa(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=d>>1;d=(j<<4|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){p=o&65535}else{p=-o>>31&4095}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){q=m&65535}else{q=-m>>31&4095}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[m>>1]=r;m=ba(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){s=o&65535}else{s=-o>>31&4095}b[c>>1]=s;c=ba(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){t=m&65535}else{t=-m>>31&4095}b[o>>1]=t;o=ba(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){u=c&65535}else{u=-c>>31&4095}b[m>>1]=u;m=ba(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){v=o&65535}else{v=-o>>31&4095}b[c>>1]=v;c=ba(e[a+16>>1]|0,i)|0;o=l+16|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){w=m&65535}else{w=-m>>31&4095}b[o>>1]=w;o=ba(e[a+18>>1]|0,i)|0;m=l+18|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){x=c&65535}else{x=-c>>31&4095}b[m>>1]=x;m=ba(e[a+20>>1]|0,i)|0;c=l+20|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){y=o&65535}else{y=-o>>31&4095}b[c>>1]=y;c=ba(e[a+22>>1]|0,i)|0;o=l+22|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){z=m&65535}else{z=-m>>31&4095}b[o>>1]=z;o=ba(e[a+24>>1]|0,i)|0;m=l+24|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){A=c&65535}else{A=-c>>31&4095}b[m>>1]=A;m=ba(e[a+26>>1]|0,i)|0;c=l+26|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){B=o&65535}else{B=-o>>31&4095}b[c>>1]=B;c=ba(e[a+28>>1]|0,i)|0;o=l+28|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){C=m&65535}else{C=-m>>31&4095}b[o>>1]=C;o=ba(e[a+30>>1]|0,i)|0;m=l+30|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){D=c&65535}else{D=-c>>31&4095}b[m>>1]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Kfa(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=d>>1;d=(j<<4|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){p=o&65535}else{p=-o>>31&4095}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){q=m&65535}else{q=-m>>31&4095}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[m>>1]=r;m=ba(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){s=o&65535}else{s=-o>>31&4095}b[c>>1]=s;c=ba(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){t=m&65535}else{t=-m>>31&4095}b[o>>1]=t;o=ba(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){u=c&65535}else{u=-c>>31&4095}b[m>>1]=u;m=ba(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){v=o&65535}else{v=-o>>31&4095}b[c>>1]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Lfa(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=d>>1;d=(j<<4|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){p=o&65535}else{p=-o>>31&4095}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){q=m&65535}else{q=-m>>31&4095}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[m>>1]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Mfa(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=d>>1;d=(j<<4|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){p=o&65535}else{p=-o>>31&4095}b[c>>1]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Nfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=d>>1;d=f<<4;f=g<<4;g=-i|0;j=i*-2|0;k=i*-3|0;l=i<<1;m=0;n=c;while(1){c=a[h+m|0]<<4;if((c|0)>=0){o=(c|0)==0;p=c|1;q=-c|0;r=0;s=n;while(1){t=s+(g<<1)|0;u=e[t>>1]|0;v=s+(j<<1)|0;w=e[v>>1]|0;x=e[s+(k<<1)>>1]|0;y=e[s>>1]|0;z=s+(i<<1)|0;A=e[z>>1]|0;B=e[s+(l<<1)>>1]|0;C=u-y|0;do{if((((C|0)>-1?C:-C|0)|0)<(d|0)){D=w-u|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=A-y|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=x-u|0;E=(((D|0)>-1?D:-D|0)|0)>=(f|0);if(E|o){F=E?c:p}else{E=((((u+1+y|0)>>>1)+x|0)>>>1)-w|0;if((E|0)<(q|0)){G=q}else{G=(E|0)>(c|0)?c:E}b[v>>1]=G+w;F=p}E=B-y|0;if((((E|0)>-1?E:-E|0)|0)<(f|0)){if(!o){E=((B+((u+1+y|0)>>>1)|0)>>>1)-A|0;if((E|0)<(q|0)){H=q}else{H=(E|0)>(c|0)?c:E}b[z>>1]=H+A}I=F+1|0}else{I=F}E=w+4-A+(y-u<<2)>>3;D=-I|0;if((E|0)<(D|0)){J=D}else{J=(E|0)>(I|0)?I:E}E=J+u|0;if(E>>>0<4096>>>0){K=E&65535}else{K=-E>>31&4095}b[t>>1]=K;E=y-J|0;if(E>>>0<4096>>>0){L=E&65535}else{L=-E>>31&4095}b[s>>1]=L}}while(0);y=r+1|0;if((y|0)<4){r=y;s=s+2|0}else{break}}}s=m+1|0;if((s|0)<4){m=s;n=n+8|0}else{break}}return}function Ofa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<4;f=g<<4;g=i<<2;j=0;k=c;while(1){c=a[h+j|0]<<4;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<4096>>>0){H=B&65535}else{H=-B>>31&4095}b[q>>1]=H;B=v-G|0;if(B>>>0<4096>>>0){I=B&65535}else{I=-B>>31&4095}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<4){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function Pfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<4;f=g<<4;g=i<<1;j=0;k=c;while(1){c=a[h+j|0]<<4;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<4096>>>0){H=B&65535}else{H=-B>>31&4095}b[q>>1]=H;B=v-G|0;if(B>>>0<4096>>>0){I=B&65535}else{I=-B>>31&4095}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<2){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function Qfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c>>1;c=d<<4;d=f<<4;f=g*-3|0;h=g*-2|0;i=-g|0;j=g<<1;k=c>>2|2;l=g*-4|0;m=g*3|0;n=0;o=a;while(1){a=o+(f<<1)|0;p=e[a>>1]|0;q=o+(h<<1)|0;r=e[q>>1]|0;s=o+(i<<1)|0;t=e[s>>1]|0;u=e[o>>1]|0;v=o+(g<<1)|0;w=e[v>>1]|0;x=o+(j<<1)|0;y=e[x>>1]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(c|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}if((A|0)>=(k|0)){b[s>>1]=(t+2+(r<<1)+w|0)>>>2;b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(l<<1)>>1]|0;b[s>>1]=(p+4+w+(t+r+u<<1)|0)>>>3;b[q>>1]=(p+2+r+t+u|0)>>>2;b[a>>1]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{b[s>>1]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(m<<1)>>1]|0;b[o>>1]=(r+4+y+(u+t+w<<1)|0)>>>3;b[v>>1]=(t+2+u+w+y|0)>>>2;b[x>>1]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+2|0}else{break}}return}function Rfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<4;d=f<<4;f=c>>2|2;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+(g<<1)|0}else{break}}return}function Sfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<4;d=f<<4;f=c>>2|2;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+(g<<1)|0}else{break}}return}function Tfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=f<<4;f=g<<4;g=d>>1;d=-g|0;j=g*-2|0;k=0;l=c;while(1){c=a[h+k|0]<<4;m=c-15|0;do{if((m|0)>=1){n=15-c|0;o=l+(d<<1)|0;p=e[o>>1]|0;q=e[l+(j<<1)>>1]|0;r=e[l>>1]|0;s=e[l+(g<<1)>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(n|0)){v=n}else{v=(u|0)>(m|0)?m:u}u=v+p|0;if(u>>>0<4096>>>0){w=u&65535}else{w=-u>>31&4095}b[o>>1]=w;u=r-v|0;if(u>>>0<4096>>>0){x=u&65535}else{x=-u>>31&4095}b[l>>1]=x}}while(0);r=l+2|0;o=l+(1-g<<1)|0;p=e[o>>1]|0;s=e[l+((j|1)<<1)>>1]|0;q=e[r>>1]|0;t=e[l+(g+1<<1)>>1]|0;u=p-q|0;if((((u|0)>-1?u:-u|0)|0)>=(i|0)){break}u=s-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=t-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s+4-t+(q-p<<2)>>3;if((u|0)<(n|0)){y=n}else{y=(u|0)>(m|0)?m:u}u=y+p|0;if(u>>>0<4096>>>0){z=u&65535}else{z=-u>>31&4095}b[o>>1]=z;o=q-y|0;if(o>>>0<4096>>>0){A=o&65535}else{A=-o>>31&4095}b[r>>1]=A}}while(0);m=k+1|0;if((m|0)<4){k=m;l=l+4|0}else{break}}return}function Ufa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<4;f=g<<4;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<4;l=c-15|0;do{if((l|0)>=1){m=15-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<4096>>>0){v=t&65535}else{v=-t>>31&4095}b[n>>1]=v;t=q-u|0;if(t>>>0<4096>>>0){w=t&65535}else{w=-t>>31&4095}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<4096>>>0){y=t&65535}else{y=-t>>31&4095}b[n>>1]=y;n=p-x|0;if(n>>>0<4096>>>0){z=n&65535}else{z=-n>>31&4095}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function Vfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=f<<4;f=g<<4;g=d>>1;d=g<<2;j=0;k=c;while(1){c=a[h+j|0]<<4;l=c-15|0;if((l|0)>=1){m=15-c|0;c=0;n=k;while(1){o=n-2|0;p=e[o>>1]|0;q=e[n-4>>1]|0;r=e[n>>1]|0;s=e[n+2>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}u=v+p|0;if(u>>>0<4096>>>0){w=u&65535}else{w=-u>>31&4095}b[o>>1]=w;u=r-v|0;if(u>>>0<4096>>>0){x=u&65535}else{x=-u>>31&4095}b[n>>1]=x}}while(0);r=c+1|0;if((r|0)<4){c=r;n=n+(g<<1)|0}else{break}}}n=j+1|0;if((n|0)<4){j=n;k=k+(d<<1)|0}else{break}}return}function Wfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=f<<4;f=g<<4;g=d>>1;d=0;j=c;while(1){c=a[h+d|0]<<4;k=c-15|0;do{if((k|0)>=1){l=15-c|0;m=j-2|0;n=e[m>>1]|0;o=e[j-4>>1]|0;p=e[j>>1]|0;q=e[j+2>>1]|0;r=n-p|0;if((((r|0)>-1?r:-r|0)|0)>=(i|0)){break}r=o-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=q-p|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=o+4-q+(p-n<<2)>>3;if((r|0)<(l|0)){s=l}else{s=(r|0)>(k|0)?k:r}r=s+n|0;if(r>>>0<4096>>>0){t=r&65535}else{t=-r>>31&4095}b[m>>1]=t;m=p-s|0;if(m>>>0<4096>>>0){u=m&65535}else{u=-m>>31&4095}b[j>>1]=u}}while(0);k=d+1|0;if((k|0)<4){d=k;j=j+(g<<1)|0}else{break}}return}function Xfa(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<4;f=g<<4;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<4;l=c-15|0;do{if((l|0)>=1){m=15-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<4096>>>0){v=t&65535}else{v=-t>>31&4095}b[n>>1]=v;t=q-u|0;if(t>>>0<4096>>>0){w=t&65535}else{w=-t>>31&4095}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<4096>>>0){y=t&65535}else{y=-t>>31&4095}b[n>>1]=y;n=p-x|0;if(n>>>0<4096>>>0){z=n&65535}else{z=-n>>31&4095}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function Yfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c>>1;c=d<<4;d=f<<4;f=-g|0;h=g*-2|0;i=a;a=0;while(1){j=i+(f<<1)|0;k=e[j>>1]|0;l=e[i+(h<<1)>>1]|0;m=e[i>>1]|0;n=e[i+(g<<1)>>1]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(c|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}b[j>>1]=(k+2+(l<<1)+n|0)>>>2;b[i>>1]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=a+1|0;if((n|0)<8){i=i+2|0;a=n}else{break}}return}function Zfa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<4;d=f<<4;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function _fa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<4;d=f<<4;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<16){f=f+(g<<1)|0;a=l}else{break}}return}function $fa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<4;d=f<<4;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<4){f=f+(g<<1)|0;a=l}else{break}}return}function aga(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<4;d=f<<4;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function bga(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c>>1;c=h<<f+6;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<16384>>>0){m=a&65535}else{m=-a>>31&16383}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){n=c&65535}else{n=-c>>31&16383}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){o=c&65535}else{o=-c>>31&16383}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){p=c&65535}else{p=-c>>31&16383}b[a>>1]=p;a=l+8|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){q=c&65535}else{q=-c>>31&16383}b[a>>1]=q;a=l+10|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[a>>1]=r;a=l+12|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){s=c&65535}else{s=-c>>31&16383}b[a>>1]=s;a=l+14|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){t=c&65535}else{t=-c>>31&16383}b[a>>1]=t;a=l+16|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){u=c&65535}else{u=-c>>31&16383}b[a>>1]=u;a=l+18|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){v=c&65535}else{v=-c>>31&16383}b[a>>1]=v;a=l+20|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){w=c&65535}else{w=-c>>31&16383}b[a>>1]=w;a=l+22|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){x=c&65535}else{x=-c>>31&16383}b[a>>1]=x;a=l+24|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){y=c&65535}else{y=-c>>31&16383}b[a>>1]=y;a=l+26|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){z=c&65535}else{z=-c>>31&16383}b[a>>1]=z;a=l+28|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){A=c&65535}else{A=-c>>31&16383}b[a>>1]=A;a=l+30|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){B=c&65535}else{B=-c>>31&16383}b[a>>1]=B;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function cga(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c>>1;c=h<<f+6;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<16384>>>0){m=a&65535}else{m=-a>>31&16383}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){n=c&65535}else{n=-c>>31&16383}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){o=c&65535}else{o=-c>>31&16383}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){p=c&65535}else{p=-c>>31&16383}b[a>>1]=p;a=l+8|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){q=c&65535}else{q=-c>>31&16383}b[a>>1]=q;a=l+10|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[a>>1]=r;a=l+12|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){s=c&65535}else{s=-c>>31&16383}b[a>>1]=s;a=l+14|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){t=c&65535}else{t=-c>>31&16383}b[a>>1]=t;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function dga(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=c>>1;c=h<<f+6;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<16384>>>0){m=a&65535}else{m=-a>>31&16383}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){n=c&65535}else{n=-c>>31&16383}b[a>>1]=n;a=l+4|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){o=c&65535}else{o=-c>>31&16383}b[a>>1]=o;a=l+6|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){p=c&65535}else{p=-c>>31&16383}b[a>>1]=p;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function ega(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c>>1;c=h<<f+6;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ba(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<16384>>>0){m=a&65535}else{m=-a>>31&16383}b[l>>1]=m;a=l+2|0;c=(ba(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){n=c&65535}else{n=-c>>31&16383}b[a>>1]=n;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function fga(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=d>>1;d=(j<<6|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){p=o&65535}else{p=-o>>31&16383}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){q=m&65535}else{q=-m>>31&16383}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[m>>1]=r;m=ba(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){s=o&65535}else{s=-o>>31&16383}b[c>>1]=s;c=ba(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){t=m&65535}else{t=-m>>31&16383}b[o>>1]=t;o=ba(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){u=c&65535}else{u=-c>>31&16383}b[m>>1]=u;m=ba(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){v=o&65535}else{v=-o>>31&16383}b[c>>1]=v;c=ba(e[a+16>>1]|0,i)|0;o=l+16|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){w=m&65535}else{w=-m>>31&16383}b[o>>1]=w;o=ba(e[a+18>>1]|0,i)|0;m=l+18|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){x=c&65535}else{x=-c>>31&16383}b[m>>1]=x;m=ba(e[a+20>>1]|0,i)|0;c=l+20|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){y=o&65535}else{y=-o>>31&16383}b[c>>1]=y;c=ba(e[a+22>>1]|0,i)|0;o=l+22|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){z=m&65535}else{z=-m>>31&16383}b[o>>1]=z;o=ba(e[a+24>>1]|0,i)|0;m=l+24|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){A=c&65535}else{A=-c>>31&16383}b[m>>1]=A;m=ba(e[a+26>>1]|0,i)|0;c=l+26|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){B=o&65535}else{B=-o>>31&16383}b[c>>1]=B;c=ba(e[a+28>>1]|0,i)|0;o=l+28|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){C=m&65535}else{C=-m>>31&16383}b[o>>1]=C;o=ba(e[a+30>>1]|0,i)|0;m=l+30|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){D=c&65535}else{D=-c>>31&16383}b[m>>1]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function gga(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=d>>1;d=(j<<6|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){p=o&65535}else{p=-o>>31&16383}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){q=m&65535}else{q=-m>>31&16383}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[m>>1]=r;m=ba(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){s=o&65535}else{s=-o>>31&16383}b[c>>1]=s;c=ba(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){t=m&65535}else{t=-m>>31&16383}b[o>>1]=t;o=ba(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){u=c&65535}else{u=-c>>31&16383}b[m>>1]=u;m=ba(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){v=o&65535}else{v=-o>>31&16383}b[c>>1]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function hga(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=d>>1;d=(j<<6|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){p=o&65535}else{p=-o>>31&16383}b[c>>1]=p;c=ba(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ba(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){q=m&65535}else{q=-m>>31&16383}b[o>>1]=q;o=ba(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ba(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[m>>1]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function iga(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=d>>1;d=(j<<6|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ba(e[a>>1]|0,i)|0;m=c+d+(ba(e[l>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[l>>1]=n;m=ba(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ba(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){p=o&65535}else{p=-o>>31&16383}b[c>>1]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function jga(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=d>>1;d=f<<6;f=g<<6;g=-i|0;j=i*-2|0;k=i*-3|0;l=i<<1;m=0;n=c;while(1){c=a[h+m|0]<<6;if((c|0)>=0){o=(c|0)==0;p=c|1;q=-c|0;r=0;s=n;while(1){t=s+(g<<1)|0;u=e[t>>1]|0;v=s+(j<<1)|0;w=e[v>>1]|0;x=e[s+(k<<1)>>1]|0;y=e[s>>1]|0;z=s+(i<<1)|0;A=e[z>>1]|0;B=e[s+(l<<1)>>1]|0;C=u-y|0;do{if((((C|0)>-1?C:-C|0)|0)<(d|0)){D=w-u|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=A-y|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=x-u|0;E=(((D|0)>-1?D:-D|0)|0)>=(f|0);if(E|o){F=E?c:p}else{E=((((u+1+y|0)>>>1)+x|0)>>>1)-w|0;if((E|0)<(q|0)){G=q}else{G=(E|0)>(c|0)?c:E}b[v>>1]=G+w;F=p}E=B-y|0;if((((E|0)>-1?E:-E|0)|0)<(f|0)){if(!o){E=((B+((u+1+y|0)>>>1)|0)>>>1)-A|0;if((E|0)<(q|0)){H=q}else{H=(E|0)>(c|0)?c:E}b[z>>1]=H+A}I=F+1|0}else{I=F}E=w+4-A+(y-u<<2)>>3;D=-I|0;if((E|0)<(D|0)){J=D}else{J=(E|0)>(I|0)?I:E}E=J+u|0;if(E>>>0<16384>>>0){K=E&65535}else{K=-E>>31&16383}b[t>>1]=K;E=y-J|0;if(E>>>0<16384>>>0){L=E&65535}else{L=-E>>31&16383}b[s>>1]=L}}while(0);y=r+1|0;if((y|0)<4){r=y;s=s+2|0}else{break}}}s=m+1|0;if((s|0)<4){m=s;n=n+8|0}else{break}}return}function kga(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<6;f=g<<6;g=i<<2;j=0;k=c;while(1){c=a[h+j|0]<<6;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<16384>>>0){H=B&65535}else{H=-B>>31&16383}b[q>>1]=H;B=v-G|0;if(B>>>0<16384>>>0){I=B&65535}else{I=-B>>31&16383}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<4){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function lga(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<6;f=g<<6;g=i<<1;j=0;k=c;while(1){c=a[h+j|0]<<6;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<16384>>>0){H=B&65535}else{H=-B>>31&16383}b[q>>1]=H;B=v-G|0;if(B>>>0<16384>>>0){I=B&65535}else{I=-B>>31&16383}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<2){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function mga(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c>>1;c=d<<6;d=f<<6;f=g*-3|0;h=g*-2|0;i=-g|0;j=g<<1;k=c>>2|2;l=g*-4|0;m=g*3|0;n=0;o=a;while(1){a=o+(f<<1)|0;p=e[a>>1]|0;q=o+(h<<1)|0;r=e[q>>1]|0;s=o+(i<<1)|0;t=e[s>>1]|0;u=e[o>>1]|0;v=o+(g<<1)|0;w=e[v>>1]|0;x=o+(j<<1)|0;y=e[x>>1]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(c|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}if((A|0)>=(k|0)){b[s>>1]=(t+2+(r<<1)+w|0)>>>2;b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(l<<1)>>1]|0;b[s>>1]=(p+4+w+(t+r+u<<1)|0)>>>3;b[q>>1]=(p+2+r+t+u|0)>>>2;b[a>>1]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{b[s>>1]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(m<<1)>>1]|0;b[o>>1]=(r+4+y+(u+t+w<<1)|0)>>>3;b[v>>1]=(t+2+u+w+y|0)>>>2;b[x>>1]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+2|0}else{break}}return}function nga(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<6;d=f<<6;f=c>>2|2;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+(g<<1)|0}else{break}}return}function oga(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<6;d=f<<6;f=c>>2|2;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+(g<<1)|0}else{break}}return}function pga(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=f<<6;f=g<<6;g=d>>1;d=-g|0;j=g*-2|0;k=0;l=c;while(1){c=a[h+k|0]<<6;m=c-63|0;do{if((m|0)>=1){n=63-c|0;o=l+(d<<1)|0;p=e[o>>1]|0;q=e[l+(j<<1)>>1]|0;r=e[l>>1]|0;s=e[l+(g<<1)>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(n|0)){v=n}else{v=(u|0)>(m|0)?m:u}u=v+p|0;if(u>>>0<16384>>>0){w=u&65535}else{w=-u>>31&16383}b[o>>1]=w;u=r-v|0;if(u>>>0<16384>>>0){x=u&65535}else{x=-u>>31&16383}b[l>>1]=x}}while(0);r=l+2|0;o=l+(1-g<<1)|0;p=e[o>>1]|0;s=e[l+((j|1)<<1)>>1]|0;q=e[r>>1]|0;t=e[l+(g+1<<1)>>1]|0;u=p-q|0;if((((u|0)>-1?u:-u|0)|0)>=(i|0)){break}u=s-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=t-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s+4-t+(q-p<<2)>>3;if((u|0)<(n|0)){y=n}else{y=(u|0)>(m|0)?m:u}u=y+p|0;if(u>>>0<16384>>>0){z=u&65535}else{z=-u>>31&16383}b[o>>1]=z;o=q-y|0;if(o>>>0<16384>>>0){A=o&65535}else{A=-o>>31&16383}b[r>>1]=A}}while(0);m=k+1|0;if((m|0)<4){k=m;l=l+4|0}else{break}}return}function qga(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<6;f=g<<6;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<6;l=c-63|0;do{if((l|0)>=1){m=63-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<16384>>>0){v=t&65535}else{v=-t>>31&16383}b[n>>1]=v;t=q-u|0;if(t>>>0<16384>>>0){w=t&65535}else{w=-t>>31&16383}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<16384>>>0){y=t&65535}else{y=-t>>31&16383}b[n>>1]=y;n=p-x|0;if(n>>>0<16384>>>0){z=n&65535}else{z=-n>>31&16383}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function rga(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=f<<6;f=g<<6;g=d>>1;d=g<<2;j=0;k=c;while(1){c=a[h+j|0]<<6;l=c-63|0;if((l|0)>=1){m=63-c|0;c=0;n=k;while(1){o=n-2|0;p=e[o>>1]|0;q=e[n-4>>1]|0;r=e[n>>1]|0;s=e[n+2>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}u=v+p|0;if(u>>>0<16384>>>0){w=u&65535}else{w=-u>>31&16383}b[o>>1]=w;u=r-v|0;if(u>>>0<16384>>>0){x=u&65535}else{x=-u>>31&16383}b[n>>1]=x}}while(0);r=c+1|0;if((r|0)<4){c=r;n=n+(g<<1)|0}else{break}}}n=j+1|0;if((n|0)<4){j=n;k=k+(d<<1)|0}else{break}}return}function sga(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=f<<6;f=g<<6;g=d>>1;d=0;j=c;while(1){c=a[h+d|0]<<6;k=c-63|0;do{if((k|0)>=1){l=63-c|0;m=j-2|0;n=e[m>>1]|0;o=e[j-4>>1]|0;p=e[j>>1]|0;q=e[j+2>>1]|0;r=n-p|0;if((((r|0)>-1?r:-r|0)|0)>=(i|0)){break}r=o-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=q-p|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=o+4-q+(p-n<<2)>>3;if((r|0)<(l|0)){s=l}else{s=(r|0)>(k|0)?k:r}r=s+n|0;if(r>>>0<16384>>>0){t=r&65535}else{t=-r>>31&16383}b[m>>1]=t;m=p-s|0;if(m>>>0<16384>>>0){u=m&65535}else{u=-m>>31&16383}b[j>>1]=u}}while(0);k=d+1|0;if((k|0)<4){d=k;j=j+(g<<1)|0}else{break}}return}function tga(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<6;f=g<<6;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<6;l=c-63|0;do{if((l|0)>=1){m=63-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<16384>>>0){v=t&65535}else{v=-t>>31&16383}b[n>>1]=v;t=q-u|0;if(t>>>0<16384>>>0){w=t&65535}else{w=-t>>31&16383}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<16384>>>0){y=t&65535}else{y=-t>>31&16383}b[n>>1]=y;n=p-x|0;if(n>>>0<16384>>>0){z=n&65535}else{z=-n>>31&16383}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function uga(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c>>1;c=d<<6;d=f<<6;f=-g|0;h=g*-2|0;i=a;a=0;while(1){j=i+(f<<1)|0;k=e[j>>1]|0;l=e[i+(h<<1)>>1]|0;m=e[i>>1]|0;n=e[i+(g<<1)>>1]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(c|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}b[j>>1]=(k+2+(l<<1)+n|0)>>>2;b[i>>1]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=a+1|0;if((n|0)<8){i=i+2|0;a=n}else{break}}return}function vga(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<6;d=f<<6;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function wga(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<6;d=f<<6;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<16){f=f+(g<<1)|0;a=l}else{break}}return}function xga(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<6;d=f<<6;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<4){f=f+(g<<1)|0;a=l}else{break}}return}function yga(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<6;d=f<<6;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function zga(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=h<<f;if((f|0)==0){j=i}else{j=i+(1<<f-1)|0}if((e|0)>0){k=0;l=b}else{return}while(1){b=(ba(d[l]|0,g)|0)+j>>f;if(b>>>0>255>>>0){m=-b>>31&255}else{m=b&255}a[l]=m;b=l+1|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b]=n;b=l+2|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){o=-i>>31&255}else{o=i&255}a[b]=o;b=l+3|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[b]=p;b=l+4|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[b]=q;b=l+5|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){r=-i>>31&255}else{r=i&255}a[b]=r;b=l+6|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){s=-i>>31&255}else{s=i&255}a[b]=s;b=l+7|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){t=-i>>31&255}else{t=i&255}a[b]=t;b=l+8|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){u=-i>>31&255}else{u=i&255}a[b]=u;b=l+9|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){v=-i>>31&255}else{v=i&255}a[b]=v;b=l+10|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){w=-i>>31&255}else{w=i&255}a[b]=w;b=l+11|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){x=-i>>31&255}else{x=i&255}a[b]=x;b=l+12|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){y=-i>>31&255}else{y=i&255}a[b]=y;b=l+13|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){z=-i>>31&255}else{z=i&255}a[b]=z;b=l+14|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){A=-i>>31&255}else{A=i&255}a[b]=A;b=l+15|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){B=-i>>31&255}else{B=i&255}a[b]=B;b=k+1|0;if((b|0)<(e|0)){k=b;l=l+c|0}else{break}}return}function Aga(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=h<<f;if((f|0)==0){j=i}else{j=i+(1<<f-1)|0}if((e|0)>0){k=0;l=b}else{return}while(1){b=(ba(d[l]|0,g)|0)+j>>f;if(b>>>0>255>>>0){m=-b>>31&255}else{m=b&255}a[l]=m;b=l+1|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b]=n;b=l+2|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){o=-i>>31&255}else{o=i&255}a[b]=o;b=l+3|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[b]=p;b=l+4|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[b]=q;b=l+5|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){r=-i>>31&255}else{r=i&255}a[b]=r;b=l+6|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){s=-i>>31&255}else{s=i&255}a[b]=s;b=l+7|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){t=-i>>31&255}else{t=i&255}a[b]=t;b=k+1|0;if((b|0)<(e|0)){k=b;l=l+c|0}else{break}}return}function Bga(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=h<<f;if((f|0)==0){j=i}else{j=i+(1<<f-1)|0}if((e|0)>0){k=0;l=b}else{return}while(1){b=(ba(d[l]|0,g)|0)+j>>f;if(b>>>0>255>>>0){m=-b>>31&255}else{m=b&255}a[l]=m;b=l+1|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b]=n;b=l+2|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){o=-i>>31&255}else{o=i&255}a[b]=o;b=l+3|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[b]=p;b=k+1|0;if((b|0)<(e|0)){k=b;l=l+c|0}else{break}}return}function Cga(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=h<<f;if((f|0)==0){j=i}else{j=i+(1<<f-1)|0}if((e|0)>0){k=0;l=b}else{return}while(1){b=(ba(d[l]|0,g)|0)+j>>f;if(b>>>0>255>>>0){m=-b>>31&255}else{m=b&255}a[l]=m;b=l+1|0;i=(ba(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b]=n;b=k+1|0;if((b|0)<(e|0)){k=b;l=l+c|0}else{break}}return}function Dga(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=(j+1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=b;b=c;while(1){c=ba(d[b]|0,i)|0;m=c+k+(ba(d[l]|0,h)|0)>>j;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=ba(d[b+1|0]|0,i)|0;c=l+1|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c]=p;c=ba(d[b+2|0]|0,i)|0;o=l+2|0;m=c+k+(ba(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){q=-m>>31&255}else{q=m&255}a[o]=q;o=ba(d[b+3|0]|0,i)|0;m=l+3|0;c=o+k+(ba(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){r=-c>>31&255}else{r=c&255}a[m]=r;m=ba(d[b+4|0]|0,i)|0;c=l+4|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){s=-o>>31&255}else{s=o&255}a[c]=s;c=ba(d[b+5|0]|0,i)|0;o=l+5|0;m=c+k+(ba(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){t=-m>>31&255}else{t=m&255}a[o]=t;o=ba(d[b+6|0]|0,i)|0;m=l+6|0;c=o+k+(ba(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){u=-c>>31&255}else{u=c&255}a[m]=u;m=ba(d[b+7|0]|0,i)|0;c=l+7|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){v=-o>>31&255}else{v=o&255}a[c]=v;c=ba(d[b+8|0]|0,i)|0;o=l+8|0;m=c+k+(ba(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){w=-m>>31&255}else{w=m&255}a[o]=w;o=ba(d[b+9|0]|0,i)|0;m=l+9|0;c=o+k+(ba(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){x=-c>>31&255}else{x=c&255}a[m]=x;m=ba(d[b+10|0]|0,i)|0;c=l+10|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){y=-o>>31&255}else{y=o&255}a[c]=y;c=ba(d[b+11|0]|0,i)|0;o=l+11|0;m=c+k+(ba(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){z=-m>>31&255}else{z=m&255}a[o]=z;o=ba(d[b+12|0]|0,i)|0;m=l+12|0;c=o+k+(ba(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){A=-c>>31&255}else{A=c&255}a[m]=A;m=ba(d[b+13|0]|0,i)|0;c=l+13|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){B=-o>>31&255}else{B=o&255}a[c]=B;c=ba(d[b+14|0]|0,i)|0;o=l+14|0;m=c+k+(ba(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){C=-m>>31&255}else{C=m&255}a[o]=C;o=ba(d[b+15|0]|0,i)|0;m=l+15|0;c=o+k+(ba(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){D=-c>>31&255}else{D=c&255}a[m]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+e|0;b=b+e|0}else{break}}return}function Ega(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=(j+1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=b;b=c;while(1){c=ba(d[b]|0,i)|0;m=c+k+(ba(d[l]|0,h)|0)>>j;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=ba(d[b+1|0]|0,i)|0;c=l+1|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c]=p;c=ba(d[b+2|0]|0,i)|0;o=l+2|0;m=c+k+(ba(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){q=-m>>31&255}else{q=m&255}a[o]=q;o=ba(d[b+3|0]|0,i)|0;m=l+3|0;c=o+k+(ba(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){r=-c>>31&255}else{r=c&255}a[m]=r;m=ba(d[b+4|0]|0,i)|0;c=l+4|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){s=-o>>31&255}else{s=o&255}a[c]=s;c=ba(d[b+5|0]|0,i)|0;o=l+5|0;m=c+k+(ba(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){t=-m>>31&255}else{t=m&255}a[o]=t;o=ba(d[b+6|0]|0,i)|0;m=l+6|0;c=o+k+(ba(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){u=-c>>31&255}else{u=c&255}a[m]=u;m=ba(d[b+7|0]|0,i)|0;c=l+7|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){v=-o>>31&255}else{v=o&255}a[c]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+e|0;b=b+e|0}else{break}}return}function Fga(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=(j+1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=b;b=c;while(1){c=ba(d[b]|0,i)|0;m=c+k+(ba(d[l]|0,h)|0)>>j;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=ba(d[b+1|0]|0,i)|0;c=l+1|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c]=p;c=ba(d[b+2|0]|0,i)|0;o=l+2|0;m=c+k+(ba(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){q=-m>>31&255}else{q=m&255}a[o]=q;o=ba(d[b+3|0]|0,i)|0;m=l+3|0;c=o+k+(ba(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){r=-c>>31&255}else{r=c&255}a[m]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+e|0;b=b+e|0}else{break}}return}function Gga(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=(j+1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=b;b=c;while(1){c=ba(d[b]|0,i)|0;m=c+k+(ba(d[l]|0,h)|0)>>j;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=ba(d[b+1|0]|0,i)|0;c=l+1|0;o=m+k+(ba(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+e|0;b=b+e|0}else{break}}return}function Hga(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=-c|0;i=c*-2|0;j=c*-3|0;k=c<<1;l=0;m=b;while(1){b=a[g+l|0]|0;n=b<<24>>24;if(!(b<<24>>24<0)){o=b<<24>>24==0;b=n+1|0;p=-n|0;q=0;r=m;while(1){s=r+h|0;t=d[s]|0;u=r+i|0;v=d[u]|0;w=d[r+j|0]|0;x=d[r]|0;y=r+c|0;z=d[y]|0;A=d[r+k|0]|0;B=t-x|0;do{if((((B|0)>-1?B:-B|0)|0)<(e|0)){C=v-t|0;if((((C|0)>-1?C:-C|0)|0)>=(f|0)){break}C=z-x|0;if((((C|0)>-1?C:-C|0)|0)>=(f|0)){break}C=w-t|0;D=(((C|0)>-1?C:-C|0)|0)>=(f|0);if(D|o){E=D?n:b}else{D=((((t+1+x|0)>>>1)+w|0)>>>1)-v|0;if((D|0)<(p|0)){F=p}else{F=(D|0)>(n|0)?n:D}a[u]=F+v;E=b}D=A-x|0;if((((D|0)>-1?D:-D|0)|0)<(f|0)){if(!o){D=((A+((t+1+x|0)>>>1)|0)>>>1)-z|0;if((D|0)<(p|0)){G=p}else{G=(D|0)>(n|0)?n:D}a[y]=G+z}H=E+1|0}else{H=E}D=v+4-z+(x-t<<2)>>3;C=-H|0;if((D|0)<(C|0)){I=C}else{I=(D|0)>(H|0)?H:D}D=I+t|0;if(D>>>0>255>>>0){J=-D>>31&255}else{J=D&255}a[s]=J;D=x-I|0;if(D>>>0>255>>>0){K=-D>>31&255}else{K=D&255}a[r]=K}}while(0);x=q+1|0;if((x|0)<4){q=x;r=r+1|0}else{break}}}r=l+1|0;if((r|0)<4){l=r;m=m+4|0}else{break}}return}function Iga(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=c<<2;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;if(!(b<<24>>24<0)){l=b<<24>>24==0;b=k+1|0;m=-k|0;n=0;o=j;while(1){p=o-1|0;q=d[p]|0;r=o-2|0;s=d[r]|0;t=d[o-3|0]|0;u=d[o]|0;v=o+1|0;w=d[v]|0;x=d[o+2|0]|0;y=q-u|0;do{if((((y|0)>-1?y:-y|0)|0)<(e|0)){z=s-q|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=t-q|0;A=(((z|0)>-1?z:-z|0)|0)>=(f|0);if(A|l){B=A?k:b}else{A=((((q+1+u|0)>>>1)+t|0)>>>1)-s|0;if((A|0)<(m|0)){C=m}else{C=(A|0)>(k|0)?k:A}a[r]=C+s;B=b}A=x-u|0;if((((A|0)>-1?A:-A|0)|0)<(f|0)){if(!l){A=((x+((q+1+u|0)>>>1)|0)>>>1)-w|0;if((A|0)<(m|0)){D=m}else{D=(A|0)>(k|0)?k:A}a[v]=D+w}E=B+1|0}else{E=B}A=s+4-w+(u-q<<2)>>3;z=-E|0;if((A|0)<(z|0)){F=z}else{F=(A|0)>(E|0)?E:A}A=F+q|0;if(A>>>0>255>>>0){G=-A>>31&255}else{G=A&255}a[p]=G;A=u-F|0;if(A>>>0>255>>>0){H=-A>>31&255}else{H=A&255}a[o]=H}}while(0);u=n+1|0;if((u|0)<4){n=u;o=o+c|0}else{break}}}o=i+1|0;if((o|0)<4){i=o;j=j+h|0}else{break}}return}function Jga(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=c<<1;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;if(!(b<<24>>24<0)){l=b<<24>>24==0;b=k+1|0;m=-k|0;n=0;o=j;while(1){p=o-1|0;q=d[p]|0;r=o-2|0;s=d[r]|0;t=d[o-3|0]|0;u=d[o]|0;v=o+1|0;w=d[v]|0;x=d[o+2|0]|0;y=q-u|0;do{if((((y|0)>-1?y:-y|0)|0)<(e|0)){z=s-q|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=t-q|0;A=(((z|0)>-1?z:-z|0)|0)>=(f|0);if(A|l){B=A?k:b}else{A=((((q+1+u|0)>>>1)+t|0)>>>1)-s|0;if((A|0)<(m|0)){C=m}else{C=(A|0)>(k|0)?k:A}a[r]=C+s;B=b}A=x-u|0;if((((A|0)>-1?A:-A|0)|0)<(f|0)){if(!l){A=((x+((q+1+u|0)>>>1)|0)>>>1)-w|0;if((A|0)<(m|0)){D=m}else{D=(A|0)>(k|0)?k:A}a[v]=D+w}E=B+1|0}else{E=B}A=s+4-w+(u-q<<2)>>3;z=-E|0;if((A|0)<(z|0)){F=z}else{F=(A|0)>(E|0)?E:A}A=F+q|0;if(A>>>0>255>>>0){G=-A>>31&255}else{G=A&255}a[p]=G;A=u-F|0;if(A>>>0>255>>>0){H=-A>>31&255}else{H=A&255}a[o]=H}}while(0);u=n+1|0;if((u|0)<2){n=u;o=o+c|0}else{break}}}o=i+1|0;if((o|0)<4){i=o;j=j+h|0}else{break}}return}function Kga(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c*-3|0;h=c*-2|0;i=-c|0;j=c<<1;k=(e>>2)+2|0;l=c*-4|0;m=c*3|0;n=0;o=b;while(1){b=o+g|0;p=d[b]|0;q=o+h|0;r=d[q]|0;s=o+i|0;t=d[s]|0;u=d[o]|0;v=o+c|0;w=d[v]|0;x=o+j|0;y=d[x]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(e|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}if((A|0)>=(k|0)){a[s]=(t+2+(r<<1)+w|0)>>>2;a[o]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(f|0)){z=d[o+l|0]|0;a[s]=(p+4+w+(t+r+u<<1)|0)>>>3;a[q]=(p+2+r+t+u|0)>>>2;a[b]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{a[s]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(f|0)){z=d[o+m|0]|0;a[o]=(r+4+y+(u+t+w<<1)|0)>>>3;a[v]=(t+2+u+w+y|0)>>>2;a[x]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{a[o]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+1|0}else{break}}return}function Lga(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=(e>>2)+2|0;h=0;i=b;while(1){b=i-3|0;j=d[b]|0;k=i-2|0;l=d[k]|0;m=i-1|0;n=d[m]|0;o=d[i]|0;p=i+1|0;q=d[p]|0;r=i+2|0;s=d[r]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(e|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}if((u|0)>=(g|0)){a[m]=(n+2+(l<<1)+q|0)>>>2;a[i]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[i-4|0]|0;a[m]=(j+4+q+(n+l+o<<1)|0)>>>3;a[k]=(j+2+l+n+o|0)>>>2;a[b]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{a[m]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[i+3|0]|0;a[i]=(l+4+s+(o+n+q<<1)|0)>>>3;a[p]=(n+2+o+q+s|0)>>>2;a[r]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{a[i]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+c|0}else{break}}return}function Mga(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=(e>>2)+2|0;h=0;i=b;while(1){b=i-3|0;j=d[b]|0;k=i-2|0;l=d[k]|0;m=i-1|0;n=d[m]|0;o=d[i]|0;p=i+1|0;q=d[p]|0;r=i+2|0;s=d[r]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(e|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}if((u|0)>=(g|0)){a[m]=(n+2+(l<<1)+q|0)>>>2;a[i]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[i-4|0]|0;a[m]=(j+4+q+(n+l+o<<1)|0)>>>3;a[k]=(j+2+l+n+o|0)>>>2;a[b]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{a[m]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[i+3|0]|0;a[i]=(l+4+s+(o+n+q<<1)|0)>>>3;a[p]=(n+2+o+q+s|0)>>>2;a[r]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{a[i]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+c|0}else{break}}return}function Nga(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=-c|0;i=c*-2|0;j=0;k=b;while(1){b=a[g+j|0]|0;l=b<<24>>24;do{if(!(b<<24>>24<1)){m=-l|0;n=k+h|0;o=d[n]|0;p=d[k+i|0]|0;q=d[k]|0;r=d[k+c|0]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(e|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0>255>>>0){v=-t>>31&255}else{v=t&255}a[n]=v;t=q-u|0;if(t>>>0>255>>>0){w=-t>>31&255}else{w=t&255}a[k]=w}}while(0);q=k+1|0;n=k+(1-c)|0;o=d[n]|0;r=d[k+(i|1)|0]|0;p=d[q]|0;s=d[k+(c+1)|0]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(e|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0>255>>>0){y=-t>>31&255}else{y=t&255}a[n]=y;n=p-x|0;if(n>>>0>255>>>0){z=-n>>31&255}else{z=n&255}a[q]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+2|0}else{break}}return}function Oga(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=c<<1;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;do{if(!(b<<24>>24<1)){l=-k|0;m=j-1|0;n=d[m]|0;o=d[j-2|0]|0;p=d[j]|0;q=d[j+1|0]|0;r=n-p|0;do{if((((r|0)>-1?r:-r|0)|0)<(e|0)){s=o-n|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=q-p|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=o+4-q+(p-n<<2)>>3;if((s|0)<(l|0)){t=l}else{t=(s|0)>(k|0)?k:s}s=t+n|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[m]=u;s=p-t|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[j]=v}}while(0);p=j+c|0;m=j+(c-1)|0;n=d[m]|0;q=d[j+(c-2)|0]|0;o=d[p]|0;r=d[j+(c+1)|0]|0;s=n-o|0;if((((s|0)>-1?s:-s|0)|0)>=(e|0)){break}s=q-n|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=r-o|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=q+4-r+(o-n<<2)>>3;if((s|0)<(l|0)){w=l}else{w=(s|0)>(k|0)?k:s}s=w+n|0;if(s>>>0>255>>>0){x=-s>>31&255}else{x=s&255}a[m]=x;m=o-w|0;if(m>>>0>255>>>0){y=-m>>31&255}else{y=m&255}a[p]=y}}while(0);k=i+1|0;if((k|0)<4){i=k;j=j+h|0}else{break}}return}function Pga(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=c<<2;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;if(!(b<<24>>24<1)){b=-k|0;l=0;m=j;while(1){n=m-1|0;o=d[n]|0;p=d[m-2|0]|0;q=d[m]|0;r=d[m+1|0]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(e|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(b|0)){u=b}else{u=(t|0)>(k|0)?k:t}t=u+o|0;if(t>>>0>255>>>0){v=-t>>31&255}else{v=t&255}a[n]=v;t=q-u|0;if(t>>>0>255>>>0){w=-t>>31&255}else{w=t&255}a[m]=w}}while(0);q=l+1|0;if((q|0)<4){l=q;m=m+c|0}else{break}}}m=i+1|0;if((m|0)<4){i=m;j=j+h|0}else{break}}return}function Qga(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=0;i=b;while(1){b=a[g+h|0]|0;j=b<<24>>24;do{if(!(b<<24>>24<1)){k=-j|0;l=i-1|0;m=d[l]|0;n=d[i-2|0]|0;o=d[i]|0;p=d[i+1|0]|0;q=m-o|0;if((((q|0)>-1?q:-q|0)|0)>=(e|0)){break}q=n-m|0;if((((q|0)>-1?q:-q|0)|0)>=(f|0)){break}q=p-o|0;if((((q|0)>-1?q:-q|0)|0)>=(f|0)){break}q=n+4-p+(o-m<<2)>>3;if((q|0)<(k|0)){r=k}else{r=(q|0)>(j|0)?j:q}q=r+m|0;if(q>>>0>255>>>0){s=-q>>31&255}else{s=q&255}a[l]=s;l=o-r|0;if(l>>>0>255>>>0){t=-l>>31&255}else{t=l&255}a[i]=t}}while(0);j=h+1|0;if((j|0)<4){h=j;i=i+c|0}else{break}}return}function Rga(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=c<<1;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;do{if(!(b<<24>>24<1)){l=-k|0;m=j-1|0;n=d[m]|0;o=d[j-2|0]|0;p=d[j]|0;q=d[j+1|0]|0;r=n-p|0;do{if((((r|0)>-1?r:-r|0)|0)<(e|0)){s=o-n|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=q-p|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=o+4-q+(p-n<<2)>>3;if((s|0)<(l|0)){t=l}else{t=(s|0)>(k|0)?k:s}s=t+n|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[m]=u;s=p-t|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[j]=v}}while(0);p=j+c|0;m=j+(c-1)|0;n=d[m]|0;q=d[j+(c-2)|0]|0;o=d[p]|0;r=d[j+(c+1)|0]|0;s=n-o|0;if((((s|0)>-1?s:-s|0)|0)>=(e|0)){break}s=q-n|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=r-o|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=q+4-r+(o-n<<2)>>3;if((s|0)<(l|0)){w=l}else{w=(s|0)>(k|0)?k:s}s=w+n|0;if(s>>>0>255>>>0){x=-s>>31&255}else{x=s&255}a[m]=x;m=o-w|0;if(m>>>0>255>>>0){y=-m>>31&255}else{y=m&255}a[p]=y}}while(0);k=i+1|0;if((k|0)<4){i=k;j=j+h|0}else{break}}return}function Sga(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=-c|0;h=c*-2|0;i=b;b=0;while(1){j=i+g|0;k=d[j]|0;l=d[i+h|0]|0;m=d[i]|0;n=d[i+c|0]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(e|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(f|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(f|0)){break}a[j]=(k+2+(l<<1)+n|0)>>>2;a[i]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=b+1|0;if((n|0)<8){i=i+1|0;b=n}else{break}}return}function Tga(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;b=0;while(1){h=g-1|0;i=d[h]|0;j=d[g-2|0]|0;k=d[g]|0;l=d[g+1|0]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[h]=(i+2+(j<<1)+l|0)>>>2;a[g]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=b+1|0;if((l|0)<8){g=g+c|0;b=l}else{break}}return}function Uga(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;b=0;while(1){h=g-1|0;i=d[h]|0;j=d[g-2|0]|0;k=d[g]|0;l=d[g+1|0]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[h]=(i+2+(j<<1)+l|0)>>>2;a[g]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=b+1|0;if((l|0)<16){g=g+c|0;b=l}else{break}}return}function Vga(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;b=0;while(1){h=g-1|0;i=d[h]|0;j=d[g-2|0]|0;k=d[g]|0;l=d[g+1|0]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[h]=(i+2+(j<<1)+l|0)>>>2;a[g]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=b+1|0;if((l|0)<4){g=g+c|0;b=l}else{break}}return}function Wga(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;b=0;while(1){h=g-1|0;i=d[h]|0;j=d[g-2|0]|0;k=d[g]|0;l=d[g+1|0]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[h]=(i+2+(j<<1)+l|0)>>>2;a[g]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=b+1|0;if((l|0)<8){g=g+c|0;b=l}else{break}}return}function Xga(b,c){b=b|0;c=c|0;var d=0,e=0;d=0;while(1){if((d|0)>=(c|0)){e=4;break}if((a[b+d|0]|0)==0){e=4;break}else{d=d+1|0}}if((e|0)==4){return d|0}return 0}function Yga(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=((b[e>>1]|0)+32&65535)<<16>>16;h=e+16|0;i=b[h>>1]|0;j=i+g|0;k=g-i|0;i=e+8|0;g=b[i>>1]|0;l=e+24|0;m=b[l>>1]|0;n=(g>>1)-m|0;o=(m>>1)+g|0;b[e>>1]=o+j;b[i>>1]=n+k;b[h>>1]=k-n;b[l>>1]=j-o;o=e+2|0;j=b[o>>1]|0;l=e+18|0;n=b[l>>1]|0;k=n+j|0;h=j-n|0;n=e+10|0;j=b[n>>1]|0;i=e+26|0;g=b[i>>1]|0;m=(j>>1)-g|0;p=(g>>1)+j|0;b[o>>1]=p+k;b[n>>1]=m+h;b[l>>1]=h-m;b[i>>1]=k-p;p=e+4|0;k=b[p>>1]|0;i=e+20|0;m=b[i>>1]|0;h=m+k|0;l=k-m|0;m=e+12|0;k=b[m>>1]|0;n=e+28|0;o=b[n>>1]|0;j=(k>>1)-o|0;g=(o>>1)+k|0;b[p>>1]=g+h;b[m>>1]=j+l;b[i>>1]=l-j;b[n>>1]=h-g;g=e+6|0;h=b[g>>1]|0;n=e+22|0;j=b[n>>1]|0;l=j+h|0;i=h-j|0;j=e+14|0;h=b[j>>1]|0;m=e+30|0;p=b[m>>1]|0;k=(h>>1)-p|0;o=(p>>1)+h|0;b[g>>1]=o+l;b[j>>1]=k+i;b[n>>1]=i-k;b[m>>1]=l-o;o=f<<1;l=f*3|0;m=0;do{k=m<<2;i=b[e+(k<<1)>>1]|0;n=b[e+((k|2)<<1)>>1]|0;j=n+i|0;g=i-n|0;n=b[e+((k|1)<<1)>>1]|0;i=b[e+((k|3)<<1)>>1]|0;k=(n>>1)-i|0;h=(i>>1)+n|0;n=c+m|0;i=(h+j>>6)+(d[n]|0)|0;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[n]=q;n=c+(m+f)|0;i=(d[n]|0)+(k+g>>6)|0;if(i>>>0>255>>>0){r=-i>>31&255}else{r=i&255}a[n]=r;n=c+(m+o)|0;i=(d[n]|0)+(g-k>>6)|0;if(i>>>0>255>>>0){s=-i>>31&255}else{s=i&255}a[n]=s;n=c+(m+l)|0;i=(d[n]|0)+(j-h>>6)|0;if(i>>>0>255>>>0){t=-i>>31&255}else{t=i&255}a[n]=t;m=m+1|0;}while((m|0)<4);TGb(e|0,0,32)|0;return}function Zga(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=(b[e>>1]|0)+32&65535;b[e>>1]=g;h=0;i=g;while(1){g=i<<16>>16;j=e+(h+32<<1)|0;k=b[j>>1]|0;l=k+g|0;m=g-k|0;k=e+(h+16<<1)|0;g=b[k>>1]|0;n=e+(h+48<<1)|0;o=b[n>>1]|0;p=(g>>1)-o|0;q=(o>>1)+g|0;g=q+l|0;o=p+m|0;r=m-p|0;p=l-q|0;q=e+(h+24<<1)|0;l=b[q>>1]|0;m=e+(h+40<<1)|0;s=b[m>>1]|0;t=e+(h+56<<1)|0;u=b[t>>1]|0;v=s-l-u-(u>>1)|0;w=e+(h+8<<1)|0;x=b[w>>1]|0;y=u-((l>>1)+l)+x|0;z=u+s+(s>>1)-x|0;u=s+l+x+(x>>1)|0;x=(u>>2)+v|0;l=(z>>2)+y|0;s=(y>>2)-z|0;z=u-(v>>2)|0;b[e+(h<<1)>>1]=z+g;b[t>>1]=g-z;b[w>>1]=s+o;b[n>>1]=o-s;b[k>>1]=l+r;b[m>>1]=r-l;b[q>>1]=x+p;b[j>>1]=p-x;x=h+1|0;if((x|0)>=8){break}h=x;i=b[e+(x<<1)>>1]|0}i=f<<1;h=f*3|0;x=f<<2;p=f*5|0;j=f*6|0;q=f*7|0;l=0;do{r=l<<3;m=b[e+(r<<1)>>1]|0;k=b[e+((r|4)<<1)>>1]|0;s=k+m|0;o=m-k|0;k=b[e+((r|2)<<1)>>1]|0;m=b[e+((r|6)<<1)>>1]|0;n=(k>>1)-m|0;w=(m>>1)+k|0;k=w+s|0;m=n+o|0;z=o-n|0;n=s-w|0;w=b[e+((r|3)<<1)>>1]|0;s=b[e+((r|5)<<1)>>1]|0;o=b[e+((r|7)<<1)>>1]|0;g=s-w-o-(o>>1)|0;t=b[e+((r|1)<<1)>>1]|0;r=o-((w>>1)+w)+t|0;v=o+s+(s>>1)-t|0;o=s+w+t+(t>>1)|0;t=(o>>2)+g|0;w=(v>>2)+r|0;s=(r>>2)-v|0;v=o-(g>>2)|0;g=c+l|0;o=(v+k>>6)+(d[g]|0)|0;if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}a[g]=A;g=c+(l+f)|0;o=(d[g]|0)+(s+m>>6)|0;if(o>>>0>255>>>0){B=-o>>31&255}else{B=o&255}a[g]=B;g=c+(l+i)|0;o=(d[g]|0)+(w+z>>6)|0;if(o>>>0>255>>>0){C=-o>>31&255}else{C=o&255}a[g]=C;g=c+(l+h)|0;o=(d[g]|0)+(t+n>>6)|0;if(o>>>0>255>>>0){D=-o>>31&255}else{D=o&255}a[g]=D;g=c+(l+x)|0;o=(d[g]|0)+(n-t>>6)|0;if(o>>>0>255>>>0){E=-o>>31&255}else{E=o&255}a[g]=E;g=c+(l+p)|0;o=(d[g]|0)+(z-w>>6)|0;if(o>>>0>255>>>0){F=-o>>31&255}else{F=o&255}a[g]=F;g=c+(l+j)|0;o=(d[g]|0)+(m-s>>6)|0;if(o>>>0>255>>>0){G=-o>>31&255}else{G=o&255}a[g]=G;g=c+(l+q)|0;o=(d[g]|0)+(k-v>>6)|0;if(o>>>0>255>>>0){H=-o>>31&255}else{H=o&255}a[g]=H;l=l+1|0;}while((l|0)<8);TGb(e|0,0,128)|0;return}function _ga(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=(b[e>>1]|0)+32>>6;b[e>>1]=0;e=0;h=c;while(1){c=(d[h]|0)+g|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=e+1|0;if((c|0)<4){e=c;h=h+f|0}else{break}}return}function $ga(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=(b[e>>1]|0)+32>>6;b[e>>1]=0;e=0;h=c;while(1){c=(d[h]|0)+g|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=h+4|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[c]=n;c=h+5|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[c]=o;c=h+6|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[c]=p;c=h+7|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[c]=q;c=e+1|0;if((c|0)<8){e=c;h=h+f|0}else{break}}return}function aha(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=0;do{k=a[i+(d[473200+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){l=g+(j<<4<<1)|0;m=b[l>>1]|0;if(m<<16>>16==0){n=l;o=15;break}p=e+(c[f+(j<<2)>>2]|0)|0;q=(m<<16>>16)+32>>6;b[l>>1]=0;l=0;m=p;while(1){p=(d[m]|0)+q|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[m]=r;p=m+1|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){t=-s>>31&255}else{t=s&255}a[p]=t;p=m+2|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[p]=u;p=m+3|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[p]=v;p=l+1|0;if((p|0)<4){l=p;m=m+h|0}else{break}}}else if((k<<24>>24|0)!=0){n=g+(j<<4<<1)|0;o=15}}while(0);if((o|0)==15){o=0;Yga(e+(c[f+(j<<2)>>2]|0)|0,n,h)}j=j+1|0;}while((j|0)<16);return}function bha(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=0;do{do{if((a[i+(d[473200+j|0]|0)|0]|0)==0){k=g+(j<<4<<1)|0;l=b[k>>1]|0;if(l<<16>>16==0){break}m=e+(c[f+(j<<2)>>2]|0)|0;n=(l<<16>>16)+32>>6;b[k>>1]=0;k=0;l=m;while(1){m=(d[l]|0)+n|0;if(m>>>0>255>>>0){o=-m>>31&255}else{o=m&255}a[l]=o;m=l+1|0;p=(d[m]|0)+n|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[m]=q;m=l+2|0;p=(d[m]|0)+n|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[m]=r;m=l+3|0;p=(d[m]|0)+n|0;if(p>>>0>255>>>0){s=-p>>31&255}else{s=p&255}a[m]=s;m=k+1|0;if((m|0)<4){k=m;l=l+h|0}else{break}}}else{Yga(e+(c[f+(j<<2)>>2]|0)|0,g+(j<<4<<1)|0,h)}}while(0);j=j+1|0;}while((j|0)<16);return}function cha(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=a[h+12|0]|0;do{if((i<<24>>24|0)==1){if((b[f>>1]|0)==0){j=4;break}$ga(d+(c[e>>2]|0)|0,f,g)}else if((i<<24>>24|0)!=0){j=4}}while(0);if((j|0)==4){Zga(d+(c[e>>2]|0)|0,f,g)}i=a[h+14|0]|0;do{if((i<<24>>24|0)==1){k=f+128|0;if((b[k>>1]|0)==0){l=k;j=9;break}$ga(d+(c[e+16>>2]|0)|0,k,g)}else if((i<<24>>24|0)!=0){l=f+128|0;j=9}}while(0);if((j|0)==9){Zga(d+(c[e+16>>2]|0)|0,l,g)}l=a[h+28|0]|0;do{if((l<<24>>24|0)==1){i=f+256|0;if((b[i>>1]|0)==0){m=i;j=14;break}$ga(d+(c[e+32>>2]|0)|0,i,g)}else if((l<<24>>24|0)!=0){m=f+256|0;j=14}}while(0);if((j|0)==14){Zga(d+(c[e+32>>2]|0)|0,m,g)}m=a[h+30|0]|0;do{if((m<<24>>24|0)==1){h=f+384|0;if((b[h>>1]|0)==0){n=h;break}$ga(d+(c[e+48>>2]|0)|0,h,g);return}else if((m<<24>>24|0)==0){return}else{n=f+384|0}}while(0);Zga(d+(c[e+48>>2]|0)|0,n,g);return}function dha(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=1;do{k=j<<4;l=k|4;if((k|0)<(l|0)){m=e+(j-1<<2)|0;n=k;do{do{if((a[i+(d[473200+n|0]|0)|0]|0)==0){k=g+(n<<4<<1)|0;o=b[k>>1]|0;if(o<<16>>16==0){break}p=(c[m>>2]|0)+(c[f+(n<<2)>>2]|0)|0;q=(o<<16>>16)+32>>6;b[k>>1]=0;k=0;o=p;while(1){p=(d[o]|0)+q|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[o]=r;p=o+1|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){t=-s>>31&255}else{t=s&255}a[p]=t;p=o+2|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[p]=u;p=o+3|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[p]=v;p=k+1|0;if((p|0)<4){k=p;o=o+h|0}else{break}}}else{Yga((c[m>>2]|0)+(c[f+(n<<2)>>2]|0)|0,g+(n<<4<<1)|0,h)}}while(0);n=n+1|0;}while((n|0)<(l|0))}j=j+1|0;}while((j|0)<3);return}function eha(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=1;while(1){k=j<<4;l=k|4;if((k|0)<(l|0)){m=e+(j-1<<2)|0;n=k;do{do{if((a[i+(d[473200+n|0]|0)|0]|0)==0){k=g+(n<<4<<1)|0;o=b[k>>1]|0;if(o<<16>>16==0){break}p=(c[m>>2]|0)+(c[f+(n<<2)>>2]|0)|0;q=(o<<16>>16)+32>>6;b[k>>1]=0;k=0;o=p;while(1){p=(d[o]|0)+q|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[o]=r;p=o+1|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){t=-s>>31&255}else{t=s&255}a[p]=t;p=o+2|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[p]=u;p=o+3|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[p]=v;p=k+1|0;if((p|0)<4){k=p;o=o+h|0}else{break}}}else{Yga((c[m>>2]|0)+(c[f+(n<<2)>>2]|0)|0,g+(n<<4<<1)|0,h)}}while(0);n=n+1|0;}while((n|0)<(l|0))}l=j+1|0;if((l|0)<3){j=l}else{w=1;break}}do{j=w<<4;v=j|4;u=j|8;if((v|0)<(u|0)){j=e+(w-1<<2)|0;t=v;do{v=t+4|0;do{if((a[i+(d[473200+v|0]|0)|0]|0)==0){r=g+(t<<4<<1)|0;l=b[r>>1]|0;if(l<<16>>16==0){break}n=(c[j>>2]|0)+(c[f+(v<<2)>>2]|0)|0;m=(l<<16>>16)+32>>6;b[r>>1]=0;r=0;l=n;while(1){n=(d[l]|0)+m|0;if(n>>>0>255>>>0){x=-n>>31&255}else{x=n&255}a[l]=x;n=l+1|0;o=(d[n]|0)+m|0;if(o>>>0>255>>>0){y=-o>>31&255}else{y=o&255}a[n]=y;n=l+2|0;o=(d[n]|0)+m|0;if(o>>>0>255>>>0){z=-o>>31&255}else{z=o&255}a[n]=z;n=l+3|0;o=(d[n]|0)+m|0;if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}a[n]=A;n=r+1|0;if((n|0)<4){r=n;l=l+h|0}else{break}}}else{Yga((c[j>>2]|0)+(c[f+(v<<2)>>2]|0)|0,g+(t<<4<<1)|0,h)}}while(0);t=t+1|0;}while((t|0)<(u|0))}w=w+1|0;}while((w|0)<3);return}function fha(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+64|0;h=g|0;j=b[e>>1]|0;k=b[e+2>>1]|0;l=k+j|0;m=j-k|0;k=b[e+4>>1]|0;j=b[e+6>>1]|0;n=k-j|0;o=j+k|0;k=o+l|0;c[h>>2]=k;c[h+4>>2]=l-o;c[h+8>>2]=m-n;c[h+12>>2]=n+m;m=b[e+8>>1]|0;n=b[e+10>>1]|0;o=n+m|0;l=m-n|0;n=b[e+12>>1]|0;m=b[e+14>>1]|0;j=n-m|0;p=m+n|0;c[h+16>>2]=p+o;c[h+20>>2]=o-p;c[h+24>>2]=l-j;c[h+28>>2]=j+l;l=b[e+16>>1]|0;j=b[e+18>>1]|0;p=j+l|0;o=l-j|0;j=b[e+20>>1]|0;l=b[e+22>>1]|0;n=j-l|0;m=l+j|0;c[h+32>>2]=m+p;c[h+36>>2]=p-m;c[h+40>>2]=o-n;c[h+44>>2]=n+o;o=b[e+24>>1]|0;n=b[e+26>>1]|0;m=n+o|0;p=o-n|0;n=b[e+28>>1]|0;o=b[e+30>>1]|0;e=n-o|0;j=o+n|0;c[h+48>>2]=j+m;c[h+52>>2]=m-j;c[h+56>>2]=p-e;c[h+60>>2]=e+p;p=0;e=k;while(1){k=d[1207560+p|0]|0;j=c[h+(p+8<<2)>>2]|0;m=j+e|0;n=e-j|0;j=c[h+(p+4<<2)>>2]|0;o=c[h+(p+12<<2)>>2]|0;l=j-o|0;q=o+j|0;b[a+(k<<1)>>1]=((ba(q+m|0,f)|0)+128|0)>>>8;b[a+(k+16<<1)>>1]=((ba(l+n|0,f)|0)+128|0)>>>8;b[a+(k+64<<1)>>1]=((ba(n-l|0,f)|0)+128|0)>>>8;b[a+(k+80<<1)>>1]=((ba(m-q|0,f)|0)+128|0)>>>8;q=p+1|0;if((q|0)>=4){break}p=q;e=c[h+(q<<2)>>2]|0}i=g;return}function gha(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[a>>1]|0;e=a+32|0;f=b[e>>1]|0;g=f+d|0;h=d-f|0;f=a+64|0;d=b[f>>1]|0;i=a+96|0;j=b[i>>1]|0;k=j+d|0;l=d-j|0;j=a+128|0;d=b[j>>1]|0;m=a+160|0;n=b[m>>1]|0;o=n+d|0;p=d-n|0;n=a+192|0;d=b[n>>1]|0;q=a+224|0;r=b[q>>1]|0;s=r+d|0;t=d-r|0;r=o+g|0;d=g-o|0;o=k-s|0;g=s+k|0;b[a>>1]=((ba(g+r|0,c)|0)+128|0)>>>8;b[f>>1]=((ba(o+d|0,c)|0)+128|0)>>>8;b[j>>1]=((ba(d-o|0,c)|0)+128|0)>>>8;b[n>>1]=((ba(r-g|0,c)|0)+128|0)>>>8;g=p+h|0;r=h-p|0;p=l-t|0;h=t+l|0;b[e>>1]=((ba(h+g|0,c)|0)+128|0)>>>8;b[i>>1]=((ba(p+r|0,c)|0)+128|0)>>>8;b[m>>1]=((ba(r-p|0,c)|0)+128|0)>>>8;b[q>>1]=((ba(g-h|0,c)|0)+128|0)>>>8;return}function hha(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[a>>1]|0;e=a+32|0;f=b[e>>1]|0;g=a+64|0;h=b[g>>1]|0;i=a+96|0;j=b[i>>1]|0;k=d-f|0;l=f+d|0;d=h-j|0;f=j+h|0;b[a>>1]=(ba(f+l|0,c)|0)>>>7;b[e>>1]=(ba(d+k|0,c)|0)>>>7;b[g>>1]=(ba(l-f|0,c)|0)>>>7;b[i>>1]=(ba(k-d|0,c)|0)>>>7;return}function iha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=d;h=(c[g>>2]|0)+32|0;i=d+32|0;j=c[i>>2]|0;k=j+h|0;l=h-j|0;j=d+16|0;h=c[j>>2]|0;m=d+48|0;n=c[m>>2]|0;o=(h>>1)-n|0;p=(n>>1)+h|0;c[g>>2]=p+k;c[j>>2]=o+l;c[i>>2]=l-o;c[m>>2]=k-p;p=d+4|0;k=c[p>>2]|0;m=d+36|0;o=c[m>>2]|0;l=o+k|0;i=k-o|0;o=d+20|0;k=c[o>>2]|0;j=d+52|0;h=c[j>>2]|0;n=(k>>1)-h|0;q=(h>>1)+k|0;c[p>>2]=q+l;c[o>>2]=n+i;c[m>>2]=i-n;c[j>>2]=l-q;q=d+8|0;l=c[q>>2]|0;j=d+40|0;n=c[j>>2]|0;i=n+l|0;m=l-n|0;n=d+24|0;l=c[n>>2]|0;o=d+56|0;p=c[o>>2]|0;k=(l>>1)-p|0;h=(p>>1)+l|0;c[q>>2]=h+i;c[n>>2]=k+m;c[j>>2]=m-k;c[o>>2]=i-h;h=d+12|0;i=c[h>>2]|0;o=d+44|0;k=c[o>>2]|0;m=k+i|0;j=i-k|0;k=d+28|0;i=c[k>>2]|0;n=d+60|0;q=c[n>>2]|0;l=(i>>1)-q|0;p=(q>>1)+i|0;c[h>>2]=p+m;c[k>>2]=l+j;c[o>>2]=j-l;c[n>>2]=m-p;p=a;a=f>>1;f=a<<1;m=a*3|0;n=0;do{l=n<<2;j=c[g+(l<<2)>>2]|0;o=c[g+((l|2)<<2)>>2]|0;k=o+j|0;h=j-o|0;o=c[g+((l|1)<<2)>>2]|0;j=c[g+((l|3)<<2)>>2]|0;l=(o>>1)-j|0;i=(j>>1)+o|0;o=p+(n<<1)|0;j=(i+k>>6)+(e[o>>1]|0)|0;if(j>>>0<512>>>0){r=j&65535}else{r=-j>>31&511}b[o>>1]=r;o=p+(n+a<<1)|0;j=(e[o>>1]|0)+(l+h>>6)|0;if(j>>>0<512>>>0){s=j&65535}else{s=-j>>31&511}b[o>>1]=s;o=p+(n+f<<1)|0;j=(e[o>>1]|0)+(h-l>>6)|0;if(j>>>0<512>>>0){t=j&65535}else{t=-j>>31&511}b[o>>1]=t;o=p+(n+m<<1)|0;j=(e[o>>1]|0)+(k-i>>6)|0;if(j>>>0<512>>>0){u=j&65535}else{u=-j>>31&511}b[o>>1]=u;n=n+1|0;}while((n|0)<4);TGb(d|0,0,64)|0;return}function jha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=d;h=(c[g>>2]|0)+32|0;c[g>>2]=h;i=0;j=h;while(1){h=g+(i+32<<2)|0;k=c[h>>2]|0;l=k+j|0;m=j-k|0;k=g+(i+16<<2)|0;n=c[k>>2]|0;o=g+(i+48<<2)|0;p=c[o>>2]|0;q=(n>>1)-p|0;r=(p>>1)+n|0;n=r+l|0;p=q+m|0;s=m-q|0;q=l-r|0;r=g+(i+24<<2)|0;l=c[r>>2]|0;m=g+(i+40<<2)|0;t=c[m>>2]|0;u=g+(i+56<<2)|0;v=c[u>>2]|0;w=t-l-v-(v>>1)|0;x=g+(i+8<<2)|0;y=c[x>>2]|0;z=v-((l>>1)+l)+y|0;A=v+t+(t>>1)-y|0;v=t+l+y+(y>>1)|0;y=(v>>2)+w|0;l=(A>>2)+z|0;t=(z>>2)-A|0;A=v-(w>>2)|0;c[g+(i<<2)>>2]=A+n;c[u>>2]=n-A;c[x>>2]=t+p;c[o>>2]=p-t;c[k>>2]=l+s;c[m>>2]=s-l;c[r>>2]=y+q;c[h>>2]=q-y;y=i+1|0;if((y|0)>=8){break}i=y;j=c[g+(y<<2)>>2]|0}j=a;a=f>>1;f=a<<1;i=a*3|0;y=a<<2;q=a*5|0;h=a*6|0;r=a*7|0;l=0;do{s=l<<3;m=c[g+(s<<2)>>2]|0;k=c[g+((s|4)<<2)>>2]|0;t=k+m|0;p=m-k|0;k=c[g+((s|2)<<2)>>2]|0;m=c[g+((s|6)<<2)>>2]|0;o=(k>>1)-m|0;x=(m>>1)+k|0;k=x+t|0;m=o+p|0;A=p-o|0;o=t-x|0;x=c[g+((s|3)<<2)>>2]|0;t=c[g+((s|5)<<2)>>2]|0;p=c[g+((s|7)<<2)>>2]|0;n=t-x-p-(p>>1)|0;u=c[g+((s|1)<<2)>>2]|0;s=p-((x>>1)+x)+u|0;w=p+t+(t>>1)-u|0;p=t+x+u+(u>>1)|0;u=(p>>2)+n|0;x=(w>>2)+s|0;t=(s>>2)-w|0;w=p-(n>>2)|0;n=j+(l<<1)|0;p=(w+k>>6)+(e[n>>1]|0)|0;if(p>>>0<512>>>0){B=p&65535}else{B=-p>>31&511}b[n>>1]=B;n=j+(l+a<<1)|0;p=(e[n>>1]|0)+(t+m>>6)|0;if(p>>>0<512>>>0){C=p&65535}else{C=-p>>31&511}b[n>>1]=C;n=j+(l+f<<1)|0;p=(e[n>>1]|0)+(x+A>>6)|0;if(p>>>0<512>>>0){D=p&65535}else{D=-p>>31&511}b[n>>1]=D;n=j+(l+i<<1)|0;p=(e[n>>1]|0)+(u+o>>6)|0;if(p>>>0<512>>>0){E=p&65535}else{E=-p>>31&511}b[n>>1]=E;n=j+(l+y<<1)|0;p=(e[n>>1]|0)+(o-u>>6)|0;if(p>>>0<512>>>0){F=p&65535}else{F=-p>>31&511}b[n>>1]=F;n=j+(l+q<<1)|0;p=(e[n>>1]|0)+(A-x>>6)|0;if(p>>>0<512>>>0){G=p&65535}else{G=-p>>31&511}b[n>>1]=G;n=j+(l+h<<1)|0;p=(e[n>>1]|0)+(m-t>>6)|0;if(p>>>0<512>>>0){H=p&65535}else{H=-p>>31&511}b[n>>1]=H;n=j+(l+r<<1)|0;p=(e[n>>1]|0)+(k-w>>6)|0;if(p>>>0<512>>>0){I=p&65535}else{I=-p>>31&511}b[n>>1]=I;l=l+1|0;}while((l|0)<8);TGb(d|0,0,256)|0;return}function kha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d;d=(c[g>>2]|0)+32>>6;h=f>>>1;c[g>>2]=0;g=0;f=a;while(1){a=(e[f>>1]|0)+d|0;if(a>>>0<512>>>0){i=a&65535}else{i=-a>>31&511}b[f>>1]=i;a=f+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){k=j&65535}else{k=-j>>31&511}b[a>>1]=k;a=f+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){l=j&65535}else{l=-j>>31&511}b[a>>1]=l;a=f+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){m=j&65535}else{m=-j>>31&511}b[a>>1]=m;a=g+1|0;if((a|0)<4){g=a;f=f+(h<<1)|0}else{break}}return}function lha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d;d=(c[g>>2]|0)+32>>6;c[g>>2]=0;g=f>>>1;f=0;h=a;while(1){a=(e[h>>1]|0)+d|0;if(a>>>0<512>>>0){i=a&65535}else{i=-a>>31&511}b[h>>1]=i;a=h+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){k=j&65535}else{k=-j>>31&511}b[a>>1]=k;a=h+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){l=j&65535}else{l=-j>>31&511}b[a>>1]=l;a=h+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){m=j&65535}else{m=-j>>31&511}b[a>>1]=m;a=h+8|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){n=j&65535}else{n=-j>>31&511}b[a>>1]=n;a=h+10|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){o=j&65535}else{o=-j>>31&511}b[a>>1]=o;a=h+12|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){p=j&65535}else{p=-j>>31&511}b[a>>1]=p;a=h+14|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){q=j&65535}else{q=-j>>31&511}b[a>>1]=q;a=f+1|0;if((a|0)<8){f=a;h=h+(g<<1)|0}else{break}}return}function mha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=f;j=0;do{k=a[h+(d[473200+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){if((c[i+(j<<4<<2)>>2]|0)==0){l=5;break}kha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else if((k<<24>>24|0)!=0){l=5}}while(0);if((l|0)==5){l=0;iha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}j=j+1|0;}while((j|0)<16);return}function nha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=f;j=0;do{do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(j<<4<<2)>>2]|0)==0){break}kha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else{iha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<16);return}function oha(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=a[g+12|0]|0;do{if((h<<24>>24|0)==1){if((c[e>>2]|0)==0){i=4;break}lha(b+(c[d>>2]|0)|0,e,f)}else if((h<<24>>24|0)!=0){i=4}}while(0);if((i|0)==4){jha(b+(c[d>>2]|0)|0,e,f)}h=a[g+14|0]|0;do{if((h<<24>>24|0)==1){if((c[e+256>>2]|0)==0){i=8;break}lha(b+(c[d+16>>2]|0)|0,e+256|0,f)}else if((h<<24>>24|0)!=0){i=8}}while(0);if((i|0)==8){jha(b+(c[d+16>>2]|0)|0,e+256|0,f)}h=a[g+28|0]|0;do{if((h<<24>>24|0)==1){if((c[e+512>>2]|0)==0){i=12;break}lha(b+(c[d+32>>2]|0)|0,e+512|0,f)}else if((h<<24>>24|0)!=0){i=12}}while(0);if((i|0)==12){jha(b+(c[d+32>>2]|0)|0,e+512|0,f)}h=a[g+30|0]|0;if((h<<24>>24|0)==0){return}else if((h<<24>>24|0)==1){i=14}do{if((i|0)==14){if((c[e+768>>2]|0)==0){break}lha(b+(c[d+48>>2]|0)|0,e+768|0,f);return}}while(0);jha(b+(c[d+48>>2]|0)|0,e+768|0,f);return}function pha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=f;j=1;do{k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[473200+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}kha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{iha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[473200+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}kha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{iha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[473200+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}kha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{iha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[473200+n|0]|0)|0]|0)!=0){iha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}kha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<3);return}function qha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=f;j=1;while(1){k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[473200+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}kha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{iha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[473200+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}kha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{iha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[473200+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}kha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{iha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[473200+n|0]|0)|0]|0)!=0){iha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}kha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);k=j+1|0;if((k|0)<3){j=k}else{o=20;break}}do{j=o+4|0;do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(o<<4<<2)>>2]|0)==0){break}kha((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}else{iha((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}}while(0);o=o+1|0;}while((o|0)<24);o=b+4|0;b=36;do{j=b+4|0;do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(b<<4<<2)>>2]|0)==0){break}kha((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}else{iha((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}}while(0);b=b+1|0;}while((b|0)<40);return}function rha(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b>>2]|0;j=c[b+4>>2]|0;k=j+h|0;l=h-j|0;j=c[b+8>>2]|0;h=c[b+12>>2]|0;m=j-h|0;n=h+j|0;j=n+k|0;c[g>>2]=j;c[g+4>>2]=k-n;c[g+8>>2]=l-m;c[g+12>>2]=m+l;l=c[b+16>>2]|0;m=c[b+20>>2]|0;n=m+l|0;k=l-m|0;m=c[b+24>>2]|0;l=c[b+28>>2]|0;h=m-l|0;o=l+m|0;c[g+16>>2]=o+n;c[g+20>>2]=n-o;c[g+24>>2]=k-h;c[g+28>>2]=h+k;k=c[b+32>>2]|0;h=c[b+36>>2]|0;o=h+k|0;n=k-h|0;h=c[b+40>>2]|0;k=c[b+44>>2]|0;m=h-k|0;l=k+h|0;c[g+32>>2]=l+o;c[g+36>>2]=o-l;c[g+40>>2]=n-m;c[g+44>>2]=m+n;n=c[b+48>>2]|0;m=c[b+52>>2]|0;l=m+n|0;o=n-m|0;m=c[b+56>>2]|0;n=c[b+60>>2]|0;b=m-n|0;h=n+m|0;c[g+48>>2]=h+l;c[g+52>>2]=l-h;c[g+56>>2]=o-b;c[g+60>>2]=b+o;o=a;a=0;b=j;while(1){j=d[1207560+a|0]|0;h=c[g+(a+8<<2)>>2]|0;l=h+b|0;m=b-h|0;h=c[g+(a+4<<2)>>2]|0;n=c[g+(a+12<<2)>>2]|0;k=h-n|0;p=n+h|0;c[o+(j<<2)>>2]=(ba(p+l|0,e)|0)+128>>8;c[o+(j+16<<2)>>2]=(ba(k+m|0,e)|0)+128>>8;c[o+(j+64<<2)>>2]=(ba(m-k|0,e)|0)+128>>8;c[o+(j+80<<2)>>2]=(ba(l-p|0,e)|0)+128>>8;p=a+1|0;if((p|0)>=4){break}a=p;b=c[g+(p<<2)>>2]|0}i=f;return}function sha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=g+e|0;i=e-g|0;g=a+128|0;e=c[g>>2]|0;j=a+192|0;k=c[j>>2]|0;l=k+e|0;m=e-k|0;k=a+256|0;e=c[k>>2]|0;n=a+320|0;o=c[n>>2]|0;p=o+e|0;q=e-o|0;o=a+384|0;e=c[o>>2]|0;r=a+448|0;a=c[r>>2]|0;s=a+e|0;t=e-a|0;a=p+h|0;e=h-p|0;p=l-s|0;h=s+l|0;c[d>>2]=(ba(h+a|0,b)|0)+128>>8;c[g>>2]=(ba(p+e|0,b)|0)+128>>8;c[k>>2]=(ba(e-p|0,b)|0)+128>>8;c[o>>2]=(ba(a-h|0,b)|0)+128>>8;h=q+i|0;a=i-q|0;q=m-t|0;i=t+m|0;c[f>>2]=(ba(i+h|0,b)|0)+128>>8;c[j>>2]=(ba(q+a|0,b)|0)+128>>8;c[n>>2]=(ba(a-q|0,b)|0)+128>>8;c[r>>2]=(ba(h-i|0,b)|0)+128>>8;return}function tha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=a+128|0;i=c[h>>2]|0;j=a+192|0;a=c[j>>2]|0;k=e-g|0;l=g+e|0;e=i-a|0;g=a+i|0;c[d>>2]=(ba(g+l|0,b)|0)>>7;c[f>>2]=(ba(e+k|0,b)|0)>>7;c[h>>2]=(ba(l-g|0,b)|0)>>7;c[j>>2]=(ba(k-e|0,b)|0)>>7;return}function uha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=d;h=(c[g>>2]|0)+32|0;i=d+32|0;j=c[i>>2]|0;k=j+h|0;l=h-j|0;j=d+16|0;h=c[j>>2]|0;m=d+48|0;n=c[m>>2]|0;o=(h>>1)-n|0;p=(n>>1)+h|0;c[g>>2]=p+k;c[j>>2]=o+l;c[i>>2]=l-o;c[m>>2]=k-p;p=d+4|0;k=c[p>>2]|0;m=d+36|0;o=c[m>>2]|0;l=o+k|0;i=k-o|0;o=d+20|0;k=c[o>>2]|0;j=d+52|0;h=c[j>>2]|0;n=(k>>1)-h|0;q=(h>>1)+k|0;c[p>>2]=q+l;c[o>>2]=n+i;c[m>>2]=i-n;c[j>>2]=l-q;q=d+8|0;l=c[q>>2]|0;j=d+40|0;n=c[j>>2]|0;i=n+l|0;m=l-n|0;n=d+24|0;l=c[n>>2]|0;o=d+56|0;p=c[o>>2]|0;k=(l>>1)-p|0;h=(p>>1)+l|0;c[q>>2]=h+i;c[n>>2]=k+m;c[j>>2]=m-k;c[o>>2]=i-h;h=d+12|0;i=c[h>>2]|0;o=d+44|0;k=c[o>>2]|0;m=k+i|0;j=i-k|0;k=d+28|0;i=c[k>>2]|0;n=d+60|0;q=c[n>>2]|0;l=(i>>1)-q|0;p=(q>>1)+i|0;c[h>>2]=p+m;c[k>>2]=l+j;c[o>>2]=j-l;c[n>>2]=m-p;p=a;a=f>>1;f=a<<1;m=a*3|0;n=0;do{l=n<<2;j=c[g+(l<<2)>>2]|0;o=c[g+((l|2)<<2)>>2]|0;k=o+j|0;h=j-o|0;o=c[g+((l|1)<<2)>>2]|0;j=c[g+((l|3)<<2)>>2]|0;l=(o>>1)-j|0;i=(j>>1)+o|0;o=p+(n<<1)|0;j=(i+k>>6)+(e[o>>1]|0)|0;if(j>>>0<1024>>>0){r=j&65535}else{r=-j>>31&1023}b[o>>1]=r;o=p+(n+a<<1)|0;j=(e[o>>1]|0)+(l+h>>6)|0;if(j>>>0<1024>>>0){s=j&65535}else{s=-j>>31&1023}b[o>>1]=s;o=p+(n+f<<1)|0;j=(e[o>>1]|0)+(h-l>>6)|0;if(j>>>0<1024>>>0){t=j&65535}else{t=-j>>31&1023}b[o>>1]=t;o=p+(n+m<<1)|0;j=(e[o>>1]|0)+(k-i>>6)|0;if(j>>>0<1024>>>0){u=j&65535}else{u=-j>>31&1023}b[o>>1]=u;n=n+1|0;}while((n|0)<4);TGb(d|0,0,64)|0;return}function vha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=d;h=(c[g>>2]|0)+32|0;c[g>>2]=h;i=0;j=h;while(1){h=g+(i+32<<2)|0;k=c[h>>2]|0;l=k+j|0;m=j-k|0;k=g+(i+16<<2)|0;n=c[k>>2]|0;o=g+(i+48<<2)|0;p=c[o>>2]|0;q=(n>>1)-p|0;r=(p>>1)+n|0;n=r+l|0;p=q+m|0;s=m-q|0;q=l-r|0;r=g+(i+24<<2)|0;l=c[r>>2]|0;m=g+(i+40<<2)|0;t=c[m>>2]|0;u=g+(i+56<<2)|0;v=c[u>>2]|0;w=t-l-v-(v>>1)|0;x=g+(i+8<<2)|0;y=c[x>>2]|0;z=v-((l>>1)+l)+y|0;A=v+t+(t>>1)-y|0;v=t+l+y+(y>>1)|0;y=(v>>2)+w|0;l=(A>>2)+z|0;t=(z>>2)-A|0;A=v-(w>>2)|0;c[g+(i<<2)>>2]=A+n;c[u>>2]=n-A;c[x>>2]=t+p;c[o>>2]=p-t;c[k>>2]=l+s;c[m>>2]=s-l;c[r>>2]=y+q;c[h>>2]=q-y;y=i+1|0;if((y|0)>=8){break}i=y;j=c[g+(y<<2)>>2]|0}j=a;a=f>>1;f=a<<1;i=a*3|0;y=a<<2;q=a*5|0;h=a*6|0;r=a*7|0;l=0;do{s=l<<3;m=c[g+(s<<2)>>2]|0;k=c[g+((s|4)<<2)>>2]|0;t=k+m|0;p=m-k|0;k=c[g+((s|2)<<2)>>2]|0;m=c[g+((s|6)<<2)>>2]|0;o=(k>>1)-m|0;x=(m>>1)+k|0;k=x+t|0;m=o+p|0;A=p-o|0;o=t-x|0;x=c[g+((s|3)<<2)>>2]|0;t=c[g+((s|5)<<2)>>2]|0;p=c[g+((s|7)<<2)>>2]|0;n=t-x-p-(p>>1)|0;u=c[g+((s|1)<<2)>>2]|0;s=p-((x>>1)+x)+u|0;w=p+t+(t>>1)-u|0;p=t+x+u+(u>>1)|0;u=(p>>2)+n|0;x=(w>>2)+s|0;t=(s>>2)-w|0;w=p-(n>>2)|0;n=j+(l<<1)|0;p=(w+k>>6)+(e[n>>1]|0)|0;if(p>>>0<1024>>>0){B=p&65535}else{B=-p>>31&1023}b[n>>1]=B;n=j+(l+a<<1)|0;p=(e[n>>1]|0)+(t+m>>6)|0;if(p>>>0<1024>>>0){C=p&65535}else{C=-p>>31&1023}b[n>>1]=C;n=j+(l+f<<1)|0;p=(e[n>>1]|0)+(x+A>>6)|0;if(p>>>0<1024>>>0){D=p&65535}else{D=-p>>31&1023}b[n>>1]=D;n=j+(l+i<<1)|0;p=(e[n>>1]|0)+(u+o>>6)|0;if(p>>>0<1024>>>0){E=p&65535}else{E=-p>>31&1023}b[n>>1]=E;n=j+(l+y<<1)|0;p=(e[n>>1]|0)+(o-u>>6)|0;if(p>>>0<1024>>>0){F=p&65535}else{F=-p>>31&1023}b[n>>1]=F;n=j+(l+q<<1)|0;p=(e[n>>1]|0)+(A-x>>6)|0;if(p>>>0<1024>>>0){G=p&65535}else{G=-p>>31&1023}b[n>>1]=G;n=j+(l+h<<1)|0;p=(e[n>>1]|0)+(m-t>>6)|0;if(p>>>0<1024>>>0){H=p&65535}else{H=-p>>31&1023}b[n>>1]=H;n=j+(l+r<<1)|0;p=(e[n>>1]|0)+(k-w>>6)|0;if(p>>>0<1024>>>0){I=p&65535}else{I=-p>>31&1023}b[n>>1]=I;l=l+1|0;}while((l|0)<8);TGb(d|0,0,256)|0;return}function wha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d;d=(c[g>>2]|0)+32>>6;h=f>>>1;c[g>>2]=0;g=0;f=a;while(1){a=(e[f>>1]|0)+d|0;if(a>>>0<1024>>>0){i=a&65535}else{i=-a>>31&1023}b[f>>1]=i;a=f+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){k=j&65535}else{k=-j>>31&1023}b[a>>1]=k;a=f+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){l=j&65535}else{l=-j>>31&1023}b[a>>1]=l;a=f+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){m=j&65535}else{m=-j>>31&1023}b[a>>1]=m;a=g+1|0;if((a|0)<4){g=a;f=f+(h<<1)|0}else{break}}return}function xha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d;d=(c[g>>2]|0)+32>>6;c[g>>2]=0;g=f>>>1;f=0;h=a;while(1){a=(e[h>>1]|0)+d|0;if(a>>>0<1024>>>0){i=a&65535}else{i=-a>>31&1023}b[h>>1]=i;a=h+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){k=j&65535}else{k=-j>>31&1023}b[a>>1]=k;a=h+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){l=j&65535}else{l=-j>>31&1023}b[a>>1]=l;a=h+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){m=j&65535}else{m=-j>>31&1023}b[a>>1]=m;a=h+8|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){n=j&65535}else{n=-j>>31&1023}b[a>>1]=n;a=h+10|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){o=j&65535}else{o=-j>>31&1023}b[a>>1]=o;a=h+12|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){p=j&65535}else{p=-j>>31&1023}b[a>>1]=p;a=h+14|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){q=j&65535}else{q=-j>>31&1023}b[a>>1]=q;a=f+1|0;if((a|0)<8){f=a;h=h+(g<<1)|0}else{break}}return}function yha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=f;j=0;do{k=a[h+(d[473200+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){if((c[i+(j<<4<<2)>>2]|0)==0){l=5;break}wha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else if((k<<24>>24|0)!=0){l=5}}while(0);if((l|0)==5){l=0;uha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}j=j+1|0;}while((j|0)<16);return}function zha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=f;j=0;do{do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(j<<4<<2)>>2]|0)==0){break}wha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else{uha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<16);return}function Aha(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=a[g+12|0]|0;do{if((h<<24>>24|0)==1){if((c[e>>2]|0)==0){i=4;break}xha(b+(c[d>>2]|0)|0,e,f)}else if((h<<24>>24|0)!=0){i=4}}while(0);if((i|0)==4){vha(b+(c[d>>2]|0)|0,e,f)}h=a[g+14|0]|0;do{if((h<<24>>24|0)==1){if((c[e+256>>2]|0)==0){i=8;break}xha(b+(c[d+16>>2]|0)|0,e+256|0,f)}else if((h<<24>>24|0)!=0){i=8}}while(0);if((i|0)==8){vha(b+(c[d+16>>2]|0)|0,e+256|0,f)}h=a[g+28|0]|0;do{if((h<<24>>24|0)==1){if((c[e+512>>2]|0)==0){i=12;break}xha(b+(c[d+32>>2]|0)|0,e+512|0,f)}else if((h<<24>>24|0)!=0){i=12}}while(0);if((i|0)==12){vha(b+(c[d+32>>2]|0)|0,e+512|0,f)}h=a[g+30|0]|0;if((h<<24>>24|0)==1){i=14}else if((h<<24>>24|0)==0){return}do{if((i|0)==14){if((c[e+768>>2]|0)==0){break}xha(b+(c[d+48>>2]|0)|0,e+768|0,f);return}}while(0);vha(b+(c[d+48>>2]|0)|0,e+768|0,f);return}function Bha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=f;j=1;do{k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[473200+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}wha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{uha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[473200+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}wha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{uha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[473200+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}wha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{uha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[473200+n|0]|0)|0]|0)!=0){uha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}wha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<3);return}function Cha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=f;j=1;while(1){k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[473200+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}wha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{uha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[473200+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}wha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{uha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[473200+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}wha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{uha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[473200+n|0]|0)|0]|0)!=0){uha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}wha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);k=j+1|0;if((k|0)<3){j=k}else{o=20;break}}do{j=o+4|0;do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(o<<4<<2)>>2]|0)==0){break}wha((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}else{uha((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}}while(0);o=o+1|0;}while((o|0)<24);o=b+4|0;b=36;do{j=b+4|0;do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(b<<4<<2)>>2]|0)==0){break}wha((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}else{uha((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}}while(0);b=b+1|0;}while((b|0)<40);return}function Dha(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b>>2]|0;j=c[b+4>>2]|0;k=j+h|0;l=h-j|0;j=c[b+8>>2]|0;h=c[b+12>>2]|0;m=j-h|0;n=h+j|0;j=n+k|0;c[g>>2]=j;c[g+4>>2]=k-n;c[g+8>>2]=l-m;c[g+12>>2]=m+l;l=c[b+16>>2]|0;m=c[b+20>>2]|0;n=m+l|0;k=l-m|0;m=c[b+24>>2]|0;l=c[b+28>>2]|0;h=m-l|0;o=l+m|0;c[g+16>>2]=o+n;c[g+20>>2]=n-o;c[g+24>>2]=k-h;c[g+28>>2]=h+k;k=c[b+32>>2]|0;h=c[b+36>>2]|0;o=h+k|0;n=k-h|0;h=c[b+40>>2]|0;k=c[b+44>>2]|0;m=h-k|0;l=k+h|0;c[g+32>>2]=l+o;c[g+36>>2]=o-l;c[g+40>>2]=n-m;c[g+44>>2]=m+n;n=c[b+48>>2]|0;m=c[b+52>>2]|0;l=m+n|0;o=n-m|0;m=c[b+56>>2]|0;n=c[b+60>>2]|0;b=m-n|0;h=n+m|0;c[g+48>>2]=h+l;c[g+52>>2]=l-h;c[g+56>>2]=o-b;c[g+60>>2]=b+o;o=a;a=0;b=j;while(1){j=d[1207560+a|0]|0;h=c[g+(a+8<<2)>>2]|0;l=h+b|0;m=b-h|0;h=c[g+(a+4<<2)>>2]|0;n=c[g+(a+12<<2)>>2]|0;k=h-n|0;p=n+h|0;c[o+(j<<2)>>2]=(ba(p+l|0,e)|0)+128>>8;c[o+(j+16<<2)>>2]=(ba(k+m|0,e)|0)+128>>8;c[o+(j+64<<2)>>2]=(ba(m-k|0,e)|0)+128>>8;c[o+(j+80<<2)>>2]=(ba(l-p|0,e)|0)+128>>8;p=a+1|0;if((p|0)>=4){break}a=p;b=c[g+(p<<2)>>2]|0}i=f;return}function Eha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=g+e|0;i=e-g|0;g=a+128|0;e=c[g>>2]|0;j=a+192|0;k=c[j>>2]|0;l=k+e|0;m=e-k|0;k=a+256|0;e=c[k>>2]|0;n=a+320|0;o=c[n>>2]|0;p=o+e|0;q=e-o|0;o=a+384|0;e=c[o>>2]|0;r=a+448|0;a=c[r>>2]|0;s=a+e|0;t=e-a|0;a=p+h|0;e=h-p|0;p=l-s|0;h=s+l|0;c[d>>2]=(ba(h+a|0,b)|0)+128>>8;c[g>>2]=(ba(p+e|0,b)|0)+128>>8;c[k>>2]=(ba(e-p|0,b)|0)+128>>8;c[o>>2]=(ba(a-h|0,b)|0)+128>>8;h=q+i|0;a=i-q|0;q=m-t|0;i=t+m|0;c[f>>2]=(ba(i+h|0,b)|0)+128>>8;c[j>>2]=(ba(q+a|0,b)|0)+128>>8;c[n>>2]=(ba(a-q|0,b)|0)+128>>8;c[r>>2]=(ba(h-i|0,b)|0)+128>>8;return}function Fha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=a+128|0;i=c[h>>2]|0;j=a+192|0;a=c[j>>2]|0;k=e-g|0;l=g+e|0;e=i-a|0;g=a+i|0;c[d>>2]=(ba(g+l|0,b)|0)>>7;c[f>>2]=(ba(e+k|0,b)|0)>>7;c[h>>2]=(ba(l-g|0,b)|0)>>7;c[j>>2]=(ba(k-e|0,b)|0)>>7;return}function Gha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=d;h=(c[g>>2]|0)+32|0;i=d+32|0;j=c[i>>2]|0;k=j+h|0;l=h-j|0;j=d+16|0;h=c[j>>2]|0;m=d+48|0;n=c[m>>2]|0;o=(h>>1)-n|0;p=(n>>1)+h|0;c[g>>2]=p+k;c[j>>2]=o+l;c[i>>2]=l-o;c[m>>2]=k-p;p=d+4|0;k=c[p>>2]|0;m=d+36|0;o=c[m>>2]|0;l=o+k|0;i=k-o|0;o=d+20|0;k=c[o>>2]|0;j=d+52|0;h=c[j>>2]|0;n=(k>>1)-h|0;q=(h>>1)+k|0;c[p>>2]=q+l;c[o>>2]=n+i;c[m>>2]=i-n;c[j>>2]=l-q;q=d+8|0;l=c[q>>2]|0;j=d+40|0;n=c[j>>2]|0;i=n+l|0;m=l-n|0;n=d+24|0;l=c[n>>2]|0;o=d+56|0;p=c[o>>2]|0;k=(l>>1)-p|0;h=(p>>1)+l|0;c[q>>2]=h+i;c[n>>2]=k+m;c[j>>2]=m-k;c[o>>2]=i-h;h=d+12|0;i=c[h>>2]|0;o=d+44|0;k=c[o>>2]|0;m=k+i|0;j=i-k|0;k=d+28|0;i=c[k>>2]|0;n=d+60|0;q=c[n>>2]|0;l=(i>>1)-q|0;p=(q>>1)+i|0;c[h>>2]=p+m;c[k>>2]=l+j;c[o>>2]=j-l;c[n>>2]=m-p;p=a;a=f>>1;f=a<<1;m=a*3|0;n=0;do{l=n<<2;j=c[g+(l<<2)>>2]|0;o=c[g+((l|2)<<2)>>2]|0;k=o+j|0;h=j-o|0;o=c[g+((l|1)<<2)>>2]|0;j=c[g+((l|3)<<2)>>2]|0;l=(o>>1)-j|0;i=(j>>1)+o|0;o=p+(n<<1)|0;j=(i+k>>6)+(e[o>>1]|0)|0;if(j>>>0<4096>>>0){r=j&65535}else{r=-j>>31&4095}b[o>>1]=r;o=p+(n+a<<1)|0;j=(e[o>>1]|0)+(l+h>>6)|0;if(j>>>0<4096>>>0){s=j&65535}else{s=-j>>31&4095}b[o>>1]=s;o=p+(n+f<<1)|0;j=(e[o>>1]|0)+(h-l>>6)|0;if(j>>>0<4096>>>0){t=j&65535}else{t=-j>>31&4095}b[o>>1]=t;o=p+(n+m<<1)|0;j=(e[o>>1]|0)+(k-i>>6)|0;if(j>>>0<4096>>>0){u=j&65535}else{u=-j>>31&4095}b[o>>1]=u;n=n+1|0;}while((n|0)<4);TGb(d|0,0,64)|0;return}function Hha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=d;h=(c[g>>2]|0)+32|0;c[g>>2]=h;i=0;j=h;while(1){h=g+(i+32<<2)|0;k=c[h>>2]|0;l=k+j|0;m=j-k|0;k=g+(i+16<<2)|0;n=c[k>>2]|0;o=g+(i+48<<2)|0;p=c[o>>2]|0;q=(n>>1)-p|0;r=(p>>1)+n|0;n=r+l|0;p=q+m|0;s=m-q|0;q=l-r|0;r=g+(i+24<<2)|0;l=c[r>>2]|0;m=g+(i+40<<2)|0;t=c[m>>2]|0;u=g+(i+56<<2)|0;v=c[u>>2]|0;w=t-l-v-(v>>1)|0;x=g+(i+8<<2)|0;y=c[x>>2]|0;z=v-((l>>1)+l)+y|0;A=v+t+(t>>1)-y|0;v=t+l+y+(y>>1)|0;y=(v>>2)+w|0;l=(A>>2)+z|0;t=(z>>2)-A|0;A=v-(w>>2)|0;c[g+(i<<2)>>2]=A+n;c[u>>2]=n-A;c[x>>2]=t+p;c[o>>2]=p-t;c[k>>2]=l+s;c[m>>2]=s-l;c[r>>2]=y+q;c[h>>2]=q-y;y=i+1|0;if((y|0)>=8){break}i=y;j=c[g+(y<<2)>>2]|0}j=a;a=f>>1;f=a<<1;i=a*3|0;y=a<<2;q=a*5|0;h=a*6|0;r=a*7|0;l=0;do{s=l<<3;m=c[g+(s<<2)>>2]|0;k=c[g+((s|4)<<2)>>2]|0;t=k+m|0;p=m-k|0;k=c[g+((s|2)<<2)>>2]|0;m=c[g+((s|6)<<2)>>2]|0;o=(k>>1)-m|0;x=(m>>1)+k|0;k=x+t|0;m=o+p|0;A=p-o|0;o=t-x|0;x=c[g+((s|3)<<2)>>2]|0;t=c[g+((s|5)<<2)>>2]|0;p=c[g+((s|7)<<2)>>2]|0;n=t-x-p-(p>>1)|0;u=c[g+((s|1)<<2)>>2]|0;s=p-((x>>1)+x)+u|0;w=p+t+(t>>1)-u|0;p=t+x+u+(u>>1)|0;u=(p>>2)+n|0;x=(w>>2)+s|0;t=(s>>2)-w|0;w=p-(n>>2)|0;n=j+(l<<1)|0;p=(w+k>>6)+(e[n>>1]|0)|0;if(p>>>0<4096>>>0){B=p&65535}else{B=-p>>31&4095}b[n>>1]=B;n=j+(l+a<<1)|0;p=(e[n>>1]|0)+(t+m>>6)|0;if(p>>>0<4096>>>0){C=p&65535}else{C=-p>>31&4095}b[n>>1]=C;n=j+(l+f<<1)|0;p=(e[n>>1]|0)+(x+A>>6)|0;if(p>>>0<4096>>>0){D=p&65535}else{D=-p>>31&4095}b[n>>1]=D;n=j+(l+i<<1)|0;p=(e[n>>1]|0)+(u+o>>6)|0;if(p>>>0<4096>>>0){E=p&65535}else{E=-p>>31&4095}b[n>>1]=E;n=j+(l+y<<1)|0;p=(e[n>>1]|0)+(o-u>>6)|0;if(p>>>0<4096>>>0){F=p&65535}else{F=-p>>31&4095}b[n>>1]=F;n=j+(l+q<<1)|0;p=(e[n>>1]|0)+(A-x>>6)|0;if(p>>>0<4096>>>0){G=p&65535}else{G=-p>>31&4095}b[n>>1]=G;n=j+(l+h<<1)|0;p=(e[n>>1]|0)+(m-t>>6)|0;if(p>>>0<4096>>>0){H=p&65535}else{H=-p>>31&4095}b[n>>1]=H;n=j+(l+r<<1)|0;p=(e[n>>1]|0)+(k-w>>6)|0;if(p>>>0<4096>>>0){I=p&65535}else{I=-p>>31&4095}b[n>>1]=I;l=l+1|0;}while((l|0)<8);TGb(d|0,0,256)|0;return}function Iha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d;d=(c[g>>2]|0)+32>>6;h=f>>>1;c[g>>2]=0;g=0;f=a;while(1){a=(e[f>>1]|0)+d|0;if(a>>>0<4096>>>0){i=a&65535}else{i=-a>>31&4095}b[f>>1]=i;a=f+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){k=j&65535}else{k=-j>>31&4095}b[a>>1]=k;a=f+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){l=j&65535}else{l=-j>>31&4095}b[a>>1]=l;a=f+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){m=j&65535}else{m=-j>>31&4095}b[a>>1]=m;a=g+1|0;if((a|0)<4){g=a;f=f+(h<<1)|0}else{break}}return}function Jha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d;d=(c[g>>2]|0)+32>>6;c[g>>2]=0;g=f>>>1;f=0;h=a;while(1){a=(e[h>>1]|0)+d|0;if(a>>>0<4096>>>0){i=a&65535}else{i=-a>>31&4095}b[h>>1]=i;a=h+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){k=j&65535}else{k=-j>>31&4095}b[a>>1]=k;a=h+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){l=j&65535}else{l=-j>>31&4095}b[a>>1]=l;a=h+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){m=j&65535}else{m=-j>>31&4095}b[a>>1]=m;a=h+8|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){n=j&65535}else{n=-j>>31&4095}b[a>>1]=n;a=h+10|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){o=j&65535}else{o=-j>>31&4095}b[a>>1]=o;a=h+12|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){p=j&65535}else{p=-j>>31&4095}b[a>>1]=p;a=h+14|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){q=j&65535}else{q=-j>>31&4095}b[a>>1]=q;a=f+1|0;if((a|0)<8){f=a;h=h+(g<<1)|0}else{break}}return}function Kha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=f;j=0;do{k=a[h+(d[473200+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){if((c[i+(j<<4<<2)>>2]|0)==0){l=5;break}Iha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else if((k<<24>>24|0)!=0){l=5}}while(0);if((l|0)==5){l=0;Gha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}j=j+1|0;}while((j|0)<16);return}function Lha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=f;j=0;do{do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(j<<4<<2)>>2]|0)==0){break}Iha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else{Gha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<16);return}function Mha(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=a[g+12|0]|0;do{if((h<<24>>24|0)==1){if((c[e>>2]|0)==0){i=4;break}Jha(b+(c[d>>2]|0)|0,e,f)}else if((h<<24>>24|0)!=0){i=4}}while(0);if((i|0)==4){Hha(b+(c[d>>2]|0)|0,e,f)}h=a[g+14|0]|0;do{if((h<<24>>24|0)==1){if((c[e+256>>2]|0)==0){i=8;break}Jha(b+(c[d+16>>2]|0)|0,e+256|0,f)}else if((h<<24>>24|0)!=0){i=8}}while(0);if((i|0)==8){Hha(b+(c[d+16>>2]|0)|0,e+256|0,f)}h=a[g+28|0]|0;do{if((h<<24>>24|0)==1){if((c[e+512>>2]|0)==0){i=12;break}Jha(b+(c[d+32>>2]|0)|0,e+512|0,f)}else if((h<<24>>24|0)!=0){i=12}}while(0);if((i|0)==12){Hha(b+(c[d+32>>2]|0)|0,e+512|0,f)}h=a[g+30|0]|0;if((h<<24>>24|0)==0){return}else if((h<<24>>24|0)==1){i=14}do{if((i|0)==14){if((c[e+768>>2]|0)==0){break}Jha(b+(c[d+48>>2]|0)|0,e+768|0,f);return}}while(0);Hha(b+(c[d+48>>2]|0)|0,e+768|0,f);return}function Nha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=f;j=1;do{k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[473200+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}Iha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{Gha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[473200+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}Iha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{Gha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[473200+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}Iha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{Gha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[473200+n|0]|0)|0]|0)!=0){Gha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}Iha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<3);return}function Oha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=f;j=1;while(1){k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[473200+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}Iha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{Gha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[473200+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}Iha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{Gha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[473200+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}Iha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{Gha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[473200+n|0]|0)|0]|0)!=0){Gha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}Iha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);k=j+1|0;if((k|0)<3){j=k}else{o=20;break}}do{j=o+4|0;do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(o<<4<<2)>>2]|0)==0){break}Iha((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}else{Gha((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}}while(0);o=o+1|0;}while((o|0)<24);o=b+4|0;b=36;do{j=b+4|0;do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(b<<4<<2)>>2]|0)==0){break}Iha((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}else{Gha((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}}while(0);b=b+1|0;}while((b|0)<40);return}function Pha(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b>>2]|0;j=c[b+4>>2]|0;k=j+h|0;l=h-j|0;j=c[b+8>>2]|0;h=c[b+12>>2]|0;m=j-h|0;n=h+j|0;j=n+k|0;c[g>>2]=j;c[g+4>>2]=k-n;c[g+8>>2]=l-m;c[g+12>>2]=m+l;l=c[b+16>>2]|0;m=c[b+20>>2]|0;n=m+l|0;k=l-m|0;m=c[b+24>>2]|0;l=c[b+28>>2]|0;h=m-l|0;o=l+m|0;c[g+16>>2]=o+n;c[g+20>>2]=n-o;c[g+24>>2]=k-h;c[g+28>>2]=h+k;k=c[b+32>>2]|0;h=c[b+36>>2]|0;o=h+k|0;n=k-h|0;h=c[b+40>>2]|0;k=c[b+44>>2]|0;m=h-k|0;l=k+h|0;c[g+32>>2]=l+o;c[g+36>>2]=o-l;c[g+40>>2]=n-m;c[g+44>>2]=m+n;n=c[b+48>>2]|0;m=c[b+52>>2]|0;l=m+n|0;o=n-m|0;m=c[b+56>>2]|0;n=c[b+60>>2]|0;b=m-n|0;h=n+m|0;c[g+48>>2]=h+l;c[g+52>>2]=l-h;c[g+56>>2]=o-b;c[g+60>>2]=b+o;o=a;a=0;b=j;while(1){j=d[1207560+a|0]|0;h=c[g+(a+8<<2)>>2]|0;l=h+b|0;m=b-h|0;h=c[g+(a+4<<2)>>2]|0;n=c[g+(a+12<<2)>>2]|0;k=h-n|0;p=n+h|0;c[o+(j<<2)>>2]=(ba(p+l|0,e)|0)+128>>8;c[o+(j+16<<2)>>2]=(ba(k+m|0,e)|0)+128>>8;c[o+(j+64<<2)>>2]=(ba(m-k|0,e)|0)+128>>8;c[o+(j+80<<2)>>2]=(ba(l-p|0,e)|0)+128>>8;p=a+1|0;if((p|0)>=4){break}a=p;b=c[g+(p<<2)>>2]|0}i=f;return}function Qha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=g+e|0;i=e-g|0;g=a+128|0;e=c[g>>2]|0;j=a+192|0;k=c[j>>2]|0;l=k+e|0;m=e-k|0;k=a+256|0;e=c[k>>2]|0;n=a+320|0;o=c[n>>2]|0;p=o+e|0;q=e-o|0;o=a+384|0;e=c[o>>2]|0;r=a+448|0;a=c[r>>2]|0;s=a+e|0;t=e-a|0;a=p+h|0;e=h-p|0;p=l-s|0;h=s+l|0;c[d>>2]=(ba(h+a|0,b)|0)+128>>8;c[g>>2]=(ba(p+e|0,b)|0)+128>>8;c[k>>2]=(ba(e-p|0,b)|0)+128>>8;c[o>>2]=(ba(a-h|0,b)|0)+128>>8;h=q+i|0;a=i-q|0;q=m-t|0;i=t+m|0;c[f>>2]=(ba(i+h|0,b)|0)+128>>8;c[j>>2]=(ba(q+a|0,b)|0)+128>>8;c[n>>2]=(ba(a-q|0,b)|0)+128>>8;c[r>>2]=(ba(h-i|0,b)|0)+128>>8;return}function Rha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=a+128|0;i=c[h>>2]|0;j=a+192|0;a=c[j>>2]|0;k=e-g|0;l=g+e|0;e=i-a|0;g=a+i|0;c[d>>2]=(ba(g+l|0,b)|0)>>7;c[f>>2]=(ba(e+k|0,b)|0)>>7;c[h>>2]=(ba(l-g|0,b)|0)>>7;c[j>>2]=(ba(k-e|0,b)|0)>>7;return}function Sha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=d;h=(c[g>>2]|0)+32|0;i=d+32|0;j=c[i>>2]|0;k=j+h|0;l=h-j|0;j=d+16|0;h=c[j>>2]|0;m=d+48|0;n=c[m>>2]|0;o=(h>>1)-n|0;p=(n>>1)+h|0;c[g>>2]=p+k;c[j>>2]=o+l;c[i>>2]=l-o;c[m>>2]=k-p;p=d+4|0;k=c[p>>2]|0;m=d+36|0;o=c[m>>2]|0;l=o+k|0;i=k-o|0;o=d+20|0;k=c[o>>2]|0;j=d+52|0;h=c[j>>2]|0;n=(k>>1)-h|0;q=(h>>1)+k|0;c[p>>2]=q+l;c[o>>2]=n+i;c[m>>2]=i-n;c[j>>2]=l-q;q=d+8|0;l=c[q>>2]|0;j=d+40|0;n=c[j>>2]|0;i=n+l|0;m=l-n|0;n=d+24|0;l=c[n>>2]|0;o=d+56|0;p=c[o>>2]|0;k=(l>>1)-p|0;h=(p>>1)+l|0;c[q>>2]=h+i;c[n>>2]=k+m;c[j>>2]=m-k;c[o>>2]=i-h;h=d+12|0;i=c[h>>2]|0;o=d+44|0;k=c[o>>2]|0;m=k+i|0;j=i-k|0;k=d+28|0;i=c[k>>2]|0;n=d+60|0;q=c[n>>2]|0;l=(i>>1)-q|0;p=(q>>1)+i|0;c[h>>2]=p+m;c[k>>2]=l+j;c[o>>2]=j-l;c[n>>2]=m-p;p=a;a=f>>1;f=a<<1;m=a*3|0;n=0;do{l=n<<2;j=c[g+(l<<2)>>2]|0;o=c[g+((l|2)<<2)>>2]|0;k=o+j|0;h=j-o|0;o=c[g+((l|1)<<2)>>2]|0;j=c[g+((l|3)<<2)>>2]|0;l=(o>>1)-j|0;i=(j>>1)+o|0;o=p+(n<<1)|0;j=(i+k>>6)+(e[o>>1]|0)|0;if(j>>>0<16384>>>0){r=j&65535}else{r=-j>>31&16383}b[o>>1]=r;o=p+(n+a<<1)|0;j=(e[o>>1]|0)+(l+h>>6)|0;if(j>>>0<16384>>>0){s=j&65535}else{s=-j>>31&16383}b[o>>1]=s;o=p+(n+f<<1)|0;j=(e[o>>1]|0)+(h-l>>6)|0;if(j>>>0<16384>>>0){t=j&65535}else{t=-j>>31&16383}b[o>>1]=t;o=p+(n+m<<1)|0;j=(e[o>>1]|0)+(k-i>>6)|0;if(j>>>0<16384>>>0){u=j&65535}else{u=-j>>31&16383}b[o>>1]=u;n=n+1|0;}while((n|0)<4);TGb(d|0,0,64)|0;return}function Tha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=d;h=(c[g>>2]|0)+32|0;c[g>>2]=h;i=0;j=h;while(1){h=g+(i+32<<2)|0;k=c[h>>2]|0;l=k+j|0;m=j-k|0;k=g+(i+16<<2)|0;n=c[k>>2]|0;o=g+(i+48<<2)|0;p=c[o>>2]|0;q=(n>>1)-p|0;r=(p>>1)+n|0;n=r+l|0;p=q+m|0;s=m-q|0;q=l-r|0;r=g+(i+24<<2)|0;l=c[r>>2]|0;m=g+(i+40<<2)|0;t=c[m>>2]|0;u=g+(i+56<<2)|0;v=c[u>>2]|0;w=t-l-v-(v>>1)|0;x=g+(i+8<<2)|0;y=c[x>>2]|0;z=v-((l>>1)+l)+y|0;A=v+t+(t>>1)-y|0;v=t+l+y+(y>>1)|0;y=(v>>2)+w|0;l=(A>>2)+z|0;t=(z>>2)-A|0;A=v-(w>>2)|0;c[g+(i<<2)>>2]=A+n;c[u>>2]=n-A;c[x>>2]=t+p;c[o>>2]=p-t;c[k>>2]=l+s;c[m>>2]=s-l;c[r>>2]=y+q;c[h>>2]=q-y;y=i+1|0;if((y|0)>=8){break}i=y;j=c[g+(y<<2)>>2]|0}j=a;a=f>>1;f=a<<1;i=a*3|0;y=a<<2;q=a*5|0;h=a*6|0;r=a*7|0;l=0;do{s=l<<3;m=c[g+(s<<2)>>2]|0;k=c[g+((s|4)<<2)>>2]|0;t=k+m|0;p=m-k|0;k=c[g+((s|2)<<2)>>2]|0;m=c[g+((s|6)<<2)>>2]|0;o=(k>>1)-m|0;x=(m>>1)+k|0;k=x+t|0;m=o+p|0;A=p-o|0;o=t-x|0;x=c[g+((s|3)<<2)>>2]|0;t=c[g+((s|5)<<2)>>2]|0;p=c[g+((s|7)<<2)>>2]|0;n=t-x-p-(p>>1)|0;u=c[g+((s|1)<<2)>>2]|0;s=p-((x>>1)+x)+u|0;w=p+t+(t>>1)-u|0;p=t+x+u+(u>>1)|0;u=(p>>2)+n|0;x=(w>>2)+s|0;t=(s>>2)-w|0;w=p-(n>>2)|0;n=j+(l<<1)|0;p=(w+k>>6)+(e[n>>1]|0)|0;if(p>>>0<16384>>>0){B=p&65535}else{B=-p>>31&16383}b[n>>1]=B;n=j+(l+a<<1)|0;p=(e[n>>1]|0)+(t+m>>6)|0;if(p>>>0<16384>>>0){C=p&65535}else{C=-p>>31&16383}b[n>>1]=C;n=j+(l+f<<1)|0;p=(e[n>>1]|0)+(x+A>>6)|0;if(p>>>0<16384>>>0){D=p&65535}else{D=-p>>31&16383}b[n>>1]=D;n=j+(l+i<<1)|0;p=(e[n>>1]|0)+(u+o>>6)|0;if(p>>>0<16384>>>0){E=p&65535}else{E=-p>>31&16383}b[n>>1]=E;n=j+(l+y<<1)|0;p=(e[n>>1]|0)+(o-u>>6)|0;if(p>>>0<16384>>>0){F=p&65535}else{F=-p>>31&16383}b[n>>1]=F;n=j+(l+q<<1)|0;p=(e[n>>1]|0)+(A-x>>6)|0;if(p>>>0<16384>>>0){G=p&65535}else{G=-p>>31&16383}b[n>>1]=G;n=j+(l+h<<1)|0;p=(e[n>>1]|0)+(m-t>>6)|0;if(p>>>0<16384>>>0){H=p&65535}else{H=-p>>31&16383}b[n>>1]=H;n=j+(l+r<<1)|0;p=(e[n>>1]|0)+(k-w>>6)|0;if(p>>>0<16384>>>0){I=p&65535}else{I=-p>>31&16383}b[n>>1]=I;l=l+1|0;}while((l|0)<8);TGb(d|0,0,256)|0;return}function Uha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d;d=(c[g>>2]|0)+32>>6;h=f>>>1;c[g>>2]=0;g=0;f=a;while(1){a=(e[f>>1]|0)+d|0;if(a>>>0<16384>>>0){i=a&65535}else{i=-a>>31&16383}b[f>>1]=i;a=f+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){k=j&65535}else{k=-j>>31&16383}b[a>>1]=k;a=f+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){l=j&65535}else{l=-j>>31&16383}b[a>>1]=l;a=f+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){m=j&65535}else{m=-j>>31&16383}b[a>>1]=m;a=g+1|0;if((a|0)<4){g=a;f=f+(h<<1)|0}else{break}}return}function Vha(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d;d=(c[g>>2]|0)+32>>6;c[g>>2]=0;g=f>>>1;f=0;h=a;while(1){a=(e[h>>1]|0)+d|0;if(a>>>0<16384>>>0){i=a&65535}else{i=-a>>31&16383}b[h>>1]=i;a=h+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){k=j&65535}else{k=-j>>31&16383}b[a>>1]=k;a=h+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){l=j&65535}else{l=-j>>31&16383}b[a>>1]=l;a=h+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){m=j&65535}else{m=-j>>31&16383}b[a>>1]=m;a=h+8|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){n=j&65535}else{n=-j>>31&16383}b[a>>1]=n;a=h+10|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){o=j&65535}else{o=-j>>31&16383}b[a>>1]=o;a=h+12|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){p=j&65535}else{p=-j>>31&16383}b[a>>1]=p;a=h+14|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){q=j&65535}else{q=-j>>31&16383}b[a>>1]=q;a=f+1|0;if((a|0)<8){f=a;h=h+(g<<1)|0}else{break}}return}function Wha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=f;j=0;do{k=a[h+(d[473200+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){if((c[i+(j<<4<<2)>>2]|0)==0){l=5;break}Uha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else if((k<<24>>24|0)!=0){l=5}}while(0);if((l|0)==5){l=0;Sha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}j=j+1|0;}while((j|0)<16);return}function Xha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=f;j=0;do{do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(j<<4<<2)>>2]|0)==0){break}Uha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else{Sha(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<16);return}function Yha(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=a[g+12|0]|0;do{if((h<<24>>24|0)==1){if((c[e>>2]|0)==0){i=4;break}Vha(b+(c[d>>2]|0)|0,e,f)}else if((h<<24>>24|0)!=0){i=4}}while(0);if((i|0)==4){Tha(b+(c[d>>2]|0)|0,e,f)}h=a[g+14|0]|0;do{if((h<<24>>24|0)==1){if((c[e+256>>2]|0)==0){i=8;break}Vha(b+(c[d+16>>2]|0)|0,e+256|0,f)}else if((h<<24>>24|0)!=0){i=8}}while(0);if((i|0)==8){Tha(b+(c[d+16>>2]|0)|0,e+256|0,f)}h=a[g+28|0]|0;do{if((h<<24>>24|0)==1){if((c[e+512>>2]|0)==0){i=12;break}Vha(b+(c[d+32>>2]|0)|0,e+512|0,f)}else if((h<<24>>24|0)!=0){i=12}}while(0);if((i|0)==12){Tha(b+(c[d+32>>2]|0)|0,e+512|0,f)}h=a[g+30|0]|0;if((h<<24>>24|0)==1){i=14}else if((h<<24>>24|0)==0){return}do{if((i|0)==14){if((c[e+768>>2]|0)==0){break}Vha(b+(c[d+48>>2]|0)|0,e+768|0,f);return}}while(0);Tha(b+(c[d+48>>2]|0)|0,e+768|0,f);return}function Zha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=f;j=1;do{k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[473200+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}Uha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{Sha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[473200+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}Uha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{Sha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[473200+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}Uha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{Sha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[473200+n|0]|0)|0]|0)!=0){Sha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}Uha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<3);return}function _ha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=f;j=1;while(1){k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[473200+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}Uha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{Sha((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[473200+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}Uha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{Sha((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[473200+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}Uha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{Sha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[473200+n|0]|0)|0]|0)!=0){Sha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}Uha((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);k=j+1|0;if((k|0)<3){j=k}else{o=20;break}}do{j=o+4|0;do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(o<<4<<2)>>2]|0)==0){break}Uha((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}else{Sha((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}}while(0);o=o+1|0;}while((o|0)<24);o=b+4|0;b=36;do{j=b+4|0;do{if((a[h+(d[473200+j|0]|0)|0]|0)==0){if((c[i+(b<<4<<2)>>2]|0)==0){break}Uha((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}else{Sha((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}}while(0);b=b+1|0;}while((b|0)<40);return}function $ha(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b>>2]|0;j=c[b+4>>2]|0;k=j+h|0;l=h-j|0;j=c[b+8>>2]|0;h=c[b+12>>2]|0;m=j-h|0;n=h+j|0;j=n+k|0;c[g>>2]=j;c[g+4>>2]=k-n;c[g+8>>2]=l-m;c[g+12>>2]=m+l;l=c[b+16>>2]|0;m=c[b+20>>2]|0;n=m+l|0;k=l-m|0;m=c[b+24>>2]|0;l=c[b+28>>2]|0;h=m-l|0;o=l+m|0;c[g+16>>2]=o+n;c[g+20>>2]=n-o;c[g+24>>2]=k-h;c[g+28>>2]=h+k;k=c[b+32>>2]|0;h=c[b+36>>2]|0;o=h+k|0;n=k-h|0;h=c[b+40>>2]|0;k=c[b+44>>2]|0;m=h-k|0;l=k+h|0;c[g+32>>2]=l+o;c[g+36>>2]=o-l;c[g+40>>2]=n-m;c[g+44>>2]=m+n;n=c[b+48>>2]|0;m=c[b+52>>2]|0;l=m+n|0;o=n-m|0;m=c[b+56>>2]|0;n=c[b+60>>2]|0;b=m-n|0;h=n+m|0;c[g+48>>2]=h+l;c[g+52>>2]=l-h;c[g+56>>2]=o-b;c[g+60>>2]=b+o;o=a;a=0;b=j;while(1){j=d[1207560+a|0]|0;h=c[g+(a+8<<2)>>2]|0;l=h+b|0;m=b-h|0;h=c[g+(a+4<<2)>>2]|0;n=c[g+(a+12<<2)>>2]|0;k=h-n|0;p=n+h|0;c[o+(j<<2)>>2]=(ba(p+l|0,e)|0)+128>>8;c[o+(j+16<<2)>>2]=(ba(k+m|0,e)|0)+128>>8;c[o+(j+64<<2)>>2]=(ba(m-k|0,e)|0)+128>>8;c[o+(j+80<<2)>>2]=(ba(l-p|0,e)|0)+128>>8;p=a+1|0;if((p|0)>=4){break}a=p;b=c[g+(p<<2)>>2]|0}i=f;return}function aia(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=g+e|0;i=e-g|0;g=a+128|0;e=c[g>>2]|0;j=a+192|0;k=c[j>>2]|0;l=k+e|0;m=e-k|0;k=a+256|0;e=c[k>>2]|0;n=a+320|0;o=c[n>>2]|0;p=o+e|0;q=e-o|0;o=a+384|0;e=c[o>>2]|0;r=a+448|0;a=c[r>>2]|0;s=a+e|0;t=e-a|0;a=p+h|0;e=h-p|0;p=l-s|0;h=s+l|0;c[d>>2]=(ba(h+a|0,b)|0)+128>>8;c[g>>2]=(ba(p+e|0,b)|0)+128>>8;c[k>>2]=(ba(e-p|0,b)|0)+128>>8;c[o>>2]=(ba(a-h|0,b)|0)+128>>8;h=q+i|0;a=i-q|0;q=m-t|0;i=t+m|0;c[f>>2]=(ba(i+h|0,b)|0)+128>>8;c[j>>2]=(ba(q+a|0,b)|0)+128>>8;c[n>>2]=(ba(a-q|0,b)|0)+128>>8;c[r>>2]=(ba(h-i|0,b)|0)+128>>8;return}function bia(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=a+128|0;i=c[h>>2]|0;j=a+192|0;a=c[j>>2]|0;k=e-g|0;l=g+e|0;e=i-a|0;g=a+i|0;c[d>>2]=(ba(g+l|0,b)|0)>>7;c[f>>2]=(ba(e+k|0,b)|0)>>7;c[h>>2]=(ba(l-g|0,b)|0)>>7;c[j>>2]=(ba(k-e|0,b)|0)>>7;return}function cia(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;if((d|0)==12){g=(b|0)==70;do{if(g){c[a>>2]=34;c[a+4>>2]=284;c[a+8>>2]=1280;c[a+12>>2]=2094;c[a+16>>2]=1600;c[a+20>>2]=1256;c[a+24>>2]=1882;c[a+28>>2]=1644;c[a+32>>2]=764;c[a+36>>2]=58;c[a+40>>2]=1172;c[a+44>>2]=2288;c[a+48>>2]=10;c[a+52>>2]=1950;c[a+56>>2]=1360}else{h=(b|0)==141;j=a|0;if(h){c[j>>2]=1730;c[a+4>>2]=594}else{c[j>>2]=34;c[a+4>>2]=284}c[a+8>>2]=1280;c[a+12>>2]=(b|0)==24?1710:760;c[a+16>>2]=1600;c[a+20>>2]=1256;c[a+24>>2]=1882;c[a+28>>2]=h?498:1276;c[a+32>>2]=604;j=a+36|0;if(h){c[j>>2]=322;c[a+48>>2]=2120;c[a+52>>2]=516;c[a+40>>2]=34;c[a+56>>2]=284;break}else{c[j>>2]=58;c[a+40>>2]=1172;c[a+44>>2]=2288;break}}}while(0);c[a+60>>2]=430;c[a+64>>2]=86;c[a+68>>2]=264;c[a+72>>2]=188;c[a+76>>2]=458;c[a+80>>2]=566;c[a+84>>2]=214;c[a+88>>2]=424;c[a+92>>2]=408;c[a+96>>2]=682;c[a+100>>2]=576;c[a+104>>2]=38;j=(e|0)<2;h=a+108|0;k=a+116|0;if(j){c[k>>2]=284;c[a+112>>2]=266}else{c[k>>2]=400;c[a+112>>2]=396}k=a+120|0;a:do{if((b|0)==141){c[k>>2]=504;c[h>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+136>>2]=294;c[a+140>>2]=460;c[a+132>>2]=j?48:96;c[a+152>>2]=292;c[a+160>>2]=170;c[a+156>>2]=310;l=77}else{c[k>>2]=j?270:298;m=h|0;do{if(g){c[m>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+132>>2]=j?48:96;c[a+152>>2]=292;c[a+160>>2]=170;c[a+156>>2]=310}else{if(j){c[m>>2]=232;c[a+124>>2]=470;c[a+128>>2]=52;c[a+136>>2]=320;c[a+140>>2]=250;c[a+144>>2]=118;c[a+148>>2]=496}else{c[m>>2]=252;c[a+124>>2]=82;c[a+128>>2]=240;c[a+136>>2]=288;c[a+140>>2]=44;c[a+144>>2]=446;c[a+148>>2]=112}c[a+132>>2]=j?48:96;c[a+152>>2]=292;c[a+160>>2]=170;c[a+156>>2]=310;if((b|0)==141){l=77;break a}else if((b|0)==24){c[a+164>>2]=518;break a}else if((b|0)==70){break}else{c[a+164>>2]=264;break a}}}while(0);c[a+164>>2]=268}}while(0);if((l|0)==77){c[a+164>>2]=448;c[a+180>>2]=60;c[a+184>>2]=308}c[a+168>>2]=324;c[a+172>>2]=464;c[a+176>>2]=244;c[a+188>>2]=566;c[a+192>>2]=290;c[a+196>>2]=554;c[a+200>>2]=1760;g=a+212|0;if(j){c[g>>2]=386;c[a+208>>2]=258}else{c[g>>2]=838;c[a+208>>2]=574}c[a+224>>2]=592;c[a+220>>2]=846;i=f;return}else if((d|0)==9){g=(b|0)==70;do{if(g){c[a>>2]=446;c[a+4>>2]=682;c[a+8>>2]=1802;c[a+12>>2]=2094;c[a+16>>2]=1650;c[a+20>>2]=744;c[a+24>>2]=450;c[a+28>>2]=1644;c[a+32>>2]=764;c[a+36>>2]=596;c[a+40>>2]=2328;c[a+44>>2]=240;c[a+48>>2]=10;c[a+52>>2]=1950;c[a+56>>2]=1360}else{j=(b|0)==141;h=a|0;if(j){c[h>>2]=1730;c[a+4>>2]=594}else{c[h>>2]=446;c[a+4>>2]=682}c[a+8>>2]=1802;c[a+12>>2]=(b|0)==24?1710:444;c[a+16>>2]=1650;c[a+20>>2]=744;c[a+24>>2]=450;c[a+28>>2]=j?498:762;c[a+32>>2]=1196;h=a+36|0;if(j){c[h>>2]=322;c[a+48>>2]=1582;c[a+52>>2]=2358;c[a+40>>2]=446;c[a+56>>2]=682;break}else{c[h>>2]=596;c[a+40>>2]=2328;c[a+44>>2]=240;break}}}while(0);c[a+60>>2]=464;c[a+64>>2]=626;c[a+68>>2]=650;c[a+72>>2]=522;c[a+76>>2]=112;c[a+80>>2]=814;c[a+84>>2]=532;c[a+88>>2]=304;c[a+92>>2]=300;c[a+96>>2]=610;c[a+100>>2]=502;c[a+104>>2]=370;h=(e|0)<2;j=a+108|0;k=a+116|0;if(h){c[k>>2]=8;c[a+112>>2]=414}else{c[k>>2]=204;c[a+112>>2]=280}k=a+120|0;b:do{if((b|0)==141){c[k>>2]=504;c[j>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+136>>2]=478;c[a+140>>2]=100;c[a+132>>2]=h?168:330;c[a+152>>2]=500;c[a+160>>2]=472;c[a+156>>2]=190;l=23}else{c[k>>2]=h?438:342;m=j|0;do{if(g){c[m>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+132>>2]=h?168:330;c[a+152>>2]=500;c[a+160>>2]=472;c[a+156>>2]=190}else{if(h){c[m>>2]=390;c[a+124>>2]=474;c[a+128>>2]=84;c[a+136>>2]=106;c[a+140>>2]=166;c[a+144>>2]=26;c[a+148>>2]=382}else{c[m>>2]=260;c[a+124>>2]=378;c[a+128>>2]=418;c[a+136>>2]=58;c[a+140>>2]=156;c[a+144>>2]=334;c[a+148>>2]=14}c[a+132>>2]=h?168:330;c[a+152>>2]=500;c[a+160>>2]=472;c[a+156>>2]=190;if((b|0)==141){l=23;break b}else if((b|0)==24){c[a+164>>2]=518;break b}else if((b|0)==70){break}else{c[a+164>>2]=520;break b}}}while(0);c[a+164>>2]=268}}while(0);if((l|0)==23){c[a+164>>2]=448;c[a+180>>2]=358;c[a+184>>2]=434}c[a+168>>2]=132;c[a+172>>2]=490;c[a+176>>2]=522;c[a+188>>2]=2034;c[a+192>>2]=360;c[a+196>>2]=1296;c[a+200>>2]=960;g=a+212|0;if(h){c[g>>2]=528;c[a+208>>2]=740}else{c[g>>2]=208;c[a+208>>2]=866}c[a+224>>2]=64;c[a+220>>2]=696;i=f;return}else if((d|0)==10){g=(b|0)==70;do{if(g){c[a>>2]=1500;c[a+4>>2]=1150;c[a+8>>2]=1896;c[a+12>>2]=2094;c[a+16>>2]=2198;c[a+20>>2]=660;c[a+24>>2]=1272;c[a+28>>2]=1644;c[a+32>>2]=764;c[a+36>>2]=646;c[a+40>>2]=1774;c[a+44>>2]=564;c[a+48>>2]=10;c[a+52>>2]=1950;c[a+56>>2]=1360}else{h=(b|0)==141;j=a|0;if(h){c[j>>2]=1730;c[a+4>>2]=594}else{c[j>>2]=1500;c[a+4>>2]=1150}c[a+8>>2]=1896;c[a+12>>2]=(b|0)==24?1710:220;c[a+16>>2]=2198;c[a+20>>2]=660;c[a+24>>2]=1272;c[a+28>>2]=h?498:1806;c[a+32>>2]=38;j=a+36|0;if(h){c[j>>2]=322;c[a+48>>2]=342;c[a+52>>2]=2314;c[a+40>>2]=1500;c[a+56>>2]=1150;break}else{c[j>>2]=646;c[a+40>>2]=1774;c[a+44>>2]=564;break}}}while(0);c[a+60>>2]=530;c[a+64>>2]=282;c[a+68>>2]=474;c[a+72>>2]=748;c[a+76>>2]=694;c[a+80>>2]=362;c[a+84>>2]=30;c[a+88>>2]=506;c[a+92>>2]=722;c[a+96>>2]=40;c[a+100>>2]=830;c[a+104>>2]=678;j=(e|0)<2;h=a+108|0;k=a+116|0;if(j){c[k>>2]=406;c[a+112>>2]=466}else{c[k>>2]=262;c[a+112>>2]=512}k=a+120|0;c:do{if((b|0)==141){c[k>>2]=504;c[h>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+136>>2]=422;c[a+140>>2]=328;c[a+132>>2]=j?468:454;c[a+152>>2]=146;c[a+160>>2]=348;c[a+156>>2]=364;l=50}else{c[k>>2]=j?394:154;m=h|0;do{if(g){c[m>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+132>>2]=j?468:454;c[a+152>>2]=146;c[a+160>>2]=348;c[a+156>>2]=364}else{if(j){c[m>>2]=356;c[a+124>>2]=50;c[a+128>>2]=196;c[a+136>>2]=318;c[a+140>>2]=248;c[a+144>>2]=116;c[a+148>>2]=494}else{c[m>>2]=386;c[a+124>>2]=326;c[a+128>>2]=360;c[a+136>>2]=286;c[a+140>>2]=42;c[a+144>>2]=450;c[a+148>>2]=110}c[a+132>>2]=j?468:454;c[a+152>>2]=146;c[a+160>>2]=348;c[a+156>>2]=364;if((b|0)==70){break}else if((b|0)==24){c[a+164>>2]=518;break c}else if((b|0)==141){l=50;break c}else{c[a+164>>2]=122;break c}}}while(0);c[a+164>>2]=268}}while(0);if((l|0)==50){c[a+164>>2]=448;c[a+180>>2]=482;c[a+184>>2]=440}c[a+168>>2]=184;c[a+172>>2]=336;c[a+176>>2]=368;c[a+188>>2]=2048;c[a+192>>2]=856;c[a+196>>2]=2342;c[a+200>>2]=2362;g=a+212|0;if(j){c[g>>2]=72;c[a+208>>2]=742}else{c[g>>2]=580;c[a+208>>2]=50}c[a+224>>2]=274;c[a+220>>2]=34;i=f;return}else if((d|0)==14){g=(b|0)==70;do{if(g){c[a>>2]=624;c[a+4>>2]=2350;c[a+8>>2]=1818;c[a+12>>2]=2094;c[a+16>>2]=1030;c[a+20>>2]=1862;c[a+24>>2]=574;c[a+28>>2]=1644;c[a+32>>2]=764;c[a+36>>2]=1570;c[a+40>>2]=1614;c[a+44>>2]=1754;c[a+48>>2]=10;c[a+52>>2]=1950;c[a+56>>2]=1360}else{j=(b|0)==141;h=a|0;if(j){c[h>>2]=1730;c[a+4>>2]=594}else{c[h>>2]=624;c[a+4>>2]=2350}c[a+8>>2]=1818;c[a+12>>2]=(b|0)==24?1710:412;c[a+16>>2]=1030;c[a+20>>2]=1862;c[a+24>>2]=574;c[a+28>>2]=j?498:670;c[a+32>>2]=298;h=a+36|0;if(j){c[h>>2]=322;c[a+48>>2]=1504;c[a+52>>2]=1114;c[a+40>>2]=624;c[a+56>>2]=2350;break}else{c[h>>2]=1570;c[a+40>>2]=1614;c[a+44>>2]=1754;break}}}while(0);c[a+60>>2]=652;c[a+64>>2]=196;c[a+68>>2]=74;c[a+72>>2]=268;c[a+76>>2]=366;c[a+80>>2]=52;c[a+84>>2]=542;c[a+88>>2]=92;c[a+92>>2]=260;c[a+96>>2]=554;c[a+100>>2]=356;c[a+104>>2]=218;h=(e|0)<2;j=a+108|0;k=a+116|0;if(h){c[k>>2]=416;c[a+112>>2]=188}else{c[k>>2]=514;c[a+112>>2]=30}k=a+120|0;d:do{if((b|0)==141){c[k>>2]=504;c[j>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+136>>2]=140;c[a+140>>2]=34;c[a+132>>2]=h?192:258;c[a+152>>2]=420;c[a+160>>2]=16;c[a+156>>2]=374;l=104}else{c[k>>2]=h?346:424;m=j|0;do{if(g){c[m>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+132>>2]=h?192:258;c[a+152>>2]=420;c[a+160>>2]=16;c[a+156>>2]=374}else{if(h){c[m>>2]=64;c[a+124>>2]=340;c[a+128>>2]=402;c[a+136>>2]=316;c[a+140>>2]=246;c[a+144>>2]=120;c[a+148>>2]=498}else{c[m>>2]=86;c[a+124>>2]=174;c[a+128>>2]=68;c[a+136>>2]=290;c[a+140>>2]=46;c[a+144>>2]=444;c[a+148>>2]=108}c[a+132>>2]=h?192:258;c[a+152>>2]=420;c[a+160>>2]=16;c[a+156>>2]=374;if((b|0)==141){l=104;break d}else if((b|0)==24){c[a+164>>2]=518;break d}else if((b|0)==70){break}else{c[a+164>>2]=398;break d}}}while(0);c[a+164>>2]=268}}while(0);if((l|0)==104){c[a+164>>2]=448;c[a+180>>2]=206;c[a+184>>2]=172}c[a+168>>2]=510;c[a+172>>2]=516;c[a+176>>2]=74;c[a+188>>2]=1170;c[a+192>>2]=2044;c[a+196>>2]=1146;c[a+200>>2]=1158;g=a+212|0;if(h){c[g>>2]=604;c[a+208>>2]=850}else{c[g>>2]=244;c[a+208>>2]=354}c[a+224>>2]=738;c[a+220>>2]=312;i=f;return}else{if((d|0)>=9){yDb(0,0,2279872,(d=i,i=i+24|0,c[d>>2]=2323976,c[d+8>>2]=2187456,c[d+16>>2]=585,d)|0);i=d;Cd()}d=(b|0)==70;do{if(d){c[a>>2]=66;c[a+4>>2]=2146;c[a+8>>2]=1446;c[a+12>>2]=2094;c[a+16>>2]=1330;c[a+20>>2]=394;c[a+24>>2]=1376;c[a+28>>2]=1644;c[a+32>>2]=764;c[a+36>>2]=1518;c[a+40>>2]=876;c[a+44>>2]=1100;c[a+48>>2]=10;c[a+52>>2]=1950;c[a+56>>2]=1360}else{g=(b|0)==141;h=a|0;if(g){c[h>>2]=1730;c[a+4>>2]=594}else{c[h>>2]=66;c[a+4>>2]=2146}c[a+8>>2]=1446;c[a+12>>2]=(b|0)==24?1710:792;c[a+16>>2]=1330;c[a+20>>2]=394;c[a+24>>2]=1376;c[a+28>>2]=g?498:2240;c[a+32>>2]=1540;h=a+36|0;if(g){c[h>>2]=322;c[a+48>>2]=1926;c[a+52>>2]=1096;c[a+40>>2]=66;c[a+56>>2]=2146;break}else{c[h>>2]=1518;c[a+40>>2]=876;c[a+44>>2]=1100;break}}}while(0);c[a+60>>2]=186;c[a+64>>2]=288;c[a+68>>2]=526;c[a+72>>2]=648;c[a+76>>2]=164;c[a+80>>2]=238;c[a+84>>2]=18;c[a+88>>2]=6;c[a+92>>2]=868;c[a+96>>2]=480;c[a+100>>2]=800;c[a+104>>2]=718;h=(e|0)<2;e=a+108|0;g=a+116|0;if(h){c[g>>2]=76;c[a+112>>2]=194}else{c[g>>2]=230;c[a+112>>2]=198}g=a+120|0;e:do{if((b|0)==141){c[g>>2]=504;c[e>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+136>>2]=2;c[a+140>>2]=370;c[a+132>>2]=h?372:228;c[a+152>>2]=178;c[a+160>>2]=272;c[a+156>>2]=276;l=133}else{c[g>>2]=h?234:526;j=e|0;do{if(d){c[j>>2]=80;c[a+124>>2]=392;c[a+128>>2]=486;c[a+132>>2]=h?372:228;c[a+152>>2]=178;c[a+160>>2]=272;c[a+156>>2]=276}else{if(h){c[j>>2]=312;c[a+124>>2]=144;c[a+128>>2]=314;c[a+136>>2]=104;c[a+140>>2]=164;c[a+144>>2]=24;c[a+148>>2]=380}else{c[j>>2]=338;c[a+124>>2]=452;c[a+128>>2]=488;c[a+136>>2]=56;c[a+140>>2]=18;c[a+144>>2]=332;c[a+148>>2]=12}c[a+132>>2]=h?372:228;c[a+152>>2]=178;c[a+160>>2]=272;c[a+156>>2]=276;if((b|0)==141){l=133;break e}else if((b|0)==70){break}else if((b|0)==24){c[a+164>>2]=518;break e}else{c[a+164>>2]=366;break e}}}while(0);c[a+164>>2]=268}}while(0);if((l|0)==133){c[a+164>>2]=448;c[a+180>>2]=158;c[a+184>>2]=492}c[a+168>>2]=344;c[a+172>>2]=160;c[a+176>>2]=202;c[a+188>>2]=2368;c[a+192>>2]=1820;c[a+196>>2]=366;c[a+200>>2]=630;l=a+212|0;if(h){c[l>>2]=58;c[a+208>>2]=376}else{c[l>>2]=538;c[a+208>>2]=856}c[a+224>>2]=172;c[a+220>>2]=342;i=f;return}}function dia(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d[a+(-e|0)|0]|0;g=d[a+(1-e)|0]|0;h=d[a+(2-e)|0]|0;i=d[a+(3-e)|0]|0;j=(f+2+(g<<1)+h|0)>>>2<<8|((d[a+~e|0]|0)+2+(f<<1)+g|0)>>>2|(g+2+(h<<1)+i|0)>>>2<<16|(h+2+(i<<1)+(d[b]|0)|0)>>>2<<24;c[a>>2]=j;c[a+e>>2]=j;c[a+(e<<1)>>2]=j;c[a+(e*3|0)>>2]=j;return}function eia(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;b=d[a-1|0]|0;f=d[a+(e-1)|0]|0;g=e<<1;h=d[a+(g-1)|0]|0;i=e*3|0;j=d[a+(i-1)|0]|0;c[a>>2]=ba(((d[a+~e|0]|0)+2+(b<<1)+f|0)>>>2,16843009)|0;c[a+e>>2]=ba((b+2+(f<<1)+h|0)>>>2,16843009)|0;c[a+g>>2]=ba((f+2+(h<<1)+j|0)>>>2,16843009)|0;c[a+i>>2]=ba((h+2+j+(j<<1)|0)>>>2,16843009)|0;return}function fia(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=a;e=d>>1;d=b+(-e<<1)|0;f=c[d>>2]|0;g=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+((e*3|0)<<1)|0;c[d>>2]=f;c[d+4>>2]=g;return}function gia(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0;b=a;f=d>>1;d=gHb(e[a-2>>1]|0,0,65537,65537)|0;g=a;c[g>>2]=d;c[g+4>>2]=F;g=gHb(e[b+(f-1<<1)>>1]|0,0,65537,65537)|0;d=b+(f<<1)|0;c[d>>2]=g;c[d+4>>2]=F;d=f<<1;g=gHb(e[b+(d-1<<1)>>1]|0,0,65537,65537)|0;a=b+(d<<1)|0;c[a>>2]=g;c[a+4>>2]=F;a=f*3|0;f=gHb(e[b+(a-1<<1)>>1]|0,0,65537,65537)|0;g=b+(a<<1)|0;c[g>>2]=f;c[g+4>>2]=F;return}function hia(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=(e[b+(-f<<1)>>1]|0)+4+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=b+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(d<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function iia(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;c=d[b+(2-e)|0]|0;f=d[b+(3-e)|0]|0;g=e<<1;h=d[b+(g-1)|0]|0;i=e*3|0;j=d[b+(i-1)|0]|0;a[b]=((d[b+(e-1)|0]|0)+(d[b+(1-e)|0]|0)|0)>>>1;k=(h+c|0)>>>1&255;a[b+e|0]=k;a[b+1|0]=k;k=(j+f|0)>>>1&255;a[b+(i+3)|0]=k;a[b+(i+2)|0]=k;a[b+(g+3)|0]=k;a[b+(i+1)|0]=k;a[b+(g+2)|0]=k;a[b+(e+3)|0]=k;a[b+i|0]=k;a[b+(g|1)|0]=k;a[b+(e+2)|0]=k;a[b+3|0]=k;a[b+g|0]=k;a[b+(e+1)|0]=k;a[b+2|0]=k;return}function jia(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=d>>1;d=e[f+(1-g<<1)>>1]|0;h=e[f+(2-g<<1)>>1]|0;i=e[f+(3-g<<1)>>1]|0;j=e[c>>1]|0;k=e[c+2>>1]|0;l=e[c+4>>1]|0;m=e[c+6>>1]|0;b[f>>1]=((e[f+(-g<<1)>>1]|0)+2+h+(d<<1)|0)>>>2;c=(d+2+i+(h<<1)|0)>>>2&65535;b[f+(g<<1)>>1]=c;b[a+2>>1]=c;c=(h+2+j+(i<<1)|0)>>>2&65535;h=g<<1;b[f+(h<<1)>>1]=c;b[f+(g+1<<1)>>1]=c;b[a+4>>1]=c;c=(i+2+k+(j<<1)|0)>>>2&65535;i=g*3|0;b[f+(i<<1)>>1]=c;b[f+((h|1)<<1)>>1]=c;b[f+(g+2<<1)>>1]=c;b[a+6>>1]=c;c=(j+2+l+(k<<1)|0)>>>2&65535;b[f+(i+1<<1)>>1]=c;b[f+(h+2<<1)>>1]=c;b[f+(g+3<<1)>>1]=c;c=(k+2+m+(l<<1)|0)>>>2&65535;b[f+(i+2<<1)>>1]=c;b[f+(h+3<<1)>>1]=c;b[f+(i+3<<1)>>1]=(l+2+(m*3|0)|0)>>>2;return}function kia(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;b[c+(o<<1)>>1]=(l+2+(n<<1)+(e[c+(o-1<<1)>>1]|0)|0)>>>2;p=(k+2+(l<<1)+n|0)>>>2&65535;b[c+(o+1<<1)>>1]=p;b[c+(m<<1)>>1]=p;p=d+2|0;n=(p+(k<<1)+l|0)>>>2&65535;b[c+(o+2<<1)>>1]=n;b[c+((m|1)<<1)>>1]=n;b[c+(f<<1)>>1]=n;n=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+3<<1)>>1]=n;b[c+(m+2<<1)>>1]=n;b[c+(f+1<<1)>>1]=n;b[c>>1]=n;n=(p+(g<<1)+h|0)>>>2&65535;b[c+(m+3<<1)>>1]=n;b[c+(f+2<<1)>>1]=n;b[a+2>>1]=n;n=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(f+3<<1)>>1]=n;b[a+4>>1]=n;b[a+6>>1]=(h+2+(i<<1)+j|0)>>>2;return}function lia(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;p=(d+1+g|0)>>>1&65535;b[c+((m|1)<<1)>>1]=p;b[c>>1]=p;p=(g+1+h|0)>>>1&65535;b[c+(m+2<<1)>>1]=p;b[a+2>>1]=p;p=(h+1+i|0)>>>1&65535;b[c+(m+3<<1)>>1]=p;b[a+4>>1]=p;b[a+6>>1]=(i+1+j|0)>>>1;a=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+1<<1)>>1]=a;b[c+(f<<1)>>1]=a;a=d+2|0;d=(a+(g<<1)+h|0)>>>2&65535;b[c+(o+2<<1)>>1]=d;b[c+(f+1<<1)>>1]=d;d=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(o+3<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;b[c+(f+3<<1)>>1]=(h+2+(i<<1)+j|0)>>>2;b[c+(m<<1)>>1]=(a+(k<<1)+l|0)>>>2;b[c+(o<<1)>>1]=(k+2+(l<<1)+n|0)>>>2;return}function mia(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[a-2>>1]|0;k=e[c+(f-1<<1)>>1]|0;l=f<<1;m=e[c+(l-1<<1)>>1]|0;n=f*3|0;o=e[c+(n-1<<1)>>1]|0;p=(d+1+j|0)>>>1&65535;b[c+(f+2<<1)>>1]=p;b[c>>1]=p;p=((d<<1)+2+g+j|0)>>>2&65535;b[c+(f+3<<1)>>1]=p;b[a+2>>1]=p;p=d+2|0;b[a+4>>1]=(p+(g<<1)+h|0)>>>2;b[a+6>>1]=(g+2+(h<<1)+i|0)>>>2;i=(j+1+k|0)>>>1&65535;b[c+(l+2<<1)>>1]=i;b[c+(f<<1)>>1]=i;i=(p+(j<<1)+k|0)>>>2&65535;b[c+(l+3<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;i=(k+1+m|0)>>>1&65535;b[c+(n+2<<1)>>1]=i;b[c+(l<<1)>>1]=i;i=(j+2+(k<<1)+m|0)>>>2&65535;b[c+(n+3<<1)>>1]=i;b[c+((l|1)<<1)>>1]=i;b[c+(n<<1)>>1]=(m+1+o|0)>>>1;b[c+(n+1<<1)>>1]=(k+2+(m<<1)+o|0)>>>2;return}function nia(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b+(3-e)|0]|0;j=d[c]|0;k=d[c+1|0]|0;l=d[c+2|0]|0;m=d[c+3|0]|0;a[b]=(f+1+g|0)>>>1;c=(g+1+h|0)>>>1&255;n=e<<1;a[b+n|0]=c;a[b+1|0]=c;c=(h+1+i|0)>>>1&255;a[b+(n|1)|0]=c;a[b+2|0]=c;c=(i+1+j|0)>>>1&255;a[b+(n+2)|0]=c;a[b+3|0]=c;a[b+e|0]=(f+2+(g<<1)+h|0)>>>2;f=(g+2+(h<<1)+i|0)>>>2&255;g=e*3|0;a[b+g|0]=f;a[b+(e+1)|0]=f;f=(h+2+(i<<1)+j|0)>>>2&255;a[b+(g+1)|0]=f;a[b+(e+2)|0]=f;f=(i+2+(j<<1)+k|0)>>>2&255;a[b+(g+2)|0]=f;a[b+(e+3)|0]=f;a[b+(n+3)|0]=(j+2+(k<<1)+l|0)>>>2;a[b+(g+3)|0]=(k+2+(l<<1)+m|0)>>>2;return}function oia(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a;g=d>>1;d=e[f+(-g<<1)>>1]|0;h=e[f+(1-g<<1)>>1]|0;i=e[f+(2-g<<1)>>1]|0;j=e[f+(3-g<<1)>>1]|0;k=e[c>>1]|0;l=e[c+2>>1]|0;m=e[c+4>>1]|0;b[f>>1]=(d+1+h|0)>>>1;c=(h+1+i|0)>>>1&65535;n=g<<1;b[f+(n<<1)>>1]=c;b[a+2>>1]=c;c=(i+1+j|0)>>>1&65535;b[f+((n|1)<<1)>>1]=c;b[a+4>>1]=c;c=(j+1+k|0)>>>1&65535;b[f+(n+2<<1)>>1]=c;b[a+6>>1]=c;b[f+(n+3<<1)>>1]=(k+1+l|0)>>>1;b[f+(g<<1)>>1]=(d+2+(h<<1)+i|0)>>>2;d=(h+2+(i<<1)+j|0)>>>2&65535;h=g*3|0;b[f+(h<<1)>>1]=d;b[f+(g+1<<1)>>1]=d;d=(i+2+(j<<1)+k|0)>>>2&65535;b[f+(h+1<<1)>>1]=d;b[f+(g+2<<1)>>1]=d;d=(j+2+(k<<1)+l|0)>>>2&65535;b[f+(h+2<<1)>>1]=d;b[f+(g+3<<1)>>1]=d;b[f+(h+3<<1)>>1]=(k+2+(l<<1)+m|0)>>>2;return}function pia(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=a;f=d>>1;d=e[a-2>>1]|0;g=e[c+(f-1<<1)>>1]|0;h=f<<1;i=e[c+(h-1<<1)>>1]|0;j=f*3|0;k=b[c+(j-1<<1)>>1]|0;l=k&65535;b[c>>1]=(d+1+g|0)>>>1;b[a+2>>1]=(d+2+(g<<1)+i|0)>>>2;d=(g+1+i|0)>>>1&65535;b[c+(f<<1)>>1]=d;b[a+4>>1]=d;d=(g+2+(i<<1)+l|0)>>>2&65535;b[c+(f+1<<1)>>1]=d;b[a+6>>1]=d;d=(i+1+l|0)>>>1&65535;b[c+(h<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;d=(i+2+l+(l<<1)|0)>>>2&65535;b[c+((h|1)<<1)>>1]=d;b[c+(f+3<<1)>>1]=d;b[c+(j+3<<1)>>1]=k;b[c+(j+2<<1)>>1]=k;b[c+(h+2<<1)>>1]=k;b[c+(j<<1)>>1]=k;b[c+(j+1<<1)>>1]=k;b[c+(h+3<<1)>>1]=k;return}function qia(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=gHb(((e[a-2>>1]|0)+2+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;i=F;j=a;c[j>>2]=h;c[j+4>>2]=i;j=b+(f<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(d<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(g<<1)|0;c[j>>2]=h;c[j+4>>2]=i;return}function ria(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0;b=a;f=d>>1;d=gHb(((e[b+(-f<<1)>>1]|0)+2+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+((f*3|0)<<1)|0;c[h>>2]=d;c[h+4>>2]=g;return}function sia(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=16777472;c[d+4>>2]=16777472;d=b+(e<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=b+(e<<1<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=b+((e*3|0)<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;return}function tia(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;c=1024-(d[b+~e|0]|0)|0;f=b+(-e|0)|0;g=b+(1-e)|0;h=b+(2-e)|0;i=b+(3-e)|0;j=(d[b-1|0]|0)+c|0;a[b]=a[1235032+(j+(d[f]|0))|0]|0;a[b+1|0]=a[1235032+((d[g]|0)+j)|0]|0;a[b+2|0]=a[1235032+((d[h]|0)+j)|0]|0;a[b+3|0]=a[1235032+((d[i]|0)+j)|0]|0;j=(d[b+(e-1)|0]|0)+c|0;a[b+e|0]=a[1235032+(j+(d[f]|0))|0]|0;a[b+(e+1)|0]=a[1235032+((d[g]|0)+j)|0]|0;a[b+(e+2)|0]=a[1235032+((d[h]|0)+j)|0]|0;a[b+(e+3)|0]=a[1235032+((d[i]|0)+j)|0]|0;j=e<<1;k=(d[b+(j-1)|0]|0)+c|0;a[b+j|0]=a[1235032+(k+(d[f]|0))|0]|0;a[b+(j|1)|0]=a[1235032+((d[g]|0)+k)|0]|0;a[b+(j+2)|0]=a[1235032+((d[h]|0)+k)|0]|0;a[b+(j+3)|0]=a[1235032+((d[i]|0)+k)|0]|0;k=j+e|0;e=(d[b+(k-1)|0]|0)+c|0;a[b+k|0]=a[1235032+(e+(d[f]|0))|0]|0;a[b+(k+1)|0]=a[1235032+((d[g]|0)+e)|0]|0;a[b+(k+2)|0]=a[1235032+((d[h]|0)+e)|0]|0;a[b+(k+3)|0]=a[1235032+((d[i]|0)+e)|0]|0;return}function uia(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=16711935;c[d+4>>2]=16711935;d=b+(e<<1)|0;c[d>>2]=16711935;c[d+4>>2]=16711935;d=b+(e<<1<<1)|0;c[d>>2]=16711935;c[d+4>>2]=16711935;d=b+((e*3|0)<<1)|0;c[d>>2]=16711935;c[d+4>>2]=16711935;return}function via(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=16843009;c[d+4>>2]=16843009;d=b+(e<<1)|0;c[d>>2]=16843009;c[d+4>>2]=16843009;d=b+(e<<1<<1)|0;c[d>>2]=16843009;c[d+4>>2]=16843009;d=b+((e*3|0)<<1)|0;c[d>>2]=16843009;c[d+4>>2]=16843009;return}function wia(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d[b+(1-e)|0]|0;g=d[b+(2-e)|0]|0;h=d[b+(3-e)|0]|0;i=d[c]|0;j=d[c+1|0]|0;k=d[c+2|0]|0;l=d[c+3|0]|0;c=d[b+(e-1)|0]|0;m=e<<1;n=d[b+(m-1)|0]|0;o=e*3|0;p=d[b+(o-1)|0]|0;q=d[b+((e<<2)-1)|0]|0;r=d[b+((e*5|0)-1)|0]|0;s=d[b+((e*6|0)-1)|0]|0;t=d[b+((e*7|0)-1)|0]|0;a[b]=((d[b+(-e|0)|0]|0)+4+g+(d[b-1|0]|0)+n+(c+f<<1)|0)>>>3;u=(f+4+h+c+p+(n+g<<1)|0)>>>3&255;a[b+e|0]=u;a[b+1|0]=u;u=(g+4+i+n+q+(p+h<<1)|0)>>>3&255;a[b+m|0]=u;a[b+(e+1)|0]=u;a[b+2|0]=u;u=(h+4+j+p+r+(q+i<<1)|0)>>>3&255;a[b+o|0]=u;a[b+(m|1)|0]=u;a[b+(e+2)|0]=u;a[b+3|0]=u;u=(i+4+k+q+s+(r+j<<1)|0)>>>3&255;a[b+(o+1)|0]=u;a[b+(m+2)|0]=u;a[b+(e+3)|0]=u;u=(j+4+l+r+t+(s+k<<1)|0)>>>3&255;a[b+(o+2)|0]=u;a[b+(m+3)|0]=u;a[b+(o+3)|0]=(k+2+l+s+t|0)>>>2;return}function xia(b,c,e){b=b|0;c=c|0;e=e|0;Roa(b,a[c]|0,a[c+1|0]|0,a[c+2|0]|0,e,d[b+(e-1)|0]|0,d[b+((e<<1)-1)|0]|0,d[b+((e*3|0)-1)|0]|0,d[b+((e<<2)-1)|0]|0);return}function yia(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d[b-1|0]|0;g=d[b+(e-1)|0]|0;h=e<<1;i=d[b+(h-1)|0]|0;j=e*3|0;k=d[b+(j-1)|0]|0;l=d[b+((e<<2)-1)|0]|0;m=d[b+((e*5|0)-1)|0]|0;n=d[b+((e*6|0)-1)|0]|0;o=d[b+(2-e)|0]|0;p=d[b+(3-e)|0]|0;q=d[c]|0;r=d[c+1|0]|0;s=d[c+2|0]|0;t=d[c+3|0]|0;c=g<<1;u=c+4|0;a[b]=(u+(d[b+(1-e)|0]|0)+p+(o+f<<1)|0)>>>3;a[b+1|0]=(f+4+c+i+o+(p<<1)+q|0)>>>3;o=i<<1;c=(u+o+p+(q<<1)+r|0)>>>3&255;a[b+e|0]=c;a[b+2|0]=c;c=(g+4+o+k+q+(r<<1)+s|0)>>>3&255;a[b+(e+1)|0]=c;a[b+3|0]=c;c=(o+4+r+t+(s+k<<1)|0)>>>3&255;a[b+h|0]=c;a[b+(e+2)|0]=c;c=(i+4+s+((t+k|0)*3|0)|0)>>>3&255;a[b+(h|1)|0]=c;a[b+(e+3)|0]=c;c=k+2|0;k=(c+(l<<1)+m|0)>>>2&255;a[b+(j+1)|0]=k;a[b+(h+3)|0]=k;k=(c+l+s+t|0)>>>2&255;a[b+(h+2)|0]=k;a[b+j|0]=k;a[b+(j+2)|0]=(l+1+m|0)>>>1;a[b+(j+3)|0]=(l+2+(m<<1)+n|0)>>>2;return}function zia(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d[b+(1-e)|0]|0;g=d[b+(2-e)|0]|0;h=d[b+(3-e)|0]|0;i=d[c]|0;j=d[c+1|0]|0;k=d[c+2|0]|0;l=d[c+3|0]|0;c=d[b+(e-1)|0]|0;m=e<<1;n=d[b+(m-1)|0]|0;o=e*3|0;p=d[b+(o-1)|0]|0;a[b]=((d[b+(-e|0)|0]|0)+4+g+(d[b-1|0]|0)+n+(c+f<<1)|0)>>>3;q=(f+4+h+c+p+(n+g<<1)|0)>>>3&255;a[b+e|0]=q;a[b+1|0]=q;q=(g+4+i+(h<<1)+n+(p*3|0)|0)>>>3&255;a[b+m|0]=q;a[b+(e+1)|0]=q;a[b+2|0]=q;q=p<<2;n=(h+4+j+(i<<1)+q|0)>>>3&255;a[b+o|0]=n;a[b+(m|1)|0]=n;a[b+(e+2)|0]=n;a[b+3|0]=n;n=(i+4+k+(j<<1)+q|0)>>>3&255;a[b+(o+1)|0]=n;a[b+(m+2)|0]=n;a[b+(e+3)|0]=n;n=(j+4+l+(k<<1)+q|0)>>>3&255;a[b+(o+2)|0]=n;a[b+(m+3)|0]=n;a[b+(o+3)|0]=(k+2+l+(p<<1)|0)>>>2;return}function Aia(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d[b-1|0]|0;g=d[b+(e-1)|0]|0;h=e<<1;i=d[b+(h-1)|0]|0;j=e*3|0;k=a[b+(j-1)|0]|0;l=k&255;m=d[b+(2-e)|0]|0;n=d[b+(3-e)|0]|0;o=d[c]|0;p=d[c+1|0]|0;q=d[c+2|0]|0;r=d[c+3|0]|0;c=g<<1;s=c+4|0;a[b]=(s+(d[b+(1-e)|0]|0)+n+(m+f<<1)|0)>>>3;a[b+1|0]=(f+4+c+i+m+(n<<1)+o|0)>>>3;m=i<<1;c=(s+m+n+(o<<1)+p|0)>>>3&255;a[b+e|0]=c;a[b+2|0]=c;c=(g+4+m+l+o+(p<<1)+q|0)>>>3&255;a[b+(e+1)|0]=c;a[b+3|0]=c;c=l<<1;o=(m+4+c+p+(q<<1)+r|0)>>>3&255;a[b+h|0]=o;a[b+(e+2)|0]=o;o=(i+4+q+((r+l|0)*3|0)|0)>>>3&255;a[b+(h|1)|0]=o;a[b+(e+3)|0]=o;a[b+(j+1)|0]=k;a[b+(h+3)|0]=k;o=(c+2+q+r|0)>>>2&255;a[b+(h+2)|0]=o;a[b+j|0]=o;a[b+(j+3)|0]=k;a[b+(j+2)|0]=k;return}function Bia(b,c,e){b=b|0;c=c|0;e=e|0;var f=0;f=d[b+((e*3|0)-1)|0]|0;Roa(b,a[c]|0,a[c+1|0]|0,a[c+2|0]|0,e,d[b+(e-1)|0]|0,d[b+((e<<1)-1)|0]|0,f,f);return}function Cia(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}b[h>>1]=((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;b[a+2>>1]=(j+2+(k<<1)+l|0)>>>2;b[a+4>>1]=(k+2+(l<<1)+m|0)>>>2;b[a+6>>1]=(l+2+(m<<1)+n|0)>>>2;l=a+8|0;b[l>>1]=(m+2+(n<<1)+o|0)>>>2;b[a+10>>1]=(n+2+(o<<1)+p|0)>>>2;b[a+12>>1]=(o+2+(p<<1)+r|0)>>>2;b[a+14>>1]=((s&65535)+2+(r<<1)+p|0)>>>2;p=a;a=c[p>>2]|0;r=c[p+4>>2]|0;p=l;l=c[p>>2]|0;s=c[p+4>>2]|0;p=h+(i<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(i+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<1;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*3|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<2;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*5|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i*6|0;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*7|0;i=h+(o<<1)|0;c[i>>2]=a;c[i+4>>2]=r;r=h+(o+4<<1)|0;c[r>>2]=l;c[r+4>>2]=s;return}function Dia(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=g<<1;j=e[d+(f-1<<1)>>1]|0;k=g*3|0;l=e[d+(k-1<<1)>>1]|0;m=g<<2;n=e[d+(m-1<<1)>>1]|0;o=g*5|0;p=e[d+(o-1<<1)>>1]|0;q=g*6|0;r=e[d+(q-1<<1)>>1]|0;s=g*7|0;t=e[d+(s-1<<1)>>1]|0;u=gHb(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2,0,65537,65537)|0;h=F;v=a;c[v>>2]=u;c[v+4>>2]=h;v=a+8|0;c[v>>2]=u;c[v+4>>2]=h;h=gHb((b+2+(i<<1)+j|0)>>>2,0,65537,65537)|0;b=F;v=d+(g<<1)|0;c[v>>2]=h;c[v+4>>2]=b;v=d+(g+4<<1)|0;c[v>>2]=h;c[v+4>>2]=b;b=gHb((i+2+(j<<1)+l|0)>>>2,0,65537,65537)|0;i=F;v=d+(f<<1)|0;c[v>>2]=b;c[v+4>>2]=i;v=d+(f+4<<1)|0;c[v>>2]=b;c[v+4>>2]=i;i=gHb((j+2+(l<<1)+n|0)>>>2,0,65537,65537)|0;j=F;v=d+(k<<1)|0;c[v>>2]=i;c[v+4>>2]=j;v=d+(k+4<<1)|0;c[v>>2]=i;c[v+4>>2]=j;j=gHb((l+2+(n<<1)+p|0)>>>2,0,65537,65537)|0;l=F;v=d+(m<<1)|0;c[v>>2]=j;c[v+4>>2]=l;v=d+(m+4<<1)|0;c[v>>2]=j;c[v+4>>2]=l;l=gHb((n+2+(p<<1)+r|0)>>>2,0,65537,65537)|0;n=F;v=d+(o<<1)|0;c[v>>2]=l;c[v+4>>2]=n;v=d+(o+4<<1)|0;c[v>>2]=l;c[v+4>>2]=n;n=gHb((p+2+(r<<1)+t|0)>>>2,0,65537,65537)|0;p=F;v=d+(q<<1)|0;c[v>>2]=n;c[v+4>>2]=p;v=d+(q+4<<1)|0;c[v>>2]=n;c[v+4>>2]=p;p=gHb((r+2+(t*3|0)|0)>>>2,0,65537,65537)|0;t=F;r=d+(s<<1)|0;c[r>>2]=p;c[r+4>>2]=t;r=d+(s+4<<1)|0;c[r>>2]=p;c[r+4>>2]=t;return}function Eia(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=a;i=g>>1;g=(d|0)!=0;if(g){d=~i;j=h+(d<<1)|0;k=a-2|0;l=d}else{d=a-2|0;j=d;k=d;l=~i}d=e[k>>1]|0;k=e[h+(i-1<<1)>>1]|0;m=e[h+((i<<1)-1<<1)>>1]|0;n=e[h+((i*3|0)-1<<1)>>1]|0;o=e[h+((i<<2)-1<<1)>>1]|0;p=e[h+((i*5|0)-1<<1)>>1]|0;q=e[h+((i*6|0)-1<<1)>>1]|0;r=e[h+((i*7|0)-1<<1)>>1]|0;s=-i|0;t=e[h+(s<<1)>>1]|0;u=e[h+(1-i<<1)>>1]|0;v=e[h+(2-i<<1)>>1]|0;w=e[h+(3-i<<1)>>1]|0;x=e[h+(4-i<<1)>>1]|0;y=e[h+(5-i<<1)>>1]|0;z=e[h+(6-i<<1)>>1]|0;A=b[h+(7-i<<1)>>1]|0;B=A&65535;if((f|0)==0){C=A}else{C=b[h+(8-i<<1)>>1]|0}A=(((e[j>>1]|0)+2+(d<<1)+k|0)>>>2)+8+((d+2+(k<<1)+m|0)>>>2)+((k+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q<<1)+r|0)>>>2)+((q+2+(r*3|0)|0)>>>2)+(((e[h+((g?l:s)<<1)>>1]|0)+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+z|0)>>>2)+((y+2+(z<<1)+B|0)>>>2)+(((C&65535)+2+(B<<1)+z|0)>>>2)>>4;z=gHb(A,(A|0)<0|0?-1:0,65537,65537)|0;A=F;B=a;c[B>>2]=z;c[B+4>>2]=A;B=a+8|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=i<<1;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;i=h+(a<<1)|0;c[i>>2]=z;c[i+4>>2]=A;i=h+(a+4<<1)|0;c[i>>2]=z;c[i+4>>2]=A;return}function Fia(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=e[g+(2-h<<1)>>1]|0;l=(i+2+(j<<1)+k|0)>>>2;m=e[g+(3-h<<1)>>1]|0;n=(j+2+(k<<1)+m|0)>>>2;o=e[g+(4-h<<1)>>1]|0;p=(k+2+(m<<1)+o|0)>>>2;k=e[g+(5-h<<1)>>1]|0;q=(m+2+(o<<1)+k|0)>>>2;m=e[g+(6-h<<1)>>1]|0;r=(o+2+(k<<1)+m|0)>>>2;o=b[g+(7-h<<1)>>1]|0;s=o&65535;t=(k+2+(m<<1)+s|0)>>>2;if((d|0)==0){u=s;v=s;w=s;x=s;y=s;z=s;A=s;B=s;C=(o&65535)+2+(s<<1)|0}else{o=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;k=e[g+(10-h<<1)>>1]|0;D=e[g+(11-h<<1)>>1]|0;E=e[g+(12-h<<1)>>1]|0;F=e[g+(13-h<<1)>>1]|0;G=e[g+(14-h<<1)>>1]|0;H=e[g+(15-h<<1)>>1]|0;u=(G+2+(H*3|0)|0)>>>2;v=(F+2+(G<<1)+H|0)>>>2;w=(E+2+(F<<1)+G|0)>>>2;x=(D+2+(E<<1)+F|0)>>>2;y=(k+2+(D<<1)+E|0)>>>2;z=(d+2+(k<<1)+D|0)>>>2;A=(o+2+(d<<1)+k|0)>>>2;B=(s+2+(o<<1)+d|0)>>>2;C=(e[g+(8-h<<1)>>1]|0)+2+(s<<1)|0}s=(C+m|0)>>>2;b[g>>1]=((((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2)+2+(l<<1)+n|0)>>>2;j=(l+2+(n<<1)+p|0)>>>2&65535;b[a+2>>1]=j;b[g+(h<<1)>>1]=j;j=(n+2+(p<<1)+q|0)>>>2&65535;b[a+4>>1]=j;b[g+(h+1<<1)>>1]=j;n=h<<1;b[g+(n<<1)>>1]=j;j=(p+2+(q<<1)+r|0)>>>2&65535;b[a+6>>1]=j;b[g+(h+2<<1)>>1]=j;b[g+((n|1)<<1)>>1]=j;p=h*3|0;b[g+(p<<1)>>1]=j;j=(q+2+(r<<1)+t|0)>>>2&65535;b[a+8>>1]=j;b[g+(h+3<<1)>>1]=j;b[g+(n+2<<1)>>1]=j;b[g+(p+1<<1)>>1]=j;q=h<<2;b[g+(q<<1)>>1]=j;j=(r+2+(t<<1)+s|0)>>>2&65535;b[a+10>>1]=j;b[g+(h+4<<1)>>1]=j;b[g+(n+3<<1)>>1]=j;b[g+(p+2<<1)>>1]=j;b[g+((q|1)<<1)>>1]=j;r=h*5|0;b[g+(r<<1)>>1]=j;j=(t+2+(s<<1)+B|0)>>>2&65535;b[a+12>>1]=j;b[g+(h+5<<1)>>1]=j;b[g+(n+4<<1)>>1]=j;b[g+(p+3<<1)>>1]=j;b[g+((q|2)<<1)>>1]=j;b[g+(r+1<<1)>>1]=j;t=h*6|0;b[g+(t<<1)>>1]=j;j=(s+2+(B<<1)+A|0)>>>2&65535;b[a+14>>1]=j;b[g+(h+6<<1)>>1]=j;b[g+(n+5<<1)>>1]=j;b[g+(p+4<<1)>>1]=j;b[g+((q|3)<<1)>>1]=j;b[g+(r+2<<1)>>1]=j;b[g+((t|1)<<1)>>1]=j;a=h*7|0;b[g+(a<<1)>>1]=j;j=(B+2+(A<<1)+z|0)>>>2&65535;b[g+(h+7<<1)>>1]=j;b[g+(n+6<<1)>>1]=j;b[g+(p+5<<1)>>1]=j;b[g+(q+4<<1)>>1]=j;b[g+(r+3<<1)>>1]=j;b[g+(t+2<<1)>>1]=j;b[g+(a+1<<1)>>1]=j;j=(A+2+(z<<1)+y|0)>>>2&65535;b[g+(n+7<<1)>>1]=j;b[g+(p+6<<1)>>1]=j;b[g+(q+5<<1)>>1]=j;b[g+(r+4<<1)>>1]=j;b[g+(t+3<<1)>>1]=j;b[g+(a+2<<1)>>1]=j;j=(z+2+(y<<1)+x|0)>>>2&65535;b[g+(p+7<<1)>>1]=j;b[g+(q+6<<1)>>1]=j;b[g+(r+5<<1)>>1]=j;b[g+(t+4<<1)>>1]=j;b[g+(a+3<<1)>>1]=j;j=(y+2+(x<<1)+w|0)>>>2&65535;b[g+(q+7<<1)>>1]=j;b[g+(r+6<<1)>>1]=j;b[g+(t+5<<1)>>1]=j;b[g+(a+4<<1)>>1]=j;j=(x+2+(w<<1)+v|0)>>>2&65535;b[g+(r+7<<1)>>1]=j;b[g+(t+6<<1)>>1]=j;b[g+(a+5<<1)>>1]=j;j=(w+2+(v<<1)+u|0)>>>2&65535;b[g+(t+7<<1)>>1]=j;b[g+(a+6<<1)>>1]=j;b[g+(a+7<<1)>>1]=(v+2+(u*3|0)|0)>>>2;return}function Gia(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;k=e[g+(v-1<<1)>>1]|0;d=i+2|0;i=(d+(w<<1)+k|0)>>>2;c=h*3|0;y=e[g+(c-1<<1)>>1]|0;z=(w+2+(k<<1)+y|0)>>>2;w=h<<2;A=e[g+(w-1<<1)>>1]|0;B=(k+2+(y<<1)+A|0)>>>2;k=h*5|0;C=e[g+(k-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*6|0;E=e[g+(y-1<<1)>>1]|0;F=(A+2+(C<<1)+E|0)>>>2;A=h*7|0;G=e[g+(A-1<<1)>>1]|0;H=(C+2+(E<<1)+G|0)>>>2;C=(d+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(A<<1)>>1]=(F+2+((E+2+(G*3|0)|0)>>>2)+(H<<1)|0)>>>2;G=(D+2+(F<<1)+H|0)>>>2&65535;b[g+(A+1<<1)>>1]=G;b[g+(y<<1)>>1]=G;G=(B+2+(D<<1)+F|0)>>>2&65535;b[g+(A+2<<1)>>1]=G;b[g+((y|1)<<1)>>1]=G;b[g+(k<<1)>>1]=G;G=(z+2+(B<<1)+D|0)>>>2&65535;b[g+(A+3<<1)>>1]=G;b[g+(y+2<<1)>>1]=G;b[g+(k+1<<1)>>1]=G;b[g+(w<<1)>>1]=G;G=(i+2+(z<<1)+B|0)>>>2&65535;b[g+(A+4<<1)>>1]=G;b[g+(y+3<<1)>>1]=G;b[g+(k+2<<1)>>1]=G;b[g+((w|1)<<1)>>1]=G;b[g+(c<<1)>>1]=G;G=(f+2+(i<<1)+z|0)>>>2&65535;b[g+(A+5<<1)>>1]=G;b[g+(y+4<<1)>>1]=G;b[g+(k+3<<1)>>1]=G;b[g+((w|2)<<1)>>1]=G;b[g+(c+1<<1)>>1]=G;b[g+(v<<1)>>1]=G;G=((f<<1)+2+i+C|0)>>>2&65535;b[g+(A+6<<1)>>1]=G;b[g+(y+5<<1)>>1]=G;b[g+(k+4<<1)>>1]=G;b[g+((w|3)<<1)>>1]=G;b[g+(c+2<<1)>>1]=G;b[g+((v|1)<<1)>>1]=G;b[g+(h<<1)>>1]=G;G=l+2|0;i=(G+f+(C<<1)|0)>>>2&65535;b[g+(A+7<<1)>>1]=i;b[g+(y+6<<1)>>1]=i;b[g+(k+5<<1)>>1]=i;b[g+(w+4<<1)>>1]=i;b[g+(c+3<<1)>>1]=i;b[g+(v+2<<1)>>1]=i;b[g+(h+1<<1)>>1]=i;b[g>>1]=i;i=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+7<<1)>>1]=i;b[g+(k+6<<1)>>1]=i;b[g+(w+5<<1)>>1]=i;b[g+(c+4<<1)>>1]=i;b[g+(v+3<<1)>>1]=i;b[g+(h+2<<1)>>1]=i;b[a+2>>1]=i;i=(G+(m<<1)+o|0)>>>2&65535;b[g+(k+7<<1)>>1]=i;b[g+(w+6<<1)>>1]=i;b[g+(c+5<<1)>>1]=i;b[g+(v+4<<1)>>1]=i;b[g+(h+3<<1)>>1]=i;b[a+4>>1]=i;i=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(w+7<<1)>>1]=i;b[g+(c+6<<1)>>1]=i;b[g+(v+5<<1)>>1]=i;b[g+(h+4<<1)>>1]=i;b[a+6>>1]=i;i=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(c+7<<1)>>1]=i;b[g+(v+6<<1)>>1]=i;b[g+(h+5<<1)>>1]=i;b[a+8>>1]=i;i=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(v+7<<1)>>1]=i;b[g+(h+6<<1)>>1]=i;b[a+10>>1]=i;i=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(h+7<<1)>>1]=i;b[a+12>>1]=i;b[a+14>>1]=(r+2+(t<<1)+(((u&65535)+2+(s<<1)+n|0)>>>2)|0)>>>2;return}function Hia(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}k=((u&65535)+2+(s<<1)+n|0)>>>2;if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;n=e[g+(v-1<<1)>>1]|0;s=i+2|0;i=(s+(w<<1)+n|0)>>>2;u=h*3|0;d=e[g+(u-1<<1)>>1]|0;c=(w+2+(n<<1)+d|0)>>>2;w=h<<2;y=e[g+(w-1<<1)>>1]|0;z=(n+2+(d<<1)+y|0)>>>2;n=h*5|0;A=e[g+(n-1<<1)>>1]|0;B=(d+2+(y<<1)+A|0)>>>2;d=h*6|0;C=e[g+(d-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*7|0;E=(A+2+(C<<1)+(e[g+(y-1<<1)>>1]|0)|0)>>>2;C=(s+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(d<<1)>>1]=(z+2+(B<<1)+D|0)>>>2;b[g+(y<<1)>>1]=(B+2+(D<<1)+E|0)>>>2;E=(i+2+(c<<1)+z|0)>>>2&65535;b[g+((d|1)<<1)>>1]=E;b[g+(w<<1)>>1]=E;E=(c+2+(z<<1)+B|0)>>>2&65535;b[g+(y+1<<1)>>1]=E;b[g+(n<<1)>>1]=E;E=((f<<1)+2+i+C|0)>>>2&65535;b[g+(d+2<<1)>>1]=E;b[g+((w|1)<<1)>>1]=E;b[g+(v<<1)>>1]=E;E=(f+2+(i<<1)+c|0)>>>2&65535;b[g+(y+2<<1)>>1]=E;b[g+(n+1<<1)>>1]=E;b[g+(u<<1)>>1]=E;E=l+2|0;c=(E+f+(C<<1)|0)>>>2&65535;b[g+(y+3<<1)>>1]=c;b[g+(n+2<<1)>>1]=c;b[g+(u+1<<1)>>1]=c;b[g+(h<<1)>>1]=c;c=l+1|0;f=(c+C|0)>>>1&65535;b[g+(d+3<<1)>>1]=f;b[g+((w|2)<<1)>>1]=f;b[g+((v|1)<<1)>>1]=f;b[g>>1]=f;f=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+4<<1)>>1]=f;b[g+(n+3<<1)>>1]=f;b[g+(u+2<<1)>>1]=f;b[g+(h+1<<1)>>1]=f;f=(c+m|0)>>>1&65535;b[g+(d+4<<1)>>1]=f;b[g+((w|3)<<1)>>1]=f;b[g+(v+2<<1)>>1]=f;b[a+2>>1]=f;f=(E+(m<<1)+o|0)>>>2&65535;b[g+(y+5<<1)>>1]=f;b[g+(n+4<<1)>>1]=f;b[g+(u+3<<1)>>1]=f;b[g+(h+2<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[g+(d+5<<1)>>1]=f;b[g+(w+4<<1)>>1]=f;b[g+(v+3<<1)>>1]=f;b[a+4>>1]=f;f=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(y+6<<1)>>1]=f;b[g+(n+5<<1)>>1]=f;b[g+(u+4<<1)>>1]=f;b[g+(h+3<<1)>>1]=f;f=(o+1+p|0)>>>1&65535;b[g+(d+6<<1)>>1]=f;b[g+(w+5<<1)>>1]=f;b[g+(v+4<<1)>>1]=f;b[a+6>>1]=f;f=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(y+7<<1)>>1]=f;b[g+(n+6<<1)>>1]=f;b[g+(u+5<<1)>>1]=f;b[g+(h+4<<1)>>1]=f;f=(p+1+q|0)>>>1&65535;b[g+(d+7<<1)>>1]=f;b[g+(w+6<<1)>>1]=f;b[g+(v+5<<1)>>1]=f;b[a+8>>1]=f;f=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(n+7<<1)>>1]=f;b[g+(u+6<<1)>>1]=f;b[g+(h+5<<1)>>1]=f;f=(q+1+r|0)>>>1&65535;b[g+(w+7<<1)>>1]=f;b[g+(v+6<<1)>>1]=f;b[a+10>>1]=f;f=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(u+7<<1)>>1]=f;b[g+(h+6<<1)>>1]=f;f=(r+1+t|0)>>>1&65535;b[g+(v+7<<1)>>1]=f;b[a+12>>1]=f;b[g+(h+7<<1)>>1]=(r+2+(t<<1)+k|0)>>>2;b[a+14>>1]=(t+1+k|0)>>>1;return}function Iia(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=a;g=f>>1;f=(c|0)!=0;c=-g|0;h=~g;i=e[d+(c<<1)>>1]|0;j=e[d+(1-g<<1)>>1]|0;k=((e[d+((f?h:c)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;c=e[d+(2-g<<1)>>1]|0;l=(i+2+(j<<1)+c|0)>>>2;m=e[d+(3-g<<1)>>1]|0;n=(j+2+(c<<1)+m|0)>>>2;j=e[d+(4-g<<1)>>1]|0;o=(c+2+(m<<1)+j|0)>>>2;c=e[d+(5-g<<1)>>1]|0;p=(m+2+(j<<1)+c|0)>>>2;m=e[d+(6-g<<1)>>1]|0;q=(j+2+(c<<1)+m|0)>>>2;j=(c+2+(m<<1)+(e[d+(7-g<<1)>>1]|0)|0)>>>2;if(f){f=d+(h<<1)|0;r=f;s=a-2|0;t=f}else{f=a-2|0;r=f;s=f;t=d+(h<<1)|0}h=e[s>>1]|0;s=e[d+(g-1<<1)>>1]|0;f=((e[r>>1]|0)+2+(h<<1)+s|0)>>>2;r=g<<1;m=e[d+(r-1<<1)>>1]|0;c=h+2|0;h=(c+(s<<1)+m|0)>>>2;u=g*3|0;v=e[d+(u-1<<1)>>1]|0;w=(s+2+(m<<1)+v|0)>>>2;s=g<<2;x=e[d+(s-1<<1)>>1]|0;y=(m+2+(v<<1)+x|0)>>>2;m=g*5|0;z=e[d+(m-1<<1)>>1]|0;A=(v+2+(x<<1)+z|0)>>>2;v=g*6|0;B=e[d+(v-1<<1)>>1]|0;C=(x+2+(z<<1)+B|0)>>>2;x=g*7|0;D=e[d+(x-1<<1)>>1]|0;E=(z+2+(B<<1)+D|0)>>>2;z=(B+2+(D*3|0)|0)>>>2;D=(c+((e[t>>1]|0)<<1)+i|0)>>>2;b[d+(x<<1)>>1]=(z+1+E|0)>>>1;b[d+(x+1<<1)>>1]=(C+2+z+(E<<1)|0)>>>2;z=(C+1+E|0)>>>1&65535;b[d+(x+2<<1)>>1]=z;b[d+(v<<1)>>1]=z;z=(A+2+(C<<1)+E|0)>>>2&65535;b[d+(x+3<<1)>>1]=z;b[d+((v|1)<<1)>>1]=z;z=(A+1+C|0)>>>1&65535;b[d+(x+4<<1)>>1]=z;b[d+(v+2<<1)>>1]=z;b[d+(m<<1)>>1]=z;z=(y+2+(A<<1)+C|0)>>>2&65535;b[d+(x+5<<1)>>1]=z;b[d+(v+3<<1)>>1]=z;b[d+(m+1<<1)>>1]=z;z=(y+1+A|0)>>>1&65535;b[d+(x+6<<1)>>1]=z;b[d+(v+4<<1)>>1]=z;b[d+(m+2<<1)>>1]=z;b[d+(s<<1)>>1]=z;z=(w+2+(y<<1)+A|0)>>>2&65535;b[d+(x+7<<1)>>1]=z;b[d+(v+5<<1)>>1]=z;b[d+(m+3<<1)>>1]=z;b[d+((s|1)<<1)>>1]=z;z=(w+1+y|0)>>>1&65535;b[d+(v+6<<1)>>1]=z;b[d+(m+4<<1)>>1]=z;b[d+((s|2)<<1)>>1]=z;b[d+(u<<1)>>1]=z;z=(h+2+(w<<1)+y|0)>>>2&65535;b[d+(v+7<<1)>>1]=z;b[d+(m+5<<1)>>1]=z;b[d+((s|3)<<1)>>1]=z;b[d+(u+1<<1)>>1]=z;z=(h+1+w|0)>>>1&65535;b[d+(m+6<<1)>>1]=z;b[d+(s+4<<1)>>1]=z;b[d+(u+2<<1)>>1]=z;b[d+(r<<1)>>1]=z;z=(f+2+(h<<1)+w|0)>>>2&65535;b[d+(m+7<<1)>>1]=z;b[d+(s+5<<1)>>1]=z;b[d+(u+3<<1)>>1]=z;b[d+((r|1)<<1)>>1]=z;z=f+1|0;m=(z+h|0)>>>1&65535;b[d+(s+6<<1)>>1]=m;b[d+(u+4<<1)>>1]=m;b[d+(r+2<<1)>>1]=m;b[d+(g<<1)>>1]=m;m=((f<<1)+2+h+D|0)>>>2&65535;b[d+(s+7<<1)>>1]=m;b[d+(u+5<<1)>>1]=m;b[d+(r+3<<1)>>1]=m;b[d+(g+1<<1)>>1]=m;m=(z+D|0)>>>1&65535;b[d+(u+6<<1)>>1]=m;b[d+(r+4<<1)>>1]=m;b[d+(g+2<<1)>>1]=m;b[d>>1]=m;m=k+2|0;z=(m+f+(D<<1)|0)>>>2&65535;b[d+(u+7<<1)>>1]=z;b[d+(r+5<<1)>>1]=z;b[d+(g+3<<1)>>1]=z;b[a+2>>1]=z;z=((k<<1)+2+l+D|0)>>>2&65535;b[d+(r+6<<1)>>1]=z;b[d+(g+4<<1)>>1]=z;b[a+4>>1]=z;z=(m+(l<<1)+n|0)>>>2&65535;b[d+(r+7<<1)>>1]=z;b[d+(g+5<<1)>>1]=z;b[a+6>>1]=z;z=(l+2+(n<<1)+o|0)>>>2&65535;b[d+(g+6<<1)>>1]=z;b[a+8>>1]=z;z=(n+2+(o<<1)+p|0)>>>2&65535;b[d+(g+7<<1)>>1]=z;b[a+10>>1]=z;b[a+12>>1]=(o+2+(p<<1)+q|0)>>>2;b[a+14>>1]=(p+2+(q<<1)+j|0)>>>2;return}function Jia(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;f=e[g+(2-h<<1)>>1]|0;c=(i+2+(j<<1)+f|0)>>>2;i=e[g+(3-h<<1)>>1]|0;l=(j+2+(f<<1)+i|0)>>>2;j=e[g+(4-h<<1)>>1]|0;m=(f+2+(i<<1)+j|0)>>>2;f=e[g+(5-h<<1)>>1]|0;n=(i+2+(j<<1)+f|0)>>>2;i=e[g+(6-h<<1)>>1]|0;o=(j+2+(f<<1)+i|0)>>>2;j=b[g+(7-h<<1)>>1]|0;p=j&65535;q=(f+2+(i<<1)+p|0)>>>2;if((d|0)==0){r=p;s=p;t=p;u=p;v=p;w=(j&65535)+2+(p<<1)|0}else{j=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;f=e[g+(10-h<<1)>>1]|0;x=e[g+(11-h<<1)>>1]|0;y=e[g+(12-h<<1)>>1]|0;r=(x+2+(y<<1)+(e[g+(13-h<<1)>>1]|0)|0)>>>2;s=(f+2+(x<<1)+y|0)>>>2;t=(d+2+(f<<1)+x|0)>>>2;u=(j+2+(d<<1)+f|0)>>>2;v=(p+2+(j<<1)+d|0)>>>2;w=(e[g+(8-h<<1)>>1]|0)+2+(p<<1)|0}p=(w+i|0)>>>2;b[g>>1]=(k+1+c|0)>>>1;b[g+(h<<1)>>1]=(k+2+(c<<1)+l|0)>>>2;k=(c+1+l|0)>>>1&65535;b[a+2>>1]=k;i=h<<1;b[g+(i<<1)>>1]=k;k=(c+2+(l<<1)+m|0)>>>2&65535;b[g+(h+1<<1)>>1]=k;c=h*3|0;b[g+(c<<1)>>1]=k;k=(l+1+m|0)>>>1&65535;b[a+4>>1]=k;b[g+((i|1)<<1)>>1]=k;w=h<<2;b[g+(w<<1)>>1]=k;k=(l+2+(m<<1)+n|0)>>>2&65535;b[g+(h+2<<1)>>1]=k;b[g+(c+1<<1)>>1]=k;l=h*5|0;b[g+(l<<1)>>1]=k;k=(m+1+n|0)>>>1&65535;b[a+6>>1]=k;b[g+(i+2<<1)>>1]=k;b[g+((w|1)<<1)>>1]=k;d=h*6|0;b[g+(d<<1)>>1]=k;k=(m+2+(n<<1)+o|0)>>>2&65535;b[g+(h+3<<1)>>1]=k;b[g+(c+2<<1)>>1]=k;b[g+(l+1<<1)>>1]=k;m=h*7|0;b[g+(m<<1)>>1]=k;k=(n+1+o|0)>>>1&65535;b[a+8>>1]=k;b[g+(i+3<<1)>>1]=k;b[g+((w|2)<<1)>>1]=k;b[g+((d|1)<<1)>>1]=k;k=(n+2+(o<<1)+q|0)>>>2&65535;b[g+(h+4<<1)>>1]=k;b[g+(c+3<<1)>>1]=k;b[g+(l+2<<1)>>1]=k;b[g+(m+1<<1)>>1]=k;k=(o+1+q|0)>>>1&65535;b[a+10>>1]=k;b[g+(i+4<<1)>>1]=k;b[g+((w|3)<<1)>>1]=k;b[g+(d+2<<1)>>1]=k;k=(o+2+(q<<1)+p|0)>>>2&65535;b[g+(h+5<<1)>>1]=k;b[g+(c+4<<1)>>1]=k;b[g+(l+3<<1)>>1]=k;b[g+(m+2<<1)>>1]=k;k=(q+1+p|0)>>>1&65535;b[a+12>>1]=k;b[g+(i+5<<1)>>1]=k;b[g+(w+4<<1)>>1]=k;b[g+(d+3<<1)>>1]=k;k=(q+2+(p<<1)+v|0)>>>2&65535;b[g+(h+6<<1)>>1]=k;b[g+(c+5<<1)>>1]=k;b[g+(l+4<<1)>>1]=k;b[g+(m+3<<1)>>1]=k;k=(p+1+v|0)>>>1&65535;b[a+14>>1]=k;b[g+(i+6<<1)>>1]=k;b[g+(w+5<<1)>>1]=k;b[g+(d+4<<1)>>1]=k;k=(p+2+(v<<1)+u|0)>>>2&65535;b[g+(h+7<<1)>>1]=k;b[g+(c+6<<1)>>1]=k;b[g+(l+5<<1)>>1]=k;b[g+(m+4<<1)>>1]=k;k=(v+1+u|0)>>>1&65535;b[g+(i+7<<1)>>1]=k;b[g+(w+6<<1)>>1]=k;b[g+(d+5<<1)>>1]=k;k=(v+2+(u<<1)+t|0)>>>2&65535;b[g+(c+7<<1)>>1]=k;b[g+(l+6<<1)>>1]=k;b[g+(m+5<<1)>>1]=k;k=(u+1+t|0)>>>1&65535;b[g+(w+7<<1)>>1]=k;b[g+(d+6<<1)>>1]=k;k=(u+2+(t<<1)+s|0)>>>2&65535;b[g+(l+7<<1)>>1]=k;b[g+(m+6<<1)>>1]=k;b[g+(d+7<<1)>>1]=(t+1+s|0)>>>1;b[g+(m+7<<1)>>1]=(t+2+(s<<1)+r|0)>>>2;return}function Kia(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a;g=f>>1;if((c|0)==0){c=a-2|0;h=c;i=c}else{h=d+(~g<<1)|0;i=a-2|0}c=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=((e[h>>1]|0)+2+(c<<1)+i|0)>>>2;h=g<<1;j=e[d+(h-1<<1)>>1]|0;k=(c+2+(i<<1)+j|0)>>>2;c=g*3|0;l=e[d+(c-1<<1)>>1]|0;m=(i+2+(j<<1)+l|0)>>>2;i=g<<2;n=e[d+(i-1<<1)>>1]|0;o=(j+2+(l<<1)+n|0)>>>2;j=g*5|0;p=e[d+(j-1<<1)>>1]|0;q=(l+2+(n<<1)+p|0)>>>2;l=g*6|0;r=e[d+(l-1<<1)>>1]|0;s=(n+2+(p<<1)+r|0)>>>2;n=g*7|0;t=e[d+(n-1<<1)>>1]|0;u=(p+2+(r<<1)+t|0)>>>2;p=(r+2+(t*3|0)|0)>>>2;b[d>>1]=(f+1+k|0)>>>1;b[a+2>>1]=(f+2+(k<<1)+m|0)>>>2;f=(k+1+m|0)>>>1&65535;b[a+4>>1]=f;b[d+(g<<1)>>1]=f;f=(k+2+(m<<1)+o|0)>>>2&65535;b[a+6>>1]=f;b[d+(g+1<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[a+8>>1]=f;b[d+(g+2<<1)>>1]=f;b[d+(h<<1)>>1]=f;f=(m+2+(o<<1)+q|0)>>>2&65535;b[a+10>>1]=f;b[d+(g+3<<1)>>1]=f;b[d+((h|1)<<1)>>1]=f;f=(o+1+q|0)>>>1&65535;b[a+12>>1]=f;b[d+(g+4<<1)>>1]=f;b[d+(h+2<<1)>>1]=f;b[d+(c<<1)>>1]=f;f=(o+2+(q<<1)+s|0)>>>2&65535;b[a+14>>1]=f;b[d+(g+5<<1)>>1]=f;b[d+(h+3<<1)>>1]=f;b[d+(c+1<<1)>>1]=f;f=(q+1+s|0)>>>1&65535;b[d+(g+6<<1)>>1]=f;b[d+(h+4<<1)>>1]=f;b[d+(c+2<<1)>>1]=f;b[d+(i<<1)>>1]=f;f=(q+2+(s<<1)+u|0)>>>2&65535;b[d+(g+7<<1)>>1]=f;b[d+(h+5<<1)>>1]=f;b[d+(c+3<<1)>>1]=f;b[d+((i|1)<<1)>>1]=f;f=(s+1+u|0)>>>1&65535;b[d+(h+6<<1)>>1]=f;b[d+(c+4<<1)>>1]=f;b[d+((i|2)<<1)>>1]=f;b[d+(j<<1)>>1]=f;f=(s+2+p+(u<<1)|0)>>>2&65535;b[d+(h+7<<1)>>1]=f;b[d+(c+5<<1)>>1]=f;b[d+((i|3)<<1)>>1]=f;b[d+(j+1<<1)>>1]=f;f=(p+1+u|0)>>>1&65535;b[d+(c+6<<1)>>1]=f;b[d+(i+4<<1)>>1]=f;b[d+(j+2<<1)>>1]=f;b[d+(l<<1)>>1]=f;f=(u+2+(p*3|0)|0)>>>2&65535;b[d+(c+7<<1)>>1]=f;b[d+(i+5<<1)>>1]=f;b[d+(j+3<<1)>>1]=f;b[d+((l|1)<<1)>>1]=f;f=p&65535;b[d+(n+7<<1)>>1]=f;b[d+(l+7<<1)>>1]=f;b[d+(j+7<<1)>>1]=f;b[d+(i+7<<1)>>1]=f;b[d+(n+6<<1)>>1]=f;b[d+(l+6<<1)>>1]=f;b[d+(j+6<<1)>>1]=f;b[d+(i+6<<1)>>1]=f;b[d+(n+5<<1)>>1]=f;b[d+(l+5<<1)>>1]=f;b[d+(j+5<<1)>>1]=f;b[d+(n+4<<1)>>1]=f;b[d+(l+4<<1)>>1]=f;b[d+(j+4<<1)>>1]=f;b[d+(n+3<<1)>>1]=f;b[d+(l+3<<1)>>1]=f;b[d+(n+2<<1)>>1]=f;b[d+(l+2<<1)>>1]=f;b[d+(n+1<<1)>>1]=f;b[d+(n<<1)>>1]=f;return}function Lia(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=e[d+((g<<1)-1<<1)>>1]|0;j=e[d+((g*3|0)-1<<1)>>1]|0;k=e[d+((g<<2)-1<<1)>>1]|0;l=e[d+((g*5|0)-1<<1)>>1]|0;m=e[d+((g*6|0)-1<<1)>>1]|0;n=e[d+((g*7|0)-1<<1)>>1]|0;o=(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2)+4+((b+2+(i<<1)+f|0)>>>2)+((i+2+(f<<1)+j|0)>>>2)+((f+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n*3|0)|0)>>>2)>>3;n=gHb(o,(o|0)<0|0?-1:0,65537,65537)|0;o=F;m=a;c[m>>2]=n;c[m+4>>2]=o;m=a+8|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=g<<1;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;g=d+(a<<1)|0;c[g>>2]=n;c[g+4>>2]=o;g=d+(a+4<<1)|0;c[g>>2]=n;c[g+4>>2]=o;return}function Mia(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}q=(((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2)+4+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+r|0)>>>2)+(((s&65535)+2+(r<<1)+p|0)>>>2)>>3;p=gHb(q,(q|0)<0|0?-1:0,65537,65537)|0;q=F;r=a;c[r>>2]=p;c[r+4>>2]=q;r=a+8|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=i<<1;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;i=h+(a<<1)|0;c[i>>2]=p;c[i+4>>2]=q;i=h+(a+4<<1)|0;c[i>>2]=p;c[i+4>>2]=q;return}function Nia(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;b=e>>1;e=a;c[e>>2]=16777472;c[e+4>>2]=16777472;e=a+8|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(b<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(b+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=b<<1;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e+b|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;return}function Oia(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function Pia(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=gHb(e[a-2>>1]|0,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=a+8|0;c[h>>2]=b;c[h+4>>2]=g;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;b=d+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(f+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f<<1;b=gHb(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=F;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*3|0;a=gHb(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;b=F;h=d+(g<<1)|0;c[h>>2]=a;c[h+4>>2]=b;h=d+(g+4<<1)|0;c[h>>2]=a;c[h+4>>2]=b;b=f<<2;h=gHb(e[d+(b-1<<1)>>1]|0,0,65537,65537)|0;a=F;g=d+(b<<1)|0;c[g>>2]=h;c[g+4>>2]=a;g=d+(b+4<<1)|0;c[g>>2]=h;c[g+4>>2]=a;a=f*5|0;g=gHb(e[d+(a-1<<1)>>1]|0,0,65537,65537)|0;h=F;b=d+(a<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(a+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f*6|0;b=gHb(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=F;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*7|0;f=gHb(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;a=F;b=d+(g<<1)|0;c[b>>2]=f;c[b+4>>2]=a;b=d+(g+4<<1)|0;c[b>>2]=f;c[b+4>>2]=a;return}function Qia(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<3;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+((b|4)<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*9|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*10|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*11|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*12|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*13|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*14|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*15|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function Ria(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ba(b,a)|0;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function Sia(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a;f=c>>1;c=a+6|0;g=(f<<2)-1|0;h=g-(f<<1)|0;i=g+f|0;j=h-f|0;k=i+f|0;l=j-f|0;m=e[d+(k+f<<1)>>1]|0;n=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=(((m-(e[d+(l-f<<1)>>1]|0)<<2)+((((e[d+(k<<1)>>1]|0)-(e[d+(l<<1)>>1]|0)|0)*3|0)+(((e[d+(i<<1)>>1]|0)-(e[d+(j<<1)>>1]|0)<<1)+((e[d+(g<<1)>>1]|0)-(e[d+(h<<1)>>1]|0))))|0)*17|0)+16>>5;h=n<<1;g=n*3|0;j=n<<2;i=n*5|0;l=n*6|0;k=n*7|0;o=d;d=((c+n|0)*-3|0)+16+((e[a-2+(8-f<<1)>>1]|0)+m<<4)|0;m=8;while(1){a=d>>5;if(a>>>0<512>>>0){p=a&65535}else{p=-a>>31&511}b[o>>1]=p;a=d+n>>5;if(a>>>0<512>>>0){q=a&65535}else{q=-a>>31&511}b[o+2>>1]=q;a=d+h>>5;if(a>>>0<512>>>0){r=a&65535}else{r=-a>>31&511}b[o+4>>1]=r;a=d+g>>5;if(a>>>0<512>>>0){s=a&65535}else{s=-a>>31&511}b[o+6>>1]=s;a=d+j>>5;if(a>>>0<512>>>0){t=a&65535}else{t=-a>>31&511}b[o+8>>1]=t;a=d+i>>5;if(a>>>0<512>>>0){u=a&65535}else{u=-a>>31&511}b[o+10>>1]=u;a=d+l>>5;if(a>>>0<512>>>0){v=a&65535}else{v=-a>>31&511}b[o+12>>1]=v;a=d+k>>5;if(a>>>0<512>>>0){w=a&65535}else{w=-a>>31&511}b[o+14>>1]=w;a=m-1|0;if((a|0)>0){o=o+(f<<1)|0;d=d+c|0;m=a}else{break}}return}function Tia(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a;f=c>>1;c=a+6|0;g=-f|0;h=(f<<3)-1|0;i=h-(f<<1)|0;j=h+f|0;k=i-f|0;l=j+f|0;m=k-f|0;n=a+((f*6|0)-2)|0;o=a+((f*22|0)-2)|0;p=f<<1;q=g<<1;r=p+f|0;s=q-f|0;t=b[o+(r+f<<1)>>1]|0;u=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=((((t&65535)-(e[n+(s-f<<1)>>1]|0)<<3)+((((e[o+(r<<1)>>1]|0)-(e[n+(s<<1)>>1]|0)|0)*7|0)+((((e[o+(p<<1)>>1]|0)-(e[n+(q<<1)>>1]|0)|0)*6|0)+((((e[o+(f<<1)>>1]|0)-(e[n+(g<<1)>>1]|0)|0)*5|0)+(((e[d+(l+f<<1)>>1]|0)-(e[d+(m-f<<1)>>1]|0)<<2)+((((e[d+(l<<1)>>1]|0)-(e[d+(m<<1)>>1]|0)|0)*3|0)+(((e[d+(j<<1)>>1]|0)-(e[d+(k<<1)>>1]|0)<<1)+((e[d+(h<<1)>>1]|0)-(e[d+(i<<1)>>1]|0))))))))|0)*5|0)+32>>6;i=u*3|0;h=u<<1;k=u<<2;j=u*5|0;m=u*6|0;l=u*7|0;g=d;d=16-i+(c*-7|0)+((e[a+(-2-(f<<1)+16)>>1]|0)+(t&65535)<<4)|0;t=16;while(1){a=d>>5;if(a>>>0<512>>>0){v=a&65535}else{v=-a>>31&511}b[g>>1]=v;a=d+u>>5;if(a>>>0<512>>>0){w=a&65535}else{w=-a>>31&511}b[g+2>>1]=w;a=d+h>>5;if(a>>>0<512>>>0){x=a&65535}else{x=-a>>31&511}b[g+4>>1]=x;a=d+i>>5;if(a>>>0<512>>>0){y=a&65535}else{y=-a>>31&511}b[g+6>>1]=y;a=d+k>>5;if(a>>>0<512>>>0){z=a&65535}else{z=-a>>31&511}b[g+8>>1]=z;a=d+j>>5;if(a>>>0<512>>>0){A=a&65535}else{A=-a>>31&511}b[g+10>>1]=A;a=d+m>>5;if(a>>>0<512>>>0){B=a&65535}else{B=-a>>31&511}b[g+12>>1]=B;a=d+l>>5;if(a>>>0<512>>>0){C=a&65535}else{C=-a>>31&511}b[g+14>>1]=C;a=t-1|0;if((a|0)>0){g=g+(f<<1)|0;d=d+c|0;t=a}else{break}}return}function Uia(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=1024-(d[b+~c|0]|0)|0;f=b+(-c|0)|0;g=b+(1-c)|0;h=b+(2-c)|0;i=b+(3-c)|0;j=b+(4-c)|0;k=b+(5-c)|0;l=b+(6-c)|0;m=b+(7-c)|0;n=0;o=b;while(1){b=(d[o-1|0]|0)+e|0;a[o]=a[1235032+(b+(d[f]|0))|0]|0;a[o+1|0]=a[1235032+((d[g]|0)+b)|0]|0;a[o+2|0]=a[1235032+((d[h]|0)+b)|0]|0;a[o+3|0]=a[1235032+((d[i]|0)+b)|0]|0;a[o+4|0]=a[1235032+((d[j]|0)+b)|0]|0;a[o+5|0]=a[1235032+((d[k]|0)+b)|0]|0;a[o+6|0]=a[1235032+((d[l]|0)+b)|0]|0;a[o+7|0]=a[1235032+((d[m]|0)+b)|0]|0;b=n+1|0;if((b|0)<8){n=b;o=o+c|0}else{break}}return}function Via(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=(e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+(e[d+(4-f<<1)>>1]|0)))|0;l=f*7|0;m=(e[d+(l-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;n=(e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+((e[a-2>>1]|0)+(e[d+(-f<<1)>>1]|0))+(e[d+(1-f<<1)>>1]|0))+(e[d+(2-f<<1)>>1]|0))+(e[d+(3-f<<1)>>1]|0)+4>>3;o=gHb(n,(n|0)<0|0?-1:0,65537,65537)|0;n=F;p=gHb((k+2|0)>>>2,0,65537,65537)|0;q=F;r=m+4+k>>3;k=a;c[k>>2]=o;c[k+4>>2]=n;k=a+8|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(f<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(f+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(h<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(h+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(j<<1)|0;c[k>>2]=o;c[k+4>>2]=n;n=d+(j+4<<1)|0;c[n>>2]=p;c[n+4>>2]=q;q=gHb((m+2|0)>>>2,0,65537,65537)|0;m=F;n=gHb(r,(r|0)<0|0?-1:0,65537,65537)|0;r=F;p=d+(b<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(b+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(g<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(g+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(i<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(i+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(l<<1)|0;c[p>>2]=q;c[p+4>>2]=m;m=d+(l+4<<1)|0;c[m>>2]=n;c[m+4>>2]=r;return}function Wia(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=f*7|0;l=(e[d+(k-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;m=gHb(((e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))+2|0)>>>2,0,65537,65537)|0;n=F;o=a;c[o>>2]=m;c[o+4>>2]=n;o=a+8|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;n=gHb((l+2|0)>>>2,0,65537,65537)|0;l=F;o=d+(b<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(b+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;return}function Xia(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=gHb(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=F;i=gHb((g+2|0)>>>2,0,65537,65537)|0;g=F;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function Yia(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;Xia(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Zia(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;Via(a,b);d=a;f=b>>1;b=gHb(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function _ia(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;Wia(a,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=16777472;c[b+4>>2]=16777472;b=f+(g<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=g<<1;e=f+(b<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=16777472;c[h+4>>2]=16777472;h=a+(d+8)|0;d=h;a=h;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(g<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;return}function $ia(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Wia(a,b);d=a;e=b>>1;b=a;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<1;f=d+(b<<1)|0;c[f>>2]=16777472;c[f+4>>2]=16777472;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=16777472;c[g+4>>2]=16777472;g=a+8|0;a=g;d=g;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(e<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(b<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(f<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;return}function aja(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=0;g=0;h=0;i=0;j=0;k=0;do{l=e[d+((ba(k,f)|0)-1<<1)>>1]|0;j=l+j+(e[d+(k-f<<1)>>1]|0)|0;l=k+4|0;i=(e[d+(l-f<<1)>>1]|0)+i|0;h=(e[d+((ba(l,f)|0)-1<<1)>>1]|0)+h|0;g=(e[d+((ba(k+8|0,f)|0)-1<<1)>>1]|0)+g|0;b=(e[d+((ba(k+12|0,f)|0)-1<<1)>>1]|0)+b|0;k=k+1|0;}while((k|0)<4);k=j+4>>3;j=gHb(k,(k|0)<0|0?-1:0,65537,65537)|0;k=F;l=i+2>>2;m=gHb(l,(l|0)<0|0?-1:0,65537,65537)|0;l=F;n=h+2>>2;o=h+4+i>>3;h=g+2>>2;p=g+4+i>>3;g=b+2>>2;q=b+4+i>>3;i=a;c[i>>2]=j;c[i+4>>2]=k;i=a+8|0;c[i>>2]=m;c[i+4>>2]=l;i=d+(f<<1)|0;c[i>>2]=j;c[i+4>>2]=k;i=d+(f+4<<1)|0;c[i>>2]=m;c[i+4>>2]=l;i=f<<1;a=d+(i<<1)|0;c[a>>2]=j;c[a+4>>2]=k;a=d+(i+4<<1)|0;c[a>>2]=m;c[a+4>>2]=l;a=f*3|0;i=d+(a<<1)|0;c[i>>2]=j;c[i+4>>2]=k;k=d+(a+4<<1)|0;c[k>>2]=m;c[k+4>>2]=l;l=gHb(n,(n|0)<0|0?-1:0,65537,65537)|0;n=F;k=gHb(o,(o|0)<0|0?-1:0,65537,65537)|0;o=F;m=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;a=gHb(p,(p|0)<0|0?-1:0,65537,65537)|0;p=F;i=gHb(g,(g|0)<0|0?-1:0,65537,65537)|0;g=F;j=gHb(q,(q|0)<0|0?-1:0,65537,65537)|0;q=F;b=f<<2;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*5|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;b=d+(r+4<<1)|0;c[b>>2]=k;c[b+4>>2]=o;b=f*6|0;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*7|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;n=d+(r+4<<1)|0;c[n>>2]=k;c[n+4>>2]=o;o=f<<3;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+((o|4)<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*9|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;o=d+(n+4<<1)|0;c[o>>2]=a;c[o+4>>2]=p;o=f*10|0;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+(o+4<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*11|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;h=d+(n+4<<1)|0;c[h>>2]=a;c[h+4>>2]=p;p=f*12|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*13|0;p=d+(h<<1)|0;c[p>>2]=i;c[p+4>>2]=g;p=d+(h+4<<1)|0;c[p>>2]=j;c[p+4>>2]=q;p=f*14|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*15|0;f=d+(h<<1)|0;c[f>>2]=i;c[f+4>>2]=g;g=d+(h+4<<1)|0;c[g>>2]=j;c[g+4>>2]=q;return}function bja(a,b){a=a|0;b=b|0;Wia(a,b);Wia(a+(b<<3)|0,b);return}function cja(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=gHb(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=F;i=gHb((g+2|0)>>>2,0,65537,65537)|0;g=F;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<3;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+((j|4)<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*9|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*10|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*11|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*12|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*13|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*14|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*15|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function dja(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;cja(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function eja(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;aja(a,b);d=a;f=b>>1;b=gHb(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function fja(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;Wia(a,b);Wia(a+(b<<3)|0,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=16777472;c[b+4>>2]=16777472;b=f+(g<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=g<<1;e=f+(b<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=16777472;c[h+4>>2]=16777472;h=a+(d+8)|0;d=h;a=h;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(g<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;return}function gja(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Wia(a,b);Wia(a+(b<<3)|0,b);d=a;e=b>>1;b=a;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<1;f=d+(b<<1)|0;c[f>>2]=16777472;c[f+4>>2]=16777472;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=16777472;c[g+4>>2]=16777472;g=a+8|0;a=g;d=g;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(e<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(b<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(f<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;return}function hja(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b<<2;f=b*5|0;g=b<<1;h=b*6|0;i=b*3|0;j=b*7|0;k=ba(((d[a+(i-1)|0]|0)+((d[a+(g-1)|0]|0)+((d[a+(b-1)|0]|0)+((d[a-1|0]|0)+(d[a+(-b|0)|0]|0)+(d[a+(4-b)|0]|0)+(d[a+(e-1)|0]|0))+(d[a+(1-b)|0]|0)+(d[a+(5-b)|0]|0)+(d[a+(f-1)|0]|0))+(d[a+(2-b)|0]|0)+(d[a+(6-b)|0]|0)+(d[a+(h-1)|0]|0))+(d[a+(3-b)|0]|0)+(d[a+(7-b)|0]|0)+(d[a+(j-1)|0]|0)+8|0)>>>4,16843009)|0;c[a>>2]=k;c[a+4>>2]=k;c[a+b>>2]=k;c[a+(b+4)>>2]=k;c[a+g>>2]=k;c[a+(g+4)>>2]=k;c[a+i>>2]=k;c[a+(i+4)>>2]=k;c[a+e>>2]=k;c[a+(e+4)>>2]=k;c[a+f>>2]=k;c[a+(f+4)>>2]=k;c[a+h>>2]=k;c[a+(h+4)>>2]=k;c[a+j>>2]=k;c[a+(j+4)>>2]=k;return}function ija(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b<<1;f=b*3|0;g=b<<2;h=b*5|0;i=b*6|0;j=b*7|0;k=ba(((d[a+(j-1)|0]|0)+((d[a+(i-1)|0]|0)+((d[a+(h-1)|0]|0)+((d[a+(g-1)|0]|0)+((d[a+(f-1)|0]|0)+((d[a+(e-1)|0]|0)+((d[a+(b-1)|0]|0)+(d[a-1|0]|0)))))))+4|0)>>>3,16843009)|0;c[a+4>>2]=k;c[a>>2]=k;c[a+(b+4)>>2]=k;c[a+b>>2]=k;c[a+(e+4)>>2]=k;c[a+e>>2]=k;c[a+(f+4)>>2]=k;c[a+f>>2]=k;c[a+(g+4)>>2]=k;c[a+g>>2]=k;c[a+(h+4)>>2]=k;c[a+h>>2]=k;c[a+(i+4)>>2]=k;c[a+i>>2]=k;c[a+(j+4)>>2]=k;c[a+j>>2]=k;return}function jja(a,b){a=a|0;b=b|0;var e=0,f=0;e=ba(((d[a+(7-b)|0]|0)+((d[a+(6-b)|0]|0)+((d[a+(5-b)|0]|0)+((d[a+(4-b)|0]|0)+((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+(d[a+(-b|0)|0]|0)))))))+4|0)>>>3,16843009)|0;c[a+4>>2]=e;c[a>>2]=e;c[a+(b+4)>>2]=e;c[a+b>>2]=e;f=b<<1;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b*3|0;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b<<2;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b*5|0;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b*6|0;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b*7|0;c[a+(f+4)>>2]=e;c[a+f>>2]=e;return}function kja(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+8|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=e<<2;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;e=d+(a+4<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;return}function lja(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=d+(e<<1)|0;TGb(a|0,1,16)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=d+(e+4<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=d+(b+4<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=d+(a+4<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=e<<2;a=d+(b<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=d+(b+4<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=d+(a+4<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=d+(b+4<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=16843009;c[e+4>>2]=16843009;e=d+(a+4<<1)|0;c[e>>2]=16843009;c[e+4>>2]=16843009;return}function mja(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+8|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<2;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;return}function nja(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=b>>1;f=a;c[f>>2]=16777472;c[f+4>>2]=16777472;f=a+8|0;c[f>>2]=16777472;c[f+4>>2]=16777472;f=d+(e<<1)|0;c[f>>2]=16777472;c[f+4>>2]=16777472;f=e+4|0;g=d+(f<<1)|0;c[g>>2]=16777472;c[g+4>>2]=16777472;g=e<<1;h=d+(g<<1)|0;c[h>>2]=16777472;c[h+4>>2]=16777472;h=g+4|0;i=d+(h<<1)|0;c[i>>2]=16777472;c[i+4>>2]=16777472;i=e*3|0;j=d+(i<<1)|0;c[j>>2]=16777472;c[j+4>>2]=16777472;j=i+4|0;k=d+(j<<1)|0;c[k>>2]=16777472;c[k+4>>2]=16777472;k=e<<2;l=d+(k<<1)|0;c[l>>2]=16777472;c[l+4>>2]=16777472;l=k+4|0;m=d+(l<<1)|0;c[m>>2]=16777472;c[m+4>>2]=16777472;m=e*5|0;n=d+(m<<1)|0;c[n>>2]=16777472;c[n+4>>2]=16777472;n=m+4|0;o=d+(n<<1)|0;c[o>>2]=16777472;c[o+4>>2]=16777472;o=e*6|0;p=d+(o<<1)|0;c[p>>2]=16777472;c[p+4>>2]=16777472;p=o+4|0;q=d+(p<<1)|0;c[q>>2]=16777472;c[q+4>>2]=16777472;q=e*7|0;r=d+(q<<1)|0;c[r>>2]=16777472;c[r+4>>2]=16777472;r=q+4|0;s=d+(r<<1)|0;c[s>>2]=16777472;c[s+4>>2]=16777472;s=b<<3;b=a+s|0;d=b;t=b;c[t>>2]=16777472;c[t+4>>2]=16777472;t=a+(s+8)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(e<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(f<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(g<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(h<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(i<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(j<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(k<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(l<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(m<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(n<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(o<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(p<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(q<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(r<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;return}function oja(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+((e[d+(-f<<1)>>1]|0)+((e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))))))))))))))))))+16>>5;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function pja(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a;a=b>>1;b=d+(-a<<1)|0;e=c[b>>2]|0;f=c[b+4>>2]|0;b=d+(4-a<<1)|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=d+(8-a<<1)|0;i=c[b>>2]|0;j=c[b+4>>2]|0;b=d+(12-a<<1)|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=0;do{m=ba(b,a)|0;n=d+(m<<1)|0;c[n>>2]=e;c[n+4>>2]=f;n=d+(m+4<<1)|0;c[n>>2]=g;c[n+4>>2]=h;n=d+(m+8<<1)|0;c[n>>2]=i;c[n+4>>2]=j;n=d+(m+12<<1)|0;c[n>>2]=k;c[n+4>>2]=l;b=b+1|0;}while((b|0)<16);return}function qja(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ba(b,a)|0;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+8<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+12<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function rja(a,b){a=a|0;b=b|0;Qoa(a,b,1,0);return}function sja(a,b){a=a|0;b=b|0;Qoa(a,b,0,1);return}function tja(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=1024-(d[b+~c|0]|0)|0;f=b+(-c|0)|0;g=b+(1-c)|0;h=b+(2-c)|0;i=b+(3-c)|0;j=b+(4-c)|0;k=b+(5-c)|0;l=b+(6-c)|0;m=b+(7-c)|0;n=b+(8-c)|0;o=b+(9-c)|0;p=b+(10-c)|0;q=b+(11-c)|0;r=b+(12-c)|0;s=b+(13-c)|0;t=b+(14-c)|0;u=b+(15-c)|0;v=0;w=b;while(1){b=(d[w-1|0]|0)+e|0;a[w]=a[1235032+(b+(d[f]|0))|0]|0;a[w+1|0]=a[1235032+((d[g]|0)+b)|0]|0;a[w+2|0]=a[1235032+((d[h]|0)+b)|0]|0;a[w+3|0]=a[1235032+((d[i]|0)+b)|0]|0;a[w+4|0]=a[1235032+((d[j]|0)+b)|0]|0;a[w+5|0]=a[1235032+((d[k]|0)+b)|0]|0;a[w+6|0]=a[1235032+((d[l]|0)+b)|0]|0;a[w+7|0]=a[1235032+((d[m]|0)+b)|0]|0;a[w+8|0]=a[1235032+((d[n]|0)+b)|0]|0;a[w+9|0]=a[1235032+((d[o]|0)+b)|0]|0;a[w+10|0]=a[1235032+((d[p]|0)+b)|0]|0;a[w+11|0]=a[1235032+((d[q]|0)+b)|0]|0;a[w+12|0]=a[1235032+((d[r]|0)+b)|0]|0;a[w+13|0]=a[1235032+((d[s]|0)+b)|0]|0;a[w+14|0]=a[1235032+((d[t]|0)+b)|0]|0;a[w+15|0]=a[1235032+((d[u]|0)+b)|0]|0;b=v+1|0;if((b|0)<16){v=b;w=w+c|0}else{break}}return}function uja(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+8|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+16|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+24|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;e=d+(a+4<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;e=d+(a+8<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;e=d+(a+12<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;return}function vja(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a;e=b>>1;b=d+(e<<1)|0;TGb(a|0,1,32)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=e<<1;a=d+(b<<1)|0;TGb(d+(e+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;f=d+(a<<1)|0;TGb(d+(b+4<<1)|0,1,24)|0;c[f>>2]=16843009;c[f+4>>2]=16843009;f=a+e|0;b=d+(f<<1)|0;TGb(d+(a+4<<1)|0,1,24)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=f+e|0;a=d+(b<<1)|0;TGb(d+(f+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;f=d+(a<<1)|0;TGb(d+(b+4<<1)|0,1,24)|0;c[f>>2]=16843009;c[f+4>>2]=16843009;f=a+e|0;b=d+(f<<1)|0;TGb(d+(a+4<<1)|0,1,24)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=f+e|0;a=d+(b<<1)|0;TGb(d+(f+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;f=d+(a<<1)|0;TGb(d+(b+4<<1)|0,1,24)|0;c[f>>2]=16843009;c[f+4>>2]=16843009;f=a+e|0;b=d+(f<<1)|0;TGb(d+(a+4<<1)|0,1,24)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=f+e|0;a=d+(b<<1)|0;TGb(d+(f+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;f=d+(a<<1)|0;TGb(d+(b+4<<1)|0,1,24)|0;c[f>>2]=16843009;c[f+4>>2]=16843009;f=a+e|0;b=d+(f<<1)|0;TGb(d+(a+4<<1)|0,1,24)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=f+e|0;a=d+(b<<1)|0;TGb(d+(f+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;e=d+(a<<1)|0;TGb(d+(b+4<<1)|0,1,24)|0;c[e>>2]=16843009;c[e+4>>2]=16843009;TGb(d+(a+4<<1)|0,1,24)|0;return}function wja(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a;f=c>>1;c=a+14|0;g=-f|0;h=(f<<3)-1|0;i=d+(h<<1)|0;j=d+(h-(f<<1)<<1)|0;h=a+((f*30|0)-2)|0;k=2;l=i;m=j;n=(e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0)|0;o=(e[i>>1]|0)-(e[j>>1]|0)|0;do{l=l+(f<<1)|0;m=m+(g<<1)|0;n=(ba((e[c+(k-f<<1)>>1]|0)-(e[c+(-(f+k|0)<<1)>>1]|0)|0,k)|0)+n|0;o=(ba((e[l>>1]|0)-(e[m>>1]|0)|0,k)|0)+o|0;k=k+1|0;}while((k|0)<9);k=(n*5|0)+32>>6;n=(o*5|0)+32>>6;o=k<<1;m=k*3|0;l=k<<2;c=((n+k|0)*-7|0)+16+((e[a-2+(16-f<<1)>>1]|0)+(e[h>>1]|0)<<4)|0;h=d;d=16;while(1){a=-16;g=c;while(1){j=g>>5;if(j>>>0<512>>>0){p=j&65535}else{p=-j>>31&511}b[h+(a+16<<1)>>1]=p;j=g+k>>5;if(j>>>0<512>>>0){q=j&65535}else{q=-j>>31&511}b[h+(a+17<<1)>>1]=q;j=g+o>>5;if(j>>>0<512>>>0){r=j&65535}else{r=-j>>31&511}b[h+(a+18<<1)>>1]=r;j=g+m>>5;if(j>>>0<512>>>0){s=j&65535}else{s=-j>>31&511}b[h+(a+19<<1)>>1]=s;j=a+4|0;if((j|0)<0){a=j;g=g+l|0}else{break}}g=d-1|0;if((g|0)>0){c=c+n|0;h=h+(f<<1)|0;d=g}else{break}}return}function xja(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))+8>>4;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function yja(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))))))))))))))+8>>4;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function zja(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+8|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+16|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+24|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+8<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+12<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;return}function Aja(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a;h=f>>1;f=h<<1;i=h*3|0;j=h<<2;k=(e[g+(-h<<1)>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=k;l=k+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=l;k=l+(c[d+32>>2]|0)|0;b[g+(i-h<<1)>>1]=k;b[g+(j-h<<1)>>1]=k+(c[d+48>>2]|0);k=1-h|0;h=(e[g+(k<<1)>>1]|0)+(c[d+4>>2]|0)|0;b[a+2>>1]=h;l=h+(c[d+20>>2]|0)|0;b[g+(k+f<<1)>>1]=l;h=l+(c[d+36>>2]|0)|0;b[g+(k+i<<1)>>1]=h;b[g+(k+j<<1)>>1]=h+(c[d+52>>2]|0);h=k+1|0;l=(e[g+(h<<1)>>1]|0)+(c[d+8>>2]|0)|0;b[a+4>>1]=l;m=l+(c[d+24>>2]|0)|0;b[g+(h+f<<1)>>1]=m;l=m+(c[d+40>>2]|0)|0;b[g+(h+i<<1)>>1]=l;b[g+(h+j<<1)>>1]=l+(c[d+56>>2]|0);l=k+2|0;k=(e[g+(l<<1)>>1]|0)+(c[d+12>>2]|0)|0;b[a+6>>1]=k;a=k+(c[d+28>>2]|0)|0;b[g+(l+f<<1)>>1]=a;f=a+(c[d+44>>2]|0)|0;b[g+(l+i<<1)>>1]=f;b[g+(l+j<<1)>>1]=f+(c[d+60>>2]|0);TGb(d|0,0,64)|0;return}function Bja(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=a;h=f>>1;f=(e[a-2>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=f;i=f+(c[d+4>>2]|0)|0;b[a+2>>1]=i;f=i+(c[d+8>>2]|0)|0;b[a+4>>1]=f;b[a+6>>1]=f+(c[d+12>>2]|0);f=(e[g+(h-1<<1)>>1]|0)+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=f;a=f+(c[d+20>>2]|0)|0;b[g+(h+1<<1)>>1]=a;f=a+(c[d+24>>2]|0)|0;b[g+(h+2<<1)>>1]=f;b[g+(h+3<<1)>>1]=f+(c[d+28>>2]|0);f=h<<1;a=(e[g+(f-1<<1)>>1]|0)+(c[d+32>>2]|0)|0;b[g+(f<<1)>>1]=a;i=a+(c[d+36>>2]|0)|0;b[g+((f|1)<<1)>>1]=i;a=i+(c[d+40>>2]|0)|0;b[g+(f+2<<1)>>1]=a;b[g+(f+3<<1)>>1]=a+(c[d+44>>2]|0);a=f+h|0;h=(e[g+(a-1<<1)>>1]|0)+(c[d+48>>2]|0)|0;b[g+(a<<1)>>1]=h;f=h+(c[d+52>>2]|0)|0;b[g+(a+1<<1)>>1]=f;h=f+(c[d+56>>2]|0)|0;b[g+(a+2<<1)>>1]=h;b[g+(a+3<<1)>>1]=h+(c[d+60>>2]|0);TGb(d|0,0,64)|0;return}function Cja(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=g<<1;h=g*3|0;i=g<<2;j=g*5|0;k=g*6|0;l=g*7|0;m=g<<3;n=0;o=a+(-g<<1)|0;a=d;while(1){p=(e[o>>1]|0)+(c[a>>2]|0)|0;b[o+(g<<1)>>1]=p;q=p+(c[a+32>>2]|0)|0;b[o+(f<<1)>>1]=q;p=q+(c[a+64>>2]|0)|0;b[o+(h<<1)>>1]=p;q=p+(c[a+96>>2]|0)|0;b[o+(i<<1)>>1]=q;p=q+(c[a+128>>2]|0)|0;b[o+(j<<1)>>1]=p;q=p+(c[a+160>>2]|0)|0;b[o+(k<<1)>>1]=q;p=q+(c[a+192>>2]|0)|0;b[o+(l<<1)>>1]=p;b[o+(m<<1)>>1]=p+(c[a+224>>2]|0);p=n+1|0;if((p|0)<8){n=p;o=o+2|0;a=a+4|0}else{break}}TGb(d|0,0,256)|0;return}function Dja(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=f>>1;f=0;h=a;a=d;while(1){i=(e[h-2>>1]|0)+(c[a>>2]|0)|0;b[h>>1]=i;j=i+(c[a+4>>2]|0)|0;b[h+2>>1]=j;i=j+(c[a+8>>2]|0)|0;b[h+4>>1]=i;j=i+(c[a+12>>2]|0)|0;b[h+6>>1]=j;i=j+(c[a+16>>2]|0)|0;b[h+8>>1]=i;j=i+(c[a+20>>2]|0)|0;b[h+10>>1]=j;i=j+(c[a+24>>2]|0)|0;b[h+12>>1]=i;b[h+14>>1]=i+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}TGb(d|0,0,256)|0;return}function Eja(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Aja(a+(c[b>>2]|0)|0,d,e);Aja(a+(c[b+4>>2]|0)|0,d+64|0,e);Aja(a+(c[b+8>>2]|0)|0,d+128|0,e);Aja(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function Fja(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Bja(a+(c[b>>2]|0)|0,d,e);Bja(a+(c[b+4>>2]|0)|0,d+64|0,e);Bja(a+(c[b+8>>2]|0)|0,d+128|0,e);Bja(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function Gja(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Aja(a+(c[b>>2]|0)|0,d,e);Aja(a+(c[b+4>>2]|0)|0,d+64|0,e);Aja(a+(c[b+8>>2]|0)|0,d+128|0,e);Aja(a+(c[b+12>>2]|0)|0,d+192|0,e);Aja(a+(c[b+32>>2]|0)|0,d+256|0,e);Aja(a+(c[b+36>>2]|0)|0,d+320|0,e);Aja(a+(c[b+40>>2]|0)|0,d+384|0,e);Aja(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function Hja(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Bja(a+(c[b>>2]|0)|0,d,e);Bja(a+(c[b+4>>2]|0)|0,d+64|0,e);Bja(a+(c[b+8>>2]|0)|0,d+128|0,e);Bja(a+(c[b+12>>2]|0)|0,d+192|0,e);Bja(a+(c[b+32>>2]|0)|0,d+256|0,e);Bja(a+(c[b+36>>2]|0)|0,d+320|0,e);Bja(a+(c[b+40>>2]|0)|0,d+384|0,e);Bja(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function Ija(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Aja(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Jja(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Bja(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Kja(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=a;e=d>>1;d=b+(-e<<1)|0;f=c[d>>2]|0;g=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+((e*3|0)<<1)|0;c[d>>2]=f;c[d+4>>2]=g;return}function Lja(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0;b=a;f=d>>1;d=gHb(e[a-2>>1]|0,0,65537,65537)|0;g=a;c[g>>2]=d;c[g+4>>2]=F;g=gHb(e[b+(f-1<<1)>>1]|0,0,65537,65537)|0;d=b+(f<<1)|0;c[d>>2]=g;c[d+4>>2]=F;d=f<<1;g=gHb(e[b+(d-1<<1)>>1]|0,0,65537,65537)|0;a=b+(d<<1)|0;c[a>>2]=g;c[a+4>>2]=F;a=f*3|0;f=gHb(e[b+(a-1<<1)>>1]|0,0,65537,65537)|0;g=b+(a<<1)|0;c[g>>2]=f;c[g+4>>2]=F;return}function Mja(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=(e[b+(-f<<1)>>1]|0)+4+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=b+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(d<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Nja(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=d>>1;d=e[f+(1-g<<1)>>1]|0;h=e[f+(2-g<<1)>>1]|0;i=e[f+(3-g<<1)>>1]|0;j=e[c>>1]|0;k=e[c+2>>1]|0;l=e[c+4>>1]|0;m=e[c+6>>1]|0;b[f>>1]=((e[f+(-g<<1)>>1]|0)+2+h+(d<<1)|0)>>>2;c=(d+2+i+(h<<1)|0)>>>2&65535;b[f+(g<<1)>>1]=c;b[a+2>>1]=c;c=(h+2+j+(i<<1)|0)>>>2&65535;h=g<<1;b[f+(h<<1)>>1]=c;b[f+(g+1<<1)>>1]=c;b[a+4>>1]=c;c=(i+2+k+(j<<1)|0)>>>2&65535;i=g*3|0;b[f+(i<<1)>>1]=c;b[f+((h|1)<<1)>>1]=c;b[f+(g+2<<1)>>1]=c;b[a+6>>1]=c;c=(j+2+l+(k<<1)|0)>>>2&65535;b[f+(i+1<<1)>>1]=c;b[f+(h+2<<1)>>1]=c;b[f+(g+3<<1)>>1]=c;c=(k+2+m+(l<<1)|0)>>>2&65535;b[f+(i+2<<1)>>1]=c;b[f+(h+3<<1)>>1]=c;b[f+(i+3<<1)>>1]=(l+2+(m*3|0)|0)>>>2;return}function Oja(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;b[c+(o<<1)>>1]=(l+2+(n<<1)+(e[c+(o-1<<1)>>1]|0)|0)>>>2;p=(k+2+(l<<1)+n|0)>>>2&65535;b[c+(o+1<<1)>>1]=p;b[c+(m<<1)>>1]=p;p=d+2|0;n=(p+(k<<1)+l|0)>>>2&65535;b[c+(o+2<<1)>>1]=n;b[c+((m|1)<<1)>>1]=n;b[c+(f<<1)>>1]=n;n=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+3<<1)>>1]=n;b[c+(m+2<<1)>>1]=n;b[c+(f+1<<1)>>1]=n;b[c>>1]=n;n=(p+(g<<1)+h|0)>>>2&65535;b[c+(m+3<<1)>>1]=n;b[c+(f+2<<1)>>1]=n;b[a+2>>1]=n;n=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(f+3<<1)>>1]=n;b[a+4>>1]=n;b[a+6>>1]=(h+2+(i<<1)+j|0)>>>2;return}function Pja(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;p=(d+1+g|0)>>>1&65535;b[c+((m|1)<<1)>>1]=p;b[c>>1]=p;p=(g+1+h|0)>>>1&65535;b[c+(m+2<<1)>>1]=p;b[a+2>>1]=p;p=(h+1+i|0)>>>1&65535;b[c+(m+3<<1)>>1]=p;b[a+4>>1]=p;b[a+6>>1]=(i+1+j|0)>>>1;a=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+1<<1)>>1]=a;b[c+(f<<1)>>1]=a;a=d+2|0;d=(a+(g<<1)+h|0)>>>2&65535;b[c+(o+2<<1)>>1]=d;b[c+(f+1<<1)>>1]=d;d=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(o+3<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;b[c+(f+3<<1)>>1]=(h+2+(i<<1)+j|0)>>>2;b[c+(m<<1)>>1]=(a+(k<<1)+l|0)>>>2;b[c+(o<<1)>>1]=(k+2+(l<<1)+n|0)>>>2;return}function Qja(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[a-2>>1]|0;k=e[c+(f-1<<1)>>1]|0;l=f<<1;m=e[c+(l-1<<1)>>1]|0;n=f*3|0;o=e[c+(n-1<<1)>>1]|0;p=(d+1+j|0)>>>1&65535;b[c+(f+2<<1)>>1]=p;b[c>>1]=p;p=((d<<1)+2+g+j|0)>>>2&65535;b[c+(f+3<<1)>>1]=p;b[a+2>>1]=p;p=d+2|0;b[a+4>>1]=(p+(g<<1)+h|0)>>>2;b[a+6>>1]=(g+2+(h<<1)+i|0)>>>2;i=(j+1+k|0)>>>1&65535;b[c+(l+2<<1)>>1]=i;b[c+(f<<1)>>1]=i;i=(p+(j<<1)+k|0)>>>2&65535;b[c+(l+3<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;i=(k+1+m|0)>>>1&65535;b[c+(n+2<<1)>>1]=i;b[c+(l<<1)>>1]=i;i=(j+2+(k<<1)+m|0)>>>2&65535;b[c+(n+3<<1)>>1]=i;b[c+((l|1)<<1)>>1]=i;b[c+(n<<1)>>1]=(m+1+o|0)>>>1;b[c+(n+1<<1)>>1]=(k+2+(m<<1)+o|0)>>>2;return}function Rja(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a;g=d>>1;d=e[f+(-g<<1)>>1]|0;h=e[f+(1-g<<1)>>1]|0;i=e[f+(2-g<<1)>>1]|0;j=e[f+(3-g<<1)>>1]|0;k=e[c>>1]|0;l=e[c+2>>1]|0;m=e[c+4>>1]|0;b[f>>1]=(d+1+h|0)>>>1;c=(h+1+i|0)>>>1&65535;n=g<<1;b[f+(n<<1)>>1]=c;b[a+2>>1]=c;c=(i+1+j|0)>>>1&65535;b[f+((n|1)<<1)>>1]=c;b[a+4>>1]=c;c=(j+1+k|0)>>>1&65535;b[f+(n+2<<1)>>1]=c;b[a+6>>1]=c;b[f+(n+3<<1)>>1]=(k+1+l|0)>>>1;b[f+(g<<1)>>1]=(d+2+(h<<1)+i|0)>>>2;d=(h+2+(i<<1)+j|0)>>>2&65535;h=g*3|0;b[f+(h<<1)>>1]=d;b[f+(g+1<<1)>>1]=d;d=(i+2+(j<<1)+k|0)>>>2&65535;b[f+(h+1<<1)>>1]=d;b[f+(g+2<<1)>>1]=d;d=(j+2+(k<<1)+l|0)>>>2&65535;b[f+(h+2<<1)>>1]=d;b[f+(g+3<<1)>>1]=d;b[f+(h+3<<1)>>1]=(k+2+(l<<1)+m|0)>>>2;return}function Sja(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=a;f=d>>1;d=e[a-2>>1]|0;g=e[c+(f-1<<1)>>1]|0;h=f<<1;i=e[c+(h-1<<1)>>1]|0;j=f*3|0;k=b[c+(j-1<<1)>>1]|0;l=k&65535;b[c>>1]=(d+1+g|0)>>>1;b[a+2>>1]=(d+2+(g<<1)+i|0)>>>2;d=(g+1+i|0)>>>1&65535;b[c+(f<<1)>>1]=d;b[a+4>>1]=d;d=(g+2+(i<<1)+l|0)>>>2&65535;b[c+(f+1<<1)>>1]=d;b[a+6>>1]=d;d=(i+1+l|0)>>>1&65535;b[c+(h<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;d=(i+2+l+(l<<1)|0)>>>2&65535;b[c+((h|1)<<1)>>1]=d;b[c+(f+3<<1)>>1]=d;b[c+(j+3<<1)>>1]=k;b[c+(j+2<<1)>>1]=k;b[c+(h+2<<1)>>1]=k;b[c+(j<<1)>>1]=k;b[c+(j+1<<1)>>1]=k;b[c+(h+3<<1)>>1]=k;return}function Tja(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=gHb(((e[a-2>>1]|0)+2+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;i=F;j=a;c[j>>2]=h;c[j+4>>2]=i;j=b+(f<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(d<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(g<<1)|0;c[j>>2]=h;c[j+4>>2]=i;return}function Uja(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0;b=a;f=d>>1;d=gHb(((e[b+(-f<<1)>>1]|0)+2+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+((f*3|0)<<1)|0;c[h>>2]=d;c[h+4>>2]=g;return}function Vja(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=33554944;c[d+4>>2]=33554944;d=b+(e<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=b+(e<<1<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=b+((e*3|0)<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;return}function Wja(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=33489407;c[d+4>>2]=33489407;d=b+(e<<1)|0;c[d>>2]=33489407;c[d+4>>2]=33489407;d=b+(e<<1<<1)|0;c[d>>2]=33489407;c[d+4>>2]=33489407;d=b+((e*3|0)<<1)|0;c[d>>2]=33489407;c[d+4>>2]=33489407;return}function Xja(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=33620481;c[d+4>>2]=33620481;d=b+(e<<1)|0;c[d>>2]=33620481;c[d+4>>2]=33620481;d=b+(e<<1<<1)|0;c[d>>2]=33620481;c[d+4>>2]=33620481;d=b+((e*3|0)<<1)|0;c[d>>2]=33620481;c[d+4>>2]=33620481;return}function Yja(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}b[h>>1]=((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;b[a+2>>1]=(j+2+(k<<1)+l|0)>>>2;b[a+4>>1]=(k+2+(l<<1)+m|0)>>>2;b[a+6>>1]=(l+2+(m<<1)+n|0)>>>2;l=a+8|0;b[l>>1]=(m+2+(n<<1)+o|0)>>>2;b[a+10>>1]=(n+2+(o<<1)+p|0)>>>2;b[a+12>>1]=(o+2+(p<<1)+r|0)>>>2;b[a+14>>1]=((s&65535)+2+(r<<1)+p|0)>>>2;p=a;a=c[p>>2]|0;r=c[p+4>>2]|0;p=l;l=c[p>>2]|0;s=c[p+4>>2]|0;p=h+(i<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(i+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<1;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*3|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<2;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*5|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i*6|0;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*7|0;i=h+(o<<1)|0;c[i>>2]=a;c[i+4>>2]=r;r=h+(o+4<<1)|0;c[r>>2]=l;c[r+4>>2]=s;return}function Zja(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=g<<1;j=e[d+(f-1<<1)>>1]|0;k=g*3|0;l=e[d+(k-1<<1)>>1]|0;m=g<<2;n=e[d+(m-1<<1)>>1]|0;o=g*5|0;p=e[d+(o-1<<1)>>1]|0;q=g*6|0;r=e[d+(q-1<<1)>>1]|0;s=g*7|0;t=e[d+(s-1<<1)>>1]|0;u=gHb(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2,0,65537,65537)|0;h=F;v=a;c[v>>2]=u;c[v+4>>2]=h;v=a+8|0;c[v>>2]=u;c[v+4>>2]=h;h=gHb((b+2+(i<<1)+j|0)>>>2,0,65537,65537)|0;b=F;v=d+(g<<1)|0;c[v>>2]=h;c[v+4>>2]=b;v=d+(g+4<<1)|0;c[v>>2]=h;c[v+4>>2]=b;b=gHb((i+2+(j<<1)+l|0)>>>2,0,65537,65537)|0;i=F;v=d+(f<<1)|0;c[v>>2]=b;c[v+4>>2]=i;v=d+(f+4<<1)|0;c[v>>2]=b;c[v+4>>2]=i;i=gHb((j+2+(l<<1)+n|0)>>>2,0,65537,65537)|0;j=F;v=d+(k<<1)|0;c[v>>2]=i;c[v+4>>2]=j;v=d+(k+4<<1)|0;c[v>>2]=i;c[v+4>>2]=j;j=gHb((l+2+(n<<1)+p|0)>>>2,0,65537,65537)|0;l=F;v=d+(m<<1)|0;c[v>>2]=j;c[v+4>>2]=l;v=d+(m+4<<1)|0;c[v>>2]=j;c[v+4>>2]=l;l=gHb((n+2+(p<<1)+r|0)>>>2,0,65537,65537)|0;n=F;v=d+(o<<1)|0;c[v>>2]=l;c[v+4>>2]=n;v=d+(o+4<<1)|0;c[v>>2]=l;c[v+4>>2]=n;n=gHb((p+2+(r<<1)+t|0)>>>2,0,65537,65537)|0;p=F;v=d+(q<<1)|0;c[v>>2]=n;c[v+4>>2]=p;v=d+(q+4<<1)|0;c[v>>2]=n;c[v+4>>2]=p;p=gHb((r+2+(t*3|0)|0)>>>2,0,65537,65537)|0;t=F;r=d+(s<<1)|0;c[r>>2]=p;c[r+4>>2]=t;r=d+(s+4<<1)|0;c[r>>2]=p;c[r+4>>2]=t;return}function _ja(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=a;i=g>>1;g=(d|0)!=0;if(g){d=~i;j=h+(d<<1)|0;k=a-2|0;l=d}else{d=a-2|0;j=d;k=d;l=~i}d=e[k>>1]|0;k=e[h+(i-1<<1)>>1]|0;m=e[h+((i<<1)-1<<1)>>1]|0;n=e[h+((i*3|0)-1<<1)>>1]|0;o=e[h+((i<<2)-1<<1)>>1]|0;p=e[h+((i*5|0)-1<<1)>>1]|0;q=e[h+((i*6|0)-1<<1)>>1]|0;r=e[h+((i*7|0)-1<<1)>>1]|0;s=-i|0;t=e[h+(s<<1)>>1]|0;u=e[h+(1-i<<1)>>1]|0;v=e[h+(2-i<<1)>>1]|0;w=e[h+(3-i<<1)>>1]|0;x=e[h+(4-i<<1)>>1]|0;y=e[h+(5-i<<1)>>1]|0;z=e[h+(6-i<<1)>>1]|0;A=b[h+(7-i<<1)>>1]|0;B=A&65535;if((f|0)==0){C=A}else{C=b[h+(8-i<<1)>>1]|0}A=(((e[j>>1]|0)+2+(d<<1)+k|0)>>>2)+8+((d+2+(k<<1)+m|0)>>>2)+((k+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q<<1)+r|0)>>>2)+((q+2+(r*3|0)|0)>>>2)+(((e[h+((g?l:s)<<1)>>1]|0)+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+z|0)>>>2)+((y+2+(z<<1)+B|0)>>>2)+(((C&65535)+2+(B<<1)+z|0)>>>2)>>4;z=gHb(A,(A|0)<0|0?-1:0,65537,65537)|0;A=F;B=a;c[B>>2]=z;c[B+4>>2]=A;B=a+8|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=i<<1;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;i=h+(a<<1)|0;c[i>>2]=z;c[i+4>>2]=A;i=h+(a+4<<1)|0;c[i>>2]=z;c[i+4>>2]=A;return}function $ja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=e[g+(2-h<<1)>>1]|0;l=(i+2+(j<<1)+k|0)>>>2;m=e[g+(3-h<<1)>>1]|0;n=(j+2+(k<<1)+m|0)>>>2;o=e[g+(4-h<<1)>>1]|0;p=(k+2+(m<<1)+o|0)>>>2;k=e[g+(5-h<<1)>>1]|0;q=(m+2+(o<<1)+k|0)>>>2;m=e[g+(6-h<<1)>>1]|0;r=(o+2+(k<<1)+m|0)>>>2;o=b[g+(7-h<<1)>>1]|0;s=o&65535;t=(k+2+(m<<1)+s|0)>>>2;if((d|0)==0){u=s;v=s;w=s;x=s;y=s;z=s;A=s;B=s;C=(o&65535)+2+(s<<1)|0}else{o=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;k=e[g+(10-h<<1)>>1]|0;D=e[g+(11-h<<1)>>1]|0;E=e[g+(12-h<<1)>>1]|0;F=e[g+(13-h<<1)>>1]|0;G=e[g+(14-h<<1)>>1]|0;H=e[g+(15-h<<1)>>1]|0;u=(G+2+(H*3|0)|0)>>>2;v=(F+2+(G<<1)+H|0)>>>2;w=(E+2+(F<<1)+G|0)>>>2;x=(D+2+(E<<1)+F|0)>>>2;y=(k+2+(D<<1)+E|0)>>>2;z=(d+2+(k<<1)+D|0)>>>2;A=(o+2+(d<<1)+k|0)>>>2;B=(s+2+(o<<1)+d|0)>>>2;C=(e[g+(8-h<<1)>>1]|0)+2+(s<<1)|0}s=(C+m|0)>>>2;b[g>>1]=((((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2)+2+(l<<1)+n|0)>>>2;j=(l+2+(n<<1)+p|0)>>>2&65535;b[a+2>>1]=j;b[g+(h<<1)>>1]=j;j=(n+2+(p<<1)+q|0)>>>2&65535;b[a+4>>1]=j;b[g+(h+1<<1)>>1]=j;n=h<<1;b[g+(n<<1)>>1]=j;j=(p+2+(q<<1)+r|0)>>>2&65535;b[a+6>>1]=j;b[g+(h+2<<1)>>1]=j;b[g+((n|1)<<1)>>1]=j;p=h*3|0;b[g+(p<<1)>>1]=j;j=(q+2+(r<<1)+t|0)>>>2&65535;b[a+8>>1]=j;b[g+(h+3<<1)>>1]=j;b[g+(n+2<<1)>>1]=j;b[g+(p+1<<1)>>1]=j;q=h<<2;b[g+(q<<1)>>1]=j;j=(r+2+(t<<1)+s|0)>>>2&65535;b[a+10>>1]=j;b[g+(h+4<<1)>>1]=j;b[g+(n+3<<1)>>1]=j;b[g+(p+2<<1)>>1]=j;b[g+((q|1)<<1)>>1]=j;r=h*5|0;b[g+(r<<1)>>1]=j;j=(t+2+(s<<1)+B|0)>>>2&65535;b[a+12>>1]=j;b[g+(h+5<<1)>>1]=j;b[g+(n+4<<1)>>1]=j;b[g+(p+3<<1)>>1]=j;b[g+((q|2)<<1)>>1]=j;b[g+(r+1<<1)>>1]=j;t=h*6|0;b[g+(t<<1)>>1]=j;j=(s+2+(B<<1)+A|0)>>>2&65535;b[a+14>>1]=j;b[g+(h+6<<1)>>1]=j;b[g+(n+5<<1)>>1]=j;b[g+(p+4<<1)>>1]=j;b[g+((q|3)<<1)>>1]=j;b[g+(r+2<<1)>>1]=j;b[g+((t|1)<<1)>>1]=j;a=h*7|0;b[g+(a<<1)>>1]=j;j=(B+2+(A<<1)+z|0)>>>2&65535;b[g+(h+7<<1)>>1]=j;b[g+(n+6<<1)>>1]=j;b[g+(p+5<<1)>>1]=j;b[g+(q+4<<1)>>1]=j;b[g+(r+3<<1)>>1]=j;b[g+(t+2<<1)>>1]=j;b[g+(a+1<<1)>>1]=j;j=(A+2+(z<<1)+y|0)>>>2&65535;b[g+(n+7<<1)>>1]=j;b[g+(p+6<<1)>>1]=j;b[g+(q+5<<1)>>1]=j;b[g+(r+4<<1)>>1]=j;b[g+(t+3<<1)>>1]=j;b[g+(a+2<<1)>>1]=j;j=(z+2+(y<<1)+x|0)>>>2&65535;b[g+(p+7<<1)>>1]=j;b[g+(q+6<<1)>>1]=j;b[g+(r+5<<1)>>1]=j;b[g+(t+4<<1)>>1]=j;b[g+(a+3<<1)>>1]=j;j=(y+2+(x<<1)+w|0)>>>2&65535;b[g+(q+7<<1)>>1]=j;b[g+(r+6<<1)>>1]=j;b[g+(t+5<<1)>>1]=j;b[g+(a+4<<1)>>1]=j;j=(x+2+(w<<1)+v|0)>>>2&65535;b[g+(r+7<<1)>>1]=j;b[g+(t+6<<1)>>1]=j;b[g+(a+5<<1)>>1]=j;j=(w+2+(v<<1)+u|0)>>>2&65535;b[g+(t+7<<1)>>1]=j;b[g+(a+6<<1)>>1]=j;b[g+(a+7<<1)>>1]=(v+2+(u*3|0)|0)>>>2;return}function aka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;k=e[g+(v-1<<1)>>1]|0;d=i+2|0;i=(d+(w<<1)+k|0)>>>2;c=h*3|0;y=e[g+(c-1<<1)>>1]|0;z=(w+2+(k<<1)+y|0)>>>2;w=h<<2;A=e[g+(w-1<<1)>>1]|0;B=(k+2+(y<<1)+A|0)>>>2;k=h*5|0;C=e[g+(k-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*6|0;E=e[g+(y-1<<1)>>1]|0;F=(A+2+(C<<1)+E|0)>>>2;A=h*7|0;G=e[g+(A-1<<1)>>1]|0;H=(C+2+(E<<1)+G|0)>>>2;C=(d+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(A<<1)>>1]=(F+2+((E+2+(G*3|0)|0)>>>2)+(H<<1)|0)>>>2;G=(D+2+(F<<1)+H|0)>>>2&65535;b[g+(A+1<<1)>>1]=G;b[g+(y<<1)>>1]=G;G=(B+2+(D<<1)+F|0)>>>2&65535;b[g+(A+2<<1)>>1]=G;b[g+((y|1)<<1)>>1]=G;b[g+(k<<1)>>1]=G;G=(z+2+(B<<1)+D|0)>>>2&65535;b[g+(A+3<<1)>>1]=G;b[g+(y+2<<1)>>1]=G;b[g+(k+1<<1)>>1]=G;b[g+(w<<1)>>1]=G;G=(i+2+(z<<1)+B|0)>>>2&65535;b[g+(A+4<<1)>>1]=G;b[g+(y+3<<1)>>1]=G;b[g+(k+2<<1)>>1]=G;b[g+((w|1)<<1)>>1]=G;b[g+(c<<1)>>1]=G;G=(f+2+(i<<1)+z|0)>>>2&65535;b[g+(A+5<<1)>>1]=G;b[g+(y+4<<1)>>1]=G;b[g+(k+3<<1)>>1]=G;b[g+((w|2)<<1)>>1]=G;b[g+(c+1<<1)>>1]=G;b[g+(v<<1)>>1]=G;G=((f<<1)+2+i+C|0)>>>2&65535;b[g+(A+6<<1)>>1]=G;b[g+(y+5<<1)>>1]=G;b[g+(k+4<<1)>>1]=G;b[g+((w|3)<<1)>>1]=G;b[g+(c+2<<1)>>1]=G;b[g+((v|1)<<1)>>1]=G;b[g+(h<<1)>>1]=G;G=l+2|0;i=(G+f+(C<<1)|0)>>>2&65535;b[g+(A+7<<1)>>1]=i;b[g+(y+6<<1)>>1]=i;b[g+(k+5<<1)>>1]=i;b[g+(w+4<<1)>>1]=i;b[g+(c+3<<1)>>1]=i;b[g+(v+2<<1)>>1]=i;b[g+(h+1<<1)>>1]=i;b[g>>1]=i;i=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+7<<1)>>1]=i;b[g+(k+6<<1)>>1]=i;b[g+(w+5<<1)>>1]=i;b[g+(c+4<<1)>>1]=i;b[g+(v+3<<1)>>1]=i;b[g+(h+2<<1)>>1]=i;b[a+2>>1]=i;i=(G+(m<<1)+o|0)>>>2&65535;b[g+(k+7<<1)>>1]=i;b[g+(w+6<<1)>>1]=i;b[g+(c+5<<1)>>1]=i;b[g+(v+4<<1)>>1]=i;b[g+(h+3<<1)>>1]=i;b[a+4>>1]=i;i=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(w+7<<1)>>1]=i;b[g+(c+6<<1)>>1]=i;b[g+(v+5<<1)>>1]=i;b[g+(h+4<<1)>>1]=i;b[a+6>>1]=i;i=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(c+7<<1)>>1]=i;b[g+(v+6<<1)>>1]=i;b[g+(h+5<<1)>>1]=i;b[a+8>>1]=i;i=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(v+7<<1)>>1]=i;b[g+(h+6<<1)>>1]=i;b[a+10>>1]=i;i=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(h+7<<1)>>1]=i;b[a+12>>1]=i;b[a+14>>1]=(r+2+(t<<1)+(((u&65535)+2+(s<<1)+n|0)>>>2)|0)>>>2;return}function bka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}k=((u&65535)+2+(s<<1)+n|0)>>>2;if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;n=e[g+(v-1<<1)>>1]|0;s=i+2|0;i=(s+(w<<1)+n|0)>>>2;u=h*3|0;d=e[g+(u-1<<1)>>1]|0;c=(w+2+(n<<1)+d|0)>>>2;w=h<<2;y=e[g+(w-1<<1)>>1]|0;z=(n+2+(d<<1)+y|0)>>>2;n=h*5|0;A=e[g+(n-1<<1)>>1]|0;B=(d+2+(y<<1)+A|0)>>>2;d=h*6|0;C=e[g+(d-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*7|0;E=(A+2+(C<<1)+(e[g+(y-1<<1)>>1]|0)|0)>>>2;C=(s+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(d<<1)>>1]=(z+2+(B<<1)+D|0)>>>2;b[g+(y<<1)>>1]=(B+2+(D<<1)+E|0)>>>2;E=(i+2+(c<<1)+z|0)>>>2&65535;b[g+((d|1)<<1)>>1]=E;b[g+(w<<1)>>1]=E;E=(c+2+(z<<1)+B|0)>>>2&65535;b[g+(y+1<<1)>>1]=E;b[g+(n<<1)>>1]=E;E=((f<<1)+2+i+C|0)>>>2&65535;b[g+(d+2<<1)>>1]=E;b[g+((w|1)<<1)>>1]=E;b[g+(v<<1)>>1]=E;E=(f+2+(i<<1)+c|0)>>>2&65535;b[g+(y+2<<1)>>1]=E;b[g+(n+1<<1)>>1]=E;b[g+(u<<1)>>1]=E;E=l+2|0;c=(E+f+(C<<1)|0)>>>2&65535;b[g+(y+3<<1)>>1]=c;b[g+(n+2<<1)>>1]=c;b[g+(u+1<<1)>>1]=c;b[g+(h<<1)>>1]=c;c=l+1|0;f=(c+C|0)>>>1&65535;b[g+(d+3<<1)>>1]=f;b[g+((w|2)<<1)>>1]=f;b[g+((v|1)<<1)>>1]=f;b[g>>1]=f;f=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+4<<1)>>1]=f;b[g+(n+3<<1)>>1]=f;b[g+(u+2<<1)>>1]=f;b[g+(h+1<<1)>>1]=f;f=(c+m|0)>>>1&65535;b[g+(d+4<<1)>>1]=f;b[g+((w|3)<<1)>>1]=f;b[g+(v+2<<1)>>1]=f;b[a+2>>1]=f;f=(E+(m<<1)+o|0)>>>2&65535;b[g+(y+5<<1)>>1]=f;b[g+(n+4<<1)>>1]=f;b[g+(u+3<<1)>>1]=f;b[g+(h+2<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[g+(d+5<<1)>>1]=f;b[g+(w+4<<1)>>1]=f;b[g+(v+3<<1)>>1]=f;b[a+4>>1]=f;f=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(y+6<<1)>>1]=f;b[g+(n+5<<1)>>1]=f;b[g+(u+4<<1)>>1]=f;b[g+(h+3<<1)>>1]=f;f=(o+1+p|0)>>>1&65535;b[g+(d+6<<1)>>1]=f;b[g+(w+5<<1)>>1]=f;b[g+(v+4<<1)>>1]=f;b[a+6>>1]=f;f=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(y+7<<1)>>1]=f;b[g+(n+6<<1)>>1]=f;b[g+(u+5<<1)>>1]=f;b[g+(h+4<<1)>>1]=f;f=(p+1+q|0)>>>1&65535;b[g+(d+7<<1)>>1]=f;b[g+(w+6<<1)>>1]=f;b[g+(v+5<<1)>>1]=f;b[a+8>>1]=f;f=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(n+7<<1)>>1]=f;b[g+(u+6<<1)>>1]=f;b[g+(h+5<<1)>>1]=f;f=(q+1+r|0)>>>1&65535;b[g+(w+7<<1)>>1]=f;b[g+(v+6<<1)>>1]=f;b[a+10>>1]=f;f=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(u+7<<1)>>1]=f;b[g+(h+6<<1)>>1]=f;f=(r+1+t|0)>>>1&65535;b[g+(v+7<<1)>>1]=f;b[a+12>>1]=f;b[g+(h+7<<1)>>1]=(r+2+(t<<1)+k|0)>>>2;b[a+14>>1]=(t+1+k|0)>>>1;return}function cka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=a;g=f>>1;f=(c|0)!=0;c=-g|0;h=~g;i=e[d+(c<<1)>>1]|0;j=e[d+(1-g<<1)>>1]|0;k=((e[d+((f?h:c)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;c=e[d+(2-g<<1)>>1]|0;l=(i+2+(j<<1)+c|0)>>>2;m=e[d+(3-g<<1)>>1]|0;n=(j+2+(c<<1)+m|0)>>>2;j=e[d+(4-g<<1)>>1]|0;o=(c+2+(m<<1)+j|0)>>>2;c=e[d+(5-g<<1)>>1]|0;p=(m+2+(j<<1)+c|0)>>>2;m=e[d+(6-g<<1)>>1]|0;q=(j+2+(c<<1)+m|0)>>>2;j=(c+2+(m<<1)+(e[d+(7-g<<1)>>1]|0)|0)>>>2;if(f){f=d+(h<<1)|0;r=f;s=a-2|0;t=f}else{f=a-2|0;r=f;s=f;t=d+(h<<1)|0}h=e[s>>1]|0;s=e[d+(g-1<<1)>>1]|0;f=((e[r>>1]|0)+2+(h<<1)+s|0)>>>2;r=g<<1;m=e[d+(r-1<<1)>>1]|0;c=h+2|0;h=(c+(s<<1)+m|0)>>>2;u=g*3|0;v=e[d+(u-1<<1)>>1]|0;w=(s+2+(m<<1)+v|0)>>>2;s=g<<2;x=e[d+(s-1<<1)>>1]|0;y=(m+2+(v<<1)+x|0)>>>2;m=g*5|0;z=e[d+(m-1<<1)>>1]|0;A=(v+2+(x<<1)+z|0)>>>2;v=g*6|0;B=e[d+(v-1<<1)>>1]|0;C=(x+2+(z<<1)+B|0)>>>2;x=g*7|0;D=e[d+(x-1<<1)>>1]|0;E=(z+2+(B<<1)+D|0)>>>2;z=(B+2+(D*3|0)|0)>>>2;D=(c+((e[t>>1]|0)<<1)+i|0)>>>2;b[d+(x<<1)>>1]=(z+1+E|0)>>>1;b[d+(x+1<<1)>>1]=(C+2+z+(E<<1)|0)>>>2;z=(C+1+E|0)>>>1&65535;b[d+(x+2<<1)>>1]=z;b[d+(v<<1)>>1]=z;z=(A+2+(C<<1)+E|0)>>>2&65535;b[d+(x+3<<1)>>1]=z;b[d+((v|1)<<1)>>1]=z;z=(A+1+C|0)>>>1&65535;b[d+(x+4<<1)>>1]=z;b[d+(v+2<<1)>>1]=z;b[d+(m<<1)>>1]=z;z=(y+2+(A<<1)+C|0)>>>2&65535;b[d+(x+5<<1)>>1]=z;b[d+(v+3<<1)>>1]=z;b[d+(m+1<<1)>>1]=z;z=(y+1+A|0)>>>1&65535;b[d+(x+6<<1)>>1]=z;b[d+(v+4<<1)>>1]=z;b[d+(m+2<<1)>>1]=z;b[d+(s<<1)>>1]=z;z=(w+2+(y<<1)+A|0)>>>2&65535;b[d+(x+7<<1)>>1]=z;b[d+(v+5<<1)>>1]=z;b[d+(m+3<<1)>>1]=z;b[d+((s|1)<<1)>>1]=z;z=(w+1+y|0)>>>1&65535;b[d+(v+6<<1)>>1]=z;b[d+(m+4<<1)>>1]=z;b[d+((s|2)<<1)>>1]=z;b[d+(u<<1)>>1]=z;z=(h+2+(w<<1)+y|0)>>>2&65535;b[d+(v+7<<1)>>1]=z;b[d+(m+5<<1)>>1]=z;b[d+((s|3)<<1)>>1]=z;b[d+(u+1<<1)>>1]=z;z=(h+1+w|0)>>>1&65535;b[d+(m+6<<1)>>1]=z;b[d+(s+4<<1)>>1]=z;b[d+(u+2<<1)>>1]=z;b[d+(r<<1)>>1]=z;z=(f+2+(h<<1)+w|0)>>>2&65535;b[d+(m+7<<1)>>1]=z;b[d+(s+5<<1)>>1]=z;b[d+(u+3<<1)>>1]=z;b[d+((r|1)<<1)>>1]=z;z=f+1|0;m=(z+h|0)>>>1&65535;b[d+(s+6<<1)>>1]=m;b[d+(u+4<<1)>>1]=m;b[d+(r+2<<1)>>1]=m;b[d+(g<<1)>>1]=m;m=((f<<1)+2+h+D|0)>>>2&65535;b[d+(s+7<<1)>>1]=m;b[d+(u+5<<1)>>1]=m;b[d+(r+3<<1)>>1]=m;b[d+(g+1<<1)>>1]=m;m=(z+D|0)>>>1&65535;b[d+(u+6<<1)>>1]=m;b[d+(r+4<<1)>>1]=m;b[d+(g+2<<1)>>1]=m;b[d>>1]=m;m=k+2|0;z=(m+f+(D<<1)|0)>>>2&65535;b[d+(u+7<<1)>>1]=z;b[d+(r+5<<1)>>1]=z;b[d+(g+3<<1)>>1]=z;b[a+2>>1]=z;z=((k<<1)+2+l+D|0)>>>2&65535;b[d+(r+6<<1)>>1]=z;b[d+(g+4<<1)>>1]=z;b[a+4>>1]=z;z=(m+(l<<1)+n|0)>>>2&65535;b[d+(r+7<<1)>>1]=z;b[d+(g+5<<1)>>1]=z;b[a+6>>1]=z;z=(l+2+(n<<1)+o|0)>>>2&65535;b[d+(g+6<<1)>>1]=z;b[a+8>>1]=z;z=(n+2+(o<<1)+p|0)>>>2&65535;b[d+(g+7<<1)>>1]=z;b[a+10>>1]=z;b[a+12>>1]=(o+2+(p<<1)+q|0)>>>2;b[a+14>>1]=(p+2+(q<<1)+j|0)>>>2;return}function dka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;f=e[g+(2-h<<1)>>1]|0;c=(i+2+(j<<1)+f|0)>>>2;i=e[g+(3-h<<1)>>1]|0;l=(j+2+(f<<1)+i|0)>>>2;j=e[g+(4-h<<1)>>1]|0;m=(f+2+(i<<1)+j|0)>>>2;f=e[g+(5-h<<1)>>1]|0;n=(i+2+(j<<1)+f|0)>>>2;i=e[g+(6-h<<1)>>1]|0;o=(j+2+(f<<1)+i|0)>>>2;j=b[g+(7-h<<1)>>1]|0;p=j&65535;q=(f+2+(i<<1)+p|0)>>>2;if((d|0)==0){r=p;s=p;t=p;u=p;v=p;w=(j&65535)+2+(p<<1)|0}else{j=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;f=e[g+(10-h<<1)>>1]|0;x=e[g+(11-h<<1)>>1]|0;y=e[g+(12-h<<1)>>1]|0;r=(x+2+(y<<1)+(e[g+(13-h<<1)>>1]|0)|0)>>>2;s=(f+2+(x<<1)+y|0)>>>2;t=(d+2+(f<<1)+x|0)>>>2;u=(j+2+(d<<1)+f|0)>>>2;v=(p+2+(j<<1)+d|0)>>>2;w=(e[g+(8-h<<1)>>1]|0)+2+(p<<1)|0}p=(w+i|0)>>>2;b[g>>1]=(k+1+c|0)>>>1;b[g+(h<<1)>>1]=(k+2+(c<<1)+l|0)>>>2;k=(c+1+l|0)>>>1&65535;b[a+2>>1]=k;i=h<<1;b[g+(i<<1)>>1]=k;k=(c+2+(l<<1)+m|0)>>>2&65535;b[g+(h+1<<1)>>1]=k;c=h*3|0;b[g+(c<<1)>>1]=k;k=(l+1+m|0)>>>1&65535;b[a+4>>1]=k;b[g+((i|1)<<1)>>1]=k;w=h<<2;b[g+(w<<1)>>1]=k;k=(l+2+(m<<1)+n|0)>>>2&65535;b[g+(h+2<<1)>>1]=k;b[g+(c+1<<1)>>1]=k;l=h*5|0;b[g+(l<<1)>>1]=k;k=(m+1+n|0)>>>1&65535;b[a+6>>1]=k;b[g+(i+2<<1)>>1]=k;b[g+((w|1)<<1)>>1]=k;d=h*6|0;b[g+(d<<1)>>1]=k;k=(m+2+(n<<1)+o|0)>>>2&65535;b[g+(h+3<<1)>>1]=k;b[g+(c+2<<1)>>1]=k;b[g+(l+1<<1)>>1]=k;m=h*7|0;b[g+(m<<1)>>1]=k;k=(n+1+o|0)>>>1&65535;b[a+8>>1]=k;b[g+(i+3<<1)>>1]=k;b[g+((w|2)<<1)>>1]=k;b[g+((d|1)<<1)>>1]=k;k=(n+2+(o<<1)+q|0)>>>2&65535;b[g+(h+4<<1)>>1]=k;b[g+(c+3<<1)>>1]=k;b[g+(l+2<<1)>>1]=k;b[g+(m+1<<1)>>1]=k;k=(o+1+q|0)>>>1&65535;b[a+10>>1]=k;b[g+(i+4<<1)>>1]=k;b[g+((w|3)<<1)>>1]=k;b[g+(d+2<<1)>>1]=k;k=(o+2+(q<<1)+p|0)>>>2&65535;b[g+(h+5<<1)>>1]=k;b[g+(c+4<<1)>>1]=k;b[g+(l+3<<1)>>1]=k;b[g+(m+2<<1)>>1]=k;k=(q+1+p|0)>>>1&65535;b[a+12>>1]=k;b[g+(i+5<<1)>>1]=k;b[g+(w+4<<1)>>1]=k;b[g+(d+3<<1)>>1]=k;k=(q+2+(p<<1)+v|0)>>>2&65535;b[g+(h+6<<1)>>1]=k;b[g+(c+5<<1)>>1]=k;b[g+(l+4<<1)>>1]=k;b[g+(m+3<<1)>>1]=k;k=(p+1+v|0)>>>1&65535;b[a+14>>1]=k;b[g+(i+6<<1)>>1]=k;b[g+(w+5<<1)>>1]=k;b[g+(d+4<<1)>>1]=k;k=(p+2+(v<<1)+u|0)>>>2&65535;b[g+(h+7<<1)>>1]=k;b[g+(c+6<<1)>>1]=k;b[g+(l+5<<1)>>1]=k;b[g+(m+4<<1)>>1]=k;k=(v+1+u|0)>>>1&65535;b[g+(i+7<<1)>>1]=k;b[g+(w+6<<1)>>1]=k;b[g+(d+5<<1)>>1]=k;k=(v+2+(u<<1)+t|0)>>>2&65535;b[g+(c+7<<1)>>1]=k;b[g+(l+6<<1)>>1]=k;b[g+(m+5<<1)>>1]=k;k=(u+1+t|0)>>>1&65535;b[g+(w+7<<1)>>1]=k;b[g+(d+6<<1)>>1]=k;k=(u+2+(t<<1)+s|0)>>>2&65535;b[g+(l+7<<1)>>1]=k;b[g+(m+6<<1)>>1]=k;b[g+(d+7<<1)>>1]=(t+1+s|0)>>>1;b[g+(m+7<<1)>>1]=(t+2+(s<<1)+r|0)>>>2;return}function eka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a;g=f>>1;if((c|0)==0){c=a-2|0;h=c;i=c}else{h=d+(~g<<1)|0;i=a-2|0}c=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=((e[h>>1]|0)+2+(c<<1)+i|0)>>>2;h=g<<1;j=e[d+(h-1<<1)>>1]|0;k=(c+2+(i<<1)+j|0)>>>2;c=g*3|0;l=e[d+(c-1<<1)>>1]|0;m=(i+2+(j<<1)+l|0)>>>2;i=g<<2;n=e[d+(i-1<<1)>>1]|0;o=(j+2+(l<<1)+n|0)>>>2;j=g*5|0;p=e[d+(j-1<<1)>>1]|0;q=(l+2+(n<<1)+p|0)>>>2;l=g*6|0;r=e[d+(l-1<<1)>>1]|0;s=(n+2+(p<<1)+r|0)>>>2;n=g*7|0;t=e[d+(n-1<<1)>>1]|0;u=(p+2+(r<<1)+t|0)>>>2;p=(r+2+(t*3|0)|0)>>>2;b[d>>1]=(f+1+k|0)>>>1;b[a+2>>1]=(f+2+(k<<1)+m|0)>>>2;f=(k+1+m|0)>>>1&65535;b[a+4>>1]=f;b[d+(g<<1)>>1]=f;f=(k+2+(m<<1)+o|0)>>>2&65535;b[a+6>>1]=f;b[d+(g+1<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[a+8>>1]=f;b[d+(g+2<<1)>>1]=f;b[d+(h<<1)>>1]=f;f=(m+2+(o<<1)+q|0)>>>2&65535;b[a+10>>1]=f;b[d+(g+3<<1)>>1]=f;b[d+((h|1)<<1)>>1]=f;f=(o+1+q|0)>>>1&65535;b[a+12>>1]=f;b[d+(g+4<<1)>>1]=f;b[d+(h+2<<1)>>1]=f;b[d+(c<<1)>>1]=f;f=(o+2+(q<<1)+s|0)>>>2&65535;b[a+14>>1]=f;b[d+(g+5<<1)>>1]=f;b[d+(h+3<<1)>>1]=f;b[d+(c+1<<1)>>1]=f;f=(q+1+s|0)>>>1&65535;b[d+(g+6<<1)>>1]=f;b[d+(h+4<<1)>>1]=f;b[d+(c+2<<1)>>1]=f;b[d+(i<<1)>>1]=f;f=(q+2+(s<<1)+u|0)>>>2&65535;b[d+(g+7<<1)>>1]=f;b[d+(h+5<<1)>>1]=f;b[d+(c+3<<1)>>1]=f;b[d+((i|1)<<1)>>1]=f;f=(s+1+u|0)>>>1&65535;b[d+(h+6<<1)>>1]=f;b[d+(c+4<<1)>>1]=f;b[d+((i|2)<<1)>>1]=f;b[d+(j<<1)>>1]=f;f=(s+2+p+(u<<1)|0)>>>2&65535;b[d+(h+7<<1)>>1]=f;b[d+(c+5<<1)>>1]=f;b[d+((i|3)<<1)>>1]=f;b[d+(j+1<<1)>>1]=f;f=(p+1+u|0)>>>1&65535;b[d+(c+6<<1)>>1]=f;b[d+(i+4<<1)>>1]=f;b[d+(j+2<<1)>>1]=f;b[d+(l<<1)>>1]=f;f=(u+2+(p*3|0)|0)>>>2&65535;b[d+(c+7<<1)>>1]=f;b[d+(i+5<<1)>>1]=f;b[d+(j+3<<1)>>1]=f;b[d+((l|1)<<1)>>1]=f;f=p&65535;b[d+(n+7<<1)>>1]=f;b[d+(l+7<<1)>>1]=f;b[d+(j+7<<1)>>1]=f;b[d+(i+7<<1)>>1]=f;b[d+(n+6<<1)>>1]=f;b[d+(l+6<<1)>>1]=f;b[d+(j+6<<1)>>1]=f;b[d+(i+6<<1)>>1]=f;b[d+(n+5<<1)>>1]=f;b[d+(l+5<<1)>>1]=f;b[d+(j+5<<1)>>1]=f;b[d+(n+4<<1)>>1]=f;b[d+(l+4<<1)>>1]=f;b[d+(j+4<<1)>>1]=f;b[d+(n+3<<1)>>1]=f;b[d+(l+3<<1)>>1]=f;b[d+(n+2<<1)>>1]=f;b[d+(l+2<<1)>>1]=f;b[d+(n+1<<1)>>1]=f;b[d+(n<<1)>>1]=f;return}function fka(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=e[d+((g<<1)-1<<1)>>1]|0;j=e[d+((g*3|0)-1<<1)>>1]|0;k=e[d+((g<<2)-1<<1)>>1]|0;l=e[d+((g*5|0)-1<<1)>>1]|0;m=e[d+((g*6|0)-1<<1)>>1]|0;n=e[d+((g*7|0)-1<<1)>>1]|0;o=(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2)+4+((b+2+(i<<1)+f|0)>>>2)+((i+2+(f<<1)+j|0)>>>2)+((f+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n*3|0)|0)>>>2)>>3;n=gHb(o,(o|0)<0|0?-1:0,65537,65537)|0;o=F;m=a;c[m>>2]=n;c[m+4>>2]=o;m=a+8|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=g<<1;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;g=d+(a<<1)|0;c[g>>2]=n;c[g+4>>2]=o;g=d+(a+4<<1)|0;c[g>>2]=n;c[g+4>>2]=o;return}function gka(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}q=(((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2)+4+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+r|0)>>>2)+(((s&65535)+2+(r<<1)+p|0)>>>2)>>3;p=gHb(q,(q|0)<0|0?-1:0,65537,65537)|0;q=F;r=a;c[r>>2]=p;c[r+4>>2]=q;r=a+8|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=i<<1;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;i=h+(a<<1)|0;c[i>>2]=p;c[i+4>>2]=q;i=h+(a+4<<1)|0;c[i>>2]=p;c[i+4>>2]=q;return}function hka(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;b=e>>1;e=a;c[e>>2]=33554944;c[e+4>>2]=33554944;e=a+8|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(b<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(b+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=b<<1;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e+b|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;return}function ika(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function jka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=gHb(e[a-2>>1]|0,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=a+8|0;c[h>>2]=b;c[h+4>>2]=g;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;b=d+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(f+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f<<1;b=gHb(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=F;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*3|0;a=gHb(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;b=F;h=d+(g<<1)|0;c[h>>2]=a;c[h+4>>2]=b;h=d+(g+4<<1)|0;c[h>>2]=a;c[h+4>>2]=b;b=f<<2;h=gHb(e[d+(b-1<<1)>>1]|0,0,65537,65537)|0;a=F;g=d+(b<<1)|0;c[g>>2]=h;c[g+4>>2]=a;g=d+(b+4<<1)|0;c[g>>2]=h;c[g+4>>2]=a;a=f*5|0;g=gHb(e[d+(a-1<<1)>>1]|0,0,65537,65537)|0;h=F;b=d+(a<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(a+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f*6|0;b=gHb(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=F;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*7|0;f=gHb(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;a=F;b=d+(g<<1)|0;c[b>>2]=f;c[b+4>>2]=a;b=d+(g+4<<1)|0;c[b>>2]=f;c[b+4>>2]=a;return}function kka(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<3;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+((b|4)<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*9|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*10|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*11|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*12|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*13|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*14|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*15|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function lka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ba(b,a)|0;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function mka(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a;f=c>>1;c=a+6|0;g=(f<<2)-1|0;h=g-(f<<1)|0;i=g+f|0;j=h-f|0;k=i+f|0;l=j-f|0;m=e[d+(k+f<<1)>>1]|0;n=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=(((m-(e[d+(l-f<<1)>>1]|0)<<2)+((((e[d+(k<<1)>>1]|0)-(e[d+(l<<1)>>1]|0)|0)*3|0)+(((e[d+(i<<1)>>1]|0)-(e[d+(j<<1)>>1]|0)<<1)+((e[d+(g<<1)>>1]|0)-(e[d+(h<<1)>>1]|0))))|0)*17|0)+16>>5;h=n<<1;g=n*3|0;j=n<<2;i=n*5|0;l=n*6|0;k=n*7|0;o=d;d=((c+n|0)*-3|0)+16+((e[a-2+(8-f<<1)>>1]|0)+m<<4)|0;m=8;while(1){a=d>>5;if(a>>>0<1024>>>0){p=a&65535}else{p=-a>>31&1023}b[o>>1]=p;a=d+n>>5;if(a>>>0<1024>>>0){q=a&65535}else{q=-a>>31&1023}b[o+2>>1]=q;a=d+h>>5;if(a>>>0<1024>>>0){r=a&65535}else{r=-a>>31&1023}b[o+4>>1]=r;a=d+g>>5;if(a>>>0<1024>>>0){s=a&65535}else{s=-a>>31&1023}b[o+6>>1]=s;a=d+j>>5;if(a>>>0<1024>>>0){t=a&65535}else{t=-a>>31&1023}b[o+8>>1]=t;a=d+i>>5;if(a>>>0<1024>>>0){u=a&65535}else{u=-a>>31&1023}b[o+10>>1]=u;a=d+l>>5;if(a>>>0<1024>>>0){v=a&65535}else{v=-a>>31&1023}b[o+12>>1]=v;a=d+k>>5;if(a>>>0<1024>>>0){w=a&65535}else{w=-a>>31&1023}b[o+14>>1]=w;a=m-1|0;if((a|0)>0){o=o+(f<<1)|0;d=d+c|0;m=a}else{break}}return}function nka(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a;f=c>>1;c=a+6|0;g=-f|0;h=(f<<3)-1|0;i=h-(f<<1)|0;j=h+f|0;k=i-f|0;l=j+f|0;m=k-f|0;n=a+((f*6|0)-2)|0;o=a+((f*22|0)-2)|0;p=f<<1;q=g<<1;r=p+f|0;s=q-f|0;t=b[o+(r+f<<1)>>1]|0;u=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=((((t&65535)-(e[n+(s-f<<1)>>1]|0)<<3)+((((e[o+(r<<1)>>1]|0)-(e[n+(s<<1)>>1]|0)|0)*7|0)+((((e[o+(p<<1)>>1]|0)-(e[n+(q<<1)>>1]|0)|0)*6|0)+((((e[o+(f<<1)>>1]|0)-(e[n+(g<<1)>>1]|0)|0)*5|0)+(((e[d+(l+f<<1)>>1]|0)-(e[d+(m-f<<1)>>1]|0)<<2)+((((e[d+(l<<1)>>1]|0)-(e[d+(m<<1)>>1]|0)|0)*3|0)+(((e[d+(j<<1)>>1]|0)-(e[d+(k<<1)>>1]|0)<<1)+((e[d+(h<<1)>>1]|0)-(e[d+(i<<1)>>1]|0))))))))|0)*5|0)+32>>6;i=u*3|0;h=u<<1;k=u<<2;j=u*5|0;m=u*6|0;l=u*7|0;g=d;d=16-i+(c*-7|0)+((e[a+(-2-(f<<1)+16)>>1]|0)+(t&65535)<<4)|0;t=16;while(1){a=d>>5;if(a>>>0<1024>>>0){v=a&65535}else{v=-a>>31&1023}b[g>>1]=v;a=d+u>>5;if(a>>>0<1024>>>0){w=a&65535}else{w=-a>>31&1023}b[g+2>>1]=w;a=d+h>>5;if(a>>>0<1024>>>0){x=a&65535}else{x=-a>>31&1023}b[g+4>>1]=x;a=d+i>>5;if(a>>>0<1024>>>0){y=a&65535}else{y=-a>>31&1023}b[g+6>>1]=y;a=d+k>>5;if(a>>>0<1024>>>0){z=a&65535}else{z=-a>>31&1023}b[g+8>>1]=z;a=d+j>>5;if(a>>>0<1024>>>0){A=a&65535}else{A=-a>>31&1023}b[g+10>>1]=A;a=d+m>>5;if(a>>>0<1024>>>0){B=a&65535}else{B=-a>>31&1023}b[g+12>>1]=B;a=d+l>>5;if(a>>>0<1024>>>0){C=a&65535}else{C=-a>>31&1023}b[g+14>>1]=C;a=t-1|0;if((a|0)>0){g=g+(f<<1)|0;d=d+c|0;t=a}else{break}}return}function oka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=(e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+(e[d+(4-f<<1)>>1]|0)))|0;l=f*7|0;m=(e[d+(l-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;n=(e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+((e[a-2>>1]|0)+(e[d+(-f<<1)>>1]|0))+(e[d+(1-f<<1)>>1]|0))+(e[d+(2-f<<1)>>1]|0))+(e[d+(3-f<<1)>>1]|0)+4>>3;o=gHb(n,(n|0)<0|0?-1:0,65537,65537)|0;n=F;p=gHb((k+2|0)>>>2,0,65537,65537)|0;q=F;r=m+4+k>>3;k=a;c[k>>2]=o;c[k+4>>2]=n;k=a+8|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(f<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(f+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(h<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(h+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(j<<1)|0;c[k>>2]=o;c[k+4>>2]=n;n=d+(j+4<<1)|0;c[n>>2]=p;c[n+4>>2]=q;q=gHb((m+2|0)>>>2,0,65537,65537)|0;m=F;n=gHb(r,(r|0)<0|0?-1:0,65537,65537)|0;r=F;p=d+(b<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(b+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(g<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(g+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(i<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(i+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(l<<1)|0;c[p>>2]=q;c[p+4>>2]=m;m=d+(l+4<<1)|0;c[m>>2]=n;c[m+4>>2]=r;return}function pka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=f*7|0;l=(e[d+(k-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;m=gHb(((e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))+2|0)>>>2,0,65537,65537)|0;n=F;o=a;c[o>>2]=m;c[o+4>>2]=n;o=a+8|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;n=gHb((l+2|0)>>>2,0,65537,65537)|0;l=F;o=d+(b<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(b+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;return}function qka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=gHb(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=F;i=gHb((g+2|0)>>>2,0,65537,65537)|0;g=F;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function rka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;qka(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function ska(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;oka(a,b);d=a;f=b>>1;b=gHb(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function tka(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;pka(a,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=33554944;c[b+4>>2]=33554944;b=f+(g<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=g<<1;e=f+(b<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=33554944;c[h+4>>2]=33554944;h=a+(d+8)|0;d=h;a=h;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(g<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;return}function uka(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;pka(a,b);d=a;e=b>>1;b=a;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<1;f=d+(b<<1)|0;c[f>>2]=33554944;c[f+4>>2]=33554944;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=33554944;c[g+4>>2]=33554944;g=a+8|0;a=g;d=g;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(e<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(b<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(f<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;return}function vka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=0;g=0;h=0;i=0;j=0;k=0;do{l=e[d+((ba(k,f)|0)-1<<1)>>1]|0;j=l+j+(e[d+(k-f<<1)>>1]|0)|0;l=k+4|0;i=(e[d+(l-f<<1)>>1]|0)+i|0;h=(e[d+((ba(l,f)|0)-1<<1)>>1]|0)+h|0;g=(e[d+((ba(k+8|0,f)|0)-1<<1)>>1]|0)+g|0;b=(e[d+((ba(k+12|0,f)|0)-1<<1)>>1]|0)+b|0;k=k+1|0;}while((k|0)<4);k=j+4>>3;j=gHb(k,(k|0)<0|0?-1:0,65537,65537)|0;k=F;l=i+2>>2;m=gHb(l,(l|0)<0|0?-1:0,65537,65537)|0;l=F;n=h+2>>2;o=h+4+i>>3;h=g+2>>2;p=g+4+i>>3;g=b+2>>2;q=b+4+i>>3;i=a;c[i>>2]=j;c[i+4>>2]=k;i=a+8|0;c[i>>2]=m;c[i+4>>2]=l;i=d+(f<<1)|0;c[i>>2]=j;c[i+4>>2]=k;i=d+(f+4<<1)|0;c[i>>2]=m;c[i+4>>2]=l;i=f<<1;a=d+(i<<1)|0;c[a>>2]=j;c[a+4>>2]=k;a=d+(i+4<<1)|0;c[a>>2]=m;c[a+4>>2]=l;a=f*3|0;i=d+(a<<1)|0;c[i>>2]=j;c[i+4>>2]=k;k=d+(a+4<<1)|0;c[k>>2]=m;c[k+4>>2]=l;l=gHb(n,(n|0)<0|0?-1:0,65537,65537)|0;n=F;k=gHb(o,(o|0)<0|0?-1:0,65537,65537)|0;o=F;m=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;a=gHb(p,(p|0)<0|0?-1:0,65537,65537)|0;p=F;i=gHb(g,(g|0)<0|0?-1:0,65537,65537)|0;g=F;j=gHb(q,(q|0)<0|0?-1:0,65537,65537)|0;q=F;b=f<<2;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*5|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;b=d+(r+4<<1)|0;c[b>>2]=k;c[b+4>>2]=o;b=f*6|0;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*7|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;n=d+(r+4<<1)|0;c[n>>2]=k;c[n+4>>2]=o;o=f<<3;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+((o|4)<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*9|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;o=d+(n+4<<1)|0;c[o>>2]=a;c[o+4>>2]=p;o=f*10|0;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+(o+4<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*11|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;h=d+(n+4<<1)|0;c[h>>2]=a;c[h+4>>2]=p;p=f*12|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*13|0;p=d+(h<<1)|0;c[p>>2]=i;c[p+4>>2]=g;p=d+(h+4<<1)|0;c[p>>2]=j;c[p+4>>2]=q;p=f*14|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*15|0;f=d+(h<<1)|0;c[f>>2]=i;c[f+4>>2]=g;g=d+(h+4<<1)|0;c[g>>2]=j;c[g+4>>2]=q;return}function wka(a,b){a=a|0;b=b|0;pka(a,b);pka(a+(b<<3)|0,b);return}function xka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=gHb(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=F;i=gHb((g+2|0)>>>2,0,65537,65537)|0;g=F;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<3;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+((j|4)<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*9|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*10|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*11|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*12|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*13|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*14|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*15|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function yka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;xka(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function zka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;vka(a,b);d=a;f=b>>1;b=gHb(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function Aka(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;pka(a,b);pka(a+(b<<3)|0,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=33554944;c[b+4>>2]=33554944;b=f+(g<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=g<<1;e=f+(b<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=33554944;c[h+4>>2]=33554944;h=a+(d+8)|0;d=h;a=h;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(g<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;return}function Bka(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;pka(a,b);pka(a+(b<<3)|0,b);d=a;e=b>>1;b=a;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<1;f=d+(b<<1)|0;c[f>>2]=33554944;c[f+4>>2]=33554944;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=33554944;c[g+4>>2]=33554944;g=a+8|0;a=g;d=g;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(e<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(b<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(f<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;return}function Cka(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+8|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=e<<2;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;e=d+(a+4<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;return}function Dka(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+8|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=e<<2;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;e=d+(a+4<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;return}function Eka(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+8|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<2;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;return}function Fka(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=b>>1;f=a;c[f>>2]=33554944;c[f+4>>2]=33554944;f=a+8|0;c[f>>2]=33554944;c[f+4>>2]=33554944;f=d+(e<<1)|0;c[f>>2]=33554944;c[f+4>>2]=33554944;f=e+4|0;g=d+(f<<1)|0;c[g>>2]=33554944;c[g+4>>2]=33554944;g=e<<1;h=d+(g<<1)|0;c[h>>2]=33554944;c[h+4>>2]=33554944;h=g+4|0;i=d+(h<<1)|0;c[i>>2]=33554944;c[i+4>>2]=33554944;i=e*3|0;j=d+(i<<1)|0;c[j>>2]=33554944;c[j+4>>2]=33554944;j=i+4|0;k=d+(j<<1)|0;c[k>>2]=33554944;c[k+4>>2]=33554944;k=e<<2;l=d+(k<<1)|0;c[l>>2]=33554944;c[l+4>>2]=33554944;l=k+4|0;m=d+(l<<1)|0;c[m>>2]=33554944;c[m+4>>2]=33554944;m=e*5|0;n=d+(m<<1)|0;c[n>>2]=33554944;c[n+4>>2]=33554944;n=m+4|0;o=d+(n<<1)|0;c[o>>2]=33554944;c[o+4>>2]=33554944;o=e*6|0;p=d+(o<<1)|0;c[p>>2]=33554944;c[p+4>>2]=33554944;p=o+4|0;q=d+(p<<1)|0;c[q>>2]=33554944;c[q+4>>2]=33554944;q=e*7|0;r=d+(q<<1)|0;c[r>>2]=33554944;c[r+4>>2]=33554944;r=q+4|0;s=d+(r<<1)|0;c[s>>2]=33554944;c[s+4>>2]=33554944;s=b<<3;b=a+s|0;d=b;t=b;c[t>>2]=33554944;c[t+4>>2]=33554944;t=a+(s+8)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(e<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(f<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(g<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(h<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(i<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(j<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(k<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(l<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(m<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(n<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(o<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(p<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(q<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(r<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;return}function Gka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+((e[d+(-f<<1)>>1]|0)+((e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))))))))))))))))))+16>>5;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Hka(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a;a=b>>1;b=d+(-a<<1)|0;e=c[b>>2]|0;f=c[b+4>>2]|0;b=d+(4-a<<1)|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=d+(8-a<<1)|0;i=c[b>>2]|0;j=c[b+4>>2]|0;b=d+(12-a<<1)|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=0;do{m=ba(b,a)|0;n=d+(m<<1)|0;c[n>>2]=e;c[n+4>>2]=f;n=d+(m+4<<1)|0;c[n>>2]=g;c[n+4>>2]=h;n=d+(m+8<<1)|0;c[n>>2]=i;c[n+4>>2]=j;n=d+(m+12<<1)|0;c[n>>2]=k;c[n+4>>2]=l;b=b+1|0;}while((b|0)<16);return}function Ika(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ba(b,a)|0;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+8<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+12<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function Jka(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+8|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+16|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+24|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;e=d+(a+4<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;e=d+(a+8<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;e=d+(a+12<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;return}function Kka(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+8|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+16|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+24|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;e=d+(a+4<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;e=d+(a+8<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;e=d+(a+12<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;return}function Lka(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a;f=c>>1;c=a+14|0;g=-f|0;h=(f<<3)-1|0;i=d+(h<<1)|0;j=d+(h-(f<<1)<<1)|0;h=a+((f*30|0)-2)|0;k=2;l=i;m=j;n=(e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0)|0;o=(e[i>>1]|0)-(e[j>>1]|0)|0;do{l=l+(f<<1)|0;m=m+(g<<1)|0;n=(ba((e[c+(k-f<<1)>>1]|0)-(e[c+(-(f+k|0)<<1)>>1]|0)|0,k)|0)+n|0;o=(ba((e[l>>1]|0)-(e[m>>1]|0)|0,k)|0)+o|0;k=k+1|0;}while((k|0)<9);k=(n*5|0)+32>>6;n=(o*5|0)+32>>6;o=k<<1;m=k*3|0;l=k<<2;c=((n+k|0)*-7|0)+16+((e[a-2+(16-f<<1)>>1]|0)+(e[h>>1]|0)<<4)|0;h=d;d=16;while(1){a=-16;g=c;while(1){j=g>>5;if(j>>>0<1024>>>0){p=j&65535}else{p=-j>>31&1023}b[h+(a+16<<1)>>1]=p;j=g+k>>5;if(j>>>0<1024>>>0){q=j&65535}else{q=-j>>31&1023}b[h+(a+17<<1)>>1]=q;j=g+o>>5;if(j>>>0<1024>>>0){r=j&65535}else{r=-j>>31&1023}b[h+(a+18<<1)>>1]=r;j=g+m>>5;if(j>>>0<1024>>>0){s=j&65535}else{s=-j>>31&1023}b[h+(a+19<<1)>>1]=s;j=a+4|0;if((j|0)<0){a=j;g=g+l|0}else{break}}g=d-1|0;if((g|0)>0){c=c+n|0;h=h+(f<<1)|0;d=g}else{break}}return}function Mka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))+8>>4;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Nka(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))))))))))))))+8>>4;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Oka(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+8|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+16|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+24|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+8<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+12<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;return}function Pka(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a;h=f>>1;f=h<<1;i=h*3|0;j=h<<2;k=(e[g+(-h<<1)>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=k;l=k+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=l;k=l+(c[d+32>>2]|0)|0;b[g+(i-h<<1)>>1]=k;b[g+(j-h<<1)>>1]=k+(c[d+48>>2]|0);k=1-h|0;h=(e[g+(k<<1)>>1]|0)+(c[d+4>>2]|0)|0;b[a+2>>1]=h;l=h+(c[d+20>>2]|0)|0;b[g+(k+f<<1)>>1]=l;h=l+(c[d+36>>2]|0)|0;b[g+(k+i<<1)>>1]=h;b[g+(k+j<<1)>>1]=h+(c[d+52>>2]|0);h=k+1|0;l=(e[g+(h<<1)>>1]|0)+(c[d+8>>2]|0)|0;b[a+4>>1]=l;m=l+(c[d+24>>2]|0)|0;b[g+(h+f<<1)>>1]=m;l=m+(c[d+40>>2]|0)|0;b[g+(h+i<<1)>>1]=l;b[g+(h+j<<1)>>1]=l+(c[d+56>>2]|0);l=k+2|0;k=(e[g+(l<<1)>>1]|0)+(c[d+12>>2]|0)|0;b[a+6>>1]=k;a=k+(c[d+28>>2]|0)|0;b[g+(l+f<<1)>>1]=a;f=a+(c[d+44>>2]|0)|0;b[g+(l+i<<1)>>1]=f;b[g+(l+j<<1)>>1]=f+(c[d+60>>2]|0);TGb(d|0,0,64)|0;return}function Qka(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=a;h=f>>1;f=(e[a-2>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=f;i=f+(c[d+4>>2]|0)|0;b[a+2>>1]=i;f=i+(c[d+8>>2]|0)|0;b[a+4>>1]=f;b[a+6>>1]=f+(c[d+12>>2]|0);f=(e[g+(h-1<<1)>>1]|0)+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=f;a=f+(c[d+20>>2]|0)|0;b[g+(h+1<<1)>>1]=a;f=a+(c[d+24>>2]|0)|0;b[g+(h+2<<1)>>1]=f;b[g+(h+3<<1)>>1]=f+(c[d+28>>2]|0);f=h<<1;a=(e[g+(f-1<<1)>>1]|0)+(c[d+32>>2]|0)|0;b[g+(f<<1)>>1]=a;i=a+(c[d+36>>2]|0)|0;b[g+((f|1)<<1)>>1]=i;a=i+(c[d+40>>2]|0)|0;b[g+(f+2<<1)>>1]=a;b[g+(f+3<<1)>>1]=a+(c[d+44>>2]|0);a=f+h|0;h=(e[g+(a-1<<1)>>1]|0)+(c[d+48>>2]|0)|0;b[g+(a<<1)>>1]=h;f=h+(c[d+52>>2]|0)|0;b[g+(a+1<<1)>>1]=f;h=f+(c[d+56>>2]|0)|0;b[g+(a+2<<1)>>1]=h;b[g+(a+3<<1)>>1]=h+(c[d+60>>2]|0);TGb(d|0,0,64)|0;return}function Rka(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=g<<1;h=g*3|0;i=g<<2;j=g*5|0;k=g*6|0;l=g*7|0;m=g<<3;n=0;o=a+(-g<<1)|0;a=d;while(1){p=(e[o>>1]|0)+(c[a>>2]|0)|0;b[o+(g<<1)>>1]=p;q=p+(c[a+32>>2]|0)|0;b[o+(f<<1)>>1]=q;p=q+(c[a+64>>2]|0)|0;b[o+(h<<1)>>1]=p;q=p+(c[a+96>>2]|0)|0;b[o+(i<<1)>>1]=q;p=q+(c[a+128>>2]|0)|0;b[o+(j<<1)>>1]=p;q=p+(c[a+160>>2]|0)|0;b[o+(k<<1)>>1]=q;p=q+(c[a+192>>2]|0)|0;b[o+(l<<1)>>1]=p;b[o+(m<<1)>>1]=p+(c[a+224>>2]|0);p=n+1|0;if((p|0)<8){n=p;o=o+2|0;a=a+4|0}else{break}}TGb(d|0,0,256)|0;return}function Ska(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=f>>1;f=0;h=a;a=d;while(1){i=(e[h-2>>1]|0)+(c[a>>2]|0)|0;b[h>>1]=i;j=i+(c[a+4>>2]|0)|0;b[h+2>>1]=j;i=j+(c[a+8>>2]|0)|0;b[h+4>>1]=i;j=i+(c[a+12>>2]|0)|0;b[h+6>>1]=j;i=j+(c[a+16>>2]|0)|0;b[h+8>>1]=i;j=i+(c[a+20>>2]|0)|0;b[h+10>>1]=j;i=j+(c[a+24>>2]|0)|0;b[h+12>>1]=i;b[h+14>>1]=i+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}TGb(d|0,0,256)|0;return}function Tka(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Pka(a+(c[b>>2]|0)|0,d,e);Pka(a+(c[b+4>>2]|0)|0,d+64|0,e);Pka(a+(c[b+8>>2]|0)|0,d+128|0,e);Pka(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function Uka(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Qka(a+(c[b>>2]|0)|0,d,e);Qka(a+(c[b+4>>2]|0)|0,d+64|0,e);Qka(a+(c[b+8>>2]|0)|0,d+128|0,e);Qka(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function Vka(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Pka(a+(c[b>>2]|0)|0,d,e);Pka(a+(c[b+4>>2]|0)|0,d+64|0,e);Pka(a+(c[b+8>>2]|0)|0,d+128|0,e);Pka(a+(c[b+12>>2]|0)|0,d+192|0,e);Pka(a+(c[b+32>>2]|0)|0,d+256|0,e);Pka(a+(c[b+36>>2]|0)|0,d+320|0,e);Pka(a+(c[b+40>>2]|0)|0,d+384|0,e);Pka(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function Wka(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Qka(a+(c[b>>2]|0)|0,d,e);Qka(a+(c[b+4>>2]|0)|0,d+64|0,e);Qka(a+(c[b+8>>2]|0)|0,d+128|0,e);Qka(a+(c[b+12>>2]|0)|0,d+192|0,e);Qka(a+(c[b+32>>2]|0)|0,d+256|0,e);Qka(a+(c[b+36>>2]|0)|0,d+320|0,e);Qka(a+(c[b+40>>2]|0)|0,d+384|0,e);Qka(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function Xka(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Pka(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Yka(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Qka(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Zka(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=a;e=d>>1;d=b+(-e<<1)|0;f=c[d>>2]|0;g=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+((e*3|0)<<1)|0;c[d>>2]=f;c[d+4>>2]=g;return}function _ka(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0;b=a;f=d>>1;d=gHb(e[a-2>>1]|0,0,65537,65537)|0;g=a;c[g>>2]=d;c[g+4>>2]=F;g=gHb(e[b+(f-1<<1)>>1]|0,0,65537,65537)|0;d=b+(f<<1)|0;c[d>>2]=g;c[d+4>>2]=F;d=f<<1;g=gHb(e[b+(d-1<<1)>>1]|0,0,65537,65537)|0;a=b+(d<<1)|0;c[a>>2]=g;c[a+4>>2]=F;a=f*3|0;f=gHb(e[b+(a-1<<1)>>1]|0,0,65537,65537)|0;g=b+(a<<1)|0;c[g>>2]=f;c[g+4>>2]=F;return}function $ka(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=(e[b+(-f<<1)>>1]|0)+4+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=b+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(d<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function ala(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=d>>1;d=e[f+(1-g<<1)>>1]|0;h=e[f+(2-g<<1)>>1]|0;i=e[f+(3-g<<1)>>1]|0;j=e[c>>1]|0;k=e[c+2>>1]|0;l=e[c+4>>1]|0;m=e[c+6>>1]|0;b[f>>1]=((e[f+(-g<<1)>>1]|0)+2+h+(d<<1)|0)>>>2;c=(d+2+i+(h<<1)|0)>>>2&65535;b[f+(g<<1)>>1]=c;b[a+2>>1]=c;c=(h+2+j+(i<<1)|0)>>>2&65535;h=g<<1;b[f+(h<<1)>>1]=c;b[f+(g+1<<1)>>1]=c;b[a+4>>1]=c;c=(i+2+k+(j<<1)|0)>>>2&65535;i=g*3|0;b[f+(i<<1)>>1]=c;b[f+((h|1)<<1)>>1]=c;b[f+(g+2<<1)>>1]=c;b[a+6>>1]=c;c=(j+2+l+(k<<1)|0)>>>2&65535;b[f+(i+1<<1)>>1]=c;b[f+(h+2<<1)>>1]=c;b[f+(g+3<<1)>>1]=c;c=(k+2+m+(l<<1)|0)>>>2&65535;b[f+(i+2<<1)>>1]=c;b[f+(h+3<<1)>>1]=c;b[f+(i+3<<1)>>1]=(l+2+(m*3|0)|0)>>>2;return}function bla(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;b[c+(o<<1)>>1]=(l+2+(n<<1)+(e[c+(o-1<<1)>>1]|0)|0)>>>2;p=(k+2+(l<<1)+n|0)>>>2&65535;b[c+(o+1<<1)>>1]=p;b[c+(m<<1)>>1]=p;p=d+2|0;n=(p+(k<<1)+l|0)>>>2&65535;b[c+(o+2<<1)>>1]=n;b[c+((m|1)<<1)>>1]=n;b[c+(f<<1)>>1]=n;n=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+3<<1)>>1]=n;b[c+(m+2<<1)>>1]=n;b[c+(f+1<<1)>>1]=n;b[c>>1]=n;n=(p+(g<<1)+h|0)>>>2&65535;b[c+(m+3<<1)>>1]=n;b[c+(f+2<<1)>>1]=n;b[a+2>>1]=n;n=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(f+3<<1)>>1]=n;b[a+4>>1]=n;b[a+6>>1]=(h+2+(i<<1)+j|0)>>>2;return}function cla(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;p=(d+1+g|0)>>>1&65535;b[c+((m|1)<<1)>>1]=p;b[c>>1]=p;p=(g+1+h|0)>>>1&65535;b[c+(m+2<<1)>>1]=p;b[a+2>>1]=p;p=(h+1+i|0)>>>1&65535;b[c+(m+3<<1)>>1]=p;b[a+4>>1]=p;b[a+6>>1]=(i+1+j|0)>>>1;a=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+1<<1)>>1]=a;b[c+(f<<1)>>1]=a;a=d+2|0;d=(a+(g<<1)+h|0)>>>2&65535;b[c+(o+2<<1)>>1]=d;b[c+(f+1<<1)>>1]=d;d=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(o+3<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;b[c+(f+3<<1)>>1]=(h+2+(i<<1)+j|0)>>>2;b[c+(m<<1)>>1]=(a+(k<<1)+l|0)>>>2;b[c+(o<<1)>>1]=(k+2+(l<<1)+n|0)>>>2;return}function dla(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[a-2>>1]|0;k=e[c+(f-1<<1)>>1]|0;l=f<<1;m=e[c+(l-1<<1)>>1]|0;n=f*3|0;o=e[c+(n-1<<1)>>1]|0;p=(d+1+j|0)>>>1&65535;b[c+(f+2<<1)>>1]=p;b[c>>1]=p;p=((d<<1)+2+g+j|0)>>>2&65535;b[c+(f+3<<1)>>1]=p;b[a+2>>1]=p;p=d+2|0;b[a+4>>1]=(p+(g<<1)+h|0)>>>2;b[a+6>>1]=(g+2+(h<<1)+i|0)>>>2;i=(j+1+k|0)>>>1&65535;b[c+(l+2<<1)>>1]=i;b[c+(f<<1)>>1]=i;i=(p+(j<<1)+k|0)>>>2&65535;b[c+(l+3<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;i=(k+1+m|0)>>>1&65535;b[c+(n+2<<1)>>1]=i;b[c+(l<<1)>>1]=i;i=(j+2+(k<<1)+m|0)>>>2&65535;b[c+(n+3<<1)>>1]=i;b[c+((l|1)<<1)>>1]=i;b[c+(n<<1)>>1]=(m+1+o|0)>>>1;b[c+(n+1<<1)>>1]=(k+2+(m<<1)+o|0)>>>2;return}function ela(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a;g=d>>1;d=e[f+(-g<<1)>>1]|0;h=e[f+(1-g<<1)>>1]|0;i=e[f+(2-g<<1)>>1]|0;j=e[f+(3-g<<1)>>1]|0;k=e[c>>1]|0;l=e[c+2>>1]|0;m=e[c+4>>1]|0;b[f>>1]=(d+1+h|0)>>>1;c=(h+1+i|0)>>>1&65535;n=g<<1;b[f+(n<<1)>>1]=c;b[a+2>>1]=c;c=(i+1+j|0)>>>1&65535;b[f+((n|1)<<1)>>1]=c;b[a+4>>1]=c;c=(j+1+k|0)>>>1&65535;b[f+(n+2<<1)>>1]=c;b[a+6>>1]=c;b[f+(n+3<<1)>>1]=(k+1+l|0)>>>1;b[f+(g<<1)>>1]=(d+2+(h<<1)+i|0)>>>2;d=(h+2+(i<<1)+j|0)>>>2&65535;h=g*3|0;b[f+(h<<1)>>1]=d;b[f+(g+1<<1)>>1]=d;d=(i+2+(j<<1)+k|0)>>>2&65535;b[f+(h+1<<1)>>1]=d;b[f+(g+2<<1)>>1]=d;d=(j+2+(k<<1)+l|0)>>>2&65535;b[f+(h+2<<1)>>1]=d;b[f+(g+3<<1)>>1]=d;b[f+(h+3<<1)>>1]=(k+2+(l<<1)+m|0)>>>2;return}function fla(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=a;f=d>>1;d=e[a-2>>1]|0;g=e[c+(f-1<<1)>>1]|0;h=f<<1;i=e[c+(h-1<<1)>>1]|0;j=f*3|0;k=b[c+(j-1<<1)>>1]|0;l=k&65535;b[c>>1]=(d+1+g|0)>>>1;b[a+2>>1]=(d+2+(g<<1)+i|0)>>>2;d=(g+1+i|0)>>>1&65535;b[c+(f<<1)>>1]=d;b[a+4>>1]=d;d=(g+2+(i<<1)+l|0)>>>2&65535;b[c+(f+1<<1)>>1]=d;b[a+6>>1]=d;d=(i+1+l|0)>>>1&65535;b[c+(h<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;d=(i+2+l+(l<<1)|0)>>>2&65535;b[c+((h|1)<<1)>>1]=d;b[c+(f+3<<1)>>1]=d;b[c+(j+3<<1)>>1]=k;b[c+(j+2<<1)>>1]=k;b[c+(h+2<<1)>>1]=k;b[c+(j<<1)>>1]=k;b[c+(j+1<<1)>>1]=k;b[c+(h+3<<1)>>1]=k;return}function gla(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=gHb(((e[a-2>>1]|0)+2+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;i=F;j=a;c[j>>2]=h;c[j+4>>2]=i;j=b+(f<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(d<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(g<<1)|0;c[j>>2]=h;c[j+4>>2]=i;return}function hla(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0;b=a;f=d>>1;d=gHb(((e[b+(-f<<1)>>1]|0)+2+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+((f*3|0)<<1)|0;c[h>>2]=d;c[h+4>>2]=g;return}function ila(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=134219776;c[d+4>>2]=134219776;d=b+(e<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=b+(e<<1<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=b+((e*3|0)<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;return}function jla(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=134154239;c[d+4>>2]=134154239;d=b+(e<<1)|0;c[d>>2]=134154239;c[d+4>>2]=134154239;d=b+(e<<1<<1)|0;c[d>>2]=134154239;c[d+4>>2]=134154239;d=b+((e*3|0)<<1)|0;c[d>>2]=134154239;c[d+4>>2]=134154239;return}function kla(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=134285313;c[d+4>>2]=134285313;d=b+(e<<1)|0;c[d>>2]=134285313;c[d+4>>2]=134285313;d=b+(e<<1<<1)|0;c[d>>2]=134285313;c[d+4>>2]=134285313;d=b+((e*3|0)<<1)|0;c[d>>2]=134285313;c[d+4>>2]=134285313;return}function lla(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}b[h>>1]=((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;b[a+2>>1]=(j+2+(k<<1)+l|0)>>>2;b[a+4>>1]=(k+2+(l<<1)+m|0)>>>2;b[a+6>>1]=(l+2+(m<<1)+n|0)>>>2;l=a+8|0;b[l>>1]=(m+2+(n<<1)+o|0)>>>2;b[a+10>>1]=(n+2+(o<<1)+p|0)>>>2;b[a+12>>1]=(o+2+(p<<1)+r|0)>>>2;b[a+14>>1]=((s&65535)+2+(r<<1)+p|0)>>>2;p=a;a=c[p>>2]|0;r=c[p+4>>2]|0;p=l;l=c[p>>2]|0;s=c[p+4>>2]|0;p=h+(i<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(i+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<1;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*3|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<2;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*5|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i*6|0;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*7|0;i=h+(o<<1)|0;c[i>>2]=a;c[i+4>>2]=r;r=h+(o+4<<1)|0;c[r>>2]=l;c[r+4>>2]=s;return}function mla(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=g<<1;j=e[d+(f-1<<1)>>1]|0;k=g*3|0;l=e[d+(k-1<<1)>>1]|0;m=g<<2;n=e[d+(m-1<<1)>>1]|0;o=g*5|0;p=e[d+(o-1<<1)>>1]|0;q=g*6|0;r=e[d+(q-1<<1)>>1]|0;s=g*7|0;t=e[d+(s-1<<1)>>1]|0;u=gHb(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2,0,65537,65537)|0;h=F;v=a;c[v>>2]=u;c[v+4>>2]=h;v=a+8|0;c[v>>2]=u;c[v+4>>2]=h;h=gHb((b+2+(i<<1)+j|0)>>>2,0,65537,65537)|0;b=F;v=d+(g<<1)|0;c[v>>2]=h;c[v+4>>2]=b;v=d+(g+4<<1)|0;c[v>>2]=h;c[v+4>>2]=b;b=gHb((i+2+(j<<1)+l|0)>>>2,0,65537,65537)|0;i=F;v=d+(f<<1)|0;c[v>>2]=b;c[v+4>>2]=i;v=d+(f+4<<1)|0;c[v>>2]=b;c[v+4>>2]=i;i=gHb((j+2+(l<<1)+n|0)>>>2,0,65537,65537)|0;j=F;v=d+(k<<1)|0;c[v>>2]=i;c[v+4>>2]=j;v=d+(k+4<<1)|0;c[v>>2]=i;c[v+4>>2]=j;j=gHb((l+2+(n<<1)+p|0)>>>2,0,65537,65537)|0;l=F;v=d+(m<<1)|0;c[v>>2]=j;c[v+4>>2]=l;v=d+(m+4<<1)|0;c[v>>2]=j;c[v+4>>2]=l;l=gHb((n+2+(p<<1)+r|0)>>>2,0,65537,65537)|0;n=F;v=d+(o<<1)|0;c[v>>2]=l;c[v+4>>2]=n;v=d+(o+4<<1)|0;c[v>>2]=l;c[v+4>>2]=n;n=gHb((p+2+(r<<1)+t|0)>>>2,0,65537,65537)|0;p=F;v=d+(q<<1)|0;c[v>>2]=n;c[v+4>>2]=p;v=d+(q+4<<1)|0;c[v>>2]=n;c[v+4>>2]=p;p=gHb((r+2+(t*3|0)|0)>>>2,0,65537,65537)|0;t=F;r=d+(s<<1)|0;c[r>>2]=p;c[r+4>>2]=t;r=d+(s+4<<1)|0;c[r>>2]=p;c[r+4>>2]=t;return}function nla(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=a;i=g>>1;g=(d|0)!=0;if(g){d=~i;j=h+(d<<1)|0;k=a-2|0;l=d}else{d=a-2|0;j=d;k=d;l=~i}d=e[k>>1]|0;k=e[h+(i-1<<1)>>1]|0;m=e[h+((i<<1)-1<<1)>>1]|0;n=e[h+((i*3|0)-1<<1)>>1]|0;o=e[h+((i<<2)-1<<1)>>1]|0;p=e[h+((i*5|0)-1<<1)>>1]|0;q=e[h+((i*6|0)-1<<1)>>1]|0;r=e[h+((i*7|0)-1<<1)>>1]|0;s=-i|0;t=e[h+(s<<1)>>1]|0;u=e[h+(1-i<<1)>>1]|0;v=e[h+(2-i<<1)>>1]|0;w=e[h+(3-i<<1)>>1]|0;x=e[h+(4-i<<1)>>1]|0;y=e[h+(5-i<<1)>>1]|0;z=e[h+(6-i<<1)>>1]|0;A=b[h+(7-i<<1)>>1]|0;B=A&65535;if((f|0)==0){C=A}else{C=b[h+(8-i<<1)>>1]|0}A=(((e[j>>1]|0)+2+(d<<1)+k|0)>>>2)+8+((d+2+(k<<1)+m|0)>>>2)+((k+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q<<1)+r|0)>>>2)+((q+2+(r*3|0)|0)>>>2)+(((e[h+((g?l:s)<<1)>>1]|0)+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+z|0)>>>2)+((y+2+(z<<1)+B|0)>>>2)+(((C&65535)+2+(B<<1)+z|0)>>>2)>>4;z=gHb(A,(A|0)<0|0?-1:0,65537,65537)|0;A=F;B=a;c[B>>2]=z;c[B+4>>2]=A;B=a+8|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=i<<1;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;i=h+(a<<1)|0;c[i>>2]=z;c[i+4>>2]=A;i=h+(a+4<<1)|0;c[i>>2]=z;c[i+4>>2]=A;return}function ola(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=e[g+(2-h<<1)>>1]|0;l=(i+2+(j<<1)+k|0)>>>2;m=e[g+(3-h<<1)>>1]|0;n=(j+2+(k<<1)+m|0)>>>2;o=e[g+(4-h<<1)>>1]|0;p=(k+2+(m<<1)+o|0)>>>2;k=e[g+(5-h<<1)>>1]|0;q=(m+2+(o<<1)+k|0)>>>2;m=e[g+(6-h<<1)>>1]|0;r=(o+2+(k<<1)+m|0)>>>2;o=b[g+(7-h<<1)>>1]|0;s=o&65535;t=(k+2+(m<<1)+s|0)>>>2;if((d|0)==0){u=s;v=s;w=s;x=s;y=s;z=s;A=s;B=s;C=(o&65535)+2+(s<<1)|0}else{o=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;k=e[g+(10-h<<1)>>1]|0;D=e[g+(11-h<<1)>>1]|0;E=e[g+(12-h<<1)>>1]|0;F=e[g+(13-h<<1)>>1]|0;G=e[g+(14-h<<1)>>1]|0;H=e[g+(15-h<<1)>>1]|0;u=(G+2+(H*3|0)|0)>>>2;v=(F+2+(G<<1)+H|0)>>>2;w=(E+2+(F<<1)+G|0)>>>2;x=(D+2+(E<<1)+F|0)>>>2;y=(k+2+(D<<1)+E|0)>>>2;z=(d+2+(k<<1)+D|0)>>>2;A=(o+2+(d<<1)+k|0)>>>2;B=(s+2+(o<<1)+d|0)>>>2;C=(e[g+(8-h<<1)>>1]|0)+2+(s<<1)|0}s=(C+m|0)>>>2;b[g>>1]=((((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2)+2+(l<<1)+n|0)>>>2;j=(l+2+(n<<1)+p|0)>>>2&65535;b[a+2>>1]=j;b[g+(h<<1)>>1]=j;j=(n+2+(p<<1)+q|0)>>>2&65535;b[a+4>>1]=j;b[g+(h+1<<1)>>1]=j;n=h<<1;b[g+(n<<1)>>1]=j;j=(p+2+(q<<1)+r|0)>>>2&65535;b[a+6>>1]=j;b[g+(h+2<<1)>>1]=j;b[g+((n|1)<<1)>>1]=j;p=h*3|0;b[g+(p<<1)>>1]=j;j=(q+2+(r<<1)+t|0)>>>2&65535;b[a+8>>1]=j;b[g+(h+3<<1)>>1]=j;b[g+(n+2<<1)>>1]=j;b[g+(p+1<<1)>>1]=j;q=h<<2;b[g+(q<<1)>>1]=j;j=(r+2+(t<<1)+s|0)>>>2&65535;b[a+10>>1]=j;b[g+(h+4<<1)>>1]=j;b[g+(n+3<<1)>>1]=j;b[g+(p+2<<1)>>1]=j;b[g+((q|1)<<1)>>1]=j;r=h*5|0;b[g+(r<<1)>>1]=j;j=(t+2+(s<<1)+B|0)>>>2&65535;b[a+12>>1]=j;b[g+(h+5<<1)>>1]=j;b[g+(n+4<<1)>>1]=j;b[g+(p+3<<1)>>1]=j;b[g+((q|2)<<1)>>1]=j;b[g+(r+1<<1)>>1]=j;t=h*6|0;b[g+(t<<1)>>1]=j;j=(s+2+(B<<1)+A|0)>>>2&65535;b[a+14>>1]=j;b[g+(h+6<<1)>>1]=j;b[g+(n+5<<1)>>1]=j;b[g+(p+4<<1)>>1]=j;b[g+((q|3)<<1)>>1]=j;b[g+(r+2<<1)>>1]=j;b[g+((t|1)<<1)>>1]=j;a=h*7|0;b[g+(a<<1)>>1]=j;j=(B+2+(A<<1)+z|0)>>>2&65535;b[g+(h+7<<1)>>1]=j;b[g+(n+6<<1)>>1]=j;b[g+(p+5<<1)>>1]=j;b[g+(q+4<<1)>>1]=j;b[g+(r+3<<1)>>1]=j;b[g+(t+2<<1)>>1]=j;b[g+(a+1<<1)>>1]=j;j=(A+2+(z<<1)+y|0)>>>2&65535;b[g+(n+7<<1)>>1]=j;b[g+(p+6<<1)>>1]=j;b[g+(q+5<<1)>>1]=j;b[g+(r+4<<1)>>1]=j;b[g+(t+3<<1)>>1]=j;b[g+(a+2<<1)>>1]=j;j=(z+2+(y<<1)+x|0)>>>2&65535;b[g+(p+7<<1)>>1]=j;b[g+(q+6<<1)>>1]=j;b[g+(r+5<<1)>>1]=j;b[g+(t+4<<1)>>1]=j;b[g+(a+3<<1)>>1]=j;j=(y+2+(x<<1)+w|0)>>>2&65535;b[g+(q+7<<1)>>1]=j;b[g+(r+6<<1)>>1]=j;b[g+(t+5<<1)>>1]=j;b[g+(a+4<<1)>>1]=j;j=(x+2+(w<<1)+v|0)>>>2&65535;b[g+(r+7<<1)>>1]=j;b[g+(t+6<<1)>>1]=j;b[g+(a+5<<1)>>1]=j;j=(w+2+(v<<1)+u|0)>>>2&65535;b[g+(t+7<<1)>>1]=j;b[g+(a+6<<1)>>1]=j;b[g+(a+7<<1)>>1]=(v+2+(u*3|0)|0)>>>2;return}function pla(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;k=e[g+(v-1<<1)>>1]|0;d=i+2|0;i=(d+(w<<1)+k|0)>>>2;c=h*3|0;y=e[g+(c-1<<1)>>1]|0;z=(w+2+(k<<1)+y|0)>>>2;w=h<<2;A=e[g+(w-1<<1)>>1]|0;B=(k+2+(y<<1)+A|0)>>>2;k=h*5|0;C=e[g+(k-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*6|0;E=e[g+(y-1<<1)>>1]|0;F=(A+2+(C<<1)+E|0)>>>2;A=h*7|0;G=e[g+(A-1<<1)>>1]|0;H=(C+2+(E<<1)+G|0)>>>2;C=(d+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(A<<1)>>1]=(F+2+((E+2+(G*3|0)|0)>>>2)+(H<<1)|0)>>>2;G=(D+2+(F<<1)+H|0)>>>2&65535;b[g+(A+1<<1)>>1]=G;b[g+(y<<1)>>1]=G;G=(B+2+(D<<1)+F|0)>>>2&65535;b[g+(A+2<<1)>>1]=G;b[g+((y|1)<<1)>>1]=G;b[g+(k<<1)>>1]=G;G=(z+2+(B<<1)+D|0)>>>2&65535;b[g+(A+3<<1)>>1]=G;b[g+(y+2<<1)>>1]=G;b[g+(k+1<<1)>>1]=G;b[g+(w<<1)>>1]=G;G=(i+2+(z<<1)+B|0)>>>2&65535;b[g+(A+4<<1)>>1]=G;b[g+(y+3<<1)>>1]=G;b[g+(k+2<<1)>>1]=G;b[g+((w|1)<<1)>>1]=G;b[g+(c<<1)>>1]=G;G=(f+2+(i<<1)+z|0)>>>2&65535;b[g+(A+5<<1)>>1]=G;b[g+(y+4<<1)>>1]=G;b[g+(k+3<<1)>>1]=G;b[g+((w|2)<<1)>>1]=G;b[g+(c+1<<1)>>1]=G;b[g+(v<<1)>>1]=G;G=((f<<1)+2+i+C|0)>>>2&65535;b[g+(A+6<<1)>>1]=G;b[g+(y+5<<1)>>1]=G;b[g+(k+4<<1)>>1]=G;b[g+((w|3)<<1)>>1]=G;b[g+(c+2<<1)>>1]=G;b[g+((v|1)<<1)>>1]=G;b[g+(h<<1)>>1]=G;G=l+2|0;i=(G+f+(C<<1)|0)>>>2&65535;b[g+(A+7<<1)>>1]=i;b[g+(y+6<<1)>>1]=i;b[g+(k+5<<1)>>1]=i;b[g+(w+4<<1)>>1]=i;b[g+(c+3<<1)>>1]=i;b[g+(v+2<<1)>>1]=i;b[g+(h+1<<1)>>1]=i;b[g>>1]=i;i=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+7<<1)>>1]=i;b[g+(k+6<<1)>>1]=i;b[g+(w+5<<1)>>1]=i;b[g+(c+4<<1)>>1]=i;b[g+(v+3<<1)>>1]=i;b[g+(h+2<<1)>>1]=i;b[a+2>>1]=i;i=(G+(m<<1)+o|0)>>>2&65535;b[g+(k+7<<1)>>1]=i;b[g+(w+6<<1)>>1]=i;b[g+(c+5<<1)>>1]=i;b[g+(v+4<<1)>>1]=i;b[g+(h+3<<1)>>1]=i;b[a+4>>1]=i;i=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(w+7<<1)>>1]=i;b[g+(c+6<<1)>>1]=i;b[g+(v+5<<1)>>1]=i;b[g+(h+4<<1)>>1]=i;b[a+6>>1]=i;i=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(c+7<<1)>>1]=i;b[g+(v+6<<1)>>1]=i;b[g+(h+5<<1)>>1]=i;b[a+8>>1]=i;i=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(v+7<<1)>>1]=i;b[g+(h+6<<1)>>1]=i;b[a+10>>1]=i;i=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(h+7<<1)>>1]=i;b[a+12>>1]=i;b[a+14>>1]=(r+2+(t<<1)+(((u&65535)+2+(s<<1)+n|0)>>>2)|0)>>>2;return}function qla(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}k=((u&65535)+2+(s<<1)+n|0)>>>2;if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;n=e[g+(v-1<<1)>>1]|0;s=i+2|0;i=(s+(w<<1)+n|0)>>>2;u=h*3|0;d=e[g+(u-1<<1)>>1]|0;c=(w+2+(n<<1)+d|0)>>>2;w=h<<2;y=e[g+(w-1<<1)>>1]|0;z=(n+2+(d<<1)+y|0)>>>2;n=h*5|0;A=e[g+(n-1<<1)>>1]|0;B=(d+2+(y<<1)+A|0)>>>2;d=h*6|0;C=e[g+(d-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*7|0;E=(A+2+(C<<1)+(e[g+(y-1<<1)>>1]|0)|0)>>>2;C=(s+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(d<<1)>>1]=(z+2+(B<<1)+D|0)>>>2;b[g+(y<<1)>>1]=(B+2+(D<<1)+E|0)>>>2;E=(i+2+(c<<1)+z|0)>>>2&65535;b[g+((d|1)<<1)>>1]=E;b[g+(w<<1)>>1]=E;E=(c+2+(z<<1)+B|0)>>>2&65535;b[g+(y+1<<1)>>1]=E;b[g+(n<<1)>>1]=E;E=((f<<1)+2+i+C|0)>>>2&65535;b[g+(d+2<<1)>>1]=E;b[g+((w|1)<<1)>>1]=E;b[g+(v<<1)>>1]=E;E=(f+2+(i<<1)+c|0)>>>2&65535;b[g+(y+2<<1)>>1]=E;b[g+(n+1<<1)>>1]=E;b[g+(u<<1)>>1]=E;E=l+2|0;c=(E+f+(C<<1)|0)>>>2&65535;b[g+(y+3<<1)>>1]=c;b[g+(n+2<<1)>>1]=c;b[g+(u+1<<1)>>1]=c;b[g+(h<<1)>>1]=c;c=l+1|0;f=(c+C|0)>>>1&65535;b[g+(d+3<<1)>>1]=f;b[g+((w|2)<<1)>>1]=f;b[g+((v|1)<<1)>>1]=f;b[g>>1]=f;f=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+4<<1)>>1]=f;b[g+(n+3<<1)>>1]=f;b[g+(u+2<<1)>>1]=f;b[g+(h+1<<1)>>1]=f;f=(c+m|0)>>>1&65535;b[g+(d+4<<1)>>1]=f;b[g+((w|3)<<1)>>1]=f;b[g+(v+2<<1)>>1]=f;b[a+2>>1]=f;f=(E+(m<<1)+o|0)>>>2&65535;b[g+(y+5<<1)>>1]=f;b[g+(n+4<<1)>>1]=f;b[g+(u+3<<1)>>1]=f;b[g+(h+2<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[g+(d+5<<1)>>1]=f;b[g+(w+4<<1)>>1]=f;b[g+(v+3<<1)>>1]=f;b[a+4>>1]=f;f=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(y+6<<1)>>1]=f;b[g+(n+5<<1)>>1]=f;b[g+(u+4<<1)>>1]=f;b[g+(h+3<<1)>>1]=f;f=(o+1+p|0)>>>1&65535;b[g+(d+6<<1)>>1]=f;b[g+(w+5<<1)>>1]=f;b[g+(v+4<<1)>>1]=f;b[a+6>>1]=f;f=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(y+7<<1)>>1]=f;b[g+(n+6<<1)>>1]=f;b[g+(u+5<<1)>>1]=f;b[g+(h+4<<1)>>1]=f;f=(p+1+q|0)>>>1&65535;b[g+(d+7<<1)>>1]=f;b[g+(w+6<<1)>>1]=f;b[g+(v+5<<1)>>1]=f;b[a+8>>1]=f;f=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(n+7<<1)>>1]=f;b[g+(u+6<<1)>>1]=f;b[g+(h+5<<1)>>1]=f;f=(q+1+r|0)>>>1&65535;b[g+(w+7<<1)>>1]=f;b[g+(v+6<<1)>>1]=f;b[a+10>>1]=f;f=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(u+7<<1)>>1]=f;b[g+(h+6<<1)>>1]=f;f=(r+1+t|0)>>>1&65535;b[g+(v+7<<1)>>1]=f;b[a+12>>1]=f;b[g+(h+7<<1)>>1]=(r+2+(t<<1)+k|0)>>>2;b[a+14>>1]=(t+1+k|0)>>>1;return}function rla(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=a;g=f>>1;f=(c|0)!=0;c=-g|0;h=~g;i=e[d+(c<<1)>>1]|0;j=e[d+(1-g<<1)>>1]|0;k=((e[d+((f?h:c)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;c=e[d+(2-g<<1)>>1]|0;l=(i+2+(j<<1)+c|0)>>>2;m=e[d+(3-g<<1)>>1]|0;n=(j+2+(c<<1)+m|0)>>>2;j=e[d+(4-g<<1)>>1]|0;o=(c+2+(m<<1)+j|0)>>>2;c=e[d+(5-g<<1)>>1]|0;p=(m+2+(j<<1)+c|0)>>>2;m=e[d+(6-g<<1)>>1]|0;q=(j+2+(c<<1)+m|0)>>>2;j=(c+2+(m<<1)+(e[d+(7-g<<1)>>1]|0)|0)>>>2;if(f){f=d+(h<<1)|0;r=f;s=a-2|0;t=f}else{f=a-2|0;r=f;s=f;t=d+(h<<1)|0}h=e[s>>1]|0;s=e[d+(g-1<<1)>>1]|0;f=((e[r>>1]|0)+2+(h<<1)+s|0)>>>2;r=g<<1;m=e[d+(r-1<<1)>>1]|0;c=h+2|0;h=(c+(s<<1)+m|0)>>>2;u=g*3|0;v=e[d+(u-1<<1)>>1]|0;w=(s+2+(m<<1)+v|0)>>>2;s=g<<2;x=e[d+(s-1<<1)>>1]|0;y=(m+2+(v<<1)+x|0)>>>2;m=g*5|0;z=e[d+(m-1<<1)>>1]|0;A=(v+2+(x<<1)+z|0)>>>2;v=g*6|0;B=e[d+(v-1<<1)>>1]|0;C=(x+2+(z<<1)+B|0)>>>2;x=g*7|0;D=e[d+(x-1<<1)>>1]|0;E=(z+2+(B<<1)+D|0)>>>2;z=(B+2+(D*3|0)|0)>>>2;D=(c+((e[t>>1]|0)<<1)+i|0)>>>2;b[d+(x<<1)>>1]=(z+1+E|0)>>>1;b[d+(x+1<<1)>>1]=(C+2+z+(E<<1)|0)>>>2;z=(C+1+E|0)>>>1&65535;b[d+(x+2<<1)>>1]=z;b[d+(v<<1)>>1]=z;z=(A+2+(C<<1)+E|0)>>>2&65535;b[d+(x+3<<1)>>1]=z;b[d+((v|1)<<1)>>1]=z;z=(A+1+C|0)>>>1&65535;b[d+(x+4<<1)>>1]=z;b[d+(v+2<<1)>>1]=z;b[d+(m<<1)>>1]=z;z=(y+2+(A<<1)+C|0)>>>2&65535;b[d+(x+5<<1)>>1]=z;b[d+(v+3<<1)>>1]=z;b[d+(m+1<<1)>>1]=z;z=(y+1+A|0)>>>1&65535;b[d+(x+6<<1)>>1]=z;b[d+(v+4<<1)>>1]=z;b[d+(m+2<<1)>>1]=z;b[d+(s<<1)>>1]=z;z=(w+2+(y<<1)+A|0)>>>2&65535;b[d+(x+7<<1)>>1]=z;b[d+(v+5<<1)>>1]=z;b[d+(m+3<<1)>>1]=z;b[d+((s|1)<<1)>>1]=z;z=(w+1+y|0)>>>1&65535;b[d+(v+6<<1)>>1]=z;b[d+(m+4<<1)>>1]=z;b[d+((s|2)<<1)>>1]=z;b[d+(u<<1)>>1]=z;z=(h+2+(w<<1)+y|0)>>>2&65535;b[d+(v+7<<1)>>1]=z;b[d+(m+5<<1)>>1]=z;b[d+((s|3)<<1)>>1]=z;b[d+(u+1<<1)>>1]=z;z=(h+1+w|0)>>>1&65535;b[d+(m+6<<1)>>1]=z;b[d+(s+4<<1)>>1]=z;b[d+(u+2<<1)>>1]=z;b[d+(r<<1)>>1]=z;z=(f+2+(h<<1)+w|0)>>>2&65535;b[d+(m+7<<1)>>1]=z;b[d+(s+5<<1)>>1]=z;b[d+(u+3<<1)>>1]=z;b[d+((r|1)<<1)>>1]=z;z=f+1|0;m=(z+h|0)>>>1&65535;b[d+(s+6<<1)>>1]=m;b[d+(u+4<<1)>>1]=m;b[d+(r+2<<1)>>1]=m;b[d+(g<<1)>>1]=m;m=((f<<1)+2+h+D|0)>>>2&65535;b[d+(s+7<<1)>>1]=m;b[d+(u+5<<1)>>1]=m;b[d+(r+3<<1)>>1]=m;b[d+(g+1<<1)>>1]=m;m=(z+D|0)>>>1&65535;b[d+(u+6<<1)>>1]=m;b[d+(r+4<<1)>>1]=m;b[d+(g+2<<1)>>1]=m;b[d>>1]=m;m=k+2|0;z=(m+f+(D<<1)|0)>>>2&65535;b[d+(u+7<<1)>>1]=z;b[d+(r+5<<1)>>1]=z;b[d+(g+3<<1)>>1]=z;b[a+2>>1]=z;z=((k<<1)+2+l+D|0)>>>2&65535;b[d+(r+6<<1)>>1]=z;b[d+(g+4<<1)>>1]=z;b[a+4>>1]=z;z=(m+(l<<1)+n|0)>>>2&65535;b[d+(r+7<<1)>>1]=z;b[d+(g+5<<1)>>1]=z;b[a+6>>1]=z;z=(l+2+(n<<1)+o|0)>>>2&65535;b[d+(g+6<<1)>>1]=z;b[a+8>>1]=z;z=(n+2+(o<<1)+p|0)>>>2&65535;b[d+(g+7<<1)>>1]=z;b[a+10>>1]=z;b[a+12>>1]=(o+2+(p<<1)+q|0)>>>2;b[a+14>>1]=(p+2+(q<<1)+j|0)>>>2;return}function sla(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;f=e[g+(2-h<<1)>>1]|0;c=(i+2+(j<<1)+f|0)>>>2;i=e[g+(3-h<<1)>>1]|0;l=(j+2+(f<<1)+i|0)>>>2;j=e[g+(4-h<<1)>>1]|0;m=(f+2+(i<<1)+j|0)>>>2;f=e[g+(5-h<<1)>>1]|0;n=(i+2+(j<<1)+f|0)>>>2;i=e[g+(6-h<<1)>>1]|0;o=(j+2+(f<<1)+i|0)>>>2;j=b[g+(7-h<<1)>>1]|0;p=j&65535;q=(f+2+(i<<1)+p|0)>>>2;if((d|0)==0){r=p;s=p;t=p;u=p;v=p;w=(j&65535)+2+(p<<1)|0}else{j=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;f=e[g+(10-h<<1)>>1]|0;x=e[g+(11-h<<1)>>1]|0;y=e[g+(12-h<<1)>>1]|0;r=(x+2+(y<<1)+(e[g+(13-h<<1)>>1]|0)|0)>>>2;s=(f+2+(x<<1)+y|0)>>>2;t=(d+2+(f<<1)+x|0)>>>2;u=(j+2+(d<<1)+f|0)>>>2;v=(p+2+(j<<1)+d|0)>>>2;w=(e[g+(8-h<<1)>>1]|0)+2+(p<<1)|0}p=(w+i|0)>>>2;b[g>>1]=(k+1+c|0)>>>1;b[g+(h<<1)>>1]=(k+2+(c<<1)+l|0)>>>2;k=(c+1+l|0)>>>1&65535;b[a+2>>1]=k;i=h<<1;b[g+(i<<1)>>1]=k;k=(c+2+(l<<1)+m|0)>>>2&65535;b[g+(h+1<<1)>>1]=k;c=h*3|0;b[g+(c<<1)>>1]=k;k=(l+1+m|0)>>>1&65535;b[a+4>>1]=k;b[g+((i|1)<<1)>>1]=k;w=h<<2;b[g+(w<<1)>>1]=k;k=(l+2+(m<<1)+n|0)>>>2&65535;b[g+(h+2<<1)>>1]=k;b[g+(c+1<<1)>>1]=k;l=h*5|0;b[g+(l<<1)>>1]=k;k=(m+1+n|0)>>>1&65535;b[a+6>>1]=k;b[g+(i+2<<1)>>1]=k;b[g+((w|1)<<1)>>1]=k;d=h*6|0;b[g+(d<<1)>>1]=k;k=(m+2+(n<<1)+o|0)>>>2&65535;b[g+(h+3<<1)>>1]=k;b[g+(c+2<<1)>>1]=k;b[g+(l+1<<1)>>1]=k;m=h*7|0;b[g+(m<<1)>>1]=k;k=(n+1+o|0)>>>1&65535;b[a+8>>1]=k;b[g+(i+3<<1)>>1]=k;b[g+((w|2)<<1)>>1]=k;b[g+((d|1)<<1)>>1]=k;k=(n+2+(o<<1)+q|0)>>>2&65535;b[g+(h+4<<1)>>1]=k;b[g+(c+3<<1)>>1]=k;b[g+(l+2<<1)>>1]=k;b[g+(m+1<<1)>>1]=k;k=(o+1+q|0)>>>1&65535;b[a+10>>1]=k;b[g+(i+4<<1)>>1]=k;b[g+((w|3)<<1)>>1]=k;b[g+(d+2<<1)>>1]=k;k=(o+2+(q<<1)+p|0)>>>2&65535;b[g+(h+5<<1)>>1]=k;b[g+(c+4<<1)>>1]=k;b[g+(l+3<<1)>>1]=k;b[g+(m+2<<1)>>1]=k;k=(q+1+p|0)>>>1&65535;b[a+12>>1]=k;b[g+(i+5<<1)>>1]=k;b[g+(w+4<<1)>>1]=k;b[g+(d+3<<1)>>1]=k;k=(q+2+(p<<1)+v|0)>>>2&65535;b[g+(h+6<<1)>>1]=k;b[g+(c+5<<1)>>1]=k;b[g+(l+4<<1)>>1]=k;b[g+(m+3<<1)>>1]=k;k=(p+1+v|0)>>>1&65535;b[a+14>>1]=k;b[g+(i+6<<1)>>1]=k;b[g+(w+5<<1)>>1]=k;b[g+(d+4<<1)>>1]=k;k=(p+2+(v<<1)+u|0)>>>2&65535;b[g+(h+7<<1)>>1]=k;b[g+(c+6<<1)>>1]=k;b[g+(l+5<<1)>>1]=k;b[g+(m+4<<1)>>1]=k;k=(v+1+u|0)>>>1&65535;b[g+(i+7<<1)>>1]=k;b[g+(w+6<<1)>>1]=k;b[g+(d+5<<1)>>1]=k;k=(v+2+(u<<1)+t|0)>>>2&65535;b[g+(c+7<<1)>>1]=k;b[g+(l+6<<1)>>1]=k;b[g+(m+5<<1)>>1]=k;k=(u+1+t|0)>>>1&65535;b[g+(w+7<<1)>>1]=k;b[g+(d+6<<1)>>1]=k;k=(u+2+(t<<1)+s|0)>>>2&65535;b[g+(l+7<<1)>>1]=k;b[g+(m+6<<1)>>1]=k;b[g+(d+7<<1)>>1]=(t+1+s|0)>>>1;b[g+(m+7<<1)>>1]=(t+2+(s<<1)+r|0)>>>2;return}function tla(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a;g=f>>1;if((c|0)==0){c=a-2|0;h=c;i=c}else{h=d+(~g<<1)|0;i=a-2|0}c=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=((e[h>>1]|0)+2+(c<<1)+i|0)>>>2;h=g<<1;j=e[d+(h-1<<1)>>1]|0;k=(c+2+(i<<1)+j|0)>>>2;c=g*3|0;l=e[d+(c-1<<1)>>1]|0;m=(i+2+(j<<1)+l|0)>>>2;i=g<<2;n=e[d+(i-1<<1)>>1]|0;o=(j+2+(l<<1)+n|0)>>>2;j=g*5|0;p=e[d+(j-1<<1)>>1]|0;q=(l+2+(n<<1)+p|0)>>>2;l=g*6|0;r=e[d+(l-1<<1)>>1]|0;s=(n+2+(p<<1)+r|0)>>>2;n=g*7|0;t=e[d+(n-1<<1)>>1]|0;u=(p+2+(r<<1)+t|0)>>>2;p=(r+2+(t*3|0)|0)>>>2;b[d>>1]=(f+1+k|0)>>>1;b[a+2>>1]=(f+2+(k<<1)+m|0)>>>2;f=(k+1+m|0)>>>1&65535;b[a+4>>1]=f;b[d+(g<<1)>>1]=f;f=(k+2+(m<<1)+o|0)>>>2&65535;b[a+6>>1]=f;b[d+(g+1<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[a+8>>1]=f;b[d+(g+2<<1)>>1]=f;b[d+(h<<1)>>1]=f;f=(m+2+(o<<1)+q|0)>>>2&65535;b[a+10>>1]=f;b[d+(g+3<<1)>>1]=f;b[d+((h|1)<<1)>>1]=f;f=(o+1+q|0)>>>1&65535;b[a+12>>1]=f;b[d+(g+4<<1)>>1]=f;b[d+(h+2<<1)>>1]=f;b[d+(c<<1)>>1]=f;f=(o+2+(q<<1)+s|0)>>>2&65535;b[a+14>>1]=f;b[d+(g+5<<1)>>1]=f;b[d+(h+3<<1)>>1]=f;b[d+(c+1<<1)>>1]=f;f=(q+1+s|0)>>>1&65535;b[d+(g+6<<1)>>1]=f;b[d+(h+4<<1)>>1]=f;b[d+(c+2<<1)>>1]=f;b[d+(i<<1)>>1]=f;f=(q+2+(s<<1)+u|0)>>>2&65535;b[d+(g+7<<1)>>1]=f;b[d+(h+5<<1)>>1]=f;b[d+(c+3<<1)>>1]=f;b[d+((i|1)<<1)>>1]=f;f=(s+1+u|0)>>>1&65535;b[d+(h+6<<1)>>1]=f;b[d+(c+4<<1)>>1]=f;b[d+((i|2)<<1)>>1]=f;b[d+(j<<1)>>1]=f;f=(s+2+p+(u<<1)|0)>>>2&65535;b[d+(h+7<<1)>>1]=f;b[d+(c+5<<1)>>1]=f;b[d+((i|3)<<1)>>1]=f;b[d+(j+1<<1)>>1]=f;f=(p+1+u|0)>>>1&65535;b[d+(c+6<<1)>>1]=f;b[d+(i+4<<1)>>1]=f;b[d+(j+2<<1)>>1]=f;b[d+(l<<1)>>1]=f;f=(u+2+(p*3|0)|0)>>>2&65535;b[d+(c+7<<1)>>1]=f;b[d+(i+5<<1)>>1]=f;b[d+(j+3<<1)>>1]=f;b[d+((l|1)<<1)>>1]=f;f=p&65535;b[d+(n+7<<1)>>1]=f;b[d+(l+7<<1)>>1]=f;b[d+(j+7<<1)>>1]=f;b[d+(i+7<<1)>>1]=f;b[d+(n+6<<1)>>1]=f;b[d+(l+6<<1)>>1]=f;b[d+(j+6<<1)>>1]=f;b[d+(i+6<<1)>>1]=f;b[d+(n+5<<1)>>1]=f;b[d+(l+5<<1)>>1]=f;b[d+(j+5<<1)>>1]=f;b[d+(n+4<<1)>>1]=f;b[d+(l+4<<1)>>1]=f;b[d+(j+4<<1)>>1]=f;b[d+(n+3<<1)>>1]=f;b[d+(l+3<<1)>>1]=f;b[d+(n+2<<1)>>1]=f;b[d+(l+2<<1)>>1]=f;b[d+(n+1<<1)>>1]=f;b[d+(n<<1)>>1]=f;return}function ula(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=e[d+((g<<1)-1<<1)>>1]|0;j=e[d+((g*3|0)-1<<1)>>1]|0;k=e[d+((g<<2)-1<<1)>>1]|0;l=e[d+((g*5|0)-1<<1)>>1]|0;m=e[d+((g*6|0)-1<<1)>>1]|0;n=e[d+((g*7|0)-1<<1)>>1]|0;o=(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2)+4+((b+2+(i<<1)+f|0)>>>2)+((i+2+(f<<1)+j|0)>>>2)+((f+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n*3|0)|0)>>>2)>>3;n=gHb(o,(o|0)<0|0?-1:0,65537,65537)|0;o=F;m=a;c[m>>2]=n;c[m+4>>2]=o;m=a+8|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=g<<1;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;g=d+(a<<1)|0;c[g>>2]=n;c[g+4>>2]=o;g=d+(a+4<<1)|0;c[g>>2]=n;c[g+4>>2]=o;return}function vla(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}q=(((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2)+4+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+r|0)>>>2)+(((s&65535)+2+(r<<1)+p|0)>>>2)>>3;p=gHb(q,(q|0)<0|0?-1:0,65537,65537)|0;q=F;r=a;c[r>>2]=p;c[r+4>>2]=q;r=a+8|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=i<<1;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;i=h+(a<<1)|0;c[i>>2]=p;c[i+4>>2]=q;i=h+(a+4<<1)|0;c[i>>2]=p;c[i+4>>2]=q;return}function wla(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;b=e>>1;e=a;c[e>>2]=134219776;c[e+4>>2]=134219776;e=a+8|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(b<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(b+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=b<<1;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e+b|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;return}function xla(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function yla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=gHb(e[a-2>>1]|0,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=a+8|0;c[h>>2]=b;c[h+4>>2]=g;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;b=d+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(f+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f<<1;b=gHb(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=F;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*3|0;a=gHb(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;b=F;h=d+(g<<1)|0;c[h>>2]=a;c[h+4>>2]=b;h=d+(g+4<<1)|0;c[h>>2]=a;c[h+4>>2]=b;b=f<<2;h=gHb(e[d+(b-1<<1)>>1]|0,0,65537,65537)|0;a=F;g=d+(b<<1)|0;c[g>>2]=h;c[g+4>>2]=a;g=d+(b+4<<1)|0;c[g>>2]=h;c[g+4>>2]=a;a=f*5|0;g=gHb(e[d+(a-1<<1)>>1]|0,0,65537,65537)|0;h=F;b=d+(a<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(a+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f*6|0;b=gHb(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=F;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*7|0;f=gHb(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;a=F;b=d+(g<<1)|0;c[b>>2]=f;c[b+4>>2]=a;b=d+(g+4<<1)|0;c[b>>2]=f;c[b+4>>2]=a;return}function zla(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<3;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+((b|4)<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*9|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*10|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*11|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*12|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*13|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*14|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*15|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function Ala(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ba(b,a)|0;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function Bla(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a;f=c>>1;c=a+6|0;g=(f<<2)-1|0;h=g-(f<<1)|0;i=g+f|0;j=h-f|0;k=i+f|0;l=j-f|0;m=e[d+(k+f<<1)>>1]|0;n=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=(((m-(e[d+(l-f<<1)>>1]|0)<<2)+((((e[d+(k<<1)>>1]|0)-(e[d+(l<<1)>>1]|0)|0)*3|0)+(((e[d+(i<<1)>>1]|0)-(e[d+(j<<1)>>1]|0)<<1)+((e[d+(g<<1)>>1]|0)-(e[d+(h<<1)>>1]|0))))|0)*17|0)+16>>5;h=n<<1;g=n*3|0;j=n<<2;i=n*5|0;l=n*6|0;k=n*7|0;o=d;d=((c+n|0)*-3|0)+16+((e[a-2+(8-f<<1)>>1]|0)+m<<4)|0;m=8;while(1){a=d>>5;if(a>>>0<4096>>>0){p=a&65535}else{p=-a>>31&4095}b[o>>1]=p;a=d+n>>5;if(a>>>0<4096>>>0){q=a&65535}else{q=-a>>31&4095}b[o+2>>1]=q;a=d+h>>5;if(a>>>0<4096>>>0){r=a&65535}else{r=-a>>31&4095}b[o+4>>1]=r;a=d+g>>5;if(a>>>0<4096>>>0){s=a&65535}else{s=-a>>31&4095}b[o+6>>1]=s;a=d+j>>5;if(a>>>0<4096>>>0){t=a&65535}else{t=-a>>31&4095}b[o+8>>1]=t;a=d+i>>5;if(a>>>0<4096>>>0){u=a&65535}else{u=-a>>31&4095}b[o+10>>1]=u;a=d+l>>5;if(a>>>0<4096>>>0){v=a&65535}else{v=-a>>31&4095}b[o+12>>1]=v;a=d+k>>5;if(a>>>0<4096>>>0){w=a&65535}else{w=-a>>31&4095}b[o+14>>1]=w;a=m-1|0;if((a|0)>0){o=o+(f<<1)|0;d=d+c|0;m=a}else{break}}return}function Cla(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a;f=c>>1;c=a+6|0;g=-f|0;h=(f<<3)-1|0;i=h-(f<<1)|0;j=h+f|0;k=i-f|0;l=j+f|0;m=k-f|0;n=a+((f*6|0)-2)|0;o=a+((f*22|0)-2)|0;p=f<<1;q=g<<1;r=p+f|0;s=q-f|0;t=b[o+(r+f<<1)>>1]|0;u=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=((((t&65535)-(e[n+(s-f<<1)>>1]|0)<<3)+((((e[o+(r<<1)>>1]|0)-(e[n+(s<<1)>>1]|0)|0)*7|0)+((((e[o+(p<<1)>>1]|0)-(e[n+(q<<1)>>1]|0)|0)*6|0)+((((e[o+(f<<1)>>1]|0)-(e[n+(g<<1)>>1]|0)|0)*5|0)+(((e[d+(l+f<<1)>>1]|0)-(e[d+(m-f<<1)>>1]|0)<<2)+((((e[d+(l<<1)>>1]|0)-(e[d+(m<<1)>>1]|0)|0)*3|0)+(((e[d+(j<<1)>>1]|0)-(e[d+(k<<1)>>1]|0)<<1)+((e[d+(h<<1)>>1]|0)-(e[d+(i<<1)>>1]|0))))))))|0)*5|0)+32>>6;i=u*3|0;h=u<<1;k=u<<2;j=u*5|0;m=u*6|0;l=u*7|0;g=d;d=16-i+(c*-7|0)+((e[a+(-2-(f<<1)+16)>>1]|0)+(t&65535)<<4)|0;t=16;while(1){a=d>>5;if(a>>>0<4096>>>0){v=a&65535}else{v=-a>>31&4095}b[g>>1]=v;a=d+u>>5;if(a>>>0<4096>>>0){w=a&65535}else{w=-a>>31&4095}b[g+2>>1]=w;a=d+h>>5;if(a>>>0<4096>>>0){x=a&65535}else{x=-a>>31&4095}b[g+4>>1]=x;a=d+i>>5;if(a>>>0<4096>>>0){y=a&65535}else{y=-a>>31&4095}b[g+6>>1]=y;a=d+k>>5;if(a>>>0<4096>>>0){z=a&65535}else{z=-a>>31&4095}b[g+8>>1]=z;a=d+j>>5;if(a>>>0<4096>>>0){A=a&65535}else{A=-a>>31&4095}b[g+10>>1]=A;a=d+m>>5;if(a>>>0<4096>>>0){B=a&65535}else{B=-a>>31&4095}b[g+12>>1]=B;a=d+l>>5;if(a>>>0<4096>>>0){C=a&65535}else{C=-a>>31&4095}b[g+14>>1]=C;a=t-1|0;if((a|0)>0){g=g+(f<<1)|0;d=d+c|0;t=a}else{break}}return}function Dla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=(e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+(e[d+(4-f<<1)>>1]|0)))|0;l=f*7|0;m=(e[d+(l-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;n=(e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+((e[a-2>>1]|0)+(e[d+(-f<<1)>>1]|0))+(e[d+(1-f<<1)>>1]|0))+(e[d+(2-f<<1)>>1]|0))+(e[d+(3-f<<1)>>1]|0)+4>>3;o=gHb(n,(n|0)<0|0?-1:0,65537,65537)|0;n=F;p=gHb((k+2|0)>>>2,0,65537,65537)|0;q=F;r=m+4+k>>3;k=a;c[k>>2]=o;c[k+4>>2]=n;k=a+8|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(f<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(f+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(h<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(h+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(j<<1)|0;c[k>>2]=o;c[k+4>>2]=n;n=d+(j+4<<1)|0;c[n>>2]=p;c[n+4>>2]=q;q=gHb((m+2|0)>>>2,0,65537,65537)|0;m=F;n=gHb(r,(r|0)<0|0?-1:0,65537,65537)|0;r=F;p=d+(b<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(b+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(g<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(g+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(i<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(i+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(l<<1)|0;c[p>>2]=q;c[p+4>>2]=m;m=d+(l+4<<1)|0;c[m>>2]=n;c[m+4>>2]=r;return}function Ela(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=f*7|0;l=(e[d+(k-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;m=gHb(((e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))+2|0)>>>2,0,65537,65537)|0;n=F;o=a;c[o>>2]=m;c[o+4>>2]=n;o=a+8|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;n=gHb((l+2|0)>>>2,0,65537,65537)|0;l=F;o=d+(b<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(b+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;return}function Fla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=gHb(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=F;i=gHb((g+2|0)>>>2,0,65537,65537)|0;g=F;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function Gla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;Fla(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Hla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;Dla(a,b);d=a;f=b>>1;b=gHb(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function Ila(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;Ela(a,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=134219776;c[b+4>>2]=134219776;b=f+(g<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=g<<1;e=f+(b<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=134219776;c[h+4>>2]=134219776;h=a+(d+8)|0;d=h;a=h;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(g<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;return}function Jla(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Ela(a,b);d=a;e=b>>1;b=a;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<1;f=d+(b<<1)|0;c[f>>2]=134219776;c[f+4>>2]=134219776;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=134219776;c[g+4>>2]=134219776;g=a+8|0;a=g;d=g;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(e<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(b<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(f<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;return}function Kla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=0;g=0;h=0;i=0;j=0;k=0;do{l=e[d+((ba(k,f)|0)-1<<1)>>1]|0;j=l+j+(e[d+(k-f<<1)>>1]|0)|0;l=k+4|0;i=(e[d+(l-f<<1)>>1]|0)+i|0;h=(e[d+((ba(l,f)|0)-1<<1)>>1]|0)+h|0;g=(e[d+((ba(k+8|0,f)|0)-1<<1)>>1]|0)+g|0;b=(e[d+((ba(k+12|0,f)|0)-1<<1)>>1]|0)+b|0;k=k+1|0;}while((k|0)<4);k=j+4>>3;j=gHb(k,(k|0)<0|0?-1:0,65537,65537)|0;k=F;l=i+2>>2;m=gHb(l,(l|0)<0|0?-1:0,65537,65537)|0;l=F;n=h+2>>2;o=h+4+i>>3;h=g+2>>2;p=g+4+i>>3;g=b+2>>2;q=b+4+i>>3;i=a;c[i>>2]=j;c[i+4>>2]=k;i=a+8|0;c[i>>2]=m;c[i+4>>2]=l;i=d+(f<<1)|0;c[i>>2]=j;c[i+4>>2]=k;i=d+(f+4<<1)|0;c[i>>2]=m;c[i+4>>2]=l;i=f<<1;a=d+(i<<1)|0;c[a>>2]=j;c[a+4>>2]=k;a=d+(i+4<<1)|0;c[a>>2]=m;c[a+4>>2]=l;a=f*3|0;i=d+(a<<1)|0;c[i>>2]=j;c[i+4>>2]=k;k=d+(a+4<<1)|0;c[k>>2]=m;c[k+4>>2]=l;l=gHb(n,(n|0)<0|0?-1:0,65537,65537)|0;n=F;k=gHb(o,(o|0)<0|0?-1:0,65537,65537)|0;o=F;m=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;a=gHb(p,(p|0)<0|0?-1:0,65537,65537)|0;p=F;i=gHb(g,(g|0)<0|0?-1:0,65537,65537)|0;g=F;j=gHb(q,(q|0)<0|0?-1:0,65537,65537)|0;q=F;b=f<<2;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*5|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;b=d+(r+4<<1)|0;c[b>>2]=k;c[b+4>>2]=o;b=f*6|0;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*7|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;n=d+(r+4<<1)|0;c[n>>2]=k;c[n+4>>2]=o;o=f<<3;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+((o|4)<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*9|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;o=d+(n+4<<1)|0;c[o>>2]=a;c[o+4>>2]=p;o=f*10|0;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+(o+4<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*11|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;h=d+(n+4<<1)|0;c[h>>2]=a;c[h+4>>2]=p;p=f*12|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*13|0;p=d+(h<<1)|0;c[p>>2]=i;c[p+4>>2]=g;p=d+(h+4<<1)|0;c[p>>2]=j;c[p+4>>2]=q;p=f*14|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*15|0;f=d+(h<<1)|0;c[f>>2]=i;c[f+4>>2]=g;g=d+(h+4<<1)|0;c[g>>2]=j;c[g+4>>2]=q;return}function Lla(a,b){a=a|0;b=b|0;Ela(a,b);Ela(a+(b<<3)|0,b);return}function Mla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=gHb(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=F;i=gHb((g+2|0)>>>2,0,65537,65537)|0;g=F;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<3;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+((j|4)<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*9|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*10|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*11|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*12|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*13|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*14|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*15|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function Nla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;Mla(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Ola(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;Kla(a,b);d=a;f=b>>1;b=gHb(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function Pla(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;Ela(a,b);Ela(a+(b<<3)|0,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=134219776;c[b+4>>2]=134219776;b=f+(g<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=g<<1;e=f+(b<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=134219776;c[h+4>>2]=134219776;h=a+(d+8)|0;d=h;a=h;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(g<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;return}function Qla(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Ela(a,b);Ela(a+(b<<3)|0,b);d=a;e=b>>1;b=a;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<1;f=d+(b<<1)|0;c[f>>2]=134219776;c[f+4>>2]=134219776;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=134219776;c[g+4>>2]=134219776;g=a+8|0;a=g;d=g;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(e<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(b<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(f<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;return}function Rla(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+8|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=e<<2;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;e=d+(a+4<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;return}function Sla(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+8|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=e<<2;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;e=d+(a+4<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;return}function Tla(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+8|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<2;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;return}function Ula(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=b>>1;f=a;c[f>>2]=134219776;c[f+4>>2]=134219776;f=a+8|0;c[f>>2]=134219776;c[f+4>>2]=134219776;f=d+(e<<1)|0;c[f>>2]=134219776;c[f+4>>2]=134219776;f=e+4|0;g=d+(f<<1)|0;c[g>>2]=134219776;c[g+4>>2]=134219776;g=e<<1;h=d+(g<<1)|0;c[h>>2]=134219776;c[h+4>>2]=134219776;h=g+4|0;i=d+(h<<1)|0;c[i>>2]=134219776;c[i+4>>2]=134219776;i=e*3|0;j=d+(i<<1)|0;c[j>>2]=134219776;c[j+4>>2]=134219776;j=i+4|0;k=d+(j<<1)|0;c[k>>2]=134219776;c[k+4>>2]=134219776;k=e<<2;l=d+(k<<1)|0;c[l>>2]=134219776;c[l+4>>2]=134219776;l=k+4|0;m=d+(l<<1)|0;c[m>>2]=134219776;c[m+4>>2]=134219776;m=e*5|0;n=d+(m<<1)|0;c[n>>2]=134219776;c[n+4>>2]=134219776;n=m+4|0;o=d+(n<<1)|0;c[o>>2]=134219776;c[o+4>>2]=134219776;o=e*6|0;p=d+(o<<1)|0;c[p>>2]=134219776;c[p+4>>2]=134219776;p=o+4|0;q=d+(p<<1)|0;c[q>>2]=134219776;c[q+4>>2]=134219776;q=e*7|0;r=d+(q<<1)|0;c[r>>2]=134219776;c[r+4>>2]=134219776;r=q+4|0;s=d+(r<<1)|0;c[s>>2]=134219776;c[s+4>>2]=134219776;s=b<<3;b=a+s|0;d=b;t=b;c[t>>2]=134219776;c[t+4>>2]=134219776;t=a+(s+8)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(e<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(f<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(g<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(h<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(i<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(j<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(k<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(l<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(m<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(n<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(o<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(p<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(q<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(r<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;return}function Vla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+((e[d+(-f<<1)>>1]|0)+((e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))))))))))))))))))+16>>5;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Wla(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a;a=b>>1;b=d+(-a<<1)|0;e=c[b>>2]|0;f=c[b+4>>2]|0;b=d+(4-a<<1)|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=d+(8-a<<1)|0;i=c[b>>2]|0;j=c[b+4>>2]|0;b=d+(12-a<<1)|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=0;do{m=ba(b,a)|0;n=d+(m<<1)|0;c[n>>2]=e;c[n+4>>2]=f;n=d+(m+4<<1)|0;c[n>>2]=g;c[n+4>>2]=h;n=d+(m+8<<1)|0;c[n>>2]=i;c[n+4>>2]=j;n=d+(m+12<<1)|0;c[n>>2]=k;c[n+4>>2]=l;b=b+1|0;}while((b|0)<16);return}function Xla(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ba(b,a)|0;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+8<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+12<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function Yla(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+8|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+16|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+24|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;e=d+(a+4<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;e=d+(a+8<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;e=d+(a+12<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;return}function Zla(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+8|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+16|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+24|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;e=d+(a+4<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;e=d+(a+8<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;e=d+(a+12<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;return}function _la(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a;f=c>>1;c=a+14|0;g=-f|0;h=(f<<3)-1|0;i=d+(h<<1)|0;j=d+(h-(f<<1)<<1)|0;h=a+((f*30|0)-2)|0;k=2;l=i;m=j;n=(e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0)|0;o=(e[i>>1]|0)-(e[j>>1]|0)|0;do{l=l+(f<<1)|0;m=m+(g<<1)|0;n=(ba((e[c+(k-f<<1)>>1]|0)-(e[c+(-(f+k|0)<<1)>>1]|0)|0,k)|0)+n|0;o=(ba((e[l>>1]|0)-(e[m>>1]|0)|0,k)|0)+o|0;k=k+1|0;}while((k|0)<9);k=(n*5|0)+32>>6;n=(o*5|0)+32>>6;o=k<<1;m=k*3|0;l=k<<2;c=((n+k|0)*-7|0)+16+((e[a-2+(16-f<<1)>>1]|0)+(e[h>>1]|0)<<4)|0;h=d;d=16;while(1){a=-16;g=c;while(1){j=g>>5;if(j>>>0<4096>>>0){p=j&65535}else{p=-j>>31&4095}b[h+(a+16<<1)>>1]=p;j=g+k>>5;if(j>>>0<4096>>>0){q=j&65535}else{q=-j>>31&4095}b[h+(a+17<<1)>>1]=q;j=g+o>>5;if(j>>>0<4096>>>0){r=j&65535}else{r=-j>>31&4095}b[h+(a+18<<1)>>1]=r;j=g+m>>5;if(j>>>0<4096>>>0){s=j&65535}else{s=-j>>31&4095}b[h+(a+19<<1)>>1]=s;j=a+4|0;if((j|0)<0){a=j;g=g+l|0}else{break}}g=d-1|0;if((g|0)>0){c=c+n|0;h=h+(f<<1)|0;d=g}else{break}}return}function $la(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))+8>>4;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function ama(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))))))))))))))+8>>4;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function bma(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+8|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+16|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+24|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+8<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+12<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;return}function cma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a;h=f>>1;f=h<<1;i=h*3|0;j=h<<2;k=(e[g+(-h<<1)>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=k;l=k+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=l;k=l+(c[d+32>>2]|0)|0;b[g+(i-h<<1)>>1]=k;b[g+(j-h<<1)>>1]=k+(c[d+48>>2]|0);k=1-h|0;h=(e[g+(k<<1)>>1]|0)+(c[d+4>>2]|0)|0;b[a+2>>1]=h;l=h+(c[d+20>>2]|0)|0;b[g+(k+f<<1)>>1]=l;h=l+(c[d+36>>2]|0)|0;b[g+(k+i<<1)>>1]=h;b[g+(k+j<<1)>>1]=h+(c[d+52>>2]|0);h=k+1|0;l=(e[g+(h<<1)>>1]|0)+(c[d+8>>2]|0)|0;b[a+4>>1]=l;m=l+(c[d+24>>2]|0)|0;b[g+(h+f<<1)>>1]=m;l=m+(c[d+40>>2]|0)|0;b[g+(h+i<<1)>>1]=l;b[g+(h+j<<1)>>1]=l+(c[d+56>>2]|0);l=k+2|0;k=(e[g+(l<<1)>>1]|0)+(c[d+12>>2]|0)|0;b[a+6>>1]=k;a=k+(c[d+28>>2]|0)|0;b[g+(l+f<<1)>>1]=a;f=a+(c[d+44>>2]|0)|0;b[g+(l+i<<1)>>1]=f;b[g+(l+j<<1)>>1]=f+(c[d+60>>2]|0);TGb(d|0,0,64)|0;return}function dma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=a;h=f>>1;f=(e[a-2>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=f;i=f+(c[d+4>>2]|0)|0;b[a+2>>1]=i;f=i+(c[d+8>>2]|0)|0;b[a+4>>1]=f;b[a+6>>1]=f+(c[d+12>>2]|0);f=(e[g+(h-1<<1)>>1]|0)+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=f;a=f+(c[d+20>>2]|0)|0;b[g+(h+1<<1)>>1]=a;f=a+(c[d+24>>2]|0)|0;b[g+(h+2<<1)>>1]=f;b[g+(h+3<<1)>>1]=f+(c[d+28>>2]|0);f=h<<1;a=(e[g+(f-1<<1)>>1]|0)+(c[d+32>>2]|0)|0;b[g+(f<<1)>>1]=a;i=a+(c[d+36>>2]|0)|0;b[g+((f|1)<<1)>>1]=i;a=i+(c[d+40>>2]|0)|0;b[g+(f+2<<1)>>1]=a;b[g+(f+3<<1)>>1]=a+(c[d+44>>2]|0);a=f+h|0;h=(e[g+(a-1<<1)>>1]|0)+(c[d+48>>2]|0)|0;b[g+(a<<1)>>1]=h;f=h+(c[d+52>>2]|0)|0;b[g+(a+1<<1)>>1]=f;h=f+(c[d+56>>2]|0)|0;b[g+(a+2<<1)>>1]=h;b[g+(a+3<<1)>>1]=h+(c[d+60>>2]|0);TGb(d|0,0,64)|0;return}function ema(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=g<<1;h=g*3|0;i=g<<2;j=g*5|0;k=g*6|0;l=g*7|0;m=g<<3;n=0;o=a+(-g<<1)|0;a=d;while(1){p=(e[o>>1]|0)+(c[a>>2]|0)|0;b[o+(g<<1)>>1]=p;q=p+(c[a+32>>2]|0)|0;b[o+(f<<1)>>1]=q;p=q+(c[a+64>>2]|0)|0;b[o+(h<<1)>>1]=p;q=p+(c[a+96>>2]|0)|0;b[o+(i<<1)>>1]=q;p=q+(c[a+128>>2]|0)|0;b[o+(j<<1)>>1]=p;q=p+(c[a+160>>2]|0)|0;b[o+(k<<1)>>1]=q;p=q+(c[a+192>>2]|0)|0;b[o+(l<<1)>>1]=p;b[o+(m<<1)>>1]=p+(c[a+224>>2]|0);p=n+1|0;if((p|0)<8){n=p;o=o+2|0;a=a+4|0}else{break}}TGb(d|0,0,256)|0;return}function fma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=f>>1;f=0;h=a;a=d;while(1){i=(e[h-2>>1]|0)+(c[a>>2]|0)|0;b[h>>1]=i;j=i+(c[a+4>>2]|0)|0;b[h+2>>1]=j;i=j+(c[a+8>>2]|0)|0;b[h+4>>1]=i;j=i+(c[a+12>>2]|0)|0;b[h+6>>1]=j;i=j+(c[a+16>>2]|0)|0;b[h+8>>1]=i;j=i+(c[a+20>>2]|0)|0;b[h+10>>1]=j;i=j+(c[a+24>>2]|0)|0;b[h+12>>1]=i;b[h+14>>1]=i+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}TGb(d|0,0,256)|0;return}function gma(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;cma(a+(c[b>>2]|0)|0,d,e);cma(a+(c[b+4>>2]|0)|0,d+64|0,e);cma(a+(c[b+8>>2]|0)|0,d+128|0,e);cma(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function hma(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;dma(a+(c[b>>2]|0)|0,d,e);dma(a+(c[b+4>>2]|0)|0,d+64|0,e);dma(a+(c[b+8>>2]|0)|0,d+128|0,e);dma(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function ima(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;cma(a+(c[b>>2]|0)|0,d,e);cma(a+(c[b+4>>2]|0)|0,d+64|0,e);cma(a+(c[b+8>>2]|0)|0,d+128|0,e);cma(a+(c[b+12>>2]|0)|0,d+192|0,e);cma(a+(c[b+32>>2]|0)|0,d+256|0,e);cma(a+(c[b+36>>2]|0)|0,d+320|0,e);cma(a+(c[b+40>>2]|0)|0,d+384|0,e);cma(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function jma(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;dma(a+(c[b>>2]|0)|0,d,e);dma(a+(c[b+4>>2]|0)|0,d+64|0,e);dma(a+(c[b+8>>2]|0)|0,d+128|0,e);dma(a+(c[b+12>>2]|0)|0,d+192|0,e);dma(a+(c[b+32>>2]|0)|0,d+256|0,e);dma(a+(c[b+36>>2]|0)|0,d+320|0,e);dma(a+(c[b+40>>2]|0)|0,d+384|0,e);dma(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function kma(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{cma(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function lma(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{dma(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function mma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=a;e=d>>1;d=b+(-e<<1)|0;f=c[d>>2]|0;g=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+((e*3|0)<<1)|0;c[d>>2]=f;c[d+4>>2]=g;return}function nma(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0;b=a;f=d>>1;d=gHb(e[a-2>>1]|0,0,65537,65537)|0;g=a;c[g>>2]=d;c[g+4>>2]=F;g=gHb(e[b+(f-1<<1)>>1]|0,0,65537,65537)|0;d=b+(f<<1)|0;c[d>>2]=g;c[d+4>>2]=F;d=f<<1;g=gHb(e[b+(d-1<<1)>>1]|0,0,65537,65537)|0;a=b+(d<<1)|0;c[a>>2]=g;c[a+4>>2]=F;a=f*3|0;f=gHb(e[b+(a-1<<1)>>1]|0,0,65537,65537)|0;g=b+(a<<1)|0;c[g>>2]=f;c[g+4>>2]=F;return}function oma(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=(e[b+(-f<<1)>>1]|0)+4+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=b+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(d<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function pma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=d>>1;d=e[f+(1-g<<1)>>1]|0;h=e[f+(2-g<<1)>>1]|0;i=e[f+(3-g<<1)>>1]|0;j=e[c>>1]|0;k=e[c+2>>1]|0;l=e[c+4>>1]|0;m=e[c+6>>1]|0;b[f>>1]=((e[f+(-g<<1)>>1]|0)+2+h+(d<<1)|0)>>>2;c=(d+2+i+(h<<1)|0)>>>2&65535;b[f+(g<<1)>>1]=c;b[a+2>>1]=c;c=(h+2+j+(i<<1)|0)>>>2&65535;h=g<<1;b[f+(h<<1)>>1]=c;b[f+(g+1<<1)>>1]=c;b[a+4>>1]=c;c=(i+2+k+(j<<1)|0)>>>2&65535;i=g*3|0;b[f+(i<<1)>>1]=c;b[f+((h|1)<<1)>>1]=c;b[f+(g+2<<1)>>1]=c;b[a+6>>1]=c;c=(j+2+l+(k<<1)|0)>>>2&65535;b[f+(i+1<<1)>>1]=c;b[f+(h+2<<1)>>1]=c;b[f+(g+3<<1)>>1]=c;c=(k+2+m+(l<<1)|0)>>>2&65535;b[f+(i+2<<1)>>1]=c;b[f+(h+3<<1)>>1]=c;b[f+(i+3<<1)>>1]=(l+2+(m*3|0)|0)>>>2;return}function qma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;b[c+(o<<1)>>1]=(l+2+(n<<1)+(e[c+(o-1<<1)>>1]|0)|0)>>>2;p=(k+2+(l<<1)+n|0)>>>2&65535;b[c+(o+1<<1)>>1]=p;b[c+(m<<1)>>1]=p;p=d+2|0;n=(p+(k<<1)+l|0)>>>2&65535;b[c+(o+2<<1)>>1]=n;b[c+((m|1)<<1)>>1]=n;b[c+(f<<1)>>1]=n;n=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+3<<1)>>1]=n;b[c+(m+2<<1)>>1]=n;b[c+(f+1<<1)>>1]=n;b[c>>1]=n;n=(p+(g<<1)+h|0)>>>2&65535;b[c+(m+3<<1)>>1]=n;b[c+(f+2<<1)>>1]=n;b[a+2>>1]=n;n=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(f+3<<1)>>1]=n;b[a+4>>1]=n;b[a+6>>1]=(h+2+(i<<1)+j|0)>>>2;return}function rma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;p=(d+1+g|0)>>>1&65535;b[c+((m|1)<<1)>>1]=p;b[c>>1]=p;p=(g+1+h|0)>>>1&65535;b[c+(m+2<<1)>>1]=p;b[a+2>>1]=p;p=(h+1+i|0)>>>1&65535;b[c+(m+3<<1)>>1]=p;b[a+4>>1]=p;b[a+6>>1]=(i+1+j|0)>>>1;a=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+1<<1)>>1]=a;b[c+(f<<1)>>1]=a;a=d+2|0;d=(a+(g<<1)+h|0)>>>2&65535;b[c+(o+2<<1)>>1]=d;b[c+(f+1<<1)>>1]=d;d=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(o+3<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;b[c+(f+3<<1)>>1]=(h+2+(i<<1)+j|0)>>>2;b[c+(m<<1)>>1]=(a+(k<<1)+l|0)>>>2;b[c+(o<<1)>>1]=(k+2+(l<<1)+n|0)>>>2;return}function sma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[a-2>>1]|0;k=e[c+(f-1<<1)>>1]|0;l=f<<1;m=e[c+(l-1<<1)>>1]|0;n=f*3|0;o=e[c+(n-1<<1)>>1]|0;p=(d+1+j|0)>>>1&65535;b[c+(f+2<<1)>>1]=p;b[c>>1]=p;p=((d<<1)+2+g+j|0)>>>2&65535;b[c+(f+3<<1)>>1]=p;b[a+2>>1]=p;p=d+2|0;b[a+4>>1]=(p+(g<<1)+h|0)>>>2;b[a+6>>1]=(g+2+(h<<1)+i|0)>>>2;i=(j+1+k|0)>>>1&65535;b[c+(l+2<<1)>>1]=i;b[c+(f<<1)>>1]=i;i=(p+(j<<1)+k|0)>>>2&65535;b[c+(l+3<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;i=(k+1+m|0)>>>1&65535;b[c+(n+2<<1)>>1]=i;b[c+(l<<1)>>1]=i;i=(j+2+(k<<1)+m|0)>>>2&65535;b[c+(n+3<<1)>>1]=i;b[c+((l|1)<<1)>>1]=i;b[c+(n<<1)>>1]=(m+1+o|0)>>>1;b[c+(n+1<<1)>>1]=(k+2+(m<<1)+o|0)>>>2;return}function tma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a;g=d>>1;d=e[f+(-g<<1)>>1]|0;h=e[f+(1-g<<1)>>1]|0;i=e[f+(2-g<<1)>>1]|0;j=e[f+(3-g<<1)>>1]|0;k=e[c>>1]|0;l=e[c+2>>1]|0;m=e[c+4>>1]|0;b[f>>1]=(d+1+h|0)>>>1;c=(h+1+i|0)>>>1&65535;n=g<<1;b[f+(n<<1)>>1]=c;b[a+2>>1]=c;c=(i+1+j|0)>>>1&65535;b[f+((n|1)<<1)>>1]=c;b[a+4>>1]=c;c=(j+1+k|0)>>>1&65535;b[f+(n+2<<1)>>1]=c;b[a+6>>1]=c;b[f+(n+3<<1)>>1]=(k+1+l|0)>>>1;b[f+(g<<1)>>1]=(d+2+(h<<1)+i|0)>>>2;d=(h+2+(i<<1)+j|0)>>>2&65535;h=g*3|0;b[f+(h<<1)>>1]=d;b[f+(g+1<<1)>>1]=d;d=(i+2+(j<<1)+k|0)>>>2&65535;b[f+(h+1<<1)>>1]=d;b[f+(g+2<<1)>>1]=d;d=(j+2+(k<<1)+l|0)>>>2&65535;b[f+(h+2<<1)>>1]=d;b[f+(g+3<<1)>>1]=d;b[f+(h+3<<1)>>1]=(k+2+(l<<1)+m|0)>>>2;return}function uma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=a;f=d>>1;d=e[a-2>>1]|0;g=e[c+(f-1<<1)>>1]|0;h=f<<1;i=e[c+(h-1<<1)>>1]|0;j=f*3|0;k=b[c+(j-1<<1)>>1]|0;l=k&65535;b[c>>1]=(d+1+g|0)>>>1;b[a+2>>1]=(d+2+(g<<1)+i|0)>>>2;d=(g+1+i|0)>>>1&65535;b[c+(f<<1)>>1]=d;b[a+4>>1]=d;d=(g+2+(i<<1)+l|0)>>>2&65535;b[c+(f+1<<1)>>1]=d;b[a+6>>1]=d;d=(i+1+l|0)>>>1&65535;b[c+(h<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;d=(i+2+l+(l<<1)|0)>>>2&65535;b[c+((h|1)<<1)>>1]=d;b[c+(f+3<<1)>>1]=d;b[c+(j+3<<1)>>1]=k;b[c+(j+2<<1)>>1]=k;b[c+(h+2<<1)>>1]=k;b[c+(j<<1)>>1]=k;b[c+(j+1<<1)>>1]=k;b[c+(h+3<<1)>>1]=k;return}function vma(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=gHb(((e[a-2>>1]|0)+2+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;i=F;j=a;c[j>>2]=h;c[j+4>>2]=i;j=b+(f<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(d<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(g<<1)|0;c[j>>2]=h;c[j+4>>2]=i;return}function wma(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0;b=a;f=d>>1;d=gHb(((e[b+(-f<<1)>>1]|0)+2+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+((f*3|0)<<1)|0;c[h>>2]=d;c[h+4>>2]=g;return}function xma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=536879104;c[d+4>>2]=536879104;d=b+(e<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=b+(e<<1<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=b+((e*3|0)<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;return}function yma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=536813567;c[d+4>>2]=536813567;d=b+(e<<1)|0;c[d>>2]=536813567;c[d+4>>2]=536813567;d=b+(e<<1<<1)|0;c[d>>2]=536813567;c[d+4>>2]=536813567;d=b+((e*3|0)<<1)|0;c[d>>2]=536813567;c[d+4>>2]=536813567;return}function zma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=536944641;c[d+4>>2]=536944641;d=b+(e<<1)|0;c[d>>2]=536944641;c[d+4>>2]=536944641;d=b+(e<<1<<1)|0;c[d>>2]=536944641;c[d+4>>2]=536944641;d=b+((e*3|0)<<1)|0;c[d>>2]=536944641;c[d+4>>2]=536944641;return}function Ama(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}b[h>>1]=((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;b[a+2>>1]=(j+2+(k<<1)+l|0)>>>2;b[a+4>>1]=(k+2+(l<<1)+m|0)>>>2;b[a+6>>1]=(l+2+(m<<1)+n|0)>>>2;l=a+8|0;b[l>>1]=(m+2+(n<<1)+o|0)>>>2;b[a+10>>1]=(n+2+(o<<1)+p|0)>>>2;b[a+12>>1]=(o+2+(p<<1)+r|0)>>>2;b[a+14>>1]=((s&65535)+2+(r<<1)+p|0)>>>2;p=a;a=c[p>>2]|0;r=c[p+4>>2]|0;p=l;l=c[p>>2]|0;s=c[p+4>>2]|0;p=h+(i<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(i+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<1;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*3|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<2;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*5|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i*6|0;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*7|0;i=h+(o<<1)|0;c[i>>2]=a;c[i+4>>2]=r;r=h+(o+4<<1)|0;c[r>>2]=l;c[r+4>>2]=s;return}function Bma(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=g<<1;j=e[d+(f-1<<1)>>1]|0;k=g*3|0;l=e[d+(k-1<<1)>>1]|0;m=g<<2;n=e[d+(m-1<<1)>>1]|0;o=g*5|0;p=e[d+(o-1<<1)>>1]|0;q=g*6|0;r=e[d+(q-1<<1)>>1]|0;s=g*7|0;t=e[d+(s-1<<1)>>1]|0;u=gHb(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2,0,65537,65537)|0;h=F;v=a;c[v>>2]=u;c[v+4>>2]=h;v=a+8|0;c[v>>2]=u;c[v+4>>2]=h;h=gHb((b+2+(i<<1)+j|0)>>>2,0,65537,65537)|0;b=F;v=d+(g<<1)|0;c[v>>2]=h;c[v+4>>2]=b;v=d+(g+4<<1)|0;c[v>>2]=h;c[v+4>>2]=b;b=gHb((i+2+(j<<1)+l|0)>>>2,0,65537,65537)|0;i=F;v=d+(f<<1)|0;c[v>>2]=b;c[v+4>>2]=i;v=d+(f+4<<1)|0;c[v>>2]=b;c[v+4>>2]=i;i=gHb((j+2+(l<<1)+n|0)>>>2,0,65537,65537)|0;j=F;v=d+(k<<1)|0;c[v>>2]=i;c[v+4>>2]=j;v=d+(k+4<<1)|0;c[v>>2]=i;c[v+4>>2]=j;j=gHb((l+2+(n<<1)+p|0)>>>2,0,65537,65537)|0;l=F;v=d+(m<<1)|0;c[v>>2]=j;c[v+4>>2]=l;v=d+(m+4<<1)|0;c[v>>2]=j;c[v+4>>2]=l;l=gHb((n+2+(p<<1)+r|0)>>>2,0,65537,65537)|0;n=F;v=d+(o<<1)|0;c[v>>2]=l;c[v+4>>2]=n;v=d+(o+4<<1)|0;c[v>>2]=l;c[v+4>>2]=n;n=gHb((p+2+(r<<1)+t|0)>>>2,0,65537,65537)|0;p=F;v=d+(q<<1)|0;c[v>>2]=n;c[v+4>>2]=p;v=d+(q+4<<1)|0;c[v>>2]=n;c[v+4>>2]=p;p=gHb((r+2+(t*3|0)|0)>>>2,0,65537,65537)|0;t=F;r=d+(s<<1)|0;c[r>>2]=p;c[r+4>>2]=t;r=d+(s+4<<1)|0;c[r>>2]=p;c[r+4>>2]=t;return}function Cma(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=a;i=g>>1;g=(d|0)!=0;if(g){d=~i;j=h+(d<<1)|0;k=a-2|0;l=d}else{d=a-2|0;j=d;k=d;l=~i}d=e[k>>1]|0;k=e[h+(i-1<<1)>>1]|0;m=e[h+((i<<1)-1<<1)>>1]|0;n=e[h+((i*3|0)-1<<1)>>1]|0;o=e[h+((i<<2)-1<<1)>>1]|0;p=e[h+((i*5|0)-1<<1)>>1]|0;q=e[h+((i*6|0)-1<<1)>>1]|0;r=e[h+((i*7|0)-1<<1)>>1]|0;s=-i|0;t=e[h+(s<<1)>>1]|0;u=e[h+(1-i<<1)>>1]|0;v=e[h+(2-i<<1)>>1]|0;w=e[h+(3-i<<1)>>1]|0;x=e[h+(4-i<<1)>>1]|0;y=e[h+(5-i<<1)>>1]|0;z=e[h+(6-i<<1)>>1]|0;A=b[h+(7-i<<1)>>1]|0;B=A&65535;if((f|0)==0){C=A}else{C=b[h+(8-i<<1)>>1]|0}A=(((e[j>>1]|0)+2+(d<<1)+k|0)>>>2)+8+((d+2+(k<<1)+m|0)>>>2)+((k+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q<<1)+r|0)>>>2)+((q+2+(r*3|0)|0)>>>2)+(((e[h+((g?l:s)<<1)>>1]|0)+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+z|0)>>>2)+((y+2+(z<<1)+B|0)>>>2)+(((C&65535)+2+(B<<1)+z|0)>>>2)>>4;z=gHb(A,(A|0)<0|0?-1:0,65537,65537)|0;A=F;B=a;c[B>>2]=z;c[B+4>>2]=A;B=a+8|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=i<<1;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;i=h+(a<<1)|0;c[i>>2]=z;c[i+4>>2]=A;i=h+(a+4<<1)|0;c[i>>2]=z;c[i+4>>2]=A;return}function Dma(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=e[g+(2-h<<1)>>1]|0;l=(i+2+(j<<1)+k|0)>>>2;m=e[g+(3-h<<1)>>1]|0;n=(j+2+(k<<1)+m|0)>>>2;o=e[g+(4-h<<1)>>1]|0;p=(k+2+(m<<1)+o|0)>>>2;k=e[g+(5-h<<1)>>1]|0;q=(m+2+(o<<1)+k|0)>>>2;m=e[g+(6-h<<1)>>1]|0;r=(o+2+(k<<1)+m|0)>>>2;o=b[g+(7-h<<1)>>1]|0;s=o&65535;t=(k+2+(m<<1)+s|0)>>>2;if((d|0)==0){u=s;v=s;w=s;x=s;y=s;z=s;A=s;B=s;C=(o&65535)+2+(s<<1)|0}else{o=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;k=e[g+(10-h<<1)>>1]|0;D=e[g+(11-h<<1)>>1]|0;E=e[g+(12-h<<1)>>1]|0;F=e[g+(13-h<<1)>>1]|0;G=e[g+(14-h<<1)>>1]|0;H=e[g+(15-h<<1)>>1]|0;u=(G+2+(H*3|0)|0)>>>2;v=(F+2+(G<<1)+H|0)>>>2;w=(E+2+(F<<1)+G|0)>>>2;x=(D+2+(E<<1)+F|0)>>>2;y=(k+2+(D<<1)+E|0)>>>2;z=(d+2+(k<<1)+D|0)>>>2;A=(o+2+(d<<1)+k|0)>>>2;B=(s+2+(o<<1)+d|0)>>>2;C=(e[g+(8-h<<1)>>1]|0)+2+(s<<1)|0}s=(C+m|0)>>>2;b[g>>1]=((((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2)+2+(l<<1)+n|0)>>>2;j=(l+2+(n<<1)+p|0)>>>2&65535;b[a+2>>1]=j;b[g+(h<<1)>>1]=j;j=(n+2+(p<<1)+q|0)>>>2&65535;b[a+4>>1]=j;b[g+(h+1<<1)>>1]=j;n=h<<1;b[g+(n<<1)>>1]=j;j=(p+2+(q<<1)+r|0)>>>2&65535;b[a+6>>1]=j;b[g+(h+2<<1)>>1]=j;b[g+((n|1)<<1)>>1]=j;p=h*3|0;b[g+(p<<1)>>1]=j;j=(q+2+(r<<1)+t|0)>>>2&65535;b[a+8>>1]=j;b[g+(h+3<<1)>>1]=j;b[g+(n+2<<1)>>1]=j;b[g+(p+1<<1)>>1]=j;q=h<<2;b[g+(q<<1)>>1]=j;j=(r+2+(t<<1)+s|0)>>>2&65535;b[a+10>>1]=j;b[g+(h+4<<1)>>1]=j;b[g+(n+3<<1)>>1]=j;b[g+(p+2<<1)>>1]=j;b[g+((q|1)<<1)>>1]=j;r=h*5|0;b[g+(r<<1)>>1]=j;j=(t+2+(s<<1)+B|0)>>>2&65535;b[a+12>>1]=j;b[g+(h+5<<1)>>1]=j;b[g+(n+4<<1)>>1]=j;b[g+(p+3<<1)>>1]=j;b[g+((q|2)<<1)>>1]=j;b[g+(r+1<<1)>>1]=j;t=h*6|0;b[g+(t<<1)>>1]=j;j=(s+2+(B<<1)+A|0)>>>2&65535;b[a+14>>1]=j;b[g+(h+6<<1)>>1]=j;b[g+(n+5<<1)>>1]=j;b[g+(p+4<<1)>>1]=j;b[g+((q|3)<<1)>>1]=j;b[g+(r+2<<1)>>1]=j;b[g+((t|1)<<1)>>1]=j;a=h*7|0;b[g+(a<<1)>>1]=j;j=(B+2+(A<<1)+z|0)>>>2&65535;b[g+(h+7<<1)>>1]=j;b[g+(n+6<<1)>>1]=j;b[g+(p+5<<1)>>1]=j;b[g+(q+4<<1)>>1]=j;b[g+(r+3<<1)>>1]=j;b[g+(t+2<<1)>>1]=j;b[g+(a+1<<1)>>1]=j;j=(A+2+(z<<1)+y|0)>>>2&65535;b[g+(n+7<<1)>>1]=j;b[g+(p+6<<1)>>1]=j;b[g+(q+5<<1)>>1]=j;b[g+(r+4<<1)>>1]=j;b[g+(t+3<<1)>>1]=j;b[g+(a+2<<1)>>1]=j;j=(z+2+(y<<1)+x|0)>>>2&65535;b[g+(p+7<<1)>>1]=j;b[g+(q+6<<1)>>1]=j;b[g+(r+5<<1)>>1]=j;b[g+(t+4<<1)>>1]=j;b[g+(a+3<<1)>>1]=j;j=(y+2+(x<<1)+w|0)>>>2&65535;b[g+(q+7<<1)>>1]=j;b[g+(r+6<<1)>>1]=j;b[g+(t+5<<1)>>1]=j;b[g+(a+4<<1)>>1]=j;j=(x+2+(w<<1)+v|0)>>>2&65535;b[g+(r+7<<1)>>1]=j;b[g+(t+6<<1)>>1]=j;b[g+(a+5<<1)>>1]=j;j=(w+2+(v<<1)+u|0)>>>2&65535;b[g+(t+7<<1)>>1]=j;b[g+(a+6<<1)>>1]=j;b[g+(a+7<<1)>>1]=(v+2+(u*3|0)|0)>>>2;return}function Ema(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;k=e[g+(v-1<<1)>>1]|0;d=i+2|0;i=(d+(w<<1)+k|0)>>>2;c=h*3|0;y=e[g+(c-1<<1)>>1]|0;z=(w+2+(k<<1)+y|0)>>>2;w=h<<2;A=e[g+(w-1<<1)>>1]|0;B=(k+2+(y<<1)+A|0)>>>2;k=h*5|0;C=e[g+(k-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*6|0;E=e[g+(y-1<<1)>>1]|0;F=(A+2+(C<<1)+E|0)>>>2;A=h*7|0;G=e[g+(A-1<<1)>>1]|0;H=(C+2+(E<<1)+G|0)>>>2;C=(d+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(A<<1)>>1]=(F+2+((E+2+(G*3|0)|0)>>>2)+(H<<1)|0)>>>2;G=(D+2+(F<<1)+H|0)>>>2&65535;b[g+(A+1<<1)>>1]=G;b[g+(y<<1)>>1]=G;G=(B+2+(D<<1)+F|0)>>>2&65535;b[g+(A+2<<1)>>1]=G;b[g+((y|1)<<1)>>1]=G;b[g+(k<<1)>>1]=G;G=(z+2+(B<<1)+D|0)>>>2&65535;b[g+(A+3<<1)>>1]=G;b[g+(y+2<<1)>>1]=G;b[g+(k+1<<1)>>1]=G;b[g+(w<<1)>>1]=G;G=(i+2+(z<<1)+B|0)>>>2&65535;b[g+(A+4<<1)>>1]=G;b[g+(y+3<<1)>>1]=G;b[g+(k+2<<1)>>1]=G;b[g+((w|1)<<1)>>1]=G;b[g+(c<<1)>>1]=G;G=(f+2+(i<<1)+z|0)>>>2&65535;b[g+(A+5<<1)>>1]=G;b[g+(y+4<<1)>>1]=G;b[g+(k+3<<1)>>1]=G;b[g+((w|2)<<1)>>1]=G;b[g+(c+1<<1)>>1]=G;b[g+(v<<1)>>1]=G;G=((f<<1)+2+i+C|0)>>>2&65535;b[g+(A+6<<1)>>1]=G;b[g+(y+5<<1)>>1]=G;b[g+(k+4<<1)>>1]=G;b[g+((w|3)<<1)>>1]=G;b[g+(c+2<<1)>>1]=G;b[g+((v|1)<<1)>>1]=G;b[g+(h<<1)>>1]=G;G=l+2|0;i=(G+f+(C<<1)|0)>>>2&65535;b[g+(A+7<<1)>>1]=i;b[g+(y+6<<1)>>1]=i;b[g+(k+5<<1)>>1]=i;b[g+(w+4<<1)>>1]=i;b[g+(c+3<<1)>>1]=i;b[g+(v+2<<1)>>1]=i;b[g+(h+1<<1)>>1]=i;b[g>>1]=i;i=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+7<<1)>>1]=i;b[g+(k+6<<1)>>1]=i;b[g+(w+5<<1)>>1]=i;b[g+(c+4<<1)>>1]=i;b[g+(v+3<<1)>>1]=i;b[g+(h+2<<1)>>1]=i;b[a+2>>1]=i;i=(G+(m<<1)+o|0)>>>2&65535;b[g+(k+7<<1)>>1]=i;b[g+(w+6<<1)>>1]=i;b[g+(c+5<<1)>>1]=i;b[g+(v+4<<1)>>1]=i;b[g+(h+3<<1)>>1]=i;b[a+4>>1]=i;i=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(w+7<<1)>>1]=i;b[g+(c+6<<1)>>1]=i;b[g+(v+5<<1)>>1]=i;b[g+(h+4<<1)>>1]=i;b[a+6>>1]=i;i=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(c+7<<1)>>1]=i;b[g+(v+6<<1)>>1]=i;b[g+(h+5<<1)>>1]=i;b[a+8>>1]=i;i=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(v+7<<1)>>1]=i;b[g+(h+6<<1)>>1]=i;b[a+10>>1]=i;i=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(h+7<<1)>>1]=i;b[a+12>>1]=i;b[a+14>>1]=(r+2+(t<<1)+(((u&65535)+2+(s<<1)+n|0)>>>2)|0)>>>2;return}function Fma(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}k=((u&65535)+2+(s<<1)+n|0)>>>2;if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;n=e[g+(v-1<<1)>>1]|0;s=i+2|0;i=(s+(w<<1)+n|0)>>>2;u=h*3|0;d=e[g+(u-1<<1)>>1]|0;c=(w+2+(n<<1)+d|0)>>>2;w=h<<2;y=e[g+(w-1<<1)>>1]|0;z=(n+2+(d<<1)+y|0)>>>2;n=h*5|0;A=e[g+(n-1<<1)>>1]|0;B=(d+2+(y<<1)+A|0)>>>2;d=h*6|0;C=e[g+(d-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*7|0;E=(A+2+(C<<1)+(e[g+(y-1<<1)>>1]|0)|0)>>>2;C=(s+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(d<<1)>>1]=(z+2+(B<<1)+D|0)>>>2;b[g+(y<<1)>>1]=(B+2+(D<<1)+E|0)>>>2;E=(i+2+(c<<1)+z|0)>>>2&65535;b[g+((d|1)<<1)>>1]=E;b[g+(w<<1)>>1]=E;E=(c+2+(z<<1)+B|0)>>>2&65535;b[g+(y+1<<1)>>1]=E;b[g+(n<<1)>>1]=E;E=((f<<1)+2+i+C|0)>>>2&65535;b[g+(d+2<<1)>>1]=E;b[g+((w|1)<<1)>>1]=E;b[g+(v<<1)>>1]=E;E=(f+2+(i<<1)+c|0)>>>2&65535;b[g+(y+2<<1)>>1]=E;b[g+(n+1<<1)>>1]=E;b[g+(u<<1)>>1]=E;E=l+2|0;c=(E+f+(C<<1)|0)>>>2&65535;b[g+(y+3<<1)>>1]=c;b[g+(n+2<<1)>>1]=c;b[g+(u+1<<1)>>1]=c;b[g+(h<<1)>>1]=c;c=l+1|0;f=(c+C|0)>>>1&65535;b[g+(d+3<<1)>>1]=f;b[g+((w|2)<<1)>>1]=f;b[g+((v|1)<<1)>>1]=f;b[g>>1]=f;f=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+4<<1)>>1]=f;b[g+(n+3<<1)>>1]=f;b[g+(u+2<<1)>>1]=f;b[g+(h+1<<1)>>1]=f;f=(c+m|0)>>>1&65535;b[g+(d+4<<1)>>1]=f;b[g+((w|3)<<1)>>1]=f;b[g+(v+2<<1)>>1]=f;b[a+2>>1]=f;f=(E+(m<<1)+o|0)>>>2&65535;b[g+(y+5<<1)>>1]=f;b[g+(n+4<<1)>>1]=f;b[g+(u+3<<1)>>1]=f;b[g+(h+2<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[g+(d+5<<1)>>1]=f;b[g+(w+4<<1)>>1]=f;b[g+(v+3<<1)>>1]=f;b[a+4>>1]=f;f=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(y+6<<1)>>1]=f;b[g+(n+5<<1)>>1]=f;b[g+(u+4<<1)>>1]=f;b[g+(h+3<<1)>>1]=f;f=(o+1+p|0)>>>1&65535;b[g+(d+6<<1)>>1]=f;b[g+(w+5<<1)>>1]=f;b[g+(v+4<<1)>>1]=f;b[a+6>>1]=f;f=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(y+7<<1)>>1]=f;b[g+(n+6<<1)>>1]=f;b[g+(u+5<<1)>>1]=f;b[g+(h+4<<1)>>1]=f;f=(p+1+q|0)>>>1&65535;b[g+(d+7<<1)>>1]=f;b[g+(w+6<<1)>>1]=f;b[g+(v+5<<1)>>1]=f;b[a+8>>1]=f;f=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(n+7<<1)>>1]=f;b[g+(u+6<<1)>>1]=f;b[g+(h+5<<1)>>1]=f;f=(q+1+r|0)>>>1&65535;b[g+(w+7<<1)>>1]=f;b[g+(v+6<<1)>>1]=f;b[a+10>>1]=f;f=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(u+7<<1)>>1]=f;b[g+(h+6<<1)>>1]=f;f=(r+1+t|0)>>>1&65535;b[g+(v+7<<1)>>1]=f;b[a+12>>1]=f;b[g+(h+7<<1)>>1]=(r+2+(t<<1)+k|0)>>>2;b[a+14>>1]=(t+1+k|0)>>>1;return}function Gma(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=a;g=f>>1;f=(c|0)!=0;c=-g|0;h=~g;i=e[d+(c<<1)>>1]|0;j=e[d+(1-g<<1)>>1]|0;k=((e[d+((f?h:c)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;c=e[d+(2-g<<1)>>1]|0;l=(i+2+(j<<1)+c|0)>>>2;m=e[d+(3-g<<1)>>1]|0;n=(j+2+(c<<1)+m|0)>>>2;j=e[d+(4-g<<1)>>1]|0;o=(c+2+(m<<1)+j|0)>>>2;c=e[d+(5-g<<1)>>1]|0;p=(m+2+(j<<1)+c|0)>>>2;m=e[d+(6-g<<1)>>1]|0;q=(j+2+(c<<1)+m|0)>>>2;j=(c+2+(m<<1)+(e[d+(7-g<<1)>>1]|0)|0)>>>2;if(f){f=d+(h<<1)|0;r=f;s=a-2|0;t=f}else{f=a-2|0;r=f;s=f;t=d+(h<<1)|0}h=e[s>>1]|0;s=e[d+(g-1<<1)>>1]|0;f=((e[r>>1]|0)+2+(h<<1)+s|0)>>>2;r=g<<1;m=e[d+(r-1<<1)>>1]|0;c=h+2|0;h=(c+(s<<1)+m|0)>>>2;u=g*3|0;v=e[d+(u-1<<1)>>1]|0;w=(s+2+(m<<1)+v|0)>>>2;s=g<<2;x=e[d+(s-1<<1)>>1]|0;y=(m+2+(v<<1)+x|0)>>>2;m=g*5|0;z=e[d+(m-1<<1)>>1]|0;A=(v+2+(x<<1)+z|0)>>>2;v=g*6|0;B=e[d+(v-1<<1)>>1]|0;C=(x+2+(z<<1)+B|0)>>>2;x=g*7|0;D=e[d+(x-1<<1)>>1]|0;E=(z+2+(B<<1)+D|0)>>>2;z=(B+2+(D*3|0)|0)>>>2;D=(c+((e[t>>1]|0)<<1)+i|0)>>>2;b[d+(x<<1)>>1]=(z+1+E|0)>>>1;b[d+(x+1<<1)>>1]=(C+2+z+(E<<1)|0)>>>2;z=(C+1+E|0)>>>1&65535;b[d+(x+2<<1)>>1]=z;b[d+(v<<1)>>1]=z;z=(A+2+(C<<1)+E|0)>>>2&65535;b[d+(x+3<<1)>>1]=z;b[d+((v|1)<<1)>>1]=z;z=(A+1+C|0)>>>1&65535;b[d+(x+4<<1)>>1]=z;b[d+(v+2<<1)>>1]=z;b[d+(m<<1)>>1]=z;z=(y+2+(A<<1)+C|0)>>>2&65535;b[d+(x+5<<1)>>1]=z;b[d+(v+3<<1)>>1]=z;b[d+(m+1<<1)>>1]=z;z=(y+1+A|0)>>>1&65535;b[d+(x+6<<1)>>1]=z;b[d+(v+4<<1)>>1]=z;b[d+(m+2<<1)>>1]=z;b[d+(s<<1)>>1]=z;z=(w+2+(y<<1)+A|0)>>>2&65535;b[d+(x+7<<1)>>1]=z;b[d+(v+5<<1)>>1]=z;b[d+(m+3<<1)>>1]=z;b[d+((s|1)<<1)>>1]=z;z=(w+1+y|0)>>>1&65535;b[d+(v+6<<1)>>1]=z;b[d+(m+4<<1)>>1]=z;b[d+((s|2)<<1)>>1]=z;b[d+(u<<1)>>1]=z;z=(h+2+(w<<1)+y|0)>>>2&65535;b[d+(v+7<<1)>>1]=z;b[d+(m+5<<1)>>1]=z;b[d+((s|3)<<1)>>1]=z;b[d+(u+1<<1)>>1]=z;z=(h+1+w|0)>>>1&65535;b[d+(m+6<<1)>>1]=z;b[d+(s+4<<1)>>1]=z;b[d+(u+2<<1)>>1]=z;b[d+(r<<1)>>1]=z;z=(f+2+(h<<1)+w|0)>>>2&65535;b[d+(m+7<<1)>>1]=z;b[d+(s+5<<1)>>1]=z;b[d+(u+3<<1)>>1]=z;b[d+((r|1)<<1)>>1]=z;z=f+1|0;m=(z+h|0)>>>1&65535;b[d+(s+6<<1)>>1]=m;b[d+(u+4<<1)>>1]=m;b[d+(r+2<<1)>>1]=m;b[d+(g<<1)>>1]=m;m=((f<<1)+2+h+D|0)>>>2&65535;b[d+(s+7<<1)>>1]=m;b[d+(u+5<<1)>>1]=m;b[d+(r+3<<1)>>1]=m;b[d+(g+1<<1)>>1]=m;m=(z+D|0)>>>1&65535;b[d+(u+6<<1)>>1]=m;b[d+(r+4<<1)>>1]=m;b[d+(g+2<<1)>>1]=m;b[d>>1]=m;m=k+2|0;z=(m+f+(D<<1)|0)>>>2&65535;b[d+(u+7<<1)>>1]=z;b[d+(r+5<<1)>>1]=z;b[d+(g+3<<1)>>1]=z;b[a+2>>1]=z;z=((k<<1)+2+l+D|0)>>>2&65535;b[d+(r+6<<1)>>1]=z;b[d+(g+4<<1)>>1]=z;b[a+4>>1]=z;z=(m+(l<<1)+n|0)>>>2&65535;b[d+(r+7<<1)>>1]=z;b[d+(g+5<<1)>>1]=z;b[a+6>>1]=z;z=(l+2+(n<<1)+o|0)>>>2&65535;b[d+(g+6<<1)>>1]=z;b[a+8>>1]=z;z=(n+2+(o<<1)+p|0)>>>2&65535;b[d+(g+7<<1)>>1]=z;b[a+10>>1]=z;b[a+12>>1]=(o+2+(p<<1)+q|0)>>>2;b[a+14>>1]=(p+2+(q<<1)+j|0)>>>2;return}function Hma(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;f=e[g+(2-h<<1)>>1]|0;c=(i+2+(j<<1)+f|0)>>>2;i=e[g+(3-h<<1)>>1]|0;l=(j+2+(f<<1)+i|0)>>>2;j=e[g+(4-h<<1)>>1]|0;m=(f+2+(i<<1)+j|0)>>>2;f=e[g+(5-h<<1)>>1]|0;n=(i+2+(j<<1)+f|0)>>>2;i=e[g+(6-h<<1)>>1]|0;o=(j+2+(f<<1)+i|0)>>>2;j=b[g+(7-h<<1)>>1]|0;p=j&65535;q=(f+2+(i<<1)+p|0)>>>2;if((d|0)==0){r=p;s=p;t=p;u=p;v=p;w=(j&65535)+2+(p<<1)|0}else{j=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;f=e[g+(10-h<<1)>>1]|0;x=e[g+(11-h<<1)>>1]|0;y=e[g+(12-h<<1)>>1]|0;r=(x+2+(y<<1)+(e[g+(13-h<<1)>>1]|0)|0)>>>2;s=(f+2+(x<<1)+y|0)>>>2;t=(d+2+(f<<1)+x|0)>>>2;u=(j+2+(d<<1)+f|0)>>>2;v=(p+2+(j<<1)+d|0)>>>2;w=(e[g+(8-h<<1)>>1]|0)+2+(p<<1)|0}p=(w+i|0)>>>2;b[g>>1]=(k+1+c|0)>>>1;b[g+(h<<1)>>1]=(k+2+(c<<1)+l|0)>>>2;k=(c+1+l|0)>>>1&65535;b[a+2>>1]=k;i=h<<1;b[g+(i<<1)>>1]=k;k=(c+2+(l<<1)+m|0)>>>2&65535;b[g+(h+1<<1)>>1]=k;c=h*3|0;b[g+(c<<1)>>1]=k;k=(l+1+m|0)>>>1&65535;b[a+4>>1]=k;b[g+((i|1)<<1)>>1]=k;w=h<<2;b[g+(w<<1)>>1]=k;k=(l+2+(m<<1)+n|0)>>>2&65535;b[g+(h+2<<1)>>1]=k;b[g+(c+1<<1)>>1]=k;l=h*5|0;b[g+(l<<1)>>1]=k;k=(m+1+n|0)>>>1&65535;b[a+6>>1]=k;b[g+(i+2<<1)>>1]=k;b[g+((w|1)<<1)>>1]=k;d=h*6|0;b[g+(d<<1)>>1]=k;k=(m+2+(n<<1)+o|0)>>>2&65535;b[g+(h+3<<1)>>1]=k;b[g+(c+2<<1)>>1]=k;b[g+(l+1<<1)>>1]=k;m=h*7|0;b[g+(m<<1)>>1]=k;k=(n+1+o|0)>>>1&65535;b[a+8>>1]=k;b[g+(i+3<<1)>>1]=k;b[g+((w|2)<<1)>>1]=k;b[g+((d|1)<<1)>>1]=k;k=(n+2+(o<<1)+q|0)>>>2&65535;b[g+(h+4<<1)>>1]=k;b[g+(c+3<<1)>>1]=k;b[g+(l+2<<1)>>1]=k;b[g+(m+1<<1)>>1]=k;k=(o+1+q|0)>>>1&65535;b[a+10>>1]=k;b[g+(i+4<<1)>>1]=k;b[g+((w|3)<<1)>>1]=k;b[g+(d+2<<1)>>1]=k;k=(o+2+(q<<1)+p|0)>>>2&65535;b[g+(h+5<<1)>>1]=k;b[g+(c+4<<1)>>1]=k;b[g+(l+3<<1)>>1]=k;b[g+(m+2<<1)>>1]=k;k=(q+1+p|0)>>>1&65535;b[a+12>>1]=k;b[g+(i+5<<1)>>1]=k;b[g+(w+4<<1)>>1]=k;b[g+(d+3<<1)>>1]=k;k=(q+2+(p<<1)+v|0)>>>2&65535;b[g+(h+6<<1)>>1]=k;b[g+(c+5<<1)>>1]=k;b[g+(l+4<<1)>>1]=k;b[g+(m+3<<1)>>1]=k;k=(p+1+v|0)>>>1&65535;b[a+14>>1]=k;b[g+(i+6<<1)>>1]=k;b[g+(w+5<<1)>>1]=k;b[g+(d+4<<1)>>1]=k;k=(p+2+(v<<1)+u|0)>>>2&65535;b[g+(h+7<<1)>>1]=k;b[g+(c+6<<1)>>1]=k;b[g+(l+5<<1)>>1]=k;b[g+(m+4<<1)>>1]=k;k=(v+1+u|0)>>>1&65535;b[g+(i+7<<1)>>1]=k;b[g+(w+6<<1)>>1]=k;b[g+(d+5<<1)>>1]=k;k=(v+2+(u<<1)+t|0)>>>2&65535;b[g+(c+7<<1)>>1]=k;b[g+(l+6<<1)>>1]=k;b[g+(m+5<<1)>>1]=k;k=(u+1+t|0)>>>1&65535;b[g+(w+7<<1)>>1]=k;b[g+(d+6<<1)>>1]=k;k=(u+2+(t<<1)+s|0)>>>2&65535;b[g+(l+7<<1)>>1]=k;b[g+(m+6<<1)>>1]=k;b[g+(d+7<<1)>>1]=(t+1+s|0)>>>1;b[g+(m+7<<1)>>1]=(t+2+(s<<1)+r|0)>>>2;return}function Ima(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a;g=f>>1;if((c|0)==0){c=a-2|0;h=c;i=c}else{h=d+(~g<<1)|0;i=a-2|0}c=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=((e[h>>1]|0)+2+(c<<1)+i|0)>>>2;h=g<<1;j=e[d+(h-1<<1)>>1]|0;k=(c+2+(i<<1)+j|0)>>>2;c=g*3|0;l=e[d+(c-1<<1)>>1]|0;m=(i+2+(j<<1)+l|0)>>>2;i=g<<2;n=e[d+(i-1<<1)>>1]|0;o=(j+2+(l<<1)+n|0)>>>2;j=g*5|0;p=e[d+(j-1<<1)>>1]|0;q=(l+2+(n<<1)+p|0)>>>2;l=g*6|0;r=e[d+(l-1<<1)>>1]|0;s=(n+2+(p<<1)+r|0)>>>2;n=g*7|0;t=e[d+(n-1<<1)>>1]|0;u=(p+2+(r<<1)+t|0)>>>2;p=(r+2+(t*3|0)|0)>>>2;b[d>>1]=(f+1+k|0)>>>1;b[a+2>>1]=(f+2+(k<<1)+m|0)>>>2;f=(k+1+m|0)>>>1&65535;b[a+4>>1]=f;b[d+(g<<1)>>1]=f;f=(k+2+(m<<1)+o|0)>>>2&65535;b[a+6>>1]=f;b[d+(g+1<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[a+8>>1]=f;b[d+(g+2<<1)>>1]=f;b[d+(h<<1)>>1]=f;f=(m+2+(o<<1)+q|0)>>>2&65535;b[a+10>>1]=f;b[d+(g+3<<1)>>1]=f;b[d+((h|1)<<1)>>1]=f;f=(o+1+q|0)>>>1&65535;b[a+12>>1]=f;b[d+(g+4<<1)>>1]=f;b[d+(h+2<<1)>>1]=f;b[d+(c<<1)>>1]=f;f=(o+2+(q<<1)+s|0)>>>2&65535;b[a+14>>1]=f;b[d+(g+5<<1)>>1]=f;b[d+(h+3<<1)>>1]=f;b[d+(c+1<<1)>>1]=f;f=(q+1+s|0)>>>1&65535;b[d+(g+6<<1)>>1]=f;b[d+(h+4<<1)>>1]=f;b[d+(c+2<<1)>>1]=f;b[d+(i<<1)>>1]=f;f=(q+2+(s<<1)+u|0)>>>2&65535;b[d+(g+7<<1)>>1]=f;b[d+(h+5<<1)>>1]=f;b[d+(c+3<<1)>>1]=f;b[d+((i|1)<<1)>>1]=f;f=(s+1+u|0)>>>1&65535;b[d+(h+6<<1)>>1]=f;b[d+(c+4<<1)>>1]=f;b[d+((i|2)<<1)>>1]=f;b[d+(j<<1)>>1]=f;f=(s+2+p+(u<<1)|0)>>>2&65535;b[d+(h+7<<1)>>1]=f;b[d+(c+5<<1)>>1]=f;b[d+((i|3)<<1)>>1]=f;b[d+(j+1<<1)>>1]=f;f=(p+1+u|0)>>>1&65535;b[d+(c+6<<1)>>1]=f;b[d+(i+4<<1)>>1]=f;b[d+(j+2<<1)>>1]=f;b[d+(l<<1)>>1]=f;f=(u+2+(p*3|0)|0)>>>2&65535;b[d+(c+7<<1)>>1]=f;b[d+(i+5<<1)>>1]=f;b[d+(j+3<<1)>>1]=f;b[d+((l|1)<<1)>>1]=f;f=p&65535;b[d+(n+7<<1)>>1]=f;b[d+(l+7<<1)>>1]=f;b[d+(j+7<<1)>>1]=f;b[d+(i+7<<1)>>1]=f;b[d+(n+6<<1)>>1]=f;b[d+(l+6<<1)>>1]=f;b[d+(j+6<<1)>>1]=f;b[d+(i+6<<1)>>1]=f;b[d+(n+5<<1)>>1]=f;b[d+(l+5<<1)>>1]=f;b[d+(j+5<<1)>>1]=f;b[d+(n+4<<1)>>1]=f;b[d+(l+4<<1)>>1]=f;b[d+(j+4<<1)>>1]=f;b[d+(n+3<<1)>>1]=f;b[d+(l+3<<1)>>1]=f;b[d+(n+2<<1)>>1]=f;b[d+(l+2<<1)>>1]=f;b[d+(n+1<<1)>>1]=f;b[d+(n<<1)>>1]=f;return}function Jma(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=e[d+((g<<1)-1<<1)>>1]|0;j=e[d+((g*3|0)-1<<1)>>1]|0;k=e[d+((g<<2)-1<<1)>>1]|0;l=e[d+((g*5|0)-1<<1)>>1]|0;m=e[d+((g*6|0)-1<<1)>>1]|0;n=e[d+((g*7|0)-1<<1)>>1]|0;o=(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2)+4+((b+2+(i<<1)+f|0)>>>2)+((i+2+(f<<1)+j|0)>>>2)+((f+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n*3|0)|0)>>>2)>>3;n=gHb(o,(o|0)<0|0?-1:0,65537,65537)|0;o=F;m=a;c[m>>2]=n;c[m+4>>2]=o;m=a+8|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=g<<1;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;g=d+(a<<1)|0;c[g>>2]=n;c[g+4>>2]=o;g=d+(a+4<<1)|0;c[g>>2]=n;c[g+4>>2]=o;return}function Kma(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}q=(((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2)+4+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+r|0)>>>2)+(((s&65535)+2+(r<<1)+p|0)>>>2)>>3;p=gHb(q,(q|0)<0|0?-1:0,65537,65537)|0;q=F;r=a;c[r>>2]=p;c[r+4>>2]=q;r=a+8|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=i<<1;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;i=h+(a<<1)|0;c[i>>2]=p;c[i+4>>2]=q;i=h+(a+4<<1)|0;c[i>>2]=p;c[i+4>>2]=q;return}function Lma(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;b=e>>1;e=a;c[e>>2]=536879104;c[e+4>>2]=536879104;e=a+8|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(b<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(b+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=b<<1;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e+b|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;return}function Mma(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function Nma(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=gHb(e[a-2>>1]|0,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=a+8|0;c[h>>2]=b;c[h+4>>2]=g;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;b=d+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(f+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f<<1;b=gHb(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=F;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*3|0;a=gHb(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;b=F;h=d+(g<<1)|0;c[h>>2]=a;c[h+4>>2]=b;h=d+(g+4<<1)|0;c[h>>2]=a;c[h+4>>2]=b;b=f<<2;h=gHb(e[d+(b-1<<1)>>1]|0,0,65537,65537)|0;a=F;g=d+(b<<1)|0;c[g>>2]=h;c[g+4>>2]=a;g=d+(b+4<<1)|0;c[g>>2]=h;c[g+4>>2]=a;a=f*5|0;g=gHb(e[d+(a-1<<1)>>1]|0,0,65537,65537)|0;h=F;b=d+(a<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(a+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f*6|0;b=gHb(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=F;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*7|0;f=gHb(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;a=F;b=d+(g<<1)|0;c[b>>2]=f;c[b+4>>2]=a;b=d+(g+4<<1)|0;c[b>>2]=f;c[b+4>>2]=a;return}function Oma(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<3;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+((b|4)<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*9|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*10|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*11|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*12|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*13|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*14|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*15|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function Pma(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ba(b,a)|0;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function Qma(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a;f=c>>1;c=a+6|0;g=(f<<2)-1|0;h=g-(f<<1)|0;i=g+f|0;j=h-f|0;k=i+f|0;l=j-f|0;m=e[d+(k+f<<1)>>1]|0;n=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=(((m-(e[d+(l-f<<1)>>1]|0)<<2)+((((e[d+(k<<1)>>1]|0)-(e[d+(l<<1)>>1]|0)|0)*3|0)+(((e[d+(i<<1)>>1]|0)-(e[d+(j<<1)>>1]|0)<<1)+((e[d+(g<<1)>>1]|0)-(e[d+(h<<1)>>1]|0))))|0)*17|0)+16>>5;h=n<<1;g=n*3|0;j=n<<2;i=n*5|0;l=n*6|0;k=n*7|0;o=d;d=((c+n|0)*-3|0)+16+((e[a-2+(8-f<<1)>>1]|0)+m<<4)|0;m=8;while(1){a=d>>5;if(a>>>0<16384>>>0){p=a&65535}else{p=-a>>31&16383}b[o>>1]=p;a=d+n>>5;if(a>>>0<16384>>>0){q=a&65535}else{q=-a>>31&16383}b[o+2>>1]=q;a=d+h>>5;if(a>>>0<16384>>>0){r=a&65535}else{r=-a>>31&16383}b[o+4>>1]=r;a=d+g>>5;if(a>>>0<16384>>>0){s=a&65535}else{s=-a>>31&16383}b[o+6>>1]=s;a=d+j>>5;if(a>>>0<16384>>>0){t=a&65535}else{t=-a>>31&16383}b[o+8>>1]=t;a=d+i>>5;if(a>>>0<16384>>>0){u=a&65535}else{u=-a>>31&16383}b[o+10>>1]=u;a=d+l>>5;if(a>>>0<16384>>>0){v=a&65535}else{v=-a>>31&16383}b[o+12>>1]=v;a=d+k>>5;if(a>>>0<16384>>>0){w=a&65535}else{w=-a>>31&16383}b[o+14>>1]=w;a=m-1|0;if((a|0)>0){o=o+(f<<1)|0;d=d+c|0;m=a}else{break}}return}function Rma(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a;f=c>>1;c=a+6|0;g=-f|0;h=(f<<3)-1|0;i=h-(f<<1)|0;j=h+f|0;k=i-f|0;l=j+f|0;m=k-f|0;n=a+((f*6|0)-2)|0;o=a+((f*22|0)-2)|0;p=f<<1;q=g<<1;r=p+f|0;s=q-f|0;t=b[o+(r+f<<1)>>1]|0;u=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=((((t&65535)-(e[n+(s-f<<1)>>1]|0)<<3)+((((e[o+(r<<1)>>1]|0)-(e[n+(s<<1)>>1]|0)|0)*7|0)+((((e[o+(p<<1)>>1]|0)-(e[n+(q<<1)>>1]|0)|0)*6|0)+((((e[o+(f<<1)>>1]|0)-(e[n+(g<<1)>>1]|0)|0)*5|0)+(((e[d+(l+f<<1)>>1]|0)-(e[d+(m-f<<1)>>1]|0)<<2)+((((e[d+(l<<1)>>1]|0)-(e[d+(m<<1)>>1]|0)|0)*3|0)+(((e[d+(j<<1)>>1]|0)-(e[d+(k<<1)>>1]|0)<<1)+((e[d+(h<<1)>>1]|0)-(e[d+(i<<1)>>1]|0))))))))|0)*5|0)+32>>6;i=u*3|0;h=u<<1;k=u<<2;j=u*5|0;m=u*6|0;l=u*7|0;g=d;d=16-i+(c*-7|0)+((e[a+(-2-(f<<1)+16)>>1]|0)+(t&65535)<<4)|0;t=16;while(1){a=d>>5;if(a>>>0<16384>>>0){v=a&65535}else{v=-a>>31&16383}b[g>>1]=v;a=d+u>>5;if(a>>>0<16384>>>0){w=a&65535}else{w=-a>>31&16383}b[g+2>>1]=w;a=d+h>>5;if(a>>>0<16384>>>0){x=a&65535}else{x=-a>>31&16383}b[g+4>>1]=x;a=d+i>>5;if(a>>>0<16384>>>0){y=a&65535}else{y=-a>>31&16383}b[g+6>>1]=y;a=d+k>>5;if(a>>>0<16384>>>0){z=a&65535}else{z=-a>>31&16383}b[g+8>>1]=z;a=d+j>>5;if(a>>>0<16384>>>0){A=a&65535}else{A=-a>>31&16383}b[g+10>>1]=A;a=d+m>>5;if(a>>>0<16384>>>0){B=a&65535}else{B=-a>>31&16383}b[g+12>>1]=B;a=d+l>>5;if(a>>>0<16384>>>0){C=a&65535}else{C=-a>>31&16383}b[g+14>>1]=C;a=t-1|0;if((a|0)>0){g=g+(f<<1)|0;d=d+c|0;t=a}else{break}}return}function Sma(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=(e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+(e[d+(4-f<<1)>>1]|0)))|0;l=f*7|0;m=(e[d+(l-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;n=(e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+((e[a-2>>1]|0)+(e[d+(-f<<1)>>1]|0))+(e[d+(1-f<<1)>>1]|0))+(e[d+(2-f<<1)>>1]|0))+(e[d+(3-f<<1)>>1]|0)+4>>3;o=gHb(n,(n|0)<0|0?-1:0,65537,65537)|0;n=F;p=gHb((k+2|0)>>>2,0,65537,65537)|0;q=F;r=m+4+k>>3;k=a;c[k>>2]=o;c[k+4>>2]=n;k=a+8|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(f<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(f+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(h<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(h+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(j<<1)|0;c[k>>2]=o;c[k+4>>2]=n;n=d+(j+4<<1)|0;c[n>>2]=p;c[n+4>>2]=q;q=gHb((m+2|0)>>>2,0,65537,65537)|0;m=F;n=gHb(r,(r|0)<0|0?-1:0,65537,65537)|0;r=F;p=d+(b<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(b+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(g<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(g+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(i<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(i+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(l<<1)|0;c[p>>2]=q;c[p+4>>2]=m;m=d+(l+4<<1)|0;c[m>>2]=n;c[m+4>>2]=r;return}function Tma(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=f*7|0;l=(e[d+(k-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;m=gHb(((e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))+2|0)>>>2,0,65537,65537)|0;n=F;o=a;c[o>>2]=m;c[o+4>>2]=n;o=a+8|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;n=gHb((l+2|0)>>>2,0,65537,65537)|0;l=F;o=d+(b<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(b+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;return}function Uma(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=gHb(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=F;i=gHb((g+2|0)>>>2,0,65537,65537)|0;g=F;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function Vma(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;Uma(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Wma(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;Sma(a,b);d=a;f=b>>1;b=gHb(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function Xma(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;Tma(a,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=536879104;c[b+4>>2]=536879104;b=f+(g<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=g<<1;e=f+(b<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=536879104;c[h+4>>2]=536879104;h=a+(d+8)|0;d=h;a=h;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(g<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;return}function Yma(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Tma(a,b);d=a;e=b>>1;b=a;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<1;f=d+(b<<1)|0;c[f>>2]=536879104;c[f+4>>2]=536879104;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=536879104;c[g+4>>2]=536879104;g=a+8|0;a=g;d=g;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(e<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(b<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(f<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;return}function Zma(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=0;g=0;h=0;i=0;j=0;k=0;do{l=e[d+((ba(k,f)|0)-1<<1)>>1]|0;j=l+j+(e[d+(k-f<<1)>>1]|0)|0;l=k+4|0;i=(e[d+(l-f<<1)>>1]|0)+i|0;h=(e[d+((ba(l,f)|0)-1<<1)>>1]|0)+h|0;g=(e[d+((ba(k+8|0,f)|0)-1<<1)>>1]|0)+g|0;b=(e[d+((ba(k+12|0,f)|0)-1<<1)>>1]|0)+b|0;k=k+1|0;}while((k|0)<4);k=j+4>>3;j=gHb(k,(k|0)<0|0?-1:0,65537,65537)|0;k=F;l=i+2>>2;m=gHb(l,(l|0)<0|0?-1:0,65537,65537)|0;l=F;n=h+2>>2;o=h+4+i>>3;h=g+2>>2;p=g+4+i>>3;g=b+2>>2;q=b+4+i>>3;i=a;c[i>>2]=j;c[i+4>>2]=k;i=a+8|0;c[i>>2]=m;c[i+4>>2]=l;i=d+(f<<1)|0;c[i>>2]=j;c[i+4>>2]=k;i=d+(f+4<<1)|0;c[i>>2]=m;c[i+4>>2]=l;i=f<<1;a=d+(i<<1)|0;c[a>>2]=j;c[a+4>>2]=k;a=d+(i+4<<1)|0;c[a>>2]=m;c[a+4>>2]=l;a=f*3|0;i=d+(a<<1)|0;c[i>>2]=j;c[i+4>>2]=k;k=d+(a+4<<1)|0;c[k>>2]=m;c[k+4>>2]=l;l=gHb(n,(n|0)<0|0?-1:0,65537,65537)|0;n=F;k=gHb(o,(o|0)<0|0?-1:0,65537,65537)|0;o=F;m=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;a=gHb(p,(p|0)<0|0?-1:0,65537,65537)|0;p=F;i=gHb(g,(g|0)<0|0?-1:0,65537,65537)|0;g=F;j=gHb(q,(q|0)<0|0?-1:0,65537,65537)|0;q=F;b=f<<2;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*5|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;b=d+(r+4<<1)|0;c[b>>2]=k;c[b+4>>2]=o;b=f*6|0;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*7|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;n=d+(r+4<<1)|0;c[n>>2]=k;c[n+4>>2]=o;o=f<<3;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+((o|4)<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*9|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;o=d+(n+4<<1)|0;c[o>>2]=a;c[o+4>>2]=p;o=f*10|0;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+(o+4<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*11|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;h=d+(n+4<<1)|0;c[h>>2]=a;c[h+4>>2]=p;p=f*12|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*13|0;p=d+(h<<1)|0;c[p>>2]=i;c[p+4>>2]=g;p=d+(h+4<<1)|0;c[p>>2]=j;c[p+4>>2]=q;p=f*14|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*15|0;f=d+(h<<1)|0;c[f>>2]=i;c[f+4>>2]=g;g=d+(h+4<<1)|0;c[g>>2]=j;c[g+4>>2]=q;return}function _ma(a,b){a=a|0;b=b|0;Tma(a,b);Tma(a+(b<<3)|0,b);return}function $ma(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=gHb(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=F;i=gHb((g+2|0)>>>2,0,65537,65537)|0;g=F;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<3;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+((j|4)<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*9|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*10|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*11|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*12|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*13|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*14|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*15|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function ana(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;$ma(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=gHb(h,(h|0)<0|0?-1:0,65537,65537)|0;h=F;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function bna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;Zma(a,b);d=a;f=b>>1;b=gHb(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=F;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function cna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;Tma(a,b);Tma(a+(b<<3)|0,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=536879104;c[b+4>>2]=536879104;b=f+(g<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=g<<1;e=f+(b<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=536879104;c[h+4>>2]=536879104;h=a+(d+8)|0;d=h;a=h;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(g<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;return}function dna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Tma(a,b);Tma(a+(b<<3)|0,b);d=a;e=b>>1;b=a;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<1;f=d+(b<<1)|0;c[f>>2]=536879104;c[f+4>>2]=536879104;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=536879104;c[g+4>>2]=536879104;g=a+8|0;a=g;d=g;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(e<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(b<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(f<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;return}function ena(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+8|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=e<<2;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;e=d+(a+4<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;return}function fna(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+8|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=e<<2;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;e=d+(a+4<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;return}function gna(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+8|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<2;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;return}function hna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=b>>1;f=a;c[f>>2]=536879104;c[f+4>>2]=536879104;f=a+8|0;c[f>>2]=536879104;c[f+4>>2]=536879104;f=d+(e<<1)|0;c[f>>2]=536879104;c[f+4>>2]=536879104;f=e+4|0;g=d+(f<<1)|0;c[g>>2]=536879104;c[g+4>>2]=536879104;g=e<<1;h=d+(g<<1)|0;c[h>>2]=536879104;c[h+4>>2]=536879104;h=g+4|0;i=d+(h<<1)|0;c[i>>2]=536879104;c[i+4>>2]=536879104;i=e*3|0;j=d+(i<<1)|0;c[j>>2]=536879104;c[j+4>>2]=536879104;j=i+4|0;k=d+(j<<1)|0;c[k>>2]=536879104;c[k+4>>2]=536879104;k=e<<2;l=d+(k<<1)|0;c[l>>2]=536879104;c[l+4>>2]=536879104;l=k+4|0;m=d+(l<<1)|0;c[m>>2]=536879104;c[m+4>>2]=536879104;m=e*5|0;n=d+(m<<1)|0;c[n>>2]=536879104;c[n+4>>2]=536879104;n=m+4|0;o=d+(n<<1)|0;c[o>>2]=536879104;c[o+4>>2]=536879104;o=e*6|0;p=d+(o<<1)|0;c[p>>2]=536879104;c[p+4>>2]=536879104;p=o+4|0;q=d+(p<<1)|0;c[q>>2]=536879104;c[q+4>>2]=536879104;q=e*7|0;r=d+(q<<1)|0;c[r>>2]=536879104;c[r+4>>2]=536879104;r=q+4|0;s=d+(r<<1)|0;c[s>>2]=536879104;c[s+4>>2]=536879104;s=b<<3;b=a+s|0;d=b;t=b;c[t>>2]=536879104;c[t+4>>2]=536879104;t=a+(s+8)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(e<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(f<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(g<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(h<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(i<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(j<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(k<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(l<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(m<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(n<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(o<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(p<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(q<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(r<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;return}function ina(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+((e[d+(-f<<1)>>1]|0)+((e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))))))))))))))))))+16>>5;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function jna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a;a=b>>1;b=d+(-a<<1)|0;e=c[b>>2]|0;f=c[b+4>>2]|0;b=d+(4-a<<1)|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=d+(8-a<<1)|0;i=c[b>>2]|0;j=c[b+4>>2]|0;b=d+(12-a<<1)|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=0;do{m=ba(b,a)|0;n=d+(m<<1)|0;c[n>>2]=e;c[n+4>>2]=f;n=d+(m+4<<1)|0;c[n>>2]=g;c[n+4>>2]=h;n=d+(m+8<<1)|0;c[n>>2]=i;c[n+4>>2]=j;n=d+(m+12<<1)|0;c[n>>2]=k;c[n+4>>2]=l;b=b+1|0;}while((b|0)<16);return}function kna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ba(b,a)|0;g=gHb(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=F;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+8<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+12<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function lna(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+8|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+16|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+24|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;e=d+(a+4<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;e=d+(a+8<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;e=d+(a+12<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;return}function mna(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+8|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+16|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+24|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;e=d+(a+4<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;e=d+(a+8<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;e=d+(a+12<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;return}function nna(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a;f=c>>1;c=a+14|0;g=-f|0;h=(f<<3)-1|0;i=d+(h<<1)|0;j=d+(h-(f<<1)<<1)|0;h=a+((f*30|0)-2)|0;k=2;l=i;m=j;n=(e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0)|0;o=(e[i>>1]|0)-(e[j>>1]|0)|0;do{l=l+(f<<1)|0;m=m+(g<<1)|0;n=(ba((e[c+(k-f<<1)>>1]|0)-(e[c+(-(f+k|0)<<1)>>1]|0)|0,k)|0)+n|0;o=(ba((e[l>>1]|0)-(e[m>>1]|0)|0,k)|0)+o|0;k=k+1|0;}while((k|0)<9);k=(n*5|0)+32>>6;n=(o*5|0)+32>>6;o=k<<1;m=k*3|0;l=k<<2;c=((n+k|0)*-7|0)+16+((e[a-2+(16-f<<1)>>1]|0)+(e[h>>1]|0)<<4)|0;h=d;d=16;while(1){a=-16;g=c;while(1){j=g>>5;if(j>>>0<16384>>>0){p=j&65535}else{p=-j>>31&16383}b[h+(a+16<<1)>>1]=p;j=g+k>>5;if(j>>>0<16384>>>0){q=j&65535}else{q=-j>>31&16383}b[h+(a+17<<1)>>1]=q;j=g+o>>5;if(j>>>0<16384>>>0){r=j&65535}else{r=-j>>31&16383}b[h+(a+18<<1)>>1]=r;j=g+m>>5;if(j>>>0<16384>>>0){s=j&65535}else{s=-j>>31&16383}b[h+(a+19<<1)>>1]=s;j=a+4|0;if((j|0)<0){a=j;g=g+l|0}else{break}}g=d-1|0;if((g|0)>0){c=c+n|0;h=h+(f<<1)|0;d=g}else{break}}return}function ona(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))+8>>4;g=gHb(b,(b|0)<0|0?-1:0,65537,65537)|0;b=F;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}



function xfb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0,H=0;h=i;i=i+48|0;j=h|0;if((f|0)<=0){i=h;return}k=j|0;l=a+28|0;a=j+40|0;m=j+16|0;n=j+24|0;o=j+28|0;p=j|0;q=j+4|0;r=j+8|0;s=j+12|0;j=0;do{ne[c[l>>2]&1023](e+(j*320|0)|0,k);t=+g[m>>2];u=+g[n>>2];v=+g[o>>2];w=+g[a>>2]*t-(u*u+v*v)/1.0000009536743164;if(w!=0.0){x=+g[p>>2];y=+g[q>>2];z=v*x+u*y-t*+g[s>>2];A=(u*x-v*y-t*+g[r>>2])/w;g[d+(j<<3)>>2]=A;y=z/w;g[d+(j<<3)+4>>2]=y;B=A;C=y}else{g[d+(j<<3)>>2]=0.0;g[d+(j<<3)+4>>2]=0.0;B=0.0;C=0.0}if(t!=0.0){y=u*C+ +g[q>>2]-B*v;A=(-0.0-(+g[p>>2]+B*u+C*v))/t;g[b+(j<<3)>>2]=A;v=(-0.0-y)/t;g[b+(j<<3)+4>>2]=v;D=A;E=v}else{g[b+(j<<3)>>2]=0.0;g[b+(j<<3)+4>>2]=0.0;D=0.0;E=0.0}F=d+(j<<3)|0;G=d+(j<<3)+4|0;v=+g[F>>2];A=+g[G>>2];if(v*v+A*A<16.0){if(!(D*D+E*E<16.0)){H=11}}else{H=11}if((H|0)==11){H=0;g[F>>2]=0.0;g[G>>2]=0.0;g[b+(j<<3)>>2]=0.0;g[b+(j<<3)+4>>2]=0.0}j=j+1|0;}while((j|0)<(f|0));i=h;return}function yfb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;j=g+8|0;k=c[j>>2]|0;a[g+12|0]=a[g+12+k|0]|0;l=g+92|0;c[l>>2]=c[e+20>>2];e=g+87628|0;a[g+87636|0]=a[g+87628+k|0]|0;m=f+8|0;n=c[m>>2]|0;o=f+16|0;p=c[o>>2]|0;q=f|0;f=c[q>>2]|0;r=f+(n>>>3)|0;s=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(n&7)>>>30;r=n+2|0;c[m>>2]=p>>>0>r>>>0?r:p;p=g|0;c[p>>2]=s;a:do{if((s|0)==3){r=c[m>>2]|0;n=c[o>>2]|0;t=f+(r>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(r&7)>>>30;t=r+2|0;c[m>>2]=n>>>0>t>>>0?t:n;a[e|0]=u;u=c[m>>2]|0;n=c[o>>2]|0;t=c[q>>2]|0;r=t+(u>>>3)|0;v=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=u+2|0;w=n>>>0>r>>>0?r:n;c[m>>2]=w;r=t+(w>>>3)|0;x=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(w&7)>>>30;r=w+2|0;w=n>>>0>r>>>0?r:n;c[m>>2]=w;r=t+(w>>>3)|0;t=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(w&7)>>>30;r=w+2|0;c[m>>2]=n>>>0>r>>>0?r:n;n=x+1+t|0;c[j>>2]=n;if(n>>>0>5>>>0){yDb(c[b+4>>2]|0,16,2216664,(y=i,i=i+8|0,c[y>>2]=n,y)|0);i=y;z=-1;i=h;return z|0}a[g+87628+n|0]=(fe(v|0)|0)<<(u&7)>>>30|16;if((x|0)!=0){u=0;v=a[g+87628|0]|0;do{n=c[m>>2]|0;r=c[o>>2]|0;w=(c[q>>2]|0)+(n>>>3)|0;A=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(n&7)>>>30;w=n+2|0;c[m>>2]=r>>>0>w>>>0?w:r;v=(v&255)+2+(A<<1)&255;u=u+1|0;a[g+87628+u|0]=v;}while((u|0)<(x|0))}x=c[j>>2]|0;if((t|0)==0){B=x}else{u=0;v=x;while(1){x=d[v-u+(g+87628)|0]|0;A=c[m>>2]|0;r=c[o>>2]|0;w=(c[q>>2]|0)+(A>>>3)|0;n=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(A&7)>>>30;w=A+2|0;c[m>>2]=r>>>0>w>>>0?w:r;a[(c[j>>2]|0)+~u+(g+87628)|0]=x+254-(n<<1);n=u+1|0;x=c[j>>2]|0;if((n|0)<(t|0)){u=n;v=x}else{B=x;break}}}v=a[1501352+B|0]|0;u=c[m>>2]|0;t=c[o>>2]|0;x=c[q>>2]|0;n=x+(u>>>3)|0;r=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(u&7)>>>((32-v|0)>>>0);n=u+v|0;v=t>>>0>n>>>0?n:t;c[m>>2]=v;n=c[j>>2]|0;if((n|0)>0){C=1;D=v;E=x;F=t}else{G=r;H=35;break}while(1){t=d[E+(D>>>3)|0]<<(D&7)>>>7;c[m>>2]=((D|0)<(F|0))+D;a[g+12+C|0]=t&1;if((C|0)>=(n|0)){G=r;H=35;break a}C=C+1|0;D=c[m>>2]|0;E=c[q>>2]|0;F=c[o>>2]|0}}else if((s|0)==1){r=c[m>>2]|0;n=c[o>>2]|0;t=f+(r>>>3)|0;x=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(r&7)>>>30;t=r+2|0;r=n>>>0>t>>>0?t:n;c[m>>2]=r;t=f+(r>>>3)|0;v=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(r&7)>>>30;t=r+2|0;c[m>>2]=n>>>0>t>>>0?t:n;n=v+1|0;c[j>>2]=n;a[e|0]=0;a[g+87628+n|0]=x|16;x=c[j>>2]|0;if((v|0)==0){I=x}else{n=0;t=x;while(1){x=d[t-n+(g+87628)|0]|0;r=c[m>>2]|0;u=c[o>>2]|0;w=(c[q>>2]|0)+(r>>>3)|0;A=(fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(r&7)>>>30;w=r+2|0;c[m>>2]=u>>>0>w>>>0?w:u;a[(c[j>>2]|0)+~n+(g+87628)|0]=x+254-(A<<1);A=n+1|0;x=c[j>>2]|0;if((A|0)<(v|0)){n=A;t=x}else{I=x;break}}}t=a[1501352+I|0]|0;n=c[m>>2]|0;v=c[o>>2]|0;x=c[q>>2]|0;A=x+(n>>>3)|0;u=(fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(n&7)>>>((32-t|0)>>>0);A=n+t|0;t=v>>>0>A>>>0?A:v;c[m>>2]=t;if((c[j>>2]|0)==0){G=u;H=35;break}else{J=0;K=t;L=x;M=v}while(1){v=d[L+(K>>>3)|0]<<(K&7)>>>7;c[m>>2]=((K|0)<(M|0))+K;a[(c[j>>2]|0)-J+(g+12)|0]=v&1;v=J+1|0;if(!(v>>>0<(c[j>>2]|0)>>>0)){G=u;H=35;break a}J=v;K=c[m>>2]|0;L=c[q>>2]|0;M=c[o>>2]|0}}else if((s|0)==0){u=c[m>>2]|0;v=c[o>>2]|0;x=f+(u>>>3)|0;t=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(u&7)>>>30;x=u+2|0;c[m>>2]=v>>>0>x>>>0?x:v;v=1<<t;c[j>>2]=v;t=v-1|0;do{if((v|0)==1){c[l>>2]=0}else{if(!(v>>>0>4>>>0)){break}yDb(c[b+4>>2]|0,16,2228488,(y=i,i=i+8|0,c[y>>2]=v,y)|0);i=y;z=-1;i=h;return z|0}}while(0);a[e|0]=0;a[g+87628+v|0]=16;x=c[j>>2]|0;u=(((x>>>1)+16|0)>>>0)/(x>>>0)|0;if((t|0)>0){x=0;A=a[g+87628|0]|0;do{A=(A&255)+u&255;x=x+1|0;a[g+87628+x|0]=A;}while((x|0)<(t|0))}t=c[m>>2]|0;x=d[(c[q>>2]|0)+(t>>>3)|0]<<(t&7)>>>7;c[m>>2]=((t|0)<(c[o>>2]|0))+t;t=x&1;x=g+13|0;a[x]=t;A=c[j>>2]|0;if(A>>>0>1>>>0){N=2;O=t}else{P=0;Q=A;break}while(1){a[g+12+N|0]=O;A=c[j>>2]|0;if(!(N>>>0<A>>>0)){P=0;Q=A;break a}N=N+1|0;O=a[x]|0}}else if((s|0)==2){x=c[m>>2]|0;A=c[o>>2]|0;t=f+(x>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(x&7)>>>30;t=x+2|0;c[m>>2]=A>>>0>t>>>0?t:A;a[e|0]=u;u=c[m>>2]|0;A=c[o>>2]|0;t=(c[q>>2]|0)+(u>>>3)|0;x=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(u&7)>>>30;t=u+2|0;c[m>>2]=A>>>0>t>>>0?t:A;A=x+1|0;c[j>>2]=A;a[g+87628+A|0]=16;if((x|0)!=0){A=0;t=a[g+87628|0]|0;do{u=c[m>>2]|0;v=c[o>>2]|0;n=(c[q>>2]|0)+(u>>>3)|0;w=(fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(u&7)>>>30;n=u+2|0;c[m>>2]=v>>>0>n>>>0?n:v;t=(t&255)+2+(w<<1)&255;A=A+1|0;a[g+87628+A|0]=t;}while((A|0)<(x|0))}x=a[1501352+(c[j>>2]|0)|0]|0;A=c[m>>2]|0;t=c[o>>2]|0;w=c[q>>2]|0;v=w+(A>>>3)|0;n=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(A&7)>>>((32-x|0)>>>0);v=A+x|0;x=t>>>0>v>>>0?v:t;c[m>>2]=x;v=c[j>>2]|0;if((v|0)>0){R=1;S=x;T=w;U=t}else{G=n;H=35;break}while(1){t=d[T+(S>>>3)|0]<<(S&7)>>>7;c[m>>2]=((S|0)<(U|0))+S;a[g+12+R|0]=t&1;if((R|0)>=(v|0)){G=n;H=35;break a}R=R+1|0;S=c[m>>2]|0;T=c[q>>2]|0;U=c[o>>2]|0}}else{P=0;Q=c[j>>2]|0}}while(0);do{if((H|0)==35){o=c[j>>2]|0;if(!(G>>>0>(o+1|0)>>>0)){P=G;Q=o;break}yDb(c[b+4>>2]|0,16,2207152,(y=i,i=i+8|0,c[y>>2]=G,y)|0);i=y;z=-1;i=h;return z|0}}while(0);G=1;while(1){if(G>>>0>Q>>>0){break}if((d[G-1+(g+87628)|0]|0)>>>0>(d[g+87628+G|0]|0)>>>0){H=39;break}else{G=G+1|0}}if((H|0)==39){yDb(c[b+4>>2]|0,16,2199096,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;z=-1;i=h;return z|0}y=Q>>>0>1>>>0?2:1;b=g+20|0;c[b>>2]=y;a[g+87637|0]=a[e|0]|0;a[g+87637+y|0]=a[g+87628+Q|0]|0;Q=c[p>>2]|0;if((c[b>>2]|0)>>>0>1>>>0){do{if((Q|0)==0){V=(c[j>>2]|0)>>>1}else{if((Q&1|0)!=0){b=P-1|0;V=(c[j>>2]|0)-((b|0)>1?b:1)|0;break}if((P|0)==1){V=(c[j>>2]|0)-1|0;break}else if((P|0)==0){V=1;break}else{V=P-1|0;break}}}while(0);a[g+87638|0]=a[g+87628+V|0]|0}V=g+14568|0;c[g+14564>>2]=-((c[V>>2]|0)!=(k|0)|0);c[V>>2]=-1;if(!((Q&1|0)==0|(P|0)==0)){c[V>>2]=1-P+(c[j>>2]|0);z=0;i=h;return z|0}if(!((Q|0)==2&P>>>0>1>>>0)){z=0;i=h;return z|0}c[V>>2]=P-1;z=0;i=h;return z|0}function zfb(e,f,h,i){e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0.0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0;j=c[e+40>>2]|0;if((i|0)==1){k=(j|0)==1?2:1}else{k=1}l=c[e+262884>>2]&1;m=(c[h+92>>2]|0)==0;if((j|0)==0|(i|0)==0){n=m?7:6;o=m?60:31;p=m?2585728:2585808;q=m?2585708:2585788}else{n=m?6:5;o=m?24:12;p=m?2585768:2585848;q=m?2585748:2585828}m=c[p>>2]|0;p=c[q>>2]|0;q=h+8|0;if((c[q>>2]|0)==0){r=0;s=h+86416|0;t=s;u=h+86416+(r*192|0)|0;v=u;UGb(t|0,v|0,192)|0;return}i=f+8|0;j=f+16|0;w=f|0;f=32-n|0;x=0;while(1){a:do{if((a[h+24+x|0]|0)==0){y=c[i>>2]|0;z=c[j>>2]|0;A=c[w>>2]|0;B=A+(y>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)>>>(f>>>0);B=y+n|0;y=z>>>0>B>>>0?B:z;c[i>>2]=y;D=+((ba(C,k)|0)>>>0>>>0);C=x+1|0;g[h+86416+(C*192|0)>>2]=D;B=h+12+C|0;if((c[e+262880+(d[B]<<2)>>2]|0)>>>0>1>>>0){E=1;F=D;G=y}else{break}do{y=A+(G>>>3)|0;H=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(G&7)>>>23;y=b[m+(H<<2)>>1]|0;I=b[m+(H<<2)+2>>1]|0;H=I<<16>>16;do{if(I<<16>>16<0){J=G+9|0;K=z>>>0>J>>>0?J:z;J=A+(K>>>3)|0;L=((fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(K&7)>>>((H+32|0)>>>0))+y|0;J=b[m+(L<<2)>>1]|0;M=b[m+(L<<2)+2>>1]|0;L=M<<16>>16;if(!(M<<16>>16<0)){N=L;O=J;P=K;break}M=K-H|0;K=z>>>0>M>>>0?M:z;M=A+(K>>>3)|0;Q=((fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>((L+32|0)>>>0))+J|0;N=b[m+(Q<<2)+2>>1]|0;O=b[m+(Q<<2)>>1]|0;P=K}else{N=H;O=y;P=G}}while(0);y=N+P|0;G=z>>>0>y>>>0?y:z;c[i>>2]=G;F=F+ +(ba(O-o|0,k)|0);g[h+86416+(C*192|0)+(E<<2)>>2]=F;E=E+1|0;}while(E>>>0<(c[e+262880+(d[B]<<2)>>2]|0)>>>0)}else{B=x+1|0;C=h+12+B|0;z=a[C]|0;if(z<<24>>24==(a[h+12+x|0]|0)){if((c[e+262880+((z&255)<<2)>>2]|0)==0){break}A=c[j>>2]|0;y=c[w>>2]|0;H=0;I=c[i>>2]|0;while(1){D=+g[h+86416+(x*192|0)+(H<<2)>>2];K=y+(I>>>3)|0;Q=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(I&7)>>>23;K=b[p+(Q<<2)>>1]|0;J=b[p+(Q<<2)+2>>1]|0;Q=J<<16>>16;do{if(J<<16>>16<0){L=I+9|0;M=A>>>0>L>>>0?L:A;L=y+(M>>>3)|0;R=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>((Q+32|0)>>>0))+K|0;L=b[p+(R<<2)>>1]|0;S=b[p+(R<<2)+2>>1]|0;R=S<<16>>16;if(!(S<<16>>16<0)){T=R;U=L;V=M;break}S=M-Q|0;M=A>>>0>S>>>0?S:A;S=y+(M>>>3)|0;W=((fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(M&7)>>>((R+32|0)>>>0))+L|0;T=b[p+(W<<2)+2>>1]|0;U=b[p+(W<<2)>>1]|0;V=M}else{T=Q;U=K;V=I}}while(0);K=T+V|0;I=A>>>0>K>>>0?K:A;c[i>>2]=I;g[h+86416+(B*192|0)+(H<<2)>>2]=D+ +(ba(U-o|0,k)|0);H=H+1|0;if(!(H>>>0<(c[e+262880+(d[C]<<2)>>2]|0)>>>0)){break a}}}if(!(z<<24>>24==0)){if((c[e+262880+((z&255)<<2)>>2]|0)==0){break}H=c[j>>2]|0;I=c[w>>2]|0;A=0;y=c[i>>2]|0;while(1){X=+g[h+86416+(x*192|0)+(A+l>>1<<2)>>2];K=I+(y>>>3)|0;Q=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(y&7)>>>23;K=b[p+(Q<<2)>>1]|0;J=b[p+(Q<<2)+2>>1]|0;Q=J<<16>>16;do{if(J<<16>>16<0){M=y+9|0;W=H>>>0>M>>>0?M:H;M=I+(W>>>3)|0;L=((fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(W&7)>>>((Q+32|0)>>>0))+K|0;M=b[p+(L<<2)>>1]|0;R=b[p+(L<<2)+2>>1]|0;L=R<<16>>16;if(!(R<<16>>16<0)){Y=L;Z=M;_=W;break}R=W-Q|0;W=H>>>0>R>>>0?R:H;R=I+(W>>>3)|0;S=((fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(W&7)>>>((L+32|0)>>>0))+M|0;Y=b[p+(S<<2)+2>>1]|0;Z=b[p+(S<<2)>>1]|0;_=W}else{Y=Q;Z=K;_=y}}while(0);K=Y+_|0;y=H>>>0>K>>>0?K:H;c[i>>2]=y;g[h+86416+(B*192|0)+(A<<2)>>2]=X+ +(ba(Z-o|0,k)|0);A=A+1|0;if(!(A>>>0<(c[e+262880+(d[C]<<2)>>2]|0)>>>0)){break a}}}if((c[e+262880>>2]|0)==0){break}else{$=0}do{if(($|0)==0){aa=0}else{aa=($<<1)-l|0}D=+g[h+86416+(x*192|0)+(aa<<2)>>2];A=c[i>>2]|0;y=c[j>>2]|0;H=c[w>>2]|0;I=H+(A>>>3)|0;z=(fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(A&7)>>>23;I=b[p+(z<<2)>>1]|0;K=b[p+(z<<2)+2>>1]|0;z=K<<16>>16;do{if(K<<16>>16<0){Q=A+9|0;J=y>>>0>Q>>>0?Q:y;Q=H+(J>>>3)|0;W=((fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(J&7)>>>((z+32|0)>>>0))+I|0;Q=b[p+(W<<2)>>1]|0;S=b[p+(W<<2)+2>>1]|0;W=S<<16>>16;if(!(S<<16>>16<0)){ca=W;da=Q;ea=J;break}S=J-z|0;J=y>>>0>S>>>0?S:y;S=H+(J>>>3)|0;M=((fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(J&7)>>>((W+32|0)>>>0))+Q|0;ca=b[p+(M<<2)+2>>1]|0;da=b[p+(M<<2)>>1]|0;ea=J}else{ca=z;da=I;ea=A}}while(0);A=ca+ea|0;c[i>>2]=y>>>0>A>>>0?A:y;g[h+86416+(B*192|0)+($<<2)>>2]=D+ +(ba(da-o|0,k)|0);$=$+1|0;}while($>>>0<(c[e+262880+(d[C]<<2)>>2]|0)>>>0)}}while(0);C=x+1|0;B=c[q>>2]|0;if(C>>>0<B>>>0){x=C}else{r=B;break}}s=h+86416|0;t=s;u=h+86416+(r*192|0)|0;v=u;UGb(t|0,v|0,192)|0;return}function Afb(e,f,h,i){e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;j=c[e+40>>2]|0;if((i|0)==1){k=(j|0)==1?2:1}else{k=1}l=(j|0)==0|(i|0)==0;i=l?31:12;j=l?c[646452]|0:c[646462]|0;m=l?c[646467]|0:c[646472]|0;l=h+20|0;if((c[l>>2]|0)==0){n=0;o=h+87568|0;p=o;q=h+87568+(n*20|0)|0;r=q;c[p>>2]=c[r>>2];c[p+4>>2]=c[r+4>>2];c[p+8>>2]=c[r+8>>2];c[p+12>>2]=c[r+12>>2];c[p+16>>2]=c[r+16>>2];return}s=f+8|0;t=f+16|0;u=f|0;f=e+262888|0;e=0;while(1){do{if((a[h+29+e|0]|0)==0){v=c[s>>2]|0;w=c[t>>2]|0;x=c[u>>2]|0;y=x+(v>>>3)|0;z=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(v&7)>>>27;y=v+5|0;v=w>>>0>y>>>0?y:w;c[s>>2]=v;A=+((ba(z,k)|0)>>>0>>>0);z=e+1|0;g[h+87568+(z*20|0)>>2]=A;if((c[f>>2]|0)>>>0>1>>>0){B=1;C=A;D=v}else{E=z;break}while(1){v=x+(D>>>3)|0;y=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(D&7)>>>23;v=b[j+(y<<2)>>1]|0;F=b[j+(y<<2)+2>>1]|0;y=F<<16>>16;do{if(F<<16>>16<0){G=D+9|0;H=w>>>0>G>>>0?G:w;G=x+(H>>>3)|0;I=((fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>((y+32|0)>>>0))+v|0;G=b[j+(I<<2)>>1]|0;J=b[j+(I<<2)+2>>1]|0;I=J<<16>>16;if(!(J<<16>>16<0)){K=I;L=G;M=H;break}J=H-y|0;H=w>>>0>J>>>0?J:w;J=x+(H>>>3)|0;N=((fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>((I+32|0)>>>0))+G|0;K=b[j+(N<<2)+2>>1]|0;L=b[j+(N<<2)>>1]|0;M=H}else{K=y;L=v;M=D}}while(0);v=K+M|0;y=w>>>0>v>>>0?v:w;c[s>>2]=y;A=C+ +(ba(L-i|0,k)|0);g[h+87568+(z*20|0)+(B<<2)>>2]=A;v=B+1|0;if(v>>>0<(c[f>>2]|0)>>>0){B=v;C=A;D=y}else{E=z;break}}}else{z=e+1|0;if((c[f>>2]|0)==0){E=z;break}w=c[t>>2]|0;x=c[u>>2]|0;y=0;v=c[s>>2]|0;while(1){A=+g[h+87568+(e*20|0)+(y<<2)>>2];F=x+(v>>>3)|0;H=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(v&7)>>>23;F=b[m+(H<<2)>>1]|0;N=b[m+(H<<2)+2>>1]|0;H=N<<16>>16;if(N<<16>>16<0){N=v+9|0;G=w>>>0>N>>>0?N:w;N=x+(G>>>3)|0;I=((fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(G&7)>>>((H+32|0)>>>0))+F|0;O=b[m+(I<<2)+2>>1]|0;P=b[m+(I<<2)>>1]|0;Q=G}else{O=H;P=F;Q=v}F=O+Q|0;H=w>>>0>F>>>0?F:w;c[s>>2]=H;g[h+87568+(z*20|0)+(y<<2)>>2]=A+ +(ba(P-i|0,k)|0);F=y+1|0;if(F>>>0<(c[f>>2]|0)>>>0){y=F;v=H}else{E=z;break}}}}while(0);z=c[l>>2]|0;if(E>>>0<z>>>0){e=E}else{n=z;break}}o=h+87568|0;p=o;q=h+87568+(n*20|0)|0;r=q;c[p>>2]=c[r>>2];c[p+4>>2]=c[r+4>>2];c[p+8>>2]=c[r+8>>2];c[p+12>>2]=c[r+12>>2];c[p+16>>2]=c[r+16>>2];return}function Bfb(a){a=a|0;var e=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+16|0;f=e|0;h=c[a+24>>2]|0;if((h|0)==0){b[a+263154>>1]=b[a+262994>>1]|0;b[a+263156>>1]=b[a+262994+(c[a+262880>>2]<<1)>>1]|0;c[a+262892>>2]=1;i=e;return}j=+g[482656+(h-1<<2)>>2];h=a+263154|0;k=h|0;l=a+263156|0;m=c[a+68>>2]&65535;b[f>>1]=m;n=a+263216|0;o=c[n>>2]|0;if((o|0)!=0){p=1;q=m;do{q=(d[p-1+(a+263220)|0]|0)+q&65535;b[f+(p<<1)>>1]=q;p=p+1|0;}while(!(p>>>0>o>>>0))}o=h;h=a+262880|0;p=c[h>>2]|0;UGb(o|0,a+262994|0,(p<<1)+2|0)|0;q=c[n>>2]|0;if(q>>>0>1>>>0){UGb(a+263154+(p+1<<1)|0,f+2|0,(q<<1)-2|0)|0;r=c[n>>2]|0;s=c[h>>2]|0}else{r=q;s=p}Yc(o|0,s+r|0,2,98);r=c[n>>2]|0;n=(c[h>>2]|0)-1+r|0;h=a+262892|0;c[h>>2]=n;if(k>>>0<(a+263154+(n<<1)|0)>>>0){t=l;u=k;v=n}else{i=e;return}a:while(1){n=t;k=v;b:while(1){w=b[n>>1]|0;l=b[u>>1]|0;if(!(+(w&65535|0)<j*+(l&65535|0))){x=9;break}c:do{if(w<<16>>16==l<<16>>16){y=k}else{s=0;while(1){if((s|0)>(r|0)){y=k;break c}if((b[f+(s<<1)>>1]|0)==w<<16>>16){z=0;break}else{s=s+1|0}}while(1){if((z|0)>(r|0)){break}if((b[f+(z<<1)>>1]|0)==l<<16>>16){x=19;break b}else{z=z+1|0}}b[u>>1]=w;y=c[h>>2]|0}}while(0);l=y-1|0;c[h>>2]=l;if(!(u>>>0<(a+263154+(l<<1)|0)>>>0)){x=21;break a}n=n+2|0;k=l}if((x|0)==9){x=0;l=u+2|0;b[l>>1]=w;A=l}else if((x|0)==19){x=0;l=u+2|0;b[l>>1]=w;A=l}if(A>>>0<(a+263154+(k<<1)|0)>>>0){t=n+2|0;u=A;v=k}else{x=21;break}}if((x|0)==21){i=e;return}}function Cfb(a,c){a=a|0;c=c|0;return(b[a>>1]|0)-(b[c>>1]|0)|0}function Dfb(){var a=0;a=0;do{g[7994608+(a<<2)>>2]=+Wc(+(+(a-200|0)*.25));a=a+1|0;}while((a|0)<428);return}function Efb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=c[a+792>>2]|0;do{if((f|0)==16){c[a+140>>2]=46}else if((f|0)==24){c[a+140>>2]=3}else if((f|0)==8){c[a+140>>2]=11;g=c[a+96>>2]|0;h=c[a+100>>2]|0;j=(h|0)>1024?1024:h;h=e+1044|0;c[h>>2]=j;if((j|0)<=3){break}j=e+20|0;k=g;g=0;while(1){l=k;c[j+(g<<2)>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|-16777216;l=g+1|0;if((l|0)<((c[h>>2]|0)/4|0|0)){k=k+4|0;g=l}else{break}}}else{yDb(a,16,1911392,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;m=-1;i=b;return m|0}}while(0);f=ICb()|0;c[e+16>>2]=f;m=(f|0)==0?-12:0;i=b;return m|0}function Ffb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;f=c[a+60>>2]|0;if((j|0)<4){yDb(a,16,2176640,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}m=f+16|0;n=$$a(a,c[m>>2]|0)|0;if((n|0)<0){l=n;i=g;return l|0}n=h;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;p=j-4|0;q=(c[a+792>>2]|0)/8|0;r=c[a+52>>2]|0;do{if((r|0)==1129529665){if((o|0)==1){s=f+4|0;if((p|0)>-1){c[s>>2]=n;c[f+12>>2]=n;c[f+8>>2]=h+j;kQa(a,c[m>>2]|0,8,s)|0;t=p;break}else{yDb(0,0,1999352,(k=i,i=i+24|0,c[k>>2]=1962536,c[k+8>>2]=1934408,c[k+16>>2]=135,k)|0);i=k;Cd();return 0}}else if((o|0)==0){s=a+120|0;u=c[s>>2]|0;v=(ba(u,q)|0)+q&~q;w=c[a+124>>2]|0;x=ba(v,w)|0;if((p|0)<(x|0)){l=-1094995529;i=g;return l|0}if((w|0)>0){y=n;z=w;A=u}else{t=p;break}while(1){u=z-1|0;w=c[m>>2]|0;UGb((c[w>>2]|0)+(ba(c[w+32>>2]|0,u)|0)|0,y|0,ba(A,q)|0)|0;if((u|0)<=0){break}y=y+v|0;z=u;A=c[s>>2]|0}t=p-x|0;break}else{yDb(a,16,2100632,(k=i,i=i+8|0,c[k>>2]=o,k)|0);i=k;l=-1094995529;i=g;return l|0}}else if((r|0)==877871425){s=f+4|0;if((j|0)>-1){c[s>>2]=h;c[f+12>>2]=h;c[f+8>>2]=h+j;kQa(a,c[m>>2]|0,8,s)|0;t=p;break}else{yDb(0,0,1999352,(k=i,i=i+24|0,c[k>>2]=1962536,c[k+8>>2]=1934408,c[k+16>>2]=135,k)|0);i=k;Cd();return 0}}else{yDb(a,16,2044976,(k=i,i=i+8|0,c[k>>2]=r,k)|0);i=k;l=-1;i=g;return l|0}}while(0);if((c[a+140>>2]|0)==11){UGb(c[(c[m>>2]|0)+4>>2]|0,f+20|0,c[f+1044>>2]|0)|0}c[e>>2]=1;e=MCb(b,c[m>>2]|0)|0;l=(e|0)<0?e:t;i=g;return l|0}function Gfb(a){a=a|0;JCb((c[a+60>>2]|0)+16|0);return 0}function Hfb(b){b=b|0;var e=0,f=0,h=0,i=0,j=0,k=0;e=c[b+60>>2]|0;c[e+4>>2]=b;Spb();f=0;while(1){a[2818776+(f*3|0)|0]=(f|0)/25|0;h=(f|0)%25|0;a[2818777+(f*3|0)|0]=(h|0)/5|0;a[2818778+(f*3|0)|0]=(h|0)%5|0;h=f+1|0;if((h|0)<128){f=h}else{i=0;break}}while(1){c[8881712+(i*12|0)>>2]=(((d[1274768+(i*3|0)|0]|0)<<24)-16777216|0)/3|0;c[8881716+(i*12|0)>>2]=(((d[1274769+(i*3|0)|0]|0)<<24)-16777216|0)/3|0;c[8881720+(i*12|0)>>2]=(((d[1274770+(i*3|0)|0]|0)<<24)-16777216|0)/3|0;f=i+1|0;if((f|0)<32){i=f}else{j=0;break}}do{c[8880176+(j*12|0)>>2]=(((d[2818776+(j*3|0)|0]|0)<<24)-33554432|0)/5|0;c[8880180+(j*12|0)>>2]=(((d[2818777+(j*3|0)|0]|0)<<24)-33554432|0)/5|0;c[8880184+(j*12|0)>>2]=(((d[2818778+(j*3|0)|0]|0)<<24)-33554432|0)/5|0;c[8879120+(j<<3)>>2]=((((j|0)/11|0)<<24)-83886080|0)/11|0;c[8879124+(j<<3)>>2]=((((j|0)%11|0)<<24)-83886080|0)/11|0;j=j+1|0;}while((j|0)<128);c[2220036]=-7190235;c[2220037]=-4793490;c[2220038]=-2396745;c[2220039]=0;c[2220040]=2396745;c[2220041]=4793490;c[2220042]=7190235;c[2219764]=-7829367;c[2219765]=-6710886;c[2219766]=-5592405;c[2219767]=-4473924;c[2219768]=-3355443;c[2219769]=-2236962;c[2219770]=-1118481;c[2219771]=0;c[2219772]=1118481;c[2219773]=2236962;c[2219774]=3355443;c[2219775]=4473924;c[2219776]=5592405;c[2219777]=6710886;c[2219778]=7829367;j=0;do{g[8163272+(j<<2)>>2]=+tGb(1.0,(j>>5)-5-(j>>7<<3)|0)*+(j&31|32|0);j=j+1|0;}while((j|0)<256);aLa(e+54556|0,8,1,1.0)|0;aLa(e+54492|0,9,1,1.0)|0;Slb(e+77568|0,5.0,256);Z3(e+54620|0,b);j=b+88|0;fCb(e+55864|0,c[j>>2]&8388608);Nfb(e+55900|0,c[j>>2]&8388608);iba(e+55952|0,b);oDb(e+54204|0,0);c[b+420>>2]=8;j=c[b+440>>2]|0;if((j|0)==2){i=b+456|0;c[i>>2]=3;c[i+4>>2]=0}else if((j|0)==1){j=b+456|0;c[j>>2]=4;c[j+4>>2]=0}j=b+416|0;i=c[j>>2]|0;do{if((i|0)>1){f=b+456|0;h=c[f>>2]|0;k=c[f+4>>2]|0;if((h|0)==4&(k|0)==0){c[j>>2]=1;break}if(!((i|0)>2&((h|0)==3&(k|0)==0))){break}c[j>>2]=2}}while(0);c[e+44992>>2]=1;c[e+56e3>>2]=e+63232;c[e+56028>>2]=e+70400;c[e+56004>>2]=e+64256;c[e+56032>>2]=e+71424;c[e+56008>>2]=e+65280;c[e+56036>>2]=e+72448;c[e+56012>>2]=e+66304;c[e+56040>>2]=e+73472;c[e+56016>>2]=e+67328;c[e+56044>>2]=e+74496;c[e+56020>>2]=e+68352;c[e+56048>>2]=e+75520;c[e+56024>>2]=e+69376;c[e+56052>>2]=e+76544;return 0}function Ifb(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0.0,na=0.0,oa=0,pa=0.0,qa=0,ra=0.0,sa=0.0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0.0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0;m=i;i=i+1168|0;n=m|0;o=m+64|0;p=m+72|0;q=m+1096|0;r=m+1128|0;s=m+1136|0;t=j;u=c[l+24>>2]|0;v=c[l+28>>2]|0;l=c[f+60>>2]|0;w=l;do{if((v|0)>1){x=u;if(!((d[x]|d[x+1|0]<<8)<<16>>16<<16>>16==2935)){y=4;break}Xe[c[l+55720>>2]&4095](l+86784|0,x,(v|0)>32768?16384:v>>1)}else{y=4}}while(0);if((y|0)==4){UGb(l+86784|0,u|0,(v|0)>32768?32768:v)|0}u=l+86784|0;x=l+8|0;z=v<<3;A=z>>>0>2147483639>>>0|(u|0)==0;B=A?0:u;u=A?0:z;z=x;c[z>>2]=B;c[l+20>>2]=u;A=l+24|0;c[A>>2]=u+8;c[l+12>>2]=B+(u>>3);u=l+16|0;c[u>>2]=0;c[o>>2]=n;B=x;x=GX(B,o)|0;do{if((x|0)==0){c[l+47080>>2]=d[n+4|0]|0;o=d[n+5|0]|0;C=l+52|0;c[C>>2]=o;c[l+56>>2]=d[n+6|0]|0;D=l+60|0;c[D>>2]=d[n+7|0]|0;E=a[n+8|0]|0;G=E&255;c[l+64>>2]=G;c[l+47084>>2]=d[n+32|0]|0;c[l+44>>2]=e[n+34>>1]|0;c[l+40>>2]=c[n+36>>2];H=d[n+40|0]|0;c[l+44928>>2]=H;I=H-G|0;c[l+44924>>2]=I;G=I+1|0;I=l+44932|0;c[I>>2]=G;H=l+36|0;c[H>>2]=e[n+42>>1]|0;J=l+72|0;c[J>>2]=0;K=l+76|0;c[K>>2]=c[n+16>>2];L=l+80|0;c[L>>2]=4;M=l+84|0;c[M>>2]=c[n+20>>2];N=l+88|0;c[N>>2]=4;c[l+92>>2]=0;c[l+48>>2]=c[n+28>>2];c[l+28>>2]=d[n+9|0]|0;c[l+32>>2]=c[n+12>>2];c[l+104>>2]=c[n+56>>2];O=l+108|0;c[O>>2]=0;P=l+112|0;c[P>>2]=0;if(E<<24>>24==0){Q=o}else{c[w+45016+(G<<2)>>2]=0;c[w+45044+(c[I>>2]<<2)>>2]=7;c[w+45092+(c[I>>2]<<2)>>2]=2;c[w+212+(c[I>>2]<<2)>>2]=0;Q=c[C>>2]|0}C=l+100|0;if((Q|0)>=11){c[C>>2]=1;T=Ikb(w)|0;y=31;break}c[C>>2]=0;c[l+136>>2]=2;c[l+140>>2]=1;c[l+144>>2]=1;c[l+148>>2]=1;c[l+152>>2]=0;c[l+47116>>2]=0;c[l+156>>2]=1;c[l+160>>2]=1;TGb(l+1888|0,0,28)|0;C=c[A>>2]|0;I=c[z>>2]|0;G=(c[D>>2]|0)==0|0;D=c[u>>2]|0;while(1){o=D+5|0;E=C>>>0>o>>>0?o:C;c[u>>2]=E;o=((E|0)<(C|0))+E|0;if((128>>>((E&7)>>>0)&d[I+(E>>>3)|0]|0)==0){U=o}else{E=o+8|0;U=C>>>0>E>>>0?E:C}c[u>>2]=U;E=((U|0)<(C|0))+U|0;if((d[I+(U>>>3)|0]&128>>>((U&7)>>>0)|0)==0){V=E}else{o=E+8|0;V=C>>>0>o>>>0?o:C}c[u>>2]=V;o=((V|0)<(C|0))+V|0;if((d[I+(V>>>3)|0]&128>>>((V&7)>>>0)|0)==0){W=o}else{E=o+7|0;W=C>>>0>E>>>0?E:C}c[u>>2]=W;if((G|0)==0){break}else{G=G-1|0;D=W}}D=W+2|0;G=C>>>0>D>>>0?D:C;c[u>>2]=G;D=d[I+(G>>>3)|0]|0;E=((G|0)<(C|0))+G|0;c[u>>2]=E;o=(D&128>>>((G&7)>>>0)|0)!=0;do{if((Q|0)==6){if(o){G=I+(E>>>3)|0;D=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7)>>>30;G=E+2|0;X=C>>>0>G>>>0?G:C;c[u>>2]=X;c[J>>2]=D;D=I+(X>>>3)|0;G=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(X&7)>>>29;D=X+3|0;X=C>>>0>D>>>0?D:C;c[u>>2]=X;c[L>>2]=G;G=I+(X>>>3)|0;D=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(X&7)>>>29;G=X+3|0;X=C>>>0>G>>>0?G:C;c[u>>2]=X;c[N>>2]=D>>>0<3>>>0?3:D;D=I+(X>>>3)|0;G=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(X&7)>>>29;D=X+3|0;X=C>>>0>D>>>0?D:C;c[u>>2]=X;c[K>>2]=G;G=I+(X>>>3)|0;D=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(X&7)>>>29;G=X+3|0;X=C>>>0>G>>>0?G:C;c[u>>2]=X;c[M>>2]=D>>>0<3>>>0?3:D;Y=X}else{Y=E}X=d[I+(Y>>>3)|0]|0;D=((Y|0)<(C|0))+Y|0;c[u>>2]=D;if((X&128>>>((Y&7)>>>0)|0)==0){Z=D;break}X=I+(D>>>3)|0;G=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(D&7)>>>30;X=D+2|0;D=C>>>0>X>>>0?X:C;c[u>>2]=D;c[O>>2]=G;G=I+(D>>>3)|0;X=(fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(D&7)>>>30;G=D+2|0;c[P>>2]=X;X=(C>>>0>G>>>0?G:C)+10|0;G=C>>>0>X>>>0?X:C;c[u>>2]=G;Z=G}else{if(o){G=E+14|0;X=C>>>0>G>>>0?G:C;c[u>>2]=X;_=X}else{_=E}X=d[I+(_>>>3)|0]|0;G=((_|0)<(C|0))+_|0;c[u>>2]=G;if((X&128>>>((_&7)>>>0)|0)==0){Z=G;break}X=G+14|0;G=C>>>0>X>>>0?X:C;c[u>>2]=G;Z=G}}while(0);E=d[I+(Z>>>3)|0]|0;o=((Z|0)<(C|0))+Z|0;c[u>>2]=o;if((E&128>>>((Z&7)>>>0)|0)==0){$=H;y=42;break}E=I+(o>>>3)|0;P=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(o&7)>>>26;E=o+6|0;o=C>>>0>E>>>0?E:C;c[u>>2]=o;E=P;P=o;while(1){o=P+8|0;aa=C>>>0>o>>>0?o:C;if((E|0)==0){break}else{E=E-1|0;P=aa}}c[u>>2]=aa;$=H;y=42}else{T=x;y=31}}while(0);a:do{if((y|0)==31){if((T|0)==(-84085770|0)){do{if((c[l+28>>2]|0)!=1){if((c[l+32>>2]|0)!=0){break}yDb(f,16,2163912,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;ca=-84085770;y=49;break a}}while(0);yDb(f,24,2173752,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;c[k>>2]=0;da=v;i=m;return da|0}else if((T|0)==(-50531338|0)){yDb(f,16,2199072,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;ca=-50531338;y=49;break}else if((T|0)==(-67308554|0)){yDb(f,16,2190472,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;ca=-67308554;y=49;break}else if((T|0)==(-117640202|0)){ca=-117640202;y=49;break}else if((T|0)==(-33754122|0)){yDb(f,16,2207128,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;ca=-33754122;y=49;break}else if((T|0)==(-16976906|0)){yDb(f,16,2216640,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;da=-1094995529;i=m;return da|0}else if((T|0)==0){$=l+36|0;y=42;break}else if((T|0)==(-100862986|0)){ca=-100862986;y=49;break}else{c[k>>2]=0;da=T;i=m;return da|0}}}while(0);b:do{if((y|0)==42){if((c[$>>2]|0)>(v|0)){yDb(f,16,2156928,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;ca=-67308554;y=49;break}T=f+696|0;do{if((c[T>>2]&65537|0)!=0){H=tBb(1)|0;if((uBb(H,0,l+86786|0,(c[$>>2]|0)-2|0)|0)==0){break}yDb(f,16,2150240,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;if((c[T>>2]&8|0)==0){ca=-100862986;y=49;break b}else{da=-1094995529}i=m;return da|0}}while(0);c[f+412>>2]=c[l+44>>2];c[f+72>>2]=c[l+40>>2];ea=0;fa=c[l+44928>>2]|0;ga=l+45e3|0;y=51}}while(0);do{if((y|0)==49){$=c[l+44928>>2]|0;if(($|0)==0){yDb(f,16,2143264,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;da=-1094995529;i=m;return da|0}else{T=l+45e3|0;if((c[T>>2]|0)!=($|0)){ea=ca;fa=$;ga=T;y=51;break}ha=ca;ia=l+44996|0;break}}}while(0);do{if((y|0)==51){c[ga>>2]=fa;ca=l+60|0;T=c[ca>>2]|0;$=l+44996|0;c[$>>2]=T;if((c[l+64>>2]|0)==0){ja=T}else{H=T|8;c[$>>2]=H;ja=H}H=c[l+44928>>2]|0;do{if((H|0)>1){x=f+456|0;aa=c[x>>2]|0;Z=c[x+4>>2]|0;if((aa|0)==4&(Z|0)==0){c[ga>>2]=1;c[$>>2]=1;ka=1;la=1;break}if(!((H|0)>2&((aa|0)==3&(Z|0)==0))){ka=fa;la=ja;break}c[ga>>2]=2;c[$>>2]=2;ka=2;la=2}else{ka=fa;la=ja}}while(0);ma=+g[1038408+(c[l+76>>2]<<2)>>2];g[l+128>>2]=ma;na=+g[1038408+(c[l+84>>2]<<2)>>2];g[l+132>>2]=na;g[l+120>>2]=.7071067690849304;g[l+124>>2]=.7071067690849304;if((H|0)==(ka|0)){ha=ea;ia=$;break}Z=c[l+44924>>2]|0;if((la&8|0)!=0&(Z|0)==(ka|0)){ha=ea;ia=$;break}aa=l+44924|0;if((Z|0)>0){Z=0;x=T;while(1){g[w+44936+(Z<<3)>>2]=+g[1038408+(d[1876568+(x*10|0)+(Z<<1)|0]<<2)>>2];g[w+44936+(Z<<3)+4>>2]=+g[1038408+(d[1876568+(x*10|0)+(Z<<1)+1|0]<<2)>>2];_=Z+1|0;Y=c[ca>>2]|0;if((_|0)<(c[aa>>2]|0)){Z=_;x=Y}else{oa=Y;break}}}else{oa=T}if(!((oa|0)<2|(oa&1|0)==0)){g[l+44948>>2]=ma;g[l+44944>>2]=ma}if((oa-4|0)>>>0<2>>>0){x=oa-2|0;pa=na*.7071067811865476;g[w+44936+(x<<3)+4>>2]=pa;g[w+44936+(x<<3)>>2]=pa;qa=c[ca>>2]|0}else{qa=oa}if((qa-6|0)>>>0<2>>>0){g[w+44936+(qa-3<<3)+4>>2]=na;g[w+44936+(qa-4<<3)>>2]=na}x=c[aa>>2]|0;if((x|0)>0){ra=0.0;sa=0.0;ta=0}else{ha=ea;ia=$;break}do{sa=sa+ +g[w+44936+(ta<<3)>>2];ra=ra+ +g[w+44936+(ta<<3)+4>>2];ta=ta+1|0;}while((ta|0)<(x|0));na=1.0/sa;ma=1.0/ra;x=0;do{ca=w+44936+(x<<3)|0;g[ca>>2]=na*+g[ca>>2];ca=w+44936+(x<<3)+4|0;g[ca>>2]=ma*+g[ca>>2];x=x+1|0;ua=c[aa>>2]|0;}while((x|0)<(ua|0));if((c[$>>2]|0)==1&(ua|0)>0){va=0}else{ha=ea;ia=$;break}while(1){x=w+44936+(va<<3)|0;g[x>>2]=(+g[x>>2]+ +g[w+44936+(va<<3)+4>>2])*.7071067811865476;x=va+1|0;if((x|0)<(ua|0)){va=x}else{ha=ea;ia=$;break}}}}while(0);ea=l+45e3|0;c[f+416>>2]=c[ea>>2];va=c[ia>>2]|0;ua=e[1746384+((va&-9)<<1)>>1]|0;ta=0;qa=f+448|0;oa=(va&8|0)==0;c[qa>>2]=oa?ua:ua|8;c[qa+4>>2]=oa?ta:ta|0;ta=c[l+56>>2]|0;oa=f+464|0;c[oa>>2]=ta;do{if((ta|0)==7){if((c[l+44928>>2]|0)<=1){break}c[oa>>2]=8}}while(0);oa=l+48|0;c[j+76>>2]=c[oa>>2]<<8;ta=_$a(f,t,0)|0;if((ta|0)<0){da=ta;i=m;return da|0}ta=c[l+64>>2]|0;qa=c[ia>>2]|0;ua=l+79616|0;va=ua;ka=l+55972|0;la=ka;ja=ua;c[s>>2]=ja;c[ka>>2]=ja;ja=l+80640|0;c[s+4>>2]=ja;c[l+55976>>2]=ja;ja=l+81664|0;c[s+8>>2]=ja;c[l+55980>>2]=ja;ja=l+82688|0;c[s+12>>2]=ja;c[l+55984>>2]=ja;ja=l+83712|0;c[s+16>>2]=ja;c[l+55988>>2]=ja;ja=l+84736|0;c[s+20>>2]=ja;c[l+55992>>2]=ja;ja=l+85760|0;c[s+24>>2]=ja;c[l+55996>>2]=ja;ja=qa&-9;qa=l+44928|0;ua=c[qa>>2]|0;if((ua|0)>0){fa=j;ga=0;$=ua;while(1){if((ga|0)<(c[ea>>2]|0)){c[la+(d[1276360+(ja*12|0)+(ta*6|0)+ga|0]<<2)>>2]=c[fa+(ga<<2)>>2];wa=c[qa>>2]|0}else{wa=$}ua=ga+1|0;if((ua|0)<(wa|0)){ga=ua;$=wa}else{break}}}if((c[oa>>2]|0)>0){wa=r|0;$=l+44924|0;ga=l+60|0;fa=l+140|0;ua=l+144|0;x=l+45012|0;aa=l+100|0;ca=l+876|0;T=l+896|0;Z=l+908|0;H=l+900|0;Y=l+4|0;_=l+45072|0;Q=l+45016|0;W=l+45044|0;V=l+45092|0;U=l+148|0;n=l+136|0;P=l+152|0;E=e[637980]|0;C=l+28|0;I=l+47116|0;o=l+47108|0;O=l+47112|0;M=l+156|0;K=l+160|0;N=q+28|0;L=q+24|0;J=q+20|0;G=l+45048|0;X=l+45052|0;D=l+55944|0;xa=l+56004|0;ya=l+44936|0;za=l+44992|0;Aa=l+56028|0;Ba=ka;ka=l+71424|0;Ca=l+70400|0;Da=l+73472|0;Ea=l+72448|0;Fa=l+74496|0;Ga=l+55952|0;Ha=l+45004|0;Ia=l+316|0;Ja=l+47080|0;Ka=l+44932|0;La=l+55920|0;Ma=l+47104|0;Na=l+47084|0;Oa=l+47092|0;Pa=l+47096|0;Qa=l+47088|0;Ra=l+47100|0;Sa=l+240|0;Ta=l+320|0;Ua=l+216|0;Va=l+220|0;Wa=f;f=l+881|0;Xa=l+904|0;Ya=l+912|0;Za=l+54468|0;_a=j;j=ha;$a=0;while(1){c:do{if((j|0)==0){ab=c[$>>2]|0;bb=c[ga>>2]|0;TGb(wa|0,0,7)|0;cb=(ab|0)<1;if((c[fa>>2]|0)==0|cb){db=0}else{eb=0;fb=1;while(1){gb=c[u>>2]|0;hb=d[(c[z>>2]|0)+(gb>>>3)|0]<<(gb&7)>>>7;c[u>>2]=((gb|0)<(c[A>>2]|0))+gb;gb=hb&1;c[w+54464+(fb<<2)>>2]=gb;if((fb|0)>1){ib=(gb|0)==(c[Za>>2]|0)?eb:1}else{ib=eb}gb=fb+1|0;if((gb|0)>(ab|0)){db=ib;break}else{eb=ib;fb=gb}}}if(!((c[ua>>2]|0)==0|cb)){fb=1;do{eb=c[u>>2]|0;gb=d[(c[z>>2]|0)+(eb>>>3)|0]<<(eb&7)>>>7;c[u>>2]=((eb|0)<(c[A>>2]|0))+eb;c[w+54176+(fb<<2)>>2]=gb&1;fb=fb+1|0;}while((fb|0)<=(ab|0))}fb=($a|0)==0;gb=(c[ga>>2]|0)==0|0;while(1){eb=c[u>>2]|0;hb=c[z>>2]|0;jb=d[hb+(eb>>>3)|0]|0;kb=c[A>>2]|0;lb=((eb|0)<(kb|0))+eb|0;c[u>>2]=lb;do{if((jb&128>>>((eb&7)>>>0)|0)==0){if(!fb){break}g[w+45004+(gb<<2)>>2]=1.0}else{mb=hb+(lb>>>3)|0;nb=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(lb&7)>>>24;mb=lb+8|0;c[u>>2]=kb>>>0>mb>>>0?mb:kb;ra=+g[8163272+(nb<<2)>>2];sa=+g[x>>2];if(ra<=1.0&sa>1.0){g[w+45004+(gb<<2)>>2]=ra;break}else{g[w+45004+(gb<<2)>>2]=+S(+ra,+sa);break}}}while(0);if((gb|0)==0){break}gb=gb-1|0}d:do{if((c[aa>>2]|0)==0){y=125}else{gb=c[u>>2]|0;if(fb){ob=gb;pb=c[z>>2]|0;qb=c[A>>2]|0}else{kb=c[z>>2]|0;lb=d[kb+(gb>>>3)|0]|0;hb=c[A>>2]|0;eb=((gb|0)<(hb|0))+gb|0;c[u>>2]=eb;if((lb&128>>>((gb&7)>>>0)|0)==0){y=125;break}else{ob=eb;pb=kb;qb=hb}}hb=d[pb+(ob>>>3)|0]<<(ob&7)>>>7;kb=((ob|0)<(qb|0))+ob|0;c[u>>2]=kb;eb=hb&1;c[ca>>2]=eb;if((eb|0)==0){if(cb){y=136;break}else{rb=1}while(1){a[w+880+rb|0]=0;a[w+929+rb|0]=1;eb=rb+1|0;if((eb|0)>(ab|0)){y=125;break d}else{rb=eb}}}do{if((c[ga>>2]|0)==1){a[f]=1;sb=kb;tb=qb;ub=pb}else{if(cb){sb=kb;tb=qb;ub=pb;break}else{vb=1;wb=kb;xb=pb;yb=qb}while(1){eb=d[xb+(wb>>>3)|0]<<(wb&7)>>>7;c[u>>2]=((wb|0)<(yb|0))+wb;a[w+880+vb|0]=eb&1;eb=vb+1|0;zb=c[u>>2]|0;if((eb|0)>(ab|0)){break}vb=eb;wb=zb;xb=c[z>>2]|0;yb=c[A>>2]|0}sb=zb;tb=c[A>>2]|0;ub=c[z>>2]|0}}while(0);kb=ub+(sb>>>3)|0;eb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(sb&7)>>>30;kb=sb+2|0;hb=tb>>>0>kb>>>0?kb:tb;c[u>>2]=hb;kb=ub+(hb>>>3)|0;gb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(hb&7)>>>29;kb=hb+3|0;hb=tb>>>0>kb>>>0?kb:tb;c[u>>2]=hb;kb=gb+2|0;if(kb>>>0>7>>>0){Ab=gb-5+kb|0}else{Ab=kb}kb=ub+(hb>>>3)|0;gb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(hb&7)>>>29;kb=hb+3|0;c[u>>2]=tb>>>0>kb>>>0?kb:tb;kb=gb+5|0;if(kb>>>0>7>>>0){Bb=gb-2+kb|0}else{Bb=kb}kb=(eb*12|0)+25|0;eb=(Ab*12|0)+25|0;if((Ab|0)>=(Bb|0)){yDb(c[Y>>2]|0,16,2131152,(ba=i,i=i+16|0,c[ba>>2]=Ab,c[ba+8>>2]=Bb,ba)|0);i=ba;break}if((kb|0)<(eb|0)){c[Xa>>2]=kb;c[T>>2]=eb;c[H>>2]=(Bb*12|0)+25;Kfb(B,$a,c[aa>>2]|0,Ab,Bb,1224864,Z,Ya);y=125;break}else{yDb(c[Y>>2]|0,16,2124752,(ba=i,i=i+16|0,c[ba>>2]=kb,c[ba+8>>2]=eb,ba)|0);i=ba;break}}}while(0);do{if((y|0)==125){y=0;if((c[ca>>2]|0)==0|cb){y=136;break}else{Cb=1}while(1){eb=w+929+Cb|0;do{if((a[w+880+Cb|0]|0)==0){a[eb]=1}else{if((a[eb]|0)==0){kb=c[u>>2]|0;gb=d[(c[z>>2]|0)+(kb>>>3)|0]|0;c[u>>2]=((kb|0)<(c[A>>2]|0))+kb;if((gb&128>>>((kb&7)>>>0)|0)==0){break}}a[eb]=0;kb=c[u>>2]|0;gb=c[A>>2]|0;hb=c[z>>2]|0;lb=hb+(kb>>>3)|0;jb=(fe(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(kb&7)>>>27;lb=kb+5|0;kb=gb>>>0>lb>>>0?lb:gb;c[u>>2]=kb;sa=+(jb>>>0>>>0)*.03125;jb=hb+(kb>>>3)|0;hb=d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0;jb=kb+2|0;c[u>>2]=gb>>>0>jb>>>0?jb:gb;if((c[Z>>2]|0)<=0){break}gb=(fe(hb|0)|0)<<(kb&7);kb=((gb>>>30)*-3|0)+25|0;gb=c[T>>2]|0;hb=0;while(1){jb=d[w+912+hb|0]|0;ra=+((jb>>>1)+gb|0)/+(c[H>>2]|0)-sa;if(ra<0.0){Db=0.0}else{Db=ra>1.0?1.0:ra}ra=+R(Db*3.0);ma=+R(1.0-Db);lb=c[u>>2]|0;nb=c[A>>2]|0;mb=c[z>>2]|0;Eb=mb+(lb>>>3)|0;Fb=(fe(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(lb&7)>>>28;Eb=lb+4|0;lb=nb>>>0>Eb>>>0?Eb:nb;c[u>>2]=lb;Eb=mb+(lb>>>3)|0;mb=(fe(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(lb&7)>>>30;Eb=lb+2|0;c[u>>2]=nb>>>0>Eb>>>0?Eb:nb;na=+(((Fb|0)==15?mb<<1:mb|4)<<kb-Fb|0)*1.1920928955078125e-7;g[w+936+(Cb*68|0)+(hb<<2)>>2]=ra*na;g[w+1412+(Cb*68|0)+(hb<<2)>>2]=ma*na;Fb=hb+1|0;if((Fb|0)<(c[Z>>2]|0)){gb=jb+gb|0;hb=Fb}else{break}}}}while(0);eb=Cb+1|0;if((eb|0)>(ab|0)){y=136;break}else{Cb=eb}}}}while(0);e:do{if((y|0)==136){y=0;do{if((c[aa>>2]|0)==0){eb=c[u>>2]|0;hb=c[z>>2]|0;gb=d[hb+(eb>>>3)|0]|0;kb=c[A>>2]|0;Fb=((eb|0)<(kb|0))+eb|0;c[u>>2]=Fb;if((gb&128>>>((eb&7)>>>0)|0)!=0){TGb(wa|0,3,7)|0;eb=d[hb+(Fb>>>3)|0]<<(Fb&7)>>>7;c[u>>2]=((Fb|0)<(kb|0))+Fb;Fb=eb&1;c[w+164+($a<<2)>>2]=Fb;Gb=Fb;y=141;break}if(fb){yDb(c[Y>>2]|0,16,2092560,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}else{Fb=w+164+($a<<2)|0;c[Fb>>2]=c[w+164+($a-1<<2)>>2];Hb=Fb;break}}else{if((c[w+188+($a<<2)>>2]|0)==0){Hb=w+164+($a<<2)|0;break}else{TGb(wa|0,3,7)|0;Gb=c[w+164+($a<<2)>>2]|0;y=141;break}}}while(0);do{if((y|0)==141){y=0;Fb=w+164+($a<<2)|0;if((Gb|0)==0){if(!cb){eb=1;do{c[w+212+(eb<<2)>>2]=0;c[w+344+(eb<<2)>>2]=1;eb=eb+1|0;}while((eb|0)<=(ab|0))}c[I>>2]=c[aa>>2];c[Sa>>2]=0;Hb=Fb;break}if((bb|0)<2){yDb(c[Y>>2]|0,16,2119200,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}do{if((c[aa>>2]|0)==0){y=146}else{eb=c[u>>2]|0;kb=d[(c[z>>2]|0)+(eb>>>3)|0]|0;c[u>>2]=((eb|0)<(c[A>>2]|0))+eb;if((kb&128>>>((eb&7)>>>0)|0)!=0){DDb(c[Y>>2]|0,2113048,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}if((c[ga>>2]|0)!=2){y=146;break}c[Ua>>2]=1;c[Va>>2]=1}}while(0);do{if((y|0)==146){y=0;if(cb){break}else{Ib=1}do{eb=c[u>>2]|0;kb=d[(c[z>>2]|0)+(eb>>>3)|0]<<(eb&7)>>>7;c[u>>2]=((eb|0)<(c[A>>2]|0))+eb;c[w+212+(Ib<<2)>>2]=kb&1;Ib=Ib+1|0;}while((Ib|0)<=(ab|0))}}while(0);kb=c[u>>2]|0;if((bb|0)==2){eb=c[z>>2]|0;hb=d[eb+(kb>>>3)|0]<<(kb&7)>>>7;gb=c[A>>2]|0;jb=((kb|0)<(gb|0))+kb|0;c[u>>2]=jb;c[Sa>>2]=hb&1;Jb=jb;Kb=gb;Lb=eb}else{Jb=kb;Kb=c[A>>2]|0;Lb=c[z>>2]|0}kb=Lb+(Jb>>>3)|0;eb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Jb&7)>>>28;kb=Jb+4|0;gb=Kb>>>0>kb>>>0?kb:Kb;c[u>>2]=gb;if((c[ca>>2]|0)==0){kb=Lb+(gb>>>3)|0;jb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(gb&7)>>>28;kb=gb+4|0;c[u>>2]=Kb>>>0>kb>>>0?kb:Kb;Mb=jb+3|0}else{Mb=((c[T>>2]|0)-37|0)/12|0}if((eb|0)<(Mb|0)){c[Q>>2]=(eb*12|0)+37;c[W>>2]=(Mb*12|0)+37;Kfb(B,$a,c[aa>>2]|0,eb,Mb,1224888,Ia,Ta);Hb=Fb;break}else{yDb(c[Y>>2]|0,16,2098824,(ba=i,i=i+16|0,c[ba>>2]=eb,c[ba+8>>2]=Mb,ba)|0);i=ba;break e}}}while(0);eb=(c[Hb>>2]|0)!=0;do{if(!(cb|eb^1)){jb=0;kb=1;f:while(1){g:do{if((c[w+212+(kb<<2)>>2]|0)==0){c[w+344+(kb<<2)>>2]=1;Nb=jb}else{if((c[aa>>2]|0)==0){y=171}else{gb=w+344+(kb<<2)|0;if((c[gb>>2]|0)==0){y=171}else{Ob=gb}}do{if((y|0)==171){y=0;gb=c[u>>2]|0;hb=d[(c[z>>2]|0)+(gb>>>3)|0]|0;c[u>>2]=((gb|0)<(c[A>>2]|0))+gb;if((hb&128>>>((gb&7)>>>0)|0)==0){if(fb){y=180;break f}else{Nb=jb;break g}}else{Ob=w+344+(kb<<2)|0;break}}}while(0);c[Ob>>2]=0;gb=c[u>>2]|0;hb=c[A>>2]|0;mb=c[z>>2]|0;nb=mb+(gb>>>3)|0;Eb=(fe(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(gb&7)>>>30;nb=gb+2|0;gb=hb>>>0>nb>>>0?nb:hb;c[u>>2]=gb;nb=Eb*3|0;if((c[Ia>>2]|0)>0){Pb=0;Qb=gb;Rb=hb;Sb=mb}else{Nb=1;break}while(1){mb=Sb+(Qb>>>3)|0;hb=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(Qb&7)>>>28;mb=Qb+4|0;gb=Rb>>>0>mb>>>0?mb:Rb;c[u>>2]=gb;mb=Sb+(gb>>>3)|0;Eb=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(gb&7)>>>28;mb=gb+4|0;c[u>>2]=Rb>>>0>mb>>>0?mb:Rb;if((hb|0)==15){mb=Eb<<22;c[w+372+(kb*72|0)+(Pb<<2)>>2]=mb;Tb=mb}else{mb=Eb<<21|33554432;c[w+372+(kb*72|0)+(Pb<<2)>>2]=mb;Tb=mb}c[w+372+(kb*72|0)+(Pb<<2)>>2]=Tb>>hb+nb;hb=Pb+1|0;if((hb|0)>=(c[Ia>>2]|0)){Nb=1;break g}Pb=hb;Qb=c[u>>2]|0;Rb=c[A>>2]|0;Sb=c[z>>2]|0}}}while(0);nb=kb+1|0;if((nb|0)>(ab|0)){break}else{jb=Nb;kb=nb}}if((y|0)==180){y=0;yDb(c[Y>>2]|0,16,2087336,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}if((bb|0)!=2|(Nb|0)==0){break}if((c[Ia>>2]|0)>0){Ub=0}else{break}do{if((c[Sa>>2]|0)==0){Vb=0}else{kb=c[u>>2]|0;jb=d[(c[z>>2]|0)+(kb>>>3)|0]<<(kb&7)>>>7;c[u>>2]=((kb|0)<(c[A>>2]|0))+kb;Vb=jb&1}c[w+244+(Ub<<2)>>2]=Vb;Ub=Ub+1|0;}while((Ub|0)<(c[Ia>>2]|0))}}while(0);h:do{if((bb|0)==2){do{if(!((c[aa>>2]|0)!=0&fb)){jb=c[u>>2]|0;kb=d[(c[z>>2]|0)+(jb>>>3)|0]|0;c[u>>2]=((jb|0)<(c[A>>2]|0))+jb;if((kb&128>>>((jb&7)>>>0)|0)!=0){break}if(!fb){break h}yDb(c[Y>>2]|0,24,2082680,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;c[_>>2]=0;break h}}while(0);c[_>>2]=4;do{if(eb){jb=c[Q>>2]|0;if((jb|0)>=62){y=194;break}c[_>>2]=(jb|0)==37?2:3;Wb=0}else{y=194}}while(0);do{if((y|0)==194){y=0;if((c[ca>>2]|0)==0){Wb=0;break}if((c[T>>2]|0)>=62){Wb=0;break}c[_>>2]=3;Wb=0}}while(0);do{jb=c[u>>2]|0;kb=d[(c[z>>2]|0)+(jb>>>3)|0]<<(jb&7)>>>7;c[u>>2]=((jb|0)<(c[A>>2]|0))+jb;c[w+45076+(Wb<<2)>>2]=kb&1;Wb=Wb+1|0;}while((Wb|0)<(c[_>>2]|0))}}while(0);kb=eb&1^1;if((kb|0)<=(c[qa>>2]|0)){jb=kb;do{if((c[aa>>2]|0)==0){Fb=2-((jb|0)==(c[Ka>>2]|0))|0;nb=c[u>>2]|0;hb=c[A>>2]|0;mb=(c[z>>2]|0)+(nb>>>3)|0;Eb=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(nb&7)>>>((32-Fb|0)>>>0);mb=Fb+nb|0;c[u>>2]=hb>>>0>mb>>>0?mb:hb;c[w+46912+($a*28|0)+(jb<<2)>>2]=Eb;Xb=Eb}else{Xb=c[w+46912+($a*28|0)+(jb<<2)>>2]|0}if((Xb|0)!=0){a[r+jb|0]=3}jb=jb+1|0;}while((jb|0)<=(c[qa>>2]|0))}i:do{if(!cb){jb=($a|0)<1;Eb=1;j:while(1){c[w+45016+(Eb<<2)>>2]=0;hb=w+46912+($a*28|0)+(Eb<<2)|0;do{if((c[hb>>2]|0)!=0){mb=w+45044+(Eb<<2)|0;nb=c[mb>>2]|0;do{if((c[w+212+(Eb<<2)>>2]|0)==0){if((a[w+880+Eb|0]|0)!=0){Fb=c[T>>2]|0;c[mb>>2]=Fb;Yb=Fb;break}Fb=c[u>>2]|0;gb=c[A>>2]|0;lb=(c[z>>2]|0)+(Fb>>>3)|0;Zb=(fe(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(Fb&7);_b=Zb>>>26;lb=Fb+6|0;c[u>>2]=gb>>>0>lb>>>0?lb:gb;if(Zb>>>0>4093640703>>>0){break j}Zb=(_b*3|0)+73|0;c[mb>>2]=Zb;Yb=Zb}else{Zb=c[Q>>2]|0;c[mb>>2]=Zb;Yb=Zb}}while(0);mb=3<<(c[hb>>2]|0)-1;c[w+45092+(Eb<<2)>>2]=(Yb-4+mb|0)/(mb|0)|0;if(jb|(Yb|0)==(nb|0)){break}TGb(wa|0,3,7)|0}}while(0);Eb=Eb+1|0;if((Eb|0)>(ab|0)){break i}}yDb(c[Y>>2]|0,16,2076952,(ba=i,i=i+8|0,c[ba>>2]=_b,ba)|0);i=ba;break e}}while(0);do{if(eb){Eb=c[w+46912+($a*28|0)>>2]|0;if((Eb|0)==0){break}c[V>>2]=((c[W>>2]|0)-(c[Q>>2]|0)|0)/(3<<Eb-1|0)|0}}while(0);Eb=c[qa>>2]|0;k:do{if((kb|0)>(Eb|0)){$b=Eb}else{jb=kb;l:while(1){hb=w+46912+($a*28|0)+(jb<<2)|0;do{if((c[hb>>2]|0)!=0){mb=c[u>>2]|0;Zb=c[A>>2]|0;gb=c[z>>2]|0;lb=gb+(mb>>>3)|0;Fb=(fe(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(mb&7)>>>28;lb=mb+4|0;mb=Zb>>>0>lb>>>0?lb:Zb;c[u>>2]=mb;lb=(jb|0)!=0;ac=lb&1;bc=Fb<<(ac^1);a[w+45120+(jb<<8)|0]=bc;Fb=c[hb>>2]|0;cc=c[w+45092+(jb<<2)>>2]|0;dc=(c[w+45016+(jb<<2)>>2]|0)+ac|0;ac=((Fb|0)==3)+Fb|0;if((cc|0)>0){Fb=0;ec=0;fc=mb;while(1){mb=gb+(fc>>>3)|0;gc=(fe(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(fc&7)>>>25;mb=fc+7|0;hc=Zb>>>0>mb>>>0?mb:Zb;c[u>>2]=hc;c[p+(ec<<2)>>2]=d[2818776+(gc*3|0)|0]|0;c[p+(ec+1<<2)>>2]=d[2818777+(gc*3|0)|0]|0;c[p+(ec+2<<2)>>2]=d[2818778+(gc*3|0)|0]|0;gc=Fb+1|0;if((gc|0)<(cc|0)){Fb=gc;ec=ec+3|0;fc=hc}else{break}}}fc=bc&255;ec=cc*3|0;if((ec|0)>0){if((ac|0)==4){Fb=0;Zb=0;gb=fc;while(1){nb=gb-2+(c[p+(Zb<<2)>>2]|0)|0;if(nb>>>0>24>>>0){break l}hc=nb&255;a[Fb+dc+(w+45120+(jb<<8))|0]=hc;a[(Fb|1)+dc+(w+45120+(jb<<8))|0]=hc;a[(Fb|2)+dc+(w+45120+(jb<<8))|0]=hc;a[(Fb|3)+dc+(w+45120+(jb<<8))|0]=hc;hc=Zb+1|0;if((hc|0)<(ec|0)){Fb=Fb+4|0;Zb=hc;gb=nb}else{break}}}else if((ac|0)==2){gb=0;Zb=0;Fb=fc;while(1){cc=Fb-2+(c[p+(Zb<<2)>>2]|0)|0;if(cc>>>0>24>>>0){break l}bc=cc&255;a[gb+dc+(w+45120+(jb<<8))|0]=bc;a[(gb|1)+dc+(w+45120+(jb<<8))|0]=bc;bc=Zb+1|0;if((bc|0)<(ec|0)){gb=gb+2|0;Zb=bc;Fb=cc}else{break}}}else{Fb=(ac|0)==1;Zb=0;gb=0;cc=fc;while(1){bc=cc-2+(c[p+(gb<<2)>>2]|0)|0;if(bc>>>0>24>>>0){break l}if(Fb){a[Zb+dc+(w+45120+(jb<<8))|0]=bc;ic=Zb+1|0}else{ic=Zb}nb=gb+1|0;if((nb|0)<(ec|0)){Zb=ic;gb=nb;cc=bc}else{break}}}}if(!lb){break}if((jb|0)==(c[Ka>>2]|0)){break}cc=c[A>>2]|0;gb=(c[u>>2]|0)+2|0;c[u>>2]=cc>>>0>gb>>>0?gb:cc}}while(0);hb=jb+1|0;cc=c[qa>>2]|0;if((hb|0)>(cc|0)){$b=cc;break k}else{jb=hb}}yDb(c[Y>>2]|0,16,2072232,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}}while(0);do{if((c[U>>2]|0)!=0){Eb=c[u>>2]|0;jb=c[z>>2]|0;hb=d[jb+(Eb>>>3)|0]|0;cc=c[A>>2]|0;gb=((Eb|0)<(cc|0))+Eb|0;c[u>>2]=gb;if((hb&128>>>((Eb&7)>>>0)|0)==0){if(!fb){break}yDb(c[Y>>2]|0,16,2067560,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}else{Eb=jb+(gb>>>3)|0;hb=(fe(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(gb&7)>>>30;Eb=gb+2|0;gb=cc>>>0>Eb>>>0?Eb:cc;c[u>>2]=gb;Eb=c[Na>>2]|0;c[Oa>>2]=(d[1274872+hb|0]|0)>>>(Eb>>>0);hb=jb+(gb>>>3)|0;Zb=(fe(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(gb&7)>>>30;hb=gb+2|0;gb=cc>>>0>hb>>>0?hb:cc;c[u>>2]=gb;c[Pa>>2]=(d[1275968+Zb|0]|0)>>>(Eb>>>0);Eb=jb+(gb>>>3)|0;Zb=(fe(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(gb&7)>>>30;Eb=gb+2|0;gb=cc>>>0>Eb>>>0?Eb:cc;c[u>>2]=gb;c[Qa>>2]=e[1274864+(Zb<<1)>>1]|0;Zb=jb+(gb>>>3)|0;Eb=(fe(d[Zb]|d[Zb+1|0]<<8|d[Zb+2|0]<<16|d[Zb+3|0]<<24|0)|0)<<(gb&7)>>>30;Zb=gb+2|0;gb=cc>>>0>Zb>>>0?Zb:cc;c[u>>2]=gb;c[Ra>>2]=e[1276456+(Eb<<1)>>1]|0;Eb=jb+(gb>>>3)|0;jb=(fe(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(gb&7)>>>29;Eb=gb+3|0;c[u>>2]=cc>>>0>Eb>>>0?Eb:cc;c[Ma>>2]=b[1275832+(jb<<1)>>1]|0;if((kb|0)>($b|0)){break}else{jc=kb}do{jb=r+jc|0;cc=a[jb]|0;a[jb]=(cc&255)>>>0>2>>>0?cc:2;jc=jc+1|0;}while((jc|0)<=($b|0))}}}while(0);cc=c[aa>>2]|0;m:do{if((cc|0)==0|fb){do{if((c[n>>2]|0)!=0){jb=c[u>>2]|0;Eb=c[z>>2]|0;gb=d[Eb+(jb>>>3)|0]|0;Zb=c[A>>2]|0;hb=((jb|0)<(Zb|0))+jb|0;c[u>>2]=hb;if((gb&128>>>((jb&7)>>>0)|0)==0){break}jb=Eb+(hb>>>3)|0;Eb=(fe(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(hb&7)>>>26;jb=hb+6|0;c[u>>2]=Zb>>>0>jb>>>0?jb:Zb;Zb=(Eb<<4)+1073741584|0;if((kb|0)>($b|0)){kc=$b;break m}Eb=($a|0)!=0;jb=Eb^1;hb=0;gb=kb;while(1){if((gb|0)==(kb|0)){y=256}else{if((c[n>>2]|0)==2){y=256}else{lc=hb}}if((y|0)==256){y=0;ec=c[u>>2]|0;dc=c[A>>2]|0;Fb=(c[z>>2]|0)+(ec>>>3)|0;fc=(fe(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(ec&7)>>>28;Fb=ec+4|0;c[u>>2]=dc>>>0>Fb>>>0?Fb:dc;lc=(fc|Zb)<<2}fc=w+47120+(gb<<2)|0;do{if(Eb){if((c[fc>>2]|0)==(lc|0)){break}dc=r+gb|0;Fb=a[dc]|0;a[dc]=(Fb&255)>>>0>1>>>0?Fb:1}}while(0);c[fc>>2]=lc;do{if((c[aa>>2]|0)==0){lb=w+47148+(gb<<2)|0;Fb=c[lb>>2]|0;dc=c[u>>2]|0;ec=c[A>>2]|0;ac=(c[z>>2]|0)+(dc>>>3)|0;bc=(fe(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(dc&7)>>>29;ac=dc+3|0;c[u>>2]=ec>>>0>ac>>>0?ac:ec;ec=e[1275952+(bc<<1)>>1]|0;c[lb>>2]=ec;if((Fb|0)==(ec|0)|jb){break}ec=r+gb|0;Fb=a[ec]|0;a[ec]=(Fb&255)>>>0>2>>>0?Fb:2}}while(0);fc=gb+1|0;Fb=c[qa>>2]|0;if((fc|0)>(Fb|0)){kc=Fb;break m}else{hb=lc;gb=fc}}}}while(0);if((cc|$a|0)!=0){kc=$b;break}yDb(c[Y>>2]|0,16,2063280,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}else{kc=$b}}while(0);n:do{if((c[P>>2]|0)==0){y=273}else{cc=c[u>>2]|0;gb=c[z>>2]|0;hb=d[gb+(cc>>>3)|0]|0;jb=c[A>>2]|0;Eb=((cc|0)<(jb|0))+cc|0;c[u>>2]=Eb;if((hb&128>>>((cc&7)>>>0)|0)==0){y=273;break}if((kb|0)>(kc|0)){mc=kc;break}else{nc=kb;oc=Eb;pc=jb;qc=gb}while(1){gb=w+47148+(nc<<2)|0;jb=c[gb>>2]|0;Eb=qc+(oc>>>3)|0;cc=(fe(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(oc&7)>>>29;Eb=oc+3|0;c[u>>2]=pc>>>0>Eb>>>0?Eb:pc;Eb=e[1275952+(cc<<1)>>1]|0;c[gb>>2]=Eb;if(!(fb|(jb|0)==(Eb|0))){Eb=r+nc|0;jb=a[Eb]|0;a[Eb]=(jb&255)>>>0>2>>>0?jb:2}jb=nc+1|0;Eb=c[qa>>2]|0;if((jb|0)>(Eb|0)){mc=Eb;break n}nc=jb;oc=c[u>>2]|0;pc=c[A>>2]|0;qc=c[z>>2]|0}}}while(0);do{if((y|0)==273){y=0;if((kb|0)>(kc|0)|(c[aa>>2]|0)!=0&fb^1){mc=kc;break}else{rc=kb}while(1){c[w+47148+(rc<<2)>>2]=E;jb=rc+1|0;Eb=c[qa>>2]|0;if((jb|0)>(Eb|0)){mc=Eb;break}else{rc=jb}}}}while(0);do{if((c[C>>2]|0)==0){jb=c[u>>2]|0;Eb=d[(c[z>>2]|0)+(jb>>>3)|0]|0;gb=c[A>>2]|0;cc=((jb|0)<(gb|0))+jb|0;c[u>>2]=cc;if((Eb&128>>>((jb&7)>>>0)|0)==0){break}jb=cc+10|0;c[u>>2]=gb>>>0>jb>>>0?jb:gb}}while(0);if(eb){gb=c[u>>2]|0;do{if((c[I>>2]|0)==0){jb=c[z>>2]|0;cc=d[jb+(gb>>>3)|0]|0;Eb=c[A>>2]|0;hb=((gb|0)<(Eb|0))+gb|0;c[u>>2]=hb;if((cc&128>>>((gb&7)>>>0)|0)!=0){sc=hb;tc=Eb;uc=jb;y=282;break}if((c[aa>>2]|$a|0)!=0){break}yDb(c[Y>>2]|0,16,2059560,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}else{sc=gb;tc=c[A>>2]|0;uc=c[z>>2]|0;y=282}}while(0);if((y|0)==282){y=0;gb=uc+(sc>>>3)|0;eb=(fe(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(sc&7)>>>29;gb=sc+3|0;jb=tc>>>0>gb>>>0?gb:tc;c[u>>2]=jb;gb=uc+(jb>>>3)|0;Eb=(fe(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(jb&7)>>>29;gb=jb+3|0;c[u>>2]=tc>>>0>gb>>>0?gb:tc;do{if(!fb){if((eb|0)==(c[o>>2]|0)){if((Eb|0)==(c[O>>2]|0)){break}}gb=a[wa]|0;a[wa]=(gb&255)>>>0>2>>>0?gb:2}}while(0);c[o>>2]=eb;c[O>>2]=Eb}c[I>>2]=0}do{if((c[M>>2]|0)==0){y=302}else{gb=c[u>>2]|0;jb=c[z>>2]|0;hb=d[jb+(gb>>>3)|0]|0;cc=c[A>>2]|0;Zb=((gb|0)<(cc|0))+gb|0;c[u>>2]=Zb;if((hb&128>>>((gb&7)>>>0)|0)==0){y=302;break}o:do{if((kb|0)<=(ab|0)){gb=jb+(Zb>>>3)|0;hb=(fe(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(Zb&7)>>>30;gb=Zb+2|0;c[u>>2]=cc>>>0>gb>>>0?gb:cc;c[w+53952+(kb<<2)>>2]=hb;p:do{if((hb|0)!=3){gb=kb;while(1){fc=r+gb|0;Fb=a[fc]|0;a[fc]=(Fb&255)>>>0>2>>>0?Fb:2;gb=gb+1|0;if((gb|0)>(ab|0)){vc=kb;break}Fb=c[u>>2]|0;fc=c[A>>2]|0;ec=(c[z>>2]|0)+(Fb>>>3)|0;lb=(fe(d[ec]|d[ec+1|0]<<8|d[ec+2|0]<<16|d[ec+3|0]<<24|0)|0)<<(Fb&7)>>>30;ec=Fb+2|0;c[u>>2]=fc>>>0>ec>>>0?ec:fc;c[w+53952+(gb<<2)>>2]=lb;if((lb|0)==3){break p}}while(1){if((c[w+53952+(vc<<2)>>2]|0)==1){gb=c[u>>2]|0;lb=c[A>>2]|0;fc=(c[z>>2]|0)+(gb>>>3)|0;ec=(fe(d[fc]|d[fc+1|0]<<8|d[fc+2|0]<<16|d[fc+3|0]<<24|0)|0)<<(gb&7)>>>29;fc=gb+3|0;c[u>>2]=lb>>>0>fc>>>0?fc:lb;lb=w+53980+(vc<<2)|0;c[lb>>2]=ec+1;ec=0;do{fc=c[u>>2]|0;gb=c[A>>2]|0;Fb=(c[z>>2]|0)+(fc>>>3)|0;bc=(fe(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(fc&7)>>>27;Fb=fc+5|0;c[u>>2]=gb>>>0>Fb>>>0?Fb:gb;a[w+54008+(vc<<3)+ec|0]=bc;bc=c[u>>2]|0;gb=c[A>>2]|0;Fb=(c[z>>2]|0)+(bc>>>3)|0;fc=(fe(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(bc&7)>>>28;Fb=bc+4|0;c[u>>2]=gb>>>0>Fb>>>0?Fb:gb;a[w+54064+(vc<<3)+ec|0]=fc;fc=c[u>>2]|0;gb=c[A>>2]|0;Fb=(c[z>>2]|0)+(fc>>>3)|0;bc=(fe(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(fc&7)>>>29;Fb=fc+3|0;c[u>>2]=gb>>>0>Fb>>>0?Fb:gb;a[w+54120+(vc<<3)+ec|0]=bc;ec=ec+1|0;}while((ec|0)<(c[lb>>2]|0));lb=r+vc|0;ec=a[lb]|0;a[lb]=(ec&255)>>>0>2>>>0?ec:2}vc=vc+1|0;if((vc|0)>(ab|0)){break o}}}}while(0);yDb(c[Y>>2]|0,16,2054432,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}}while(0);wc=c[qa>>2]|0}}while(0);do{if((y|0)==302){y=0;if((mc|0)<0|fb^1){wc=mc;break}else{xc=0}while(1){c[w+53952+(xc<<2)>>2]=2;Eb=xc+1|0;eb=c[qa>>2]|0;if((Eb|0)>(eb|0)){wc=eb;break}else{xc=Eb}}}}while(0);q:do{if((kb|0)>(wc|0)){yc=wc}else{Eb=kb;while(1){eb=a[r+Eb|0]|0;if((eb&255)>>>0>2>>>0){Qpb(w+45120+(Eb<<8)|0,c[w+45016+(Eb<<2)>>2]|0,c[w+45044+(Eb<<2)>>2]|0,w+48968+(Eb<<9)|0,w+52552+(Eb*100|0)|0)}if((eb&255)>>>0>1>>>0){if((Rpb(Ja,w+52552+(Eb*100|0)|0,c[w+45016+(Eb<<2)>>2]|0,c[w+45044+(Eb<<2)>>2]|0,c[w+47148+(Eb<<2)>>2]|0,(Eb|0)==(c[Ka>>2]|0)|0,c[w+53952+(Eb<<2)>>2]|0,c[w+53980+(Eb<<2)>>2]|0,w+54008+(Eb<<3)|0,w+54064+(Eb<<3)|0,w+54120+(Eb<<3)|0,w+53252+(Eb*100|0)|0)|0)!=0){break}}if(!(eb<<24>>24==0)){Be[c[La>>2]&127](w+53252+(Eb*100|0)|0,w+48968+(Eb<<9)|0,c[w+45016+(Eb<<2)>>2]|0,c[w+45044+(Eb<<2)>>2]|0,c[w+47120+(Eb<<2)>>2]|0,c[Ma>>2]|0,(c[w+1888+(Eb<<2)>>2]|0)!=0?1224320:1276664,w+47176+(Eb<<8)|0)}eb=Eb+1|0;cc=c[qa>>2]|0;if((eb|0)>(cc|0)){yc=cc;break q}else{Eb=eb}}yDb(c[Y>>2]|0,16,2043624,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}}while(0);do{if((c[K>>2]|0)!=0){kb=c[u>>2]|0;Eb=c[z>>2]|0;eb=d[Eb+(kb>>>3)|0]|0;cc=c[A>>2]|0;Zb=((kb|0)<(cc|0))+kb|0;c[u>>2]=Zb;if((eb&128>>>((kb&7)>>>0)|0)==0){break}kb=Eb+(Zb>>>3)|0;Eb=(fe(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Zb&7)>>>23;kb=Zb+9|0;Zb=cc>>>0>kb>>>0?kb:cc;c[u>>2]=Zb;if((Eb|0)==0){break}else{zc=Eb;Ac=Zb}do{zc=zc-1|0;Zb=Ac+8|0;Ac=cc>>>0>Zb>>>0?Zb:cc;}while((zc|0)!=0);c[u>>2]=Ac}}while(0);c[N>>2]=0;c[L>>2]=0;c[J>>2]=0;if((yc|0)>=1){cc=1;Zb=0;Eb=0;while(1){kb=Eb+1|0;Mfb(w,$a,cc,q);do{if((c[w+212+(cc<<2)>>2]|0)==0){Bc=Zb;Cc=w+45044+(cc<<2)|0}else{if((Zb|0)!=0){Bc=Zb;Cc=W;break}Mfb(w,$a,0,q);eb=c[Ia>>2]|0;if((eb|0)<=0){Bc=1;Cc=W;break}jb=0;hb=c[Q>>2]|0;ec=c[$>>2]|0;lb=eb;while(1){eb=a[w+320+jb|0]|0;bc=(eb&255)+hb|0;do{if((ec|0)<1){Dc=ec;Ec=lb}else{gb=w+244+(jb<<2)|0;if(eb<<24>>24==0){Dc=ec;Ec=lb;break}else{Fc=1}do{do{if((c[w+212+(Fc<<2)>>2]|0)!=0){Fb=c[w+372+(Fc*72|0)+(jb<<2)>>2]<<5;fc=Fb;ac=(Fb|0)<0|0?-1:0;Fb=hb;do{dc=c[w+56064+(Fb<<2)>>2]<<4;gHb(dc,(dc|0)<0|0?-1:0,fc,ac)|0;c[w+56064+(Fc<<10)+(Fb<<2)>>2]=F;Fb=Fb+1|0;}while((Fb|0)<(bc|0));if((Fc|0)!=2){break}if((c[gb>>2]|0)==0){break}else{Gc=hb}do{Fb=w+58112+(Gc<<2)|0;c[Fb>>2]=-(c[Fb>>2]|0);Gc=Gc+1|0;}while((Gc|0)<(bc|0))}}while(0);Fc=Fc+1|0;Hc=c[$>>2]|0;}while((Fc|0)<=(Hc|0));Dc=Hc;Ec=c[Ia>>2]|0}}while(0);eb=jb+1|0;if((eb|0)<(Ec|0)){jb=eb;hb=bc;ec=Dc;lb=Ec}else{Bc=1;Cc=W;break}}}}while(0);lb=c[Cc>>2]|0;ec=lb+1|0;TGb(w+56064+(kb<<10)+(lb<<2)|0,0,((ec|0)>256?ec:256)-lb<<2|0)|0;lb=cc+1|0;if((lb|0)>(c[qa>>2]|0)){break}else{cc=lb;Zb=Bc;Eb=kb}}}Eb=c[$>>2]|0;if((Eb|0)>=1){Zb=1;cc=Eb;while(1){do{if((c[w+54176+(Zb<<2)>>2]|0)==0){if((c[w+212+(Zb<<2)>>2]|0)==0){Ic=cc;break}Eb=c[Q>>2]|0;lb=c[W>>2]|0;if((Eb|0)<(lb|0)){Jc=Eb;Kc=lb}else{Ic=cc;break}while(1){if((a[w+47176+Jc|0]|0)==0){c[w+56064+(Zb<<10)+(Jc<<2)>>2]=0;Lc=c[W>>2]|0}else{Lc=Kc}lb=Jc+1|0;if((lb|0)<(Lc|0)){Jc=lb;Kc=Lc}else{break}}Ic=c[$>>2]|0}else{Ic=cc}}while(0);kb=Zb+1|0;if((kb|0)>(Ic|0)){break}else{Zb=kb;cc=Ic}}}do{if((c[ga>>2]|0)==2){cc=c[G>>2]|0;Zb=c[X>>2]|0;kb=(cc|0)>(Zb|0)?Zb:cc;cc=c[_>>2]|0;if((cc|0)>0){Mc=0;Nc=cc}else{break}while(1){cc=Mc+1|0;do{if((c[w+45076+(Mc<<2)>>2]|0)==0){Oc=Nc}else{Zb=d[1274888+cc|0]|0;lb=(kb|0)>(Zb|0)?Zb:kb;Zb=d[1274888+Mc|0]|0;if((Zb|0)<(lb|0)){Pc=Zb}else{Oc=Nc;break}do{Zb=w+57088+(Pc<<2)|0;Eb=c[Zb>>2]|0;ec=w+58112+(Pc<<2)|0;hb=c[ec>>2]|0;c[Zb>>2]=hb+Eb;c[ec>>2]=Eb-hb;Pc=Pc+1|0;}while((Pc|0)<(lb|0));Oc=c[_>>2]|0}}while(0);if((cc|0)<(Oc|0)){Mc=cc;Nc=Oc}else{break}}}}while(0);kb=c[qa>>2]|0;if((kb|0)<1){Qc=kb}else{kb=1;while(1){if((c[ga>>2]|0)==0){Rc=w+45004+(2-kb<<2)|0}else{Rc=Ha}te[c[Ga>>2]&7](w+63232+(kb<<10)|0,w+56064+(kb<<10)|0,+g[Rc>>2]*2.384185791015625e-7,256);lb=kb+1|0;bc=c[qa>>2]|0;if((lb|0)>(bc|0)){Qc=bc;break}else{kb=lb}}}if((c[ca>>2]|0)==0){Sc=Qc}else{Gkb(w);Sc=c[qa>>2]|0}kb=c[ea>>2]|0;do{if((Sc|0)==(kb|0)){Tc=0}else{if((c[ia>>2]&8|0)==0){Tc=1;break}Tc=(c[$>>2]|0)!=(kb|0)}}while(0);do{if((db|0)==0){do{if(Tc){le[c[D>>2]&1023](xa,ya,kb,c[$>>2]|0,256);if((c[za>>2]|0)!=0){break}c[za>>2]=1;le[c[D>>2]&1023](Aa,ya,c[ea>>2]|0,c[$>>2]|0,128)}}while(0);Lfb(w,c[ea>>2]|0)}else{r:do{if((c[za>>2]|0)!=0){c[za>>2]=0;switch(c[ga>>2]|0){case 0:case 2:{UGb(ka|0,Ca|0,1024)|0;break r;break};case 6:{TGb(Da|0,0,1024)|0;y=367;break};case 4:{y=367;break};case 7:{TGb(Fa|0,0,1024)|0;y=369;break};case 5:{y=369;break};case 3:{break};default:{break r}}if((y|0)==367){y=0;TGb(Ea|0,0,1024)|0;break}else if((y|0)==369){y=0;TGb(Da|0,0,1024)|0}UGb(Ea|0,ka|0,1024)|0;TGb(ka|0,0,1024)|0}}while(0);Lfb(w,Sc);if(!Tc){break}le[c[D>>2]&1023](Ba,ya,c[ea>>2]|0,c[$>>2]|0,256)}}while(0);Uc=0;Vc=c[ea>>2]|0;y=382;break c}}while(0);yDb(Wa,16,2137832,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;Wc=1;y=379}else{Wc=j;y=379}}while(0);do{if((y|0)==379){y=0;if((c[ea>>2]|0)<=0){Xc=Wc;break}fb=$a<<8;ab=0;while(1){UGb((c[_a+(ab<<2)>>2]|0)+(fb<<2)|0,c[s+(ab<<2)>>2]|0,1024)|0;cb=ab+1|0;bb=c[ea>>2]|0;if((cb|0)<(bb|0)){ab=cb}else{Uc=Wc;Vc=bb;y=382;break}}}}while(0);do{if((y|0)==382){y=0;ab=(Vc|0)>0;if(ab){Yc=0}else{Xc=Uc;break}do{c[s+(Yc<<2)>>2]=c[la+(d[1276360+(ja*12|0)+(ta*6|0)+Yc|0]<<2)>>2];Yc=Yc+1|0;}while((Yc|0)<(Vc|0));if(ab){Zc=0;_c=Vc}else{Xc=Uc;break}while(1){if((Zc|0)==0){$c=a[1276360+(ja*12|0)+(ta*6|0)|0]|0;y=388}else{fb=a[1276360+(ja*12|0)+(ta*6|0)+Zc|0]|0;if(fb<<24>>24==0){ad=_c}else{$c=fb;y=388}}if((y|0)==388){y=0;fb=la+(($c&255)<<2)|0;c[fb>>2]=(c[fb>>2]|0)+1024;ad=c[ea>>2]|0}fb=Zc+1|0;if((fb|0)<(ad|0)){Zc=fb;_c=ad}else{Xc=Uc;break}}}}while(0);ab=$a+1|0;if((ab|0)<(c[oa>>2]|0)){j=Xc;$a=ab}else{bd=Xc;break}}}else{bd=ha}zCb(t,(bd|0)!=0|0);if((c[ea>>2]|0)>0){bd=0;do{UGb(va+(bd<<10)|0,c[s+(bd<<2)>>2]|0,1024)|0;bd=bd+1|0;}while((bd|0)<(c[ea>>2]|0))}ea=c[l+60>>2]|0;do{if((ea|0)==2){if((c[ia>>2]&-9|0)!=2){cd=0;break}if((c[l+104>>2]|0)==2){cd=1;break}cd=(c[l+112>>2]|0)==2?6:0}else{if((ea|0)<=5){cd=0;break}if((ea|0)!=(c[ia>>2]&-9|0)){cd=0;break}bd=c[l+108>>2]|0;if((bd|0)==2){cd=5;break}else if((bd|0)==3){cd=4;break}else{cd=0;break}}}while(0);ia=W$a(t,cd)|0;if((ia|0)<0){da=ia;i=m;return da|0}ia=FBb(t)|0;if((ia|0)==0){da=-12;i=m;return da|0}t=c[l+72>>2]|0;if((t|0)==1){c[ia>>2]=2}else if((t|0)==2){c[ia>>2]=1}else if((t|0)==3){c[ia>>2]=3}else{c[ia>>2]=0}h[ia+8>>3]=+g[1038408+(c[l+76>>2]<<2)>>2];h[ia+16>>3]=+g[1038408+(c[l+80>>2]<<2)>>2];h[ia+24>>3]=+g[1038408+(c[l+84>>2]<<2)>>2];h[ia+32>>3]=+g[1038408+(c[l+88>>2]<<2)>>2];if((c[l+92>>2]|0)==0){h[ia+40>>3]=0.0}else{h[ia+40>>3]=+g[1038280+(c[l+96>>2]<<2)>>2]}c[k>>2]=1;k=c[l+36>>2]|0;da=(v|0)>(k|0)?k:v;i=m;return da|0}function Jfb(a){a=a|0;var b=0;b=c[a+60>>2]|0;bLa(b+54492|0);bLa(b+54556|0);return 0}function Kfb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;m=i;i=i+48|0;n=m|0;o=m+24|0;p=h-g|0;do{if((f|0)==0){q=3}else{h=b+8|0;r=c[h>>2]|0;s=d[(c[b>>2]|0)+(r>>>3)|0]|0;c[h>>2]=((r|0)<(c[b+16>>2]|0))+r;if((s&128>>>((r&7)>>>0)|0)!=0){q=3;break}if((e|0)==0){t=j+(g+1)|0;break}else{i=m;return}}}while(0);if((q|0)==3){q=p-1|0;if((q|0)>0){g=b+8|0;j=c[b>>2]|0;e=c[b+16>>2]|0;b=0;f=c[g>>2]|0;do{r=d[j+(f>>>3)|0]<<(f&7)>>>7;f=((f|0)<(e|0))+f|0;c[g>>2]=f;a[o+b|0]=r&1;b=b+1|0;}while((b|0)<(q|0))}t=o|0}o=(k|0)!=0;q=(l|0)==0;do{if(q&(o^1)){u=0}else{a[n|0]=12;if((p|0)>1){v=0;w=p;x=1}else{u=p;break}while(1){if((a[t+(x-1)|0]|0)==0){b=v+1|0;a[n+b|0]=12;y=w;z=b}else{b=n+v|0;a[b]=(a[b]|0)+12;y=w-1|0;z=v}b=x+1|0;if((b|0)<(p|0)){v=z;w=y;x=b}else{u=y;break}}}}while(0);if(o){c[k>>2]=u}if(q){i=m;return}UGb(l|0,n|0,u)|0;i=m;return}function Lfb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((b|0)<1){return}d=a+54492|0;e=a+54536|0;f=a+78592|0;h=a+55880|0;i=a+77568|0;j=a+79104|0;k=j;l=a+54556|0;m=a+54600|0;n=1;do{if((c[a+54464+(n<<2)>>2]|0)==0){Xe[c[e>>2]&4095](d,f,a+63232+(n<<10)|0);o=n-1|0;p=a+70400+(o<<10)|0;le[c[h>>2]&1023](c[a+55972+(o<<2)>>2]|0,p|0,f,i,128);UGb(p|0,k|0,512)|0}else{p=0;do{g[a+78592+(p+128<<2)>>2]=+g[a+63232+(n<<10)+(p<<1<<2)>>2];p=p+1|0;}while((p|0)<128);Xe[c[m>>2]&4095](l,f,j);p=n-1|0;o=a+70400+(p<<10)|0;le[c[h>>2]&1023](c[a+55972+(p<<2)>>2]|0,o,f,i,128);p=0;do{g[a+78592+(p+128<<2)>>2]=+g[a+63232+(n<<10)+((p<<1|1)<<2)>>2];p=p+1|0;}while((p|0)<128);Xe[c[m>>2]&4095](l,o,j)}n=n+1|0;}while((n|0)<=(b|0));return}function Mfb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;if((c[b+1888+(f<<2)>>2]|0)!=0){if((e|0)==0){Hkb(b,f)}j=c[b+45016+(f<<2)>>2]|0;k=b+45044+(f<<2)|0;if((j|0)<(c[k>>2]|0)){l=j}else{i=h;return}do{c[b+56064+(f<<10)+(l<<2)>>2]=c[b+1916+(f*6144|0)+(l*24|0)+(e<<2)>>2]>>a[b+45120+(f<<8)+l|0];l=l+1|0;}while((l|0)<(c[k>>2]|0));i=h;return}k=c[b+45016+(f<<2)>>2]|0;l=c[b+45044+(f<<2)>>2]|0;if((f|0)==0){m=1}else{m=(c[b+54176+(f<<2)>>2]|0)!=0}if((k|0)>=(l|0)){i=h;return}e=b+4|0;j=b+16|0;n=b+24|0;o=b+8|0;p=b+54460|0;q=g+20|0;r=g+4|0;s=g|0;t=g+24|0;u=g+12|0;v=g+8|0;w=g+28|0;x=g+16|0;y=k;do{k=a[b+47176+(f<<8)+y|0]|0;z=k&255;a:do{switch(z|0){case 1:{A=c[q>>2]|0;if((A|0)==0){B=c[j>>2]|0;C=c[n>>2]|0;D=(c[o>>2]|0)+(B>>>3)|0;E=(fe(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7)>>>27;D=B+5|0;c[j>>2]=C>>>0>D>>>0?D:C;C=c[8881712+(E*12|0)>>2]|0;c[r>>2]=c[8881716+(E*12|0)>>2];c[s>>2]=c[8881720+(E*12|0)>>2];c[q>>2]=2;F=C;break a}else{C=A-1|0;c[q>>2]=C;F=c[g+(C<<2)>>2]|0;break a}break};case 4:{if((c[w>>2]|0)==0){C=c[j>>2]|0;A=c[n>>2]|0;E=(c[o>>2]|0)+(C>>>3)|0;D=(fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(C&7)>>>25;E=C+7|0;c[j>>2]=A>>>0>E>>>0?E:A;A=c[8879120+(D<<3)>>2]|0;c[x>>2]=c[8879124+(D<<3)>>2];c[w>>2]=1;F=A;break a}else{c[w>>2]=0;F=c[x>>2]|0;break a}break};case 2:{A=c[t>>2]|0;if((A|0)==0){D=c[j>>2]|0;E=c[n>>2]|0;C=(c[o>>2]|0)+(D>>>3)|0;B=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(D&7)>>>25;C=D+7|0;c[j>>2]=E>>>0>C>>>0?C:E;E=c[8880176+(B*12|0)>>2]|0;c[u>>2]=c[8880180+(B*12|0)>>2];c[v>>2]=c[8880184+(B*12|0)>>2];c[t>>2]=2;F=E;break a}else{E=A-1|0;c[t>>2]=E;F=c[g+8+(E<<2)>>2]|0;break a}break};case 5:{E=c[j>>2]|0;A=c[n>>2]|0;B=(c[o>>2]|0)+(E>>>3)|0;C=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(E&7)>>>28;B=E+4|0;c[j>>2]=A>>>0>B>>>0?B:A;F=c[8879056+(C<<2)>>2]|0;break};case 3:{C=c[j>>2]|0;A=c[n>>2]|0;B=(c[o>>2]|0)+(C>>>3)|0;E=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>29;B=C+3|0;c[j>>2]=A>>>0>B>>>0?B:A;F=c[8880144+(E<<2)>>2]|0;break};case 0:{if(!m){F=0;break a}E=c[p>>2]|0;c[b+54204+((E&63)<<2)>>2]=(c[b+54204+((E+9&63)<<2)>>2]|0)+(c[b+54204+((E+40&63)<<2)>>2]|0);E=c[p>>2]|0;c[p>>2]=E+1;F=((((c[b+54204+((E&63)<<2)>>2]|0)>>>8)*181|0)>>>8)-5931008|0;break};default:{if((k&255)>>>0>15>>>0){yDb(c[e>>2]|0,16,2038912,(E=i,i=i+8|0,c[E>>2]=z,E)|0);i=E;G=15}else{G=z}E=d[552160+G|0]|0;A=c[j>>2]|0;B=c[n>>2]|0;C=(c[o>>2]|0)+(A>>>3)|0;D=(fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(A&7)>>32-E;C=A+E|0;c[j>>2]=B>>>0>C>>>0?C:B;F=D<<24-E}}}while(0);c[b+56064+(f<<10)+(y<<2)>>2]=F>>a[b+45120+(f<<8)+y|0];y=y+1|0;}while((y|0)<(l|0));i=h;return}function Nfb(a,b){a=a|0;b=b|0;c[a>>2]=2182;c[a+4>>2]=368;c[a+8>>2]=2020;c[a+12>>2]=2176;c[a+16>>2]=1462;c[a+20>>2]=58;c[a+24>>2]=2022;c[a+28>>2]=542;c[a+32>>2]=644;c[a+36>>2]=194;c[a+40>>2]=90;c[a+44>>2]=348;c[a+48>>2]=494;return}function Ofb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(!((c|0)!=0&(d|0)>0)){return}if((c|0)>0){e=0;f=b}else{b=0;do{b=b+1|0;}while((b|0)<(d|0));return}while(1){b=0;g=a[f]|0;h=f;do{h=h+256|0;i=a[h]|0;g=(i&255)>>>0<(g&255)>>>0?i:g;b=b+1|0;}while((b|0)<(c|0));a[f]=g;b=e+1|0;if((b|0)<(d|0)){e=b;f=f+1|0}else{break}}return}function Pfb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;if((c|0)>0){d=0;e=0}else{f=0;return f|0}while(1){g=b[a+(d<<1)>>1]|0;h=g<<16>>16;i=(g<<16>>16>-1?h:-h|0)|e;h=d+1|0;if((h|0)<(c|0)){d=h;e=i}else{f=i;break}}return f|0}function Qfb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=a;a=65535-(65536<<d)|0;f=b>>>1;if((f|0)==0){return}else{g=0}do{b=e+(g<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|1)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|2)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|3)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|4)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|5)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|6)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|7)<<2)|0;c[b>>2]=c[b>>2]<<d&a;g=g+8|0;}while(g>>>0<f>>>0);return}function Rfb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=a;a=b;while(1){b=e+4|0;c[e>>2]=c[e>>2]>>d;f=e+8|0;c[b>>2]=c[b>>2]>>d;b=e+12|0;c[f>>2]=c[f>>2]>>d;f=e+16|0;c[b>>2]=c[b>>2]>>d;b=e+20|0;c[f>>2]=c[f>>2]>>d;f=e+24|0;c[b>>2]=c[b>>2]>>d;b=e+28|0;c[f>>2]=c[f>>2]>>d;c[b>>2]=c[b>>2]>>d;b=a-8|0;if((b|0)==0){break}else{e=e+32|0;a=b}}return}function Sfb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a;a=d;d=b;while(1){c[e>>2]=Gc(+(+g[d>>2]*16777216.0))|0;c[e+4>>2]=Gc(+(+g[d+4>>2]*16777216.0))|0;c[e+8>>2]=Gc(+(+g[d+8>>2]*16777216.0))|0;c[e+12>>2]=Gc(+(+g[d+12>>2]*16777216.0))|0;c[e+16>>2]=Gc(+(+g[d+16>>2]*16777216.0))|0;c[e+20>>2]=Gc(+(+g[d+20>>2]*16777216.0))|0;c[e+24>>2]=Gc(+(+g[d+24>>2]*16777216.0))|0;c[e+28>>2]=Gc(+(+g[d+28>>2]*16777216.0))|0;b=a-8|0;if((b|0)==0){break}else{e=e+32|0;a=b;d=d+32|0}}return}function Tfb(c,e,f,g,h,i,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((h|0)==-960){TGb(k|0,0,256)|0;return}l=~g;m=f;n=d[7959496+f|0]|0;while(1){f=(b[c+(n<<1)>>1]|0)-h-i|0;o=n+1|0;p=d[1276728+o|0]|0;q=(p|0)>(g|0)?g:p;if((m|0)<(q|0)){r=((f|0)>0?-(f&8160)|0:0)-i|0;f=~p;p=(l|0)>(f|0)?l:f;f=m;do{s=r+(b[e+(f<<1)>>1]|0)>>5;if((s|0)<0){t=0}else{t=(s|0)>63?63:s}a[k+f|0]=a[j+t|0]|0;f=f+1|0;}while((f|0)<(q|0));u=~p}else{u=m}if((q|0)<(g|0)){m=u;n=o}else{break}}return}function Ufb(a,c,e){a=a|0;c=c|0;e=e|0;var f=0;if((e|0)>0){f=e}else{return}do{f=f-1|0;e=a+((d[c+f|0]|0)<<1)|0;b[e>>1]=(b[e>>1]|0)+1;}while((f|0)>0);return}function Vfb(a){a=a|0;var b=0,c=0;b=0;c=0;do{c=((e[a+(b<<5)+30>>1]|0)<<4)+(((e[a+(b<<5)+28>>1]|0)*14|0)+(((e[a+(b<<5)+26>>1]|0)*12|0)+(((e[a+(b<<5)+24>>1]|0)*11|0)+(((e[a+(b<<5)+22>>1]|0)*10|0)+(((e[a+(b<<5)+20>>1]|0)*9|0)+(((e[a+(b<<5)+18>>1]|0)<<3)+(((e[a+(b<<5)+16>>1]|0)*7|0)+(((e[a+(b<<5)+14>>1]|0)*6|0)+(((e[a+(b<<5)+12>>1]|0)*5|0)+(((e[a+(b<<5)+10>>1]|0)<<2)+(((((e[a+(b<<5)+2>>1]|0)/3|0)&65535)*5|0)+c+((e[a+(b<<5)+6>>1]|0)*3|0)+((((e[a+(b<<5)+8>>1]|0)>>>1)+(((e[a+(b<<5)+4>>1]|0)/3|0)&65535)|0)*7|0))))))))))))|0;b=b+1|0;}while((b|0)<6);return c|0}function Wfb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=0}else{return}do{h=c[e+(g<<2)>>2]|0;i=(h|0)>-1?h:-h|0;if((i|0)==0){j=24}else{h=i>>>0>65535>>>0;k=h?i>>>16:i;i=h?16:0;if((k&65280|0)==0){l=i;m=k}else{l=i|8;m=k>>>8}j=23-l-(d[1191992+m|0]|0)&255}a[b+g|0]=j;g=g+1|0;}while((g|0)<(f|0));return}function Xfb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=a+24|0;g=a+16|0;h=a+8|0;TGb(a|0,0,32)|0;if((e|0)>0){i=0;j=0;k=0;l=0;m=0;n=0;o=0;p=0;q=0}else{return}do{r=c[b+(i<<2)>>2]|0;s=c[d+(i<<2)>>2]|0;t=s+r|0;u=r-s|0;v=r;w=(r|0)<0|0?-1:0;r=gHb(v,w,v,w)|0;k=YGb(k,j,r,F)|0;j=F;r=s;w=(s|0)<0|0?-1:0;s=gHb(r,w,r,w)|0;m=YGb(m,l,s,F)|0;l=F;s=t;w=(t|0)<0|0?-1:0;t=gHb(s,w,s,w)|0;o=YGb(o,n,t,F)|0;n=F;t=u;w=(u|0)<0|0?-1:0;u=gHb(t,w,t,w)|0;q=YGb(q,p,u,F)|0;p=F;i=i+1|0;}while((i|0)<(e|0));c[a>>2]=k;c[a+4>>2]=j;c[h>>2]=m;c[h+4>>2]=l;c[g>>2]=o;c[g+4>>2]=n;c[f>>2]=q;c[f+4>>2]=p;return}function Yfb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0;e=a+12|0;f=a+8|0;h=a+4|0;TGb(a|0,0,16)|0;if((d|0)>0){i=0;j=0.0;k=0.0;l=0.0;m=0.0}else{return}do{n=+g[b+(i<<2)>>2];o=+g[c+(i<<2)>>2];p=n+o;q=n-o;j=n*n+j;g[a>>2]=j;k=o*o+k;g[h>>2]=k;l=p*p+l;g[f>>2]=l;m=q*q+m;g[e>>2]=m;i=i+1|0;}while((i|0)<(d|0));return}function Zfb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0;if((d|0)==2){if((f|0)<=0){return}h=c[a>>2]|0;i=c[a+4>>2]|0;if((e|0)>0){j=0}else{k=0;do{g[h+(k<<2)>>2]=0.0;g[i+(k<<2)>>2]=0.0;k=k+1|0;}while((k|0)<(f|0));return}do{k=0;l=0.0;m=0.0;do{n=+g[(c[a+(k<<2)>>2]|0)+(j<<2)>>2];l=l+n*+g[b+(k<<3)>>2];m=m+n*+g[b+(k<<3)+4>>2];k=k+1|0;}while((k|0)<(e|0));g[h+(j<<2)>>2]=l;g[i+(j<<2)>>2]=m;j=j+1|0;}while((j|0)<(f|0));return}else if((d|0)==1){if((f|0)<=0){return}d=c[a>>2]|0;if((e|0)>0){o=0}else{TGb(d|0,0,f<<2|0)|0;return}do{j=0;n=0.0;do{n=n+ +g[(c[a+(j<<2)>>2]|0)+(o<<2)>>2]*+g[b+(j<<3)>>2];j=j+1|0;}while((j|0)<(e|0));g[d+(o<<2)>>2]=n;o=o+1|0;}while((o|0)<(f|0));return}else{return}}function _fb(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=e>>>1;if((f|0)==0){return}else{g=0}do{h=b[d+(g<<1)>>1]|0;b[a+(g<<1)>>1]=((ba(b[c+(g<<1)>>1]|0,h)|0)+16384|0)>>>15;i=e-g-1|0;b[a+(i<<1)>>1]=((ba(b[c+(i<<1)>>1]|0,h)|0)+16384|0)>>>15;g=g+1|0;}while((g|0)<(f|0));return}function $fb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=a+2360|0;d=a+2352|0;e=c[d>>2]|0;f=c[d+4>>2]|0;g=c[a+2320>>2]|0;h=g;i=(g|0)<0|0?-1:0;g=c[a+2324>>2]|0;a:do{if((f|0)<(i|0)|(f|0)==(i|0)&e>>>0<h>>>0){j=f;k=e;l=c[b+4>>2]|0;m=c[b>>2]|0}else{n=g;o=(g|0)<0|0?-1:0;p=f;q=e;r=c[b+4>>2]|0;s=c[b>>2]|0;while(1){if((r|0)<(o|0)|(r|0)==(o|0)&s>>>0<n>>>0){j=p;k=q;l=r;m=s;break a}t=ZGb(q,p,h,i)|0;u=F;c[d>>2]=t;c[d+4>>2]=u;v=ZGb(s,r,n,o)|0;w=F;c[b>>2]=v;c[b+4>>2]=w;if((u|0)<(i|0)|(u|0)==(i|0)&t>>>0<h>>>0){j=u;k=t;l=w;m=v;break}else{p=u;q=t;r=w;s=v}}}}while(0);e=c[a+2336>>2]|0;f=gHb(g,(g|0)<0|0?-1:0,k,j)|0;g=F;s=gHb(h,i,m,l)|0;i=F;h=((((g|0)<(i|0)|(g|0)==(i|0)&f>>>0<s>>>0)&1)<<1)+e|0;c[a+2340>>2]=h;e=h<<3;h=YGb(e,(e|0)<0|0?-1:0,k,j)|0;c[d>>2]=h;c[d+4>>2]=F;d=c[a+2332>>2]<<8;a=YGb(d,(d|0)<0|0?-1:0,m,l)|0;c[b>>2]=a;c[b+4>>2]=F;return}function agb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=b+2332|0;f=c[e>>2]|0;do{if((f|0)>0){g=b+2368|0;h=b+2464|0;i=0;j=c[g>>2]|0;k=f;while(1){if((j|0)<1){l=j;m=k}else{n=1;do{a[b+1536+(i<<7)+64+n|0]=c[h>>2];n=n+1|0;o=c[g>>2]|0;}while((n|0)<=(o|0));l=o;m=c[e>>2]|0}n=i+1|0;if((n|0)<(m|0)){i=n;j=l;k=m}else{break}}if((m|0)<=0){p=m;q=26;break}k=b+2368|0;j=0;i=0;g=0;h=c[k>>2]|0;while(1){n=b+1536+(g<<7)+72|0;c[n>>2]=0;if((h|0)<1){r=b+1536+(g<<7)+60|0;c[r>>2]=0;s=r;t=j;q=13}else{r=1;u=0;do{u=u+(d[b+1536+(g<<7)+64+r|0]|0)|0;c[n>>2]=u;r=r+1|0;}while((r|0)<=(h|0));r=(u|0)>1;v=r&1;w=b+1536+(g<<7)+60|0;c[w>>2]=v;x=v+j|0;if(r){y=h;z=w;A=x}else{s=w;t=x;q=13}}do{if((q|0)==13){q=0;c[n>>2]=0;if((h|0)<1){y=h;z=s;A=t;break}else{B=1}while(1){a[b+1536+(g<<7)+64+B|0]=0;x=B+1|0;w=c[k>>2]|0;if((x|0)>(w|0)){y=w;z=s;A=t;break}else{B=x}}}}while(0);n=(g|0)!=0;u=n&1^1;x=b+1536+(g<<7)+56|0;c[x>>2]=u;do{if(n){w=g-1|0;r=1;while(1){if((r|0)>(y|0)){C=u;break}if((a[b+1536+(g<<7)+64+r|0]|0)==(a[b+1536+(w<<7)+64+r|0]|0)){r=r+1|0}else{q=19;break}}if((q|0)==19){q=0;c[x>>2]=1;C=1}c[b+1536+(g<<7)+96>>2]=C;if((c[z>>2]|0)!=0&(i|0)==0){q=22;break}c[b+1536+(g<<7)+92>>2]=0;D=i}else{c[b+1632>>2]=u;q=22}}while(0);if((q|0)==22){q=0;c[b+1536+(g<<7)+92>>2]=1;D=(c[z>>2]|0)==0?i:1}u=g+1|0;E=c[e>>2]|0;if((u|0)<(E|0)){j=A;i=D;g=u;h=y}else{break}}if((A|0)==0){p=E;q=26}else{F=E}}else{p=f;q=26}}while(0);if((q|0)==26){c[b+2464>>2]=0;F=p}if((F|0)<=0){return}p=b+2368|0;q=b+2428|0;f=b+2432|0;E=0;A=c[p>>2]|0;y=F;while(1){if((A|0)<1){G=A;H=y}else{F=1;do{if((a[b+1536+(E<<7)+64+F|0]|0)==0){c[b+1536+(E<<7)+100+(F<<2)>>2]=((c[q>>2]|0)*3|0)+73}else{c[b+1536+(E<<7)+100+(F<<2)>>2]=c[f>>2]}F=F+1|0;I=c[p>>2]|0;}while((F|0)<=(I|0));G=I;H=c[e>>2]|0}F=E+1|0;if((F|0)<(H|0)){E=F;A=G;y=H}else{break}}return}function bgb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((c[b+2500>>2]|0)==0){return}e=b+2332|0;f=c[e>>2]|0;if((f|0)>0){g=0;h=0;i=f}else{return}while(1){if((a[b+1536+(h<<7)+47|0]|0)==0){j=g}else{j=b+1536+(h<<7)+52|0}f=c[b+1536+(h<<7)+104>>2]|0;k=c[b+1536+(h<<7)+108>>2]|0;l=(f|0)>(k|0)?k:f;f=b+1536+(h<<7)+48|0;k=c[f>>2]|0;if((k|0)>0){m=b+1536+(h<<7)+4|0;n=0;o=k;while(1){do{if((a[j+n|0]|0)==0){p=o;q=n+1|0}else{k=d[1274888+n|0]|0;r=n+1|0;s=d[1274888+r|0]|0;t=(l|0)>(s|0)?s:l;if((k|0)>=(t|0)){p=o;q=r;break}s=c[m>>2]|0;u=c[s+4>>2]|0;v=c[s+8>>2]|0;s=k;do{k=u+(s<<2)|0;w=c[k>>2]|0;x=v+(s<<2)|0;y=c[x>>2]|0;c[k>>2]=y+w>>1;c[x>>2]=w-y>>1;s=s+1|0;}while((s|0)<(t|0));p=c[f>>2]|0;q=r}}while(0);if((q|0)<(p|0)){n=q;o=p}else{break}}z=c[e>>2]|0}else{z=i}o=h+1|0;if((o|0)<(z|0)){g=j;h=o;i=z}else{break}}return}function cgb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b+2332|0;e=c[d>>2]|0;if((e|0)<=0){return}f=b+2372|0;g=0;h=c[f>>2]|0;i=e;while(1){e=(c[b+1536+(g<<7)+60>>2]|0)==0|0;if((e|0)>(h|0)){j=h;k=i}else{l=b+1536+(g<<7)+8|0;m=b+1536+(g<<7)+12|0;n=e;e=h;while(1){o=a[b+2688+(n*6|0)+g|0]|0;p=o&255;if(o<<24>>24==0){q=e}else{r=(n|0)==0|0;s=(o<<24>>24==3)+p|0;o=c[b+2432+(n<<2)>>2]|0;t=a[(c[b+1536+(g<<7)+100+(n<<2)>>2]|0)-o+(8150456+(r*768|0)+(p-1<<8))|0]|0;p=t&255;u=c[(c[l>>2]|0)+(n<<2)>>2]|0;v=o-r|0;r=a[u+v|0]|0;a[c[(c[m>>2]|0)+(n<<2)>>2]|0]=r;if(!(t<<24>>24==0)){t=s<<1;o=t+s|0;w=u+(v+1)|0;v=1;u=r;while(1){r=a[w]|0;x=a[w+s|0]|0;y=a[w+t|0]|0;a[(c[(c[m>>2]|0)+(n<<2)>>2]|0)+v|0]=((62-x&255)+y&255)+(((x-r&255)+((r-u&255)*5&255)&255)*5&255);r=v+1|0;if((r|0)>(p|0)){break}else{w=w+o|0;v=r;u=y}}}q=c[f>>2]|0}u=n+1|0;if((u|0)>(q|0)){break}else{n=u;e=q}}j=q;k=c[d>>2]|0}e=g+1|0;if((e|0)<(k|0)){g=e;h=j;i=k}else{break}}return}function dgb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=b+2464|0;f=(c[e>>2]|0)==0|0;g=b+2332|0;h=b+2372|0;i=ba(c[g>>2]<<8,(f^1)+(c[h>>2]|0)|0)|0;j=b+1544|0;Xe[c[b+1448>>2]&4095](c[(c[j>>2]|0)+(f<<2)>>2]|0,c[(c[b+1540>>2]|0)+(f<<2)>>2]|0,i);i=(c[e>>2]|0)==0|0;f=b+2368|0;if((i|0)<=(c[f>>2]|0)){k=b+188|0;l=b+2328|0;m=i;do{i=c[(c[j>>2]|0)+(m<<2)>>2]|0;a[b+2688+(m*6|0)|0]=1;n=i+256|0;o=c[g>>2]|0;a:do{if((o|0)>1){p=b+2432+(m<<2)|0;if((m|0)==0){q=1;r=i;s=n;while(1){do{if((c[b+1536+(q-1<<7)+60>>2]|0)==0){a[b+2688+q|0]=1}else{if((c[b+1536+(q<<7)+60>>2]|0)==0){a[b+2688+q|0]=0;break}t=Pe[c[k>>2]&255](0,s,r,16,16)|0;u=b+2688+q|0;a[u]=0;if((t|0)<=((((c[b+1536+(q<<7)+100>>2]|0)-(c[p>>2]|0)|0)*500|0|0)/256|0|0)){break}a[u]=1}}while(0);u=q+1|0;t=c[g>>2]|0;if((u|0)<(t|0)){q=u;r=s;s=s+256|0}else{v=t;break a}}}if((m|0)>0){w=1;x=i;y=n}else{s=1;r=i;q=n;while(1){if((a[b+1536+(s<<7)+64+m|0]|0)==(a[b+1536+(s-1<<7)+64+m|0]|0)){Pe[c[k>>2]&255](0,q,r,16,16)|0;a[b+2688+(m*6|0)+s|0]=0}else{a[b+2688+(m*6|0)+s|0]=1}p=s+1|0;t=c[g>>2]|0;if((p|0)<(t|0)){s=p;r=q;q=q+256|0}else{v=t;break a}}}while(1){do{if((a[b+1536+(w<<7)+64+m|0]|0)==(a[b+1536+(w-1<<7)+64+m|0]|0)){q=Pe[c[k>>2]&255](0,y,x,16,16)|0;r=b+2688+(m*6|0)+w|0;a[r]=0;if((q|0)<=500){break}a[r]=1}else{a[b+2688+(m*6|0)+w|0]=1}}while(0);r=w+1|0;q=c[g>>2]|0;if((r|0)<(q|0)){w=r;x=y;y=y+256|0}else{v=q;break}}}else{v=o}}while(0);if((v|0)>0){o=0;n=v;while(1){i=o;do{i=i+1|0;if((i|0)>=(n|0)){break}}while((a[b+2688+(m*6|0)+i|0]|0)==0);a[b+2688+(m*6|0)+o|0]=a[i+~o+(1321024+((c[l>>2]|0)*6|0))|0]|0;q=c[g>>2]|0;if((i|0)<(q|0)){o=i;n=q}else{break}}}m=m+1|0;}while((m|0)<=(c[f>>2]|0))}do{if((c[b+2376>>2]|0)!=0){f=c[b+2380>>2]|0;a[b+2688+(f*6|0)|0]=1;if((c[g>>2]|0)>1){z=1}else{break}do{a[b+2688+(f*6|0)+z|0]=0;z=z+1|0;}while((z|0)<(c[g>>2]|0))}}while(0);if((c[b+2308>>2]|0)!=0){l8(b)}z=(c[e>>2]|0)==0|0;e=c[h>>2]|0;if((z|0)>(e|0)){A=b+2956|0;c[A>>2]=0;return}f=b+1416|0;m=z;z=c[g>>2]|0;l=e;while(1){e=b+2432+(m<<2)|0;v=(m|0)==0;y=v&1;if((z|0)>0){x=y^1;w=(c[(c[j>>2]|0)+(m<<2)>>2]|0)+(c[e>>2]|0)|0;k=0;n=z;while(1){do{if(v){if((c[b+1536+(k<<7)+60>>2]|0)!=0){B=41;break}C=k+1|0;D=w+256|0;E=n}else{B=41}}while(0);if((B|0)==41){B=0;i=(c[b+1536+(k<<7)+100+(m<<2)>>2]|0)-(c[e>>2]|0)|0;o=k&255;a[b+2744+(m*6|0)+k|0]=o;q=k+1|0;b:do{if((q|0)<(c[g>>2]|0)){r=q;while(1){if((a[b+2688+(m*6|0)+r|0]|0)!=0){F=r;break b}a[b+2744+(m*6|0)+r|0]=o;s=r+1|0;if((s|0)<(c[g>>2]|0)){r=s}else{F=s;break}}}else{F=q}}while(0);q=F-k|0;Xe[c[f>>2]&4095](w+(-(c[e>>2]|0)|0)|0,q-1|0,256);o=d[b+2688+(m*6|0)+k|0]|0;r=d[8150456+(y*768|0)+(o-1<<8)+i|0]|0;s=r*3|0;do{if((o|0)==2){if((s|0)==0){break}else{G=x;H=1}while(1){t=a[w+G|0]|0;p=a[w+(G+1)|0]|0;a[w+(H-y)|0]=(p&255)>>>0<(t&255)>>>0?p:t;t=H+1|0;if((t|0)>(s|0)){break}else{G=G+2|0;H=t}}}else if((o|0)==3){if((s|0)==0){break}else{I=x;J=1}while(1){t=a[w+I|0]|0;p=a[w+(I+1)|0]|0;u=(p&255)>>>0<(t&255)>>>0?p:t;t=a[w+(I+2)|0]|0;p=(t&255)>>>0<(u&255)>>>0?t:u;u=a[w+(I+3)|0]|0;a[w+(J-y)|0]=(u&255)>>>0<(p&255)>>>0?u:p;p=J+1|0;if((p|0)>(s|0)){break}else{I=I+4|0;J=p}}}}while(0);do{if(!v){if(!((d[w]|0)>>>0>15>>>0)){break}a[w]=15}}while(0);i=(s|0)==0;do{if(!i){p=1;u=a[w]|0;do{t=w+p|0;K=a[t]|0;L=(u&255)+2|0;u=(K&255)>>>0>L>>>0?L&255:K;a[t]=u;p=p+1|0;}while((p|0)<=(s|0));p=(s+1|0)>>>0>2>>>0?s:1;if((p|0)==0){break}u=p;t=a[w+p|0]|0;do{u=u-1|0;p=w+u|0;K=a[p]|0;L=(t&255)+2|0;t=(K&255)>>>0>L>>>0?L&255:K;a[p]=t;}while((u|0)>0)}}while(0);if(v){a[w-1|0]=a[w]&-2}do{if((o|0)==2){if(i){break}u=(r*6|0)-y|0;t=s;while(1){p=a[w+(t-y)|0]|0;a[w+u|0]=p;a[w+(u-1)|0]=p;p=t-1|0;if((p|0)>0){u=u-2|0;t=p}else{break}}}else if((o|0)==3){if(i){break}t=(r*12|0)-y|0;u=s;while(1){p=a[w+(u-y)|0]|0;a[w+(t-3)|0]=p;a[w+(t-2)|0]=p;a[w+(t-1)|0]=p;a[w+t|0]=p;p=u-1|0;if((p|0)>0){t=t-4|0;u=p}else{break}}}}while(0);C=F;D=w+(q<<8)|0;E=c[g>>2]|0}if((C|0)<(E|0)){w=D;k=C;n=E}else{break}}M=E;N=c[h>>2]|0}else{M=z;N=l}n=m+1|0;if((n|0)>(N|0)){break}else{m=n;z=M;l=N}}A=b+2956|0;c[A>>2]=0;return}function egb(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;f=c[b+2308>>2]|0;g=(f|0)==0;do{if(g){h=(c[b+24>>2]|0)==0?0:7;if((c[b+2312>>2]|0)!=6){i=h;break}j=(c[b+44>>2]|0)==0?h:h+14|0;if((c[b+68>>2]|0)==0){i=j;break}i=j+14|0}else{j=c[b+2392>>2]|0;if((c[b+84>>2]|0)==0){k=0}else{h=(j|0)>2?2:0;l=(c[b+2384>>2]|0)==0?h:h+6|0;k=(c[b+2376>>2]|0)+((j|0)<2?6:5)+((c[b+2388>>2]|0)==0?l:l+6|0)|0}if((c[b+88>>2]|0)==0){m=k}else{l=((j|0)==2?9:5)+k|0;m=((c[b+24>>2]|0)==0?2:10)+((j|0)>5?l+2|0:l)|0}do{if((j|0)>1){l=m+1|0;h=c[b+2332>>2]|0;if((h|0)>1){n=l;o=1}else{p=l;break}while(1){l=((c[b+1536+(o<<7)+56>>2]|0)==0?1:2)+n|0;q=o+1|0;if((q|0)<(h|0)){n=l;o=q}else{p=l;break}}}else{p=m}}while(0);j=c[b+2464>>2]|0;if((j|0)==0){i=p;break}if((c[b+2740>>2]|0)!=0){i=(j*5|0)+p|0;break}j=c[b+2332>>2]|0;if((j|0)>0){r=p;s=0}else{i=p;break}while(1){h=(c[b+1536+(s<<7)+60>>2]<<1)+r|0;l=s+1|0;if((l|0)<(j|0)){r=h;s=l}else{i=h;break}}}}while(0);s=b+2332|0;r=c[s>>2]|0;p=(r|0)>0;do{if(p){m=g&1;o=c[b+2392>>2]|0;n=(o|0)==2;k=c[b+2368>>2]|0;j=(k|0)<1;h=b+2372|0;l=b+2476|0;q=m^1;t=b+2472|0;u=g^1;v=i;w=0;x=f;y=f;z=f;A=o;o=f;while(1){B=v+m|0;do{if((c[b+1536+(w<<7)+56>>2]|0)==0){C=B;D=x;E=y;F=z;G=A;H=c[b+1536+(w<<7)+60>>2]|0;I=26}else{J=B+m|0;K=c[b+1536+(w<<7)+60>>2]|0;if((K|0)==0){L=J;M=x;N=y;O=0;P=o;Q=A;R=z;S=1;break}T=(A|0)==2&u;U=T?2:A;V=(T?0:k)+q+((U|0)==2)+J|0;if((o|0)==0){W=K;X=0;Y=U;Z=0;_=0;$=0;aa=V+7+(c[t>>2]|0)|0;I=27;break}else{C=V+9|0;D=o;E=o;F=o;G=U;H=K;I=26;break}}}while(0);if((I|0)==26){I=0;if((H|0)==0){L=C;M=D;N=E;O=0;P=o;Q=G;R=F;S=1}else{W=H;X=o;Y=G;Z=F;_=E;$=D;aa=C;I=27}}do{if((I|0)==27){I=0;if(j){L=aa;M=$;N=_;O=W;P=X;Q=Y;R=Z;S=0;break}B=(Z|0)!=0;K=aa;U=1;V=$;J=_;while(1){do{if((a[b+1536+(w<<7)+64+U|0]|0)==0){ba=K;ca=V;da=J}else{T=a[b+1536+(w<<7)+76+U|0]|0;if(B&T<<24>>24==2){ea=K}else{fa=K+1|0;if(T<<24>>24==0){ba=fa;ca=Z;da=Z;break}else{ea=fa}}ba=ea+2+(c[l>>2]<<3)|0;ca=Z;da=Z}}while(0);fa=U+1|0;if((fa|0)>(k|0)){L=ba;M=ca;N=da;O=W;P=X;Q=Y;R=Z;S=0;break}else{K=ba;U=fa;V=ca;J=da}}}}while(0);do{if(n){J=(((M|0)==0|(w|0)>0)&1)+L|0;if((a[b+1536+(w<<7)+47|0]|0)==0){ga=J;break}ga=(c[b+1536+(w<<7)+48>>2]|0)+J|0}else{ga=L}}while(0);if(j){ha=ga}else{J=ga;V=1;while(1){if((a[b+2688+(V*6|0)+w|0]|0)==0){ia=J}else{ia=((a[b+1536+(w<<7)+64+V|0]|0)==0?J+6|0:J)+2|0}U=V+1|0;if((U|0)>(k|0)){ha=ia;break}else{J=ia;V=U}}}do{if(g){V=S?ha:ha+2|0;if((M|0)!=0){ja=V;ka=M;break}if((c[b+1536+(w<<7)+92>>2]|0)==0){ja=V+1|0;ka=0;break}ja=V+7+(((c[h>>2]|0)+O|0)*7|0)|0;ka=0}else{ja=ha;ka=M}}while(0);do{if(S){la=ja;ma=ka}else{V=c[b+1536+(w<<7)+96>>2]|0;if((N|0)!=0&(V|0)==2){na=ja}else{J=ja+1|0;if((V|0)==0){la=J;ma=N;break}else{na=J}}la=na+6|0;ma=N}}while(0);J=w+1|0;if((J|0)<(r|0)){v=la;w=J;x=ma;y=N;z=R;A=Q;o=P}else{break}}o=(c[b+2620>>2]|0)+la|0;A=b+2624|0;c[A>>2]=o;if(!p){oa=o;I=57;break}z=c[b+2372>>2]|0;y=0;x=0;while(1){w=(c[b+1536+(x<<7)+60>>2]|0)==0|0;if((w|0)>(z|0)){pa=y}else{v=y;h=w;while(1){w=a[b+2688+(h*6|0)+x|0]|0;if(w<<24>>24==0){qa=v}else{qa=v+4+((d[(c[b+1536+(x<<7)+100+(h<<2)>>2]|0)-(c[b+2432+(h<<2)>>2]|0)+(8150456+(((h|0)==0|0)*768|0)+((w&255)-1<<8))|0]|0)*7|0)|0}w=h+1|0;if((w|0)>(z|0)){pa=qa;break}else{v=qa;h=w}}}h=x+1|0;if((h|0)<(r|0)){y=pa;x=h}else{break}}x=b+2628|0;c[x>>2]=pa;if(!p){ra=o;sa=pa;break}y=b+2372|0;z=b+2524|0;h=b+2380|0;v=0;w=c[y>>2]|0;k=r;while(1){j=(c[b+1536+(v<<7)+60>>2]|0)==0|0;if((j|0)>(w|0)){ta=w;ua=k}else{n=b+1536+(v<<7)+8|0;l=b+1536+(v<<7)+16|0;t=b+1536+(v<<7)+20|0;q=b+1536+(v<<7)+24|0;u=j;j=w;while(1){if((a[b+2688+(u*6|0)+v|0]|0)==0){va=j}else{m=b+2432+(u<<2)|0;J=b+1536+(v<<7)+100+(u<<2)|0;Qpb(c[(c[n>>2]|0)+(u<<2)>>2]|0,c[m>>2]|0,c[J>>2]|0,c[(c[l>>2]|0)+(u<<2)>>2]|0,c[(c[t>>2]|0)+(u<<2)>>2]|0);Rpb(z,c[(c[t>>2]|0)+(u<<2)>>2]|0,c[m>>2]|0,c[J>>2]|0,e[1275952+(c[b+2564+(u<<2)>>2]<<1)>>1]|0,(u|0)==(c[h>>2]|0)|0,2,0,0,0,0,c[(c[q>>2]|0)+(u<<2)>>2]|0)|0;va=c[y>>2]|0}J=u+1|0;if((J|0)>(va|0)){break}else{u=J;j=va}}ta=va;ua=c[s>>2]|0}j=v+1|0;if((j|0)<(ua|0)){v=j;w=ta;k=ua}else{break}}ra=c[A>>2]|0;sa=c[x>>2]|0}else{k=(c[b+2620>>2]|0)+i|0;c[b+2624>>2]=k;oa=k;I=57}}while(0);if((I|0)==57){c[b+2628>>2]=0;ra=oa;sa=0}oa=(c[b+2340>>2]<<3)-ra-sa|0;if((oa|0)<0){wa=-22;return wa|0}sa=b+2560|0;ra=c[sa>>2]<<4;do{if((ra|c[b+2596>>2]|0)==1023){if((lgb(b,1023)|0)>(oa|0)){xa=ra;break}else{wa=0}return wa|0}else{xa=ra}}while(0);while(1){if(!((xa|0)>-1)){wa=-22;I=98;break}if((lgb(b,xa)|0)>(oa|0)){xa=xa-64|0}else{break}}if((I|0)==98){return wa|0}ra=b+2644|0;i=c[ra>>2]|0;ua=b+2640|0;c[ra>>2]=c[ua>>2];c[ua>>2]=i;i=xa+64|0;a:do{if((i|0)<1024){ta=xa;va=i;while(1){if((lgb(b,va)|0)>(oa|0)){ya=ta;break a}r=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=r;r=va+64|0;if((r|0)<1024){ta=va;va=r}else{ya=va;break}}}else{ya=xa}}while(0);xa=ya+16|0;b:do{if((xa|0)<1024){i=ya;va=xa;while(1){if((lgb(b,va)|0)>(oa|0)){za=i;break b}ta=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=ta;ta=va+16|0;if((ta|0)<1024){i=va;va=ta}else{za=va;break}}}else{za=ya}}while(0);ya=za+4|0;c:do{if((ya|0)<1024){xa=za;va=ya;while(1){if((lgb(b,va)|0)>(oa|0)){Aa=xa;break c}i=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=i;i=va+4|0;if((i|0)<1024){xa=va;va=i}else{Aa=va;break}}}else{Aa=za}}while(0);za=Aa+1|0;d:do{if((za|0)<1024){ya=Aa;va=za;while(1){if((lgb(b,va)|0)>(oa|0)){Ba=ya;break d}xa=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=xa;xa=va+1|0;if((xa|0)<1024){ya=va;va=xa}else{Ba=va;break}}}else{Ba=Aa}}while(0);Aa=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=Aa;do{if((c[b+2788>>2]|0)==(Aa|0)){if((c[b+2956>>2]|0)==0){I=79;break}Ca=c[b+2372>>2]|0}else{I=79}}while(0);if((I|0)==79){I=b+2372|0;ua=c[I>>2]|0;if((ua|0)<0){Da=ua}else{ra=0;oa=Aa;Aa=c[s>>2]|0;za=ua;while(1){if((Aa|0)>0){ua=0;do{c[b+2788+(ra*24|0)+(ua<<2)>>2]=oa+(d[b+2744+(ra*6|0)+ua|0]<<8);ua=ua+1|0;Ea=c[s>>2]|0;}while((ua|0)<(Ea|0));Fa=Ea;Ga=c[I>>2]|0}else{Fa=Aa;Ga=za}ua=ra+1|0;if((ua|0)>(Ga|0)){Da=Ga;break}else{ra=ua;oa=oa+(Fa<<8)|0;Aa=Fa;za=Ga}}}c[b+2956>>2]=1;Ca=Da}c[sa>>2]=Ba>>4;sa=(c[b+2464>>2]|0)==0|0;Da=b+2372|0;if((sa|0)>(Ca|0)){wa=0;return wa|0}Ca=Ba&15;Ba=sa;while(1){c[b+2592+(Ba<<2)>>2]=Ca;sa=Ba+1|0;if((sa|0)>(c[Da>>2]|0)){wa=0;break}else{Ba=sa}}return wa|0}function fgb(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=c[f+2332>>2]|0;if((g|0)<=0){return}h=c[f+2372>>2]|0;i=0;j=0;while(1){if((h|0)<1){k=i}else{l=f+1536+(j<<7)+4|0;m=f+1536+(j<<7)+28|0;n=0;o=0;p=0;q=0;r=0;s=0;t=1;u=i;v=(c[f+1536+(j<<7)+60>>2]|0)==0|0;while(1){if((v|0)==0&(t|0)>1){w=t-1|0;x=(a[f+1536+(j<<7)+64+w|0]|0)==0;y=x&1^1;z=x?u:w;A=x?t:0}else{y=v;z=u;A=t}x=c[(c[l>>2]|0)+(A<<2)>>2]|0;w=c[(c[f+1536+(d[f+2744+(A*6|0)+j|0]<<7)+8>>2]|0)+(A<<2)>>2]|0;B=c[f+2788+(A*24|0)+(j<<2)>>2]|0;C=c[(c[m>>2]|0)+(A<<2)>>2]|0;D=c[f+2432+(A<<2)>>2]|0;E=c[f+1536+(j<<7)+100+(A<<2)>>2]|0;if((D|0)<(E|0)){F=D;D=s;G=r;H=q;I=p;J=o;K=n;while(1){L=c[x+(F<<2)>>2]|0;M=d[w+F|0]|0;N=a[B+F|0]|0;O=N&255;a:do{if(N<<24>>24==0){P=N&255;Q=D;R=G;S=H;T=I;U=J;V=K}else{switch(O|0){case 15:{W=(L<<M>>8)+1>>1;P=(W|0)>32767?32767:W&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a;break};case 1:{W=((L*3|0)>>24-M)+3>>1;if((I|0)==0){P=(W*9|0)&65535;Q=C+(F<<1)|0;R=G;S=H;T=1;U=J;V=K;break a}else if((I|0)==1){b[D>>1]=(e[D>>1]|0)+(W*3|0);P=128;Q=D;R=G;S=H;T=2;U=J;V=K;break a}else{b[D>>1]=(e[D>>1]|0)+W;P=128;Q=D;R=G;S=H;T=0;U=J;V=K;break a}break};case 3:{P=(((L*7|0)>>24-M)+7|0)>>>1&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a;break};case 4:{W=((L*11|0)>>24-M)+11>>1;if((K|0)==0){P=(W*11|0)&65535;Q=D;R=G;S=C+(F<<1)|0;T=I;U=J;V=1;break a}else{b[H>>1]=(e[H>>1]|0)+W;P=128;Q=D;R=G;S=H;T=I;U=J;V=0;break a}break};case 5:{P=(((L*15|0)>>24-M)+15|0)>>>1&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a;break};case 14:{W=(L<<M>>10)+1>>1;P=(W|0)>8191?8191:W&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a;break};case 2:{W=((L*5|0)>>24-M)+5>>1;if((J|0)==0){P=(W*25|0)&65535;Q=D;R=C+(F<<1)|0;S=H;T=I;U=1;V=K;break a}else if((J|0)==1){b[G>>1]=(e[G>>1]|0)+(W*5|0);P=128;Q=D;R=G;S=H;T=I;U=2;V=K;break a}else{b[G>>1]=(e[G>>1]|0)+W;P=128;Q=D;R=G;S=H;T=I;U=0;V=K;break a}break};default:{W=(L<<M>>25-O)+1>>1;X=1<<O-2;P=((W|0)<(X|0)?W:X+65535|0)&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a}}}}while(0);b[C+(F<<1)>>1]=P;O=F+1|0;if((O|0)<(E|0)){F=O;D=Q;G=R;H=S;I=T;J=U;K=V}else{Y=Q;Z=R;_=S;$=T;aa=U;ba=V;break}}}else{Y=s;Z=r;_=q;$=p;aa=o;ba=n}K=((A|0)==0?z:A)+1|0;if((K|0)>(h|0)){k=z;break}else{n=ba;o=aa;p=$;q=_;r=Z;s=Y;t=K;u=z;v=y}}}v=j+1|0;if((v|0)<(g|0)){i=k;j=v}else{break}}return}function ggb(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0;c[e+132>>2]=30720;g=e+120|0;c[g>>2]=f;c[e+128>>2]=f+3840;h=e+124|0;c[h>>2]=f;f=e+116|0;c[f>>2]=32;i=e+112|0;c[i>>2]=0;me[c[e+2972>>2]&511](e);j=e+2332|0;if((c[j>>2]|0)>0){k=e+2308|0;l=e+2368|0;m=e+2392|0;n=e+2376|0;o=e+2380|0;p=e+2372|0;q=e+2508|0;r=e+2512|0;s=e+2504|0;t=e+2516|0;u=e+2520|0;v=e+2560|0;w=e+2552|0;y=e+2556|0;z=e+2428|0;A=e+2476|0;B=e+2432|0;C=e+2460|0;D=0;do{do{if((c[k>>2]|0)==0){E=c[l>>2]|0;if((E|0)<=0){F=15;break}G=0;H=c[i>>2]|0;I=c[f>>2]|0;J=E;while(1){if((I|0)>1){K=I-1|0;L=H<<1;M=J}else{E=fe(H<<I|0)|0;N=c[h>>2]|0;x=E;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;K=I+31|0;L=0;M=c[l>>2]|0}c[i>>2]=L;c[f>>2]=K;N=G+1|0;if((N|0)<(M|0)){G=N;H=L;I=K;J=M}else{break}}if((c[k>>2]|0)==0&(M|0)>0){O=0;P=L;Q=K;R=M}else{F=15;break}while(1){if((Q|0)>1){S=Q-1|0;T=P<<1|1;U=R}else{J=fe(1>>>((1-Q|0)>>>0)|P<<Q|0)|0;I=c[h>>2]|0;x=J;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;S=Q+31|0;T=1;U=c[l>>2]|0}c[i>>2]=T;c[f>>2]=S;I=O+1|0;if((I|0)<(U|0)){O=I;P=T;Q=S;R=U}else{V=S;break}}}else{F=15}}while(0);if((F|0)==15){F=0;V=c[f>>2]|0}I=c[i>>2]|0;if((V|0)>1){W=V-1|0;X=I<<1}else{J=fe(I<<V|0)|0;I=c[h>>2]|0;x=J;a[I]=x;x=x>>8;a[I+1|0]=x;x=x>>8;a[I+2|0]=x;x=x>>8;a[I+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;W=V+31|0;X=0}c[i>>2]=X;c[f>>2]=W;I=c[k>>2]|0;do{if((I|0)==0){Y=W;Z=X;F=25}else{if((W|0)>1){_=W-1|0;$=X<<1;aa=I}else{J=fe(X<<W|0)|0;H=c[h>>2]|0;x=J;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;_=W+31|0;$=0;aa=c[k>>2]|0}c[i>>2]=$;c[f>>2]=_;if((aa|0)==0){Y=_;Z=$;F=25;break}ba=$;ca=_;da=e+1536+(D<<7)+56|0}}while(0);if((F|0)==25){F=0;I=e+1536+(D<<7)+56|0;H=c[I>>2]|0;if((Y|0)>1){ea=Y-1|0;fa=H|Z<<1}else{J=fe(H>>>((1-Y|0)>>>0)|Z<<Y|0)|0;G=c[h>>2]|0;x=J;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;ea=Y+31|0;fa=H}c[i>>2]=fa;c[f>>2]=ea;ba=fa;ca=ea;da=I}do{if((c[da>>2]|0)==0){ga=ba;ha=ca;ia=e+1536+(D<<7)+60|0}else{I=e+1536+(D<<7)+60|0;if((c[k>>2]|0)==0){H=c[I>>2]|0;if((ca|0)>1){ja=ca-1|0;ka=H|ba<<1}else{G=fe(H>>>((1-ca|0)>>>0)|ba<<ca|0)|0;J=c[h>>2]|0;x=G;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;ja=ca+31|0;ka=H}c[i>>2]=ka;c[f>>2]=ja;la=ka;ma=ja}else{la=ba;ma=ca}if((c[I>>2]|0)==0){ga=la;ha=ma;ia=I;break}H=c[k>>2]|0;do{if((H|0)==0){na=la;oa=ma;F=43}else{if((ma|0)>1){pa=ma-1|0;qa=la<<1;ra=H}else{J=fe(la<<ma|0)|0;G=c[h>>2]|0;x=J;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;pa=ma+31|0;qa=0;ra=c[k>>2]|0}c[i>>2]=qa;c[f>>2]=pa;if((ra|0)==0){na=qa;oa=pa;F=43;break}if((c[m>>2]|0)==2){sa=pa;ta=qa;F=49}else{na=qa;oa=pa;F=43}}}while(0);if((F|0)==43){F=0;H=c[l>>2]|0;if((H|0)<1){ua=na;va=oa}else{G=1;J=na;N=oa;E=H;while(1){H=d[e+1536+(D<<7)+64+G|0]|0;if((N|0)>1){wa=N-1|0;xa=H|J<<1;ya=E}else{za=fe(H>>>((1-N|0)>>>0)|J<<N|0)|0;Aa=c[h>>2]|0;x=za;a[Aa]=x;x=x>>8;a[Aa+1|0]=x;x=x>>8;a[Aa+2|0]=x;x=x>>8;a[Aa+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;wa=N+31|0;xa=H;ya=c[l>>2]|0}c[i>>2]=xa;c[f>>2]=wa;H=G+1|0;if((H|0)>(ya|0)){ua=xa;va=wa;break}else{G=H;J=xa;N=wa;E=ya}}}if((c[m>>2]|0)==2){sa=va;ta=ua;F=49}else{Ba=ua;Ca=va}}if((F|0)==49){F=0;if((sa|0)>1){Da=sa-1|0;Ea=ta<<1}else{E=fe(ta<<sa|0)|0;N=c[h>>2]|0;x=E;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Da=sa+31|0;Ea=0}c[i>>2]=Ea;c[f>>2]=Da;Ba=Ea;Ca=Da}N=((c[B>>2]|0)-37|0)/12|0;E=((c[C>>2]|0)-37|0)/12|0;if((Ca|0)>4){Fa=Ca-4|0;Ga=N|Ba<<4}else{J=fe(N>>>((4-Ca|0)>>>0)|Ba<<Ca|0)|0;G=c[h>>2]|0;x=J;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Fa=Ca+28|0;Ga=N}c[i>>2]=Ga;c[f>>2]=Fa;G=E-3|0;if((Fa|0)>4){Ha=Fa-4|0;Ia=Ga<<4|G}else{J=fe(G>>>((4-Fa|0)>>>0)|Ga<<Fa|0)|0;H=c[h>>2]|0;x=J;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Ha=Fa+28|0;Ia=G}c[i>>2]=Ia;c[f>>2]=Ha;if((c[k>>2]|0)!=0){if((Ha|0)>1){Ja=Ha-1|0;Ka=Ia<<1}else{G=fe(Ia<<Ha|0)|0;H=c[h>>2]|0;x=G;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Ja=Ha+31|0;Ka=0}c[i>>2]=Ka;c[f>>2]=Ja;ga=Ka;ha=Ja;ia=I;break}H=N+1|0;if((H|0)<(E|0)){La=H;Ma=Ia;Na=Ha}else{ga=Ia;ha=Ha;ia=I;break}while(1){H=d[1224888+La|0]|0;if((Na|0)>1){Oa=Na-1|0;Pa=H|Ma<<1}else{N=fe(H>>>((1-Na|0)>>>0)|Ma<<Na|0)|0;G=c[h>>2]|0;x=N;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Oa=Na+31|0;Pa=H}c[i>>2]=Pa;c[f>>2]=Oa;H=La+1|0;if((H|0)<(E|0)){La=H;Ma=Pa;Na=Oa}else{ga=Pa;ha=Oa;ia=I;break}}}}while(0);do{if((c[ia>>2]|0)==0){Qa=ga;Ra=ha}else{if((c[l>>2]|0)<1){Qa=ga;Ra=ha;break}I=e+1536+(D<<7)+32|0;E=e+1536+(D<<7)+36|0;H=1;G=ga;N=ha;while(1){do{if((a[e+1536+(D<<7)+64+H|0]|0)==0){Sa=G;Ta=N}else{J=e+1536+(D<<7)+76+H|0;Aa=a[J]|0;if((c[k>>2]|0)!=0&Aa<<24>>24==2){Ua=N;Va=G}else{za=Aa&255;if((N|0)>1){Wa=N-1|0;Xa=za|G<<1}else{Aa=fe(za>>>((1-N|0)>>>0)|G<<N|0)|0;Ya=c[h>>2]|0;x=Aa;a[Ya]=x;x=x>>8;a[Ya+1|0]=x;x=x>>8;a[Ya+2|0]=x;x=x>>8;a[Ya+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Wa=N+31|0;Xa=za}c[i>>2]=Xa;c[f>>2]=Wa;if((a[J]|0)==0){Sa=Xa;Ta=Wa;break}else{Ua=Wa;Va=Xa}}J=d[e+1536+(D<<7)+83+H|0]|0;if((Ua|0)>2){Za=Ua-2|0;_a=J|Va<<2}else{za=fe(J>>>((2-Ua|0)>>>0)|Va<<Ua|0)|0;Ya=c[h>>2]|0;x=za;a[Ya]=x;x=x>>8;a[Ya+1|0]=x;x=x>>8;a[Ya+2|0]=x;x=x>>8;a[Ya+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Za=Ua+30|0;_a=J}c[i>>2]=_a;c[f>>2]=Za;if((c[A>>2]|0)>0){$a=0;ab=_a;bb=Za}else{Sa=_a;Ta=Za;break}while(1){J=d[(c[(c[I>>2]|0)+(H<<2)>>2]|0)+$a|0]|0;if((bb|0)>4){cb=bb-4|0;db=J|ab<<4}else{Ya=fe(J>>>((4-bb|0)>>>0)|ab<<bb|0)|0;za=c[h>>2]|0;x=Ya;a[za]=x;x=x>>8;a[za+1|0]=x;x=x>>8;a[za+2|0]=x;x=x>>8;a[za+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;cb=bb+28|0;db=J}c[i>>2]=db;c[f>>2]=cb;J=d[(c[(c[E>>2]|0)+(H<<2)>>2]|0)+$a|0]|0;if((cb|0)>4){eb=cb-4|0;fb=J|db<<4}else{za=fe(J>>>((4-cb|0)>>>0)|db<<cb|0)|0;Ya=c[h>>2]|0;x=za;a[Ya]=x;x=x>>8;a[Ya+1|0]=x;x=x>>8;a[Ya+2|0]=x;x=x>>8;a[Ya+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;eb=cb+28|0;fb=J}c[i>>2]=fb;c[f>>2]=eb;J=$a+1|0;if((J|0)<(c[A>>2]|0)){$a=J;ab=fb;bb=eb}else{Sa=fb;Ta=eb;break}}}}while(0);J=H+1|0;if((J|0)>(c[l>>2]|0)){Qa=Sa;Ra=Ta;break}else{H=J;G=Sa;N=Ta}}}}while(0);do{if((c[m>>2]|0)==2){N=e+1536+(D<<7)+47|0;if((c[k>>2]|0)==0|(D|0)>0){G=d[N]|0;if((Ra|0)>1){gb=Ra-1|0;hb=G|Qa<<1}else{H=fe(G>>>((1-Ra|0)>>>0)|Qa<<Ra|0)|0;E=c[h>>2]|0;x=H;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;gb=Ra+31|0;hb=G}c[i>>2]=hb;c[f>>2]=gb;ib=hb;jb=gb}else{ib=Qa;jb=Ra}if((a[N]|0)==0){kb=ib;lb=jb;break}N=e+1536+(D<<7)+48|0;G=c[N>>2]|0;if((G|0)>0){mb=0;nb=ib;ob=jb;pb=G}else{kb=ib;lb=jb;break}while(1){G=d[e+1536+(D<<7)+52+mb|0]|0;if((ob|0)>1){qb=ob-1|0;rb=G|nb<<1;sb=pb}else{E=fe(G>>>((1-ob|0)>>>0)|nb<<ob|0)|0;H=c[h>>2]|0;x=E;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;qb=ob+31|0;rb=G;sb=c[N>>2]|0}c[i>>2]=rb;c[f>>2]=qb;G=mb+1|0;if((G|0)<(sb|0)){mb=G;nb=rb;ob=qb;pb=sb}else{kb=rb;lb=qb;break}}}else{kb=Qa;lb=Ra}}while(0);do{if((c[k>>2]|0)==0){N=(c[ia>>2]|0)==0|0;G=c[l>>2]|0;if((N|0)>(G|0)){tb=kb;ub=lb}else{H=N;N=kb;E=lb;I=G;while(1){G=d[e+2688+(H*6|0)+D|0]|0;if((E|0)>2){vb=E-2|0;wb=G|N<<2;xb=I}else{J=fe(G>>>((2-E|0)>>>0)|N<<E|0)|0;Ya=c[h>>2]|0;x=J;a[Ya]=x;x=x>>8;a[Ya+1|0]=x;x=x>>8;a[Ya+2|0]=x;x=x>>8;a[Ya+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;vb=E+30|0;wb=G;xb=c[l>>2]|0}c[i>>2]=wb;c[f>>2]=vb;G=H+1|0;if((G|0)>(xb|0)){tb=wb;ub=vb;break}else{H=G;N=wb;E=vb;I=xb}}}if((c[n>>2]|0)==0){yb=tb;zb=ub;break}I=d[e+2688+((c[o>>2]|0)*6|0)+D|0]|0;if((ub|0)>1){Ab=ub-1|0;Bb=I|tb<<1}else{E=fe(I>>>((1-ub|0)>>>0)|tb<<ub|0)|0;N=c[h>>2]|0;x=E;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Ab=ub+31|0;Bb=I}c[i>>2]=Bb;c[f>>2]=Ab;yb=Bb;zb=Ab}else{yb=kb;zb=lb}}while(0);I=c[l>>2]|0;if((I|0)<1){Cb=yb;Db=zb}else{N=1;E=yb;H=zb;G=I;while(1){do{if((a[e+2688+(N*6|0)+D|0]|0)==0){Eb=E;Fb=H;Gb=G}else{if((a[e+1536+(D<<7)+64+N|0]|0)!=0){Eb=E;Fb=H;Gb=G;break}I=c[z>>2]|0;if((H|0)>6){Hb=H-6|0;Ib=I|E<<6;Jb=G}else{Ya=fe(I>>>((6-H|0)>>>0)|E<<H|0)|0;J=c[h>>2]|0;x=Ya;a[J]=x;x=x>>8;a[J+1|0]=x;x=x>>8;a[J+2|0]=x;x=x>>8;a[J+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Hb=H+26|0;Ib=I;Jb=c[l>>2]|0}c[i>>2]=Ib;c[f>>2]=Hb;Eb=Ib;Fb=Hb;Gb=Jb}}while(0);I=N+1|0;if((I|0)>(Gb|0)){Cb=Eb;Db=Fb;break}else{N=I;E=Eb;H=Fb;G=Gb}}}G=(c[ia>>2]|0)==0|0;if((G|0)>(c[p>>2]|0)){Kb=Cb;Lb=Db}else{H=e+1536+(D<<7)+12|0;E=G;G=Cb;N=Db;while(1){I=(E|0)==0;J=I&1;Ya=e+2688+(E*6|0)+D|0;do{if((a[Ya]|0)==0){Mb=G;Nb=N}else{za=(d[c[(c[H>>2]|0)+(E<<2)>>2]|0]|0)>>>(J>>>0);if((N|0)>4){Ob=N-4|0;Pb=za|G<<4}else{Aa=fe(za>>>((4-N|0)>>>0)|G<<N|0)|0;Qb=c[h>>2]|0;x=Aa;a[Qb]=x;x=x>>8;a[Qb+1|0]=x;x=x>>8;a[Qb+2|0]=x;x=x>>8;a[Qb+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Ob=N+28|0;Pb=za}c[i>>2]=Pb;c[f>>2]=Ob;za=a[(c[e+1536+(D<<7)+100+(E<<2)>>2]|0)-(c[e+2432+(E<<2)>>2]|0)+(8150456+(J*768|0)+((d[Ya]|0)-1<<8))|0]|0;Qb=za&255;if(za<<24>>24==0){Rb=Pb;Sb=Ob}else{za=1;Aa=Pb;Tb=Ob;while(1){Ub=d[(c[(c[H>>2]|0)+(E<<2)>>2]|0)+za|0]|0;if((Tb|0)>7){Vb=Tb-7|0;Wb=Ub|Aa<<7}else{Xb=fe(Ub>>>((7-Tb|0)>>>0)|Aa<<Tb|0)|0;Yb=c[h>>2]|0;x=Xb;a[Yb]=x;x=x>>8;a[Yb+1|0]=x;x=x>>8;a[Yb+2|0]=x;x=x>>8;a[Yb+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Vb=Tb+25|0;Wb=Ub}c[i>>2]=Wb;c[f>>2]=Vb;Ub=za+1|0;if((Ub|0)>(Qb|0)){Rb=Wb;Sb=Vb;break}else{za=Ub;Aa=Wb;Tb=Vb}}}if((E|0)==(c[o>>2]|0)|I){Mb=Rb;Nb=Sb;break}if((Sb|0)>2){Zb=Sb-2|0;_b=Rb<<2}else{Tb=fe(Rb<<Sb|0)|0;Aa=c[h>>2]|0;x=Tb;a[Aa]=x;x=x>>8;a[Aa+1|0]=x;x=x>>8;a[Aa+2|0]=x;x=x>>8;a[Aa+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Zb=Sb+30|0;_b=0}c[i>>2]=_b;c[f>>2]=Zb;Mb=_b;Nb=Zb}}while(0);I=E+1|0;if((I|0)>(c[p>>2]|0)){Kb=Mb;Lb=Nb;break}else{E=I;G=Mb;N=Nb}}}do{if((c[k>>2]|0)==0){N=(D|0)==0;G=N&1;if((Lb|0)>1){$b=Lb-1|0;ac=Kb<<1|G}else{E=fe(G>>>((1-Lb|0)>>>0)|Kb<<Lb|0)|0;H=c[h>>2]|0;x=E;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;$b=Lb+31|0;ac=G}c[i>>2]=ac;c[f>>2]=$b;if(N){N=c[q>>2]|0;if(($b|0)>2){bc=$b-2|0;cc=N|ac<<2}else{G=fe(N>>>((2-$b|0)>>>0)|ac<<$b|0)|0;H=c[h>>2]|0;x=G;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;bc=$b+30|0;cc=N}c[i>>2]=cc;c[f>>2]=bc;N=c[r>>2]|0;if((bc|0)>2){dc=bc-2|0;ec=N|cc<<2}else{H=fe(N>>>((2-bc|0)>>>0)|cc<<bc|0)|0;G=c[h>>2]|0;x=H;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;dc=bc+30|0;ec=N}c[i>>2]=ec;c[f>>2]=dc;N=c[s>>2]|0;if((dc|0)>2){fc=dc-2|0;gc=N|ec<<2}else{G=fe(N>>>((2-dc|0)>>>0)|ec<<dc|0)|0;H=c[h>>2]|0;x=G;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;fc=dc+30|0;gc=N}c[i>>2]=gc;c[f>>2]=fc;N=c[t>>2]|0;if((fc|0)>2){hc=fc-2|0;ic=N|gc<<2}else{H=fe(N>>>((2-fc|0)>>>0)|gc<<fc|0)|0;G=c[h>>2]|0;x=H;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;hc=fc+30|0;ic=N}c[i>>2]=ic;c[f>>2]=hc;N=c[u>>2]|0;if((hc|0)>3){jc=hc-3|0;kc=N|ic<<3}else{G=fe(N>>>((3-hc|0)>>>0)|ic<<hc|0)|0;H=c[h>>2]|0;x=G;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;jc=hc+29|0;kc=N}c[i>>2]=kc;c[f>>2]=jc;lc=kc;mc=jc}else{lc=ac;mc=$b}if((c[k>>2]|0)!=0){nc=lc;oc=mc;F=175;break}N=e+1536+(D<<7)+92|0;H=c[N>>2]|0;if((mc|0)>1){pc=mc-1|0;qc=H|lc<<1;rc=H}else{G=fe(H>>>((1-mc|0)>>>0)|lc<<mc|0)|0;E=c[h>>2]|0;x=G;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;pc=mc+31|0;qc=H;rc=c[N>>2]|0}c[i>>2]=qc;c[f>>2]=pc;if((rc|0)==0){sc=qc;tc=pc;F=179;break}N=c[v>>2]|0;if((pc|0)>6){uc=pc-6|0;vc=N|qc<<6}else{H=fe(N>>>((6-pc|0)>>>0)|qc<<pc|0)|0;E=c[h>>2]|0;x=H;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;uc=pc+26|0;vc=N}c[i>>2]=vc;c[f>>2]=uc;N=c[ia>>2]|0;E=(N|0)==0|0;if((E|0)>(c[p>>2]|0)){wc=vc;xc=uc;yc=N;break}else{zc=E;Ac=vc;Bc=uc}while(1){E=c[e+2592+(zc<<2)>>2]|0;if((Bc|0)>4){Cc=Bc-4|0;Dc=E|Ac<<4}else{N=fe(E>>>((4-Bc|0)>>>0)|Ac<<Bc|0)|0;H=c[h>>2]|0;x=N;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Cc=Bc+28|0;Dc=E}c[i>>2]=Dc;c[f>>2]=Cc;E=c[e+2564+(zc<<2)>>2]|0;if((Cc|0)>3){Ec=Cc-3|0;Fc=E|Dc<<3}else{H=fe(E>>>((3-Cc|0)>>>0)|Dc<<Cc|0)|0;N=c[h>>2]|0;x=H;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Ec=Cc+29|0;Fc=E}c[i>>2]=Fc;c[f>>2]=Ec;E=zc+1|0;if((E|0)>(c[p>>2]|0)){sc=Fc;tc=Ec;F=179;break}else{zc=E;Ac=Fc;Bc=Ec}}}else{nc=Kb;oc=Lb;F=175}}while(0);if((F|0)==175){F=0;if((oc|0)>1){Gc=oc-1|0;Hc=nc<<1}else{E=fe(nc<<oc|0)|0;N=c[h>>2]|0;x=E;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Gc=oc+31|0;Hc=0}c[i>>2]=Hc;c[f>>2]=Gc;sc=Hc;tc=Gc;F=179}if((F|0)==179){F=0;wc=sc;xc=tc;yc=c[ia>>2]|0}do{if((yc|0)==0){Ic=wc;Jc=xc}else{N=e+1536+(D<<7)+96|0;E=c[N>>2]|0;if((c[k>>2]|0)!=0&(E|0)==2){Kc=xc;Lc=wc}else{if((xc|0)>1){Mc=xc-1|0;Nc=E|wc<<1;Oc=E}else{H=fe(E>>>((1-xc|0)>>>0)|wc<<xc|0)|0;G=c[h>>2]|0;x=H;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Mc=xc+31|0;Nc=E;Oc=c[N>>2]|0}c[i>>2]=Nc;c[f>>2]=Mc;if((Oc|0)==0){Ic=Nc;Jc=Mc;break}else{Kc=Mc;Lc=Nc}}N=c[w>>2]|0;if((Kc|0)>3){Pc=Kc-3|0;Qc=N|Lc<<3}else{E=fe(N>>>((3-Kc|0)>>>0)|Lc<<Kc|0)|0;G=c[h>>2]|0;x=E;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Pc=Kc+29|0;Qc=N}c[i>>2]=Qc;c[f>>2]=Pc;N=c[y>>2]|0;if((Pc|0)>3){Rc=Pc-3|0;Sc=N|Qc<<3}else{G=fe(N>>>((3-Pc|0)>>>0)|Qc<<Pc|0)|0;E=c[h>>2]|0;x=G;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Rc=Pc+29|0;Sc=N}c[i>>2]=Sc;c[f>>2]=Rc;Ic=Sc;Jc=Rc}}while(0);if((c[k>>2]|0)==0){if((Jc|0)>1){Tc=Jc-1|0;Uc=Ic<<1}else{N=fe(Ic<<Jc|0)|0;E=c[h>>2]|0;x=N;a[E]=x;x=x>>8;a[E+1|0]=x;x=x>>8;a[E+2|0]=x;x=x>>8;a[E+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Tc=Jc+31|0;Uc=0}c[i>>2]=Uc;c[f>>2]=Tc;if((Tc|0)>1){Vc=Tc-1|0;Wc=Uc<<1}else{E=fe(Uc<<Tc|0)|0;N=c[h>>2]|0;x=E;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;Vc=Tc+31|0;Wc=0}c[i>>2]=Wc;c[f>>2]=Vc;Xc=Wc;Yc=Vc}else{Xc=Ic;Yc=Jc}N=c[p>>2]|0;if((N|0)>=1){E=e+1536+(D<<7)+28|0;G=0;H=(c[ia>>2]|0)==0|0;I=1;Ya=Xc;J=Yc;Aa=N;while(1){if((H|0)==0&(I|0)>1){N=I-1|0;Tb=(a[e+1536+(D<<7)+64+N|0]|0)==0;Zc=Tb?I:0;_c=Tb&1^1;$c=Tb?G:N}else{Zc=I;_c=H;$c=G}N=c[e+2432+(Zc<<2)>>2]|0;Tb=e+1536+(D<<7)+100+(Zc<<2)|0;if((N|0)<(c[Tb>>2]|0)){za=e+2788+(Zc*24|0)+(D<<2)|0;Qb=N;N=Ya;Ub=J;while(1){Yb=b[(c[(c[E>>2]|0)+(Zc<<2)>>2]|0)+(Qb<<1)>>1]|0;Xb=Yb&65535;ad=d[(c[za>>2]|0)+Qb|0]|0;a:do{switch(ad|0){case 4:{if(Yb<<16>>16==128){bd=N;cd=Ub;break a}if((Ub|0)>7){dd=Ub-7|0;ed=Xb|N<<7}else{fd=fe(Xb>>>((7-Ub|0)>>>0)|N<<Ub|0)|0;gd=c[h>>2]|0;x=fd;a[gd]=x;x=x>>8;a[gd+1|0]=x;x=x>>8;a[gd+2|0]=x;x=x>>8;a[gd+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;dd=Ub+25|0;ed=Xb}c[i>>2]=ed;c[f>>2]=dd;bd=ed;cd=dd;break};case 3:{gd=Xb&7;if((Ub|0)>3){hd=Ub-3|0;id=gd|N<<3}else{fd=fe(gd>>>((3-Ub|0)>>>0)|N<<Ub|0)|0;jd=c[h>>2]|0;x=fd;a[jd]=x;x=x>>8;a[jd+1|0]=x;x=x>>8;a[jd+2|0]=x;x=x>>8;a[jd+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;hd=Ub+29|0;id=gd}c[i>>2]=id;c[f>>2]=hd;bd=id;cd=hd;break};case 0:{bd=N;cd=Ub;break};case 2:{if(Yb<<16>>16==128){bd=N;cd=Ub;break a}if((Ub|0)>7){kd=Ub-7|0;ld=Xb|N<<7}else{gd=fe(Xb>>>((7-Ub|0)>>>0)|N<<Ub|0)|0;jd=c[h>>2]|0;x=gd;a[jd]=x;x=x>>8;a[jd+1|0]=x;x=x>>8;a[jd+2|0]=x;x=x>>8;a[jd+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;kd=Ub+25|0;ld=Xb}c[i>>2]=ld;c[f>>2]=kd;bd=ld;cd=kd;break};case 14:{jd=Xb&16383;if((Ub|0)>14){md=Ub-14|0;nd=jd|N<<14}else{gd=fe(jd>>>((14-Ub|0)>>>0)|N<<Ub|0)|0;fd=c[h>>2]|0;x=gd;a[fd]=x;x=x>>8;a[fd+1|0]=x;x=x>>8;a[fd+2|0]=x;x=x>>8;a[fd+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;md=Ub+18|0;nd=jd}c[i>>2]=nd;c[f>>2]=md;bd=nd;cd=md;break};case 1:{if(Yb<<16>>16==128){bd=N;cd=Ub;break a}if((Ub|0)>5){od=Ub-5|0;pd=Xb|N<<5}else{jd=fe(Xb>>>((5-Ub|0)>>>0)|N<<Ub|0)|0;fd=c[h>>2]|0;x=jd;a[fd]=x;x=x>>8;a[fd+1|0]=x;x=x>>8;a[fd+2|0]=x;x=x>>8;a[fd+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;od=Ub+27|0;pd=Xb}c[i>>2]=pd;c[f>>2]=od;bd=pd;cd=od;break};case 15:{if((Ub|0)>16){qd=Ub-16|0;rd=Xb|N<<16}else{fd=fe(Xb>>>((16-Ub|0)>>>0)|N<<Ub|0)|0;jd=c[h>>2]|0;x=fd;a[jd]=x;x=x>>8;a[jd+1|0]=x;x=x>>8;a[jd+2|0]=x;x=x>>8;a[jd+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;qd=Ub+16|0;rd=Xb}c[i>>2]=rd;c[f>>2]=qd;bd=rd;cd=qd;break};default:{jd=ad-1|0;fd=(1<<jd)+65535&Xb;if((Ub|0)>(jd|0)){sd=Ub-jd|0;td=fd|N<<jd}else{gd=fe(fd>>>((jd-Ub|0)>>>0)|N<<Ub|0)|0;jd=c[h>>2]|0;x=gd;a[jd]=x;x=x>>8;a[jd+1|0]=x;x=x>>8;a[jd+2|0]=x;x=x>>8;a[jd+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;sd=Ub+33-ad|0;td=fd}c[i>>2]=td;c[f>>2]=sd;bd=td;cd=sd}}}while(0);ad=Qb+1|0;if((ad|0)<(c[Tb>>2]|0)){Qb=ad;N=bd;Ub=cd}else{break}}ud=bd;vd=cd;wd=c[p>>2]|0}else{ud=Ya;vd=J;wd=Aa}Ub=((Zc|0)==0?$c:Zc)+1|0;if((Ub|0)>(wd|0)){break}else{G=$c;H=_c;I=Ub;Ya=ud;J=vd;Aa=wd}}}D=D+1|0;}while((D|0)<(c[j>>2]|0))}j=tBb(1)|0;D=e+2340|0;wd=c[D>>2]|0;vd=(wd>>2)+(wd>>4)<<1;ud=c[f>>2]|0;if((ud|0)<32){_c=c[i>>2]<<ud;c[i>>2]=_c;ud=_c>>>24&255;while(1){_c=c[h>>2]|0;c[h>>2]=_c+1;a[_c]=ud;_c=c[i>>2]|0;c[i>>2]=_c<<8;$c=(c[f>>2]|0)+8|0;c[f>>2]=$c;if(($c|0)<32){ud=_c>>>16&255}else{break}}xd=c[D>>2]|0}else{xd=wd}c[f>>2]=32;c[i>>2]=0;i=c[g>>2]|0;g=c[h>>2]|0;h=xd-2+i-g|0;if((h|0)>0){TGb(g|0,0,h|0)|0}if((c[e+2308>>2]|0)==0){h=b[e+2348+(((c[D>>2]|0)>(c[e+2336>>2]|0))<<1)>>1]|0;if(h<<16>>16==0){yd=0}else{e=(de((uBb(j,0,i+4|0,vd-4|0)|0)&65535|0)|0)&65535;g=h&65535;h=0;while(1){zd=((g&1|0)==0?0:e)^h;xd=g>>>1;f=e<<1;if((xd|0)==0){break}else{e=(f&65536|0)==0?f:f^98309;g=xd;h=zd}}yd=zd&65535}zd=i+2|0;x=de(yd|0)|0;a[zd]=x;x=x>>8;a[zd+1|0]=x;zd=c[D>>2]|0;Ad=uBb(j,0,i+vd|0,-3-vd+zd|0)|0;Bd=zd}else{zd=c[D>>2]|0;Ad=uBb(j,0,i+2|0,zd-5|0)|0;Bd=zd}zd=i+(Bd-3)|0;vd=uBb(j,Ad,zd,1)|0;if((vd|0)!=30475){Cd=vd&65535;Dd=Bd;Ed=Dd-2|0;Fd=i+Ed|0;Gd=Fd;x=Cd;a[Gd]=x;x=x>>8;a[Gd+1|0]=x;return}a[zd]=a[zd]^1;zd=c[D>>2]|0;Cd=(uBb(j,Ad,i+(zd-3)|0,1)|0)&65535;Dd=zd;Ed=Dd-2|0;Fd=i+Ed|0;Gd=Fd;x=Cd;a[Gd]=x;x=x>>8;a[Gd+1|0]=x;return}function hgb(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;e=c[b+108>>2]|0;f=b+24|0;c[f>>2]=0;j=b+44|0;c[j>>2]=0;k=b+68|0;c[k>>2]=0;l=b+84|0;c[l>>2]=0;m=b+88|0;c[m>>2]=0;n=c[b+2392>>2]|0;do{if((n|0)>2){if((c[b+48>>2]|0)==-1){break}c[j>>2]=1;c[l>>2]=1}}while(0);o=b+2384|0;p=(c[o>>2]|0)==0;do{if(!p){if(+g[b+52>>2]<0.0){if(+g[b+60>>2]<0.0){break}}c[j>>2]=1;c[l>>2]=1}}while(0);q=b+2388|0;r=c[q>>2]|0;do{if((r|0)!=0){if(+g[b+56>>2]<0.0){if(+g[b+64>>2]<0.0){break}}c[j>>2]=1;c[l>>2]=1}}while(0);s=b+2308|0;t=(c[s>>2]|0)==0;a:do{if(t){if((c[b+28>>2]|0)==-1){if(!((c[b+32>>2]|0)==-1)){u=31}}else{u=31}if((u|0)==31){c[f>>2]=1}do{if((n|0)>5){if((c[b+72>>2]|0)==-1){break}c[k>>2]=1}}while(0);do{if((n|0)==2){if((c[b+76>>2]|0)==-1){break}c[k>>2]=1}}while(0);if((c[b+80>>2]|0)==-1){break}c[k>>2]=1}else{if((c[e+464>>2]|0)!=0){c[m>>2]=1}if((c[b+36>>2]|0)==-1){if(!((c[b+40>>2]|0)==-1)){u=17}}else{u=17}if((u|0)==17){c[m>>2]=1}do{if((n|0)==2){if((c[b+76>>2]|0)==-1){if((c[b+20>>2]|0)==-1){break}}c[m>>2]=1}}while(0);do{if((n|0)>5){if((c[b+72>>2]|0)==-1){break}c[m>>2]=1}}while(0);do{if((c[b+28>>2]|0)==-1){if(!((c[b+32>>2]|0)==-1)){break}if((c[b+80>>2]|0)==-1){break a}}}while(0);c[f>>2]=1;c[m>>2]=1}}while(0);do{if(t){if(p){v=r}else{n=e;w=b+12|0;x=b+2400|0;y=+g[w>>2];z=y;A=0;while(1){if((A|0)>=3){break}B=+g[1484432+(A<<2)>>2];if(z<B+.01&z>B+-.01){break}else{A=A+1|0}}C=(A|0)==3?-1:A;do{if((C|0)<0){if(y<0.0){D=1;E=r;break}yDb(n,24,2240480,(F=i,i=i+16|0,c[F>>2]=2187776,h[F+8>>3]=.5946035385131836,F)|0);i=F;D=1;E=c[q>>2]|0}else{D=C;E=r}}while(0);g[w>>2]=+g[1484432+(D<<2)>>2];c[x>>2]=D;v=E}if((v|0)==0){break}C=e;n=b+16|0;A=b+2404|0;y=+g[n>>2];z=y;G=0;while(1){if((G|0)>=3){break}B=+g[429264+(G<<2)>>2];if(z<B+.01&z>B+-.01){break}else{G=G+1|0}}x=(G|0)==3?-1:G;do{if((x|0)<0){if(y<0.0){H=1;break}yDb(C,24,2240480,(F=i,i=i+16|0,c[F>>2]=2308304,h[F+8>>3]=.5,F)|0);i=F;H=1}else{H=x}}while(0);g[n>>2]=+g[429264+(H<<2)>>2];c[A>>2]=H}}while(0);if((c[j>>2]|0)==0){if((c[l>>2]|0)!=0){u=59}}else{u=59}do{if((u|0)==59){l=b+48|0;if((c[l>>2]|0)==-1){c[l>>2]=0}if((c[s>>2]|0)==0){u=63}else{if((c[o>>2]|0)==0){u=76}else{u=63}}if((u|0)==63){l=e;H=b+52|0;v=b+2408|0;y=+g[H>>2];z=y;E=0;while(1){if((E|0)>=8){break}B=+g[1320656+(E<<2)>>2];if(z<B+.01&z>B+-.01){break}else{E=E+1|0}}A=(E|0)==8?-1:E;do{if((A|0)<0){if(y<0.0){I=5;break}yDb(l,24,2240480,(F=i,i=i+16|0,c[F>>2]=2176400,h[F+8>>3]=.5946035385131836,F)|0);i=F;I=5}else{I=A}}while(0);g[H>>2]=+g[1320656+(I<<2)>>2];c[v>>2]=I;A=b+60|0;E=b+2416|0;y=+g[A>>2];z=y;n=0;while(1){if((n|0)>=8){break}B=+g[1320656+(n<<2)>>2];if(z<B+.01&z>B+-.01){break}else{n=n+1|0}}v=(n|0)==8?-1:n;do{if((v|0)<0){if(y<0.0){J=5;break}yDb(l,24,2240480,(F=i,i=i+16|0,c[F>>2]=2100512,h[F+8>>3]=.5946035385131836,F)|0);i=F;J=5}else{J=v}}while(0);g[A>>2]=+g[1320656+(J<<2)>>2];c[E>>2]=J;if((c[s>>2]|0)!=0){u=76}}if((u|0)==76){if((c[q>>2]|0)==0){break}}v=e;l=b+56|0;n=b+2412|0;y=+g[l>>2];z=y;H=0;while(1){if((H|0)>=8){break}B=+g[1320656+(H<<2)>>2];if(z<B+.01&z>B+-.01){break}else{H=H+1|0}}E=(H|0)==8?-1:H;do{if((E|0)<3){if(y<0.0){K=6;break}yDb(v,24,2240480,(F=i,i=i+16|0,c[F>>2]=2044928,h[F+8>>3]=.5,F)|0);i=F;K=6}else{K=E}}while(0);g[l>>2]=+g[1320656+(K<<2)>>2];c[n>>2]=K;E=b+64|0;H=b+2420|0;y=+g[E>>2];z=y;A=0;while(1){if((A|0)>=8){break}B=+g[1320656+(A<<2)>>2];if(z<B+.01&z>B+-.01){break}else{A=A+1|0}}n=(A|0)==8?-1:A;do{if((n|0)<3){if(y<0.0){L=6;break}yDb(v,24,2240480,(F=i,i=i+16|0,c[F>>2]=1999264,h[F+8>>3]=.5,F)|0);i=F;L=6}else{L=n}}while(0);g[E>>2]=+g[1320656+(L<<2)>>2];c[H>>2]=L}}while(0);L=c[e+464>>2]|0;do{if((L|0)==8){if((c[e+416>>2]|0)==1){u=94}}else{if(!((L-5|0)>>>0<3>>>0)){break}if((c[e+416>>2]|0)>1){u=94}}}while(0);if((u|0)==94){yDb(e,16,1962408,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;M=-22;i=d;return M|0}L=(c[k>>2]|0)==0;if(L){if((c[m>>2]|0)!=0){u=97}}else{u=97}do{if((u|0)==97){k=b+76|0;if((c[k>>2]|0)==-1){c[k>>2]=0}k=b+72|0;if((c[k>>2]|0)==-1){c[k>>2]=0}k=b+80|0;if(!((c[k>>2]|0)==-1)){break}c[k>>2]=0}}while(0);k=(c[s>>2]|0)==0;if(k){u=105}else{if((c[m>>2]|0)!=0){u=105}}do{if((u|0)==105){s=b+36|0;if((c[s>>2]|0)==-1){c[s>>2]=0}s=b+40|0;if((c[s>>2]|0)==-1){c[s>>2]=1}if(!k){if((c[m>>2]|0)==0){break}}s=b+20|0;if(!((c[s>>2]|0)==-1)){break}c[s>>2]=0}}while(0);do{if((c[f>>2]|0)!=0){m=c[b+28>>2]|0;if((m|0)==-1){yDb(e,16,1934272,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;M=-22;i=d;return M|0}if((m|0)<80){yDb(e,16,1911280,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;M=-22;i=d;return M|0}else{m=b+32|0;if(!((c[m>>2]|0)==-1)){break}c[m>>2]=0;break}}}while(0);if(!k){M=0;i=d;return M|0}if(!((c[j>>2]|0)!=0|L^1)){M=0;i=d;return M|0}L=b+2312|0;if(!(((c[L>>2]|0)-9|0)>>>0<2>>>0)){c[L>>2]=6;M=0;i=d;return M|0}if(a[1274760]|0){M=0;i=d;return M|0}yDb(e,24,1890760,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;a[1274760]=1;M=0;i=d;return M|0}function igb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+60>>2]|0;a=b;$Db(b+2632|0);d=b+2636|0;e=d;f=c[e>>2]|0;a:do{if((f|0)!=0){g=b+2372|0;if((c[g>>2]|0)>0){h=0;i=f}else{break}while(1){$Db(i+(h<<2)|0);j=h+1|0;if((j|0)>=(c[g>>2]|0)){break a}h=j;i=c[e>>2]|0}}}while(0);$Db(d);$Db(b+2640|0);$Db(b+2644|0);$Db(b+2648|0);$Db(b+2652|0);$Db(b+2656|0);$Db(b+2660|0);$Db(b+2664|0);$Db(b+2668|0);$Db(b+2672|0);$Db(b+2676|0);$Db(b+2680|0);$Db(b+2684|0);d=b+2332|0;if((c[d>>2]|0)<=0){k=b+2960|0;l=k;m=c[l>>2]|0;me[m&511](a);return 0}e=b+1536|0;i=0;do{$Db(e+(i<<7)|0);$Db(e+(i<<7)+4|0);$Db(e+(i<<7)+8|0);$Db(e+(i<<7)+12|0);$Db(e+(i<<7)+16|0);$Db(e+(i<<7)+20|0);$Db(e+(i<<7)+24|0);$Db(e+(i<<7)+28|0);$Db(e+(i<<7)+32|0);$Db(e+(i<<7)+36|0);i=i+1|0;}while((i|0)<(c[d>>2]|0));k=b+2960|0;l=k;m=c[l>>2]|0;me[m&511](a);return 0}function jgb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0;g=i;i=i+16|0;h=g|0;j=c[f+60>>2]|0;k=j;l=j+108|0;c[l>>2]=f;m=j+2308|0;c[m>>2]=(c[f+48>>2]|0)==86057;Spb();n=c[l>>2]|0;o=n+448|0;if((c[o>>2]|0)==0&(c[o+4>>2]|0)==0){yDb(n,24,2327960,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}q=c[n+416>>2]|0;a:do{if(!((q-1|0)>>>0>6>>>0)){r=c[o>>2]|0;s=c[o+4>>2]|0;t=0;if(s>>>0>t>>>0|s>>>0==t>>>0&r>>>0>2047>>>0){break}t=r;if((t|0)==0){r=jBb(q)|0;u=r}else{u=t}t=u>>>3&1;r=j+2376|0;c[r>>2]=t;s=j+2372|0;c[s>>2]=q;v=q-t|0;w=j+2368|0;c[w>>2]=v;x=(t|0)==0;y=j+2380|0;c[y>>2]=x?-1:v+1|0;v=x?u:u-8|0;switch(v|0){case 3:{c[j+2392>>2]=2;z=0;A=2;break};case 259:{c[j+2392>>2]=4;z=0;A=4;break};case 7:{c[j+2392>>2]=3;B=3;C=15;break};case 4:{c[j+2392>>2]=1;B=1;C=15;break};case 51:case 1539:{c[j+2392>>2]=6;z=0;A=6;break};case 1543:case 55:{c[j+2392>>2]=7;B=7;C=15;break};case 263:{c[j+2392>>2]=5;B=5;C=15;break};default:{break a}}if((C|0)==15){z=(B|0)!=1|0;A=B}c[j+2384>>2]=z;c[j+2388>>2]=A&4;c[j+2396>>2]=1276080+(A*12|0)+(t*6|0);t=v;D=(v|0)<0|0?-1:0;c[o>>2]=x?t:t|8;c[o+4>>2]=x?D:D|0;D=c[m>>2]|0;x=(D|0)!=0?2:8;t=n+412|0;v=0;while(1){if((v|0)>(x|0)){C=20;break}E=(v|0)%3|0;F=(v|0)/3|0;G=(e[1274880+(E<<1)>>1]|0)>>>(F>>>0);if((G|0)==(c[t>>2]|0)){break}else{v=v+1|0}}if((C|0)==20){yDb(n,16,2285824,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;H=-22;i=g;return H|0}v=j+2324|0;c[v>>2]=G;t=j+2528|0;c[t>>2]=F;x=j+2524|0;c[x>>2]=E;c[j+2312>>2]=(D|0)==0?F+8|0:16;I=n+72|0;J=c[I>>2]|0;b:do{if((J|0)==0){switch(c[w>>2]|0){case 3:{c[I>>2]=32e4;K=32e4;break b;break};case 2:{c[I>>2]=192e3;K=192e3;break b;break};case 4:{c[I>>2]=384e3;K=384e3;break b;break};case 1:{c[I>>2]=96e3;K=96e3;break b;break};case 5:{c[I>>2]=448e3;K=448e3;break b;break};default:{K=0;break b}}}else{K=J}}while(0);if((c[m>>2]|0)==0){J=0;D=2147483647;L=0;M=0;while(1){if((J|0)>=19){N=L;O=M;break}P=((e[1276624+(J<<1)>>1]|0)>>>((c[t>>2]|0)>>>0))*1e3|0;Q=P-K|0;R=(Q|0)>-1?Q:-Q|0;Q=(R|0)<(D|0);S=Q?P:M;P=Q?J:L;T=Q?R:D;if((T|0)==0){N=P;O=S;break}else{J=J+1|0;D=T;L=P;M=S}}c[I>>2]=O;M=N<<1;c[j+2344>>2]=M;L=e[1275600+(M*6|0)+(c[x>>2]<<1)>>1]<<1;c[j+2336>>2]=L;c[j+2328>>2]=3;c[j+2332>>2]=6;U=L}else{L=h|0;M=h+4|0;D=h+8|0;J=h+12|0;S=0;P=0;T=3;R=0;Q=0;while(1){if(!((T|0)>-1)){V=S;W=P;X=R;Y=Q;break}c[L>>2]=1;c[M>>2]=2;c[D>>2]=3;c[J>>2]=6;Z=c[h+(T<<2)>>2]|0;_=Z<<8;$=c[v>>2]|0;aa=(($<<11|0)/(_|0)|0)<<4;ca=((_-1+$|0)/(_|0)|0)<<4;if((K|0)>(aa|0)){S=_;P=Z;T=T-1|0;R=ca;Q=aa}else{V=_;W=Z;X=ca;Y=aa;break}}if((K|0)<(X|0)|(K|0)>(Y|0)){yDb(n,16,2270008,(p=i,i=i+16|0,c[p>>2]=X,c[p+8>>2]=Y,p)|0);i=p;H=-22;i=g;return H|0}c[j+2328>>2]=T;c[j+2332>>2]=W;Q=c[I>>2]|0;R=c[v>>2]|0;P=2147483647;S=-1;J=0;while(1){D=((e[1276624+(J<<1)>>1]|0)*1e3|0)-Q|0;M=(D|0)>-1?D:-D|0;D=(M|0)<(P|0);da=D?J:S;L=J+1|0;if((L|0)<19){P=D?M:P;S=da;J=L}else{break}}J=(ba((Q|0)/16|0,V)|0)/(R|0)|0;c[j+2344>>2]=da<<1;S=J;while(1){if((S|0)<=1){break}J=((ba(S,R)|0)/1536|0)<<4;if((J|0)>(c[I>>2]|0)){S=S-1|0}else{break}}R=S<<1;c[j+2336>>2]=R;U=R}c[j+2320>>2]=c[I>>2];R=j+2340|0;c[R>>2]=U;Q=c[n+436>>2]|0;if((Q|0)<0){yDb(n,16,2254664,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;H=-22;i=g;return H|0}J=j+2424|0;c[J>>2]=Q;P=c[v>>2]>>1;if((Q|0)>(P|0)){c[J>>2]=P}P=hgb(k)|0;if((P|0)!=0){H=P;i=g;return H|0}if((c[j+96>>2]|0)==0){ea=0}else{ea=(c[j+2392>>2]|0)==2|0}c[j+2500>>2]=ea;P=j+100|0;if((c[P>>2]|0)==0){fa=0}else{fa=(c[j+2392>>2]|0)>1|0}Q=j+2468|0;c[Q>>2]=fa;T=j+2332|0;c[f+424>>2]=c[T>>2]<<8;c[f+116>>2]=256;L=c[f+464>>2]|0;c[j+2316>>2]=(L|0)==8?7:L;TGb(j+2352|0,0,16)|0;L=c[R>>2]|0;R=L-16+(L>>>2<<4)&-16;if((R|0)==0){ga=1}else{M=R;R=49154;D=1;while(1){do{if((M&1|0)==0){ha=D}else{if((D|0)==0){ha=0;break}else{ia=R;ja=D;ka=0}while(1){aa=((ja&1|0)==0?0:ia)^ka;ca=ja>>>1;Z=ia<<1;if((ca|0)==0){ha=aa;break}else{ia=(Z&65536|0)==0?Z:Z^98309;ja=ca;ka=aa}}}}while(0);if((R|0)==0){la=0}else{aa=R;ca=R;Z=0;while(1){_=((ca&1|0)==0?0:aa)^Z;$=ca>>>1;ma=aa<<1;if(($|0)==0){la=_;break}else{aa=(ma&65536|0)==0?ma:ma^98309;ca=$;Z=_}}}Z=M>>>1;if((Z|0)==0){break}else{M=Z;R=la;D=ha}}ga=ha&65535}b[j+2348>>1]=ga;D=c[x>>2]|0;if((D|0)==1){R=L-14+((L+2|0)>>>2<<4)&-16;if((R|0)==0){na=1}else{M=R;R=49154;I=1;while(1){do{if((M&1|0)==0){oa=I}else{if((I|0)==0){oa=0;break}else{pa=R;qa=I;ra=0}while(1){S=((qa&1|0)==0?0:pa)^ra;Z=qa>>>1;ca=pa<<1;if((Z|0)==0){oa=S;break}else{pa=(ca&65536|0)==0?ca:ca^98309;qa=Z;ra=S}}}}while(0);if((R|0)==0){sa=0}else{S=R;Z=R;ca=0;while(1){aa=((Z&1|0)==0?0:S)^ca;_=Z>>>1;$=S<<1;if((_|0)==0){sa=aa;break}else{S=($&65536|0)==0?$:$^98309;Z=_;ca=aa}}}ca=M>>>1;if((ca|0)==0){break}else{M=ca;R=sa;I=oa}}na=oa&65535}b[j+2350>>1]=na}I=j+2304|0;R=j+2960|0;if((c[I>>2]|0)==0){c[R>>2]=196;c[j+2964>>2]=202;c[j+2968>>2]=1510}else{c[R>>2]=178;c[j+2964>>2]=442;c[j+2968>>2]=304}c[j+2972>>2]=(c[m>>2]|0)==0?62:2;R=c[J>>2]|0;if((R|0)==0){M=c[w>>2]|0;c[j+2428>>2]=d[((c[j+2344>>2]|0)/2|0)+(1877040+((M-1|0)*57|0)+(D*19|0))|0]|0;ta=M}else{M=((R<<9|0)/(c[v>>2]|0)|0)-73|0;R=(M|0)/3|0;if((M|0)<-2){ua=0}else{ua=(R|0)>60?60:R}c[j+2428>>2]=ua;ta=c[w>>2]|0}if((ta|0)<1){va=1}else{R=j+2428|0;M=1;while(1){c[k+2432+(M<<2)>>2]=0;if((c[T>>2]|0)>0){L=0;do{c[k+1536+(L<<7)+100+(M<<2)>>2]=((c[R>>2]|0)*3|0)+73;L=L+1|0;}while((L|0)<(c[T>>2]|0))}L=M+1|0;if((L|0)>(c[w>>2]|0)){va=L;break}else{M=L}}}do{if((c[r>>2]|0)!=0){c[k+2432+(c[y>>2]<<2)>>2]=0;if((c[T>>2]|0)>0){wa=0}else{break}do{c[k+1536+(wa<<7)+100+(va<<2)>>2]=7;wa=wa+1|0;}while((wa|0)<(c[T>>2]|0))}}while(0);c:do{if((c[Q>>2]|0)==0){xa=12}else{y=c[j+104>>2]|0;do{if((y|0)==-1){M=a[((c[j+2344>>2]|0)/2|0)+(1876696+(((c[j+2392>>2]|0)-2|0)*57|0)+((c[x>>2]|0)*19|0))|0]|0;if(!(M<<24>>24<0)){ya=M<<24>>24;break}if(!((c[P>>2]|0)==-1)){ya=15;break}c[Q>>2]=0;xa=12;break c}else{ya=y}}while(0);y=j+2480|0;M=(c[j+2428>>2]|0)/4|0;R=M+3|0;v=M+2|0;M=(v|0)>15?15:v;if((ya|0)<0){za=0}else{za=(ya|0)>(M|0)?M:ya}c[j+2472>>2]=R-za;M=j+2476|0;c[M>>2]=1;a[y]=12;v=za+1|0;d:do{if((v|0)<(R|0)){D=y;J=v;do{L=J;ca=12;while(1){if((a[1224888+L|0]|0)==0){break}Z=ca+12&255;a[D]=Z;S=L+1|0;if((S|0)<(R|0)){L=S;ca=Z}else{break d}}c[M>>2]=(c[M>>2]|0)+1;D=D+1|0;a[D]=12;J=L+1|0;}while((J|0)<(R|0))}}while(0);c[j+2432>>2]=(za*12|0)+37;M=(R*12|0)+37|0;c[j+2460>>2]=M;v=c[T>>2]|0;if((v|0)>0){Aa=0}else{xa=12;break}while(1){c[k+1536+(Aa<<7)+100>>2]=M;y=Aa+1|0;if((y|0)<(v|0)){Aa=y}else{xa=12;break}}}}while(0);while(1){a[8150456+xa|0]=(xa-1|0)/3|0;a[8151224+xa|0]=(xa|0)/3|0;P=xa+1|0;if((P|0)<256){xa=P}else{Ba=12;break}}while(1){a[8150712+Ba|0]=(Ba+2|0)/6|0;a[8151480+Ba|0]=(Ba|0)/6|0;P=Ba+1|0;if((P|0)<256){Ba=P}else{Ca=12;break}}do{a[8150968+Ca|0]=(Ca+8|0)/12|0;a[8151736+Ca|0]=(Ca|0)/12|0;Ca=Ca+1|0;}while((Ca|0)<256);a[8150463]=2;if((c[m>>2]|0)==0){Da=0}else{k8();Da=c[m>>2]|0}P=j+2508|0;c[P>>2]=2;x=j+2512|0;c[x>>2]=1;v=j+2504|0;c[v>>2]=1;M=(Da|0)!=0?2:3;R=j+2516|0;c[R>>2]=M;y=j+2520|0;c[y>>2]=7;if((c[s>>2]|0)<0){Ea=2;Fa=1;Ga=1;Ha=M;Ia=7;Ja=Da}else{M=0;do{c[k+2564+(M<<2)>>2]=4;M=M+1|0;}while((M|0)<=(c[s>>2]|0));Ea=c[P>>2]|0;Fa=c[x>>2]|0;Ga=c[v>>2]|0;Ha=c[R>>2]|0;Ia=c[y>>2]|0;Ja=c[m>>2]|0}c[j+2560>>2]=40;M=c[t>>2]|0;c[j+2536>>2]=(d[1274872+Ea|0]|0)>>>(M>>>0);c[j+2540>>2]=(d[1275968+Fa|0]|0)>>>(M>>>0);c[j+2532>>2]=e[1274864+(Ga<<1)>>1]|0;c[j+2544>>2]=e[1276456+(Ha<<1)>>1]|0;c[j+2548>>2]=b[1275832+(Ia<<1)>>1]|0;c[j+2552>>2]=0;c[j+2556>>2]=0;M=(Ja|0)==0;if(M){Ka=(c[1419032+(c[j+2392>>2]<<2)>>2]|0)+65|0;La=c[T>>2]|0}else{J=c[T>>2]|0;if((c[j+2740>>2]|0)==0){D=c[w>>2]|0;Ma=ba(J<<1,D)|0;Na=D}else{D=c[w>>2]|0;Ma=D*5|0;Na=D}D=Ma+((J|0)==6?66:65)+((c[r>>2]|0)==0?0:J)|0;if((c[j+2328>>2]|0)==3){Oa=D+(Na*5|0)|0}else{Oa=D+1|0}Ka=Oa+((J|0)==1?10:11)|0;La=J}if((La|0)>0){J=M&1^1;D=0;ca=Ka;Z=Ja;while(1){do{if(M){S=(Z|0)==0;aa=c[w>>2]<<1;_=(S?1:2)+ca+aa|0;if(!S){Pa=_;Qa=Z;break}Pa=aa+((D|0)==0?12:1)+_+((c[r>>2]|0)!=0)|0;Qa=0}else{Pa=ca+2|0;Qa=Z}}while(0);_=Pa+J|0;aa=M?_+2|0:_;_=D+1|0;if((_|0)<(La|0)){D=_;ca=aa;Z=Qa}else{Ra=aa;break}}}else{Ra=Ka}c[j+2620>>2]=Ra+18;Z=re[c[j+2964>>2]&4095](k)|0;e:do{if((Z|0)==0){ca=c[l>>2]|0;D=c[s>>2]|0;M=D+1|0;J=ba(M,c[T>>2]|0)|0;r=J<<8;if((re[c[j+2968>>2]&4095](k)|0)!=0){Sa=-12;break}w=WDb(r)|0;c[j+2640>>2]=w;t=(r|0)==0;if(!((w|0)!=0|t)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}w=WDb(r)|0;c[j+2644>>2]=w;if(!((w|0)!=0|t)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}w=J<<10;y=cEb(w)|0;R=j+2648|0;c[R>>2]=y;v=(w|0)==0;if(!((y|0)!=0|v)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}y=WDb(r)|0;r=j+2656|0;c[r>>2]=y;if(!((y|0)!=0|t)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}t=J<<7;y=WDb(t)|0;x=j+2660|0;c[x>>2]=y;P=(t|0)==0;if(!((y|0)!=0|P)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}y=J<<9;aa=WDb(y)|0;_=j+2664|0;c[_>>2]=aa;S=(y|0)==0;if(!((aa|0)!=0|S)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}aa=WDb(t)|0;$=j+2668|0;c[$>>2]=aa;if(!((aa|0)!=0|P)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}aa=WDb(t)|0;t=j+2672|0;c[t>>2]=aa;if(!((aa|0)!=0|P)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}P=WDb(y)|0;y=j+2676|0;c[y>>2]=P;if(!((P|0)!=0|S)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}do{if((c[Q>>2]|0)!=0){S=J<<4;P=WDb(S)|0;c[j+2680>>2]=P;aa=(S|0)==0;if(!((P|0)!=0|aa)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}P=WDb(S)|0;c[j+2684>>2]=P;if((P|0)!=0|aa){break}yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}}while(0);J=c[T>>2]|0;f:do{if((J|0)>0){aa=M<<2;P=(aa|0)==0;S=(M|0)>0;ma=j+2680|0;Ta=j+2684|0;Ua=0;while(1){Va=cEb(aa)|0;Wa=k+1536+(Ua<<7)|0;c[Wa>>2]=Va;if(!((Va|0)!=0|P)){C=153;break}Va=cEb(aa)|0;Xa=k+1536+(Ua<<7)+8|0;c[Xa>>2]=Va;if(!((Va|0)!=0|P)){C=155;break}Va=cEb(aa)|0;Ya=k+1536+(Ua<<7)+12|0;c[Ya>>2]=Va;if(!((Va|0)!=0|P)){C=157;break}Va=cEb(aa)|0;Za=k+1536+(Ua<<7)+16|0;c[Za>>2]=Va;if(!((Va|0)!=0|P)){C=159;break}Va=cEb(aa)|0;_a=k+1536+(Ua<<7)+20|0;c[_a>>2]=Va;if(!((Va|0)!=0|P)){C=161;break}Va=cEb(aa)|0;$a=k+1536+(Ua<<7)+24|0;c[$a>>2]=Va;if(!((Va|0)!=0|P)){C=163;break}Va=cEb(aa)|0;ab=k+1536+(Ua<<7)+28|0;c[ab>>2]=Va;if(!((Va|0)!=0|P)){C=165;break}if((c[Q>>2]|0)!=0){Va=cEb(aa)|0;c[k+1536+(Ua<<7)+32>>2]=Va;if(!((Va|0)!=0|P)){C=171;break}Va=cEb(aa)|0;c[k+1536+(Ua<<7)+36>>2]=Va;if(!((Va|0)!=0|P)){C=173;break}}if(S){Va=ba(Ua,M)|0;bb=k+1536+(Ua<<7)+32|0;cb=k+1536+(Ua<<7)+36|0;db=(c[Q>>2]|0)==0;eb=0;while(1){fb=eb+Va|0;c[(c[Ya>>2]|0)+(eb<<2)>>2]=(c[x>>2]|0)+(fb<<7);gb=fb<<8;c[(c[Za>>2]|0)+(eb<<2)>>2]=(c[_>>2]|0)+(gb<<1);hb=fb<<6;c[(c[_a>>2]|0)+(eb<<2)>>2]=(c[$>>2]|0)+(hb<<1);c[(c[$a>>2]|0)+(eb<<2)>>2]=(c[t>>2]|0)+(hb<<1);c[(c[ab>>2]|0)+(eb<<2)>>2]=(c[y>>2]|0)+(gb<<1);if(!db){gb=fb<<4;c[(c[bb>>2]|0)+(eb<<2)>>2]=(c[ma>>2]|0)+gb;c[(c[cb>>2]|0)+(eb<<2)>>2]=(c[Ta>>2]|0)+gb}gb=c[T>>2]|0;fb=(ba(gb,eb)|0)+Ua<<8;c[(c[Xa>>2]|0)+(eb<<2)>>2]=(c[r>>2]|0)+fb;c[(c[Wa>>2]|0)+(eb<<2)>>2]=(c[R>>2]|0)+(fb<<2);fb=eb+1|0;if((fb|0)<(M|0)){eb=fb}else{ib=gb;break}}}else{ib=c[T>>2]|0}eb=Ua+1|0;if((eb|0)<(ib|0)){Ua=eb}else{jb=ib;break f}}if((C|0)==153){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((C|0)==155){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((C|0)==157){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((C|0)==159){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((C|0)==161){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((C|0)==163){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((C|0)==165){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((C|0)==171){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((C|0)==173){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}}else{jb=J}}while(0);g:do{if((c[I>>2]|0)==0){J=cEb(w)|0;R=j+2652|0;c[R>>2]=J;if(!((J|0)!=0|v)){yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}if((c[T>>2]|0)<=0){break}J=M<<2;r=(J|0)==0;y=(M|0)>0;t=(D|0)>0;$=0;while(1){_=cEb(J)|0;x=_;Ua=k+1536+($<<7)+4|0;c[Ua>>2]=x;if(!((_|0)!=0|r)){break}_=c[T>>2]|0;do{if(y){c[x>>2]=(c[R>>2]|0)+($<<8<<2);if(t){kb=1}else{break}do{Ta=(ba(kb,_)|0)+$<<8;c[(c[Ua>>2]|0)+(kb<<2)>>2]=(c[R>>2]|0)+(Ta<<2);kb=kb+1|0;}while((kb|0)<(M|0))}}while(0);$=$+1|0;if(($|0)>=(_|0)){break g}}yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else{if((jb|0)<=0){break}$=M<<2;R=($|0)==0;t=(M|0)>0;y=(D|0)>0;r=0;while(1){J=cEb($)|0;Ua=J;x=k+1536+(r<<7)+4|0;c[x>>2]=Ua;if(!((J|0)!=0|R)){break}do{if(t){J=k+1536+(r<<7)|0;c[Ua>>2]=c[c[J>>2]>>2];if(y){lb=1}else{break}do{c[(c[x>>2]|0)+(lb<<2)>>2]=c[(c[J>>2]|0)+(lb<<2)>>2];lb=lb+1|0;}while((lb|0)<(M|0))}}while(0);r=r+1|0;if((r|0)>=(c[T>>2]|0)){break g}}yDb(ca,16,2348272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}}while(0);Z3(j+136|0,f);ca=f+88|0;fCb(j+1380|0,c[ca>>2]&8388608);Nfb(j+1416|0,c[ca>>2]&8388608);H=0;i=g;return H|0}else{Sa=Z}}while(0);igb(f)|0;H=Sa;i=g;return H|0}}while(0);yDb(n,16,2303720,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;H=-22;i=g;return H|0}function kgb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;d=b+112|0;e=c[d>>2]|0;f=b+116|0;g=c[f>>2]|0;if((g|0)>16){h=g-16|0;i=e<<16|2935}else{j=fe(2935>>>((16-g|0)>>>0)|e<<g|0)|0;e=b+124|0;k=c[e>>2]|0;x=j;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[e>>2]=(c[e>>2]|0)+4;h=g+16|0;i=2935}c[d>>2]=i;c[f>>2]=h;if((h|0)>16){l=h-16|0;m=i<<16}else{g=fe(i<<h|0)|0;i=b+124|0;e=c[i>>2]|0;x=g;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;l=h+16|0;m=0}c[d>>2]=m;c[f>>2]=l;h=c[b+2524>>2]|0;if((l|0)>2){n=l-2|0;o=m<<2|h}else{i=fe(m<<l|h>>>((2-l|0)>>>0)|0)|0;m=b+124|0;e=c[m>>2]|0;x=i;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;n=l+30|0;o=h}c[d>>2]=o;c[f>>2]=n;h=(((c[b+2340>>2]|0)-(c[b+2336>>2]|0)|0)/2|0)+(c[b+2344>>2]|0)|0;if((n|0)>6){p=n-6|0;q=o<<6|h}else{l=fe(h>>>((6-n|0)>>>0)|o<<n|0)|0;o=b+124|0;m=c[o>>2]|0;x=l;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[o>>2]=(c[o>>2]|0)+4;p=n+26|0;q=h}c[d>>2]=q;c[f>>2]=p;h=b+2312|0;n=c[h>>2]|0;if((p|0)>5){r=p-5|0;s=q<<5|n}else{o=fe(q<<p|n>>>((5-p|0)>>>0)|0)|0;q=b+124|0;m=c[q>>2]|0;x=o;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;r=p+27|0;s=n}c[d>>2]=s;c[f>>2]=r;n=c[b+2316>>2]|0;if((r|0)>3){t=r-3|0;u=s<<3|n}else{p=fe(s<<r|n>>>((3-r|0)>>>0)|0)|0;s=b+124|0;q=c[s>>2]|0;x=p;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;t=r+29|0;u=n}c[d>>2]=u;c[f>>2]=t;n=b+2392|0;r=c[n>>2]|0;if((t|0)>3){v=t-3|0;w=u<<3|r;y=r}else{s=fe(u<<t|r>>>((3-t|0)>>>0)|0)|0;u=b+124|0;q=c[u>>2]|0;x=s;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;v=t+29|0;w=r;y=c[n>>2]|0}c[d>>2]=w;c[f>>2]=v;if((y&1|0)==0|(y|0)==1){z=y;A=w;B=v}else{r=c[b+2400>>2]|0;if((v|0)>2){C=v-2|0;D=w<<2|r;E=y}else{y=fe(w<<v|r>>>((2-v|0)>>>0)|0)|0;w=b+124|0;t=c[w>>2]|0;x=y;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;C=v+30|0;D=r;E=c[n>>2]|0}c[d>>2]=D;c[f>>2]=C;z=E;A=D;B=C}if((z&4|0)==0){F=z;G=A;H=B}else{C=c[b+2404>>2]|0;if((B|0)>2){I=B-2|0;J=A<<2|C;K=z}else{z=fe(C>>>((2-B|0)>>>0)|A<<B|0)|0;A=b+124|0;D=c[A>>2]|0;x=z;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;I=B+30|0;J=C;K=c[n>>2]|0}c[d>>2]=J;c[f>>2]=I;F=K;G=J;H=I}if((F|0)==2){F=c[b+20>>2]|0;if((H|0)>2){L=H-2|0;M=G<<2|F}else{I=fe(F>>>((2-H|0)>>>0)|G<<H|0)|0;J=b+124|0;K=c[J>>2]|0;x=I;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[J>>2]=(c[J>>2]|0)+4;L=H+30|0;M=F}c[d>>2]=M;c[f>>2]=L;N=L;O=M}else{N=H;O=G}G=c[b+2376>>2]|0;if((N|0)>1){P=N-1|0;Q=O<<1|G}else{H=fe(O<<N|G>>>((1-N|0)>>>0)|0)|0;O=b+124|0;M=c[O>>2]|0;x=H;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[O>>2]=(c[O>>2]|0)+4;P=N+31|0;Q=G}c[d>>2]=Q;c[f>>2]=P;G=-(c[b+4>>2]|0)|0;if((P|0)>5){R=P-5|0;S=Q<<5|G}else{N=fe(Q<<P|G>>>((5-P|0)>>>0)|0)|0;Q=b+124|0;O=c[Q>>2]|0;x=N;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[Q>>2]=(c[Q>>2]|0)+4;R=P+27|0;S=G}c[d>>2]=S;c[f>>2]=R;if((R|0)>1){T=R-1|0;U=S<<1}else{G=fe(S<<R|0)|0;S=b+124|0;P=c[S>>2]|0;x=G;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[S>>2]=(c[S>>2]|0)+4;T=R+31|0;U=0}c[d>>2]=U;c[f>>2]=T;if((T|0)>1){V=T-1|0;W=U<<1}else{R=fe(U<<T|0)|0;U=b+124|0;S=c[U>>2]|0;x=R;a[S]=x;x=x>>8;a[S+1|0]=x;x=x>>8;a[S+2|0]=x;x=x>>8;a[S+3|0]=x;c[U>>2]=(c[U>>2]|0)+4;V=T+31|0;W=0}c[d>>2]=W;c[f>>2]=V;T=b+24|0;U=c[T>>2]|0;if((V|0)>1){X=V-1|0;Y=W<<1|U;Z=U}else{S=fe(W<<V|U>>>((1-V|0)>>>0)|0)|0;W=b+124|0;R=c[W>>2]|0;x=S;a[R]=x;x=x>>8;a[R+1|0]=x;x=x>>8;a[R+2|0]=x;x=x>>8;a[R+3|0]=x;c[W>>2]=(c[W>>2]|0)+4;X=V+31|0;Y=U;Z=c[T>>2]|0}c[d>>2]=Y;c[f>>2]=X;if((Z|0)==0){_=X;$=Y}else{Z=(c[b+28>>2]|0)-80|0;if((X|0)>5){aa=X-5|0;ba=Y<<5|Z}else{T=fe(Z>>>((5-X|0)>>>0)|Y<<X|0)|0;Y=b+124|0;U=c[Y>>2]|0;x=T;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;c[Y>>2]=(c[Y>>2]|0)+4;aa=X+27|0;ba=Z}c[d>>2]=ba;c[f>>2]=aa;Z=c[b+32>>2]|0;if((aa|0)>2){ca=aa-2|0;da=ba<<2|Z}else{X=fe(ba<<aa|Z>>>((2-aa|0)>>>0)|0)|0;ba=b+124|0;Y=c[ba>>2]|0;x=X;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;c[ba>>2]=(c[ba>>2]|0)+4;ca=aa+30|0;da=Z}c[d>>2]=da;c[f>>2]=ca;_=ca;$=da}da=c[b+36>>2]|0;if((_|0)>1){ea=_-1|0;fa=$<<1|da}else{ca=fe($<<_|da>>>((1-_|0)>>>0)|0)|0;$=b+124|0;Z=c[$>>2]|0;x=ca;a[Z]=x;x=x>>8;a[Z+1|0]=x;x=x>>8;a[Z+2|0]=x;x=x>>8;a[Z+3|0]=x;c[$>>2]=(c[$>>2]|0)+4;ea=_+31|0;fa=da}c[d>>2]=fa;c[f>>2]=ea;da=c[b+40>>2]|0;if((ea|0)>1){ga=ea-1|0;ha=fa<<1|da}else{_=fe(fa<<ea|da>>>((1-ea|0)>>>0)|0)|0;fa=b+124|0;$=c[fa>>2]|0;x=_;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;c[fa>>2]=(c[fa>>2]|0)+4;ga=ea+31|0;ha=da}c[d>>2]=ha;c[f>>2]=ga;do{if((c[h>>2]|0)==6){da=b+44|0;ea=c[da>>2]|0;if((ga|0)>1){ia=ga-1|0;ja=ha<<1|ea;ka=ea}else{fa=fe(ha<<ga|ea>>>((1-ga|0)>>>0)|0)|0;$=b+124|0;_=c[$>>2]|0;x=fa;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;c[$>>2]=(c[$>>2]|0)+4;ia=ga+31|0;ja=ea;ka=c[da>>2]|0}c[d>>2]=ja;c[f>>2]=ia;if((ka|0)==0){la=ia;ma=ja}else{da=c[b+48>>2]|0;if((ia|0)>2){na=ia-2|0;oa=ja<<2|da}else{ea=fe(ja<<ia|da>>>((2-ia|0)>>>0)|0)|0;$=b+124|0;_=c[$>>2]|0;x=ea;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;c[$>>2]=(c[$>>2]|0)+4;na=ia+30|0;oa=da}c[d>>2]=oa;c[f>>2]=na;da=c[b+2408>>2]|0;if((na|0)>3){pa=na-3|0;qa=oa<<3|da}else{$=fe(oa<<na|da>>>((3-na|0)>>>0)|0)|0;_=b+124|0;ea=c[_>>2]|0;x=$;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;c[_>>2]=(c[_>>2]|0)+4;pa=na+29|0;qa=da}c[d>>2]=qa;c[f>>2]=pa;da=c[b+2412>>2]|0;if((pa|0)>3){ra=pa-3|0;sa=qa<<3|da}else{_=fe(qa<<pa|da>>>((3-pa|0)>>>0)|0)|0;ea=b+124|0;$=c[ea>>2]|0;x=_;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;c[ea>>2]=(c[ea>>2]|0)+4;ra=pa+29|0;sa=da}c[d>>2]=sa;c[f>>2]=ra;da=c[b+2416>>2]|0;if((ra|0)>3){ta=ra-3|0;ua=sa<<3|da}else{ea=fe(sa<<ra|da>>>((3-ra|0)>>>0)|0)|0;$=b+124|0;_=c[$>>2]|0;x=ea;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;c[$>>2]=(c[$>>2]|0)+4;ta=ra+29|0;ua=da}c[d>>2]=ua;c[f>>2]=ta;da=c[b+2420>>2]|0;if((ta|0)>3){va=ta-3|0;wa=ua<<3|da}else{$=fe(ua<<ta|da>>>((3-ta|0)>>>0)|0)|0;_=b+124|0;ea=c[_>>2]|0;x=$;a[ea]=x;x=x>>8;a[ea+1|0]=x;x=x>>8;a[ea+2|0]=x;x=x>>8;a[ea+3|0]=x;c[_>>2]=(c[_>>2]|0)+4;va=ta+29|0;wa=da}c[d>>2]=wa;c[f>>2]=va;la=va;ma=wa}da=b+68|0;_=c[da>>2]|0;if((la|0)>1){xa=la-1|0;ya=ma<<1|_;za=_}else{ea=fe(ma<<la|_>>>((1-la|0)>>>0)|0)|0;$=b+124|0;fa=c[$>>2]|0;x=ea;a[fa]=x;x=x>>8;a[fa+1|0]=x;x=x>>8;a[fa+2|0]=x;x=x>>8;a[fa+3|0]=x;c[$>>2]=(c[$>>2]|0)+4;xa=la+31|0;ya=_;za=c[da>>2]|0}c[d>>2]=ya;c[f>>2]=xa;if((za|0)==0){Aa=xa;Ba=ya;break}da=c[b+72>>2]|0;if((xa|0)>2){Ca=xa-2|0;Da=ya<<2|da}else{_=fe(ya<<xa|da>>>((2-xa|0)>>>0)|0)|0;$=b+124|0;fa=c[$>>2]|0;x=_;a[fa]=x;x=x>>8;a[fa+1|0]=x;x=x>>8;a[fa+2|0]=x;x=x>>8;a[fa+3|0]=x;c[$>>2]=(c[$>>2]|0)+4;Ca=xa+30|0;Da=da}c[d>>2]=Da;c[f>>2]=Ca;da=c[b+76>>2]|0;if((Ca|0)>2){Ea=Ca-2|0;Fa=Da<<2|da}else{$=fe(Da<<Ca|da>>>((2-Ca|0)>>>0)|0)|0;fa=b+124|0;_=c[fa>>2]|0;x=$;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;c[fa>>2]=(c[fa>>2]|0)+4;Ea=Ca+30|0;Fa=da}c[d>>2]=Fa;c[f>>2]=Ea;da=c[b+80>>2]|0;if((Ea|0)>1){Ga=Ea-1|0;Ha=Fa<<1|da}else{fa=fe(Fa<<Ea|da>>>((1-Ea|0)>>>0)|0)|0;_=b+124|0;$=c[_>>2]|0;x=fa;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;c[_>>2]=(c[_>>2]|0)+4;Ga=Ea+31|0;Ha=da}c[d>>2]=Ha;c[f>>2]=Ga;if((Ga|0)>9){Ia=Ga-9|0;Ja=Ha<<9}else{da=fe(Ha<<Ga|0)|0;_=b+124|0;$=c[_>>2]|0;x=da;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;c[_>>2]=(c[_>>2]|0)+4;Ia=Ga+23|0;Ja=0}c[d>>2]=Ja;c[f>>2]=Ia;Aa=Ia;Ba=Ja}else{if((ga|0)>1){Ka=ga-1|0;La=ha<<1}else{_=fe(ha<<ga|0)|0;$=b+124|0;da=c[$>>2]|0;x=_;a[da]=x;x=x>>8;a[da+1|0]=x;x=x>>8;a[da+2|0]=x;x=x>>8;a[da+3|0]=x;c[$>>2]=(c[$>>2]|0)+4;Ka=ga+31|0;La=0}c[d>>2]=La;c[f>>2]=Ka;if((Ka|0)>1){Ma=Ka-1|0;Na=La<<1}else{$=fe(La<<Ka|0)|0;da=b+124|0;_=c[da>>2]|0;x=$;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;c[da>>2]=(c[da>>2]|0)+4;Ma=Ka+31|0;Na=0}c[d>>2]=Na;c[f>>2]=Ma;Aa=Ma;Ba=Na}}while(0);if((Aa|0)>1){Oa=Aa-1|0;Pa=Ba<<1;c[d>>2]=Pa;c[f>>2]=Oa;return}else{Na=fe(Ba<<Aa|0)|0;Ba=b+124|0;b=c[Ba>>2]|0;x=Na;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[Ba>>2]=(c[Ba>>2]|0)+4;Oa=Aa+31|0;Pa=0;c[d>>2]=Pa;c[f>>2]=Oa;return}}function lgb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;i=i+192|0;h=g|0;j=(f<<2)-960|0;f=c[e+2640>>2]|0;if((c[e+2788>>2]|0)==(f|0)){if((c[e+2956>>2]|0)==0){k=3}}else{k=3}if((k|0)==3){k=e+2372|0;l=c[k>>2]|0;if((l|0)>=0){m=e+2332|0;n=0;o=f;f=c[m>>2]|0;p=l;while(1){if((f|0)>0){l=0;do{c[e+2788+(n*24|0)+(l<<2)>>2]=o+(d[e+2744+(n*6|0)+l|0]<<8);l=l+1|0;q=c[m>>2]|0;}while((l|0)<(q|0));r=q;s=c[k>>2]|0}else{r=f;s=p}l=n+1|0;if((l|0)>(s|0)){break}else{n=l;o=o+(r<<8)|0;f=r;p=s}}}c[e+2956>>2]=1}s=e+2332|0;p=c[s>>2]|0;r=e+2372|0;if((p|0)>0){f=e+1436|0;o=e+2548|0;n=0;k=c[r>>2]|0;q=p;while(1){m=(c[e+1536+(n<<7)+60>>2]|0)==0|0;if((m|0)>(k|0)){t=k;u=q}else{l=e+1536+(n<<7)+24|0;v=e+1536+(n<<7)+16|0;w=m;m=k;while(1){if((a[e+2688+(w*6|0)+n|0]|0)==0){x=m}else{Be[c[f>>2]&127](c[(c[l>>2]|0)+(w<<2)>>2]|0,c[(c[v>>2]|0)+(w<<2)>>2]|0,c[e+2432+(w<<2)>>2]|0,c[e+1536+(n<<7)+100+(w<<2)>>2]|0,j,c[o>>2]|0,1276664,c[e+2788+(w*24|0)+(n<<2)>>2]|0);x=c[r>>2]|0}y=w+1|0;if((y|0)>(x|0)){break}else{w=y;m=x}}t=x;u=c[s>>2]|0}m=n+1|0;if((m|0)<(u|0)){n=m;k=t;q=u}else{z=u;A=t;break}}}else{z=p;A=c[r>>2]|0}r=h|0;TGb(h|0,0,32)|0;b[h+4>>1]=2;b[h+2>>1]=2;b[h+8>>1]=1;TGb(h+32|0,0,32)|0;b[h+36>>1]=2;b[h+34>>1]=2;b[h+40>>1]=1;TGb(h+64|0,0,32)|0;b[h+68>>1]=2;b[h+66>>1]=2;b[h+72>>1]=1;TGb(h+96|0,0,32)|0;b[h+100>>1]=2;b[h+98>>1]=2;b[h+104>>1]=1;TGb(h+128|0,0,32)|0;b[h+132>>1]=2;b[h+130>>1]=2;b[h+136>>1]=1;TGb(h+160|0,0,32)|0;b[h+164>>1]=2;b[h+162>>1]=2;b[h+168>>1]=1;p=((c[e+2428>>2]|0)*3|0)+73|0;t=(c[e+2468>>2]|0)==0|0;u=e+2372|0;if((t|0)>(A|0)){B=e+1444|0;C=c[B>>2]|0;D=re[C&4095](r)|0;i=g;return D|0}A=e+1440|0;q=t;t=z;while(1){z=c[e+2432+(q<<2)>>2]|0;a:do{if((t|0)>0){if((q|0)==0){E=0;F=t}else{k=0;while(1){n=c[e+1536+(k<<7)+100+(q<<2)>>2]|0;Xe[c[A>>2]&4095](h+(k<<5)|0,(c[e+2788+(q*24|0)+(k<<2)>>2]|0)+z|0,((n|0)<(p|0)?n:p)-z|0);n=c[s>>2]|0;x=k+1|0;if((x|0)<(n|0)){k=x}else{G=n;break a}}}while(1){if((c[e+1536+(E<<7)+60>>2]|0)==0){H=F}else{k=c[e+1536+(E<<7)+100>>2]|0;Xe[c[A>>2]&4095](h+(E<<5)|0,(c[e+2788+(E<<2)>>2]|0)+z|0,((k|0)<(p|0)?k:p)-z|0);H=c[s>>2]|0}k=E+1|0;if((k|0)<(H|0)){E=k;F=H}else{G=H;break}}}else{G=t}}while(0);z=q+1|0;if((z|0)>(c[u>>2]|0)){break}else{q=z;t=G}}B=e+1444|0;C=c[B>>2]|0;D=re[C&4095](r)|0;i=g;return D|0}function mgb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=WDb(1024)|0;c[a+2632>>2]=d;if((d|0)==0){yDb(c[a+108>>2]|0,16,2187488,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}d=a+2372|0;g=WDb(c[d>>2]<<2)|0;h=a+2636|0;c[h>>2]=g;do{if((g|0)==0){if((c[d>>2]&1073741823|0)==0){j=0;break}yDb(c[a+108>>2]|0,16,2187488,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}else{j=0}}while(0);while(1){if((j|0)>=(c[d>>2]|0)){f=0;k=10;break}g=cEb(3584)|0;c[(c[h>>2]|0)+(j<<2)>>2]=g;if((c[(c[h>>2]|0)+(j<<2)>>2]|0)==0){break}j=j+1|0}if((k|0)==10){i=b;return f|0}yDb(c[a+108>>2]|0,16,2187488,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}function ngb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;h=i;i=i+8104|0;j=h|0;k=h+32|0;l=h+2720|0;m=h+8096|0;n=c[b+60>>2]|0;o=n;do{if((c[n+92>>2]|0)!=0){p=hgb(o)|0;if((p|0)==0){break}else{q=p}i=h;return q|0}}while(0);if((c[n+2524>>2]|0)==1){r=5}else{if((c[n+2308>>2]|0)!=0){r=5}}if((r|0)==5){$fb(o)}r=c[f+64>>2]|0;p=n+2372|0;s=c[p>>2]|0;do{if((s|0)>0){t=n+2636|0;u=n+2332|0;v=n+2396|0;w=0;do{x=c[(c[t>>2]|0)+(w<<2)>>2]|0;UGb(x|0,x+(c[u>>2]<<8<<1)|0,512)|0;UGb((c[(c[t>>2]|0)+(w<<2)>>2]|0)+512|0,c[r+(d[(c[v>>2]|0)+w|0]<<2)>>2]|0,c[u>>2]<<9)|0;w=w+1|0;y=c[p>>2]|0;}while((w|0)<(y|0));if((y|0)<=0){z=y;break}w=n+1464|0;v=n+2632|0;x=n+1532|0;A=n+2304|0;B=n+1468|0;C=n+1520|0;D=n+1420|0;E=n+1424|0;G=0;H=c[u>>2]|0;I=y;while(1){J=G+1|0;if((H|0)>0){K=0;do{cf[c[w>>2]&1023](c[v>>2]|0,(c[(c[t>>2]|0)+(G<<2)>>2]|0)+(K<<8<<1)|0,c[x>>2]|0,512);if((c[A>>2]|0)!=0){L=Oe[c[D>>2]&1023](c[v>>2]|0,512)|0;M=L>>>0>65535>>>0;N=M?L>>>16:L;L=M?16:0;if((N&65280|0)==0){O=L;P=N}else{O=L|8;P=N>>>8}N=14-O-(d[1191992+P|0]|0)|0;if((N|0)>0){Xe[c[E>>2]&4095](c[v>>2]|0,512,N)}a[o+1536+(K<<7)+40+J|0]=N+6}Xe[c[C>>2]&4095](B,c[(c[o+1536+(K<<7)>>2]|0)+(J<<2)>>2]|0,c[v>>2]|0);K=K+1|0;Q=c[u>>2]|0;}while((K|0)<(Q|0));R=Q;S=c[p>>2]|0}else{R=H;S=I}if((J|0)<(S|0)){G=J;H=R;I=S}else{z=S;break}}}else{z=s}}while(0);s=n+2304|0;S=n+2332|0;R=c[S>>2]|0;if((c[s>>2]|0)!=0&(R|0)>0){Q=n+1428|0;P=0;O=z;y=R;r=z;while(1){if((O|0)<1){T=O;U=y;V=r}else{I=o+1536+(P<<7)|0;H=1;do{Xe[c[Q>>2]&4095](c[(c[I>>2]|0)+(H<<2)>>2]|0,256,d[o+1536+(P<<7)+40+H|0]|0);H=H+1|0;W=c[p>>2]|0;}while((H|0)<=(W|0));T=W;U=c[S>>2]|0;V=W}H=P+1|0;if((H|0)<(U|0)){P=H;O=T;y=U;r=V}else{X=V;Y=U;break}}}else{X=z;Y=R}R=c[(c[n+1536>>2]|0)+4>>2]|0;z=n+2332|0;U=ba(Y<<8,X)|0;X=n+1368|0;le[c[X>>2]&1023](R,R,-16777215,16777215,U);U=n+2464|0;c[U>>2]=c[n+2468>>2];agb(o);do{if((c[U>>2]|0)!=0){TGb(l|0,0,5376)|0;TGb(k|0,0,2688)|0;R=n+2432|0;Y=c[R>>2]|0;V=((c[n+2472>>2]|0)*12|0|1)+31&-32;r=Y-1+V|0;y=((r|0)<256?r:256)-V|0;r=c[z>>2]|0;if((r|0)>0){T=V<<2;O=n+2368|0;P=(V|0)<1;W=0;S=r;while(1){Q=o+1536+(W<<7)|0;H=c[c[Q>>2]>>2]|0;I=H+(y<<2)|0;if((c[o+1536+(W<<7)+60>>2]|0)==0){Z=S}else{TGb(I|0,0,T|0)|0;G=c[O>>2]|0;if((G|0)>=1){u=c[Q>>2]|0;Q=1;v=G;while(1){G=c[u+(Q<<2)>>2]|0;if((a[o+1536+(W<<7)+64+Q|0]|0)==0|P){_=v}else{B=0;do{C=B+y|0;E=H+(C<<2)|0;c[E>>2]=(c[E>>2]|0)+(c[G+(C<<2)>>2]|0);B=B+1|0;}while((B|0)<(V|0));_=c[O>>2]|0}B=Q+1|0;if((B|0)>(_|0)){break}else{Q=B;v=_}}}le[c[X>>2]&1023](I,I,-16777215,16777215,V);Z=c[z>>2]|0}v=W+1|0;if((v|0)<(Z|0)){W=v;S=Z}else{break}}$=c[R>>2]|0;aa=Z}else{$=Y;aa=r}S=c[n+2460>>2]|0;if(($|0)<(S|0)){W=c[n+2368>>2]|0;V=(W|0)<0;O=(aa|0)>0;y=$;P=0;while(1){T=a[o+2480+P|0]|0;v=T&255;if(!V){Q=T<<24>>24!=0;T=0;do{a:do{if(O){if((T|0)<=0){if(Q){ca=0}else{break}while(1){if((c[o+1536+(ca<<7)+60>>2]|0)!=0){H=c[(c[o+1536+(ca<<7)>>2]|0)+(T<<2)>>2]|0;u=l+(ca*896|0)+(T<<7)+(P<<3)|0;J=0;B=c[u+4>>2]|0;G=c[u>>2]|0;do{C=c[H+(J+y<<2)>>2]|0;E=C;D=(C|0)<0|0?-1:0;C=gHb(E,D,E,D)|0;G=YGb(C,F,G,B)|0;B=F;J=J+1|0;}while((J|0)<(v|0));c[u>>2]=G;c[u+4>>2]=B}ca=ca+1|0;if((ca|0)>=(aa|0)){break a}}}if(Q){da=0}else{break}do{do{if((c[o+1536+(da<<7)+60>>2]|0)!=0){if((a[o+1536+(da<<7)+64+T|0]|0)==0){break}J=c[(c[o+1536+(da<<7)>>2]|0)+(T<<2)>>2]|0;H=l+(da*896|0)+(T<<7)+(P<<3)|0;C=0;D=c[H+4>>2]|0;E=c[H>>2]|0;do{A=c[J+(C+y<<2)>>2]|0;x=A;t=(A|0)<0|0?-1:0;A=gHb(x,t,x,t)|0;E=YGb(A,F,E,D)|0;D=F;C=C+1|0;}while((C|0)<(v|0));c[H>>2]=E;c[H+4>>2]=D}}while(0);da=da+1|0;}while((da|0)<(aa|0))}}while(0);T=T+1|0;}while((T|0)<=(W|0))}T=v+y|0;if((T|0)<(S|0)){y=T;P=P+1|0}else{break}}}if((aa|0)>0){P=n+2368|0;y=n+2476|0;S=0;while(1){do{if((c[o+1536+(S<<7)+60>>2]|0)!=0){W=c[P>>2]|0;if((W|0)<1){break}else{ea=1}do{do{if((a[o+1536+(S<<7)+64+ea|0]|0)!=0){O=c[y>>2]|0;if((O|0)>0){fa=0}else{break}do{V=l+(S*896|0)+(ea<<7)+(fa<<3)|0;r=l+(S*896|0)+(fa<<3)|0;c[k+(S*448|0)+(ea<<6)+(fa<<2)>>2]=rgb(c[V>>2]|0,c[V+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0)|0;fa=fa+1|0;}while((fa|0)<(O|0))}}while(0);ea=ea+1|0;}while((ea|0)<=(W|0))}}while(0);v=S+1|0;if((v|0)<(aa|0)){S=v}else{ga=0;break}}while(1){S=(ga|0)==0;if(S){ha=0}else{ha=o+1536+(ga-1<<7)|0}TGb(o+1536+(ga<<7)+76|0,0,7)|0;b:do{if((c[o+1536+(ga<<7)+60>>2]|0)!=0){do{if(!S){if((c[ha+60>>2]|0)==0){break}if((c[P>>2]|0)<1){break b}v=ga-1|0;W=1;while(1){do{if((a[o+1536+(ga<<7)+64+W|0]|0)!=0){if((a[ha+64+W|0]|0)==0){a[o+1536+(ga<<7)+76+W|0]=1;break}O=c[y>>2]|0;if((O|0)>0){r=0;V=0;Y=0;while(1){R=(c[k+(v*448|0)+(W<<6)+(Y<<2)>>2]|0)-(c[k+(ga*448|0)+(W<<6)+(Y<<2)>>2]|0)|0;T=(R|0)>-1?R:-R|0;R=YGb(T,(T|0)<0|0?-1:0,V,r)|0;T=F;Q=Y+1|0;if((Q|0)<(O|0)){r=T;V=R;Y=Q}else{ia=T;ja=R;break}}}else{ia=0;ja=0}Y=eHb(ja,ia,O,(O|0)<0|0?-1:0)|0;V=F;r=0;if(!((V|0)>(r|0)|(V|0)==(r|0)&Y>>>0>503317>>>0)){break}a[o+1536+(ga<<7)+76+W|0]=1}}while(0);W=W+1|0;if((W|0)>(c[P>>2]|0)){break b}}}}while(0);if((c[P>>2]|0)<1){break}else{ka=1}do{a[o+1536+(ga<<7)+76+ka|0]=1;ka=ka+1|0;}while((ka|0)<=(c[P>>2]|0))}}while(0);S=ga+1|0;W=c[z>>2]|0;if((S|0)<(W|0)){ga=S}else{la=W;ma=y;break}}}else{la=aa;ma=n+2476|0}y=c[ma>>2]|0;if((y|0)>0){P=n+2368|0;W=0;S=0;while(1){v=0;Y=W;c:while(1){r=v;while(1){if((r|0)>=(la|0)){break c}if((c[o+1536+(r<<7)+60>>2]|0)==0){r=r+1|0;continue}na=c[P>>2]|0;if((na|0)<1){r=Y}else{break}}V=l+(r*896|0)+(S<<3)|0;D=Y;H=1;while(1){if((a[o+1536+(r<<7)+64+H|0]|0)==0){oa=D}else{E=l+(r*896|0)+(H<<7)+(S<<3)|0;R=c[V+4>>2]|0;T=c[V>>2]|0;Q=c[E+4>>2]|0;I=c[E>>2]|0;E=r;d:while(1){pa=E;do{pa=pa+1|0;if(!((a[o+1536+(pa<<7)+76+H|0]|0)==0&(pa|0)<(la|0))){break d}}while((c[o+1536+(pa<<7)+60>>2]|0)==0);B=l+(pa*896|0)+(S<<3)|0;u=YGb(c[B>>2]|0,c[B+4>>2]|0,T,R)|0;B=F;G=l+(pa*896|0)+(H<<7)+(S<<3)|0;C=YGb(c[G>>2]|0,c[G+4>>2]|0,I,Q)|0;R=B;T=u;Q=F;I=C;E=pa}c[k+(r*448|0)+(H<<6)+(S<<2)>>2]=rgb(I,Q,T,R)|0;oa=pa}E=H+1|0;if((E|0)>(na|0)){v=oa;Y=oa;continue c}else{D=oa;H=E}}}v=S+1|0;if((v|0)<(y|0)){W=Y;S=v}else{break}}}if((la|0)>0){S=n+1448|0;W=n+2368|0;y=0;P=la;while(1){if((c[o+1536+(y<<7)+60>>2]|0)==0){qa=P}else{v=o+1536+(y<<7)+32|0;Xe[c[S>>2]&4095](c[(c[v>>2]|0)+4>>2]|0,k+(y*448|0)+64|0,c[W>>2]<<4);H=c[W>>2]|0;if((H|0)>=1){D=o+1536+(y<<7)+36|0;r=1;V=H;while(1){if((a[o+1536+(y<<7)+76+r|0]|0)==0){ra=V}else{H=c[(c[v>>2]|0)+(r<<2)>>2]|0;E=a[H]|0;C=E&255;u=c[ma>>2]|0;if((u|0)>1){B=1;G=C;J=C;while(1){A=d[H+B|0]|0;t=(A|0)>(G|0)?G:A;x=(A|0)>(J|0)?A:J;A=B+1|0;if((A|0)<(u|0)){B=A;G=t;J=x}else{sa=t;ta=x;break}}}else{sa=C;ta=C}J=(ta-13|0)/3|0;G=(J|0)>0?J:0;while(1){ua=G*3|0;if((sa|0)<(ua|0)){G=G-1|0}else{break}}e:do{if((u|0)>0){C=0;J=H;B=E;while(1){x=(B&255)-ua|0;if((x|0)<0){va=0}else{va=(x|0)>15?15:x&255}a[J+C|0]=va;x=C+1|0;if((x|0)>=(c[ma>>2]|0)){break e}t=c[(c[v>>2]|0)+(r<<2)>>2]|0;C=x;J=t;B=a[t+x|0]|0}}}while(0);a[o+1536+(y<<7)+83+r|0]=G;if((c[ma>>2]|0)>0){E=ua+5|0;H=0;do{u=a[(c[(c[v>>2]|0)+(r<<2)>>2]|0)+H|0]|0;B=c[k+(y*448|0)+(r<<6)+(H<<2)>>2]<<E+(u&255)>>24;a[(c[(c[D>>2]|0)+(r<<2)>>2]|0)+H|0]=u<<24>>24==15?B>>>1:B+240|0;H=H+1|0;}while((H|0)<(c[ma>>2]|0))}ra=c[W>>2]|0}H=r+1|0;if((H|0)>(ra|0)){break}else{r=H;V=ra}}}qa=c[z>>2]|0}V=y+1|0;if((V|0)<(qa|0)){y=V;P=qa}else{break}}}if((c[n+2308>>2]|0)==0){break}m8(o)}}while(0);do{if((c[n+2392>>2]|0)==2){qa=c[z>>2]|0;if((qa|0)<=0){break}ra=n+2500|0;ma=j|0;k=n+1452|0;ua=j+16|0;va=j+24|0;sa=j+8|0;ta=n+2432|0;la=a[1274888]|0;oa=0;na=0;pa=qa;while(1){qa=o+1536+(na<<7)|0;l=(na|0)!=0;aa=o+1536+(na<<7)+47|0;a[aa]=l&1^1;ga=o+1536+(na<<7)+48|0;c[ga>>2]=4;do{if((c[o+1536+(na<<7)+60>>2]|0)==0){wa=4}else{ka=c[ta>>2]|0;ia=4-((ka|0)<62)-((ka|0)==37)|0;c[ga>>2]=ia;if(!l){wa=ia;break}if((ia|0)==(c[oa+48>>2]|0)){wa=ia;break}a[aa]=1;wa=ia}}while(0);ia=c[o+1536+(na<<7)+104>>2]|0;ka=c[o+1536+(na<<7)+108>>2]|0;ja=(ia|0)>(ka|0)?ka:ia;if((c[ra>>2]|0)!=0&(wa|0)>0){ia=qa|0;ka=0;ha=la;while(1){ea=ha&255;fa=ka+1|0;da=a[1274888+fa|0]|0;ca=da&255;$=c[ia>>2]|0;cf[c[k>>2]&1023](ma,(c[$+4>>2]|0)+(ea<<2)|0,(c[$+8>>2]|0)+(ea<<2)|0,((ja|0)>(ca|0)?ca:ja)-ea|0);ea=c[ua>>2]|0;ca=c[ua+4>>2]|0;$=c[va>>2]|0;Z=c[va+4>>2]|0;X=(ca|0)>(Z|0)|(ca|0)==(Z|0)&ea>>>0>$>>>0;_=X?Z:ca;ca=c[ma>>2]|0;Z=c[ma+4>>2]|0;U=c[sa>>2]|0;P=c[sa+4>>2]|0;y=(Z|0)>(P|0)|(Z|0)==(P|0)&ca>>>0>U>>>0;W=y?P:Z;Z=((_|0)<(W|0)|(_|0)==(W|0)&(X?$:ea)>>>0<(y?U:ca)>>>0)&1;a[o+1536+(na<<7)+52+ka|0]=Z;do{if(l){if(Z<<24>>24==(a[oa+52+ka|0]|0)){break}a[aa]=1}}while(0);if((fa|0)<(c[ga>>2]|0)){ka=fa;ha=da}else{break}}xa=c[z>>2]|0}else{xa=pa}ha=na+1|0;if((ha|0)<(xa|0)){oa=qa;na=ha;pa=xa}else{break}}}}while(0);do{if((c[s>>2]|0)==0){xa=c[z>>2]|0;if((xa|0)<=0){break}wa=n+1428|0;j=0;pa=c[p>>2]|0;na=xa;while(1){if((pa|0)<1){ya=pa;za=na}else{xa=o+1536+(j<<7)|0;oa=1;do{Xe[c[wa>>2]&4095](c[(c[xa>>2]|0)+(oa<<2)>>2]|0,256,d[o+1536+(j<<7)+40+oa|0]|0);oa=oa+1|0;Aa=c[p>>2]|0;}while((oa|0)<=(Aa|0));ya=Aa;za=c[z>>2]|0}oa=j+1|0;if((oa|0)<(za|0)){j=oa;pa=ya;na=za}else{break}}}}while(0);bgb(o);dgb(o);za=egb(o)|0;if((za|0)!=0){yDb(b,16,2308120,(ya=i,i=i+1|0,i=i+7&-8,c[ya>>2]=0,ya)|0);i=ya;q=za;i=h;return q|0}cgb(o);fgb(o);za=c[n+2340>>2]|0;n=r0a(b,e,za,(za|0)<0|0?-1:0)|0;if((n|0)<0){q=n;i=h;return q|0}ggb(o,c[e+24>>2]|0);o=f+136|0;f=c[o>>2]|0;n=c[o+4>>2]|0;if(!((f|0)==0&(n|0)==(-2147483648|0))){o=c[b+116>>2]|0;c[m>>2]=1;c[m+4>>2]=c[b+412>>2];za=KDb(o,(o|0)<0|0?-1:0,m,b+104|0)|0;b=ZGb(f,n,za,F)|0;za=e+8|0;c[za>>2]=b;c[za+4>>2]=F}c[g>>2]=1;q=0;i=h;return q|0}function ogb(a){a=a|0;_lb(a+1468|0);return}function pgb(a){a=a|0;var b=0;b=Zlb(a+1468|0,9,0,-1.0)|0;c[a+1532>>2]=1274248;return b|0}function qgb(a){a=a|0;c[(c[a+60>>2]|0)+2304>>2]=1;return jgb(a)|0}function rgb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=0;if((f|0)<(g|0)|(f|0)==(g|0)&e>>>0<16777216>>>0){h=1048576;return h|0}g=eHb(a,b,e>>>24|f<<8,f>>24|((f|0)<0|0?-1:0)<<8)|0;f=F;e=0;b=f>>>0>e>>>0|f>>>0==e>>>0&g>>>0>1073741824>>>0?1073741824:g;if(b>>>0<255>>>0){i=(d[b+1135649|0]|0)-1>>4}else{do{if(b>>>0<4096>>>0){j=(d[1135648+(b>>>4)|0]|0)>>>2}else{if(b>>>0<16384>>>0){j=(d[1135648+(b>>>6)|0]|0)>>>1;break}if(b>>>0<65536>>>0){j=d[1135648+(b>>>8)|0]|0;break}else{g=b>>>16;e=(g&65280|0)==0;f=((d[1191992+(e?g:b>>>24)|0]|0)+(e?0:8)|0)>>>1;e=b>>>((f+2|0)>>>0);g=d[1135648+(e>>>((f+8|0)>>>0))|0]|0;gHb(e,0,c[1199552+(g<<2)>>2]|0,0)|0;j=F+(g<<f)|0;break}}}while(0);i=j-((ba(j,j)|0)>>>0>b>>>0)|0}b=i<<9;h=b>>>0>16777215>>>0?16777215:b;return h|0}function sgb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=WDb(2048)|0;c[a+2632>>2]=d;if((d|0)==0){yDb(c[a+108>>2]|0,16,2186432,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}d=a+2372|0;g=WDb(c[d>>2]<<2)|0;h=a+2636|0;c[h>>2]=g;do{if((g|0)==0){if((c[d>>2]&1073741823|0)==0){j=0;break}yDb(c[a+108>>2]|0,16,2186432,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}else{j=0}}while(0);while(1){if((j|0)>=(c[d>>2]|0)){f=0;k=10;break}g=cEb(7168)|0;c[(c[h>>2]|0)+(j<<2)>>2]=g;if((c[(c[h>>2]|0)+(j<<2)>>2]|0)==0){break}j=j+1|0}if((k|0)==10){i=b;return f|0}yDb(c[a+108>>2]|0,16,2186432,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}function tgb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0.0,Y=0.0,Z=0,_=0.0,$=0,aa=0,ca=0.0,da=0,ea=0,fa=0.0,ga=0.0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0.0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;j=i;i=i+8088|0;k=j|0;l=j+16|0;m=j+2704|0;n=j+5392|0;o=j+8080|0;p=c[b+60>>2]|0;q=p;do{if((c[p+92>>2]|0)!=0){r=hgb(q)|0;if((r|0)==0){break}else{s=r}i=j;return s|0}}while(0);if((c[p+2524>>2]|0)==1){t=5}else{if((c[p+2308>>2]|0)!=0){t=5}}if((t|0)==5){$fb(q)}t=c[f+64>>2]|0;r=p+2372|0;u=c[r>>2]|0;do{if((u|0)>0){v=p+2636|0;w=p+2332|0;x=p+2396|0;y=0;do{z=c[(c[v>>2]|0)+(y<<2)>>2]|0;UGb(z|0,z+(c[w>>2]<<8<<2)|0,1024)|0;UGb((c[(c[v>>2]|0)+(y<<2)>>2]|0)+1024|0,c[t+(d[(c[x>>2]|0)+y|0]<<2)>>2]|0,c[w>>2]<<10)|0;y=y+1|0;A=c[r>>2]|0;}while((y|0)<(A|0));if((A|0)<=0){B=A;break}y=p+1380|0;x=p+2632|0;z=p+1532|0;C=p+2304|0;D=p+1468|0;E=p+1520|0;G=0;H=c[w>>2]|0;I=A;while(1){J=G+1|0;if((H|0)>0){K=0;do{cf[c[y>>2]&1023](c[x>>2]|0,(c[(c[v>>2]|0)+(G<<2)>>2]|0)+(K<<8<<2)|0,c[z>>2]|0,512);if((c[C>>2]|0)!=0){a[q+1536+(K<<7)+40+J|0]=0}Xe[c[E>>2]&4095](D,c[(c[q+1536+(K<<7)>>2]|0)+(J<<2)>>2]|0,c[x>>2]|0);K=K+1|0;L=c[w>>2]|0;}while((K|0)<(L|0));M=L;N=c[r>>2]|0}else{M=H;N=I}if((J|0)<(N|0)){G=J;H=M;I=N}else{B=N;break}}}else{B=u}}while(0);u=p+2304|0;N=p+2332|0;if((c[u>>2]|0)==0){O=B;P=p+2464|0}else{M=c[N>>2]<<8;L=p+2464|0;A=c[L>>2]|0;t=M&-((A|0)==0|0);I=ba(B+A|0,M)|0;Xe[c[p+1432>>2]&4095]((c[p+2652>>2]|0)+(t<<2)|0,(c[p+2648>>2]|0)+(t<<2)|0,I);O=c[r>>2]|0;P=L}L=c[(c[p+1536>>2]|0)+4>>2]|0;I=ba(c[N>>2]<<8,O)|0;O=p+1240|0;af[c[O>>2]&3](L,L,-.9999999403953552,.9999999403953552,I);c[P>>2]=c[p+2468>>2];agb(q);do{if((c[P>>2]|0)!=0){TGb(n|0,0,2688)|0;TGb(l|0,0,2688)|0;TGb(m|0,0,2688)|0;I=p+2432|0;L=c[I>>2]|0;t=((c[p+2472>>2]|0)*12|0|1)+31&-32;M=L-1+t|0;A=((M|0)<256?M:256)-t|0;M=c[N>>2]|0;if((M|0)>0){B=t<<2;H=p+2368|0;G=(t|0)<1;w=0;x=M;while(1){D=q+1536+(w<<7)|0;E=c[c[D>>2]>>2]|0;C=E+(A<<2)|0;if((c[q+1536+(w<<7)+60>>2]|0)==0){Q=x}else{TGb(C|0,0,B|0)|0;z=c[H>>2]|0;if((z|0)>=1){v=c[D>>2]|0;D=1;do{y=c[v+(D<<2)>>2]|0;if(!((a[q+1536+(w<<7)+64+D|0]|0)==0|G)){K=0;do{S=K+A|0;T=E+(S<<2)|0;g[T>>2]=+g[y+(S<<2)>>2]+ +g[T>>2];K=K+1|0;}while((K|0)<(t|0))}D=D+1|0;}while((D|0)<=(z|0))}af[c[O>>2]&3](C,C,-.9999999403953552,.9999999403953552,t);Q=c[N>>2]|0}z=w+1|0;if((z|0)<(Q|0)){w=z;x=Q}else{break}}U=c[I>>2]|0;V=Q}else{U=L;V=M}x=c[p+2460>>2]|0;if((U|0)<(x|0)){w=c[p+2368>>2]|0;t=(w|0)<0;A=(V|0)>0;G=U;H=0;while(1){B=a[q+2480+H|0]|0;z=B&255;if(!t){D=B<<24>>24!=0;B=0;do{a:do{if(A){if((B|0)<=0){if(D){W=0}else{break}while(1){if((c[q+1536+(W<<7)+60>>2]|0)!=0){E=c[(c[q+1536+(W<<7)>>2]|0)+(B<<2)>>2]|0;v=n+(W*448|0)+(B<<6)+(H<<2)|0;J=0;X=+g[v>>2];do{Y=+g[E+(J+G<<2)>>2];X=X+Y*Y;J=J+1|0;}while((J|0)<(z|0));g[v>>2]=X}W=W+1|0;if((W|0)>=(V|0)){break a}}}if(D){Z=0}else{break}do{do{if((c[q+1536+(Z<<7)+60>>2]|0)!=0){if((a[q+1536+(Z<<7)+64+B|0]|0)==0){break}J=c[(c[q+1536+(Z<<7)>>2]|0)+(B<<2)>>2]|0;E=n+(Z*448|0)+(B<<6)+(H<<2)|0;K=0;Y=+g[E>>2];do{_=+g[J+(K+G<<2)>>2];Y=Y+_*_;K=K+1|0;}while((K|0)<(z|0));g[E>>2]=Y}}while(0);Z=Z+1|0;}while((Z|0)<(V|0))}}while(0);B=B+1|0;}while((B|0)<=(w|0))}B=z+G|0;if((B|0)<(x|0)){G=B;H=H+1|0}else{break}}}if((V|0)>0){H=p+2368|0;G=p+2476|0;x=0;while(1){do{if((c[q+1536+(x<<7)+60>>2]|0)!=0){w=c[H>>2]|0;if((w|0)<1){break}else{$=1}do{do{if((a[q+1536+(x<<7)+64+$|0]|0)!=0){A=c[G>>2]|0;if((A|0)>0){aa=0}else{break}do{X=+g[n+(x*448|0)+(aa<<2)>>2];if(X>0.0){ca=+R(+g[n+(x*448|0)+($<<6)+(aa<<2)>>2]/X)*.125}else{ca=.125}g[l+(x*448|0)+($<<6)+(aa<<2)>>2]=ca>.9999999403953552?.9999999403953552:ca;aa=aa+1|0;}while((aa|0)<(A|0))}}while(0);$=$+1|0;}while(($|0)<=(w|0))}}while(0);z=x+1|0;if((z|0)<(V|0)){x=z}else{da=0;break}}while(1){x=(da|0)==0;if(x){ea=0}else{ea=q+1536+(da-1<<7)|0}TGb(q+1536+(da<<7)+76|0,0,7)|0;b:do{if((c[q+1536+(da<<7)+60>>2]|0)!=0){do{if(!x){if((c[ea+60>>2]|0)==0){break}if((c[H>>2]|0)<1){break b}z=da-1|0;w=1;while(1){do{if((a[q+1536+(da<<7)+64+w|0]|0)!=0){if((a[ea+64+w|0]|0)==0){a[q+1536+(da<<7)+76+w|0]=1;break}A=c[G>>2]|0;if((A|0)>0){X=0.0;t=0;while(1){_=+g[l+(z*448|0)+(w<<6)+(t<<2)>>2]- +g[l+(da*448|0)+(w<<6)+(t<<2)>>2];if(_<0.0){fa=-0.0-_}else{fa=_}_=X+fa;M=t+1|0;if((M|0)<(A|0)){X=_;t=M}else{ga=_;break}}}else{ga=0.0}if(!(ga/+(A|0)>.03)){break}a[q+1536+(da<<7)+76+w|0]=1}}while(0);w=w+1|0;if((w|0)>(c[H>>2]|0)){break b}}}}while(0);if((c[H>>2]|0)<1){break}else{ha=1}do{a[q+1536+(da<<7)+76+ha|0]=1;ha=ha+1|0;}while((ha|0)<=(c[H>>2]|0))}}while(0);x=da+1|0;w=c[N>>2]|0;if((x|0)<(w|0)){da=x}else{ia=w;ja=G;break}}}else{ia=V;ja=p+2476|0}G=c[ja>>2]|0;if((G|0)>0){H=p+2368|0;w=0;x=0;while(1){z=0;t=w;c:while(1){E=z;while(1){if((E|0)>=(ia|0)){break c}if((c[q+1536+(E<<7)+60>>2]|0)==0){E=E+1|0;continue}ka=c[H>>2]|0;if((ka|0)<1){E=t}else{break}}M=n+(E*448|0)+(x<<2)|0;L=t;I=1;while(1){if((a[q+1536+(E<<7)+64+I|0]|0)==0){la=L}else{X=+g[M>>2];Y=+g[n+(E*448|0)+(I<<6)+(x<<2)>>2];B=E;d:while(1){ma=B;do{ma=ma+1|0;if(!((a[q+1536+(ma<<7)+76+I|0]|0)==0&(ma|0)<(ia|0))){break d}}while((c[q+1536+(ma<<7)+60>>2]|0)==0);X=X+ +g[n+(ma*448|0)+(x<<2)>>2];Y=Y+ +g[n+(ma*448|0)+(I<<6)+(x<<2)>>2];B=ma}if(X>0.0){na=+R(Y/X)*.125}else{na=.125}g[l+(E*448|0)+(I<<6)+(x<<2)>>2]=na>.9999999403953552?.9999999403953552:na;la=ma}B=I+1|0;if((B|0)>(ka|0)){z=la;t=la;continue c}else{L=la;I=B}}}z=x+1|0;if((z|0)<(G|0)){w=t;x=z}else{break}}}if((ia|0)>0){x=p+1432|0;w=p+2368|0;G=p+1448|0;H=0;z=ia;while(1){if((c[q+1536+(H<<7)+60>>2]|0)==0){oa=z}else{I=m+(H*448|0)+64|0;Xe[c[x>>2]&4095](I,l+(H*448|0)+64|0,c[w>>2]<<4);L=q+1536+(H<<7)+32|0;Xe[c[G>>2]&4095](c[(c[L>>2]|0)+4>>2]|0,I,c[w>>2]<<4);I=c[w>>2]|0;if((I|0)>=1){E=q+1536+(H<<7)+36|0;M=1;B=I;while(1){if((a[q+1536+(H<<7)+76+M|0]|0)==0){pa=B}else{I=c[(c[L>>2]|0)+(M<<2)>>2]|0;D=a[I]|0;C=D&255;v=c[ja>>2]|0;if((v|0)>1){K=1;J=C;y=C;while(1){T=d[I+K|0]|0;S=(T|0)>(J|0)?J:T;qa=(T|0)>(y|0)?T:y;T=K+1|0;if((T|0)<(v|0)){K=T;J=S;y=qa}else{ra=S;sa=qa;break}}}else{ra=C;sa=C}y=(sa-13|0)/3|0;J=(y|0)>0?y:0;while(1){ta=J*3|0;if((ra|0)<(ta|0)){J=J-1|0}else{break}}e:do{if((v|0)>0){C=0;y=I;K=D;while(1){qa=(K&255)-ta|0;if((qa|0)<0){ua=0}else{ua=(qa|0)>15?15:qa&255}a[y+C|0]=ua;qa=C+1|0;if((qa|0)>=(c[ja>>2]|0)){break e}S=c[(c[L>>2]|0)+(M<<2)>>2]|0;C=qa;y=S;K=a[S+qa|0]|0}}}while(0);a[q+1536+(H<<7)+83+M|0]=J;if((c[ja>>2]|0)>0){D=ta+5|0;I=0;do{v=a[(c[(c[L>>2]|0)+(M<<2)>>2]|0)+I|0]|0;K=c[m+(H*448|0)+(M<<6)+(I<<2)>>2]<<D+(v&255)>>24;a[(c[(c[E>>2]|0)+(M<<2)>>2]|0)+I|0]=v<<24>>24==15?K>>>1:K+240|0;I=I+1|0;}while((I|0)<(c[ja>>2]|0))}pa=c[w>>2]|0}I=M+1|0;if((I|0)>(pa|0)){break}else{M=I;B=pa}}}oa=c[N>>2]|0}B=H+1|0;if((B|0)<(oa|0)){H=B;z=oa}else{break}}}if((c[p+2308>>2]|0)==0){break}m8(q)}}while(0);do{if((c[p+2392>>2]|0)==2){oa=c[N>>2]|0;if((oa|0)<=0){break}pa=p+2500|0;ja=k|0;m=p+1456|0;ta=k+8|0;ua=k+12|0;ra=k+4|0;sa=p+2432|0;l=a[1274888]|0;ia=0;la=0;ka=oa;while(1){oa=q+1536+(la<<7)|0;ma=(la|0)!=0;n=q+1536+(la<<7)+47|0;a[n]=ma&1^1;V=q+1536+(la<<7)+48|0;c[V>>2]=4;do{if((c[q+1536+(la<<7)+60>>2]|0)==0){va=4}else{da=c[sa>>2]|0;ha=4-((da|0)<62)-((da|0)==37)|0;c[V>>2]=ha;if(!ma){va=ha;break}if((ha|0)==(c[ia+48>>2]|0)){va=ha;break}a[n]=1;va=ha}}while(0);ha=c[q+1536+(la<<7)+104>>2]|0;da=c[q+1536+(la<<7)+108>>2]|0;ea=(ha|0)>(da|0)?da:ha;if((c[pa>>2]|0)!=0&(va|0)>0){ha=oa|0;da=0;$=l;while(1){aa=$&255;Z=da+1|0;W=a[1274888+Z|0]|0;U=W&255;Q=c[ha>>2]|0;cf[c[m>>2]&1023](ja,(c[Q+4>>2]|0)+(aa<<2)|0,(c[Q+8>>2]|0)+(aa<<2)|0,((ea|0)>(U|0)?U:ea)-aa|0);na=+g[ta>>2];ga=+g[ua>>2];fa=+g[ja>>2];ca=+g[ra>>2];aa=(na>ga?ga:na)<(fa>ca?ca:fa)|0;a[q+1536+(la<<7)+52+da|0]=aa;do{if(ma){if(aa<<24>>24==(a[ia+52+da|0]|0)){break}a[n]=1}}while(0);if((Z|0)<(c[V>>2]|0)){da=Z;$=W}else{break}}wa=c[N>>2]|0}else{wa=ka}$=la+1|0;if(($|0)<(wa|0)){ia=oa;la=$;ka=wa}else{break}}}}while(0);if((c[u>>2]|0)==0){u=c[N>>2]<<8;N=c[P>>2]|0;P=u&-((N|0)==0|0);wa=ba((c[r>>2]|0)+N|0,u)|0;Xe[c[p+1432>>2]&4095]((c[p+2652>>2]|0)+(P<<2)|0,(c[p+2648>>2]|0)+(P<<2)|0,wa)}bgb(q);dgb(q);wa=egb(q)|0;if((wa|0)!=0){yDb(b,16,2307528,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;s=wa;i=j;return s|0}cgb(q);fgb(q);wa=c[p+2340>>2]|0;p=r0a(b,e,wa,(wa|0)<0|0?-1:0)|0;if((p|0)<0){s=p;i=j;return s|0}ggb(q,c[e+24>>2]|0);q=f+136|0;f=c[q>>2]|0;p=c[q+4>>2]|0;if(!((f|0)==0&(p|0)==(-2147483648|0))){q=c[b+116>>2]|0;c[o>>2]=1;c[o+4>>2]=c[b+412>>2];wa=KDb(q,(q|0)<0|0?-1:0,o,b+104|0)|0;b=ZGb(f,p,wa,F)|0;wa=e+8|0;c[wa>>2]=b;c[wa+4>>2]=F}c[h>>2]=1;s=0;i=j;return s|0}function ugb(a){a=a|0;bLa(a+1468|0);$Db(a+1532|0);return}function vgb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=WDb(2048)|0;e=d;if((d|0)==0){yDb(c[a+108>>2]|0,16,2186432,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;f=-12;i=b;return f|0}Slb(e,5.0,256);d=0;do{g[e+(511-d<<2)>>2]=+g[e+(d<<2)>>2];d=d+1|0;}while((d|0)<256);c[a+1532>>2]=e;f=aLa(a+1468|0,9,0,-.00390625)|0;i=b;return f|0}function wgb(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;if((j|0)<=0){i=k;return}if((h|0)>0){l=0}else{m=0;do{b[a+(m<<1)>>1]=0;m=m+1|0;}while((m|0)<(j|0));i=k;return}do{m=0;n=0;o=16384;do{p=(ba(b[e+(n+g<<1)>>1]|0,b[d+(m+l<<1)>>1]|0)|0)+o|0;n=n+f|0;m=m+1|0;o=p+(ba(b[e+(n-g<<1)>>1]|0,b[d+(l-m<<1)>>1]|0)|0)|0;}while((m|0)<(h|0));m=o>>15;n=m&65535;if((m+32768|0)>>>0>65535>>>0){q=(o>>31^32767)&65535}else{q=n}if((q<<16>>16|0)!=(m|0)){yDb(0,24,2185248,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}b[a+(l<<1)>>1]=n;l=l+1|0;}while((l|0)<(j|0));i=k;return}function xgb(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0.0,m=0,n=0,o=0.0;if((h|0)<=0){return}if((f|0)>0){i=0}else{TGb(a|0,0,h<<2|0)|0;return}do{j=0;k=0;l=0.0;while(1){m=k+d|0;n=j+1|0;o=l+ +g[b+(j+i<<2)>>2]*+g[c+(k+e<<2)>>2]+ +g[b+(i-n<<2)>>2]*+g[c+(m-e<<2)>>2];if((n|0)<(f|0)){j=n;k=m;l=o}else{break}}g[a+(i<<2)>>2]=o;i=i+1|0;}while((i|0)<(h|0));return}function ygb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f|0)<=0){return}g=d+4|0;h=0;i=c[d>>2]|0;j=c[g>>2]|0;while(1){k=gHb(i,(i|0)<0|0?-1:0,15836,0)|0;l=F;m=gHb(j,(j|0)<0|0?-1:0,-7667,-1)|0;n=F;o=YGb(m>>>13|n<<19,n>>>13|0<<19,k>>>13|l<<19,l>>>13|0<<19)|0;p=(((b[e+(h<<1)>>1]|0)-(b[e+(h-1<<1)>>1]<<1)+(b[e+(h-2<<1)>>1]|0)|0)*7699|0)+o|0;o=p+2048|0;l=o>>12;if((l+32768|0)>>>0>65535>>>0){q=(o>>31^32767)&65535}else{q=l&65535}b[a+(h<<1)>>1]=q;l=h+1|0;if((l|0)<(f|0)){h=l;j=i;i=p}else{break}}c[d>>2]=p;c[g>>2]=i;return}function zgb(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0.0,q=0;if((h|0)<=0){return}i=d+4|0;j=f+4|0;k=c+4|0;l=0;m=+g[f>>2];n=+g[j>>2];while(1){o=+g[b+(l<<2)>>2]*e- +g[d>>2]*m- +g[i>>2]*n;g[a+(l<<2)>>2]=o+m*+g[c>>2]+n*+g[k>>2];p=+g[f>>2];g[j>>2]=p;g[f>>2]=o;q=l+1|0;if((q|0)<(h|0)){l=q;m=o;n=p}else{break}}return}function Agb(a,b,c,d){a=a|0;b=+b;c=c|0;d=d|0;var e=0,f=0.0,h=0.0,i=0.0;e=d-1|0;f=+g[c+(e<<2)>>2];if((e|0)>0){d=e;h=f;while(1){e=d-1|0;i=+g[c+(e<<2)>>2];g[c+(d<<2)>>2]=h-i*b;if((e|0)>0){d=e;h=i}else{break}}}g[c>>2]=+g[c>>2]- +g[a>>2]*b;g[a>>2]=f;return}function Bgb(a){a=a|0;c[a>>2]=210;c[a+4>>2]=2;return}function Cgb(a){a=a|0;var b=0,c=0;b=a+58|0;if((b|0)<=254){c=b;return c|0}c=(b*3|0)-510|0;return c|0}function Dgb(a,b){a=a|0;b=b|0;var c=0;if((a|0)<4){c=(b+a|0)*3|0;return c|0}if((a|0)<12){c=a+6+(b*3|0)|0;return c|0}else{c=((b+a|0)*3|0)-18|0;return c|0}return 0}function Egb(a,b){a=a|0;b=b|0;return a-2+(b*3|0)|0}function Fgb(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(1<<d)-1|0;g=b[a+(f<<1)>>1]|0;if((f|0)>0){h=f;f=g;while(1){i=h-1|0;j=b[a+(i<<1)>>1]|0;k=(j<<16>>16)+f|0;b[a+(h<<1)>>1]=j;if((i|0)>0){h=i;f=k}else{l=k;break}}}else{l=g}if((e|0)==0){m=((((B$(c)|0)>>2)*6165|0)+417193984|0)>>>13&65535;b[a>>1]=m;return}c=l>>d;if(!((c|0)>-10240)){m=-14336;b[a>>1]=m;return}m=c+61440&65535;b[a>>1]=m;return}function Ggb(a,d,e,f,g,h,i,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0.0;k=f<<10;if((j|0)>0){f=k;l=0;while(1){m=(ba(b[h+(l<<1)>>1]|0,b[g+(l<<1)>>1]|0)|0)+f|0;n=l+1|0;if((n|0)<(j|0)){f=m;l=n}else{o=m;break}}}else{o=k}p=+(d|0)*+_(+(o|0)*1.3724476653301989e-8);return~~(p/+R(+(ze[c[a+1224>>2]&511](e,e,i)|0)))>>>12&65535|0}function Hgb(a,b,c,d,e){a=+a;b=+b;c=c|0;d=+d;e=e|0;var f=0.0;f=+Wc(+((+eCb(e,c,4)+d)*.16609640474436813))*a/+R(b);VGb(c|0,c+4|0,12)|0;g[c+12>>2]=+ad(+a)*20.0;return+f}function Igb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)==0){i=3}else if((f|0)==2){if((g|0)==0){i=6}else{i=3}}else{i=6}do{if((i|0)==3){if((d|0)<197){j=d+59|0;break}else{j=(d*3|0)-335|0;break}}else if((i|0)==6){if((h|0)==4){g=e-5|0;if((g|0)<20){k=20}else{k=(g|0)>134?134:g}if((d|0)<4){j=((k+d|0)*3|0)+1|0;break}if((d|0)<12){j=d+7+(k*3|0)|0;break}else{j=((k+d|0)*3|0)-17|0;break}}else{g=d-1|0;if((h|0)==5){f=e-10|0;if((f|0)<20){l=60}else{l=(f|0)>124?372:f*3|0}j=l+g|0;break}else{f=e-5|0;if((f|0)<20){m=60}else{m=(f|0)>134?402:f*3|0}j=m+g|0;break}}}}while(0);m=(j*10923|0)>>15;c[a>>2]=m;c[b>>2]=j-1+(m*-3|0);return}function Jgb(a,c,f,g,h,i,j){a=a|0;c=c|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=(1<<j)-1|0;l=(h&1|0)!=0?8191:-8192;if((i|0)>0){m=h;h=g;n=0;o=l;while(1){p=a+((d[c+(h&k)|0]|0)+n<<1)|0;b[p>>1]=(e[p>>1]|0)+o;p=h>>j;q=m>>1;r=n+1|0;s=(q&1|0)!=0?8191:-8192;if((r|0)<(i|0)){m=q;h=p;n=r;o=s}else{t=p;u=s;break}}}else{t=g;u=l}l=a+((d[f+t|0]|0)<<1)|0;b[l>>1]=(e[l>>1]|0)+u;return}function Kgb(a,e,f,h,i){a=a|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0;j=1<<i;i=j-1|0;c[e+84>>2]=0;c[e>>2]=h<<1;if((h|0)>0){k=0}else{return}do{l=k<<1;m=l|1;n=b[a+(m<<1)>>1]|0;o=(d[f+(n&i)|0]|0)+k|0;p=(d[f+(b[a+(l<<1)>>1]&i)|0]|0)+k|0;q=(n&j|0)!=0?-1.0:1.0;c[e+4+(m<<2)>>2]=o;c[e+4+(l<<2)>>2]=p;g[e+44+(m<<2)>>2]=q;if((p|0)<(o|0)){r=-0.0-q}else{r=q}g[e+44+(l<<2)>>2]=r;k=k+1|0;}while((k|0)<(h|0));return}function Lgb(a,c,d,e,f,g,h,i){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((i|0)<=0){return}j=e<<16>>16;e=f<<16>>16;f=g<<16>>16;g=0;do{k=ba(b[c+(g<<1)>>1]|0,j)|0;l=k+f+(ba(b[d+(g<<1)>>1]|0,e)|0)>>h;if((l+32768|0)>>>0>65535>>>0){m=(l>>31^32767)&65535}else{m=l&65535}b[a+(g<<1)>>1]=m;g=g+1|0;}while((g|0)<(i|0));return}function Mgb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=+d;e=+e;f=f|0;var h=0;if((f|0)>0){h=0}else{return}do{g[a+(h<<2)>>2]=+g[b+(h<<2)>>2]*d+ +g[c+(h<<2)>>2]*e;h=h+1|0;}while((h|0)<(f|0));return}function Ngb(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=d|0;e=+e;f=f|0;var h=0.0,i=0.0,j=0.0,k=0,l=0.0,m=0.0,n=0;h=+eCb(b,b,d);i=+g[f>>2];if(h!=0.0){j=+R(c/h)}else{j=1.0}h=(1.0-e)*j;if((d|0)>0){k=0;l=i}else{m=i;g[f>>2]=m;return}while(1){i=h+l*e;g[a+(k<<2)>>2]=i*+g[b+(k<<2)>>2];n=k+1|0;if((n|0)<(d|0)){k=n;l=i}else{m=i;break}}g[f>>2]=m;return}function Ogb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0.0,f=0.0,h=0;e=+eCb(b,b,d);if(e!=0.0){f=+R(c/e)}else{f=e}if((d|0)>0){h=0}else{return}do{g[a+(h<<2)>>2]=f*+g[b+(h<<2)>>2];h=h+1|0;}while((h|0)<(d|0));return}function Pgb(a,b,d,e){a=a|0;b=b|0;d=+d;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0;f=c[b>>2]|0;if((f|0)<=0){return}h=b+84|0;i=b+92|0;j=c[b+88>>2]|0;k=0;do{l=c[b+4+(k<<2)>>2]|0;m=+g[b+44+(k<<2)>>2]*d;a:do{if((j|0)>0){if((c[h>>2]&1<<k|0)==0){n=m;o=l}else{p=a+(l<<2)|0;g[p>>2]=m+ +g[p>>2];break}while(1){p=a+(o<<2)|0;g[p>>2]=n+ +g[p>>2];p=j+o|0;if((p|0)>=(e|0)){break a}n=n*+g[i>>2];o=p}}}while(0);k=k+1|0;}while((k|0)<(f|0));return}function Qgb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0,k=0;e=c[b>>2]|0;if((e|0)<=0){return}f=c[b+84>>2]|0;h=c[b+88>>2]|0;if((h|0)>0){i=0}else{return}do{j=c[b+4+(i<<2)>>2]|0;if((f&1<<i|0)==0){k=j;do{g[a+(k<<2)>>2]=0.0;k=h+k|0;}while((k|0)<(d|0))}else{g[a+(j<<2)>>2]=0.0}i=i+1|0;}while((i|0)<(e|0));return}function Rgb(a){a=a|0;c[a>>2]=2;return}function Sgb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;e=c[a+60>>2]|0;f=c[(c[a+12>>2]|0)+12>>2]|0;if((f|0)==1095123744|(f|0)==69652|(f|0)==69654|(f|0)==69653|(f|0)==69657|(f|0)==69650){g=6;h=1}else if((f|0)==1146374944|(f|0)==69642){g=2;h=2}else{g=2;h=1}j=c[a+416>>2]|0;if(j>>>0<h>>>0|j>>>0>g>>>0){yDb(a,16,1926112,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;k=-22;i=b;return k|0}do{if((f|0)==69632|(f|0)==1146374944|(f|0)==69639|(f|0)==69640|(f|0)==69652|(f|0)==69654|(f|0)==69653|(f|0)==69657|(f|0)==69650|(f|0)==1095123744){l=15}else if((f|0)==69644){c[e+44>>2]=511;c[e+8>>2]=511;l=17}else if((f|0)==69636){g=c[a+96>>2]|0;do{if((g|0)!=0){if((c[a+100>>2]|0)<=1){break}j=g;c[e+216>>2]=(d[j]|d[j+1|0]<<8)<<16>>16&65535}}while(0);c[a+420>>2]=(c[e+216>>2]|0)==3?6:1;k=0;i=b;return k|0}else if((f|0)==69661){g=c[a+96>>2]|0;if((g|0)==0){l=17;break}if((c[a+100>>2]|0)<=7){l=17;break}j=g;c[e>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=g+4|0;c[e+36>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;l=17}else if((f|0)==69633){if(((c[a+792>>2]|0)-2|0)>>>0>3>>>0){k=-1094995529}else{l=15;break}i=b;return k|0}else{l=17}}while(0);if((l|0)==15){c[a+420>>2]=6;k=0;i=b;return k|0}else if((l|0)==17){c[a+420>>2]=1;k=0;i=b;return k|0}return 0}function Tgb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,ee=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0;j=i;i=i+496|0;k=j|0;l=j+8|0;m=j+24|0;n=j+32|0;o=j+40|0;p=j+64|0;q=j+96|0;r=j+112|0;s=c[h+24>>2]|0;t=h+28|0;h=c[t>>2]|0;u=e+60|0;v=c[u>>2]|0;if(!((h|0)>-1)){yDb(0,0,1931480,(w=i,i=i+24|0,c[w>>2]=1929608,c[w+8>>2]=1927808,c[w+16>>2]=135,w)|0);i=w;Cd();return 0}x=s+h|0;y=e+416|0;z=c[y>>2]|0;a:do{if((z|0)>=1){A=e+12|0;B=c[(c[A>>2]|0)+12>>2]|0;do{if((B|0)==69652){C=19}else if((B|0)==69632){if((z*34|0|0)>(h|0)){break a}else{D=0;E=0;F=s;G=64}}else if((B|0)==69647){C=42}else if((B|0)==69648){C=41}else if((B|0)==69649){H=4;C=43}else if((B|0)==69638){C=38}else if((B|0)==69644|(B|0)==69661|(B|0)==69655|(B|0)==1330333984|(B|0)==69636|(B|0)==69646){I=(h<<1|0)/(z|0)|0;if((I|0)!=0){J=I;K=s;L=0;M=0;C=57;break}if((B|0)==69652){C=19}else if((B|0)==69647){C=42}else if((B|0)==69648){C=41}else if((B|0)==69649){H=4;C=43}else if((B|0)==69638){C=38}else if((B|0)==69653){C=23}else if((B|0)==69642){C=12}else if((B|0)==69645){C=44}else if((B|0)==69650){C=48}else if((B|0)==69640){C=54}else if((B|0)==1146374944){C=55}else if((B|0)==69658){C=18}else if((B|0)==69656){C=15}else if((B|0)==69651){N=8;C=10}else if((B|0)==1095123744){C=53}else if((B|0)==69639|(B|0)==69659|(B|0)==69637){C=9}else if((B|0)==69654){C=21}else{break a}}else if((B|0)==69635){C=29}else if((B|0)==69653){C=23}else if((B|0)==69642){C=12}else if((B|0)==1380008992){C=32}else if((B|0)==69645){C=44}else if((B|0)==69650){C=48}else if((B|0)==69633){C=35}else if((B|0)==69640){C=54}else if((B|0)==1146374944){C=55}else if((B|0)==69634){C=26}else if((B|0)==69658){C=18}else if((B|0)==69657){if((z*76|0|0)>(h|0)){break a}else{D=0;E=0;F=s;G=128}}else if((B|0)==69656){C=15}else if((B|0)==69651){N=8;C=10}else if((B|0)==1095123744){C=53}else if((B|0)==69639|(B|0)==69659|(B|0)==69637){C=9}else if((B|0)==69654){C=21}else{break a}}while(0);do{if((C|0)==9){I=z<<2;if((I|0)>0){N=I;C=10;break}if((B|0)==69652){C=19}else if((B|0)==69647){C=42}else if((B|0)==69648){C=41}else if((B|0)==69649){H=4;C=43}else if((B|0)==69638){C=38}else if((B|0)==69635){C=29}else if((B|0)==69653){C=23}else if((B|0)==69642){C=12}else if((B|0)==1380008992){C=32}else if((B|0)==69645){C=44}else if((B|0)==69650){C=48}else if((B|0)==69633){C=35}else if((B|0)==69640){C=54}else if((B|0)==1146374944){C=55}else if((B|0)==69634){C=26}else if((B|0)==69658){C=18}else if((B|0)==69656){C=15}else if((B|0)==1095123744){C=53}else if((B|0)==69654){C=21}else{break a}}}while(0);do{if((C|0)==10){J=(h-N<<1|0)/(z|0)|0;K=s;L=0;M=0;C=57}else if((C|0)==12){if((h|0)<4){O=0;P=s}else{B=s;O=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;P=s+4|0}Q=((h-12|0)/30|0)*28|0;R=O-((O|0)%28|0)|0;S=P;T=0;C=56}else if((C|0)==15){if((h|0)<4){U=0;V=s}else{B=s;U=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;V=s+4|0}Q=(h-(z<<3|4)<<1|0)/(z|0)|0;R=U;S=V;T=0;C=56}else if((C|0)==18){J=((h-z|0)/(z|0)|0)<<1;K=s;L=0;M=0;C=57}else if((C|0)==19){B=z*9|0;if((h|0)<4){W=B;X=s;Y=0;Z=0;C=25;break}I=s;W=B;X=s+4|0;Y=0;Z=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;C=25}else if((C|0)==21){I=z*5|0;if((h|0)<4){W=I;X=s;Y=1;Z=0;C=25;break}B=s;W=I;X=s+4|0;Y=1;Z=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;C=25}else if((C|0)==23){B=z*5|0;if((h|0)<4){W=B;X=s;Y=1;Z=0;C=25;break}I=s;W=B;X=s+4|0;Y=1;Z=fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0;C=25}else if((C|0)==26){I=c[e+432>>2]|0;if((I|0)>0){_=(I|0)<(h|0)?I:h}else{_=h}J=((((_<<1)-32|0)/3|0)<<2|0)/(z|0)|0;K=s;L=0;M=0;C=57}else if((C|0)==29){I=c[e+432>>2]|0;if((I|0)>0){$=(I|0)<(h|0)?I:h}else{$=h}J=(($-(z<<2)<<1|0)/(z|0)|0)+1|0;K=s;L=0;M=0;C=57}else if((C|0)==32){I=c[e+432>>2]|0;if((I|0)>0){aa=(I|0)<(h|0)?I:h}else{aa=h}J=(aa-(z<<2)<<1|0)/(z|0)|0;K=s;L=0;M=0;C=57}else if((C|0)==35){I=(c[e+792>>2]|0)-2|0;B=c[e+432>>2]|0;if((B|0)>0){ca=(B|0)<(h|0)?B:h}else{ca=h}J=(ba((ca-(z<<2)|0)/(ba(d[1271776+I|0]|0,z)|0)|0,d[1271784+I|0]|0)|0)+1|0;K=s;L=0;M=0;C=57}else if((C|0)==38){I=c[e+432>>2]|0;if((I|0)>0){da=(I|0)<(h|0)?I:h}else{da=h}J=((da+(z*-7|0)<<1|0)/(z|0)|0)+2|0;K=s;L=0;M=0;C=57}else if((C|0)==41){H=3;C=43}else if((C|0)==42){H=2;C=43}else if((C|0)==44){I=(h<<3)-2|0;if((h|0)<1){ea=2;fa=s}else{ea=((d[s]|0)>>>6)+2|0;fa=s+1|0}B=z*22|0;ga=ba(ea,z)|0;ha=(ga*4095|0)+B|0;ia=(I|0)/(ha|0)|0;ja=I-(ba(ha,ia)|0)|0;ha=ia<<12;if((ja|0)<(B|0)){J=ha;K=fa;L=0;M=0;C=57;break}J=((ja-B|0)/(ga|0)|0)+(ha|1)|0;K=fa;L=0;M=0;C=57}else if((C|0)==48){if((c[e+96>>2]|0)!=0){J=((h|0)/(z<<3|0)|0)*14|0;K=s;L=0;M=0;C=57;break}ha=h>>>0>4>>>0?4:h;ga=s+ha|0;if((x-ga|0)<4){ka=0;la=ga}else{B=ga;ka=fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0;la=s+(ha+4)|0}Q=((h-8+(z*-36|0)|0)/(z<<3|0)|0)*14|0;R=ka-((ka|0)%14|0)|0;S=la;T=0;C=56}else if((C|0)==53){J=((h|0)/(z*9|0|0)|0)<<4;K=s;L=0;M=0;C=57}else if((C|0)==54){J=(((h|0)/128|0)*224|0|0)/(z|0)|0;K=s;L=0;M=0;C=57}else if((C|0)==55){J=((h|0)/(z<<4|0)|0)*28|0;K=s;L=0;M=0;C=57}}while(0);if((C|0)==25){ha=(h-4-W<<1|0)/(z|0)|0;Q=ha-((ha|0)%28|0)|0;R=Z-((Z|0)%28|0)|0;S=X;T=Y;C=56}else if((C|0)==43){ha=(b[v+4>>1]|0)==0;J=(ha&1)+((ba(h-(ha?z:0)|0,H)|0)/(z|0)|0)|0;K=s;L=0;M=0;C=57}if((C|0)==56){if((R|0)<1|(R|0)>(Q|0)){break}else{J=Q;K=S;L=T;M=R;C=57}}if((C|0)==57){if((J|0)<1){break}else{D=M;E=L;F=K;G=J}}ha=f+76|0;c[ha>>2]=G;B=_$a(e,f,0)|0;if((B|0)<0){ma=B;i=j;return ma|0}B=f;ga=c[f>>2]|0;ja=ga;ia=c[f+64>>2]|0;if((D|0)==0){na=G}else{if(!((E|0)!=0|(D|0)==(G|0))){yDb(e,24,1959152,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}c[ha>>2]=D;na=D}I=c[y>>2]|0;oa=(I|0)==2;pa=oa&1;qa=c[(c[A>>2]|0)+12>>2]|0;b:do{if((qa|0)==69639){if((I|0)<=0){ra=F;break}sa=v;ta=F;ua=0;while(1){va=ta+2|0;wa=ta;c[sa+(ua*36|0)>>2]=(d[wa]|d[wa+1|0]<<8)<<16>>16<<16>>16;wa=ua+1|0;xa=c[y>>2]|0;if((wa|0)<(xa|0)){ta=va;ua=wa}else{break}}ua=(xa|0)>0;if(!ua){ra=va;break}ta=v;sa=va;wa=0;while(1){ya=sa;za=(d[ya]|d[ya+1|0]<<8)<<16>>16;b[ta+(wa*36|0)+4>>1]=za;if((za&65535)>>>0>88>>>0){C=152;break}Aa=sa+2|0;ya=wa+1|0;if((ya|0)<(xa|0)){sa=Aa;wa=ya}else{break}}if((C|0)==152){yDb(e,16,1957032,(w=i,i=i+16|0,c[w>>2]=wa,c[w+8>>2]=za<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}if(!ua){ra=Aa;break}sa=v;ta=na>>1;ya=(ta|0)>0;Ba=Aa;Ca=0;Da=xa;while(1){if(ya){Ea=sa+(Ca*36|0)+4|0;Fa=sa+(Ca*36|0)|0;Ga=Ba;Ha=c[B+(Ca<<2)>>2]|0;Ia=ta;while(1){Ja=a[Ga]|0;Ka=b[Ea>>1]|0;La=Ja&15;Ma=(a[1270408+La|0]|0)+Ka|0;if((Ma|0)<0){Na=0}else{Na=(Ma|0)>88?88:Ma&65535}Ma=(ba(La<<1&14|1,b[1269584+(Ka<<1)>>1]|0)|0)>>4;Ka=(c[Fa>>2]|0)+((La&8|0)==0?Ma:-Ma|0)|0;if((Ka+32768|0)>>>0>65535>>>0){Oa=(Ka>>31^32767)&65535}else{Oa=Ka&65535}Ka=Oa<<16>>16;c[Fa>>2]=Ka;b[Ea>>1]=Na;b[Ha>>1]=Oa;Ma=b[Ea>>1]|0;La=(Ja&255)>>>4&255;Ja=(a[1270408+La|0]|0)+Ma|0;if((Ja|0)<0){Pa=0}else{Pa=(Ja|0)>88?88:Ja&65535}Ja=(ba(b[1269584+(Ma<<1)>>1]|0,La<<1&14|1)|0)>>4;Ma=Ka+((La&8|0)==0?Ja:-Ja|0)|0;if((Ma+32768|0)>>>0>65535>>>0){Qa=(Ma>>31^32767)&65535}else{Qa=Ma&65535}c[Fa>>2]=Qa<<16>>16;b[Ea>>1]=Pa;b[Ha+2>>1]=Qa;Ma=Ia-1|0;if((Ma|0)>0){Ga=Ga+1|0;Ha=Ha+4|0;Ia=Ma}else{break}}Ra=Ba+ta|0;Sa=c[y>>2]|0}else{Ra=Ba;Sa=Da}Ia=Ca+1|0;if((Ia|0)<(Sa|0)){Ba=Ra;Ca=Ia;Da=Sa}else{ra=Ra;break}}}else if((qa|0)==69646){Da=na>>(pa^1);if((Da|0)<=0){ra=F;break}Ca=v;Ba=v+8|0;ta=v;sa=Ca+(pa*36|0)+8|0;ya=Ca+(pa*36|0)|0;Ca=F;ua=ja;wa=Da;while(1){Ia=a[Ca]|0;Ha=c[Ba>>2]|0;if((Ha|0)==0){c[ta>>2]=0;c[Ba>>2]=127;Ta=127;Ua=0}else{Ta=Ha;Ua=c[ta>>2]|0}Ha=Ia&15;Ga=((ba(a[1269048+Ha|0]|0,Ta)|0)/8|0)+Ua|0;if((Ga+32768|0)>>>0>65535>>>0){Va=(Ga>>31^32767)&65535}else{Va=Ga&65535}c[ta>>2]=Va<<16>>16;Ga=(ba(b[1268912+(Ha<<1)>>1]|0,Ta)|0)>>8;if((Ga|0)<127){Wa=127}else{Wa=(Ga|0)>24567?24567:Ga}c[Ba>>2]=Wa;b[ua>>1]=Va;Ga=c[sa>>2]|0;if((Ga|0)==0){c[ya>>2]=0;c[sa>>2]=127;Xa=127;Ya=0}else{Xa=Ga;Ya=c[ya>>2]|0}Ga=(Ia&255)>>>4&255;Ia=((ba(a[1269048+Ga|0]|0,Xa)|0)/8|0)+Ya|0;if((Ia+32768|0)>>>0>65535>>>0){Za=(Ia>>31^32767)&65535}else{Za=Ia&65535}c[ya>>2]=Za<<16>>16;Ia=(ba(b[1268912+(Ga<<1)>>1]|0,Xa)|0)>>8;if((Ia|0)<127){_a=127}else{_a=(Ia|0)>24567?24567:Ia}c[sa>>2]=_a;b[ua+2>>1]=Za;Ia=wa-1|0;if((Ia|0)>0){Ca=Ca+1|0;ua=ua+4|0;wa=Ia}else{break}}ra=F+Da|0}else if((qa|0)==69656){wa=v;ua=F;Ca=0;sa=F+(pa<<2|8)|0;while(1){ya=ua;$a=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24)&65535;b[wa+(Ca*36|0)+4>>1]=$a;if(($a&65535)>>>0>88>>>0){C=343;break}ya=ua+4|0;Ba=Ca+1|0;if((Ba|0)>(pa|0)){ab=ya;bb=0;break}else{ua=ya;Ca=Ba;sa=sa+4|0}}if((C|0)==343){yDb(e,16,1957032,(w=i,i=i+16|0,c[w>>2]=Ca,c[w+8>>2]=$a<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}while(1){ua=ab;c[wa+(bb*36|0)>>2]=d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24;ua=bb+1|0;if((ua|0)>(pa|0)){break}else{ab=ab+4|0;bb=ua}}Ca=na>>(pa^1);if((Ca|0)<=0){ra=sa;break}ua=v+4|0;Da=v;Ba=wa+(pa*36|0)+4|0;ya=wa+(pa*36|0)|0;ta=sa;Ia=ja;Ga=Ca;while(1){Ca=ta+1|0;Ha=a[ta]|0;Ea=b[ua>>1]|0;Fa=(Ha&255)>>>4&255;Ma=(a[1270408+Fa|0]|0)+Ea|0;if((Ma|0)<0){cb=0}else{cb=(Ma|0)>88?88:Ma&65535}Ma=(ba(Fa<<1&14|1,b[1269584+(Ea<<1)>>1]|0)|0)>>3;Ea=(c[Da>>2]|0)+((Fa&8|0)==0?Ma:-Ma|0)|0;if((Ea+32768|0)>>>0>65535>>>0){db=(Ea>>31^32767)&65535}else{db=Ea&65535}c[Da>>2]=db<<16>>16;b[ua>>1]=cb;b[Ia>>1]=db;Ea=b[Ba>>1]|0;Ma=Ha&15;Ha=(a[1270408+Ma|0]|0)+Ea|0;if((Ha|0)<0){eb=0}else{eb=(Ha|0)>88?88:Ha&65535}Ha=(ba(b[1269584+(Ea<<1)>>1]|0,Ma<<1&14|1)|0)>>3;Ea=(c[ya>>2]|0)+((Ma&8|0)==0?Ha:-Ha|0)|0;if((Ea+32768|0)>>>0>65535>>>0){fb=(Ea>>31^32767)&65535}else{fb=Ea&65535}c[ya>>2]=fb<<16>>16;b[Ba>>1]=eb;b[Ia+2>>1]=fb;Ea=Ga-1|0;if((Ea|0)>0){ta=Ca;Ia=Ia+4|0;Ga=Ea}else{ra=Ca;break}}}else if((qa|0)==69647|(qa|0)==69648|(qa|0)==69649){Ga=v;Ia=v+4|0;if((b[Ia>>1]|0)==0){ta=F+1|0;Ba=ga+2|0;b[ja>>1]=(d[F]<<7)-16384;if(oa){b[Ba>>1]=(d[ta]<<7)-16384;gb=ga+4|0;hb=F+2|0}else{gb=Ba;hb=ta}b[Ia>>1]=1;ib=gb;jb=na-1|0;kb=hb}else{ib=ja;jb=na;kb=F}if((qa|0)==69648){Ia=jb<<pa;if((Ia|0)<=2){ra=kb;break}ta=(Ia|0)/3|0;Ia=v+8|0;Ba=v;ya=-ta|0;ua=ta+((ya|0)>-1?ya:-1)+1|0;ya=kb;Da=ib;sa=ta;ta=c[Ia>>2]|0;wa=c[Ba>>2]|0;while(1){Ca=ya+1|0;Ea=a[ya]|0;Ha=(Ea&255)>>>5&255;Ma=Ha&3;Fa=Ma<<ta+7;Ja=((Ha&4|0)!=0?-Fa|0:Fa)+wa|0;if((Ja|0)<-16384){lb=-16384}else{lb=(Ja|0)>16256?16256:Ja}c[Ba>>2]=lb;do{if((Ma|0)==3&(ta|0)<3){Ja=ta+1|0;c[Ia>>2]=Ja;mb=Ja}else{if(!((Ma|0)==0&(ta|0)>0)){mb=ta;break}Ja=ta-1|0;c[Ia>>2]=Ja;mb=Ja}}while(0);Ma=Da+2|0;b[Da>>1]=lb;Ja=(Ea&255)>>>2&7;Fa=Ja&3;Ha=Fa<<mb+7;La=((Ja&4|0)!=0?-Ha|0:Ha)+lb|0;if((La|0)<-16384){nb=-16384}else{nb=(La|0)>16256?16256:La}c[Ba>>2]=nb;do{if((Fa|0)==3&(mb|0)<3){La=mb+1|0;c[Ia>>2]=La;ob=La}else{if(!((Fa|0)==0&(mb|0)>0)){ob=mb;break}La=mb-1|0;c[Ia>>2]=La;ob=La}}while(0);Fa=Da+4|0;b[Ma>>1]=nb;La=Ea&3;Ha=La&1;Ja=Ha<<ob+7;Ka=((La&2|0)!=0?-Ja|0:Ja)+nb|0;if((Ka|0)<-16384){pb=-16384}else{pb=(Ka|0)>16256?16256:Ka}c[Ba>>2]=pb;do{if((Ha|0)!=0&(ob|0)<3){Ka=ob+1|0;c[Ia>>2]=Ka;qb=Ka}else{if(!((Ha|0)==0&(ob|0)>0)){qb=ob;break}Ka=ob-1|0;c[Ia>>2]=Ka;qb=Ka}}while(0);b[Fa>>1]=pb;Ha=sa-1|0;if((Ha|0)>0){ya=Ca;Da=Da+6|0;sa=Ha;ta=qb;wa=pb}else{break}}ra=kb+ua|0;break}else if((qa|0)==69647){wa=jb>>(pa^1);if((wa|0)<=0){ra=kb;break}ta=v+8|0;sa=v;Da=Ga+(pa*36|0)+8|0;ya=Ga+(pa*36|0)|0;Ia=kb;Ba=ib;Ha=wa;while(1){Ea=Ia+1|0;Ma=a[Ia]|0;Ka=(Ma&255)>>>4&255;Ja=Ka&7;La=c[ta>>2]|0;rb=Ja<<La+7;sb=((Ka&8|0)!=0?-rb|0:rb)+(c[sa>>2]|0)|0;if((sb|0)<-16384){tb=-16384}else{tb=(sb|0)>16256?16256:sb}c[sa>>2]=tb;do{if(Ja>>>0>4>>>0&(La|0)<3){c[ta>>2]=La+1}else{if(!((Ja|0)==0&(La|0)>0)){break}c[ta>>2]=La-1}}while(0);La=Ba+2|0;b[Ba>>1]=tb;Ja=Ma&15;Ca=Ja&7;Fa=c[Da>>2]|0;sb=Ca<<Fa+7;rb=((Ja&8|0)!=0?-sb|0:sb)+(c[ya>>2]|0)|0;if((rb|0)<-16384){ub=-16384}else{ub=(rb|0)>16256?16256:rb}c[ya>>2]=ub;do{if(Ca>>>0>4>>>0&(Fa|0)<3){c[Da>>2]=Fa+1}else{if(!((Ca|0)==0&(Fa|0)>0)){break}c[Da>>2]=Fa-1}}while(0);b[La>>1]=ub;Fa=Ha-1|0;if((Fa|0)>0){Ia=Ea;Ba=Ba+4|0;Ha=Fa}else{break}}ra=kb+wa|0;break}else{Ha=jb>>2-pa;if((Ha|0)<=0){ra=kb;break}Ba=v+8|0;Ia=v;Da=Ga+(pa*36|0)+8|0;ya=Ga+(pa*36|0)|0;ta=kb;sa=ib;ua=Ha;while(1){Fa=ta+1|0;Ca=a[ta]|0;Ma=(Ca&255)>>>6&255;rb=Ma&1;sb=c[Ba>>2]|0;Ja=rb<<sb+9;Ka=((Ma&2|0)!=0?-Ja|0:Ja)+(c[Ia>>2]|0)|0;if((Ka|0)<-16384){vb=-16384}else{vb=(Ka|0)>16256?16256:Ka}c[Ia>>2]=vb;do{if((rb|0)!=0&(sb|0)<3){c[Ba>>2]=sb+1}else{if(!((rb|0)==0&(sb|0)>0)){break}c[Ba>>2]=sb-1}}while(0);sb=sa+2|0;b[sa>>1]=vb;rb=(Ca&255)>>>4&3;Ea=rb&1;La=c[Da>>2]|0;Ka=Ea<<La+9;Ja=((rb&2|0)!=0?-Ka|0:Ka)+(c[ya>>2]|0)|0;if((Ja|0)<-16384){wb=-16384}else{wb=(Ja|0)>16256?16256:Ja}c[ya>>2]=wb;do{if((Ea|0)!=0&(La|0)<3){c[Da>>2]=La+1}else{if(!((Ea|0)==0&(La|0)>0)){break}c[Da>>2]=La-1}}while(0);La=sa+4|0;b[sb>>1]=wb;Ea=(Ca&255)>>>2&3;Ja=Ea&1;Ka=c[Ba>>2]|0;rb=Ja<<Ka+9;Ma=((Ea&2|0)!=0?-rb|0:rb)+(c[Ia>>2]|0)|0;if((Ma|0)<-16384){xb=-16384}else{xb=(Ma|0)>16256?16256:Ma}c[Ia>>2]=xb;do{if((Ja|0)!=0&(Ka|0)<3){c[Ba>>2]=Ka+1}else{if(!((Ja|0)==0&(Ka|0)>0)){break}c[Ba>>2]=Ka-1}}while(0);Ka=sa+6|0;b[La>>1]=xb;Ja=Ca&3;sb=Ja&1;Ma=c[Da>>2]|0;rb=sb<<Ma+9;Ea=((Ja&2|0)!=0?-rb|0:rb)+(c[ya>>2]|0)|0;if((Ea|0)<-16384){yb=-16384}else{yb=(Ea|0)>16256?16256:Ea}c[ya>>2]=yb;do{if((sb|0)!=0&(Ma|0)<3){c[Da>>2]=Ma+1}else{if(!((sb|0)==0&(Ma|0)>0)){break}c[Da>>2]=Ma-1}}while(0);b[Ka>>1]=yb;Ma=ua-1|0;if((Ma|0)>0){ta=Fa;sa=sa+8|0;ua=Ma}else{break}}ra=kb+Ha|0;break}}else if((qa|0)==69645){ua=h<<3;sa=ua>>>0>2147483639>>>0|(s|0)==0;ta=sa?0:s;Da=sa?8:ua+8|0;sa=ta;ya=(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)>>>6&3;sa=Da>>>0>2>>>0?2:Da;Ba=ya+2|0;Ia=1<<ya;Ga=1<<ya+1;if((sa|0)<=((I*-22|0)+ua|0)){wa=30-ya|0;Ma=c[u>>2]|0;sb=~Ga;Ca=sa;sa=ja;La=I;while(1){if((La|0)>0){Ea=Ca;rb=0;Ja=sa;while(1){zb=ta+(Ea>>>3)|0;Ab=(fe(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)|0)<<(Ea&7)>>16;zb=Ea+16|0;Bb=Da>>>0>zb>>>0?zb:Da;c[Ma+(rb*36|0)>>2]=Ab;zb=Ja+2|0;b[Ja>>1]=Ab;Ab=ta+(Bb>>>3)|0;Cb=(fe(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)|0)<<(Bb&7)>>>26;Ab=Bb+6|0;Bb=Da>>>0>Ab>>>0?Ab:Da;b[Ma+(rb*36|0)+4>>1]=Cb;Cb=rb+1|0;Ab=c[y>>2]|0;if((Cb|0)<(Ab|0)){Ea=Bb;rb=Cb;Ja=zb}else{Db=Bb;Eb=zb;Fb=Ab;break}}}else{Db=Ca;Eb=sa;Fb=La}if((Db|0)>(ua-(ba(Fb,Ba)|0)|0)){Gb=Db;Hb=Eb;Ib=Fb}else{Ja=Db;rb=0;Ea=Eb;Fa=Fb;while(1){if((Fa|0)>0){Ka=Ja;Ab=0;zb=Ea;while(1){Bb=ta+(Ka>>>3)|0;Cb=(fe(d[Bb]|d[Bb+1|0]<<8|d[Bb+2|0]<<16|d[Bb+3|0]<<24|0)|0)<<(Ka&7)>>>(wa>>>0);Bb=Ka+Ba|0;Jb=Ma+(Ab*36|0)+4|0;Kb=b[Jb>>1]|0;Lb=Ia;Mb=0;Nb=b[1269584+(Kb<<16>>16<<1)>>1]|0;do{Mb=((Lb&Cb|0)==0?0:Nb)+Mb|0;Nb=Nb>>1;Lb=Lb>>1;}while((Lb|0)!=0);Lb=Da>>>0>Bb>>>0?Bb:Da;Ob=Mb+Nb|0;Pb=Ma+(Ab*36|0)|0;Qb=(c[Pb>>2]|0)+((Cb&Ga|0)==0?Ob:-Ob|0)|0;c[Pb>>2]=Qb;Ob=(c[402800+(ya<<6)+((Cb&sb)<<2)>>2]|0)+(Kb&65535)|0;Rb=Ob<<16;if((Rb|0)<0){Sb=0}else{Sb=(Rb|0)>5767168?88:Ob&65535}b[Jb>>1]=Sb;if((Qb+32768|0)>>>0>65535>>>0){Tb=(Qb>>31^32767)&65535}else{Tb=Qb&65535}c[Pb>>2]=Tb<<16>>16;Pb=zb+2|0;b[zb>>1]=Tb;Qb=Ab+1|0;Ob=c[y>>2]|0;if((Qb|0)<(Ob|0)){Ka=Lb;Ab=Qb;zb=Pb}else{Ub=Lb;Vb=Pb;Wb=Ob;break}}}else{Ub=Ja;Vb=Ea;Wb=Fa}zb=rb+1|0;if((Ub|0)<=(ua-(ba(Wb,Ba)|0)|0)&(zb|0)<4095){Ja=Ub;rb=zb;Ea=Vb;Fa=Wb}else{Gb=Ub;Hb=Vb;Ib=Wb;break}}}if((Gb|0)>((Ib*-22|0)+ua|0)){break}else{Ca=Gb;sa=Hb;La=Ib}}}ra=s+((-h|0)>0?0:h)|0}else if((qa|0)==69633){c:do{if((I|0)>0){La=v;sa=F;Ca=0;while(1){ua=sa;Ba=(d[ua]|d[ua+1|0]<<8)<<16>>16;b[c[ia+(Ca<<2)>>2]>>1]=Ba;c[La+(Ca*36|0)>>2]=Ba<<16>>16;Ba=sa+2|0;Xb=(d[Ba]|d[Ba+1|0]<<8)<<16>>16;b[La+(Ca*36|0)+4>>1]=Xb;if((Xb&65535)>>>0>88>>>0){break}Ba=sa+4|0;ua=Ca+1|0;sb=c[y>>2]|0;if((ua|0)<(sb|0)){sa=Ba;Ca=ua}else{Yb=Ba;Zb=sb;break c}}yDb(e,16,1957032,(w=i,i=i+16|0,c[w>>2]=Ca,c[w+8>>2]=Xb<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{Yb=F;Zb=I}}while(0);sa=e+792|0;La=c[sa>>2]|0;if((La|0)!=4){sb=d[1271784+(La-2)|0]|0;La=x-Yb|0;Ba=La>>>0>268435455>>>0?-8:La<<3;ua=Ba>>>0>2147483639>>>0|(Yb|0)==0;ya=ua?0:Yb;Ga=ua?8:Ba+8|0;Ba=(na-1|0)/(sb|0)|0;if((Ba|0)>0){ua=v;Ma=0;Da=0;Ia=Zb;while(1){if((Ia|0)>0){wa=(ba(Da,sb)|0)+1|0;ta=Ma;Ha=0;while(1){Fa=c[ia+(Ha<<2)>>2]|0;Ea=ua+(Ha*36|0)+4|0;rb=ua+(Ha*36|0)|0;Ja=ta;zb=0;do{Ab=c[sa>>2]|0;Ka=Ab-1|0;Ob=ya+(Ja>>>3)|0;Pb=32-Ab|0;Lb=(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)>>>((Ja&7)>>>0)<<Pb>>>(Pb>>>0);Pb=Ab+Ja|0;Ja=Ga>>>0>Pb>>>0?Pb:Ga;Pb=b[Ea>>1]|0;Ob=(a[(c[1270392+(Ab-2<<2)>>2]|0)+Lb|0]|0)+Pb|0;if((Ob|0)<0){_b=0}else{_b=(Ob|0)>88?88:Ob&65535}Ob=1<<Ka;Ab=(ba((Lb&Ob-1)<<1|1,b[1269584+(Pb<<1)>>1]|0)|0)>>Ka;Ka=(c[rb>>2]|0)+((Lb&Ob|0)==0?Ab:-Ab|0)|0;if((Ka+32768|0)>>>0>65535>>>0){$b=(Ka>>31^32767)&65535}else{$b=Ka&65535}c[rb>>2]=$b<<16>>16;b[Ea>>1]=_b;b[Fa+(wa+zb<<1)>>1]=$b;zb=zb+1|0;}while((zb|0)<(sb|0));zb=c[y>>2]|0;Fa=Ha+1|0;if((Fa|0)<(zb|0)){ta=Ja;Ha=Fa}else{ac=Ja;bc=zb;break}}}else{ac=Ma;bc=Ia}Ha=Da+1|0;if((Ha|0)<(Ba|0)){Ma=ac;Da=Ha;Ia=bc}else{cc=bc;break}}}else{cc=Zb}Ia=(c[e+432>>2]|0)-(cc<<2)|0;ra=Yb+(La>>>0>Ia>>>0?Ia:La)|0;break}Ia=na-1|0;Da=(Ia|0)/8|0;if((Ia|0)<=7){ra=Yb;break}Ia=v;Ma=Yb;Ba=0;sb=Zb;while(1){if((sb|0)>0){Ga=Ba<<3|1;ya=Ma;sa=0;while(1){ua=c[ia+(sa<<2)>>2]|0;Ha=Ia+(sa*36|0)+4|0;ta=Ia+(sa*36|0)|0;wa=ya;Ca=0;while(1){zb=a[wa]|0;Fa=b[Ha>>1]|0;Ea=zb&15;rb=(a[1270408+Ea|0]|0)+Fa|0;if((rb|0)<0){dc=0}else{dc=(rb|0)>88?88:rb&65535}rb=(ba(Ea<<1&14|1,b[1269584+(Fa<<1)>>1]|0)|0)>>3;Fa=(c[ta>>2]|0)+((Ea&8|0)==0?rb:-rb|0)|0;if((Fa+32768|0)>>>0>65535>>>0){ec=(Fa>>31^32767)&65535}else{ec=Fa&65535}Fa=ec<<16>>16;c[ta>>2]=Fa;b[Ha>>1]=dc;b[ua+(Ca+Ga<<1)>>1]=ec;rb=b[Ha>>1]|0;Ea=(zb&255)>>>4&255;zb=(a[1270408+Ea|0]|0)+rb|0;if((zb|0)<0){fc=0}else{fc=(zb|0)>88?88:zb&65535}zb=(ba(b[1269584+(rb<<1)>>1]|0,Ea<<1&14|1)|0)>>3;rb=Fa+((Ea&8|0)==0?zb:-zb|0)|0;if((rb+32768|0)>>>0>65535>>>0){gc=(rb>>31^32767)&65535}else{gc=rb&65535}c[ta>>2]=gc<<16>>16;b[Ha>>1]=fc;b[ua+((Ca|1)+Ga<<1)>>1]=gc;rb=Ca+2|0;if((rb|0)<8){wa=wa+1|0;Ca=rb}else{break}}Ca=ya+4|0;wa=sa+1|0;ua=c[y>>2]|0;if((wa|0)<(ua|0)){ya=Ca;sa=wa}else{hc=Ca;ic=ua;break}}}else{hc=Ma;ic=sb}sa=Ba+1|0;if((sa|0)<(Da|0)){Ma=hc;Ba=sa;sb=ic}else{ra=hc;break}}}else if((qa|0)==69659){d:do{if((I|0)>0){sb=v;Ba=F;Ma=0;while(1){Da=Ba;c[sb+(Ma*36|0)>>2]=(d[Da]|d[Da+1|0]<<8)<<16>>16<<16>>16;Da=Ba+2|0;jc=(d[Da]|d[Da+1|0]<<8)<<16>>16;b[sb+(Ma*36|0)+4>>1]=jc;if((jc&65535)>>>0>88>>>0){break}Da=Ba+4|0;Ia=Ma+1|0;if((Ia|0)<(c[y>>2]|0)){Ba=Da;Ma=Ia}else{kc=Da;break d}}yDb(e,16,1957032,(w=i,i=i+16|0,c[w>>2]=Ma,c[w+8>>2]=jc<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{kc=F}}while(0);Ba=na>>(pa^1);if((Ba|0)<=0){ra=kc;break}sb=v;Da=v+4|0;Ia=v;La=sb+(pa*36|0)+4|0;sa=sb+(pa*36|0)|0;sb=kc;ya=ja;Ga=Ba;while(1){ua=a[sb]|0;Ca=(ua&255)>>>4;if(oa){lc=Ca&255;mc=ua&15}else{lc=ua&15;mc=Ca&255}Ca=b[Da>>1]|0;ua=lc<<24>>24;wa=(a[1270408+ua|0]|0)+Ca|0;if((wa|0)<0){nc=0}else{nc=(wa|0)>88?88:wa&65535}wa=(ba(ua<<1&14|1,b[1269584+(Ca<<1)>>1]|0)|0)>>3;Ca=(c[Ia>>2]|0)+((ua&8|0)==0?wa:-wa|0)|0;if((Ca+32768|0)>>>0>65535>>>0){oc=(Ca>>31^32767)&65535}else{oc=Ca&65535}c[Ia>>2]=oc<<16>>16;b[Da>>1]=nc;b[ya>>1]=oc;Ca=b[La>>1]|0;wa=mc<<24>>24;ua=(a[1270408+wa|0]|0)+Ca|0;if((ua|0)<0){pc=0}else{pc=(ua|0)>88?88:ua&65535}ua=(ba(b[1269584+(Ca<<1)>>1]|0,wa<<1&14|1)|0)>>3;Ca=(c[sa>>2]|0)+((wa&8|0)==0?ua:-ua|0)|0;if((Ca+32768|0)>>>0>65535>>>0){qc=(Ca>>31^32767)&65535}else{qc=Ca&65535}c[sa>>2]=qc<<16>>16;b[La>>1]=pc;b[ya+2>>1]=qc;Ca=Ga-1|0;if((Ca|0)>0){sb=sb+1|0;ya=ya+4|0;Ga=Ca}else{break}}ra=kc+Ba|0}else if((qa|0)==69632){if((I|0)<=0){ra=F;break}Ga=v;ya=F;sb=0;while(1){La=Ga+(sb*36|0)|0;sa=ya+2|0;Da=ya;Ia=(de((d[Da]|d[Da+1|0]<<8)<<16>>16|0)|0)<<16>>16;Da=Ia&127;Ca=Ia&-128;Ia=Ga+(sb*36|0)+4|0;ua=b[Ia>>1]|0;wa=La|0;if((ua<<16>>16|0)==(Da|0)){Ha=c[wa>>2]|0;ta=Ca-Ha|0;if((((ta|0)<0?-ta|0:ta)|0)>127){C=90}else{rc=ua;sc=Ha}}else{C=90}if((C|0)==90){C=0;Ha=Da&65535;b[Ia>>1]=Ha;c[wa>>2]=Ca;rc=Ha;sc=Ca}if((rc&65535)>>>0>88>>>0){break}Ca=c[ia+(sb<<2)>>2]|0;Ha=La|0;La=sa;sa=0;wa=sc;Da=rc;while(1){ua=d[La]|0;ta=Da<<16>>16;Ja=b[1269584+(ta<<1)>>1]|0;rb=(a[1270408+(ua&15)|0]|0)+ta|0;if((rb|0)<0){tc=0}else{tc=(rb|0)>88?88:rb&65535}rb=(Ja>>3)+((ua&4|0)==0?0:Ja)|0;if((ua&2|0)==0){uc=rb}else{uc=rb+(Ja>>1)|0}if((ua&1|0)==0){vc=uc}else{vc=uc+(Ja>>2)|0}Ja=wa+((ua&8|0)==0?vc:-vc|0)|0;if((Ja+32768|0)>>>0>65535>>>0){wc=(Ja>>31^32767)&65535}else{wc=Ja&65535}Ja=wc<<16>>16;c[Ha>>2]=Ja;b[Ia>>1]=tc;b[Ca+(sa<<1)>>1]=wc;rb=ua>>>4;ua=b[Ia>>1]|0;ta=b[1269584+(ua<<1)>>1]|0;zb=(a[1270408+rb|0]|0)+ua|0;if((zb|0)<0){xc=0}else{xc=(zb|0)>88?88:zb&65535}zb=(ta>>3)+((rb&4|0)==0?0:ta)|0;if((rb&2|0)==0){yc=zb}else{yc=zb+(ta>>1)|0}if((rb&1|0)==0){zc=yc}else{zc=yc+(ta>>2)|0}ta=Ja+((rb&8|0)==0?zc:-zc|0)|0;if((ta+32768|0)>>>0>65535>>>0){Ac=(ta>>31^32767)&65535}else{Ac=ta&65535}ta=Ac<<16>>16;c[Ha>>2]=ta;b[Ia>>1]=xc;b[Ca+((sa|1)<<1)>>1]=Ac;rb=sa+2|0;if((rb|0)>=64){break}La=La+1|0;sa=rb;wa=ta;Da=b[Ia>>1]|0}Ia=ya+34|0;Da=sb+1|0;if((Da|0)<(c[y>>2]|0)){ya=Ia;sb=Da}else{ra=Ia;break b}}yDb(e,16,1957032,(w=i,i=i+16|0,c[w>>2]=sb,c[w+8>>2]=rc<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else if((qa|0)==69638){ya=F+1|0;Ga=a[F]|0;Ba=Ga&255;if((Ga&255)>>>0>6>>>0){yDb(e,16,1954744,(w=i,i=i+8|0,c[w>>2]=Ba,w)|0);i=w;ma=-1094995529;i=j;return ma|0}Ga=d[1273768+Ba|0]|0;Ia=v;Da=v+24|0;c[Da>>2]=Ga;wa=a[1273760+Ba|0]|0;Ba=v+28|0;c[Ba>>2]=wa;do{if(oa){sa=a[ya]|0;La=sa&255;if(!((sa&255)>>>0>6>>>0)){c[v+60>>2]=d[1273768+La|0]|0;c[v+64>>2]=a[1273760+La|0]|0;sa=F+2|0;Ca=(d[sa]|d[sa+1|0]<<8)<<16>>16<<16>>16;c[v+32>>2]=Ca;sa=F+4|0;c[v+68>>2]=(d[sa]|d[sa+1|0]<<8)<<16>>16<<16>>16;sa=F+6|0;Ha=(d[sa]|d[sa+1|0]<<8)<<16>>16;sa=Ha<<16>>16;Ma=v+16|0;c[Ma>>2]=sa;ta=F+8|0;c[v+52>>2]=(d[ta]|d[ta+1|0]<<8)<<16>>16<<16>>16;ta=F+10|0;rb=(d[ta]|d[ta+1|0]<<8)<<16>>16;ta=rb<<16>>16;Ja=v+20|0;c[Ja>>2]=ta;zb=F+12|0;ua=(d[zb]|d[zb+1|0]<<8)<<16>>16;c[v+56>>2]=ua<<16>>16;b[ja>>1]=rb;b[ga+2>>1]=ua;b[ga+4>>1]=Ha;b[ga+6>>1]=c[v+52>>2];Bc=ga+8|0;Cc=F+14|0;Dc=Ma;Ec=sa;Fc=Ca;Gc=ta;Hc=Ja;break}yDb(e,16,1952504,(w=i,i=i+8|0,c[w>>2]=La,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{La=ya;Ja=(d[La]|d[La+1|0]<<8)<<16>>16<<16>>16;c[v+32>>2]=Ja;La=F+3|0;ta=(d[La]|d[La+1|0]<<8)<<16>>16;La=ta<<16>>16;Ca=v+16|0;c[Ca>>2]=La;sa=F+5|0;Ma=(d[sa]|d[sa+1|0]<<8)<<16>>16;sa=Ma<<16>>16;Ha=v+20|0;c[Ha>>2]=sa;b[ja>>1]=Ma;b[ga+2>>1]=ta;Bc=ga+4|0;Cc=F+7|0;Dc=Ca;Ec=La;Fc=Ja;Gc=sa;Hc=Ha}}while(0);ya=na-2>>(pa^1);if((ya|0)<=0){ra=Cc;break}sb=v+32|0;Ha=Ia+(pa*36|0)+16|0;sa=Ia+(pa*36|0)+24|0;Ja=Ia+(pa*36|0)+20|0;La=Ia+(pa*36|0)+28|0;Ca=Ia+(pa*36|0)+32|0;ta=Cc;Ma=Bc;ua=ya;rb=Ec;zb=Ga;Ea=Gc;Fa=wa;Ka=Fc;while(1){Ab=d[ta]|0;Ob=Ab>>>4;Lb=((ba(Fa,Ea)|0)+(ba(zb,rb)|0)|0)/64|0;Pb=(ba(Ka,(Ob&8|0)!=0?Ob|-16:Ob)|0)+Lb|0;c[Hc>>2]=rb;if((Pb+32768|0)>>>0>65535>>>0){Ic=(Pb>>31^32767)&65535}else{Ic=Pb&65535}c[Dc>>2]=Ic<<16>>16;Pb=(ba(b[1273728+(Ob<<1)>>1]|0,Ka)|0)>>8;c[sb>>2]=(Pb|0)<16?16:Pb;b[Ma>>1]=Ic;Pb=Ab&15;Ob=c[Ha>>2]|0;Lb=ba(c[sa>>2]|0,Ob)|0;Qb=((ba(c[La>>2]|0,c[Ja>>2]|0)|0)+Lb|0)/64|0;Lb=c[Ca>>2]|0;Rb=(ba(Lb,(Ab&8|0)!=0?Ab|-16:Pb)|0)+Qb|0;c[Ja>>2]=Ob;if((Rb+32768|0)>>>0>65535>>>0){Jc=(Rb>>31^32767)&65535}else{Jc=Rb&65535}c[Ha>>2]=Jc<<16>>16;Rb=(ba(b[1273728+(Pb<<1)>>1]|0,Lb)|0)>>8;c[Ca>>2]=(Rb|0)<16?16:Rb;b[Ma+2>>1]=Jc;Rb=ua-1|0;if((Rb|0)<=0){break}ta=ta+1|0;Ma=Ma+4|0;ua=Rb;rb=c[Dc>>2]|0;zb=c[Da>>2]|0;Ea=c[Hc>>2]|0;Fa=c[Ba>>2]|0;Ka=c[sb>>2]|0}ra=Cc+ya|0}else if((qa|0)==69652|(qa|0)==69654|(qa|0)==69653){sb=(qa|0)==69653;do{if((I|0)==0){Kc=0}else{Ka=x;Ba=F;Fa=0;while(1){Ea=(Ka-Ba|0)<4;do{if(sb){if(Ea){Lc=0;Mc=Ba;break}Da=Ba;Lc=fe(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0;Mc=Ba+4|0}else{if(Ea){Lc=0;Mc=Ba;break}Da=Ba;Lc=d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0;Mc=Ba+4|0}}while(0);c[o+(Fa<<2)>>2]=Lc+4+(I<<2);Ea=Fa+1|0;if(Ea>>>0<I>>>0){Ba=Mc;Fa=Ea}else{break}}if((I|0)==0){Kc=0;break}Fa=x;Ba=v;Ka=(na|0)/28|0;Ea=(na|0)>27;Da=e;zb=(Ka|0)>1?Ka:1;rb=0;ua=0;Ma=qa;while(1){ta=c[o+(rb<<2)>>2]|0;if((ta|0)<0){Nc=0}else{Nc=(h|0)<(ta|0)?h:ta}ta=s+Nc|0;Ca=c[ia+(rb<<2)>>2]|0;do{if((Ma|0)==69652){if((Fa-ta|0)<2){Oc=0;Pc=ta}else{Ha=ta;Oc=(d[Ha]|d[Ha+1|0]<<8)<<16>>16<<16>>16;Pc=s+(Nc+2)|0}if((Fa-Pc|0)<2){Qc=Oc;Rc=0;Sc=Pc;break}Ha=Pc;Qc=Oc;Rc=(d[Ha]|d[Ha+1|0]<<8)<<16>>16<<16>>16;Sc=Pc+2|0}else{Qc=c[Ba+(rb*36|0)>>2]|0;Rc=c[Ba+(rb*36|0)+12>>2]|0;Sc=ta}}while(0);if(Ea){ta=Sc;Ha=Rc;Ja=Qc;La=Ca;sa=0;while(1){do{if((Fa-ta|0)<1){Tc=ta;Uc=0;C=421}else{wa=ta+1|0;Ga=a[ta]|0;if(!(Ga<<24>>24==-18)){Tc=wa;Uc=Ga&255;C=421;break}if((Fa-wa|0)<2){Vc=0;Wc=wa}else{Ga=wa;Vc=(de((d[Ga]|d[Ga+1|0]<<8)<<16>>16|0)|0)<<16>>16;Wc=ta+3|0}if((Fa-Wc|0)<2){Xc=0;Yc=Wc}else{Ga=Wc;Xc=(de((d[Ga]|d[Ga+1|0]<<8)<<16>>16|0)|0)<<16>>16;Yc=Wc+2|0}Ga=Yc;wa=La;Ia=0;while(1){if((Fa-Ga|0)<2){Zc=0;_c=Ga}else{Rb=Ga;Zc=de((d[Rb]|d[Rb+1|0]<<8)<<16>>16|0)|0;_c=Ga+2|0}b[wa>>1]=Zc;Rb=Ia+1|0;if((Rb|0)<28){Ga=_c;wa=wa+2|0;Ia=Rb}else{$c=Vc;ad=Xc;bd=_c;break}}}}while(0);if((C|0)==421){C=0;Jb=Uc>>>4;Kb=c[1344856+(Jb<<2)>>2]|0;Cb=c[1344856+(Jb+4<<2)>>2]|0;Jb=20-(Uc&15)|0;Nb=Tc;Mb=Ha;Bb=Ja;Ia=La;wa=Uc;Ga=0;while(1){if((Ga&1|0)==0){if((Fa-Nb|0)<1){cd=0;dd=Nb}else{cd=d[Nb]|0;dd=Nb+1|0}ed=cd;fd=cd>>>4;gd=dd}else{ed=wa;fd=wa;gd=Nb}Rb=(ba(Bb,Kb)|0)+(ba(Mb,Cb)|0)+(fd<<28>>28<<Jb)|0;Lb=Rb>>8;if((Lb+32768|0)>>>0>65535>>>0){hd=(Rb>>31^32767)&65535}else{hd=Lb&65535}Lb=hd<<16>>16;b[Ia>>1]=hd;Rb=Ga+1|0;if((Rb|0)<28){Nb=gd;Mb=Bb;Bb=Lb;Ia=Ia+2|0;wa=ed;Ga=Rb}else{$c=Lb;ad=Bb;bd=gd;break}}}Bb=sa+1|0;if((Bb|0)<(Ka|0)){ta=bd;Ha=ad;Ja=$c;La=La+56|0;sa=Bb}else{id=ad;jd=$c;kd=zb;break}}}else{id=Rc;jd=Qc;kd=0}do{if((ua|0)==0){ld=kd;md=Ma}else{if((ua|0)==(kd|0)){ld=ua;md=Ma;break}yDb(Da,24,1948376,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ld=(ua|0)>(kd|0)?ua:kd;md=c[(c[A>>2]|0)+12>>2]|0}}while(0);if((md|0)!=69652){c[Ba+(rb*36|0)>>2]=jd;c[Ba+(rb*36|0)+12>>2]=id}sa=rb+1|0;if(sa>>>0<(c[y>>2]|0)>>>0){rb=sa;ua=ld;Ma=md}else{Kc=ld;break}}}}while(0);c[ha>>2]=Kc*28|0;ra=s+((-h|0)>0?0:h)|0}else if((qa|0)==1380008992){e:do{if((I|0)>0){sb=v;ya=F;Ma=0;while(1){ua=ya;nd=(d[ua]|d[ua+1|0]<<8)<<16>>16;b[sb+(Ma*36|0)+4>>1]=nd;ua=ya+2|0;c[sb+(Ma*36|0)>>2]=(d[ua]|d[ua+1|0]<<8)<<16>>16<<16>>16;if((nd&65535)>>>0>88>>>0){break}ua=ya+4|0;rb=Ma+1|0;Ba=c[y>>2]|0;if((rb|0)<(Ba|0)){ya=ua;Ma=rb}else{od=ua;pd=Ba;break e}}yDb(e,16,1957032,(w=i,i=i+16|0,c[w>>2]=Ma,c[w+8>>2]=nd<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{od=F;pd=I}}while(0);ya=(na|0)/2|0;if((na|0)<=1){ra=od;break}sb=k|0;Ba=k+4|0;ua=v;rb=od;Da=ja;zb=0;Ka=pd;while(1){Fa=rb+1|0;Ea=d[rb]|0;c[sb>>2]=Ea;if(oa){c[Ba>>2]=d[Fa]|0;qd=rb+2|0}else{qd=Fa}f:do{if((Ka|0)>0){Fa=Da;sa=0;La=Ea;while(1){Ja=ua+(sa*36|0)+4|0;Ha=b[Ja>>1]|0;ta=La&15;Ca=(a[1270408+ta|0]|0)+Ha|0;if((Ca|0)<0){rd=0}else{rd=(Ca|0)>88?88:Ca&65535}Ca=(ba(ta<<1&14|1,b[1269584+(Ha<<1)>>1]|0)|0)>>3;Ha=ua+(sa*36|0)|0;ta=(c[Ha>>2]|0)+((La&8|0)==0?Ca:-Ca|0)|0;if((ta+32768|0)>>>0>65535>>>0){sd=(ta>>31^32767)&65535}else{sd=ta&65535}c[Ha>>2]=sd<<16>>16;b[Ja>>1]=rd;td=Fa+2|0;b[Fa>>1]=sd;Ja=sa+1|0;ud=c[y>>2]|0;if((Ja|0)>=(ud|0)){break}Fa=td;sa=Ja;La=c[k+(Ja<<2)>>2]|0}if((ud|0)>0){vd=td;wd=0;xd=Ea}else{yd=td;zd=ud;break}while(1){La=xd>>>4;sa=ua+(wd*36|0)+4|0;Fa=b[sa>>1]|0;Ja=La<<24>>24;Ha=(a[1270408+Ja|0]|0)+Fa|0;if((Ha|0)<0){Ad=0}else{Ad=(Ha|0)>88?88:Ha&65535}Ha=(ba(La<<1&14|1,b[1269584+(Fa<<1)>>1]|0)|0)>>3;Fa=ua+(wd*36|0)|0;La=(c[Fa>>2]|0)+((Ja&8|0)==0?Ha:-Ha|0)|0;if((La+32768|0)>>>0>65535>>>0){Bd=(La>>31^32767)&65535}else{Bd=La&65535}c[Fa>>2]=Bd<<16>>16;b[sa>>1]=Ad;sa=vd+2|0;b[vd>>1]=Bd;Fa=wd+1|0;La=c[y>>2]|0;if((Fa|0)>=(La|0)){yd=sa;zd=La;break f}vd=sa;wd=Fa;xd=c[k+(Fa<<2)>>2]|0}}else{yd=Da;zd=Ka}}while(0);Ea=zb+1|0;if((Ea|0)<(ya|0)){rb=qd;Da=yd;zb=Ea;Ka=zd}else{ra=qd;break}}}else if((qa|0)==69640){Ka=c[ia>>2]|0;zb=c[ia+4>>2]|0;Da=(3-I|0)*112|0;rb=x;ya=F;if(!((rb-ya|0)>>>0>127>>>0)){ra=F;break}ua=s;Ba=e;sb=v+16|0;Ea=v+20|0;Ma=v+52|0;Fa=v+56|0;sa=F;La=0;Ha=ya;ya=I;while(1){Ja=Ha-ua|0;ta=Ka+(La<<1)|0;do{if((ya|0)==1){Dd=Ka+(La+28<<1)|0;Ed=(3-ya|0)*28|0;C=313}else{Ca=zb+(La<<1)|0;Bb=(3-ya|0)*28|0;if((ya|0)!=2){Dd=Ca;Ed=Bb;C=313;break}Ga=Ja+4|0;wa=Ja+5|0;Ia=Ca;Ca=ta;Mb=0;while(1){Nb=Mb<<1;Jb=a[s+(Ga+Nb)|0]|0;Cb=Jb&255;Kb=12-(Cb&15)|0;Lb=Cb>>>4;if((Jb&255)>>>0>79>>>0){DDb(Ba,1933664,(w=i,i=i+8|0,c[w>>2]=Lb,w)|0);i=w;Fd=0}else{Fd=Lb}Lb=c[2848+(Fd<<3)>>2]|0;Jb=c[2852+(Fd<<3)>>2]|0;Cb=Mb+16+Ja|0;Rb=0;Pb=c[sb>>2]|0;Ob=c[Ea>>2]|0;while(1){Qb=(d[s+(Cb+(Rb<<2))|0]<<28>>28<<Kb)+((ba(Ob,Jb)|0)+32+(ba(Pb,Lb)|0)>>6)|0;if((Qb+32768|0)>>>0>65535>>>0){Gd=(Qb>>31^32767)&65535}else{Gd=Qb&65535}Hd=Gd<<16>>16;b[Ca+(Rb<<1)>>1]=Gd;Qb=Rb+1|0;if((Qb|0)<28){Rb=Qb;Ob=Pb;Pb=Hd}else{break}}c[sb>>2]=Hd;c[Ea>>2]=Pb;Ob=c[Ma>>2]|0;Rb=c[Fa>>2]|0;Lb=a[s+(wa+Nb)|0]|0;Jb=Lb&255;Kb=12-(Jb&15)|0;Qb=Jb>>>4;if((Lb&255)>>>0>79>>>0){DDb(Ba,1933664,(w=i,i=i+8|0,c[w>>2]=Qb,w)|0);i=w;Id=0}else{Id=Qb}Qb=c[2848+(Id<<3)>>2]|0;Lb=c[2852+(Id<<3)>>2]|0;Jb=0;Ab=Ob;Ob=Rb;while(1){Rb=((d[s+(Cb+(Jb<<2))|0]|0)>>>4<<28>>28<<Kb)+((ba(Ob,Lb)|0)+32+(ba(Ab,Qb)|0)>>6)|0;if((Rb+32768|0)>>>0>65535>>>0){Jd=(Rb>>31^32767)&65535}else{Jd=Rb&65535}Kd=Jd<<16>>16;b[Ia+(Jb<<1)>>1]=Jd;Rb=Jb+1|0;if((Rb|0)<28){Jb=Rb;Ob=Ab;Ab=Kd}else{break}}c[Ma>>2]=Kd;c[Fa>>2]=Ab;Ob=Mb+1|0;if((Ob|0)<4){Ia=Ia+(Bb<<1)|0;Ca=Ca+(Bb<<1)|0;Mb=Ob}else{break}}}}while(0);if((C|0)==313){C=0;Mb=Ja+4|0;Bb=Ja+5|0;Ca=Dd;Ia=ta;wa=0;while(1){Ga=wa<<1;Ob=a[s+(Mb+Ga)|0]|0;Jb=Ob&255;Qb=12-(Jb&15)|0;Lb=Jb>>>4;if((Ob&255)>>>0>79>>>0){DDb(Ba,1933664,(w=i,i=i+8|0,c[w>>2]=Lb,w)|0);i=w;Ld=0}else{Ld=Lb}Lb=c[2848+(Ld<<3)>>2]|0;Ob=c[2852+(Ld<<3)>>2]|0;Jb=wa+16+Ja|0;Kb=0;Cb=c[sb>>2]|0;Nb=c[Ea>>2]|0;while(1){Pb=(d[s+(Jb+(Kb<<2))|0]<<28>>28<<Qb)+((ba(Nb,Ob)|0)+32+(ba(Cb,Lb)|0)>>6)|0;if((Pb+32768|0)>>>0>65535>>>0){Md=(Pb>>31^32767)&65535}else{Md=Pb&65535}Nd=Md<<16>>16;b[Ia+(Kb<<1)>>1]=Md;Pb=Kb+1|0;if((Pb|0)<28){Kb=Pb;Nb=Cb;Cb=Nd}else{break}}Nb=a[s+(Bb+Ga)|0]|0;Kb=Nb&255;Lb=12-(Kb&15)|0;Ob=Kb>>>4;if((Nb&255)>>>0>79>>>0){DDb(Ba,1933664,(w=i,i=i+8|0,c[w>>2]=Ob,w)|0);i=w;Od=0}else{Od=Ob}Ob=c[2848+(Od<<3)>>2]|0;Nb=c[2852+(Od<<3)>>2]|0;Kb=0;Qb=Nd;Pb=Cb;while(1){Rb=((d[s+(Jb+(Kb<<2))|0]|0)>>>4<<28>>28<<Lb)+((ba(Pb,Nb)|0)+32+(ba(Qb,Ob)|0)>>6)|0;if((Rb+32768|0)>>>0>65535>>>0){Pd=(Rb>>31^32767)&65535}else{Pd=Rb&65535}Qd=Pd<<16>>16;b[Ca+(Kb<<1)>>1]=Pd;Rb=Kb+1|0;if((Rb|0)<28){Kb=Rb;Pb=Qb;Qb=Qd}else{break}}c[sb>>2]=Qd;c[Ea>>2]=Qb;Pb=wa+1|0;if((Pb|0)<4){Ca=Ca+(Ed<<1)|0;Ia=Ia+(Ed<<1)|0;wa=Pb}else{break}}}wa=sa+128|0;Ia=wa;if(!((rb-Ia|0)>>>0>127>>>0)){ra=wa;break b}sa=wa;La=La+Da|0;Ha=Ia;ya=c[y>>2]|0}}else if((qa|0)==69642){if(!oa){ma=-1094995529;i=j;return ma|0}ya=F+8|0;Ha=(na|0)/28|0;if((na|0)>27){Da=F+6|0;La=F+4|0;sa=F+2|0;rb=F;Ea=(na|0)>55?(Ha*30|0)+8|0:38;sb=ya;Ba=(d[La]|d[La+1|0]<<8)<<16>>16<<16>>16;La=(d[rb]|d[rb+1|0]<<8)<<16>>16<<16>>16;rb=(d[Da]|d[Da+1|0]<<8)<<16>>16<<16>>16;Da=(d[sa]|d[sa+1|0]<<8)<<16>>16<<16>>16;sa=0;Fa=ja;while(1){Ma=d[sb]|0;zb=Ma>>>4;Ka=c[1344856+(zb<<2)>>2]|0;ua=c[1344856+(zb+4<<2)>>2]|0;zb=Ma&15;Ma=c[1344856+(zb<<2)>>2]|0;Ia=c[1344856+(zb+4<<2)>>2]|0;zb=d[sb+1|0]|0;wa=20-(zb>>>4)|0;Ca=20-(zb&15)|0;zb=Fa+112|0;Bb=sb+2|0;Ja=Ba;Mb=La;ta=rb;Pb=Da;Kb=0;Ob=Fa;while(1){Nb=d[Bb]|0;Lb=(ba(Mb,Ka)|0)+128+(ba(Pb,ua)|0)+(Nb>>>4<<28>>28<<wa)|0;Jb=Lb>>8;Cb=(ba(Ja,Ma)|0)+128+(ba(ta,Ia)|0)+(Nb<<28>>28<<Ca)|0;Nb=Cb>>8;if((Jb+32768|0)>>>0>65535>>>0){Rd=(Lb>>31^32767)&65535}else{Rd=Jb&65535}Sd=Rd<<16>>16;if((Nb+32768|0)>>>0>65535>>>0){Td=(Cb>>31^32767)&65535}else{Td=Nb&65535}Ud=Td<<16>>16;b[Ob>>1]=Rd;b[Ob+2>>1]=Td;Nb=Kb+1|0;if((Nb|0)<28){Bb=Bb+1|0;ta=Ja;Ja=Ud;Pb=Mb;Mb=Sd;Kb=Nb;Ob=Ob+4|0}else{break}}Ob=sa+1|0;if((Ob|0)<(Ha|0)){sb=sb+30|0;Ba=Ud;La=Sd;rb=Ja;Da=Mb;sa=Ob;Fa=zb}else{break}}Vd=F+Ea|0}else{Vd=ya}Fa=x-Vd|0;ra=Vd+(Fa>>>0>2>>>0?2:Fa)|0}else if((qa|0)==69637){g:do{if((I|0)>0){Fa=v;sa=F;Da=0;while(1){rb=sa;c[Fa+(Da*36|0)>>2]=(de((d[rb]|d[rb+1|0]<<8)<<16>>16|0)|0)<<16>>16;Wd=a[sa+2|0]|0;b[Fa+(Da*36|0)+4>>1]=Wd&255;if((Wd&255)>>>0>88>>>0){break}rb=sa+4|0;La=Da+1|0;if((La|0)<(c[y>>2]|0)){sa=rb;Da=La}else{Xd=rb;break g}}yDb(e,16,1946472,(w=i,i=i+8|0,c[w>>2]=Wd&255,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{Xd=F}}while(0);ya=na>>(pa^1);if((ya|0)<=0){ra=Xd;break}Ea=v;Da=v+4|0;sa=v;Fa=Ea+(pa*36|0)+4|0;zb=Ea+(pa*36|0)|0;Ea=Xd;Mb=ja;Ja=ya;while(1){rb=d[Ea]|0;La=rb>>>4;Ba=b[Da>>1]|0;sb=b[1269584+(Ba<<1)>>1]|0;Ha=(a[1270408+La|0]|0)+Ba|0;if((Ha|0)<0){Yd=0}else{Yd=(Ha|0)>88?88:Ha&65535}Ha=((La&4|0)==0?0:sb)+(sb>>3)|0;if((La&2|0)==0){Zd=Ha}else{Zd=Ha+(sb>>1)|0}if((La&1|0)==0){_d=Zd}else{_d=Zd+(sb>>2)|0}sb=(c[sa>>2]|0)+((La&8|0)==0?_d:-_d|0)|0;if((sb+32768|0)>>>0>65535>>>0){$d=(sb>>31^32767)&65535}else{$d=sb&65535}c[sa>>2]=$d<<16>>16;b[Da>>1]=Yd;b[Mb>>1]=$d;sb=b[Fa>>1]|0;La=b[1269584+(sb<<1)>>1]|0;Ha=(a[1270408+(rb&15)|0]|0)+sb|0;if((Ha|0)<0){ae=0}else{ae=(Ha|0)>88?88:Ha&65535}Ha=(La>>3)+((rb&4|0)==0?0:La)|0;if((rb&2|0)==0){be=Ha}else{be=Ha+(La>>1)|0}if((rb&1|0)==0){ce=be}else{ce=be+(La>>2)|0}La=(c[zb>>2]|0)+((rb&8|0)==0?ce:-ce|0)|0;if((La+32768|0)>>>0>65535>>>0){ee=(La>>31^32767)&65535}else{ee=La&65535}c[zb>>2]=ee<<16>>16;b[Fa>>1]=ae;b[Mb+2>>1]=ee;La=Ja-1|0;if((La|0)>0){Ea=Ea+1|0;Mb=Mb+4|0;Ja=La}else{break}}ra=Xd+ya|0}else if((qa|0)==1146374944){if((I|0)<=0){ra=F;break}Ja=(na|0)/28|0;Mb=(na|0)>27;Ea=s+((h|0)<0?h:0)|0;Fa=v;zb=F;Da=0;sa=32;while(1){La=(Da|0)!=0;if(Mb){rb=4-Da|0;Ha=Fa+(Da*36|0)+16|0;sb=Fa+(Da*36|0)+20|0;Ba=zb;Ob=c[ia+(Da<<2)>>2]|0;Kb=0;while(1){Pb=La?Ba+1|0:Ba;ta=d[Pb]|0;Bb=ta>>>4;Ca=ta&15;ta=Ob+56|0;Ia=Pb+rb|0;Ma=Ob;wa=0;while(1){if((Bb|0)==1){ge=(c[Ha>>2]|0)*60|0;C=647}else if((Bb|0)==2){ge=((c[sb>>2]|0)*-52|0)+((c[Ha>>2]|0)*115|0)|0;C=647}else if((Bb|0)==3){ge=((c[sb>>2]|0)*-55|0)+((c[Ha>>2]|0)*98|0)|0;C=647}else{he=0;C=648}if((C|0)==647){C=0;ua=ge+32>>6;if((ua|0)<-2097152){ie=-2097152}else{he=ua;C=648}}if((C|0)==648){C=0;ie=(he|0)>2097151?2097151:he}ua=d[Ia]|0;Ka=((La?ua>>>4:ua)<<28>>16>>Ca<<6)+ie|0;ua=Ka>>6;if((ua+32768|0)>>>0>65535>>>0){je=(Ka>>31^32767)&65535}else{je=ua&65535}b[Ma>>1]=je;c[sb>>2]=c[Ha>>2];c[Ha>>2]=Ka;Ka=wa+1|0;if((Ka|0)<28){Ia=Ia+1|0;Ma=Ma+2|0;wa=Ka}else{break}}wa=Pb+sa|0;Ma=Kb+1|0;if((Ma|0)<(Ja|0)){Ba=wa;Ob=ta;Kb=Ma}else{ke=wa;break}}}else{ke=zb}Kb=La?ke:Ea;Ob=Da+1|0;if((Ob|0)<(c[y>>2]|0)){zb=Kb;Da=Ob;sa=sa-1|0}else{ra=Kb;break}}}else if((qa|0)==69650){sa=c[e+96>>2]|0;if((sa|0)==0){Da=(I|0)>0;if(Da){le=F;me=0}else{ra=F;break}do{zb=le;c[r+(me<<6)>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+2|0;c[r+(me<<6)+4>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+4|0;c[r+(me<<6)+8>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+6|0;c[r+(me<<6)+12>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+8|0;c[r+(me<<6)+16>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+10|0;c[r+(me<<6)+20>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+12|0;c[r+(me<<6)+24>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+14|0;c[r+(me<<6)+28>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+16|0;c[r+(me<<6)+32>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+18|0;c[r+(me<<6)+36>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+20|0;c[r+(me<<6)+40>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+22|0;c[r+(me<<6)+44>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+24|0;c[r+(me<<6)+48>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+26|0;c[r+(me<<6)+52>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+28|0;c[r+(me<<6)+56>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;zb=le+30|0;c[r+(me<<6)+60>>2]=(de((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)<<16>>16;le=le+32|0;me=me+1|0;}while((me|0)<(I|0));if(!Da){ra=le;break}zb=v;Ea=le;Ja=0;while(1){Fa=Ea;c[zb+(Ja*36|0)+16>>2]=(de((d[Fa]|d[Fa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Fa=Ea+4|0;Mb=Ea+2|0;c[zb+(Ja*36|0)+20>>2]=(de((d[Mb]|d[Mb+1|0]<<8)<<16>>16|0)|0)<<16>>16;Mb=Ja+1|0;ya=c[y>>2]|0;if((Mb|0)<(ya|0)){Ea=Fa;Ja=Mb}else{ne=Fa;oe=ya;break}}}else{Ja=c[e+100>>2]|0;if((Ja|0)<(I<<5|0)){yDb(e,16,1944464,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ma=-1094995529;i=j;return ma|0}if(!((Ja|0)>-1)){yDb(0,0,1931480,(w=i,i=i+24|0,c[w>>2]=1929608,c[w+8>>2]=1927808,c[w+16>>2]=135,w)|0);i=w;Cd();return 0}if((I|0)>0){pe=sa;qe=0}else{ra=F;break}while(1){Ja=pe;c[r+(qe<<6)>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+2|0;c[r+(qe<<6)+4>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+4|0;c[r+(qe<<6)+8>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+6|0;c[r+(qe<<6)+12>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+8|0;c[r+(qe<<6)+16>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+10|0;c[r+(qe<<6)+20>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+12|0;c[r+(qe<<6)+24>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+14|0;c[r+(qe<<6)+28>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+16|0;c[r+(qe<<6)+32>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+18|0;c[r+(qe<<6)+36>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+20|0;c[r+(qe<<6)+40>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+22|0;c[r+(qe<<6)+44>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+24|0;c[r+(qe<<6)+48>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+26|0;c[r+(qe<<6)+52>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+28|0;c[r+(qe<<6)+56>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=pe+30|0;c[r+(qe<<6)+60>>2]=(de((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)<<16>>16;Ja=qe+1|0;if((Ja|0)<(I|0)){pe=pe+32|0;qe=Ja}else{ne=F;oe=I;break}}}if((oe|0)<=0){ra=ne;break}sa=(na|0)/14|0;Ja=(na|0)>13;Ea=v;zb=ne;Da=0;ya=oe;while(1){if(Ja){Fa=Ea+(Da*36|0)+16|0;Mb=Ea+(Da*36|0)+20|0;Kb=zb;Ob=c[ia+(Da<<2)>>2]|0;Ba=0;while(1){Ha=d[Kb]|0;sb=Ha&15;rb=Ha>>>4<<1&14;wa=c[r+(Da<<6)+(rb<<2)>>2]|0;Ma=c[r+(Da<<6)+((rb|1)<<2)>>2]|0;rb=Kb+1|0;Ia=Ob;Ca=Ha;Ha=0;while(1){if((Ha&1|0)==0){Bb=d[rb]|0;re=Bb;se=Bb>>>4;te=rb+1|0}else{re=Ca;se=Ca;te=rb}Bb=c[Fa>>2]|0;Qb=ba(Bb,wa)|0;Ka=((ba(c[Mb>>2]|0,Ma)|0)+Qb>>11)+(se<<28>>28<<sb)|0;if((Ka+32768|0)>>>0>65535>>>0){ue=(Ka>>31^32767)&65535}else{ue=Ka&65535}b[Ia>>1]=ue;c[Mb>>2]=Bb;c[Fa>>2]=ue<<16>>16;Bb=Ha+1|0;if((Bb|0)<14){rb=te;Ia=Ia+2|0;Ca=re;Ha=Bb}else{break}}Ha=Ba+1|0;if((Ha|0)<(sa|0)){Kb=te;Ob=Ob+28|0;Ba=Ha}else{break}}ve=te;we=c[y>>2]|0}else{ve=zb;we=ya}Ba=Da+1|0;if((Ba|0)<(we|0)){zb=ve;Da=Ba;ya=we}else{ra=ve;break}}}else if((qa|0)==1095123744){ya=c[e+96>>2]|0;do{if((ya|0)==0){C=598}else{if((c[e+100>>2]|0)!=1){C=598;break}Da=a[ya]|0;zb=Da&255;if(Da<<24>>24==0){C=598;break}Da=(na|0)/(zb|0)|0;if((Da|0)>0){xe=zb;ye=Da;ze=zb;C=600}}}while(0);if((C|0)==598){xe=na;ye=1;ze=na;C=600}if((C|0)==600){ya=(ze|0)/16|0;zb=v;Da=(xe|0)>15;sa=F;Ea=0;Ja=I;while(1){if((Ja|0)>0){Ba=Ea<<4;Ob=sa;Kb=0;while(1){Fa=zb+(Kb*36|0)+16|0;Mb=c[Fa>>2]|0;La=zb+(Kb*36|0)+20|0;Ha=c[La>>2]|0;if(Da){Ca=Ob;Ia=Mb;rb=Ha;sb=(c[ia+(Kb<<2)>>2]|0)+(Ba<<1)|0;Ma=0;while(1){wa=d[Ca]|0;ta=wa>>>4;Pb=wa&15;Bb=b[1273456+(Pb<<1)>>1]|0;Ka=b[1273488+(Pb<<1)>>1]|0;Pb=Ca+1|0;Qb=Ia;ua=rb;Nb=wa;wa=sb;Cb=0;while(1){if((Cb&1|0)==0){Jb=d[Pb]|0;Ae=Jb;Be=Jb>>>4;Ce=Pb+1|0}else{Ae=Nb;Be=Nb;Ce=Pb}Jb=(ba(ua,Ka)|0)+(ba(Qb,Bb)|0)+(Be<<28>>28<<ta<<11)|0;Lb=Jb>>11;if((Lb+32768|0)>>>0>65535>>>0){De=(Jb>>31^32767)&65535}else{De=Lb&65535}b[wa>>1]=De;Ee=De<<16>>16;Lb=Cb+1|0;if((Lb|0)<16){Pb=Ce;ua=Qb;Qb=Ee;Nb=Ae;wa=wa+2|0;Cb=Lb}else{break}}Cb=Ma+1|0;if((Cb|0)<(ya|0)){Ca=Ce;Ia=Ee;rb=Qb;sb=sb+32|0;Ma=Cb}else{Fe=Ce;Ge=Ee;He=Qb;break}}}else{Fe=Ob;Ge=Mb;He=Ha}c[Fa>>2]=Ge;c[La>>2]=He;Ma=Kb+1|0;sb=c[y>>2]|0;if((Ma|0)<(sb|0)){Ob=Fe;Kb=Ma}else{Ie=Fe;Je=sb;break}}}else{Ie=sa;Je=Ja}Kb=Ea+1|0;if((Kb|0)<(ye|0)){sa=Ie;Ea=Kb;Ja=Je}else{break}}}ra=s+((-h|0)>0?0:h)|0}else if((qa|0)==69636){do{if((c[v+216>>2]|0)==3){if((I|0)<=0){break}Ja=(na|0)/2|0;Ea=(na|0)>1;sa=v;ya=-Ja|0;Da=Ja+((ya|0)>-1?ya:-1)+1|0;ya=F;zb=0;Kb=I;while(1){if(Ea){Ob=sa+(zb*36|0)+4|0;Ba=sa+(zb*36|0)|0;sb=ya;Ma=c[ia+(zb<<2)>>2]|0;rb=Ja;while(1){Ia=a[sb]|0;Ca=b[Ob>>1]|0;Cb=(Ia&255)>>>4&255;wa=(a[1270408+Cb|0]|0)+Ca|0;if((wa|0)<0){Ke=0}else{Ke=(wa|0)>88?88:wa&65535}wa=(ba(Cb<<1&14|1,b[1269584+(Ca<<1)>>1]|0)|0)>>3;Ca=(c[Ba>>2]|0)+((Cb&8|0)==0?wa:-wa|0)|0;if((Ca+32768|0)>>>0>65535>>>0){Le=(Ca>>31^32767)&65535}else{Le=Ca&65535}Ca=Le<<16>>16;c[Ba>>2]=Ca;b[Ob>>1]=Ke;b[Ma>>1]=Le;wa=b[Ob>>1]|0;Cb=Ia&15;Ia=(a[1270408+Cb|0]|0)+wa|0;if((Ia|0)<0){Me=0}else{Me=(Ia|0)>88?88:Ia&65535}Ia=(ba(b[1269584+(wa<<1)>>1]|0,Cb<<1&14|1)|0)>>3;wa=Ca+((Cb&8|0)==0?Ia:-Ia|0)|0;if((wa+32768|0)>>>0>65535>>>0){Ne=(wa>>31^32767)&65535}else{Ne=wa&65535}c[Ba>>2]=Ne<<16>>16;b[Ob>>1]=Me;b[Ma+2>>1]=Ne;wa=rb-1|0;if((wa|0)>0){sb=sb+1|0;Ma=Ma+4|0;rb=wa}else{break}}Oe=ya+Da|0;Pe=c[y>>2]|0}else{Oe=ya;Pe=Kb}rb=zb+1|0;if((rb|0)<(Pe|0)){ya=Oe;zb=rb;Kb=Pe}else{break}}}else{if((na|0)<=1){break}Kb=v;zb=oa?2:1;ya=F;Da=ja;Ja=(na|0)/2|0;sa=I;while(1){if((sa|0)>0){Ea=ya;rb=Da;Ma=0;while(1){sb=Ea+1|0;Ob=a[Ea]|0;Ba=Kb+(Ma*36|0)+4|0;La=b[Ba>>1]|0;Fa=(Ob&255)>>>4&255;Ha=(a[1270408+Fa|0]|0)+La|0;if((Ha|0)<0){Qe=0}else{Qe=(Ha|0)>88?88:Ha&65535}Ha=(ba(Fa<<1&14|1,b[1269584+(La<<1)>>1]|0)|0)>>3;La=Kb+(Ma*36|0)|0;Mb=(c[La>>2]|0)+((Fa&8|0)==0?Ha:-Ha|0)|0;if((Mb+32768|0)>>>0>65535>>>0){Re=(Mb>>31^32767)&65535}else{Re=Mb&65535}Mb=Re<<16>>16;c[La>>2]=Mb;b[Ba>>1]=Qe;Ha=rb+2|0;b[rb>>1]=Re;Fa=b[Ba>>1]|0;wa=Ob&15;Ob=(a[1270408+wa|0]|0)+Fa|0;if((Ob|0)<0){Se=0}else{Se=(Ob|0)>88?88:Ob&65535}Ob=(ba(b[1269584+(Fa<<1)>>1]|0,wa<<1&14|1)|0)>>3;Fa=Mb+((wa&8|0)==0?Ob:-Ob|0)|0;if((Fa+32768|0)>>>0>65535>>>0){Te=(Fa>>31^32767)&65535}else{Te=Fa&65535}c[La>>2]=Te<<16>>16;b[Ba>>1]=Se;b[rb+(zb<<1)>>1]=Te;Ba=Ma+1|0;La=c[y>>2]|0;if((Ba|0)<(La|0)){Ea=sb;rb=Ha;Ma=Ba}else{Ue=sb;Ve=Ha;We=La;break}}}else{Ue=ya;Ve=Da;We=sa}Ma=Ja-1|0;if((Ma|0)>0){ya=Ue;Da=Ve+(We<<1)|0;Ja=Ma;sa=We}else{break}}}}while(0);ra=s+((-h|0)>0?0:h)|0}else if((qa|0)==69657){if((I|0)>0){Xe=F;Ye=0}else{ra=F;break}while(1){sa=ia+(Ye<<2)|0;Ja=c[sa>>2]|0;Da=Xe;ya=(d[Da]|d[Da+1|0]<<8)<<16>>16;Da=ya&15;c[p>>2]=c[1344856+(Da<<2)>>2];c[p+16>>2]=c[1344856+(Da+4<<2)>>2];b[Ja>>1]=ya&-16;ya=Xe+2|0;Da=(d[ya]|d[ya+1|0]<<8)<<16>>16;c[q>>2]=20-(Da&15);b[Ja+2>>1]=Da&-16;Da=Xe+4|0;ya=(d[Da]|d[Da+1|0]<<8)<<16>>16;Da=ya&15;c[p+4>>2]=c[1344856+(Da<<2)>>2];c[p+20>>2]=c[1344856+(Da+4<<2)>>2];b[Ja+64>>1]=ya&-16;ya=Xe+6|0;Da=(d[ya]|d[ya+1|0]<<8)<<16>>16;c[q+4>>2]=20-(Da&15);b[Ja+66>>1]=Da&-16;Da=Xe+8|0;ya=(d[Da]|d[Da+1|0]<<8)<<16>>16;Da=ya&15;c[p+8>>2]=c[1344856+(Da<<2)>>2];c[p+24>>2]=c[1344856+(Da+4<<2)>>2];b[Ja+128>>1]=ya&-16;ya=Xe+10|0;Da=(d[ya]|d[ya+1|0]<<8)<<16>>16;c[q+8>>2]=20-(Da&15);b[Ja+130>>1]=Da&-16;Da=Xe+12|0;ya=(d[Da]|d[Da+1|0]<<8)<<16>>16;Da=ya&15;c[p+12>>2]=c[1344856+(Da<<2)>>2];c[p+28>>2]=c[1344856+(Da+4<<2)>>2];b[Ja+192>>1]=ya&-16;ya=Xe+14|0;Da=(d[ya]|d[ya+1|0]<<8)<<16>>16;c[q+12>>2]=20-(Da&15);b[Ja+194>>1]=Da&-16;Da=Xe+16|0;Ja=2;while(1){ya=Da;zb=(c[sa>>2]|0)+(Ja<<1)|0;Kb=0;while(1){Ma=d[ya]|0;rb=c[q+(Kb<<2)>>2]|0;Ea=b[zb-2>>1]|0;La=c[p+(Kb<<2)>>2]|0;Ha=ba(Ea,La)|0;sb=c[p+16+(Kb<<2)>>2]|0;Ba=Ha+128+(Ma>>>4<<28>>28<<rb)+(ba(b[zb-4>>1]|0,sb)|0)|0;Ha=Ba>>8;if((Ha+32768|0)>>>0>65535>>>0){Ze=(Ba>>31^32767)&65535}else{Ze=Ha&65535}b[zb>>1]=Ze;Ha=(Ma<<28>>28<<rb)+128+(ba(La,Ze<<16>>16)|0)+(ba(Ea,sb)|0)|0;sb=Ha>>8;if((sb+32768|0)>>>0>65535>>>0){_e=(Ha>>31^32767)&65535}else{_e=sb&65535}b[zb+2>>1]=_e;sb=Kb+1|0;if((sb|0)>=4){break}ya=ya+1|0;zb=zb+64|0;Kb=sb}Kb=Ja+2|0;if((Kb|0)<32){Da=Da+4|0;Ja=Kb}else{break}}Ja=Xe+76|0;Da=Ye+1|0;if((Da|0)<(I|0)){Xe=Ja;Ye=Da}else{ra=Ja;break}}}else if((qa|0)==69658){if((I|0)>0){Ja=F;Da=0;while(1){sa=d[Ja]|0;Kb=sa>>>4;c[l+(Da<<3)>>2]=c[1344856+(Kb<<2)>>2];c[l+(Da<<3)+4>>2]=c[1344856+(Kb+4<<2)>>2];Kb=Ja+1|0;c[m+(Da<<2)>>2]=20-(sa&15);sa=Da+1|0;if((sa|0)<(I|0)){Ja=Kb;Da=sa}else{$e=Kb;break}}}else{$e=F}Da=(na|0)/2|0;if((na|0)>1){Ja=n|0;Kb=n+4|0;sa=v;zb=$e;ya=0;sb=ja;Ha=I;while(1){Ea=zb+1|0;La=d[zb]|0;c[Ja>>2]=La;if(oa){c[Kb>>2]=d[Ea]|0;af=zb+2|0}else{af=Ea}h:do{if((Ha|0)>0){Ea=sb;rb=0;Ma=La;while(1){Ba=sa+(rb*36|0)+16|0;Fa=c[Ba>>2]|0;Ob=ba(c[l+(rb<<3)>>2]|0,Fa)|0;wa=sa+(rb*36|0)+20|0;Mb=Ob+128+(Ma>>>4<<28>>28<<c[m+(rb<<2)>>2])+(ba(c[l+(rb<<3)+4>>2]|0,c[wa>>2]|0)|0)|0;Ob=Mb>>8;c[wa>>2]=Fa;if((Ob+32768|0)>>>0>65535>>>0){bf=(Mb>>31^32767)&65535}else{bf=Ob&65535}c[Ba>>2]=bf<<16>>16;cf=Ea+2|0;b[Ea>>1]=bf;Ba=rb+1|0;df=c[y>>2]|0;if((Ba|0)>=(df|0)){break}Ea=cf;rb=Ba;Ma=c[n+(Ba<<2)>>2]|0}if((df|0)>0){ef=cf;ff=0;gf=La}else{hf=cf;jf=df;break}while(1){Ma=sa+(ff*36|0)+16|0;rb=c[Ma>>2]|0;Ea=ba(c[l+(ff<<3)>>2]|0,rb)|0;Ba=sa+(ff*36|0)+20|0;Ob=Ea+128+(gf<<28>>28<<c[m+(ff<<2)>>2])+(ba(c[l+(ff<<3)+4>>2]|0,c[Ba>>2]|0)|0)|0;Ea=Ob>>8;c[Ba>>2]=rb;if((Ea+32768|0)>>>0>65535>>>0){kf=(Ob>>31^32767)&65535}else{kf=Ea&65535}c[Ma>>2]=kf<<16>>16;Ma=ef+2|0;b[ef>>1]=kf;Ea=ff+1|0;Ob=c[y>>2]|0;if((Ea|0)>=(Ob|0)){hf=Ma;jf=Ob;break h}ef=Ma;ff=Ea;gf=c[n+(Ea<<2)>>2]|0}}else{hf=sb;jf=Ha}}while(0);La=ya+1|0;if((La|0)<(Da|0)){zb=af;ya=La;sb=hf;Ha=jf}else{break}}}ra=s+((-h|0)>0?0:h)|0}else if((qa|0)==1330333984){if((x|0)==(F|0)){ra=x;break}Ha=v;sb=v+4|0;ya=v;zb=Ha+(pa*36|0)+4|0;Da=Ha+(pa*36|0)|0;Ha=F;sa=ja;while(1){Kb=Ha+1|0;Ja=d[Ha]|0;La=Ja>>>4;Ea=b[sb>>1]|0;Ma=(a[1270408+La|0]|0)+Ea|0;if((Ma|0)<0){lf=0}else{lf=(Ma|0)>48?48:Ma&65535}Ma=(ba(La<<1&14|1,b[1270080+(Ea<<1)>>1]|0)|0)>>3;Ea=(c[ya>>2]|0)+((La&8|0)==0?Ma:-Ma|0)|0;if((Ea|0)<-2048){mf=-2048}else{mf=(Ea|0)>2047?2047:Ea}c[ya>>2]=mf;b[sb>>1]=lf;b[sa>>1]=mf<<4;Ea=b[zb>>1]|0;Ma=(a[1270408+(Ja&15)|0]|0)+Ea|0;if((Ma|0)<0){nf=0}else{nf=(Ma|0)>48?48:Ma&65535}Ma=(ba(b[1270080+(Ea<<1)>>1]|0,Ja<<1&14|1)|0)>>3;Ea=(c[Da>>2]|0)+((Ja&8|0)==0?Ma:-Ma|0)|0;if((Ea|0)<-2048){of=-2048}else{of=(Ea|0)>2047?2047:Ea}c[Da>>2]=of;b[zb>>1]=nf;b[sa+2>>1]=of<<4;if((x|0)==(Kb|0)){ra=x;break}else{Ha=Kb;sa=sa+4|0}}}else if((qa|0)==69634){sa=ja+((ba(I,na)|0)<<1)|0;Ha=F+10|0;zb=(d[Ha]|d[Ha+1|0]<<8)<<16>>16<<16>>16;Ha=v;c[Ha>>2]=zb;Da=F+12|0;sb=(d[Da]|d[Da+1|0]<<8)<<16>>16<<16>>16;Da=v+36|0;c[Da>>2]=sb;ya=a[F+14|0]|0;Kb=v+4|0;b[Kb>>1]=ya&255;Ea=a[F+15|0]|0;Ma=v+40|0;b[Ma>>1]=Ea&255;if((ya&255)>>>0>88>>>0|(Ea&255)>>>0>88>>>0){yDb(e,16,1950328,(w=i,i=i+16|0,c[w>>2]=ya&255,c[w+8>>2]=Ea&255,w)|0);i=w;ma=-1094995529;i=j;return ma|0}Ea=F+16|0;if(ja>>>0<sa>>>0){ya=Ea;Ja=0;La=0;Ob=ja;rb=zb;zb=sb;while(1){if((Ja|0)==0){sb=a[ya]|0;pf=(sb&255)>>>4;qf=sb&15;rf=1;sf=ya+1|0}else{pf=La;qf=La;rf=0;sf=ya}sb=b[Kb>>1]|0;Ba=qf<<24>>24;Mb=(a[1270408+Ba|0]|0)+sb|0;if((Mb|0)<0){tf=0}else{tf=(Mb|0)>88?88:Mb&65535}Mb=(ba(b[1269584+(sb<<1)>>1]|0,Ba<<1&14|1)|0)>>3;sb=rb+((Ba&8|0)==0?Mb:-Mb|0)|0;if((sb+32768|0)>>>0>65535>>>0){uf=(sb>>31^32767)&65535}else{uf=sb&65535}sb=uf<<16>>16;c[Ha>>2]=sb;b[Kb>>1]=tf;if(rf){vf=pf;wf=pf;xf=0;yf=sf}else{Mb=a[sf]|0;vf=(Mb&255)>>>4;wf=Mb&15;xf=1;yf=sf+1|0}Mb=b[Ma>>1]|0;Ba=wf<<24>>24;Fa=(a[1270408+Ba|0]|0)+Mb|0;if((Fa|0)<0){zf=0}else{zf=(Fa|0)>88?88:Fa&65535}Fa=(ba(b[1269584+(Mb<<1)>>1]|0,Ba<<1&14|1)|0)>>3;Mb=zb+((Ba&8|0)==0?Fa:-Fa|0)|0;if((Mb+32768|0)>>>0>65535>>>0){Af=(Mb>>31^32767)&65535}else{Af=Mb&65535}Mb=Af<<16>>16;c[Da>>2]=Mb;b[Ma>>1]=zf;b[Ob>>1]=uf+Af;b[Ob+2>>1]=uf-Af;if(xf){Bf=vf;Cf=vf;Df=0;Ef=yf}else{Fa=a[yf]|0;Bf=(Fa&255)>>>4;Cf=Fa&15;Df=1;Ef=yf+1|0}Fa=b[Kb>>1]|0;Ba=Cf<<24>>24;wa=(a[1270408+Ba|0]|0)+Fa|0;if((wa|0)<0){Ff=0}else{Ff=(wa|0)>88?88:wa&65535}wa=(ba(b[1269584+(Fa<<1)>>1]|0,Ba<<1&14|1)|0)>>3;Fa=sb+((Ba&8|0)==0?wa:-wa|0)|0;if((Fa+32768|0)>>>0>65535>>>0){Gf=(Fa>>31^32767)&65535}else{Gf=Fa&65535}Fa=Gf<<16>>16;c[Ha>>2]=Fa;b[Kb>>1]=Ff;b[Ob+4>>1]=Gf+Af;wa=Ob+8|0;b[Ob+6>>1]=Gf-Af;if(wa>>>0<sa>>>0){ya=Ef;Ja=Df;La=Bf;Ob=wa;rb=Fa;zb=Mb}else{Hf=Ef;break}}}else{Hf=Ea}zb=Hf;if((zb-s&1|0)==0){ra=Hf;break}rb=x-zb|0;ra=Hf+(rb>>>0>1>>>0?1:rb)|0}else if((qa|0)==69655){rb=na>>(pa^1);if((rb|0)<=0){ra=F;break}zb=v;Ob=v+4|0;La=v;Ja=zb+(pa*36|0)+4|0;ya=zb+(pa*36|0)|0;zb=F;sa=ja;Kb=rb;while(1){Ha=a[zb]|0;Ma=b[Ob>>1]|0;Da=(Ha&255)>>>4&255;Mb=(a[1270408+Da|0]|0)+Ma|0;if((Mb|0)<0){If=0}else{If=(Mb|0)>88?88:Mb&65535}Mb=(ba(Da<<1&14|1,b[1269584+(Ma<<1)>>1]|0)|0)>>6;Ma=(c[La>>2]|0)+((Da&8|0)==0?Mb:-Mb|0)|0;if((Ma+32768|0)>>>0>65535>>>0){Jf=(Ma>>31^32767)&65535}else{Jf=Ma&65535}c[La>>2]=Jf<<16>>16;b[Ob>>1]=If;b[sa>>1]=Jf;Ma=b[Ja>>1]|0;Mb=Ha&15;Ha=(a[1270408+Mb|0]|0)+Ma|0;if((Ha|0)<0){Kf=0}else{Kf=(Ha|0)>88?88:Ha&65535}Ha=(ba(b[1269584+(Ma<<1)>>1]|0,Mb<<1&14|1)|0)>>6;Ma=(c[ya>>2]|0)+((Mb&8|0)==0?Ha:-Ha|0)|0;if((Ma+32768|0)>>>0>65535>>>0){Lf=(Ma>>31^32767)&65535}else{Lf=Ma&65535}c[ya>>2]=Lf<<16>>16;b[Ja>>1]=Kf;b[sa+2>>1]=Lf;Ma=Kb-1|0;if((Ma|0)>0){zb=zb+1|0;sa=sa+4|0;Kb=Ma}else{break}}ra=F+rb|0}else if((qa|0)==69651){Kb=F;sa=(d[Kb]|d[Kb+1|0]<<8)<<16>>16<<16>>16;Kb=v;c[Kb>>2]=sa;zb=F+2|0;Ja=(d[zb]|d[zb+1|0]<<8)<<16>>16;zb=v+4|0;b[zb>>1]=Ja;if((Ja&65535)>>>0>88>>>0){yDb(e,16,1946472,(w=i,i=i+8|0,c[w>>2]=Ja<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}ya=F+8|0;Ob=na>>(pa^1);if((Ob|0)<=0){ra=ya;break}La=Ob+8|0;Ea=ya;ya=ja;Ma=Ob;Ob=sa;sa=Ja;while(1){Ja=a[Ea]|0;Ha=sa<<16>>16;Mb=(Ja&255)>>>4&255;Da=(a[1270408+Mb|0]|0)+Ha|0;if((Da|0)<0){Mf=0}else{Mf=(Da|0)>88?88:Da&65535}Da=(ba(Mb<<1&14|1,b[1269584+(Ha<<1)>>1]|0)|0)>>3;Ha=Ob+((Mb&8|0)==0?Da:-Da|0)|0;if((Ha+32768|0)>>>0>65535>>>0){Nf=(Ha>>31^32767)&65535}else{Nf=Ha&65535}Ha=Nf<<16>>16;c[Kb>>2]=Ha;b[zb>>1]=Mf;b[ya>>1]=Nf;Da=b[zb>>1]|0;Mb=Ja&15;Ja=(a[1270408+Mb|0]|0)+Da|0;if((Ja|0)<0){Of=0}else{Of=(Ja|0)>88?88:Ja&65535}Ja=(ba(b[1269584+(Da<<1)>>1]|0,Mb<<1&14|1)|0)>>3;Da=Ha+((Mb&8|0)==0?Ja:-Ja|0)|0;if((Da+32768|0)>>>0>65535>>>0){Pf=(Da>>31^32767)&65535}else{Pf=Da&65535}Da=Pf<<16>>16;c[Kb>>2]=Da;b[zb>>1]=Of;b[ya+2>>1]=Pf;Ja=Ma-1|0;if((Ja|0)<=0){break}Ea=Ea+1|0;ya=ya+4|0;Ma=Ja;Ob=Da;sa=b[zb>>1]|0}ra=F+La|0}else if((qa|0)==69635){i:do{if((I|0)>0){zb=v;sa=F;Ob=ja;Ma=0;while(1){ya=sa;Ea=(d[ya]|d[ya+1|0]<<8)<<16>>16;b[Ob>>1]=Ea;c[zb+(Ma*36|0)>>2]=Ea<<16>>16;Ea=sa+2|0;Qf=(d[Ea]|d[Ea+1|0]<<8)<<16>>16;b[zb+(Ma*36|0)+4>>1]=Qf;if((Qf&65535)>>>0>88>>>0){break}Ea=sa+4|0;ya=Ob+2|0;Kb=Ma+1|0;if((Kb|0)<(c[y>>2]|0)){sa=Ea;Ob=ya;Ma=Kb}else{Rf=Ea;Sf=ya;break i}}yDb(e,16,1957032,(w=i,i=i+16|0,c[w>>2]=Ma,c[w+8>>2]=Qf<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{Rf=F;Sf=ja}}while(0);La=na-1>>(pa^1);if((La|0)<=0){ra=Rf;break}Ob=v;sa=v+4|0;zb=v;ya=Ob+(pa*36|0)+4|0;Ea=Ob+(pa*36|0)|0;Ob=Rf;Kb=Sf;rb=La;while(1){Da=a[Ob]|0;Ja=b[sa>>1]|0;Mb=(Da&255)>>>4&255;Ha=(a[1270408+Mb|0]|0)+Ja|0;if((Ha|0)<0){Tf=0}else{Tf=(Ha|0)>88?88:Ha&65535}Ha=(ba(Mb<<1&14|1,b[1269584+(Ja<<1)>>1]|0)|0)>>3;Ja=(c[zb>>2]|0)+((Mb&8|0)==0?Ha:-Ha|0)|0;if((Ja+32768|0)>>>0>65535>>>0){Uf=(Ja>>31^32767)&65535}else{Uf=Ja&65535}c[zb>>2]=Uf<<16>>16;b[sa>>1]=Tf;b[Kb>>1]=Uf;Ja=b[ya>>1]|0;Ha=Da&15;Da=(a[1270408+Ha|0]|0)+Ja|0;if((Da|0)<0){Vf=0}else{Vf=(Da|0)>88?88:Da&65535}Da=(ba(b[1269584+(Ja<<1)>>1]|0,Ha<<1&14|1)|0)>>3;Ja=(c[Ea>>2]|0)+((Ha&8|0)==0?Da:-Da|0)|0;if((Ja+32768|0)>>>0>65535>>>0){Wf=(Ja>>31^32767)&65535}else{Wf=Ja&65535}c[Ea>>2]=Wf<<16>>16;b[ya>>1]=Vf;b[Kb+2>>1]=Wf;Ja=rb-1|0;if((Ja|0)>0){Ob=Ob+1|0;Kb=Kb+4|0;rb=Ja}else{break}}ra=Rf+La|0}else if((qa|0)==69644){rb=na>>(pa^1);if((rb|0)<=0){ra=F;break}Kb=v;Ob=v+8|0;ya=v;Ea=Kb+(pa*36|0)+8|0;sa=Kb+(pa*36|0)|0;Kb=F;zb=ja;Ja=rb;while(1){Da=a[Kb]|0;Ha=(Da&255)>>>4&255;Mb=Ha&7;Fa=c[Ob>>2]|0;wa=(ba(Mb<<1|1,Fa)|0)>>3;Ba=((Ha&8|0)!=0?-wa|0:wa)+(((c[ya>>2]|0)*254|0)>>8)|0;if((Ba+32768|0)>>>0>65535>>>0){Xf=(Ba>>31^32767)&65535}else{Xf=Ba&65535}c[ya>>2]=Xf<<16>>16;Ba=(ba(b[1273728+(Mb<<1)>>1]|0,Fa)|0)>>8;if((Ba|0)<511){Yf=511}else{Yf=(Ba|0)>32767?32767:Ba}c[Ob>>2]=Yf;b[zb>>1]=Xf;Ba=Da&15;Da=Ba&7;Fa=c[Ea>>2]|0;Mb=(ba(Fa,Da<<1|1)|0)>>3;wa=(((c[sa>>2]|0)*254|0)>>8)+((Ba&8|0)!=0?-Mb|0:Mb)|0;if((wa+32768|0)>>>0>65535>>>0){Zf=(wa>>31^32767)&65535}else{Zf=wa&65535}c[sa>>2]=Zf<<16>>16;wa=(ba(b[1273728+(Da<<1)>>1]|0,Fa)|0)>>8;if((wa|0)<511){_f=511}else{_f=(wa|0)>32767?32767:wa}c[Ea>>2]=_f;b[zb+2>>1]=Zf;wa=Ja-1|0;if((wa|0)>0){Kb=Kb+1|0;zb=zb+4|0;Ja=wa}else{break}}ra=F+rb|0}else if((qa|0)==69661){if((x|0)==(F|0)){ra=x;break}Ja=v;zb=v+4|0;Kb=v;Ea=Ja+(pa*36|0)+4|0;sa=Ja+(pa*36|0)|0;Ja=F;Ob=ja;while(1){ya=Ja+1|0;La=a[Ja]|0;wa=b[zb>>1]|0;Fa=(La&255)>>>4&255;Da=(a[1270408+Fa|0]|0)+wa|0;if((Da|0)<0){$f=0}else{$f=(Da|0)>88?88:Da&65535}Da=(ba(Fa<<1&14|1,b[1269584+(wa<<1)>>1]|0)|0)>>3;wa=(c[Kb>>2]|0)+((Fa&8|0)==0?Da:-Da|0)|0;if((wa+32768|0)>>>0>65535>>>0){ag=(wa>>31^32767)&65535}else{ag=wa&65535}c[Kb>>2]=ag<<16>>16;b[zb>>1]=$f;b[Ob>>1]=ag;wa=b[Ea>>1]|0;Da=La&15;La=(a[1270408+Da|0]|0)+wa|0;if((La|0)<0){bg=0}else{bg=(La|0)>88?88:La&65535}La=(ba(b[1269584+(wa<<1)>>1]|0,Da<<1&14|1)|0)>>3;wa=(c[sa>>2]|0)+((Da&8|0)==0?La:-La|0)|0;if((wa+32768|0)>>>0>65535>>>0){cg=(wa>>31^32767)&65535}else{cg=wa&65535}c[sa>>2]=cg<<16>>16;b[Ea>>1]=bg;b[Ob+2>>1]=cg;if((x|0)==(ya|0)){ra=x;break}else{Ja=ya;Ob=Ob+4|0}}}else{ma=-1;i=j;return ma|0}}while(0);if((c[t>>2]|0)!=0&(ra|0)==(s|0)){yDb(e,16,1941664,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{c[g>>2]=1;ma=ra-s|0;i=j;return ma|0}}}while(0);yDb(e,16,1961536,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ma=-1094995529;i=j;return ma|0}function Ugb(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;f=b+60|0;g=c[f>>2]|0;h=b+416|0;if((c[h>>2]|0)>2){yDb(b,16,2327648,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=e;return k|0}l=c[b+600>>2]|0;if(l>>>0>16>>>0){yDb(b,16,2303568,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=e;return k|0}do{if((l|0)==0){m=14}else{n=1<<l;o=n<<10;p=WDb(o)|0;c[g+216>>2]=p;if(!((p|0)!=0|(o|0)==0)){yDb(b,16,2348e3,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-12;break}o=40<<l;p=WDb(o)|0;c[g+220>>2]=p;if(!((p|0)!=0|(o|0)==0)){yDb(b,16,2348e3,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-12;break}o=n<<3;n=WDb(o)|0;c[g+224>>2]=n;if(!((n|0)!=0|(o|0)==0)){yDb(b,16,2348e3,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-12;break}o=WDb(65536)|0;c[g+228>>2]=o;if((o|0)!=0){m=14;break}yDb(b,16,2348e3,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-12}}while(0);a:do{if((m|0)==14){g=b+12|0;l=b+792|0;c[l>>2]=u0a(c[(c[g>>2]|0)+12>>2]|0)|0;switch(c[(c[g>>2]|0)+12>>2]|0){case 69638:{g=c[h>>2]|0;o=b+424|0;c[o>>2]=(((g*-14|0)+2048|0)/(g|0)|0)+2;c[l>>2]=4;c[b+432>>2]=1024;g=WDb(48)|0;c[b+96>>2]=g;if((g|0)==0){q=-12;break a}c[b+100>>2]=32;n=g;x=c[o>>2]&65535;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+2|0;x=7;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+4|0;x=d[1273768]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+6|0;x=a[1273760]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+8|0;x=d[1273769]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+10|0;x=a[1273761]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+12|0;x=d[1273770]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+14|0;x=a[1273762]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+16|0;x=d[1273771]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+18|0;x=a[1273763]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+20|0;x=d[1273772]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+22|0;x=a[1273764]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+24|0;x=d[1273773]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+26|0;x=a[1273765]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+28|0;x=d[1273774]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;n=g+30|0;x=a[1273766]<<2;a[n]=x;x=x>>8;a[n+1|0]=x;k=0;i=e;return k|0};case 69632:{c[b+424>>2]=64;c[b+432>>2]=(c[h>>2]|0)*34|0;k=0;i=e;return k|0};case 69645:{n=c[b+412>>2]|0;if(!((n|0)==11025|(n|0)==22050|(n|0)==44100)){yDb(b,16,2285592,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-22;break a}c[b+424>>2]=((n|0)/11025|0)<<9;k=0;i=e;return k|0};case 69633:{n=c[h>>2]<<2;c[b+424>>2]=((1024-n<<3|0)/(n|0)|0)+1;c[b+432>>2]=1024;c[l>>2]=4;k=0;i=e;return k|0};case 69646:{c[b+424>>2]=2048/(c[h>>2]|0)|0;c[b+432>>2]=1024;k=0;i=e;return k|0};default:{q=-22;break a}}}}while(0);b=c[f>>2]|0;$Db(b+216|0);$Db(b+220|0);$Db(b+224|0);$Db(b+228|0);k=q;i=e;return k|0}function Vgb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0;k=i;i=i+64|0;l=k|0;m=f+60|0;n=c[m>>2]|0;o=c[h>>2]|0;p=o;q=c[h+64>>2]|0;r=f+416|0;s=c[r>>2]|0;t=(s|0)==2|0;if((c[f+48>>2]|0)==69645){u=((ba((c[h+76>>2]<<2)+18|0,s)|0)+9|0)/8|0}else{u=c[f+432>>2]|0}s=r0a(f,g,u,(u|0)<0|0?-1:0)|0;if((s|0)<0){v=s;i=k;return v|0}s=c[g+24>>2]|0;w=f+12|0;a:do{switch(c[(c[w>>2]|0)+12>>2]|0){case 69632:{y=0;do{if((c[r>>2]|0)>0){z=n;A=f+600|0;B=l|0;C=(u&268435456|0)!=0?0:s;D=32;E=0;F=0;while(1){G=z+(E*36|0)+12|0;H=(c[G>>2]|0)>>>7&511;if((D|0)>9){I=D-9|0;J=F<<9|H;K=C}else{L=C;x=fe(H>>>((9-D|0)>>>0)|F<<D|0)|0;a[L]=x;x=x>>8;a[L+1|0]=x;x=x>>8;a[L+2|0]=x;x=x>>8;a[L+3|0]=x;I=D+23|0;J=H;K=C+4|0}y=J;H=z+(E*36|0)+4|0;L=b[H>>1]|0;if((I|0)>7){M=I-7|0;N=L|J<<7;O=K}else{P=K;x=fe(L>>>((7-I|0)>>>0)|J<<I|0)|0;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;M=I+25|0;N=L;O=K+4|0}y=N;L=c[A>>2]|0;P=q+(E<<2)|0;if((L|0)>0){Xgb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,L,(c[P>>2]|0)+2|0,B,z+(E*36|0)|0,64,1);L=O;Q=M;R=0;S=N;while(1){T=d[l+(R^1)|0]|0;if((Q|0)>4){U=Q-4|0;V=S<<4|T;W=L}else{X=L;x=fe(T>>>((4-Q|0)>>>0)|S<<Q|0)|0;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;U=Q+28|0;V=T;W=L+4|0}y=V;T=R+1|0;if((T|0)<64){L=W;Q=U;R=T;S=V}else{Y=U;Z=W;_=V;break}}}else{S=O;R=M;Q=0;L=N;while(1){T=c[G>>2]|0;X=(b[(c[P>>2]|0)+(Q<<1)>>1]|0)-T|0;$=b[H>>1]|0;aa=b[1269584+($<<1)>>1]|0;ca=X>>>31<<3;da=(X|0)>-1?X:-X|0;if((da|0)<(aa|0)){ea=ca;fa=da}else{ea=ca|4;fa=da-aa|0}ca=aa>>1;if((fa|0)<(ca|0)){ga=ea;ha=fa}else{ga=ea|2;ha=fa-ca|0}ca=aa>>2;if((ha|0)<(ca|0)){ia=ga;ja=ha}else{ia=ga|1;ja=ha-ca|0}ca=(aa>>3)+da-ja|0;da=((ia&8|0)==0?ca:-ca|0)+T|0;if((da+32768|0)>>>0>65535>>>0){ka=(da>>31^32767)&65535}else{ka=da&65535}da=ka<<16>>16;c[G>>2]=da;T=(a[1270408+ia|0]|0)+$|0;if((T|0)<0){la=0}else{la=(T|0)>88?88:T&65535}b[H>>1]=la;T=ia&255;$=(b[(c[P>>2]|0)+((Q|1)<<1)>>1]|0)-da|0;ca=la<<16>>16;aa=b[1269584+(ca<<1)>>1]|0;X=$>>>31<<3;ma=($|0)>-1?$:-$|0;if((ma|0)<(aa|0)){na=X;oa=ma}else{na=X|4;oa=ma-aa|0}X=aa>>1;if((oa|0)<(X|0)){pa=na;qa=oa}else{pa=na|2;qa=oa-X|0}X=aa>>2;if((qa|0)<(X|0)){ra=pa;sa=qa}else{ra=pa|1;sa=qa-X|0}X=(aa>>3)+ma-sa|0;ma=((ra&8|0)==0?X:-X|0)+da|0;if((ma+32768|0)>>>0>65535>>>0){ta=(ma>>31^32767)&65535}else{ta=ma&65535}c[G>>2]=ta<<16>>16;ma=(a[1270408+ra|0]|0)+ca|0;if((ma|0)<0){ua=0}else{ua=(ma|0)>88?88:ma&65535}b[H>>1]=ua;ma=ra&255;if((R|0)>4){va=R-4|0;wa=L<<4|ma;xa=S}else{ca=S;x=fe(L<<R|ma>>>((4-R|0)>>>0)|0)|0;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;va=R+28|0;wa=ma;xa=S+4|0}y=wa;if((va|0)>4){ya=va-4|0;za=wa<<4|T;Aa=xa}else{ma=xa;x=fe(T>>>((4-va|0)>>>0)|wa<<va|0)|0;a[ma]=x;x=x>>8;a[ma+1|0]=x;x=x>>8;a[ma+2|0]=x;x=x>>8;a[ma+3|0]=x;ya=va+28|0;za=T;Aa=xa+4|0}y=za;T=Q+2|0;if((T|0)<64){S=Aa;R=ya;Q=T;L=za}else{Y=ya;Z=Aa;_=za;break}}}L=E+1|0;if((L|0)<(c[r>>2]|0)){C=Z;D=Y;E=L;F=_}else{break}}if((Y|0)>=32){break}F=_<<Y;y=F;E=F>>>24&255;F=Y;D=Z;while(1){a[D]=E;C=y;y=C<<8;z=F+8|0;if((z|0)<32){E=C>>>16&255;F=z;D=D+1|0}else{break}}}}while(0);y=0;break};case 69645:{D=(u&268435456|0)!=0?0:s;F=h+76|0;E=(c[F>>2]|0)-1|0;z=2;C=c[r>>2]|0;if((C|0)>0){B=n;A=D;L=30;Q=0;R=2;while(1){S=B+(Q*36|0)+4|0;H=b[S>>1]|0;if(H<<16>>16<0){Ba=0}else{Ba=H<<16>>16>63?63:H}b[S>>1]=Ba;H=p+(Q<<1)|0;G=e[H>>1]|0;if((L|0)>16){Ca=L-16|0;Da=R<<16|G;Ea=A;Fa=Ba}else{P=A;x=fe(G>>>((16-L|0)>>>0)|R<<L|0)|0;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;Ca=L+16|0;Da=G;Ea=A+4|0;Fa=b[S>>1]|0}z=Da;S=Fa<<16>>16;if((Ca|0)>6){Ga=Ca-6|0;Ha=S|Da<<6;Ia=Ea}else{G=Ea;x=fe(S>>>((6-Ca|0)>>>0)|Da<<Ca|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;Ga=Ca+26|0;Ha=S;Ia=Ea+4|0}z=Ha;c[B+(Q*36|0)+12>>2]=b[H>>1]|0;H=Q+1|0;S=c[r>>2]|0;if((H|0)<(S|0)){A=Ia;L=Ga;Q=H;R=Ha}else{Ja=Ia;Ka=Ga;La=Ha;Ma=S;break}}}else{Ja=D;Ka=30;La=2;Ma=C}R=f+600|0;b:do{if((c[R>>2]|0)>0){Q=E<<1;L=WDb(Q)|0;if(!((L|0)!=0|(Q|0)==0)){yDb(f,16,2348e3,(Na=i,i=i+1|0,i=i+7&-8,c[Na>>2]=0,Na)|0);i=Na;v=-12;i=k;return v|0}Q=c[r>>2]|0;Xgb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[R>>2]|0,p+(Q<<1)|0,L,n,E,Q);if((c[r>>2]|0)==2){Xgb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[R>>2]|0,o+6|0,L+E|0,n+36|0,E,2)}if((E|0)>0){Q=Ja;A=Ka;B=0;y=La;while(1){S=d[L+B|0]|0;if((A|0)>4){Oa=A-4|0;Pa=y<<4|S;Qa=Q}else{H=Q;x=fe(S>>>((4-A|0)>>>0)|y<<A|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;Oa=A+28|0;Pa=S;Qa=Q+4|0}z=Pa;if((c[r>>2]|0)==2){S=d[L+(B+E)|0]|0;if((Oa|0)>4){Ra=Oa-4|0;Sa=S|Pa<<4;Ta=Qa}else{H=Qa;x=fe(S>>>((4-Oa|0)>>>0)|Pa<<Oa|0)|0;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;Ra=Oa+28|0;Sa=S;Ta=Qa+4|0}z=Sa;Ua=Ra;Va=Ta;Wa=Sa}else{Ua=Oa;Va=Qa;Wa=Pa}S=B+1|0;if((S|0)<(E|0)){Q=Va;A=Ua;B=S;y=Wa}else{Xa=Va;Ya=Ua;Za=Wa;break}}}else{Xa=Ja;Ya=Ka;Za=La}ZDb(L);_a=Ya;$a=Xa;ab=Za}else{if((c[F>>2]|0)<=1){_a=Ka;$a=Ja;ab=La;break}y=n+12|0;B=n+4|0;A=n+48|0;Q=n+40|0;S=Ja;H=Ka;G=1;P=La;T=Ma;while(1){ma=b[p+((ba(T,G)|0)<<1)>>1]|0;ca=c[y>>2]|0;da=ma-ca|0;ma=b[B>>1]|0;X=b[1269584+(ma<<1)>>1]|0;aa=(((da|0)>-1?da:-da|0)<<2|0)/(X|0)|0;$=((aa|0)<7?aa:7)+(da>>>31<<3)|0;da=((ba(a[1269048+$|0]|0,X)|0)/8|0)+ca|0;if((da+32768|0)>>>0>65535>>>0){bb=(da>>31^32767)&65535}else{bb=da&65535}c[y>>2]=bb<<16>>16;da=(a[1270408+$|0]|0)+ma|0;if((da|0)<0){cb=0}else{cb=(da|0)>88?88:da&65535}b[B>>1]=cb;da=$&255;if((H|0)>4){db=H-4|0;eb=P<<4|da;fb=S}else{$=S;x=fe(P<<H|da>>>((4-H|0)>>>0)|0)|0;a[$]=x;x=x>>8;a[$+1|0]=x;x=x>>8;a[$+2|0]=x;x=x>>8;a[$+3|0]=x;db=H+28|0;eb=da;fb=S+4|0}z=eb;if((c[r>>2]|0)==2){da=c[A>>2]|0;$=(b[p+((G<<1|1)<<1)>>1]|0)-da|0;ma=b[Q>>1]|0;ca=b[1269584+(ma<<1)>>1]|0;X=((($|0)>-1?$:-$|0)<<2|0)/(ca|0)|0;aa=((X|0)<7?X:7)+($>>>31<<3)|0;$=((ba(a[1269048+aa|0]|0,ca)|0)/8|0)+da|0;if(($+32768|0)>>>0>65535>>>0){gb=($>>31^32767)&65535}else{gb=$&65535}c[A>>2]=gb<<16>>16;$=(a[1270408+aa|0]|0)+ma|0;if(($|0)<0){hb=0}else{hb=($|0)>88?88:$&65535}b[Q>>1]=hb;$=aa&255;if((db|0)>4){ib=db-4|0;jb=eb<<4|$;kb=fb}else{aa=fb;x=fe(eb<<db|$>>>((4-db|0)>>>0)|0)|0;a[aa]=x;x=x>>8;a[aa+1|0]=x;x=x>>8;a[aa+2|0]=x;x=x>>8;a[aa+3|0]=x;ib=db+28|0;jb=$;kb=fb+4|0}z=jb;lb=ib;mb=kb;nb=jb}else{lb=db;mb=fb;nb=eb}$=G+1|0;if(($|0)>=(c[F>>2]|0)){_a=lb;$a=mb;ab=nb;break b}S=mb;H=lb;G=$;P=nb;T=c[r>>2]|0}}}while(0);if((_a|0)<32){F=ab<<_a;z=F;E=F>>>24&255;F=_a;R=$a;while(1){a[R]=E;C=z;z=C<<8;D=F+8|0;if((D|0)<32){E=C>>>16&255;F=D;R=R+1|0}else{break}}}z=0;break};case 69638:{R=c[r>>2]|0;do{if((R|0)>0){F=d[1273768]|0;E=n;D=a[1273760]|0;C=s;T=0;while(1){ob=C+1|0;a[C]=0;c[E+(T*36|0)+24>>2]=F;c[E+(T*36|0)+28>>2]=D;P=T+1|0;pb=c[r>>2]|0;if((P|0)<(pb|0)){C=ob;T=P}else{break}}if((pb|0)<=0){qb=ob;rb=pb;sb=p;break}T=n;C=ob;D=0;do{E=T+(D*36|0)+32|0;F=c[E>>2]|0;if((F|0)<16){c[E>>2]=16;tb=16}else{tb=F&65535}F=C;x=tb;a[F]=x;x=x>>8;a[F+1|0]=x;C=C+2|0;D=D+1|0;ub=c[r>>2]|0;}while((D|0)<(ub|0));if((ub|0)<=0){qb=C;rb=ub;sb=p;break}D=n;T=p;F=0;while(1){vb=T+2|0;c[D+(F*36|0)+20>>2]=b[T>>1]|0;E=F+1|0;wb=c[r>>2]|0;if((E|0)<(wb|0)){T=vb;F=E}else{break}}if((wb|0)<=0){qb=C;rb=wb;sb=vb;break}F=n;T=C;D=vb;E=0;while(1){xb=D+2|0;P=b[D>>1]|0;c[F+(E*36|0)+16>>2]=P<<16>>16;G=T;x=P;a[G]=x;x=x>>8;a[G+1|0]=x;yb=T+2|0;G=E+1|0;zb=c[r>>2]|0;if((G|0)<(zb|0)){T=yb;D=xb;E=G}else{break}}if((zb|0)<=0){qb=yb;rb=zb;sb=xb;break}E=n;D=yb;T=0;while(1){F=D;x=c[E+(T*36|0)+20>>2]&65535;a[F]=x;x=x>>8;a[F+1|0]=x;F=D+2|0;C=T+1|0;G=c[r>>2]|0;if((C|0)<(G|0)){D=F;T=C}else{qb=F;rb=G;sb=xb;break}}}else{qb=s;rb=R;sb=p}}while(0);R=f+600|0;if((c[R>>2]|0)>0){z=(c[f+432>>2]|0)+(rb*-7|0)|0;T=z<<1;D=WDb(T)|0;if(!((D|0)!=0|(T|0)==0)){yDb(f,16,2348e3,(Na=i,i=i+1|0,i=i+7&-8,c[Na>>2]=0,Na)|0);i=Na;v=-12;i=k;return v|0}T=c[r>>2]|0;Xgb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[R>>2]|0,sb,D,n,z,T);do{if((T|0)==1){if((z|0)>0){Ab=qb;Bb=0}else{break}while(1){a[Ab]=a[D+Bb|0]<<4|a[D+(Bb|1)|0];E=Bb+2|0;if((E|0)<(z|0)){Ab=Ab+1|0;Bb=E}else{break}}}else{Xgb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[R>>2]|0,sb+2|0,D+z|0,n+36|0,z,c[r>>2]|0);if((z|0)>0){Cb=qb;Db=0}else{break}while(1){a[Cb]=a[D+Db|0]<<4|a[D+(Db+z)|0];E=Db+1|0;if((E|0)<(z|0)){Cb=Cb+1|0;Db=E}else{break}}}}while(0);ZDb(D);break a}z=rb*7|0;R=f+432|0;if((z|0)>=(c[R>>2]|0)){break a}T=n;E=n+16|0;G=n+24|0;F=n+20|0;C=n+28|0;P=n+32|0;H=T+(t*36|0)+16|0;S=T+(t*36|0)+24|0;Q=T+(t*36|0)+20|0;A=T+(t*36|0)+28|0;B=T+(t*36|0)+32|0;T=qb;y=sb;L=z;while(1){z=c[E>>2]|0;$=ba(c[G>>2]|0,z)|0;aa=((ba(c[C>>2]|0,c[F>>2]|0)|0)+$|0)/64|0;$=(b[y>>1]|0)-aa|0;ma=c[P>>2]|0;if(($|0)>-1){Eb=(ma|0)/2|0}else{Eb=(ma|0)/-2|0}da=(Eb+$|0)/(ma|0)|0;if((da|0)<-8){Fb=-8}else{Fb=(da|0)>7?7:da}da=Fb&15;$=(ba((Fb&8|0)!=0?Fb|-16:da,ma)|0)+aa|0;c[F>>2]=z;if(($+32768|0)>>>0>65535>>>0){Gb=($>>31^32767)&65535}else{Gb=$&65535}c[E>>2]=Gb<<16>>16;$=(ba(b[1273728+(da<<1)>>1]|0,ma)|0)>>8;c[P>>2]=($|0)<16?16:$;$=c[H>>2]|0;ma=ba(c[S>>2]|0,$)|0;da=((ba(c[A>>2]|0,c[Q>>2]|0)|0)+ma|0)/64|0;ma=(b[y+2>>1]|0)-da|0;z=c[B>>2]|0;if((ma|0)>-1){Hb=(z|0)/2|0}else{Hb=(z|0)/-2|0}aa=(Hb+ma|0)/(z|0)|0;if((aa|0)<-8){Ib=-8}else{Ib=(aa|0)>7?7:aa}aa=Ib&15;ma=(ba((Ib&8|0)!=0?Ib|-16:aa,z)|0)+da|0;c[Q>>2]=$;if((ma+32768|0)>>>0>65535>>>0){Jb=(ma>>31^32767)&65535}else{Jb=ma&65535}c[H>>2]=Jb<<16>>16;ma=(ba(b[1273728+(aa<<1)>>1]|0,z)|0)>>8;c[B>>2]=(ma|0)<16?16:ma;a[T]=aa&255|(Fb&255)<<4;aa=L+1|0;if((aa|0)<(c[R>>2]|0)){T=T+1|0;y=y+4|0;L=aa}else{break}}break};case 69646:{L=(c[h+76>>2]|0)/2|0;y=f+600|0;if((c[y>>2]|0)>0){T=L<<1;R=L<<2;B=WDb(R)|0;if(!((B|0)!=0|(R|0)==0)){yDb(f,16,2348e3,(Na=i,i=i+1|0,i=i+7&-8,c[Na>>2]=0,Na)|0);i=Na;v=-12;i=k;return v|0}R=c[r>>2]|0;Xgb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[y>>2]|0,p,B,n,T,R);do{if((R|0)==1){if((T|0)>0){Kb=s;Lb=0}else{break}while(1){a[Kb]=a[B+(Lb|1)|0]<<4|a[B+Lb|0];H=Lb+2|0;if((H|0)<(T|0)){Kb=Kb+1|0;Lb=H}else{break}}}else{Xgb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[y>>2]|0,o+2|0,B+T|0,n+36|0,T,c[r>>2]|0);if((T|0)>0){Mb=s;Nb=0}else{break}while(1){a[Mb]=a[B+(Nb+T)|0]<<4|a[B+Nb|0];H=Nb+1|0;if((H|0)<(T|0)){Mb=Mb+1|0;Nb=H}else{break}}}}while(0);ZDb(B);break a}T=ba(c[r>>2]|0,L)|0;if((T|0)<=0){break a}y=n;R=n+8|0;H=n;Q=y+(t*36|0)+8|0;A=y+(t*36|0)|0;y=s;S=p;P=T;while(1){T=b[S>>1]|0;E=c[R>>2]|0;if((E|0)==0){c[H>>2]=0;c[R>>2]=127;Ob=127;Pb=0}else{Ob=E;Pb=c[H>>2]|0}E=(T<<16>>16)-Pb|0;T=(((E|0)>-1?E:-E|0)<<2|0)/(Ob|0)|0;F=((T|0)<7?T:7)+(E>>>31<<3)|0;E=((ba(a[1269048+F|0]|0,Ob)|0)/8|0)+Pb|0;if((E+32768|0)>>>0>65535>>>0){Qb=(E>>31^32767)&65535}else{Qb=E&65535}c[H>>2]=Qb<<16>>16;E=(ba(b[1268912+(F<<1)>>1]|0,Ob)|0)>>8;if((E|0)<127){Rb=127}else{Rb=(E|0)>24567?24567:E}c[R>>2]=Rb;E=b[S+2>>1]|0;T=c[Q>>2]|0;if((T|0)==0){c[A>>2]=0;c[Q>>2]=127;Sb=127;Tb=0}else{Sb=T;Tb=c[A>>2]|0}T=(E<<16>>16)-Tb|0;E=(((T|0)>-1?T:-T|0)<<2|0)/(Sb|0)|0;C=((E|0)<7?E:7)+(T>>>31<<3)|0;T=((ba(a[1269048+C|0]|0,Sb)|0)/8|0)+Tb|0;if((T+32768|0)>>>0>65535>>>0){Ub=(T>>31^32767)&65535}else{Ub=T&65535}c[A>>2]=Ub<<16>>16;T=(ba(b[1268912+(C<<1)>>1]|0,Sb)|0)>>8;if((T|0)<127){Vb=127}else{Vb=(T|0)>24567?24567:T}c[Q>>2]=Vb;a[y]=(C&255)<<4|F&255;F=P-1|0;if((F|0)>0){y=y+1|0;S=S+4|0;P=F}else{break}}break};case 69633:{P=(c[h+76>>2]|0)-1|0;S=(P|0)/8|0;y=c[r>>2]|0;if((y|0)>0){Q=n;A=s;R=0;while(1){H=b[c[q+(R<<2)>>2]>>1]|0;c[Q+(R*36|0)+12>>2]=H<<16>>16;L=A;x=H;a[L]=x;x=x>>8;a[L+1|0]=x;a[A+2|0]=b[Q+(R*36|0)+4>>1];L=A+4|0;a[A+3|0]=0;H=R+1|0;B=c[r>>2]|0;if((H|0)<(B|0)){A=L;R=H}else{Wb=L;Xb=B;break}}}else{Wb=s;Xb=y}R=f+600|0;if((c[R>>2]|0)>0){A=S<<3;Q=WDb(ba(A,Xb)|0)|0;B=c[r>>2]|0;do{if((Q|0)==0){if(((ba(B,S)|0)&536870911|0)==0){break}yDb(f,16,2348e3,(Na=i,i=i+1|0,i=i+7&-8,c[Na>>2]=0,Na)|0);i=Na;v=-12;i=k;return v|0}}while(0);if((B|0)>0){y=n;L=0;while(1){H=Q+(ba(A,L)|0)|0;Xgb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[R>>2]|0,(c[q+(L<<2)>>2]|0)+2|0,H,y+(L*36|0)|0,A,1);H=L+1|0;F=c[r>>2]|0;if((H|0)<(F|0)){L=H}else{Yb=F;break}}}else{Yb=B}if((P|0)>7){L=Wb;y=0;R=Yb;while(1){if((R|0)>0){F=y<<3;H=L;C=0;while(1){T=(ba(A,C)|0)+F|0;a[H]=a[Q+(T|1)|0]<<4|a[Q+T|0];a[H+1|0]=a[Q+(T|3)|0]<<4|a[Q+(T|2)|0];a[H+2|0]=a[Q+(T|5)|0]<<4|a[Q+(T|4)|0];a[H+3|0]=a[Q+(T|7)|0]<<4|a[Q+(T|6)|0];T=H+4|0;E=C+1|0;G=c[r>>2]|0;if((E|0)<(G|0)){H=T;C=E}else{Zb=T;_b=G;break}}}else{Zb=L;_b=R}C=y+1|0;if((C|0)<(S|0)){L=Zb;y=C;R=_b}else{break}}}ZDb(Q);break a}if((P|0)<=7){break a}R=n;y=Wb;L=0;A=Xb;while(1){if((A|0)>0){B=L<<3|1;C=y;H=0;while(1){F=c[q+(H<<2)>>2]|0;G=R+(H*36|0)+12|0;T=R+(H*36|0)+4|0;E=C;D=0;while(1){aa=c[G>>2]|0;ma=(b[F+(D+B<<1)>>1]|0)-aa|0;z=b[T>>1]|0;$=b[1269584+(z<<1)>>1]|0;da=(((ma|0)>-1?ma:-ma|0)<<2|0)/($|0)|0;ca=((da|0)<7?da:7)+(ma>>>31<<3)|0;ma=((ba(a[1269048+ca|0]|0,$)|0)/8|0)+aa|0;if((ma+32768|0)>>>0>65535>>>0){$b=(ma>>31^32767)&65535}else{$b=ma&65535}ma=$b<<16>>16;c[G>>2]=ma;aa=(a[1270408+ca|0]|0)+z|0;if((aa|0)<0){ac=0}else{ac=(aa|0)>88?88:aa&65535}b[T>>1]=ac;aa=(b[F+((D|1)+B<<1)>>1]|0)-ma|0;z=ac<<16>>16;$=b[1269584+(z<<1)>>1]|0;da=(((aa|0)>-1?aa:-aa|0)<<2|0)/($|0)|0;X=((da|0)<7?da:7)+(aa>>>31<<3)|0;aa=((ba(a[1269048+X|0]|0,$)|0)/8|0)+ma|0;if((aa+32768|0)>>>0>65535>>>0){bc=(aa>>31^32767)&65535}else{bc=aa&65535}c[G>>2]=bc<<16>>16;aa=(a[1270408+X|0]|0)+z|0;if((aa|0)<0){cc=0}else{cc=(aa|0)>88?88:aa&65535}b[T>>1]=cc;a[E]=(X&255)<<4|ca&255;ca=D+2|0;if((ca|0)<8){E=E+1|0;D=ca}else{break}}D=C+4|0;E=H+1|0;T=c[r>>2]|0;if((E|0)<(T|0)){C=D;H=E}else{dc=D;ec=T;break}}}else{dc=y;ec=A}H=L+1|0;if((H|0)<(S|0)){y=dc;L=H;A=ec}else{break}}break};default:{v=-22;i=k;return v|0}}}while(0);c[g+28>>2]=u;c[j>>2]=1;v=0;i=k;return v|0}function Wgb(a){a=a|0;var b=0;b=c[a+60>>2]|0;$Db(b+216|0);$Db(b+220|0);$Db(b+224|0);$Db(b+228|0);return 0}function Xgb(e,f,g,h,i,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0;m=1<<g;n=c[f+216>>2]|0;o=c[f+220>>2]|0;p=c[f+224>>2]|0;q=p+(m<<2)|0;r=c[f+228>>2]|0;TGb(r|0,-1|0,65536)|0;TGb(p|0,0,m<<3|0)|0;f=o+(m*20|0)|0;c[p>>2]=f;c[f>>2]=0;c[o+(m*20|0)+4>>2]=0;f=j+4|0;s=o+(m*20|0)+16|0;c[s>>2]=b[f>>1]|0;t=j+16|0;u=o+(m*20|0)+8|0;c[u>>2]=c[t>>2];v=j+20|0;c[o+(m*20|0)+12>>2]=c[v>>2];w=(e-69632|0)>>>0<2>>>0|(e|0)==69645;if(w){c[u>>2]=c[j+12>>2]}x=(e|0)==69638;do{if(x){c[s>>2]=c[j+32>>2]}else{if((e|0)!=69646){break}y=c[j+8>>2]|0;if((y|0)==0){c[s>>2]=127;c[u>>2]=0;break}else{c[s>>2]=y;c[u>>2]=c[j>>2];break}}}while(0);if((k|0)>0){u=m<<2;s=(m|0)>0;e=u-4|0;y=(m|0)>1;z=(m|0)/2|0;A=j+24|0;B=j+28|0;C=m>>1;D=C-1|0;E=0;G=0;H=-1;I=0;J=q;q=p;while(1){K=b[h+((ba(G,l)|0)<<1)>>1]|0;TGb(J|0,0,u|0)|0;a:do{if(s){L=E&255;M=0;N=o+(((G&1)<<g)*20|0)|0;O=0;P=I;while(1){Q=q+(O<<2)|0;R=c[Q>>2]|0;if((R|0)==0){S=P;break a}T=(O|0)<(z|0)|0;U=c[R+16>>2]|0;V=c[R+8>>2]|0;do{if(x){W=ba(c[A>>2]|0,V)|0;X=((ba(c[B>>2]|0,c[R+12>>2]|0)|0)+W|0)/64|0;W=(K-X|0)/(U|0)|0;Y=W-T|0;if((Y|0)<-8){Z=-8}else{Z=(Y|0)>6?6:Y}Y=W+T|0;if((Y|0)<-7){_=-7}else{_=(Y|0)>7?7:Y}if((Z|0)>(_|0)){$=P;aa=N;ca=M;break}else{da=Z;ea=M;fa=N;ga=P}while(1){Y=da&15;W=(ba(da,U)|0)+X|0;if((W+32768|0)>>>0>65535>>>0){ha=(W>>31^32767)&65535}else{ha=W&65535}W=ha<<16>>16;ia=K-W|0;ja=lc(c[c[Q>>2]>>2]|0,ba(ia,ia)|0)|0;ia=ja;b:do{if(F){ka=ga;la=fa;ma=ea}else{ja=r+(ha&65535)|0;if((d[ja]|0)==(E|0)){ka=ga;la=fa;ma=ea;break}if((ea|0)<(m|0)){na=ea}else{oa=(ea&D)+C|0;if(ia>>>0>(c[c[J+(oa<<2)>>2]>>2]|0)>>>0){ka=ga;la=fa;ma=ea;break}else{na=oa}}oa=ea+1|0;a[ja]=L;ja=J+(na<<2)|0;pa=c[ja>>2]|0;if((pa|0)==0){c[ja>>2]=fa;c[fa+4>>2]=ga;qa=ga+1|0;ra=fa+20|0;sa=fa;ta=ga}else{qa=ga;ra=fa;sa=pa;ta=c[pa+4>>2]|0}c[sa>>2]=ia;pa=(ba(b[1273728+(Y<<1)>>1]|0,U)|0)>>8;c[sa+16>>2]=(pa|0)<16?16:pa;pa=c[Q>>2]|0;c[sa+12>>2]=c[pa+8>>2];c[sa+8>>2]=W;c[n+(ta<<3)>>2]=Y;c[n+(c[sa+4>>2]<<3)+4>>2]=c[pa+4>>2];if((na|0)>0){ua=na}else{ka=qa;la=ra;ma=oa;break}while(1){pa=ua-1>>1;ja=J+(pa<<2)|0;va=c[ja>>2]|0;if(!((c[va>>2]|0)>>>0>ia>>>0)){ka=qa;la=ra;ma=oa;break b}c[J+(ua<<2)>>2]=va;c[ja>>2]=sa;if((pa|0)>0){ua=pa}else{ka=qa;la=ra;ma=oa;break}}}}while(0);ia=da+1|0;if((ia|0)>(_|0)){$=ka;aa=la;ca=ma;break}else{da=ia;ea=ma;fa=la;ga=ka}}}else{X=K-V<<2;if(w){ia=b[1269584+(U<<1)>>1]|0;Y=(X|0)/(ia|0)|0;W=Y-T|0;if((W|0)<-7){wa=-7}else{wa=(W|0)>6?6:W}W=Y+T|0;if((W|0)<-6){xa=-6}else{xa=(W|0)>7?7:W}W=(((wa|0)<1)<<31>>31)+wa|0;Y=(xa>>31)+xa|0;if((W|0)>(Y|0)){$=P;aa=N;ca=M;break}else{ya=W;za=M;Aa=N;Ba=P}while(1){W=(ya|0)<0?7-ya|0:ya;oa=((ba(a[1269048+W|0]|0,ia)|0)/8|0)+V|0;if((oa+32768|0)>>>0>65535>>>0){Ca=(oa>>31^32767)&65535}else{Ca=oa&65535}oa=Ca<<16>>16;pa=K-oa|0;ja=lc(c[c[Q>>2]>>2]|0,ba(pa,pa)|0)|0;pa=ja;c:do{if(F){Da=Ba;Ea=Aa;Fa=za}else{ja=r+(Ca&65535)|0;if((d[ja]|0)==(E|0)){Da=Ba;Ea=Aa;Fa=za;break}if((za|0)<(m|0)){Ga=za}else{va=(za&D)+C|0;if(pa>>>0>(c[c[J+(va<<2)>>2]>>2]|0)>>>0){Da=Ba;Ea=Aa;Fa=za;break}else{Ga=va}}va=za+1|0;a[ja]=L;ja=J+(Ga<<2)|0;Ha=c[ja>>2]|0;if((Ha|0)==0){c[ja>>2]=Aa;c[Aa+4>>2]=Ba;Ia=Ba+1|0;Ja=Aa+20|0;Ka=Aa}else{Ia=Ba;Ja=Aa;Ka=Ha}c[Ka>>2]=pa;Ha=(a[1270408+W|0]|0)+U|0;if((Ha|0)<0){La=0}else{La=(Ha|0)>88?88:Ha}c[Ka+16>>2]=La;Ha=c[Q>>2]|0;c[Ka+12>>2]=c[Ha+8>>2];c[Ka+8>>2]=oa;ja=Ka+4|0;c[n+(c[ja>>2]<<3)>>2]=W;c[n+(c[ja>>2]<<3)+4>>2]=c[Ha+4>>2];if((Ga|0)>0){Ma=Ga}else{Da=Ia;Ea=Ja;Fa=va;break}while(1){Ha=Ma-1>>1;ja=J+(Ha<<2)|0;Na=c[ja>>2]|0;if(!((c[Na>>2]|0)>>>0>pa>>>0)){Da=Ia;Ea=Ja;Fa=va;break c}c[J+(Ma<<2)>>2]=Na;c[ja>>2]=Ka;if((Ha|0)>0){Ma=Ha}else{Da=Ia;Ea=Ja;Fa=va;break}}}}while(0);pa=ya+1|0;if((pa|0)>(Y|0)){$=Da;aa=Ea;ca=Fa;break}else{ya=pa;za=Fa;Aa=Ea;Ba=Da}}}else{Y=(X|0)/(U|0)|0;ia=Y-T|0;if((ia|0)<-7){Oa=-7}else{Oa=(ia|0)>6?6:ia}ia=Y+T|0;if((ia|0)<-6){Pa=-6}else{Pa=(ia|0)>7?7:ia}ia=(((Oa|0)<1)<<31>>31)+Oa|0;Y=(Pa>>31)+Pa|0;if((ia|0)>(Y|0)){$=P;aa=N;ca=M;break}else{Qa=ia;Ra=M;Sa=N;Ta=P}while(1){ia=(Qa|0)<0?7-Qa|0:Qa;pa=((ba(a[1269048+ia|0]|0,U)|0)/8|0)+V|0;if((pa+32768|0)>>>0>65535>>>0){Ua=(pa>>31^32767)&65535}else{Ua=pa&65535}pa=Ua<<16>>16;W=K-pa|0;oa=lc(c[c[Q>>2]>>2]|0,ba(W,W)|0)|0;W=oa;d:do{if(F){Va=Ta;Wa=Sa;Xa=Ra}else{oa=r+(Ua&65535)|0;if((d[oa]|0)==(E|0)){Va=Ta;Wa=Sa;Xa=Ra;break}if((Ra|0)<(m|0)){Ya=Ra}else{va=(Ra&D)+C|0;if(W>>>0>(c[c[J+(va<<2)>>2]>>2]|0)>>>0){Va=Ta;Wa=Sa;Xa=Ra;break}else{Ya=va}}va=Ra+1|0;a[oa]=L;oa=J+(Ya<<2)|0;Ha=c[oa>>2]|0;if((Ha|0)==0){c[oa>>2]=Sa;c[Sa+4>>2]=Ta;Za=Sa;_a=Ta+1|0;$a=Sa+20|0}else{Za=Ha;_a=Ta;$a=Sa}c[Za>>2]=W;Ha=(ba(b[1268912+(ia<<1)>>1]|0,U)|0)>>8;if((Ha|0)<127){ab=127}else{ab=(Ha|0)>24567?24567:Ha}c[Za+16>>2]=ab;Ha=c[Q>>2]|0;c[Za+12>>2]=c[Ha+8>>2];c[Za+8>>2]=pa;oa=Za+4|0;c[n+(c[oa>>2]<<3)>>2]=ia;c[n+(c[oa>>2]<<3)+4>>2]=c[Ha+4>>2];if((Ya|0)>0){bb=Ya}else{Va=_a;Wa=$a;Xa=va;break}while(1){Ha=bb-1>>1;oa=J+(Ha<<2)|0;ja=c[oa>>2]|0;if(!((c[ja>>2]|0)>>>0>W>>>0)){Va=_a;Wa=$a;Xa=va;break d}c[J+(bb<<2)>>2]=ja;c[oa>>2]=Za;if((Ha|0)>0){bb=Ha}else{Va=_a;Wa=$a;Xa=va;break}}}}while(0);W=Qa+1|0;if((W|0)>(Y|0)){$=Va;aa=Wa;ca=Xa;break}else{Qa=W;Ra=Xa;Sa=Wa;Ta=Va}}}}}while(0);Q=O+1|0;if((Q|0)<(m|0)){M=ca;N=aa;O=Q;P=$}else{S=$;break}}}else{S=I}}while(0);K=E+1|0;if((K|0)==255){TGb(r|0,-1|0,65536)|0;cb=0}else{cb=K}K=c[J>>2]|0;P=K|0;if((c[P>>2]|0)>>>0>268435456>>>0){e:do{if(y){O=1;do{N=c[J+(O<<2)>>2]|0;if((N|0)==0){break e}M=N|0;c[M>>2]=(c[M>>2]|0)-(c[P>>2]|0);O=O+1|0;}while((O|0)<(m|0))}}while(0);c[P>>2]=0}if((G|0)==(H+128|0)){if((G|0)>(H|0)){O=G;M=K+4|0;while(1){N=c[M>>2]|0;a[i+O|0]=c[n+(N<<3)>>2];L=O-1|0;if((L|0)>(H|0)){O=L;M=n+(N<<3)+4|0}else{break}}}TGb(J+4|0,0,e|0)|0;db=0;eb=G}else{db=S;eb=H}M=G+1|0;if((M|0)<(k|0)){O=J;J=q;E=cb;G=M;H=eb;I=db;q=O}else{fb=eb;gb=J;break}}}else{fb=-1;gb=p}p=k-1|0;if((p|0)<=(fb|0)){hb=c[gb>>2]|0;ib=hb+8|0;jb=c[ib>>2]|0;kb=j|0;c[kb>>2]=jb;lb=c[ib>>2]|0;c[t>>2]=lb;mb=hb+12|0;nb=c[mb>>2]|0;c[v>>2]=nb;ob=hb+16|0;pb=c[ob>>2]|0;qb=pb&65535;b[f>>1]=qb;rb=j+8|0;c[rb>>2]=pb;sb=c[ob>>2]|0;tb=j+32|0;c[tb>>2]=sb;return}k=(c[gb>>2]|0)+4|0;J=p;while(1){p=c[k>>2]|0;a[i+J|0]=c[n+(p<<3)>>2];eb=J-1|0;if((eb|0)>(fb|0)){k=n+(p<<3)+4|0;J=eb}else{break}}hb=c[gb>>2]|0;ib=hb+8|0;jb=c[ib>>2]|0;kb=j|0;c[kb>>2]=jb;lb=c[ib>>2]|0;c[t>>2]=lb;mb=hb+12|0;nb=c[mb>>2]|0;c[v>>2]=nb;ob=hb+16|0;pb=c[ob>>2]|0;qb=pb&65535;b[f>>1]=qb;rb=j+8|0;c[rb>>2]=pb;sb=c[ob>>2]|0;tb=j+32|0;c[tb>>2]=sb;return}function Ygb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=c[a+60>>2]|0;e=c[a+100>>2]|0;do{if((e|0)>23){if((KX(a,c[a+96>>2]|0,e,b|0,d+32|0)|0)>=0){c[d>>2]=c[a+416>>2];c[d+20>>2]=1;break}yDb(a,16,2174928,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1094995529;i=b;return g|0}}while(0);c[a+420>>2]=6;g=0;i=b;return g|0}function Zgb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;h=i;i=i+8|0;j=h|0;k=e;l=g+28|0;m=c[l>>2]|0;n=c[a+60>>2]|0;o=n;p=g+24|0;g=c[p>>2]|0;q=g+m|0;r=n+24|0;if((c[r>>2]|0)!=0){c[f>>2]=0;s=m;i=h;return s|0}t=n+20|0;u=c[t>>2]|0;do{if((u|0)==0&(m|0)>1){v=g;if(!((d[v]|d[v+1|0]<<8)<<16>>16<<16>>16==128)){s=-1094995529;i=h;return s|0}if((KX(a,g,m,j,n+32|0)|0)<0){yDb(a,16,2174928,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;s=-1094995529;i=h;return s|0}c[n>>2]=c[a+416>>2];c[t>>2]=1;v=c[j>>2]|0;if((m|0)<(v|0)){s=-1094995529;i=h;return s|0}else{w=m-v|0;x=g+v|0;break}}else{if((u|0)==0){s=-1094995529}else{w=m;x=g;break}i=h;return s|0}}while(0);g=n;m=(w|0)/((c[g>>2]|0)*18|0|0)|0;do{if((m|0)!=0){if(((w|0)%((c[a+416>>2]|0)*18|0|0)|0|0)!=0){break}u=e+76|0;c[u>>2]=m<<5;j=_$a(a,k,0)|0;if((j|0)<0){s=j;i=h;return s|0}j=c[e+64>>2]|0;t=q;v=n+32|0;y=n+36|0;z=0;A=x;B=m;C=c[g>>2]|0;while(1){D=B-1|0;a:do{if((C|0)>0){E=A;F=0;G=C;while(1){if((t-E|0)<18){break}H=E;I=(de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;if((I&32768|0)!=0){break}H=(E+2|0)==0?8:136;J=o+4+(F<<3)|0;K=o+4+(F<<3)+4|0;L=I<<12;I=c[v>>2]|0;M=c[y>>2]|0;N=0;O=0;P=(c[j+(F<<2)>>2]|0)+(z<<1)|0;Q=c[J>>2]|0;R=c[K>>2]|0;while(1){S=E+((N>>>3)+2)|0;T=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(N&7)>>28;S=N+4|0;U=(ba(Q,I)|0)+(ba(R,M)|0)+(ba(L,T)|0)|0;T=U>>12;if((T+32768|0)>>>0>65535>>>0){V=(U>>31^32767)&65535}else{V=T&65535}W=V<<16>>16;b[P>>1]=V;T=O+1|0;if((T|0)<32){N=H>>>0>S>>>0?S:H;O=T;P=P+2|0;R=Q;Q=W}else{break}}c[J>>2]=W;c[K>>2]=Q;R=E+18|0;P=F+1|0;O=c[g>>2]|0;if((P|0)<(O|0)){E=R;F=P;G=O}else{X=R;Y=O;Z=26;break a}}c[r>>2]=1;_=(c[p>>2]|0)+(c[l>>2]|0)|0;$=G;aa=0}else{X=A;Y=C;Z=26}}while(0);if((Z|0)==26){Z=0;_=X;$=Y;aa=(c[r>>2]|0)==0}ca=aa?z+32|0:z;if((D|0)==0){break}else{z=ca;A=_;B=D;C=$}}c[u>>2]=ca;c[f>>2]=1;s=_-(c[p>>2]|0)|0;i=h;return s|0}}while(0);if((w|0)<=3){s=-1094995529;i=h;return s|0}w=x;if(((d[w]|d[w+1|0]<<8)<<16>>16&128)==0){s=-1094995529;i=h;return s|0}c[r>>2]=1;c[f>>2]=0;s=c[l>>2]|0;i=h;return s|0}function _gb(a){a=a|0;var b=0;b=c[a+60>>2]|0;TGb(b+4|0,0,16)|0;c[b+24>>2]=0;return}function $gb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+60>>2]|0;if((c[a+416>>2]|0)>2){yDb(a,16,2044240,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}else{c[a+424>>2]=32;c[d+28>>2]=500;JX(500,c[a+412>>2]|0,12,d+32|0);f=0;i=b;return f|0}return 0}function ahb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;i=i+128|0;j=h|0;k=d+60|0;l=c[k>>2]|0;m=c[f>>2]|0;f=d+416|0;n=l+20|0;o=(-((c[n>>2]|0)==0|0)&36)+((c[f>>2]|0)*18|0)|0;p=r0a(d,e,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=h;return q|0}p=c[e+24>>2]|0;if((c[n>>2]|0)==0){e=c[k>>2]|0;k=p;x=128;a[k]=x;x=x>>8;a[k+1|0]=x;k=p+2|0;x=8192;a[k]=x;x=x>>8;a[k+1|0]=x;a[p+4|0]=3;a[p+5|0]=18;a[p+6|0]=4;a[p+7|0]=c[f>>2];k=p+8|0;x=fe(c[d+412>>2]|0)|0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=p+12|0;x=0;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;k=p+16|0;x=de(c[e+28>>2]&65535|0)|0;a[k]=x;x=x>>8;a[k+1|0]=x;a[p+18|0]=3;k=p+30|0;TGb(p+19|0,0,11)|0;a[k]=a[2099552]|0;a[k+1|0]=a[2099553]|0;a[k+2|0]=a[2099554]|0;a[k+3|0]=a[2099555]|0;a[k+4|0]=a[2099556]|0;a[k+5|0]=a[2099557]|0;c[n>>2]=1;r=p+36|0}else{r=p}p=c[f>>2]|0;if((p|0)>0){n=l+4|0;k=l+32|0;e=l+36|0;l=0;d=r;r=p;while(1){p=n+(l<<3)|0;o=n+(l<<3)+4|0;s=c[k>>2]|0;t=c[e>>2]|0;u=0;v=0;w=c[p>>2]|0;y=c[o>>2]|0;z=0;A=0;while(1){B=b[m+(v+l<<1)>>1]|0;C=(B<<12)-((ba(w,s)|0)+(ba(y,t)|0))>>12;c[j+(u<<2)>>2]=C;D=(z|0)<(C|0)?C:z;E=(A|0)>(C|0)?C:A;C=u+1|0;if((C|0)<32){u=C;v=v+r|0;y=w;w=B;z=D;A=E}else{break}}c[p>>2]=B;c[o>>2]=w;do{if((E|D|0)==0){TGb(d|0,0,18)|0}else{A=(D|0)/7|0;z=(E|0)/-8|0;y=(A|0)>(z|0)?A:z;z=(y|0)==0?1:y;y=d;x=de(z&65535|0)|0;a[y]=x;x=x>>8;a[y+1|0]=x;y=d+2|0;A=32;v=0;u=0;while(1){t=(c[j+(v<<2)>>2]|0)/(z|0)|0;if((t|0)<-8){F=8}else{F=(t|0)>7?7:t&15}if((A|0)>4){G=A-4|0;H=F|u<<4;I=y}else{t=y;x=fe(F>>>((4-A|0)>>>0)|u<<A|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;G=A+28|0;H=F;I=y+4|0}t=v+1|0;if((t|0)<32){y=I;A=G;v=t;u=H}else{break}}if((G|0)>=32){break}u=H<<G;v=u>>>24&255;A=G;y=I;z=u;while(1){a[y]=v;u=A+8|0;if((u|0)<32){v=z>>>16&255;A=u;y=y+1|0;z=z<<8}else{break}}}}while(0);w=l+1|0;o=c[f>>2]|0;if((w|0)<(o|0)){l=w;d=d+18|0;r=o}else{break}}}c[g>>2]=1;q=0;i=h;return q|0}function bhb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+64|0;e=d|0;f=c[b+60>>2]|0;c[f>>2]=b;c[b+140>>2]=0;Z3(f+8|0,b);g=0;do{a[e+g|0]=g;g=g+1|0;}while((g|0)<64);x2(f+1136|0,f+1252|0,e|0);e=(c[b+120>>2]|0)+15>>4;c[f+1392>>2]=e;c[f+1396>>2]=(c[b+124>>2]|0)+15>>4;g=f+1384|0;c[g>>2]=16;h=(e|0)/16|0;j=f+1388|0;c[j>>2]=h;k=1;while(1){if(((e|0)%(k|0)|0|0)==0){l=(e|0)/(k|0)|0;if((l|0)<32){m=6;break}}n=k+1|0;if((n|0)<32){k=n}else{o=h;break}}if((m|0)==6){c[j>>2]=l;c[g>>2]=k;o=l}l=WDb(o*768|0)|0;o=l;c[f+1408>>2]=o;if((l|0)==0){yDb(b,16,2327616,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;p=-12;i=d;return p|0}else{c[f+1412>>2]=o;b=c[j>>2]|0;c[f+1416>>2]=o+(b<<6<<1);c[f+1420>>2]=o+((b*96|0)<<1);c[f+1424>>2]=o+((b*288|0)<<1);p=0;i=d;return p|0}return 0}function chb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;k=i;i=i+32|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=c[f+60>>2]|0;q=p;r=c[j+24>>2]|0;s=j+28|0;j=c[s>>2]|0;t=g;u=p+4|0;c[u>>2]=t;c[g+88>>2]=1;c[g+84>>2]=1;g=p+1384|0;v=p+1396|0;w=(ba(c[g>>2]<<1,c[v>>2]|0)|0)+27&-4;if(j>>>0<w>>>0){yDb(f,16,2174856,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=k;return y|0}z=a[r]|0;if(!(z<<24>>24==1)){yDb(c[p>>2]|0,16,1933968,(x=i,i=i+8|0,c[x>>2]=z&255,x)|0);i=x;y=-1094995529;i=k;return y|0}z=a[r+1|0]|0;if(!(z<<24>>24==22)){yDb(c[p>>2]|0,16,1910992,(x=i,i=i+8|0,c[x>>2]=z&255,x)|0);i=x;y=-1094995529;i=k;return y|0}z=r+2|0;A=fe(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0;z=r+6|0;B=(de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535;z=r+8|0;C=(de((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535;z=c[p>>2]|0;if(A>>>0>j>>>0){yDb(z,16,1890536,(x=i,i=i+16|0,c[x>>2]=A,c[x+8>>2]=j,x)|0);i=x;y=-1094995529;i=k;return y|0}A=c[z+120>>2]|0;D=c[z+124>>2]|0;if(!((B|0)==(A|0)&(C|0)==(D|0))){yDb(z,16,2347944,(x=i,i=i+32|0,c[x>>2]=A,c[x+8>>2]=D,c[x+16>>2]=B,c[x+24>>2]=C,x)|0);i=x;y=-1094995529;i=k;return y|0}C=p+1400|0;c[C>>2]=d[r+15|0]|0;B=p+1404|0;c[B>>2]=(a[r+16|0]&-16)<<24>>24==48;D=_$a(f,t,0)|0;if((D|0)<0){y=D;i=k;return y|0}D=c[v>>2]|0;t=ba(c[g>>2]<<1,D)|0;if(!((t|0)>-1)){yDb(0,0,2044208,(x=i,i=i+24|0,c[x>>2]=1998800,c[x+8>>2]=1961928,c[x+16>>2]=135,x)|0);i=x;Cd();return 0}a:do{if((D|0)>0){g=p+1392|0;A=r+(t+24)|0;z=p+1388|0;E=p+1412|0;F=p+1416|0;G=p+1420|0;H=p+1424|0;I=p+1408|0;J=p+1440|0;K=p+1256|0;L=p+1124|0;M=p+20|0;N=r+24|0;O=w;P=0;Q=c[g>>2]|0;R=D;b:while(1){if((Q|0)>0){S=N;T=O;U=0;V=Q;while(1){if((A-S|0)<2){break b}W=S+2|0;X=S;Y=(d[X]|d[X+1|0]<<8)<<16>>16;X=Y&65535;Z=(X<<2)+T|0;if(!(Z>>>0<=j>>>0&Y<<16>>16!=0)){break b}Y=c[z>>2]|0;_=V-U|0;c[l>>2]=c[E>>2];c[m>>2]=c[F>>2];c[n>>2]=c[G>>2];c[o>>2]=c[H>>2];$=c[u>>2]|0;aa=c[$+32>>2]|0;ca=(ba(aa,P)|0)+U<<4;da=(c[$+4>>2]|0)+((ba(c[$+36>>2]|0,P)|0)+U<<3)|0;ea=(c[$+8>>2]|0)+((ba(c[$+40>>2]|0,P)|0)+U<<3)|0;fa=(Y|0)>(_|0)?_:Y;Y=(c[$>>2]|0)+ca|0;ca=(r+T|0)==0?8:X<<5|8;TGb(c[I>>2]|0,0,fa*768|0|0)|0;X=(fa|0)>0;$=(c[B>>2]|0)==0|0;_=0;ga=0;c:while(1){ha=c[q+1412+(ga<<2)>>2]|0;ia=c[1799432+(ga<<2)>>2]|0;ja=c[1799352+((ga|$)<<2)>>2]|0;ka=d[r+((_>>>3)+T)|0]|0;la=((_|0)<(ca|0))+_|0;ma=((la|0)<(ca|0))+la|0;na=(d[r+((la>>>3)+T)|0]|0)<<(la&7)>>>7&1;la=r+((ma>>>3)+T)|0;oa=(fe(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>29;la=ma+3|0;ma=ca>>>0>la>>>0?la:ca;do{if((ka&128>>>((_&7)>>>0)|0)==0){if(!X){pa=ma;break}la=(na|0)==0;qa=(oa|0)==0;ra=32-oa|0;sa=ha;ta=0;ua=ma;while(1){if(la){va=0;wa=ua;while(1){xa=0;ya=wa;while(1){if((xa|0)>=31){za=ya;break}Aa=((ya|0)<(ca|0))+ya|0;if(((d[r+((ya>>>3)+T)|0]|0)&128>>>((ya&7)>>>0)|0)==0){xa=xa+1|0;ya=Aa}else{za=Aa;break}}if(qa){Ba=xa;Ca=za}else{ya=r+((za>>>3)+T)|0;Aa=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(za&7)>>>(ra>>>0);ya=za+oa|0;Ba=Aa+(xa<<oa)|0;Ca=ca>>>0>ya>>>0?ya:ca}if(Ba>>>0>65535>>>0){Da=-1094995529;break c}b[sa+((d[ja+va|0]|0)<<1)>>1]=Ba;ya=va+1|0;if((ya|0)<(ia|0)){va=ya;wa=Ca}else{Ea=Ca;break}}}else{wa=0;va=ua;while(1){ya=r+((va>>>3)+T)|0;Aa=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(va&7);if(Aa>>>0>134217727>>>0){ya=Aa>>>23;Fa=(d[1213744+ya|0]|0)+va|0;Ga=d[1108392+ya|0]|0;Ha=ca>>>0>Fa>>>0?Fa:ca}else{Fa=Aa>>>0>65535>>>0;ya=Fa?Aa>>>16:Aa;Ia=Fa?16:0;if((ya&65280|0)==0){Ja=Ia;Ka=ya}else{Ja=Ia|8;Ka=ya>>>8}ya=(d[1191992+Ka|0]|0)+Ja<<1;Ia=63-ya+va|0;Ga=(Aa>>>((ya-31|0)>>>0))-1|0;Ha=ca>>>0>Ia>>>0?Ia:ca}if(qa){La=Ga;Ma=Ha}else{Ia=r+((Ha>>>3)+T)|0;ya=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ha&7)>>>(ra>>>0);Ia=Ha+oa|0;La=ya+(Ga<<oa)|0;Ma=ca>>>0>Ia>>>0?Ia:ca}if(La>>>0>65535>>>0){Da=-1094995529;break c}b[sa+((d[ja+wa|0]|0)<<1)>>1]=La;Ia=wa+1|0;if((Ia|0)<(ia|0)){wa=Ia;va=Ma}else{Ea=Ma;break}}}va=ta+1|0;if((va|0)<(fa|0)){sa=sa+(ia<<1)|0;ta=va;ua=Ea}else{pa=Ea;break}}}else{ua=((ma|0)<(ca|0))+ma|0;ta=r+((ua>>>3)+T)|0;sa=(fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(ua&7)>>>29;ta=ua+3|0;ua=ca>>>0>ta>>>0?ta:ca;if(!X){pa=ua;break}ta=((d[r+((ma>>>3)+T)|0]|0)&128>>>((ma&7)>>>0)|0)==0;ra=(sa|0)==0;qa=(na|0)==0;la=(oa|0)==0;va=ia-1|0;wa=32-oa|0;Ia=32-sa|0;ya=ha;Aa=0;Fa=ua;while(1){ua=-1;Na=Fa;while(1){d:do{if(ta){Oa=0;Pa=Na;while(1){if((Oa|0)>=31){Qa=Oa;Ra=Pa;break d}Sa=((Pa|0)<(ca|0))+Pa|0;if(((d[r+((Pa>>>3)+T)|0]|0)&128>>>((Pa&7)>>>0)|0)==0){Oa=Oa+1|0;Pa=Sa}else{Qa=Oa;Ra=Sa;break}}}else{Oa=r+((Na>>>3)+T)|0;Pa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Na&7);if(Pa>>>0>134217727>>>0){Oa=Pa>>>23;Sa=(d[1213744+Oa|0]|0)+Na|0;Qa=d[1108392+Oa|0]|0;Ra=ca>>>0>Sa>>>0?Sa:ca;break}Sa=Pa>>>0>65535>>>0;Oa=Sa?Pa>>>16:Pa;Ta=Sa?16:0;if((Oa&65280|0)==0){Ua=Ta;Va=Oa}else{Ua=Ta|8;Va=Oa>>>8}Oa=(d[1191992+Va|0]|0)+Ua<<1;Ta=63-Oa+Na|0;Qa=(Pa>>>((Oa-31|0)>>>0))-1|0;Ra=ca>>>0>Ta>>>0?Ta:ca}}while(0);if(ra){Wa=Qa;Xa=Ra}else{xa=r+((Ra>>>3)+T)|0;Ta=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ra&7)>>>(Ia>>>0);xa=Ra+sa|0;Wa=Ta+(Qa<<sa)|0;Xa=ca>>>0>xa>>>0?xa:ca}if(Wa>>>0>65535>>>0){Da=-1094995529;break c}xa=ua+1+Wa|0;if((xa|0)>=(ia|0)){Ya=Xa;break}e:do{if(qa){Ta=0;Oa=Xa;while(1){if((Ta|0)>=31){Za=Ta;_a=Oa;break e}Pa=((Oa|0)<(ca|0))+Oa|0;if(((d[r+((Oa>>>3)+T)|0]|0)&128>>>((Oa&7)>>>0)|0)==0){Ta=Ta+1|0;Oa=Pa}else{Za=Ta;_a=Pa;break}}}else{Ta=r+((Xa>>>3)+T)|0;Oa=(fe(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(Xa&7);if(Oa>>>0>134217727>>>0){Ta=Oa>>>23;Pa=(d[1213744+Ta|0]|0)+Xa|0;Za=d[1108392+Ta|0]|0;_a=ca>>>0>Pa>>>0?Pa:ca;break}Pa=Oa>>>0>65535>>>0;Ta=Pa?Oa>>>16:Oa;Sa=Pa?16:0;if((Ta&65280|0)==0){$a=Sa;ab=Ta}else{$a=Sa|8;ab=Ta>>>8}Ta=(d[1191992+ab|0]|0)+$a<<1;Sa=63-Ta+Xa|0;Za=(Oa>>>((Ta-31|0)>>>0))-1|0;_a=ca>>>0>Sa>>>0?Sa:ca}}while(0);if(la){bb=Za;cb=_a}else{Sa=r+((_a>>>3)+T)|0;Ta=(fe(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(_a&7)>>>(wa>>>0);Sa=_a+oa|0;bb=Ta+(Za<<oa)|0;cb=ca>>>0>Sa>>>0?Sa:ca}Sa=bb+1|0;if(Sa>>>0>65535>>>0){Da=-1094995529;break c}b[ya+((d[ja+xa|0]|0)<<1)>>1]=Sa;if((xa|0)<(va|0)){ua=xa;Na=cb}else{Ya=cb;break}}Na=Aa+1|0;if((Na|0)<(fa|0)){ya=ya+(ia<<1)|0;Aa=Na;Fa=Ya}else{pa=Ya;break}}}}while(0);ia=ga+1|0;if((ia|0)<4){_=pa;ga=ia}else{db=21;break}}do{if((db|0)==21){db=0;if(!X){Da=0;break}ga=aa<<3;_=aa<<1;ca=0;$=Y;ia=da;ja=ea;while(1){oa=0;do{do{if((c[B>>2]|0)==0){ehb(J,K,l,n)}else{ha=c[n>>2]|0;if((oa|0)>=2){na=0;do{b[q+1440+((d[q+1256+na|0]|0)<<1)>>1]=b[ha+(na<<1)>>1]|0;na=na+1|0;}while((na|0)<64);c[n>>2]=ha+128;break}na=c[l>>2]|0;xa=0;ma=na;ka=ha;while(1){Fa=xa<<3;b[q+1440+((d[q+1256+Fa|0]|0)<<1)>>1]=b[ma>>1]|0;b[q+1440+((d[(Fa|1)+(q+1256)|0]|0)<<1)>>1]=b[ma+2>>1]|0;b[q+1440+((d[(Fa|2)+(q+1256)|0]|0)<<1)>>1]=b[ma+4>>1]|0;b[q+1440+((d[(Fa|3)+(q+1256)|0]|0)<<1)>>1]=b[ma+6>>1]|0;b[q+1440+((d[(Fa|4)+(q+1256)|0]|0)<<1)>>1]=b[ka>>1]|0;b[q+1440+((d[(Fa|5)+(q+1256)|0]|0)<<1)>>1]=b[ka+2>>1]|0;b[q+1440+((d[(Fa|6)+(q+1256)|0]|0)<<1)>>1]=b[ka+4>>1]|0;b[q+1440+((d[(Fa|7)+(q+1256)|0]|0)<<1)>>1]=b[ka+6>>1]|0;Fa=xa+1|0;if((Fa|0)<8){xa=Fa;ma=ma+8|0;ka=ka+8|0}else{break}}c[l>>2]=na+64;c[n>>2]=ha+64}}while(0);ka=c[C>>2]|0;ma=0;do{xa=q+1440+(ma<<1)|0;Fa=e[xa>>1]|0;Aa=Fa&1;b[xa>>1]=((ba(ba(d[1799368+ma|0]|0,ka)|0,Fa>>>1^-Aa)|0)>>>4)+Aa;ma=ma+1|0;}while((ma|0)<64);me[c[L>>2]&511](J);if((c[B>>2]|0)==0){ma=$+((ba(ga,oa>>1)|0)+(oa<<3&8))|0;Xe[c[M>>2]&4095](J,ma,aa)}else{ma=$+((oa<<3&8)+(ba(oa>>1,aa)|0))|0;Xe[c[M>>2]&4095](J,ma,_)}oa=oa+1|0;}while((oa|0)<4);ehb(J,K,m,o);oa=c[C>>2]|0;ma=0;do{ka=q+1440+(ma<<1)|0;Aa=e[ka>>1]|0;Fa=Aa&1;b[ka>>1]=((ba(ba(d[1799368+ma|0]|0,oa)|0,Aa>>>1^-Fa)|0)>>>4)+Fa;ma=ma+1|0;}while((ma|0)<64);me[c[L>>2]&511](J);Xe[c[M>>2]&4095](J,ia,c[(c[u>>2]|0)+36>>2]|0);ehb(J,K,m,o);ma=c[C>>2]|0;oa=0;do{Fa=q+1440+(oa<<1)|0;Aa=e[Fa>>1]|0;ka=Aa&1;b[Fa>>1]=((ba(ba(d[1799368+oa|0]|0,ma)|0,Aa>>>1^-ka)|0)>>>4)+ka;oa=oa+1|0;}while((oa|0)<64);me[c[L>>2]&511](J);Xe[c[M>>2]&4095](J,ja,c[(c[u>>2]|0)+40>>2]|0);oa=ca+1|0;if((oa|0)<(fa|0)){ca=oa;$=$+16|0;ia=ia+8|0;ja=ja+8|0}else{Da=0;break}}}}while(0);if((Da|0)<0){y=Da;db=98;break b}fa=(c[z>>2]|0)+U|0;eb=c[g>>2]|0;if((fa|0)<(eb|0)){S=W;T=Z;U=fa;V=eb}else{break}}fb=W;gb=Z;hb=eb;ib=c[v>>2]|0}else{fb=N;gb=O;hb=Q;ib=R}V=P+1|0;if((V|0)<(ib|0)){N=fb;O=gb;P=V;Q=hb;R=ib}else{break a}}if((db|0)==98){i=k;return y|0}yDb(f,16,2099528,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=k;return y|0}}while(0);c[h>>2]=1;y=c[s>>2]|0;i=k;return y|0}function dhb(a){a=a|0;$Db((c[a+60>>2]|0)+1408|0);return 0}function ehb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;h=0;i=c[g>>2]|0;while(1){j=h<<3;k=c[f>>2]|0;b[a+((d[e+j|0]|0)<<1)>>1]=b[k>>1]|0;b[a+((d[e+(j|1)|0]|0)<<1)>>1]=b[k+2>>1]|0;b[a+((d[e+(j|2)|0]|0)<<1)>>1]=b[k+4>>1]|0;b[a+((d[e+(j|3)|0]|0)<<1)>>1]=b[k+6>>1]|0;b[a+((d[e+(j|4)|0]|0)<<1)>>1]=b[i>>1]|0;b[a+((d[e+(j|5)|0]|0)<<1)>>1]=b[i+2>>1]|0;b[a+((d[e+(j|6)|0]|0)<<1)>>1]=b[i+4>>1]|0;b[a+((d[e+(j|7)|0]|0)<<1)>>1]=b[i+6>>1]|0;c[f>>2]=k+8;k=(c[g>>2]|0)+8|0;c[g>>2]=k;j=h+1|0;if((j|0)<4){h=j;i=k}else{l=4;m=k;break}}do{i=l<<3;b[a+((d[e+i|0]|0)<<1)>>1]=b[m>>1]|0;b[a+((d[e+(i|1)|0]|0)<<1)>>1]=b[m+2>>1]|0;b[a+((d[e+(i|2)|0]|0)<<1)>>1]=b[m+4>>1]|0;b[a+((d[e+(i|3)|0]|0)<<1)>>1]=b[m+6>>1]|0;b[a+((d[e+(i|4)|0]|0)<<1)>>1]=b[m+8>>1]|0;b[a+((d[e+(i|5)|0]|0)<<1)>>1]=b[m+10>>1]|0;b[a+((d[e+(i|6)|0]|0)<<1)>>1]=b[m+12>>1]|0;b[a+((d[e+(i|7)|0]|0)<<1)>>1]=b[m+14>>1]|0;m=m+16|0;c[g>>2]=m;l=l+1|0;}while((l|0)<8);return}function fhb(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;f=c[b+60>>2]|0;g=f;h=f;c[h>>2]=b;if((c[b+100>>2]|0)<36){yDb(b,16,2303544,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=e;return k|0}l=c[b+96>>2]|0;m=l+12|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=fe(n|0)|0;o=f+52|0;c[o>>2]=m;if((n|0)==0|m>>>0>536870911>>>0){n=b;yDb(n,16,2206864,(j=i,i=i+8|0,c[j>>2]=m,j)|0);i=j;yDb(n,16,2285544,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=e;return k|0}n=a[l+17|0]|0;m=f+56|0;a[m]=n;a[f+57|0]=a[l+18|0]|0;a[f+58|0]=a[l+19|0]|0;a[f+59|0]=a[l+20|0]|0;p=f+24|0;c[p>>2]=d[l+21|0]|0;l=n&255;if((l|0)==24|(l|0)==32){c[b+420>>2]=7}else if((l|0)==16){c[b+420>>2]=6}else{DDb(b,2269864,(j=i,i=i+8|0,c[j>>2]=l,j)|0);i=j;k=-1163346256;i=e;return k|0}c[b+796>>2]=d[m]|0;l=c[p>>2]|0;do{if((l|0)<1){yDb(b,24,2254472,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;c[p>>2]=c[b+416>>2]}else{n=b+416|0;if((l|0)>8){c[p>>2]=c[n>>2];break}else{c[n>>2]=l;break}}}while(0);l=c[b+416>>2]|0;if((l-1|0)>>>0>7>>>0){yDb(b,16,2240328,(j=i,i=i+8|0,c[j>>2]=l,j)|0);i=j;k=-1163346256;i=e;return k|0}l=c[p>>2]|0;n=1265320+(l-1<<3)|0;q=c[n+4>>2]|0;r=b+448|0;c[r>>2]=c[n>>2];c[r+4>>2]=q;q=c[o>>2]<<2;o=f+68|0;if((q|0)==0){if((l|0)>0){s=0}else{k=0;i=e;return k|0}while(1){c[g+28+(s<<2)>>2]=WDb(0)|0;if((d[m]|0)>>>0>16>>>0){f=(CFb(c[(c[h>>2]|0)+420>>2]|0)|0)!=0;c[o>>2]=f&1;if(!f){t=21}}else{c[o>>2]=0;t=21}if((t|0)==21){t=0;c[g+36+(s<<2)>>2]=WDb(0)|0}c[g+44+(s<<2)>>2]=WDb(0)|0;f=s+1|0;r=c[p>>2]|0;if((f|0)<(((r|0)>2?2:r)|0)){s=f}else{k=0;break}}i=e;return k|0}else{u=0;v=l}while(1){if((u|0)>=(((v|0)>2?2:v)|0)){k=0;t=40;break}l=WDb(q)|0;c[g+28+(u<<2)>>2]=l;if((l|0)==0){t=25;break}if((d[m]|0)>>>0>16>>>0){l=(CFb(c[(c[h>>2]|0)+420>>2]|0)|0)!=0;c[o>>2]=l&1;if(!l){t=29}}else{c[o>>2]=0;t=29}if((t|0)==29){t=0;l=WDb(q)|0;c[g+36+(u<<2)>>2]=l;if((l|0)==0){t=30;break}}l=WDb(q)|0;c[g+44+(u<<2)>>2]=l;if((l|0)==0){t=33;break}u=u+1|0;v=c[p>>2]|0}if((t|0)==25){yDb(c[h>>2]|0,16,2216472,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}else if((t|0)==30){yDb(c[h>>2]|0,16,2216472,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}else if((t|0)==33){yDb(c[h>>2]|0,16,2216472,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}else if((t|0)==40){i=e;return k|0}t=c[(c[h>>2]|0)+60>>2]|0;h=t+24|0;if((c[h>>2]|0)>0){p=t+28|0;v=t+68|0;u=t+36|0;g=t+44|0;t=0;do{$Db(p+(t<<2)|0);if((c[v>>2]|0)==0){$Db(u+(t<<2)|0)}$Db(g+(t<<2)|0);t=t+1|0;q=c[h>>2]|0;}while((t|0)<(((q|0)>2?2:q)|0))}yDb(b,16,2228248,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-12;i=e;return k|0}function ghb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0;k=i;i=i+176|0;l=k|0;m=k+16|0;n=k+144|0;o=k+152|0;p=k+160|0;q=k+168|0;r=f+60|0;s=c[r>>2]|0;t=g;u=c[j+24>>2]|0;v=j+28|0;j=c[v>>2]|0;w=j>>>0>268435455>>>0?-8:j<<3;j=w>>>0>2147483639>>>0|(u|0)==0;x=j?0:u;u=j?0:w;w=s+4|0;c[w>>2]=x;y=s+16|0;c[y>>2]=u;z=u+8|0;A=s+20|0;c[A>>2]=z;c[s+8>>2]=x+(u>>3);B=s+12|0;c[B>>2]=0;if(j){C=j?-1094995529:0;i=k;return C|0}c[s+64>>2]=0;a:do{if((u|0)>2){j=s+24|0;D=f;E=l|0;F=l+4|0;G=l+8|0;H=g+76|0;I=f+420|0;J=g+64|0;K=0;L=0;M=z;N=x;while(1){O=N+(L>>>3)|0;P=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>29;O=L+3|0;Q=M>>>0>O>>>0?O:M;c[B>>2]=Q;if((P|0)==7){R=159;break}else if(!((P|0)==3|(P|0)==1|(P|0)==0)){R=6;break}O=(P|0)==1;S=O?2:1;T=S+K|0;U=c[j>>2]|0;if((T|0)>(U|0)){R=9;break}V=d[1265392+(U-1<<3)+K|0]|0;if((V+S|0)>(U|0)){R=9;break}U=c[r>>2]|0;W=U+12|0;X=U+20|0;Y=c[X>>2]|0;Z=(c[W>>2]|0)+4|0;_=(Y>>>0>Z>>>0?Z:Y)+12|0;Z=Y>>>0>_>>>0?_:Y;c[W>>2]=Z;_=U+4|0;$=c[_>>2]|0;aa=a[$+(Z>>>3)|0]|0;ca=((Z|0)<(Y|0))+Z|0;c[W>>2]=ca;da=$+(ca>>>3)|0;ea=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ca&7)>>>30;da=ca+2|0;ca=Y>>>0>da>>>0?da:Y;c[W>>2]=ca;da=ea<<3;ea=U+60|0;c[ea>>2]=da;fa=U+56|0;ga=(d[fa]|0)-da+S|0;da=ga-1|0;b:do{if(da>>>0>32>>>0){yDb(D,16,1933944,(ha=i,i=i+8|0,c[ha>>2]=da,ha)|0);i=ha;ia=-1163346256}else{ja=d[$+(ca>>>3)|0]|0;ka=((ca|0)<(Y|0))+ca|0;c[W>>2]=ka;la=(ja&128>>>((ca&7)>>>0)|0)==0;if((128>>>((Z&7)>>>0)&(aa&255)|0)==0){ma=c[U+52>>2]|0}else{ja=$+(ka>>>3)|0;na=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ka&7)&-65536;ja=ka+16|0;ka=Y>>>0>ja>>>0?ja:Y;c[W>>2]=ka;ja=$+(ka>>>3)|0;oa=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ka&7)>>>16;ja=ka+16|0;c[W>>2]=Y>>>0>ja>>>0?ja:Y;ma=oa|na}do{if((ma|0)!=0){na=U+52|0;if(ma>>>0>(c[na>>2]|0)>>>0){break}oa=U+64|0;ja=c[oa>>2]|0;do{if((ja|0)==0){c[E>>2]=t;c[F>>2]=0;c[G>>2]=0;c[H>>2]=ma;ka=W0a(f,l,0)|0;if((ka|0)<0){ia=ka;break b}}else{if((ma|0)==(ja|0)){break}yDb(D,16,1890496,(ha=i,i=i+16|0,c[ha>>2]=ma,c[ha+8>>2]=ja,ha)|0);i=ha;ia=-1094995529;break b}}while(0);c[oa>>2]=ma;if((c[U+68>>2]|0)!=0){ja=U+36|0;ka=0;do{c[ja+(ka<<2)>>2]=c[(c[J>>2]|0)+(ka+V<<2)>>2];ka=ka+1|0;}while((ka|0)<(S|0))}do{if(la){ka=c[W>>2]|0;ja=c[X>>2]|0;pa=c[_>>2]|0;qa=pa+(ka>>>3)|0;ra=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ka&7)>>>24;qa=ka+8|0;ka=ja>>>0>qa>>>0?qa:ja;c[W>>2]=ka;qa=pa+(ka>>>3)|0;sa=(fe(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ka&7)>>>24;qa=ka+8|0;ka=ja>>>0>qa>>>0?qa:ja;c[W>>2]=ka;qa=c[na>>2]|0;ta=0;ua=ka;while(1){ka=pa+(ua>>>3)|0;va=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ua&7)>>>28;ka=ua+4|0;wa=ja>>>0>ka>>>0?ka:ja;c[W>>2]=wa;c[o+(ta<<2)>>2]=va;va=pa+(wa>>>3)|0;ka=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(wa&7)>>>28;va=wa+4|0;wa=ja>>>0>va>>>0?va:ja;c[W>>2]=wa;c[p+(ta<<2)>>2]=ka;ka=pa+(wa>>>3)|0;va=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(wa&7)>>>29;ka=wa+3|0;wa=ja>>>0>ka>>>0?ka:ja;c[W>>2]=wa;c[q+(ta<<2)>>2]=va;va=pa+(wa>>>3)|0;ka=(fe(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(wa&7)>>>27;va=wa+5|0;wa=ja>>>0>va>>>0?va:ja;c[W>>2]=wa;c[n+(ta<<2)>>2]=ka;if(!(ka>>>0<qa>>>0)){ia=-1094995529;break b}if((ka|0)==0){xa=wa}else{va=ka;ka=wa;while(1){wa=va-1|0;ya=pa+(ka>>>3)|0;za=(fe(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(ka&7)>>>16;ya=ka+16|0;Aa=ja>>>0>ya>>>0?ya:ja;c[W>>2]=Aa;b[m+(ta<<6)+(wa<<1)>>1]=za;if((wa|0)>0){va=wa;ka=Aa}else{xa=Aa;break}}}ka=ta+1|0;if((ka|0)<(S|0)){ta=ka;ua=xa}else{break}}c:do{if((c[ea>>2]|0)!=0){if((c[oa>>2]|0)<=0){break}ua=U+16|0;ta=U+44|0;if(((c[ua>>2]|0)-xa|0)<1){ia=-1;break b}else{Ba=xa;Ca=0}while(1){ja=0;qa=Ba;while(1){ka=c[ea>>2]|0;va=c[X>>2]|0;Aa=pa+(qa>>>3)|0;wa=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(qa&7)>>>((32-ka|0)>>>0);Aa=ka+qa|0;c[W>>2]=va>>>0>Aa>>>0?Aa:va;c[(c[ta+(ja<<2)>>2]|0)+(Ca<<2)>>2]=wa;wa=ja+1|0;if((wa|0)>=(S|0)){break}ja=wa;qa=c[W>>2]|0}qa=Ca+1|0;if((qa|0)>=(c[oa>>2]|0)){break c}ja=c[W>>2]|0;if(((c[ua>>2]|0)-ja|0)<1){ia=-1;break b}else{Ba=ja;Ca=qa}}}}while(0);pa=U+28|0;ua=U+57|0;ta=U+58|0;qa=U+16|0;ja=U+59|0;wa=(da|0)==0;va=(da|0)<26;Aa=33-ga|0;ka=ga-17|0;za=49-ga|0;ya=U;Da=U+36|0;Ea=Da;Fa=0;do{Ga=pa+(Fa<<2)|0;Ha=c[Ga>>2]|0;Ia=c[oa>>2]|0;Ja=(ba(d[ua]|0,c[q+(Fa<<2)>>2]|0)|0)/4|0;if((Ia|0)>0){Ka=0;La=d[ta]|0;Ma=0;while(1){Na=c[W>>2]|0;if(((c[qa>>2]|0)-Na|0)<1){ia=-1;break b}Oa=(La>>>9)+3|0;Pa=Oa>>>0>65535>>>0;Qa=Pa?Oa>>>16:Oa;Oa=Pa?16:0;if((Qa&65280|0)==0){Ra=Oa;Sa=Qa}else{Ra=Oa|8;Sa=Qa>>>8}Qa=(d[1191992+Sa|0]|0)+Ra|0;Oa=d[ja]|0;Pa=(Qa|0)>(Oa|0)?Oa:Qa;Qa=0;Oa=Na;while(1){if((Qa|0)>=9){Ta=Oa;R=51;break}Ua=c[_>>2]|0;Na=d[Ua+(Oa>>>3)|0]|0;Va=c[X>>2]|0;Wa=((Oa|0)<(Va|0))+Oa|0;c[W>>2]=Wa;if((Na&128>>>((Oa&7)>>>0)|0)==0){R=50;break}else{Qa=Qa+1|0;Oa=Wa}}do{if((R|0)==50){R=0;if(Qa>>>0>8>>>0){Ta=Wa;R=51;break}if((Pa|0)==1){Xa=Qa;break}Oa=Ua+(Wa>>>3)|0;Na=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Wa&7)>>>((32-Pa|0)>>>0);Oa=(Qa<<Pa)-Qa|0;if((Na|0)>1){Ya=Wa+Pa|0;c[W>>2]=Va>>>0>Ya>>>0?Ya:Va;Xa=Oa-1+Na|0;break}else{Na=Pa-1+Wa|0;c[W>>2]=Va>>>0>Na>>>0?Na:Va;Xa=Oa;break}}}while(0);do{if((R|0)==51){R=0;if(wa){Xa=0;break}Pa=c[X>>2]|0;Qa=c[_>>2]|0;Oa=Qa+(Ta>>>3)|0;Na=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Ta&7);if(va){Oa=Ta+da|0;c[W>>2]=Pa>>>0>Oa>>>0?Oa:Pa;Xa=Na>>>(Aa>>>0);break}else{Oa=Ta+16|0;Ya=Pa>>>0>Oa>>>0?Oa:Pa;c[W>>2]=Ya;Oa=Qa+(Ya>>>3)|0;Qa=(fe(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Ya&7)>>>(za>>>0);Oa=Ya+ka|0;c[W>>2]=Pa>>>0>Oa>>>0?Oa:Pa;Xa=Qa|Na>>>16<<ka;break}}}while(0);Na=Xa+Ma|0;c[Ha+(Ka<<2)>>2]=Na>>>1^-(Na&1);do{if(Na>>>0>65535>>>0){Za=0;_a=65535;$a=Ka}else{Qa=(ba(Na,Ja)|0)-((ba(La,Ja)|0)>>>9)+La|0;if(!(Qa>>>0<128>>>0)){Za=0;_a=Qa;$a=Ka;break}Pa=Ka+1|0;if((Pa|0)>=(Ia|0)){Za=0;_a=Qa;$a=Ka;break}Oa=(Qa&65280|0)==0;Ya=((Qa+16|0)>>>6)+7+(Oa?0:-8)-(d[1191992+(Oa?Qa:Qa>>>8)|0]|0)|0;Qa=d[ja]|0;Oa=(Ya|0)>(Qa|0)?Qa:Ya;Ya=0;Qa=c[W>>2]|0;while(1){if((Ya|0)>=9){R=66;break}ab=c[_>>2]|0;bb=d[ab+(Qa>>>3)|0]|0;cb=c[X>>2]|0;db=((Qa|0)<(cb|0))+Qa|0;c[W>>2]=db;if((bb&128>>>((Qa&7)>>>0)|0)==0){R=65;break}else{Ya=Ya+1|0;Qa=db}}do{if((R|0)==65){R=0;if(Ya>>>0>8>>>0){eb=db;fb=cb;gb=ab;R=67;break}if((Oa|0)==1){hb=Ya;break}bb=ab+(db>>>3)|0;ib=(fe(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(db&7)>>>((32-Oa|0)>>>0);bb=(Ya<<Oa)-Ya|0;if((ib|0)>1){jb=db+Oa|0;c[W>>2]=cb>>>0>jb>>>0?jb:cb;hb=bb-1+ib|0;break}else{ib=Oa-1+db|0;c[W>>2]=cb>>>0>ib>>>0?ib:cb;hb=bb;break}}else if((R|0)==66){R=0;eb=Qa;fb=c[X>>2]|0;gb=c[_>>2]|0;R=67}}while(0);if((R|0)==67){R=0;Qa=gb+(eb>>>3)|0;Oa=(fe(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(eb&7)>>>16;Qa=eb+16|0;c[W>>2]=fb>>>0>Qa>>>0?Qa:fb;hb=Oa}if((hb|0)>0){Oa=Ia-Ka|0;if((hb|0)<(Oa|0)){kb=hb}else{yDb(c[ya>>2]|0,16,2327560,(ha=i,i=i+24|0,c[ha>>2]=hb,c[ha+8>>2]=Ia,c[ha+16>>2]=Ka,ha)|0);i=ha;kb=Oa-1|0}TGb(Ha+(Pa<<2)|0,0,kb<<2|0)|0;lb=kb;mb=kb+Ka|0}else{lb=hb;mb=Ka}Za=(lb|0)<65536|0;_a=0;$a=mb}}while(0);Na=$a+1|0;if((Na|0)<(Ia|0)){Ka=Na;La=_a;Ma=Za}else{break}}}Ma=c[o+(Fa<<2)>>2]|0;do{if((Ma|0)==15){La=c[Ga>>2]|0;Ka=c[oa>>2]|0;if((Ka|0)<2){nb=Ka;ob=La;break}Ia=1;Ha=c[La>>2]|0;while(1){Ja=La+(Ia<<2)|0;Na=(c[Ja>>2]|0)+Ha<<Aa>>Aa;c[Ja>>2]=Na;Ja=Ia+1|0;if((Ja|0)<(Ka|0)){Ia=Ja;Ha=Na}else{R=84;break}}}else{if((Ma|0)<=0){R=84;break}yDb(D,24,2347912,(ha=i,i=i+8|0,c[ha>>2]=Ma,ha)|0);i=ha;R=84}}while(0);if((R|0)==84){R=0;nb=c[oa>>2]|0;ob=c[Ga>>2]|0}Ma=c[Ea+(Fa<<2)>>2]|0;Ha=c[n+(Fa<<2)>>2]|0;Ia=c[p+(Fa<<2)>>2]|0;Ka=c[ob>>2]|0;c[Ma>>2]=Ka;d:do{if((nb|0)>=2){if((Ha|0)==0){UGb(Ma+4|0,ob+4|0,(nb<<2)-4|0)|0;break}else if((Ha|0)==31){La=1;Na=Ka;do{Na=(c[ob+(La<<2)>>2]|0)+Na<<Aa>>Aa;c[Ma+(La<<2)>>2]=Na;La=La+1|0;}while((La|0)<(nb|0))}else{La=(Ha|0)>0;if(La){Na=1-nb|0;Ja=1;Oa=Ka;do{Oa=(c[ob+(Ja<<2)>>2]|0)+Oa<<Aa>>Aa;c[Ma+(Ja<<2)>>2]=Oa;Ja=Ja+1|0;}while((Ja|0)<=(Ha|0)&(Ja|0)<(nb|0));Ja=-Ha|0;pb=1-(Na>>>0<Ja>>>0?Ja:Na)|0}else{pb=1}if((pb|0)>=(nb|0)){break}Ja=1<<Ia-1;if(La){qb=Ma;rb=pb}else{Oa=Ja>>Ia;Qa=Ma;Ya=pb;while(1){c[Ma+(Ya<<2)>>2]=(c[ob+(Ya<<2)>>2]|0)+Oa+(c[Qa>>2]|0)<<Aa>>Aa;bb=Ya+1|0;if((bb|0)>=(nb|0)){break d}Qa=Qa+4|0;Ya=bb}}while(1){Ya=c[ob+(rb<<2)>>2]|0;Qa=c[qb>>2]|0;Oa=0;La=0;while(1){Na=La+1|0;sb=(ba(b[m+(Fa<<6)+(La<<1)>>1]|0,(c[qb+(Na<<2)>>2]|0)-Qa|0)|0)+Oa|0;if((Na|0)<(Ha|0)){Oa=sb;La=Na}else{break}}La=qb+4|0;c[Ma+(rb<<2)>>2]=Qa+Ya+(sb+Ja>>Ia)<<Aa>>Aa;e:do{if((Ya|0)!=0){Oa=(Ya|0)>0?1:-1;Pa=Ya;Na=0;while(1){if((ba(Pa,Oa)|0)<=0){break e}bb=Na+1|0;ib=c[qb+(bb<<2)>>2]|0;jb=Qa-ib|0;if((Qa|0)==(ib|0)){tb=0}else{tb=(jb|0)>0?1:-1}ib=ba(tb,Oa)|0;ub=m+(Fa<<6)+(Na<<1)|0;b[ub>>1]=(e[ub>>1]|0)-ib;ub=Pa-(ba((ba(ib,jb)|0)>>Ia,bb)|0)|0;if((bb|0)<(Ha|0)){Pa=ub;Na=bb}else{break}}}}while(0);Qa=rb+1|0;if((Qa|0)<(nb|0)){qb=La;rb=Qa}else{break}}}}}while(0);Fa=Fa+1|0;}while((Fa|0)<(S|0));do{if(!((sa|0)==0|O^1)){Fa=c[oa>>2]|0;if((Fa|0)<=0){break}Aa=c[Da>>2]|0;Ea=c[U+40>>2]|0;ya=0;do{ja=Aa+(ya<<2)|0;ka=Ea+(ya<<2)|0;za=c[ka>>2]|0;va=(c[ja>>2]|0)-((ba(za,sa)|0)>>ra)|0;c[ja>>2]=va+za;c[ka>>2]=va;ya=ya+1|0;}while((ya|0)<(Fa|0))}}while(0);ra=c[ea>>2]|0;if((ra|0)==0){break}sa=Da;Fa=U+44|0;ya=c[oa>>2]|0;Ea=(ya|0)>0;Aa=0;do{if(Ea){va=c[sa+(Aa<<2)>>2]|0;ka=c[Fa+(Aa<<2)>>2]|0;za=0;do{ja=va+(za<<2)|0;c[ja>>2]=c[ka+(za<<2)>>2]|c[ja>>2]<<ra;za=za+1|0;}while((za|0)<(ya|0))}Aa=Aa+1|0;}while((Aa|0)<(S|0))}else{if((c[oa>>2]|0)>0){Aa=U+16|0;ya=U+36|0;ra=0;do{if(((c[Aa>>2]|0)-(c[W>>2]|0)|0)<1){ia=-1;break b}else{vb=0}do{Fa=a[fa]|0;sa=Fa&255;do{if(Fa<<24>>24==0){wb=0}else{Ea=c[W>>2]|0;Da=c[X>>2]|0;za=c[_>>2]|0;ka=za+(Ea>>>3)|0;va=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(Ea&7);if((Fa&255)>>>0<26>>>0){ka=Ea+sa|0;c[W>>2]=Da>>>0>ka>>>0?ka:Da;wb=va>>>((32-sa|0)>>>0);break}else{ka=Ea+16|0;Ea=Da>>>0>ka>>>0?ka:Da;c[W>>2]=Ea;ka=sa-16|0;ja=za+(Ea>>>3)|0;za=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(Ea&7)>>>((48-sa|0)>>>0);ja=Ea+ka|0;c[W>>2]=Da>>>0>ja>>>0?ja:Da;wb=za|va>>>16<<ka;break}}}while(0);Fa=32-sa|0;c[(c[ya+(vb<<2)>>2]|0)+(ra<<2)>>2]=wb<<Fa>>Fa;vb=vb+1|0;}while((vb|0)<(S|0));ra=ra+1|0;}while((ra|0)<(c[oa>>2]|0))}c[ea>>2]=0}}while(0);na=(CFb(c[I>>2]|0)|0)==0;ra=d[fa]|0;if(!na){if((ra|0)==24){na=U+36|0;ya=0;Aa=c[oa>>2]|0;while(1){if((Aa|0)>0){Fa=c[na+(ya<<2)>>2]|0;ka=0;while(1){va=Fa+(ka<<2)|0;c[va>>2]=c[va>>2]<<8;va=ka+1|0;za=c[oa>>2]|0;if((va|0)<(za|0)){ka=va}else{xb=za;break}}}else{xb=Aa}ka=ya+1|0;if((ka|0)<(S|0)){ya=ka;Aa=xb}else{ia=0;break b}}}else if((ra|0)==16){Aa=c[J>>2]|0;ya=c[oa>>2]|0;na=(ya|0)>0;ka=U+36|0;Fa=0;while(1){if(na){za=c[ka+(Fa<<2)>>2]|0;va=0;Da=c[Aa+(Fa+V<<2)>>2]|0;while(1){b[Da>>1]=c[za+(va<<2)>>2];ja=va+1|0;if((ja|0)<(ya|0)){va=ja;Da=Da+2|0}else{break}}}Da=Fa+1|0;if((Da|0)<(S|0)){Fa=Da}else{ia=0;break b}}}else{ia=0;break b}}if((ra|0)==16){Fa=c[oa>>2]|0;if((Fa|0)<=0){ia=0;break b}ya=c[U+24>>2]|0;Aa=U+36|0;ka=0;na=(c[c[J>>2]>>2]|0)+(V<<1)|0;while(1){Da=0;va=na;while(1){b[va>>1]=c[(c[Aa+(Da<<2)>>2]|0)+(ka<<2)>>2];za=Da+1|0;if((za|0)<(S|0)){Da=za;va=va+2|0}else{break}}va=ka+1|0;if((va|0)<(Fa|0)){ka=va;na=na+(ya<<1)|0}else{ia=0;break b}}}else if((ra|0)==24){if((c[oa>>2]|0)<=0){ia=0;break b}ya=U+24|0;na=U+36|0;ka=0;Fa=(c[c[J>>2]>>2]|0)+(V<<2)|0;while(1){Aa=0;va=Fa;while(1){c[va>>2]=c[(c[na+(Aa<<2)>>2]|0)+(ka<<2)>>2]<<8;Da=Aa+1|0;if((Da|0)<(S|0)){Aa=Da;va=va+4|0}else{break}}va=ka+1|0;if((va|0)<(c[oa>>2]|0)){ka=va;Fa=Fa+(c[ya>>2]<<2)|0}else{ia=0;break b}}}else if((ra|0)==32){if((c[oa>>2]|0)<=0){ia=0;break b}ya=U+24|0;Fa=U+36|0;ka=0;na=(c[c[J>>2]>>2]|0)+(V<<2)|0;while(1){va=0;Aa=na;while(1){c[Aa>>2]=c[(c[Fa+(va<<2)>>2]|0)+(ka<<2)>>2];Da=va+1|0;if((Da|0)<(S|0)){va=Da;Aa=Aa+4|0}else{break}}Aa=ka+1|0;if((Aa|0)<(c[oa>>2]|0)){ka=Aa;na=na+(c[ya>>2]<<2)|0}else{ia=0;break b}}}else{ia=0;break b}}}while(0);yDb(D,16,1910960,(ha=i,i=i+8|0,c[ha>>2]=ma,ha)|0);i=ha;ia=-1094995529}}while(0);S=c[B>>2]|0;V=c[y>>2]|0;if((ia|0)<0){if((V|0)==(S|0)){yb=S}else{C=ia;R=165;break}}else{yb=V}if((yb-S|0)<=2){zb=D;break a}K=T;L=S;M=c[A>>2]|0;N=c[w>>2]|0}if((R|0)==6){yDb(D,16,2174808,(ha=i,i=i+8|0,c[ha>>2]=P,ha)|0);i=ha;C=-1163346256;i=k;return C|0}else if((R|0)==9){yDb(D,16,2099496,(ha=i,i=i+1|0,i=i+7&-8,c[ha>>2]=0,ha)|0);i=ha;C=-1094995529;i=k;return C|0}else if((R|0)==159){N=(c[v>>2]<<3)-Q|0;if((N|0)>8){yDb(D,16,1998776,(ha=i,i=i+8|0,c[ha>>2]=N,ha)|0);i=ha}if((c[j>>2]|0)==(K|0)){c[h>>2]=1}else{yDb(D,24,1961896,(ha=i,i=i+1|0,i=i+7&-8,c[ha>>2]=0,ha)|0);i=ha}C=c[v>>2]|0;i=k;return C|0}else if((R|0)==165){i=k;return C|0}}else{zb=f}}while(0);yDb(zb,16,2044168,(ha=i,i=i+1|0,i=i+7&-8,c[ha>>2]=0,ha)|0);i=ha;C=-1094995529;i=k;return C|0}function hhb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;a=b+24|0;if((c[a>>2]|0)<=0){return 0}d=b+28|0;e=b+68|0;f=b+36|0;g=b+44|0;b=0;do{$Db(d+(b<<2)|0);if((c[e>>2]|0)==0){$Db(f+(b<<2)|0)}$Db(g+(b<<2)|0);b=b+1|0;h=c[a>>2]|0;}while((b|0)<(((h|0)>2?2:h)|0));return 0}function ihb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;d=i;e=b+60|0;f=c[e>>2]|0;c[f>>2]=4096;g=b+424|0;c[g>>2]=4096;h=b+796|0;if((c[b+420>>2]|0)==7){if((c[h>>2]|0)!=24){yDb(b,24,2174728,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}c[h>>2]=24}else{c[h>>2]=16;c[f+28>>2]=0}k=c[b+84>>2]|0;if((k|0)==-1){c[f+8>>2]=2}else{if((k|0)<0){l=0}else{l=(k|0)>2?2:k}c[f+8>>2]=l}l=f+49216|0;c[l>>2]=40;k=f+49220|0;c[k>>2]=10;m=f+49224|0;c[m>>2]=14;c[f+49228>>2]=4;n=c[g>>2]|0;o=b+416|0;p=f+20|0;c[p>>2]=((ba(ba(c[o>>2]|0,n)|0,c[h>>2]|0)|0)+10+(((n|0)<4096)<<5|23)&-8|0)/8|0;n=cEb(52)|0;q=b+96|0;c[q>>2]=n;r=b+100|0;a:do{if((n|0)==0){s=-12}else{c[r>>2]=36;t=n;x=603979776;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=n+4|0;x=1667329121;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=n+12|0;x=fe(c[g>>2]|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=c[h>>2]|0;a[n+17|0]=t;u=c[o>>2]|0;a[n+21|0]=u;v=n+24|0;x=fe(c[p>>2]|0)|0;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;v=c[b+412>>2]|0;w=n+28|0;x=fe(ba(ba(u,v)|0,t)|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;w=n+32|0;x=fe(v|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;if((c[f+8>>2]|0)>0){a[n+18|0]=c[l>>2];a[n+19|0]=c[k>>2];a[n+20|0]=c[m>>2]}w=f+12|0;c[w>>2]=4;v=c[b+604>>2]|0;do{if((v|0)>-1){if((v-1|0)>>>0>29>>>0){yDb(b,16,2099456,(j=i,i=i+8|0,c[j>>2]=v,j)|0);i=j;s=-22;break a}else{c[w>>2]=v;y=v;break}}else{y=4}}while(0);v=f+16|0;c[v>>2]=6;w=c[b+608>>2]|0;do{if((w|0)>-1){if((w-1|0)>>>0>29>>>0){yDb(b,16,2044128,(j=i,i=i+8|0,c[j>>2]=w,j)|0);i=j;s=-22;break a}else{c[v>>2]=w;z=w;break}}else{z=6}}while(0);if((z|0)<(y|0)){yDb(b,16,1998728,(j=i,i=i+16|0,c[j>>2]=y,c[j+8>>2]=z,j)|0);i=j;s=-22;break}c[f+49524>>2]=b;w=FKa(f+49496|0,c[g>>2]|0,z,2)|0;if((w|0)<0){s=w;break}else{A=0}i=d;return A|0}}while(0);EKa((c[e>>2]|0)+49496|0);$Db(q);c[r>>2]=0;A=s;i=d;return A|0}function jhb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[a+60>>2]|0;g=f;h=d+76|0;i=c[h>>2]|0;c[f>>2]=i;if((c[h>>2]|0)<4096){j=((((i|0)<4096)<<5|23)+10+(ba(ba(c[a+416>>2]|0,i)|0,c[a+796>>2]|0)|0)&-8|0)/8|0}else{j=c[f+20>>2]|0}i=j<<1;h=r0a(a,b,i,(i|0)<0|0?-1:0)|0;if((h|0)<0){k=h;return k|0}h=f+4|0;if((c[f+8>>2]|0)==0){c[h>>2]=1;c[f+28>>2]=0}else{c[h>>2]=0;c[f+28>>2]=(c[a+796>>2]|0)-16}a=d+64|0;d=b+24|0;i=b+28|0;b=lhb(g,c[d>>2]|0,c[i>>2]|0,c[a>>2]|0)|0;if((b|0)>(j|0)){c[h>>2]=1;c[f+28>>2]=0;l=lhb(g,c[d>>2]|0,c[i>>2]|0,c[a>>2]|0)|0}else{l=b}c[i>>2]=l;c[e>>2]=1;k=0;return k|0}function khb(a){a=a|0;EKa((c[a+60>>2]|0)+49496|0);$Db(a+96|0);c[a+100>>2]=0;return 0}function lhb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=b+49524|0;i=(c[h>>2]|0)+416|0;j=(c[i>>2]|0)-1|0;k=(f|0)<0;l=k?0:e;e=k?0:f;c[b+49212>>2]=e<<3;f=b+49200|0;c[f>>2]=l;c[b+49208>>2]=l+e;e=b+49204|0;c[e>>2]=l;l=b+49196|0;c[l>>2]=32;k=b+49192|0;c[k>>2]=0;do{if((c[i>>2]|0)>0){m=0;n=0;o=0;p=0;while(1){q=c[g+((d[1265392+(j<<3)+m|0]|0)<<2)>>2]|0;if((c[1265456+(j*20|0)+(n<<2)>>2]|0)==1){mhb(b,1,p,q,c[g+((d[m+1+(1265392+(j<<3))|0]|0)<<2)>>2]|0);r=p+1|0;s=o;t=m+2|0}else{mhb(b,0,o,q,0);r=p;s=o+1|0;t=m+1|0}if((t|0)<(c[(c[h>>2]|0)+416>>2]|0)){m=t;n=n+1|0;o=s;p=r}else{break}}p=c[k>>2]|0;o=c[l>>2]|0;if((o|0)>3){u=o;v=p;w=7;break}n=fe(7>>>((3-o|0)>>>0)|p<<o|0)|0;p=c[e>>2]|0;x=n;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[e>>2]=(c[e>>2]|0)+4;y=o+29|0;z=7}else{u=32;v=0;w=7}}while(0);if((w|0)==7){y=u-3|0;z=v<<3|7}c[k>>2]=z;c[l>>2]=y;if((y|0)>=32){c[l>>2]=32;c[k>>2]=0;A=c[f>>2]|0;B=c[e>>2]|0;C=B;D=A;E=C-D|0;F=E<<3;G=F>>3;return G|0}v=z<<y;c[k>>2]=v;y=v>>>24&255;while(1){v=c[e>>2]|0;c[e>>2]=v+1;a[v]=y;v=c[k>>2]|0;c[k>>2]=v<<8;z=(c[l>>2]|0)+8|0;c[l>>2]=z;if((z|0)>=32){break}y=v>>>16&255}c[l>>2]=32;c[k>>2]=0;A=c[f>>2]|0;B=c[e>>2]|0;C=B;D=A;E=C-D|0;F=E<<3;G=F>>3;return G|0}function mhb(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;k=i;i=i+4416|0;l=k|0;m=k+4096|0;n=k+4224|0;o=k+4360|0;p=k+4392|0;q=k+4400|0;r=k+4408|0;c[p>>2]=h;c[p+4>>2]=j;s=e+49192|0;t=(f|0)==1;u=t?2:1;if((c[e+4>>2]|0)!=0){nhb(e,f,g);v=e+49524|0;w=c[v>>2]|0;if((c[w+420>>2]|0)==7){y=32-(c[w+796>>2]|0)|0;c[q>>2]=h;c[q+4>>2]=j;w=e|0;if((c[w>>2]|0)<=0){i=k;return}z=s|0;A=e+49196|0;B=e+49204|0;C=0;D=c[z>>2]|0;E=c[A>>2]|0;while(1){G=0;H=D;I=E;while(1){J=c[(c[v>>2]|0)+796>>2]|0;K=c[(c[q+(G<<2)>>2]|0)+(C<<2)>>2]>>y&(1<<J)-1;if((I|0)>(J|0)){L=I-J|0;M=H<<J|K}else{N=fe(K>>>((J-I|0)>>>0)|H<<I|0)|0;O=c[B>>2]|0;x=N;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[B>>2]=(c[B>>2]|0)+4;L=32-J+I|0;M=K}c[z>>2]=M;c[A>>2]=L;K=G+1|0;if((K|0)<(u|0)){G=K;H=M;I=L}else{break}}I=C+1|0;if((I|0)<(c[w>>2]|0)){C=I;D=M;E=L}else{break}}i=k;return}else{c[r>>2]=h;c[r+4>>2]=j;j=e|0;if((c[j>>2]|0)<=0){i=k;return}L=s|0;E=e+49196|0;M=e+49204|0;D=0;C=c[L>>2]|0;w=c[E>>2]|0;while(1){A=0;z=C;B=w;while(1){y=c[(c[v>>2]|0)+796>>2]|0;q=b[(c[r+(A<<2)>>2]|0)+(D<<1)>>1]&(1<<y)-1;if((B|0)>(y|0)){P=B-y|0;Q=z<<y|q}else{I=fe(q>>>((y-B|0)>>>0)|z<<B|0)|0;H=c[M>>2]|0;x=I;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[M>>2]=(c[M>>2]|0)+4;P=32-y+B|0;Q=q}c[L>>2]=Q;c[E>>2]=P;q=A+1|0;if((q|0)<(u|0)){A=q;z=Q;B=P}else{break}}B=D+1|0;if((B|0)<(c[j>>2]|0)){D=B;C=Q;w=P}else{break}}i=k;return}}P=e+49524|0;w=c[P>>2]|0;Q=e+28|0;C=e+24|0;c[C>>2]=u-1+(c[w+796>>2]|0)-(c[Q>>2]|0);D=(BFb(c[w+420>>2]|0)|0)<<3;w=c[P>>2]|0;P=D-(c[w+796>>2]|0)|0;D=e|0;j=c[D>>2]|0;a:do{if((c[w+420>>2]|0)==7){E=0;L=j;M=h;while(1){r=M;if((L|0)>0){v=0;while(1){c[e+32+(E<<14)+(v<<2)>>2]=c[r+(v<<2)>>2]>>P;B=v+1|0;z=c[D>>2]|0;if((B|0)<(z|0)){v=B}else{R=z;break}}}else{R=L}v=E+1|0;if((v|0)>=(u|0)){break a}E=v;L=R;M=c[p+(v<<2)>>2]|0}}else{M=0;L=j;E=h;while(1){v=E;if((L|0)>0){r=0;while(1){c[e+32+(M<<14)+(r<<2)>>2]=b[v+(r<<1)>>1]>>P;z=r+1|0;B=c[D>>2]|0;if((z|0)<(B|0)){r=z}else{S=B;break}}}else{S=L}r=M+1|0;if((r|0)>=(u|0)){break a}M=r;L=S;E=c[p+(r<<2)>>2]|0}}}while(0);nhb(e,f,g);do{if(t){g=c[D>>2]|0;if((g|0)>2){f=2;p=0;S=0;P=0;h=0;j=0;R=0;w=0;E=0;L=c[e+36>>2]|0;M=c[e+16420>>2]|0;while(1){r=c[e+32+(f<<2)>>2]|0;v=f-2|0;B=r-(L<<1)+(c[e+32+(v<<2)>>2]|0)|0;z=c[e+16416+(f<<2)>>2]|0;A=z-(M<<1)+(c[e+16416+(v<<2)>>2]|0)|0;v=A+B>>1;q=(v|0)>-1?v:-v|0;v=YGb(q,(q|0)<0|0?-1:0,h,P)|0;q=F;y=B-A|0;H=(y|0)>-1?y:-y|0;y=YGb(H,(H|0)<0|0?-1:0,S,p)|0;H=F;I=(B|0)>-1?B:-B|0;B=YGb(I,(I|0)<0|0?-1:0,E,w)|0;I=F;G=(A|0)>-1?A:-A|0;A=YGb(G,(G|0)<0|0?-1:0,R,j)|0;G=F;K=f+1|0;if((K|0)<(g|0)){f=K;p=H;S=y;P=q;h=v;j=G;R=A;w=I;E=B;L=r;M=z}else{T=H;U=y;V=q;W=v;X=G;Y=A;Z=I;_=B;break}}}else{T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;_=0}M=YGb(Y,X,_,Z)|0;L=F;E=o|0;c[E>>2]=M;c[E+4>>2]=L;E=YGb(U,T,_,Z)|0;w=F;R=o+8|0;c[R>>2]=E;c[R+4>>2]=w;R=YGb(U,T,Y,X)|0;j=F;h=o+16|0;c[h>>2]=R;c[h+4>>2]=j;h=YGb(U,T,W,V)|0;P=F;S=o+24|0;c[S>>2]=h;c[S+4>>2]=P;S=(w>>>0<L>>>0|w>>>0==L>>>0&E>>>0<M>>>0)&1;M=o+(S<<3)|0;E=c[M+4>>2]|0;L=j>>>0<E>>>0|j>>>0==E>>>0&R>>>0<(c[M>>2]|0)>>>0?2:S;S=o+(L<<3)|0;M=c[S+4>>2]|0;R=P>>>0<M>>>0|P>>>0==M>>>0&h>>>0<(c[S>>2]|0)>>>0?3:L;if((R|0)==1){if((g|0)>0){L=0;do{S=e+16416+(L<<2)|0;c[S>>2]=(c[e+32+(L<<2)>>2]|0)-(c[S>>2]|0);L=L+1|0;}while((L|0)<(g|0))}c[e+49188>>2]=1;c[e+49184>>2]=0;$=0;aa=1;break}else if((R|0)==2){if((g|0)>0){L=0;do{S=e+16416+(L<<2)|0;h=c[S>>2]|0;M=e+32+(L<<2)|0;P=(c[M>>2]|0)-h|0;c[S>>2]=P;c[M>>2]=(P>>31)+h;L=L+1|0;}while((L|0)<(g|0))}c[e+49188>>2]=1;c[e+49184>>2]=31;$=31;aa=1;break}else if((R|0)==0){c[e+49188>>2]=0;c[e+49184>>2]=0;$=0;aa=0;break}else{if((g|0)>0){L=0;do{h=e+32+(L<<2)|0;P=c[h>>2]|0;M=e+16416+(L<<2)|0;S=c[M>>2]|0;c[h>>2]=S+P>>1;c[M>>2]=P-S;L=L+1|0;}while((L|0)<(g|0))}c[e+49188>>2]=1;c[e+49184>>2]=1;$=1;aa=1;break}}else{c[e+49188>>2]=0;c[e+49184>>2]=0;$=0;aa=0}}while(0);o=s|0;s=c[o>>2]|0;V=e+49196|0;W=c[V>>2]|0;if((W|0)>8){ca=W-8|0;da=s<<8|$;ea=aa}else{aa=fe($>>>((8-W|0)>>>0)|s<<W|0)|0;s=e+49204|0;T=c[s>>2]|0;x=aa;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;ca=W+24|0;da=$;ea=c[e+49188>>2]|0}c[o>>2]=da;c[V>>2]=ca;if((ca|0)>8){fa=ca-8|0;ga=da<<8|ea;ha=e+49204|0}else{$=fe(da<<ca|ea>>>((8-ca|0)>>>0)|0)|0;da=e+49204|0;W=c[da>>2]|0;x=$;a[W]=x;x=x>>8;a[W+1|0]=x;x=x>>8;a[W+2|0]=x;x=x>>8;a[W+3|0]=x;c[da>>2]=(c[da>>2]|0)+4;fa=ca+24|0;ga=ea;ha=da}c[o>>2]=ga;c[V>>2]=fa;fa=e+8|0;ga=e+49228|0;da=e+49496|0;ea=e+12|0;ca=e+16|0;W=l|0;$=m|0;s=0;do{if((c[fa>>2]|0)==1){c[e+49232+(s*132|0)>>2]=6;c[e+49232+(s*132|0)+128>>2]=6;c[e+49232+(s*132|0)+4>>2]=160;c[e+49232+(s*132|0)+8>>2]=-190;c[e+49232+(s*132|0)+12>>2]=170;c[e+49232+(s*132|0)+16>>2]=-130;c[e+49232+(s*132|0)+20>>2]=80;c[e+49232+(s*132|0)+24>>2]=-25}else{T=DKa(da,e+32+(s<<14)|0,c[D>>2]|0,c[ea>>2]|0,c[ca>>2]|0,9,W,$,2,0,0,9,1)|0;c[e+49232+(s*132|0)>>2]=T;aa=T-1|0;c[e+49232+(s*132|0)+128>>2]=c[m+(aa<<2)>>2];UGb(e+49232+(s*132|0)+4|0,l+(aa<<7)|0,T<<2)|0}T=c[o>>2]|0;aa=c[V>>2]|0;if((aa|0)>4){ia=aa-4|0;ja=T<<4}else{U=fe(T<<aa|0)|0;T=c[ha>>2]|0;x=U;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[ha>>2]=(c[ha>>2]|0)+4;ia=aa+28|0;ja=0}c[o>>2]=ja;c[V>>2]=ia;aa=c[e+49232+(s*132|0)+128>>2]|0;if((ia|0)>4){ka=ia-4|0;la=ja<<4|aa}else{T=fe(ja<<ia|aa>>>((4-ia|0)>>>0)|0)|0;U=c[ha>>2]|0;x=T;a[U]=x;x=x>>8;a[U+1|0]=x;x=x>>8;a[U+2|0]=x;x=x>>8;a[U+3|0]=x;c[ha>>2]=(c[ha>>2]|0)+4;ka=ia+28|0;la=aa}c[o>>2]=la;c[V>>2]=ka;aa=c[ga>>2]|0;if((ka|0)>3){ma=ka-3|0;na=la<<3|aa}else{U=fe(la<<ka|aa>>>((3-ka|0)>>>0)|0)|0;T=c[ha>>2]|0;x=U;a[T]=x;x=x>>8;a[T+1|0]=x;x=x>>8;a[T+2|0]=x;x=x>>8;a[T+3|0]=x;c[ha>>2]=(c[ha>>2]|0)+4;ma=ka+29|0;na=aa}c[o>>2]=na;c[V>>2]=ma;aa=e+49232+(s*132|0)|0;T=c[aa>>2]|0;if((ma|0)>5){oa=ma-5|0;pa=na<<5|T}else{U=fe(na<<ma|T>>>((5-ma|0)>>>0)|0)|0;X=c[ha>>2]|0;x=U;a[X]=x;x=x>>8;a[X+1|0]=x;x=x>>8;a[X+2|0]=x;x=x>>8;a[X+3|0]=x;c[ha>>2]=(c[ha>>2]|0)+4;oa=ma+27|0;pa=T}c[o>>2]=pa;c[V>>2]=oa;if((c[aa>>2]|0)>0){T=0;X=pa;U=oa;while(1){Y=c[e+49232+(s*132|0)+4+(T<<2)>>2]&65535;if((U|0)>16){qa=U-16|0;ra=X<<16|Y}else{Z=fe(Y>>>((16-U|0)>>>0)|X<<U|0)|0;_=c[ha>>2]|0;x=Z;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;c[ha>>2]=(c[ha>>2]|0)+4;qa=U+16|0;ra=Y}c[o>>2]=ra;c[V>>2]=qa;Y=T+1|0;if((Y|0)<(c[aa>>2]|0)){T=Y;X=ra;U=qa}else{break}}}s=s+1|0;}while((s|0)<(u|0));s=c[Q>>2]|0;do{if((s|0)!=0){qa=(1<<s)-1|0;if((c[D>>2]|0)>0){sa=0}else{break}do{ra=0;do{oa=c[Q>>2]|0;pa=e+32+(ra<<14)+(sa<<2)|0;ma=c[pa>>2]&qa;na=c[o>>2]|0;ka=c[V>>2]|0;if((ka|0)>(oa|0)){ta=ka-oa|0;ua=na<<oa|ma;va=oa}else{la=fe(ma>>>((oa-ka|0)>>>0)|na<<ka|0)|0;na=c[ha>>2]|0;x=la;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[ha>>2]=(c[ha>>2]|0)+4;ta=32-oa+ka|0;ua=ma;va=c[Q>>2]|0}c[o>>2]=ua;c[V>>2]=ta;c[pa>>2]=c[pa>>2]>>va;ra=ra+1|0;}while((ra|0)<(u|0));sa=sa+1|0;}while((sa|0)<(c[D>>2]|0))}}while(0);sa=n;va=n|0;ta=e+32800|0;V=e+49220|0;ua=e+49216|0;o=n+128|0;Q=0;do{UGb(sa|0,e+49232+(Q*132|0)|0,132)|0;ha=c[va>>2]|0;do{if((ha|0)==31){c[ta>>2]=c[e+32+(Q<<14)>>2];s=c[D>>2]|0;if((s|0)>1){wa=1}else{xa=s;break}while(1){c[e+32800+(wa<<2)>>2]=(c[e+32+(Q<<14)+(wa<<2)>>2]|0)-(c[e+32+(Q<<14)+(wa-1<<2)>>2]|0);s=wa+1|0;qa=c[D>>2]|0;if((s|0)<(qa|0)){wa=s}else{xa=qa;break}}}else{if((ha|0)<=0){xa=c[D>>2]|0;break}qa=e+32+(Q<<14)|0;c[ta>>2]=c[qa>>2];s=1;do{ra=32-(c[C>>2]|0)|0;c[e+32800+(s<<2)>>2]=(c[e+32+(Q<<14)+(s<<2)>>2]|0)-(c[e+32+(Q<<14)+(s-1<<2)>>2]|0)<<ra>>ra;s=s+1|0;}while((s|0)<=(ha|0));s=ha+1|0;ra=c[D>>2]|0;if((s|0)>=(ra|0)){xa=ra;break}ra=qa;pa=s;s=c[o>>2]|0;ma=ha;while(1){ka=1<<s-1;oa=(ma|0)>0;na=c[ra>>2]|0;if(oa){la=ka;ga=0;while(1){ia=(ba((c[ra+(ma-ga<<2)>>2]|0)-na|0,c[n+4+(ga<<2)>>2]|0)|0)+la|0;ja=ga+1|0;if((ja|0)<(ma|0)){la=ia;ga=ja}else{ya=ia;break}}}else{ya=ka}ga=32-(c[C>>2]|0)|0;la=(c[ra+(ma+1<<2)>>2]|0)-((ya>>s)+na)<<ga>>ga;c[e+32800+(pa<<2)>>2]=la;b:do{if((la|0)==0){za=s;Aa=ma}else{ga=ma-1|0;if(!oa){za=s;Aa=ma;break}if((la|0)<0){ia=la;ja=ga;l=s;m=ma;while(1){if((ia|0)>=0){za=l;Aa=m;break b}$=c[ra>>2]|0;W=c[ra+(m-ja<<2)>>2]|0;ca=$-W|0;if(($|0)==(W|0)){Ba=0}else{Ba=(ca|0)>0?1:-1}W=n+4+(ja<<2)|0;c[W>>2]=(c[W>>2]|0)+Ba;W=ba(Ba,-ca|0)|0;ca=c[o>>2]|0;$=c[va>>2]|0;ea=ia-(ba($-ja|0,W>>ca)|0)|0;if((ja|0)>0){ia=ea;ja=ja-1|0;l=ca;m=$}else{za=ca;Aa=$;break}}}else{m=la;l=ga;ja=s;ia=ma;while(1){if((m|0)<=0){za=ja;Aa=ia;break b}$=c[ra>>2]|0;ca=c[ra+(ia-l<<2)>>2]|0;ea=$-ca|0;if(($|0)==(ca|0)){Ca=0}else{Ca=(ea|0)>0?1:-1}ca=n+4+(l<<2)|0;c[ca>>2]=(c[ca>>2]|0)-Ca;ca=ba(Ca,ea)|0;ea=c[o>>2]|0;$=c[va>>2]|0;W=m-(ba($-l|0,ca>>ea)|0)|0;if((l|0)>0){m=W;l=l-1|0;ja=ea;ia=$}else{za=ea;Aa=$;break}}}}}while(0);la=pa+1|0;oa=c[D>>2]|0;if((la|0)<(oa|0)){ra=ra+4|0;pa=la;s=za;ma=Aa}else{xa=oa;break}}}}while(0);if((xa|0)>0){ha=0;ma=0;s=ta;pa=c[V>>2]|0;while(1){ra=(pa>>>9)+3|0;qa=ra>>>0>65535>>>0;oa=qa?ra>>>16:ra;ra=qa?16:0;if((oa&65280|0)==0){Da=ra;Ea=oa}else{Da=ra|8;Ea=oa>>>8}oa=((c[s>>2]|0)*-2|0)-1|0;ra=oa>>31^oa;oa=s+4|0;qa=ma+1|0;ohb(e,ra-ha|0,(d[1191992+Ea|0]|0)+Da|0,c[C>>2]|0);la=c[ua>>2]|0;na=pa-((ba(la,pa)|0)>>>9)+(ba(ra,la)|0)|0;la=(ra|0)>65535?65535:na;do{if(la>>>0<128>>>0){na=c[D>>2]|0;if((qa|0)>=(na|0)){Fa=la;Ga=oa;Ha=qa;Ia=0;break}ra=(la&65280|0)==0;ka=((la+16|0)>>>6)+7+(ra?0:-8)-(d[1191992+(ra?la:la>>>8)|0]|0)|0;c:do{if((c[oa>>2]|0)==0){ra=qa;ia=oa;ja=0;while(1){if((ra|0)>=(na|0)){Ja=ra;Ka=ia;La=ja;break c}l=ia+4|0;m=ra+1|0;ga=ja+1|0;if((c[l>>2]|0)==0){ra=m;ia=l;ja=ga}else{Ja=m;Ka=l;La=ga;break}}}else{Ja=qa;Ka=oa;La=0}}while(0);ohb(e,La,ka,16);Fa=0;Ga=Ka;Ha=Ja;Ia=La>>>0<65536>>>0|0}else{Fa=la;Ga=oa;Ha=qa;Ia=0}}while(0);if((Ha|0)<(c[D>>2]|0)){ha=Ia;ma=Ha;s=Ga;pa=Fa}else{break}}}Q=Q+1|0;}while((Q|0)<(u|0));i=k;return}function nhb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=b|0;g=(c[f>>2]|0)<4096;h=g&1;i=b+49192|0;j=c[i>>2]|0;k=b+49196|0;l=c[k>>2]|0;if((l|0)>3){m=l-3|0;n=j<<3|d}else{o=fe(d>>>((3-l|0)>>>0)|j<<l|0)|0;j=b+49204|0;p=c[j>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;m=l+29|0;n=d}c[i>>2]=n;c[k>>2]=m;if((m|0)>4){q=m-4|0;r=n<<4|e}else{d=fe(e>>>((4-m|0)>>>0)|n<<m|0)|0;n=b+49204|0;l=c[n>>2]|0;x=d;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;q=m+28|0;r=e}c[i>>2]=r;c[k>>2]=q;if((q|0)>12){s=q-12|0;t=r<<12}else{e=fe(r<<q|0)|0;r=b+49204|0;m=c[r>>2]|0;x=e;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;s=q+20|0;t=0}c[i>>2]=t;c[k>>2]=s;if((s|0)>1){u=s-1|0;v=t<<1|h}else{q=fe(h>>>((1-s|0)>>>0)|t<<s|0)|0;t=b+49204|0;r=c[t>>2]|0;x=q;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;c[t>>2]=(c[t>>2]|0)+4;u=s+31|0;v=h}c[i>>2]=v;c[k>>2]=u;h=c[b+28>>2]>>3;if((u|0)>2){w=u-2|0;y=v<<2|h}else{s=fe(h>>>((2-u|0)>>>0)|v<<u|0)|0;v=b+49204|0;t=c[v>>2]|0;x=s;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;w=u+30|0;y=h}c[i>>2]=y;c[k>>2]=w;h=c[b+4>>2]|0;if((w|0)>1){z=w-1|0;A=y<<1|h}else{u=fe(y<<w|h>>>((1-w|0)>>>0)|0)|0;y=b+49204|0;v=c[y>>2]|0;x=u;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;z=w+31|0;A=h}c[i>>2]=A;c[k>>2]=z;if(!g){return}g=c[f>>2]|0;f=g&65535;h=g>>>16;if((z|0)>16){B=z-16|0;C=A<<16|h}else{g=fe(h>>>((16-z|0)>>>0)|A<<z|0)|0;A=b+49204|0;w=c[A>>2]|0;x=g;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;B=z+16|0;C=h}c[i>>2]=C;c[k>>2]=B;if((B|0)>16){D=B-16|0;E=C<<16|f}else{h=fe(f>>>((16-B|0)>>>0)|C<<B|0)|0;C=b+49204|0;b=c[C>>2]|0;x=h;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;D=B+16|0;E=f}c[i>>2]=E;c[k>>2]=D;return}function ohb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0;g=c[b+49224>>2]|0;h=(g|0)<(e|0)?g:e;e=(1<<h)-1|0;g=(d|0)/(e|0)|0;i=(d|0)%(e|0)|0;if((g|0)>8){e=b+49192|0;j=c[e>>2]|0;k=b+49196|0;l=c[k>>2]|0;if((l|0)>9){m=l-9|0;n=j<<9|511}else{o=fe(511>>>((9-l|0)>>>0)|j<<l|0)|0;j=b+49204|0;p=c[j>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;m=l+23|0;n=511}c[e>>2]=n;c[k>>2]=m;if((m|0)>(f|0)){q=m-f|0;r=n<<f|d}else{l=fe(d>>>((f-m|0)>>>0)|n<<m|0)|0;n=b+49204|0;j=c[n>>2]|0;x=l;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;q=32-f+m|0;r=d}c[e>>2]=r;c[k>>2]=q;return}if((g|0)==0){s=c[b+49192>>2]|0;t=c[b+49196>>2]|0}else{q=(1<<g)-1|0;k=b+49192|0;r=c[k>>2]|0;e=b+49196|0;d=c[e>>2]|0;if((d|0)>(g|0)){u=d-g|0;v=r<<g|q}else{m=fe(q>>>((g-d|0)>>>0)|r<<d|0)|0;r=b+49204|0;f=c[r>>2]|0;x=m;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;u=32-g+d|0;v=q}c[k>>2]=v;c[e>>2]=u;s=v;t=u}u=b+49192|0;v=b+49196|0;if((t|0)>1){w=t-1|0;y=s<<1}else{e=fe(s<<t|0)|0;s=b+49204|0;k=c[s>>2]|0;x=e;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;w=t+31|0;y=0}c[u>>2]=y;c[v>>2]=w;if((h|0)==1){return}if((i|0)>0){t=i+1|0;if((w|0)>(h|0)){z=w-h|0;A=y<<h|t}else{i=fe(y<<w|t>>>((h-w|0)>>>0)|0)|0;s=b+49204|0;k=c[s>>2]|0;x=i;a[k]=x;x=x>>8;a[k+1|0]=x;x=x>>8;a[k+2|0]=x;x=x>>8;a[k+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;z=32-h+w|0;A=t}c[u>>2]=A;c[v>>2]=z;return}else{z=h-1|0;if((w|0)>(z|0)){B=w-z|0;C=y<<z}else{z=fe(y<<w|0)|0;y=b+49204|0;b=c[y>>2]|0;x=z;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;B=33-h+w|0;C=0}c[u>>2]=C;c[v>>2]=B;return}}function phb(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0;l=i;m=vAb(2180744,(n=i,i=i+80|0,c[n>>2]=b,c[n+8>>2]=d,c[n+16>>2]=e,c[n+24>>2]=e,c[n+32>>2]=f,c[n+40>>2]=f,c[n+48>>2]=-g,c[n+56>>2]=-h,c[n+64>>2]=-j,c[n+72>>2]=k,n)|0)|0;i=n;c[a+860>>2]=m;if((m|0)==0){o=-12;i=l;return o|0}c[a+864>>2]=SGb(m|0)|0;o=0;i=l;return o|0}function qhb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=vAb(2180744,(e=i,i=i+80|0,c[e>>2]=2305472,c[e+8>>2]=16,c[e+16>>2]=16777215,c[e+24>>2]=16777215,c[e+32>>2]=0,c[e+40>>2]=0,c[e+48>>2]=0,c[e+56>>2]=0,c[e+64>>2]=0,c[e+72>>2]=2,e)|0)|0;i=e;c[a+860>>2]=d;if((d|0)==0){f=-12;i=b;return f|0}c[a+864>>2]=SGb(d|0)|0;f=0;i=b;return f|0}function rhb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+8|0;j=h|0;c[j>>2]=d;k=(g|0)==2;do{if((g|0)==2|(g|0)==0){do{if(k){l=Vb(d|0,44)|0;c[j>>2]=l;if((l|0)==0){m=-1094995529;i=h;return m|0}n=l+1|0;c[j>>2]=n;l=kb(n|0,j|0,10)|0;n=c[j>>2]|0;if((a[n]|0)==44){o=n+1|0;c[j>>2]=o;p=l;q=o;break}else{m=-1094995529;i=h;return m|0}}else{p=0;q=d}}while(0);KAb(b,2174656,(r=i,i=i+8|0,c[r>>2]=p,r)|0);i=r;if((e|0)==-1){KAb(b,2347896,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}else{o=(e|0)/36e4|0;l=(o*-36e4|0)+e|0;n=(l|0)/6e3|0;s=l+(n*-6e3|0)|0;l=(s|0)/100|0;KAb(b,2327536,(r=i,i=i+32|0,c[r>>2]=o,c[r+8>>2]=n,c[r+16>>2]=l,c[r+24>>2]=s+(l*-100|0),r)|0);i=r}l=(f|0)==-1?-1:f+e|0;if((l|0)==-1){KAb(b,2347896,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}else{s=(l|0)/36e4|0;n=(s*-36e4|0)+l|0;l=(n|0)/6e3|0;o=n+(l*-6e3|0)|0;n=(o|0)/100|0;KAb(b,2327536,(r=i,i=i+32|0,c[r>>2]=s,c[r+8>>2]=l,c[r+16>>2]=n,c[r+24>>2]=o+(n*-100|0),r)|0);i=r}if(k){t=q;break}KAb(b,2099408,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;t=q}else{t=d}}while(0);d=hc(t|0,2044112)|0;q=((a[t+d|0]|0)==10)+d|0;KAb(b,1998704,(r=i,i=i+16|0,c[r>>2]=q,c[r+8>>2]=t,r)|0);i=r;if(!k){m=q;i=h;return m|0}KAb(b,1961864,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=q;i=h;return m|0}function shb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+1024|0;h=g|0;IAb(h,0,-1);j=rhb(h,b,d,e,f)|0;do{if((j|0)<0){k=j}else{if(!((c[h+4>>2]|0)>>>0<(c[h+8>>2]|0)>>>0)){k=-12;break}f=a+16|0;d=a+12|0;b=XDb(c[f>>2]|0,(c[d>>2]<<2)+4|0)|0;l=b;if((b|0)==0){k=-12;break}c[f>>2]=l;f=a+8|0;b=c[f>>2]|0;m=e*10|0;c[f>>2]=b>>>0>m>>>0?b:m;m=cEb(100)|0;c[l+(c[d>>2]<<2)>>2]=m;c[m+84>>2]=3;l=QAb(h,m+92|0)|0;if((l|0)<0){k=l;break}c[d>>2]=(c[d>>2]|0)+1;n=j;i=g;return n|0}}while(0);QAb(h,0)|0;n=k;i=g;return n|0}function thb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=d+e|0;a:do{if((e|0)>0){k=(g|0)==0;l=d+(e-1)|0;if((f|0)==0){m=d;while(1){n=a[m]|0;if(n<<24>>24==0){break a}do{if(k){o=n<<24>>24;if((Ib(1910952,o|0,4)|0)==0){p=8;break}KAb(b,1890488,(q=i,i=i+8|0,c[q>>2]=o,q)|0);i=q}else{p=8}}while(0);b:do{if((p|0)==8){p=0;do{if((n<<24>>24|0)==13){if(!(m>>>0<l>>>0)){break}if((a[m+1|0]|0)==10){break b}}else if((n<<24>>24|0)==10){if(!(m>>>0<l>>>0)){break b}KAb(b,1933936,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break b}}while(0);MAb(b,n,1)}}while(0);m=m+1|0;if(!(m>>>0<j>>>0)){break a}}}if(k){r=d}else{m=d;while(1){n=a[m]|0;if(n<<24>>24==0){break a}c:do{if((Vb(f|0,n<<24>>24|0)|0)==0){do{if((n<<24>>24|0)==10){if(!(m>>>0<l>>>0)){break c}KAb(b,1933936,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break c}else if((n<<24>>24|0)==13){if(!(m>>>0<l>>>0)){break}if((a[m+1|0]|0)==10){break c}}}while(0);MAb(b,n,1)}else{KAb(b,1933936,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}}while(0);m=m+1|0;if(!(m>>>0<j>>>0)){break a}}}do{m=a[r]|0;k=m<<24>>24;if(m<<24>>24==0){break a}d:do{if((Vb(f|0,k|0)|0)==0){if((Ib(1910952,k|0,4)|0)!=0){KAb(b,1890488,(q=i,i=i+8|0,c[q>>2]=k,q)|0);i=q;break}do{if((m<<24>>24|0)==13){if(!(r>>>0<l>>>0)){break}if((a[r+1|0]|0)==10){break d}}else if((m<<24>>24|0)==10){if(!(r>>>0<l>>>0)){break d}KAb(b,1933936,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break d}}while(0);MAb(b,m,1)}else{KAb(b,1933936,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}}while(0);r=r+1|0;}while(r>>>0<j>>>0)}}while(0);KAb(b,1961864,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;i=h;return}function uhb(a){a=a|0;var b=0,d=0,e=0;b=cEb(72)|0;d=b;c[b+36>>2]=-1;if((vhb(d,a)|0)>=0){e=d;return e|0}whb(d);e=0;return e|0}function vhb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+24|0;f=e|0;g=b+36|0;if((c[g>>2]|0)>-1){h=Bhb(b,d)|0}else{h=d}if((h|0)==0){j=-1094995529;i=e;return j|0}d=e+8|0;k=h;while(1){if((a[k]|0)==0){j=0;l=11;break}h=xd(k|0,1998264,(m=i,i=i+16|0,c[m>>2]=d,c[m+8>>2]=f,m)|0)|0;i=m;m=hc(k|0,1994408)|0;n=k+(((a[k+m|0]|0)!=0)+m)|0;do{if((h|0)==2){if((QGb(d,2131008)|0)==0){c[g>>2]=0;o=Bhb(b,n)|0}else{o=n}if((QGb(d,2087160)|0)==0){c[g>>2]=1;p=Bhb(b,o)|0}else{p=o}if((QGb(d,2027624)|0)==0){c[g>>2]=2;q=Bhb(b,p)|0}else{q=p}if((QGb(d,2180600)|0)!=0){r=q;break}c[g>>2]=3;r=Bhb(b,q)|0}else{r=n}}while(0);if((r|0)==0){j=-1094995529;l=11;break}else{k=r}}if((l|0)==11){i=e;return j|0}return 0}function whb(a){a=a|0;if((a|0)==0){return}yhb(a,1789888);$Db(a+56|0);yhb(a,1790032);$Db(a+60|0);yhb(a,1790176);$Db(a+64|0);yhb(a,1790320);$Db(a+68|0);ZDb(a);return}function xhb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;a:do{if((d|0)==0){f=0;while(1){if(!(f>>>0<4>>>0)){break a}g=1789888+(f*144|0)|0;if((QGb(c[g>>2]|0,2180600)|0)==0){break}else{f=f+1|0}}yhb(a,g)}}while(0);g=a+32|0;d=c[g>>2]|0;if((vhb(a,b)|0)==0){h=(c[a+28>>2]|0)+(d*20|0)|0}else{h=0}if((e|0)==0){return h|0}c[e>>2]=(c[g>>2]|0)-d;return h|0}function yhb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+8|0;e=d|0;f=a;a=b+16|0;g=f+(c[a>>2]|0)|0;c[e>>2]=1;h=b+4|0;j=c[h>>2]|0;if((j|0)==0){k=g;l=e}else{k=c[g>>2]|0;l=f+(c[b+20>>2]|0)|0}do{if((k|0)==0){m=j}else{g=c[l>>2]|0;if((g|0)<=0){m=j;break}e=b+24|0;n=b+12|0;o=1;p=k;q=g;while(1){if((c[e>>2]|0)==0){r=q}else{g=0;do{if((c[b+24+(g*12|0)+4>>2]|0)==0){$Db(p+(c[b+24+(g*12|0)+8>>2]|0)|0)}g=g+1|0;}while((c[b+24+(g*12|0)>>2]|0)!=0);r=c[l>>2]|0}if((o|0)>=(r|0)){break}o=o+1|0;p=p+(c[n>>2]|0)|0;q=r}m=c[h>>2]|0}}while(0);c[l>>2]=0;if((m|0)==0){i=d;return}$Db(f+(c[a>>2]|0)|0);i=d;return}function zhb(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;g=i;i=i+256|0;h=g+32|0;j=g+168|0;k=g+176|0;l=g+184|0;m=g+192|0;n=g+200|0;o=g+208|0;p=g+216|0;q=g+224|0;r=g+232|0;s=g+240|0;t=g+248|0;do{if((f|0)!=0){u=d|0;v=g|0;w=d+4|0;x=g+40|0;y=g+8|0;z=g+16|0;A=d+8|0;B=g+24|0;C=d+12|0;D=h;E=d+16|0;F=d+20|0;G=d+24|0;H=d+28|0;I=d+32|0;J=d+36|0;K=d+40|0;L=f;M=0;N=0;a:while(1){O=L;P=M;while(1){Q=(P|0)!=0;if((a[O]|0)==0){R=73;break a}do{if(Q){if((c[u>>2]|0)==0){S=P;break}T=xd(O|0,2305440,(U=i,i=i+8|0,c[U>>2]=v,U)|0)|0;i=U;if((T|0)!=1){if((RGb(O,2174616,2)|0)!=0){S=P;break}}Xe[c[u>>2]&4095](e,P,N);S=0}else{S=0}}while(0);T=xd(O|0,2305440,(U=i,i=i+8|0,c[U>>2]=v,U)|0)|0;i=U;if((T|0)==1){T=c[w>>2]|0;if((T|0)!=0){ne[T&1023](e,(a[v]|0)==78|0)}V=O+2|0}else{if((RGb(O,2174616,2)|0)!=0){break}T=O+1|0;W=a[T]|0;if(W<<24>>24==92){X=T;while(1){b[h>>1]=48;TGb(x|0,0,128)|0;c[j>>2]=-1;c[l>>2]=-1;c[m>>2]=-1;c[n>>2]=-1;c[s>>2]=-1;c[t>>2]=-1;Y=xd(X|0,2099344,(U=i,i=i+24|0,c[U>>2]=y,c[U+8>>2]=z,c[U+16>>2]=k,U)|0)|0;i=U;b:do{if((Y|0)>1){Z=a[z]|0;if(Z<<24>>24==48){_=1}else{_=(Z<<24>>24!=49)<<31>>31}c[k>>2]=((_|0)!=-1)+(c[k>>2]|0);Z=c[A>>2]|0;if((Z|0)==0){break}Xe[Z&4095](e,a[y]|0,_)}else{Z=xd(X|0,2044064,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((Z|0)<=0){$=xd(X|0,1998664,(U=i,i=i+24|0,c[U>>2]=j,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if(($|0)>1){break}$=xd(X|0,1961816,(U=i,i=i+24|0,c[U>>2]=h,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if(($|0)>1){break}$=xd(X|0,1933888,(U=i,i=i+32|0,c[U>>2]=h,c[U+8>>2]=j,c[U+16>>2]=B,c[U+24>>2]=k,U)|0)|0;i=U;if(($|0)>2){break}$=xd(X|0,1910920,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if(($|0)<=0){aa=xd(X|0,1890448,(U=i,i=i+24|0,c[U>>2]=n,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((aa|0)>1){break}aa=xd(X|0,2347856,(U=i,i=i+24|0,c[U>>2]=h,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((aa|0)>1){break}aa=xd(X|0,2327488,(U=i,i=i+32|0,c[U>>2]=h,c[U+8>>2]=n,c[U+16>>2]=B,c[U+24>>2]=k,U)|0)|0;i=U;if((aa|0)>2){break}aa=xd(X|0,2303512,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((aa|0)<=0){ba=xd(X|0,2285504,(U=i,i=i+24|0,c[U>>2]=x,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((ba|0)>1){break}ba=xd(X|0,2269824,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((ba|0)<=0){ca=xd(X|0,2254440,(U=i,i=i+24|0,c[U>>2]=l,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((ca|0)>1){break}ca=xd(X|0,2240296,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((ca|0)<=0){da=xd(X|0,2228216,(U=i,i=i+24|0,c[U>>2]=m,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((da|0)>1){break}da=xd(X|0,2216440,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;if((da|0)>0){break}da=xd(X|0,2206792,(U=i,i=i+24|0,c[U>>2]=m,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((da|0)>1){break}da=xd(X|0,2198920,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((da|0)<=0){ea=xd(X|0,2190024,(U=i,i=i+24|0,c[U>>2]=x,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((ea|0)>1){break}ea=xd(X|0,2173224,(U=i,i=i+48|0,c[U>>2]=o,c[U+8>>2]=p,c[U+16>>2]=q,c[U+24>>2]=r,c[U+32>>2]=B,c[U+40>>2]=k,U)|0)|0;i=U;do{if((ea|0)<=4){fa=xd(X|0,2163632,(U=i,i=i+64|0,c[U>>2]=o,c[U+8>>2]=p,c[U+16>>2]=q,c[U+24>>2]=r,c[U+32>>2]=s,c[U+40>>2]=t,c[U+48>>2]=B,c[U+56>>2]=k,U)|0)|0;i=U;if((fa|0)>6){break}fa=xd(X|0,2156784,(U=i,i=i+32|0,c[U>>2]=o,c[U+8>>2]=p,c[U+16>>2]=B,c[U+24>>2]=k,U)|0)|0;i=U;if((fa|0)>2){fa=c[J>>2]|0;if((fa|0)==0){break b}ga=c[o>>2]|0;ha=c[p>>2]|0;Ke[fa&1023](e,ga,ha,ga,ha,-1,-1);break b}ha=xd(X|0,215e4,(U=i,i=i+32|0,c[U>>2]=o,c[U+8>>2]=p,c[U+16>>2]=B,c[U+24>>2]=k,U)|0)|0;i=U;if((ha|0)<=2){c[k>>2]=(hc(X+1|0,2143112)|0)+2;break b}ha=c[K>>2]|0;if((ha|0)==0){break b}Xe[ha&4095](e,c[o>>2]|0,c[p>>2]|0);break b}}while(0);ea=c[J>>2]|0;if((ea|0)==0){break b}Ke[ea&1023](e,c[o>>2]|0,c[p>>2]|0,c[q>>2]|0,c[r>>2]|0,c[s>>2]|0,c[t>>2]|0);break b}}while(0);da=c[I>>2]|0;if((da|0)==0){break b}ne[da&1023](e,x);break b}}while(0);ca=c[m>>2]|0;do{if((ca|0)==-1){ia=-1}else{if((a[X+2|0]|0)==110){ia=ca;break}if((ca&4|0)==0){ja=(ca&8|0)!=0?3:0}else{ja=6}da=ja+(ca&3)|0;c[m>>2]=da;ia=da}}while(0);ca=c[H>>2]|0;if((ca|0)==0){break b}ne[ca&1023](e,ia);break b}}while(0);ba=c[G>>2]|0;if((ba|0)==0){break b}ne[ba&1023](e,c[l>>2]|0);break b}}while(0);aa=c[F>>2]|0;if((aa|0)==0){break b}ne[aa&1023](e,(a[x]|0)!=0?x:0);break b}}while(0);$=c[E>>2]|0;if(($|0)==0){break b}Xe[$&4095](e,c[n>>2]|0,(a[D]|0)-48|0);break b}}while(0);Z=c[C>>2]|0;if((Z|0)==0){break}Xe[Z&4095](e,c[j>>2]|0,(a[D]|0)-48|0)}}while(0);Y=X+((c[k>>2]|0)-1)|0;Z=a[Y]|0;if(Z<<24>>24==92){X=Y}else{ka=Y;la=Z;break}}}else{ka=T;la=W}if(la<<24>>24==125){V=ka+1|0}else{ma=-1094995529;R=78;break a}}if((V|0)==0){na=S;oa=N;R=4;break a}else{O=V;P=S}}X=(S|0)==0;Z=X?O:S;Y=X?1:N+1|0;X=O+1|0;if((X|0)==0){na=Z;oa=Y;R=4;break}else{L=X;M=Z;N=Y}}if((R|0)==4){if((na|0)==0){break}pa=na;qa=oa;ra=d|0}else if((R|0)==73){if(Q){pa=P;qa=N;ra=u}else{break}}else if((R|0)==78){i=g;return ma|0}M=c[ra>>2]|0;if((M|0)==0){break}Xe[M&4095](e,pa,qa)}}while(0);qa=c[d+44>>2]|0;if((qa|0)==0){ma=0;i=g;return ma|0}me[qa&511](e);ma=0;i=g;return ma|0}function Ahb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)==0){e=3}else{if((a[d]|0)==0){e=3}else{f=d}}if((e|0)==3){f=2137664}d=c[b+24>>2]|0;g=b+20|0;b=0;while(1){if((b|0)>=(d|0)){h=0;e=8;break}i=c[g>>2]|0;if((QGb(c[i+(b*36|0)>>2]|0,f)|0)==0){break}else{b=b+1|0}}if((e|0)==8){return h|0}h=i+(b*36|0)|0;return h|0}function Bhb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=b+36|0;f=c[e>>2]|0;g=b+40+(f<<2)|0;if((d|0)==0){h=0;return h|0}i=1789892+(f*144|0)|0;j=(f|0)!=0;k=(f|0)==0;l=b;m=1789904+(f*144|0)|0;n=1789896+(f*144|0)|0;o=c[b+56+(f<<2)>>2]|0;p=d;a:while(1){d=a[p]|0;if((d<<24>>24|0)==0){h=p;q=47;break}else if((d<<24>>24|0)==33){if((a[p+1|0]|0)==58){r=p;s=o}else{q=6}}else if((d<<24>>24|0)==91){q=4;break}else if((d<<24>>24|0)==59){r=p;s=o}else{q=6}b:do{if((q|0)==6){q=0;d=c[i>>2]|0;if(j&(o|0)==0){t=SGb(d|0)|0;if((RGb(p,d,t)|0)!=0){h=0;q=47;break a}if((a[p+t|0]|0)!=58){h=0;q=47;break a}d=p+(t+1)|0;t=d;u=0;v=a[d]|0;c:while(1){if((v<<24>>24|0)==13|(v<<24>>24|0)==10|(v<<24>>24|0)==0){break}else{w=t;x=v}while(1){d=w+1|0;if(!(x<<24>>24==32)){break}w=d;x=a[d]|0}d=hc(w|0,1991056)|0;y=XDb(u,(c[g>>2]<<2)+4|0)|0;z=y;if((y|0)==0){h=0;q=47;break a}c[z+(c[g>>2]<<2)>>2]=-1;y=0;while(1){A=c[1789912+(f*144|0)+(y*12|0)>>2]|0;if((A|0)==0){break}if((RGb(w,A,d)|0)==0){q=17;break}else{y=y+1|0}}if((q|0)==17){q=0;c[z+(c[g>>2]<<2)>>2]=y}c[g>>2]=(c[g>>2]|0)+1;A=w+(((a[w+d|0]|0)==44)+d)|0;while(1){B=a[A]|0;if(B<<24>>24==32){A=A+1|0}else{t=A;u=z;v=B;continue c}}}c[b+56+(c[e>>2]<<2)>>2]=u;r=t;s=u;break}if(k){v=hc(p|0,1980472)|0;if((a[p+v|0]|0)==58){C=0}else{r=p;s=o;break}while(1){z=c[1789912+(C*12|0)>>2]|0;if((z|0)==0){r=p;s=o;break b}if((RGb(p,z,v)|0)==0){break}else{C=C+1|0}}u=c[1789916+(C*12|0)>>2]|0;t=(c[1789920+(C*12|0)>>2]|0)+(c[m>>2]|0)|0;z=p+(v+1)|0;while(1){if((a[z]|0)==32){z=z+1|0}else{break}}v=c[1420344+(u<<2)>>2]|0;A=hc(z|0,1987560)|0;ze[v&511](l+t|0,z,A)|0;r=z;s=o;break}A=c[n>>2]|0;v=SGb(A|0)|0;if((RGb(p,A,v)|0)!=0){r=p;s=o;break}if((a[p+v|0]|0)!=58){r=p;s=o;break}A=c[e>>2]|0;d=l+(c[1789908+(A*144|0)>>2]|0)|0;y=l+(c[1789904+(A*144|0)>>2]|0)|0;B=c[1789900+(A*144|0)>>2]|0;A=XDb(c[y>>2]|0,ba((c[d>>2]|0)+1|0,B)|0)|0;if((A|0)==0){h=0;q=47;break a}c[y>>2]=A;y=ba(c[d>>2]|0,B)|0;D=A+y|0;TGb(D|0,0,B|0)|0;c[d>>2]=(c[d>>2]|0)+1;if((D|0)==0){h=0;q=47;break a}D=p+(v+1)|0;v=D;d=0;B=a[D]|0;while(1){if((B<<24>>24|0)==13|(B<<24>>24|0)==10|(B<<24>>24|0)==0){r=v;s=o;break b}D=c[g>>2]|0;if((d|0)>=(D|0)){r=v;s=o;break b}E=D-1|0;D=v;F=B;while(1){G=D+1|0;if(!(F<<24>>24==32)){break}D=G;F=a[G]|0}F=(d|0)==(E|0);G=hc(D|0,(F?1987560:1983328)|0)|0;H=c[o+(d<<2)>>2]|0;if((H|0)>-1){ze[c[1420344+(c[1789912+(f*144|0)+(H*12|0)+4>>2]<<2)>>2]&511](A+((c[1789912+(f*144|0)+(H*12|0)+8>>2]|0)+y)|0,D,G)|0}H=D+G|0;do{if(F){I=H}else{if((a[H]|0)==0){I=H;break}I=D+(G+1)|0}}while(0);while(1){J=a[I]|0;if(!(J<<24>>24==32)){break}I=I+1|0}v=I;d=d+1|0;B=J}}}while(0);B=hc(r|0,1994408)|0;d=r+(((a[r+B|0]|0)!=0)+B)|0;if((d|0)==0){h=0;q=47;break}else{o=s;p=d}}if((q|0)==4){c[e>>2]=-1;h=p;return h|0}else if((q|0)==47){return h|0}return 0}function Chb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=WDb(e+1|0)|0;g=(f|0)!=0;if(!g){h=g&1;i=h^1;return i|0}UGb(f|0,d|0,e)|0;a[f+e|0]=0;e=b;b=c[e>>2]|0;if((b|0)!=0){ZDb(b)}c[e>>2]=f;h=g&1;i=h^1;return i|0}function Dhb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=i;e=xd(b|0,1977696,(b=i,i=i+8|0,c[b>>2]=a,b)|0)|0;i=b;i=d;return(e|0)==1|0}function Ehb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=i;e=xd(b|0,1970232,(b=i,i=i+8|0,c[b>>2]=a,b)|0)|0;i=b;i=d;return(e|0)==1|0}function Fhb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=i;e=xd(b|0,1973248,(f=i,i=i+8|0,c[f>>2]=a,f)|0)|0;i=f;if((e|0)==1){g=1;i=d;return g|0}e=xd(b|0,1977696,(f=i,i=i+8|0,c[f>>2]=a,f)|0)|0;i=f;g=(e|0)==1|0;i=d;return g|0}function Ghb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=xd(b|0,1975184,(b=i,i=i+32|0,c[b>>2]=e,c[b+8>>2]=f,c[b+16>>2]=g,c[b+24>>2]=h,b)|0)|0;i=b;b=(j|0)==4;if(!b){k=b&1;i=d;return k|0}c[a>>2]=((c[f>>2]|0)*6e3|0)+((c[e>>2]|0)*36e4|0)+((c[g>>2]|0)*100|0)+(c[h>>2]|0);k=b&1;i=d;return k|0}function Hhb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=xd(b|0,1977696,(b=i,i=i+8|0,c[b>>2]=e,b)|0)|0;i=b;if((f|0)!=1){g=0;i=d;return g|0}f=c[e>>2]|0;c[a>>2]=(f>>>1&2)+f-(-(f>>>3&1)&5);g=1;i=d;return g|0}function Ihb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;Z3(b+4|0,a);d=a+120|0;c[b+1428>>2]=((c[d>>2]|0)+15|0)/16|0;e=a+124|0;c[b+1432>>2]=((c[e>>2]|0)+15|0)/16|0;c[b+1436>>2]=(c[d>>2]|0)/16|0;c[b+1440>>2]=(c[e>>2]|0)/16|0;c[b>>2]=a;return}function Jhb(){var a=0,b=0,c=0.0;if(!(+g[1989869]!=0.0)){a=0;do{g[7959224+(a<<2)>>2]=+Wc(+(+(a-15|0)/3.0));a=a+1|0;}while((a|0)<64)}if(+g[1150501]!=0.0){return}else{b=0}do{c=+g[556376+(b<<2)>>2]*2.0;g[4601816+(47-b<<2)>>2]=c;g[4601816+(b<<2)>>2]=c;b=b+1|0;}while((b|0)<24);return}function Khb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;c[a+192>>2]=d;e=a+196|0;c[e>>2]=1<<d;c[a+188>>2]=b;g[a>>2]=+tGb(1.0,b);g[a+4>>2]=+tGb(1.0,b-1|0);g[a+8>>2]=+tGb(1.0,b-2|0);g[a+12>>2]=+tGb(1.0,b-3|0);g[a+16>>2]=+tGb(1.0,b-4|0);g[a+20>>2]=+tGb(1.0,b-5|0);g[a+24>>2]=+tGb(1.0,b-6|0);g[a+28>>2]=+tGb(1.0,b-7|0);g[a+32>>2]=+tGb(1.0,b-8|0);g[a+36>>2]=+tGb(1.0,b-9|0);g[a+40>>2]=+tGb(1.0,b-10|0);g[a+44>>2]=+tGb(1.0,b-11|0);g[a+48>>2]=+tGb(1.0,b-12|0);g[a+52>>2]=+tGb(1.0,b-13|0);g[a+56>>2]=+tGb(1.0,b-14|0);g[a+60>>2]=+tGb(1.0,b-15|0);b=-15;do{g[a+64+(b+15<<2)>>2]=+Wc(+(+(b|0)*(-1.0/+(c[e>>2]|0))));b=b+1|0;}while((b|0)<16);return}function Lhb(a,b,d,e,f,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0;if((c[f>>2]|0)==0){j=1.0}else{j=+g[a+(c[f+4>>2]<<2)>>2]}f=c[e>>2]|0;if((f|0)==0){if((h|0)>0){k=0}else{l=d;m=b+(h<<2)|0;n=m;o=h<<2;UGb(l|0,n|0,o)|0;return}do{g[i+(k<<2)>>2]=j*+g[b+(k<<2)>>2]+ +g[d+(k<<2)>>2];k=k+1|0;}while((k|0)<(h|0));l=d;m=b+(h<<2)|0;n=m;o=h<<2;UGb(l|0,n|0,o)|0;return}if((f|0)>0){k=a+196|0;p=a+188|0;q=c[a+192>>2]|0;r=0;s=0;while(1){t=c[e+32+(r<<2)>>2]<<q;u=c[e+4+(r<<2)>>2]|0;v=+g[a+(u<<2)>>2];w=r+1|0;x=(w|0)<(f|0);if(x){y=e+4+(w<<2)|0}else{y=p}z=+g[a+64+((c[y>>2]|0)+15-u<<2)>>2];if((s|0)<(t|0)){u=s;while(1){g[i+(u<<2)>>2]=v*(j*+g[b+(u<<2)>>2]+ +g[d+(u<<2)>>2]);A=u+1|0;if((A|0)<(t|0)){u=A}else{B=t;break}}}else{B=s}u=(c[k>>2]|0)+t|0;if((B|0)<(u|0)){A=B+1|0;C=(u|0)>(A|0);D=B;E=v;while(1){g[i+(D<<2)>>2]=E*(j*+g[b+(D<<2)>>2]+ +g[d+(D<<2)>>2]);F=D+1|0;if((F|0)<(u|0)){D=F;E=z*E}else{break}}G=C?u:A}else{G=B}if(x){r=w;s=G}else{H=G;break}}}else{H=0}if((H|0)<(h|0)){I=H}else{l=d;m=b+(h<<2)|0;n=m;o=h<<2;UGb(l|0,n|0,o)|0;return}do{g[i+(I<<2)>>2]=j*+g[b+(I<<2)>>2]+ +g[d+(I<<2)>>2];I=I+1|0;}while((I|0)<(h|0));l=d;m=b+(h<<2)|0;n=m;o=h<<2;UGb(l|0,n|0,o)|0;return}function Mhb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0;h=e;UGb(f|0,h|0,184)|0;e=(c|0)==0;if(e){i=c<<1;j=f+(i<<2)|0;k=j;UGb(h|0,k|0,184)|0;return}else{l=0}do{m=a+(l<<2)|0;n=b+(l<<2)|0;o=l<<1;g[f+(o+46<<2)>>2]=+g[m>>2]+ +g[n>>2];g[f+((o|1)+46<<2)>>2]=+g[m>>2]- +g[n>>2];n=l|1;m=a+(n<<2)|0;p=b+(n<<2)|0;g[f+((o|2)+46<<2)>>2]=+g[m>>2]+ +g[p>>2];g[f+((o|3)+46<<2)>>2]=+g[m>>2]- +g[p>>2];l=l+2|0;}while(l>>>0<c>>>0);if(e){i=c<<1;j=f+(i<<2)|0;k=j;UGb(h|0,k|0,184)|0;return}else{q=c;r=f;s=d}while(1){d=0;t=0.0;u=0.0;do{t=t+ +g[r+(d<<2)>>2]*+g[4601816+(d<<2)>>2];e=d|1;u=u+ +g[r+(e<<2)>>2]*+g[4601816+(e<<2)>>2];d=d+2|0;}while((d|0)<48);g[s>>2]=u;g[s+4>>2]=t;d=q-1|0;if((d|0)==0){break}else{q=d;r=r+8|0;s=s+8|0}}i=c<<1;j=f+(i<<2)|0;k=j;UGb(h|0,k|0,184)|0;return}function Nhb(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;i=i+8|0;b=a|0;d=0;e=0;f=2508;while(1){c[2547012+(d*20|0)>>2]=2858528+(e<<2);g=c[1260576+(d<<2)>>2]|0;h=2547020+(d*20|0)|0;c[h>>2]=1<<g;c[8749780+(d*20|0)>>2]=2858528+(f<<2);j=c[1260816+(d<<2)>>2]|0;k=8749788+(d*20|0)|0;c[k>>2]=1<<j;N_(2547008+(d*20|0)|0,g,c[1260560+(d<<2)>>2]|0,c[1260608+(d<<2)>>2]|0,1,1,c[1260592+(d<<2)>>2]|0,1,1,c[1260544+(d<<2)>>2]|0,1,1,4)|0;N_(8749776+(d*20|0)|0,j,c[1260800+(d<<2)>>2]|0,c[1260848+(d<<2)>>2]|0,1,1,c[1260832+(d<<2)>>2]|0,1,1,c[1260784+(d<<2)>>2]|0,1,1,4)|0;j=d+1|0;if((j|0)<4){d=j;e=(c[h>>2]|0)+e|0;f=(c[k>>2]|0)+f|0}else{l=0;m=76;break}}while(1){c[4311308+(l*20|0)>>2]=2858528+(m<<2);f=c[1260688+(l<<2)>>2]|0;e=4311316+(l*20|0)|0;c[e>>2]=1<<f;N_(4311304+(l*20|0)|0,f,c[1260656+(l<<2)>>2]|0,c[1260752+(l<<2)>>2]|0,1,1,c[1260720+(l<<2)>>2]|0,2,2,c[1260624+(l<<2)>>2]|0,1,1,4)|0;f=l+1|0;if((f|0)<8){l=f;m=(c[e>>2]|0)+m|0}else{break}}c[b>>2]=2564;m=0;do{l=c[1784192+(m<<4)>>2]|0;if((l|0)==0){c[4284492+(m*20|0)>>2]=0}else{Ohb(l,c[1784196+(m<<4)>>2]|0,b,4284488+(m*20|0)|0)}m=m+1|0;}while((m|0)<112);Ohb(1787736,0,b,5221176);Ohb(1787736,1787728,b,5221196);Ohb(1788080,1788064,b,5221216);Ohb(1788048,1788032,b,5221236);Ohb(1788016,1788e3,b,5221256);Ohb(1787984,1787968,b,5221276);Ohb(1787872,1787840,b,5221296);Ohb(1787952,1787920,b,5221316);Ohb(1787832,1787800,b,5221336);Ohb(1787912,1787880,b,5221356);Ohb(1787784,1787752,b,5221376);Ohb(1787688,0,b,2858384);Ohb(1787712,0,b,2858404);Ohb(1787704,1787696,b,2858424);Ohb(1787680,1787648,b,2858444);Ohb(1787640,1787608,b,2858464);Ohb(1787592,1787560,b,2858484);Ohb(1788352,1788096,b,2858504);i=a;return}function Ohb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+768|0;j=h|0;k=h+512|0;l=a[d]|0;m=a[d+1|0]|0;n=m&255;a:do{if((l&255)>>>0>(m&255)>>>0){o=0}else{p=l&255;q=0;r=0;s=d+2|0;b:while(1){t=s+1|0;u=a[s]|0;if(u<<24>>24==0){v=q;w=r}else{x=p&255;y=q;z=r;A=u&255;while(1){if((z|0)>=256){break b}a[k+z|0]=x;u=y+1|0;b[j+(z<<1)>>1]=y;B=z+1|0;C=A-1|0;if((C|0)>0){y=u;z=B;A=C}else{v=u;w=B;break}}}A=p+1|0;if((A|0)>(n|0)){o=w;break a}else{p=A;q=v<<1;r=w;s=t}}yDb(0,0,2327456,(s=i,i=i+24|0,c[s>>2]=2303496,c[s+8>>2]=2285480,c[s+16>>2]=66,s)|0);i=s;Cd()}}while(0);c[g+4>>2]=2858528+(c[f>>2]<<2);w=1<<n;c[g+12>>2]=w;N_(g,n,o,k|0,1,1,j,2,2,e,1,1,4)|0;c[f>>2]=(c[f>>2]|0)+w;i=h;return}function Phb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0;k=i;i=i+296|0;l=k|0;m=k+192|0;n=k+256|0;o=f+8|0;p=c[o>>2]|0;q=f+16|0;r=c[q>>2]|0;s=f|0;f=c[s>>2]|0;t=f+(p>>>3)|0;u=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(p&7)>>>27;t=p+5|0;c[o>>2]=r>>>0>t>>>0?t:r;r=u+1|0;t=g+4|0;c[t>>2]=r;if((u-28|0)>>>0<3>>>0){yDb(j,16,2179608,(v=i,i=i+8|0,c[v>>2]=r,v)|0);i=v;w=-1094995529;i=k;return w|0}r=c[o>>2]|0;u=d[f+(r>>>3)|0]<<(r&7)>>>7;c[o>>2]=((r|0)<(c[q>>2]|0))+r;c[g+20>>2]=u&1;u=(h|0)>0;a:do{if(u){r=g+84|0;p=g+76|0;x=g+80|0;y=g+92|0;z=g+100|0;A=g+96|0;B=0;b:while(1){TGb(g+72+(B*7768|0)+20|0,0,128)|0;C=g+72+(B*7768|0)|0;D=g+72+(B*7768|0)+8|0;c[D>>2]=0;E=c[o>>2]|0;F=c[q>>2]|0;G=c[s>>2]|0;H=G+(E>>>3)|0;I=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(E&7)>>>30;H=E+2|0;E=F>>>0>H>>>0?H:F;c[o>>2]=E;c:do{if((I|0)==0){if((c[t>>2]|0)>0){J=0;K=E;L=F}else{M=0;break}while(1){H=G+(K>>>3)|0;N=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(K&7)>>>29;H=K+3|0;c[o>>2]=L>>>0>H>>>0?H:L;c[g+72+(B*7768|0)+20+(J<<2)>>2]=N;N=J+1|0;if((N|0)>=(c[t>>2]|0)){M=0;break c}J=N;K=c[o>>2]|0;L=c[q>>2]|0}}else if((I|0)==1){N=G+(E>>>3)|0;H=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(E&7)>>>30;N=E+2|0;O=F>>>0>N>>>0?N:F;c[o>>2]=O;if((B|0)!=0){c[D>>2]=H;do{if((H|0)==0){N=c[t>>2]|0;c[g+72+(B*7768|0)+4>>2]=N;P=N}else{N=c[o>>2]|0;Q=c[q>>2]|0;R=G+(N>>>3)|0;S=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(N&7)>>>27;R=N+5|0;c[o>>2]=Q>>>0>R>>>0?R:Q;Q=g+72+(B*7768|0)+4|0;c[Q>>2]=S;if((S|0)>(c[t>>2]|0)){T=15;break b}if((c[D>>2]|0)!=3){P=S;break}S=c[o>>2]|0;R=c[q>>2]|0;N=G+(S>>>3)|0;U=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(S&7)>>>30;N=S+2|0;c[o>>2]=R>>>0>N>>>0?N:R;c[g+72+(B*7768|0)+12>>2]=U+1+(c[C>>2]<<1);P=c[Q>>2]|0}}while(0);Q=g+72+(B*7768|0)+4|0;if((P|0)==0){M=0;break}U=c[o>>2]|0;R=c[q>>2]|0;N=G+(U>>>3)|0;S=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(U&7)>>>30;N=U+2|0;U=R>>>0>N>>>0?N:R;c[o>>2]=U;if((c[Q>>2]|0)<=0){M=0;break}N=2547008+(S*20|0)|0;V=c[2547012+(S*20|0)>>2]|0;S=0;W=U;U=R;while(1){R=c[N>>2]|0;X=G+(W>>>3)|0;Y=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(W&7)>>>((32-R|0)>>>0);R=e[V+(Y<<2)>>1]|0;X=(b[V+(Y<<2)+2>>1]|0)+W|0;c[o>>2]=U>>>0>X>>>0?X:U;c[g+72+(B*7768|0)+20+(S<<2)>>2]=(c[g+92+(S<<2)>>2]|0)+R&7;R=S+1|0;if((R|0)>=(c[Q>>2]|0)){M=0;break c}S=R;W=c[o>>2]|0;U=c[q>>2]|0}}U=G+(O>>>3)|0;W=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(O&7)>>>30;U=O+2|0;c[o>>2]=F>>>0>U>>>0?U:F;c[x>>2]=W;do{if((W|0)==0){U=c[t>>2]|0;c[p>>2]=U;Z=U}else{U=c[o>>2]|0;S=c[q>>2]|0;Q=G+(U>>>3)|0;V=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(U&7)>>>27;Q=U+5|0;c[o>>2]=S>>>0>Q>>>0?Q:S;c[p>>2]=V;if((V|0)>(c[t>>2]|0)){T=26;break b}if((c[x>>2]|0)!=3){Z=V;break}V=c[o>>2]|0;S=c[q>>2]|0;Q=G+(V>>>3)|0;U=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(V&7)>>>30;Q=V+2|0;c[o>>2]=S>>>0>Q>>>0?Q:S;c[r>>2]=U+1+(c[C>>2]<<1);Z=c[p>>2]|0}}while(0);if((Z|0)==0){M=H;break}W=c[o>>2]|0;O=c[q>>2]|0;U=G+(W>>>3)|0;S=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(W&7);U=S>>>27;Q=W+5|0;W=O>>>0>Q>>>0?Q:O;c[o>>2]=W;if((U|0)>(c[p>>2]|0)){T=29;break b}Q=G+(W>>>3)|0;V=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(W&7)>>>30;Q=W+2|0;W=O>>>0>Q>>>0?Q:O;c[o>>2]=W;Q=G+(W>>>3)|0;N=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(W&7)>>>29;Q=W+3|0;W=O>>>0>Q>>>0?Q:O;c[o>>2]=W;do{if((U|0)!=0){Q=G+(W>>>3)|0;R=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(W&7)>>>29;Q=W+3|0;c[o>>2]=O>>>0>Q>>>0?Q:O;c[y>>2]=R;if(S>>>0>268435455>>>0){_=1}else{break}do{R=c[o>>2]|0;Q=c[q>>2]|0;X=G+(R>>>3)|0;Y=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(R&7)>>>29;X=R+3|0;c[o>>2]=Q>>>0>X>>>0?X:Q;c[g+92+(_<<2)>>2]=Y;_=_+1|0;}while((_|0)<(U|0))}}while(0);if((U|0)>=(c[p>>2]|0)){M=H;break}S=32-V|0;if((V|0)==0){O=U;while(1){c[g+92+(O<<2)>>2]=N;W=O+1|0;if((W|0)<(c[p>>2]|0)){O=W}else{M=H;break}}}else{O=U;while(1){W=c[o>>2]|0;Y=c[q>>2]|0;Q=G+(W>>>3)|0;X=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(W&7)>>>(S>>>0);Q=W+V|0;c[o>>2]=Y>>>0>Q>>>0?Q:Y;c[g+92+(O<<2)>>2]=X+N&7;X=O+1|0;if((X|0)<(c[p>>2]|0)){O=X}else{M=H;break}}}}else if((I|0)==3){H=G+(E>>>3)|0;O=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(E&7)>>>30;H=E+2|0;N=F>>>0>H>>>0?H:F;c[o>>2]=N;H=G+(N>>>3)|0;V=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(N&7)>>>30;H=N+2|0;c[o>>2]=F>>>0>H>>>0?H:F;c[D>>2]=V;do{if((V|0)==0){H=c[t>>2]|0;c[g+72+(B*7768|0)+4>>2]=H;$=H}else{H=c[o>>2]|0;N=c[q>>2]|0;S=G+(H>>>3)|0;U=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(H&7)>>>27;S=H+5|0;c[o>>2]=N>>>0>S>>>0?S:N;N=g+72+(B*7768|0)+4|0;c[N>>2]=U;if((U|0)>(c[t>>2]|0)){T=68;break b}if((c[D>>2]|0)!=3){$=U;break}U=c[o>>2]|0;S=c[q>>2]|0;H=G+(U>>>3)|0;X=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(U&7)>>>30;H=U+2|0;c[o>>2]=S>>>0>H>>>0?H:S;c[g+72+(B*7768|0)+12>>2]=X+1+(c[C>>2]<<1);$=c[N>>2]|0}}while(0);V=g+72+(B*7768|0)+4|0;if(($|0)==0){M=O;break}N=c[o>>2]|0;X=c[q>>2]|0;S=G+(N>>>3)|0;H=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(N&7)>>>30;S=N+2|0;N=X>>>0>S>>>0?S:X;c[o>>2]=N;S=G+(N>>>3)|0;U=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(N&7)>>>29;S=N+3|0;c[o>>2]=X>>>0>S>>>0?S:X;c[g+72+(B*7768|0)+20>>2]=U;if((c[V>>2]|0)<=1){M=O;break}U=2547008+(H*20|0)|0;X=c[2547012+(H*20|0)>>2]|0;H=1;while(1){S=c[U>>2]|0;N=c[o>>2]|0;Y=c[q>>2]|0;Q=G+(N>>>3)|0;W=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(N&7)>>>((32-S|0)>>>0);S=e[X+(W<<2)>>1]|0;Q=(b[X+(W<<2)+2>>1]|0)+N|0;c[o>>2]=Y>>>0>Q>>>0?Q:Y;c[g+72+(B*7768|0)+20+(H<<2)>>2]=(c[g+72+(B*7768|0)+20+(H-1<<2)>>2]|0)+S&7;S=H+1|0;if((S|0)<(c[V>>2]|0)){H=S}else{M=O;break}}}else if((I|0)==2){O=G+(E>>>3)|0;H=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(E&7)>>>30;O=E+2|0;c[o>>2]=F>>>0>O>>>0?O:F;c[D>>2]=H;do{if((H|0)==0){c[g+72+(B*7768|0)+4>>2]=c[t>>2]}else{O=c[o>>2]|0;V=c[q>>2]|0;X=G+(O>>>3)|0;U=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(O&7)>>>27;X=O+5|0;c[o>>2]=V>>>0>X>>>0?X:V;c[g+72+(B*7768|0)+4>>2]=U;if((U|0)>(c[t>>2]|0)){T=42;break b}if((c[D>>2]|0)!=3){break}U=c[o>>2]|0;V=c[q>>2]|0;X=G+(U>>>3)|0;O=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(U&7)>>>30;X=U+2|0;c[o>>2]=V>>>0>X>>>0?X:V;c[g+72+(B*7768|0)+12>>2]=O+1+(c[C>>2]<<1)}}while(0);if((B|0)!=0){H=g+72+(B*7768|0)+4|0;if((c[H>>2]|0)==0){M=0;break}O=c[o>>2]|0;V=c[q>>2]|0;X=G+(O>>>3)|0;U=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(O&7)>>>30;X=O+2|0;O=V>>>0>X>>>0?X:V;c[o>>2]=O;X=c[2547012+(U*20|0)>>2]|0;S=2547008+(U*20|0)|0;U=c[S>>2]|0;Y=G+(O>>>3)|0;Q=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(O&7)>>>((32-U|0)>>>0);U=e[X+(Q<<2)>>1]|0;Y=(b[X+(Q<<2)+2>>1]|0)+O|0;c[o>>2]=V>>>0>Y>>>0?Y:V;c[g+72+(B*7768|0)+20>>2]=(c[y>>2]|0)+U&7;if((c[H>>2]|0)>1){aa=1}else{M=0;break}while(1){U=aa-1|0;V=(c[g+92+(aa<<2)>>2]|0)-(c[g+92+(U<<2)>>2]|0)|0;Y=c[S>>2]|0;O=c[o>>2]|0;Q=c[q>>2]|0;N=G+(O>>>3)|0;W=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(O&7)>>>((32-Y|0)>>>0);Y=e[X+(W<<2)>>1]|0;N=(b[X+(W<<2)+2>>1]|0)+O|0;c[o>>2]=Q>>>0>N>>>0?N:Q;c[g+72+(B*7768|0)+20+(aa<<2)>>2]=V+Y+(c[g+72+(B*7768|0)+20+(U<<2)>>2]|0)&7;U=aa+1|0;if((U|0)<(c[H>>2]|0)){aa=U}else{M=0;break c}}}if((c[p>>2]|0)==0){M=0;break}H=c[o>>2]|0;X=c[q>>2]|0;S=G+(H>>>3)|0;U=fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0;S=H&7;Y=H+1|0;H=X>>>0>Y>>>0?Y:X;c[o>>2]=H;Y=G+(H>>>3)|0;V=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(H&7)>>>31;Y=H+1|0;H=X>>>0>Y>>>0?Y:X;c[o>>2]=H;Y=2547008+(V*20|0)|0;Q=G+(H>>>3)|0;N=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(H&7)>>>29;Q=H+3|0;H=X>>>0>Q>>>0?Q:X;c[o>>2]=H;Q=G+(H>>>3)|0;O=(fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(H&7)>>>28;Q=H+4|0;c[o>>2]=X>>>0>Q>>>0?Q:X;X=c[p>>2]|0;do{if((X|0)==0){ca=0}else{c[z>>2]=N;c[A>>2]=N;c[y>>2]=N;if((X|0)>3){da=3}else{ca=X;break}do{c[g+92+(da<<2)>>2]=N-(a[(d[1787528+da|0]|0)-1+(1782888+(N*144|0)+(O*9|0))|0]|0);da=da+1|0;}while((da|0)<(X|0));ca=c[p>>2]|0}}while(0);if((U&-2147483648>>>(S>>>0)|0)==0){if((ca|0)<=0){M=0;break}X=Y|0;O=c[2547012+(V*20|0)>>2]|0;N=0;while(1){Q=c[X>>2]|0;H=c[o>>2]|0;W=c[q>>2]|0;R=G+(H>>>3)|0;ea=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(H&7)>>>((32-Q|0)>>>0);Q=e[O+(ea<<2)>>1]|0;R=(b[O+(ea<<2)+2>>1]|0)+H|0;c[o>>2]=W>>>0>R>>>0?R:W;W=g+92+(N<<2)|0;c[W>>2]=(c[W>>2]|0)+Q&7;Q=N+1|0;if((Q|0)<(c[p>>2]|0)){N=Q}else{M=0;break c}}}if((ca&-2|0)>0){N=2547012+(V*20|0)|0;O=Y|0;X=0;while(1){S=c[o>>2]|0;U=d[G+(S>>>3)|0]|0;Q=c[q>>2]|0;W=((S|0)<(Q|0))+S|0;c[o>>2]=W;if((U&128>>>((S&7)>>>0)|0)==0){S=g+92+(X<<2)|0;U=c[S>>2]|0;R=c[N>>2]|0;H=c[O>>2]|0;ea=G+(W>>>3)|0;fa=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(W&7)>>>((32-H|0)>>>0);H=e[R+(fa<<2)>>1]|0;ea=(b[R+(fa<<2)+2>>1]|0)+W|0;c[o>>2]=Q>>>0>ea>>>0?ea:Q;c[S>>2]=H+U&7;U=g+92+((X|1)<<2)|0;H=c[U>>2]|0;S=c[O>>2]|0;Q=c[o>>2]|0;ea=c[q>>2]|0;W=G+(Q>>>3)|0;fa=(fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Q&7)>>>((32-S|0)>>>0);S=e[R+(fa<<2)>>1]|0;W=(b[R+(fa<<2)+2>>1]|0)+Q|0;c[o>>2]=ea>>>0>W>>>0?W:ea;c[U>>2]=S+H&7}H=X+2|0;S=c[p>>2]|0;if((H|0)<(S&-2|0)){X=H}else{ga=H;ha=S;break}}}else{ga=0;ha=ca}if((ha&1|0)==0){M=0;break}X=g+92+(ga<<2)|0;O=c[X>>2]|0;N=c[2547012+(V*20|0)>>2]|0;S=c[Y>>2]|0;H=c[o>>2]|0;U=c[q>>2]|0;ea=G+(H>>>3)|0;W=(fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(H&7)>>>((32-S|0)>>>0);S=e[N+(W<<2)>>1]|0;ea=(b[N+(W<<2)+2>>1]|0)+H|0;c[o>>2]=U>>>0>ea>>>0?ea:U;c[X>>2]=S+O&7;M=0}else{M=0}}while(0);F=c[D>>2]|0;do{if((F|0)==2){E=c[g+72+(B*7768|0)+4>>2]|0;if((E|0)>=(c[t>>2]|0)){break}if((B|0)==0){I=E;do{c[g+92+(I<<2)>>2]=1;I=I+1|0;}while((I|0)<(c[t>>2]|0))}else{I=E;do{Y=c[o>>2]|0;V=d[G+(Y>>>3)|0]<<(Y&7)>>>7;c[o>>2]=((Y|0)<(c[q>>2]|0))+Y;c[g+72+(B*7768|0)+20+(I<<2)>>2]=V&1;I=I+1|0;}while((I|0)<(c[t>>2]|0))}}else if((F|0)==3){if((B|0)==0){ia=(c[t>>2]|0)-(c[r>>2]|0)|0;ja=c[p>>2]|0}else{I=c[g+72+(B*7768|0)+4>>2]|0;ia=(c[g+72+(B*7768|0)+12>>2]|0)+I|0;ja=I}if((ja|0)<(ia|0)){ka=ja}else{break}do{c[g+72+(B*7768|0)+20+(ka<<2)>>2]=1;ka=ka+1|0;}while((ka|0)<(ia|0))}}while(0);d:do{if((M|0)!=0){F=M-1+((c[C>>2]|0)*3|0)|0;la=0;while(1){if((la|0)>=(c[t>>2]|0)){break d}D=g+72+(B*7768|0)+20+(la<<2)|0;ma=(c[D>>2]|0)+(a[1782696+(F<<5)+la|0]|0)|0;c[D>>2]=ma;if(ma>>>0>7>>>0){T=88;break b}la=la+1|0}}}while(0);C=B+1|0;if((C|0)<(h|0)){B=C}else{na=G;break a}}if((T|0)==15){yDb(j,16,2347720,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==26){yDb(j,16,2347720,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==29){yDb(j,16,1910880,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==42){yDb(j,16,2347720,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==68){yDb(j,16,2347720,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==88){yDb(j,16,1890408,(v=i,i=i+16|0,c[v>>2]=la,c[v+8>>2]=ma,v)|0);i=v;w=-1094995529;i=k;return w|0}}else{na=f}}while(0);f=c[t>>2]|0;t=f-1|0;e:do{if((f|0)>0){if((h|0)==2){oa=f;pa=t}else{ma=f;la=t;while(1){if((c[g+92+(la<<2)>>2]|0)!=0){qa=ma;break e}if((la|0)>0){ma=la;la=la-1|0}else{qa=la;break e}}}while(1){if((c[g+92+(pa<<2)>>2]|0)!=0){qa=oa;break e}if((c[g+7860+(pa<<2)>>2]|0)!=0){qa=oa;break e}if((pa|0)>0){oa=pa;pa=pa-1|0}else{qa=pa;break}}}else{qa=f}}while(0);f=g+12|0;c[f>>2]=qa;pa=g+8|0;c[pa>>2]=(d[1787496+t|0]|0)+1;f:do{if((qa|0)==0){t=g+16|0;c[t>>2]=0;ra=t;T=215}else{t=g+16|0;c[t>>2]=(d[1787496+(qa-1)|0]|0)+1;do{if(u){oa=g+220|0;la=g+228|0;ma=g+224|0;M=0;g:while(1){TGb(g+72+(M*7768|0)+148|0,0,128)|0;ia=c[o>>2]|0;ka=c[q>>2]|0;sa=c[s>>2]|0;ja=sa+(ia>>>3)|0;ga=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ia&7)>>>30;ja=ia+2|0;ia=ka>>>0>ja>>>0?ja:ka;c[o>>2]=ia;h:do{if((ga|0)==2){ja=sa+(ia>>>3)|0;ha=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ia&7)>>>30;ja=ia+2|0;ca=ka>>>0>ja>>>0?ja:ka;c[o>>2]=ca;if((M|0)!=0){ja=c[4311308+(ha*20|0)>>2]|0;da=4311304+(ha*20|0)|0;aa=c[da>>2]|0;$=sa+(ca>>>3)|0;_=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ca&7)>>>((32-aa|0)>>>0);aa=e[ja+(_<<2)>>1]|0;$=(b[ja+(_<<2)+2>>1]|0)+ca|0;c[o>>2]=ka>>>0>$>>>0?$:ka;c[g+72+(M*7768|0)+148>>2]=(c[oa>>2]|0)+aa&63;if((c[f>>2]|0)>1){ta=1}else{break}while(1){aa=ta-1|0;$=(c[g+220+(ta<<2)>>2]|0)-(c[g+220+(aa<<2)>>2]|0)|0;_=c[da>>2]|0;Z=c[o>>2]|0;P=c[q>>2]|0;L=sa+(Z>>>3)|0;K=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(Z&7)>>>((32-_|0)>>>0);_=e[ja+(K<<2)>>1]|0;L=(b[ja+(K<<2)+2>>1]|0)+Z|0;c[o>>2]=P>>>0>L>>>0?L:P;c[g+72+(M*7768|0)+148+(ta<<2)>>2]=$+_+(c[g+72+(M*7768|0)+148+(aa<<2)>>2]|0)&63;ta=ta+1|0;if((ta|0)>=(c[f>>2]|0)){break h}}}ja=ha|4;da=sa+(ca>>>3)|0;aa=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ca&7)>>>26;da=ca+6|0;_=ka>>>0>da>>>0?da:ka;c[o>>2]=_;da=sa+(_>>>3)|0;$=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(_&7)>>>26;da=_+6|0;c[o>>2]=ka>>>0>da>>>0?da:ka;da=c[f>>2]|0;if((da|0)==0){break}c[la>>2]=aa;c[ma>>2]=aa;c[oa>>2]=aa;if((da|0)>3){_=3;do{c[g+220+(_<<2)>>2]=aa-(a[(d[1787528+_|0]|0)-1+(1786040+($*9|0))|0]|0);_=_+1|0;}while((_|0)<(da|0));ua=c[f>>2]|0}else{ua=da}if((ua|0)<=0){break}_=4311304+(ja*20|0)|0;$=c[4311308+(ja*20|0)>>2]|0;aa=0;do{ca=c[_>>2]|0;ha=c[o>>2]|0;P=c[q>>2]|0;L=sa+(ha>>>3)|0;Z=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(ha&7)>>>((32-ca|0)>>>0);ca=e[$+(Z<<2)>>1]|0;L=(b[$+(Z<<2)+2>>1]|0)+ha|0;c[o>>2]=P>>>0>L>>>0?L:P;P=g+220+(aa<<2)|0;c[P>>2]=(ca<<28>>28)+(c[P>>2]|0)&63;aa=aa+1|0;}while((aa|0)<(c[f>>2]|0))}else if((ga|0)==3){if((M|0)!=0){if((c[f>>2]|0)>0){va=0}else{break}while(1){c[g+72+(M*7768|0)+148+(va<<2)>>2]=c[g+220+(va<<2)>>2];va=va+1|0;if((va|0)>=(c[f>>2]|0)){break h}}}aa=sa+(ia>>>3)|0;$=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ia&7)>>>30;aa=ia+2|0;_=ka>>>0>aa>>>0?aa:ka;c[o>>2]=_;aa=sa+(_>>>3)|0;ja=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(_&7)>>>30;aa=_+2|0;_=ka>>>0>aa>>>0?aa:ka;c[o>>2]=_;if(($|0)!=3){aa=sa+(_>>>3)|0;da=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(_&7)>>>26;aa=_+6|0;c[o>>2]=ka>>>0>aa>>>0?aa:ka;c[oa>>2]=da;da=c[f>>2]|0;if((da|0)<=1){wa=$;xa=da;T=154;break}da=4311304+(ja*20|0)|0;aa=c[4311308+(ja*20|0)>>2]|0;P=1;while(1){ca=c[da>>2]|0;L=c[o>>2]|0;ha=c[q>>2]|0;Z=sa+(L>>>3)|0;K=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(L&7)>>>((32-ca|0)>>>0);ca=e[aa+(K<<2)>>1]|0;Z=(b[aa+(K<<2)+2>>1]|0)+L|0;c[o>>2]=ha>>>0>Z>>>0?Z:ha;c[g+220+(P<<2)>>2]=(c[g+220+(P-1<<2)>>2]|0)+ca&63;ca=P+1|0;ha=c[f>>2]|0;if((ca|0)<(ha|0)){P=ca}else{wa=$;xa=ha;T=154;break h}}}$=ja|4;P=sa+(_>>>3)|0;aa=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(_&7)>>>26;P=_+6|0;da=ka>>>0>P>>>0?P:ka;c[o>>2]=da;P=sa+(da>>>3)|0;ha=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(da&7)>>>26;P=da+6|0;c[o>>2]=ka>>>0>P>>>0?P:ka;P=c[f>>2]|0;do{if((P|0)!=0){c[la>>2]=aa;c[ma>>2]=aa;c[oa>>2]=aa;if((P|0)>3){ya=3}else{break}do{c[g+220+(ya<<2)>>2]=aa-(a[(d[1787528+ya|0]|0)-1+(1786040+(ha*9|0))|0]|0);ya=ya+1|0;}while((ya|0)<(P|0))}}while(0);P=c[o>>2]|0;ha=c[q>>2]|0;aa=sa+(P>>>3)|0;_=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(P&7)>>>28;aa=P+4|0;c[o>>2]=ha>>>0>aa>>>0?aa:ha;ha=_+56|0;c[oa>>2]=ha+(c[oa>>2]|0)&63;if((c[f>>2]|0)<=1){break}_=4311304+($*20|0)|0;aa=c[4311308+($*20|0)>>2]|0;P=ha;ha=1;do{ja=c[_>>2]|0;da=c[o>>2]|0;ca=c[q>>2]|0;Z=sa+(da>>>3)|0;L=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(da&7)>>>((32-ja|0)>>>0);ja=e[aa+(L<<2)>>1]|0;Z=(b[aa+(L<<2)+2>>1]|0)+da|0;c[o>>2]=ca>>>0>Z>>>0?Z:ca;P=(ja<<28>>28)+(P&63)|0;ja=g+220+(ha<<2)|0;c[ja>>2]=P+(c[ja>>2]|0)&63;ha=ha+1|0;}while((ha|0)<(c[f>>2]|0))}else if((ga|0)==1){ha=sa+(ia>>>3)|0;P=(fe(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ia&7)>>>30;ha=ia+2|0;aa=ka>>>0>ha>>>0?ha:ka;c[o>>2]=aa;if((M|0)!=0){if((c[f>>2]|0)<=0){break}ha=4311304+(P*20|0)|0;_=c[4311308+(P*20|0)>>2]|0;$=0;ja=aa;ca=ka;while(1){Z=c[ha>>2]|0;da=sa+(ja>>>3)|0;L=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ja&7)>>>((32-Z|0)>>>0);Z=e[_+(L<<2)>>1]|0;da=(b[_+(L<<2)+2>>1]|0)+ja|0;c[o>>2]=ca>>>0>da>>>0?da:ca;c[g+72+(M*7768|0)+148+($<<2)>>2]=(c[g+220+($<<2)>>2]|0)+Z&63;Z=$+1|0;if((Z|0)>=(c[f>>2]|0)){break h}$=Z;ja=c[o>>2]|0;ca=c[q>>2]|0}}ca=sa+(aa>>>3)|0;ja=(fe(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(aa&7);if((P|0)!=3){ca=ja>>>27;$=aa+5|0;_=ka>>>0>$>>>0?$:ka;c[o>>2]=_;$=sa+(_>>>3)|0;ha=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(_&7)>>>29;$=_+3|0;_=ka>>>0>$>>>0?$:ka;c[o>>2]=_;$=sa+(_>>>3)|0;Z=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(_&7)>>>26;$=_+6|0;_=ka>>>0>$>>>0?$:ka;c[o>>2]=_;$=c[f>>2]|0;if((ca|0)>($|0)|(ha|0)==7){T=124;break g}if((ca|0)==0){za=$}else{$=sa+(_>>>3)|0;da=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(_&7)>>>26;$=_+6|0;c[o>>2]=ka>>>0>$>>>0?$:ka;c[oa>>2]=da;if(ja>>>0>268435455>>>0){da=1;do{$=c[o>>2]|0;_=c[q>>2]|0;L=sa+($>>>3)|0;K=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<($&7)>>>26;L=$+6|0;c[o>>2]=_>>>0>L>>>0?L:_;c[g+220+(da<<2)>>2]=K;da=da+1|0;}while((da|0)<(ca|0))}za=c[f>>2]|0}if((ca|0)>=(za|0)){wa=P;xa=za;T=154;break}da=32-ha|0;if((ha|0)==0){K=ca;while(1){c[g+220+(K<<2)>>2]=Z;_=K+1|0;L=c[f>>2]|0;if((_|0)<(L|0)){K=_}else{wa=P;xa=L;T=154;break h}}}else{K=ca;while(1){L=c[o>>2]|0;_=c[q>>2]|0;$=sa+(L>>>3)|0;J=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(L&7)>>>(da>>>0);$=L+ha|0;c[o>>2]=_>>>0>$>>>0?$:_;c[g+220+(K<<2)>>2]=J+Z&63;J=K+1|0;_=c[f>>2]|0;if((J|0)<(_|0)){K=J}else{wa=P;xa=_;T=154;break h}}}}P=ja>>>26;K=aa+6|0;Z=ka>>>0>K>>>0?K:ka;c[o>>2]=Z;K=sa+(Z>>>3)|0;ha=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(Z&7)>>>26;K=Z+6|0;c[o>>2]=ka>>>0>K>>>0?K:ka;K=c[f>>2]|0;do{if((K|0)!=0){c[la>>2]=P;c[ma>>2]=P;c[oa>>2]=P;if((K|0)>3){Aa=3}else{break}do{c[g+220+(Aa<<2)>>2]=P-(a[(d[1787528+Aa|0]|0)-1+(1786040+(ha*9|0))|0]|0);Aa=Aa+1|0;}while((Aa|0)<(K|0))}}while(0);K=c[o>>2]|0;ha=c[q>>2]|0;P=sa+(K>>>3)|0;aa=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(K&7)>>>27;P=K+5|0;K=ha>>>0>P>>>0?P:ha;c[o>>2]=K;P=sa+(K>>>3)|0;ja=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(K&7)>>>30;P=K+2|0;K=ha>>>0>P>>>0?P:ha;c[o>>2]=K;P=sa+(K>>>3)|0;Z=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(K&7)>>>28;P=K+4|0;K=ha>>>0>P>>>0?P:ha;c[o>>2]=K;P=Z+57|0;i:do{if((aa|0)!=0){Z=0;da=K;ca=ha;while(1){_=g+220+(Z<<2)|0;J=c[_>>2]|0;$=sa+(da>>>3)|0;L=(fe(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(da&7)>>>28;$=da+4|0;c[o>>2]=ca>>>0>$>>>0?$:ca;c[_>>2]=J+57+L&63;L=Z+1|0;if((L|0)>=(aa|0)){break i}Z=L;da=c[o>>2]|0;ca=c[q>>2]|0}}}while(0);if((aa|0)>=(c[f>>2]|0)){break}ha=32-ja|0;if((ja|0)==0){K=aa;do{ca=g+220+(K<<2)|0;c[ca>>2]=(c[ca>>2]|0)+P&63;K=K+1|0;}while((K|0)<(c[f>>2]|0))}else{K=aa;do{ca=g+220+(K<<2)|0;da=(c[ca>>2]|0)+P|0;Z=c[o>>2]|0;L=c[q>>2]|0;J=sa+(Z>>>3)|0;_=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(Z&7)>>>(ha>>>0);J=Z+ja|0;c[o>>2]=L>>>0>J>>>0?J:L;c[ca>>2]=da+_&63;K=K+1|0;}while((K|0)<(c[f>>2]|0))}}else if((ga|0)==0){if((c[f>>2]|0)>0){Ba=0;Ca=ia;Da=ka}else{break}while(1){K=sa+(Ca>>>3)|0;ja=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(Ca&7)>>>26;K=Ca+6|0;c[o>>2]=Da>>>0>K>>>0?K:Da;c[g+72+(M*7768|0)+148+(Ba<<2)>>2]=ja;ja=Ba+1|0;if((ja|0)>=(c[f>>2]|0)){break h}Ba=ja;Ca=c[o>>2]|0;Da=c[q>>2]|0}}}while(0);do{if((T|0)==154){T=0;if((wa|0)==3|(wa|0)==0){break}ka=wa-1|0;if((xa|0)>0){Ea=0}else{break}while(1){ia=g+72+(M*7768|0)+148+(Ea<<2)|0;Fa=(c[ia>>2]|0)-(a[1785976+(ka<<5)+Ea|0]|0)|0;c[ia>>2]=Fa;if(Fa>>>0>63>>>0){T=158;break g}ia=Ea+1|0;if((ia|0)<(c[f>>2]|0)){Ea=ia}else{break}}}}while(0);ka=M+1|0;if((ka|0)<(h|0)){M=ka}else{T=160;break}}if((T|0)==124){yDb(j,16,1961744,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==158){yDb(j,16,1933824,(v=i,i=i+16|0,c[v>>2]=Ea,c[v+8>>2]=Fa,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==160){if((c[f>>2]|0)==0){ra=t;T=215;break f}else{Ga=sa;break}}}else{Ga=na}}while(0);M=c[o>>2]|0;oa=d[Ga+(M>>>3)|0]<<(M&7)>>>7;c[o>>2]=((M|0)<(c[q>>2]|0))+M;M=g+24|0;c[M>>2]=oa&1;if(u){Ha=0}else{T=458;break}j:while(1){TGb(g+72+(Ha*7768|0)+276|0,0,128)|0;oa=(c[M>>2]|0)!=0?7:3;ma=c[o>>2]|0;la=c[s>>2]|0;G=d[la+(ma>>>3)|0]<<(ma&7)>>>7;c[o>>2]=((ma|0)<(c[q>>2]|0))+ma;c[g+72+(Ha*7768|0)+16>>2]=G&1;G=c[o>>2]|0;ma=c[q>>2]|0;ka=la+(G>>>3)|0;ia=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(G&7)>>>30;ka=G+2|0;G=ma>>>0>ka>>>0?ka:ma;c[o>>2]=G;do{if((ia|0)==1){ka=(c[M>>2]|0)!=0?8749796:8749776;ga=d[la+(G>>>3)|0]|0;ja=((G|0)<(ma|0))+G|0;c[o>>2]=ja;if((ga&128>>>((G&7)>>>0)|0)==0){ga=c[f>>2]|0;if((ga|0)<0){w=ga;T=635;break j}else{Ia=ga}}else{ga=la+(ja>>>3)|0;Ja=(fe(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ja&7)>>>27;ga=ja+5|0;c[o>>2]=ma>>>0>ga>>>0?ga:ma;if((Ja|0)>(c[f>>2]|0)){T=177;break j}else{Ia=Ja}}if((Ia|0)<=0){break}ga=(Ha|0)==0;ja=ka+4|0;K=ka|0;ka=0;do{do{if((c[g+72+(Ha*7768|0)+20+(ka<<2)>>2]|0)==0){if(ga){break}if((c[g+92+(ka<<2)>>2]|0)==0){break}ha=c[o>>2]|0;P=d[la+(ha>>>3)|0]<<(ha&7)>>>7;c[o>>2]=((ha|0)<(c[q>>2]|0))+ha;c[g+72+(Ha*7768|0)+276+(ka<<2)>>2]=P&1}else{P=c[ja>>2]|0;ha=c[K>>2]|0;aa=c[o>>2]|0;_=c[q>>2]|0;da=la+(aa>>>3)|0;ca=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(aa&7)>>>((32-ha|0)>>>0);ha=b[P+(ca<<2)>>1]|0;da=(b[P+(ca<<2)+2>>1]|0)+aa|0;c[o>>2]=_>>>0>da>>>0?da:_;c[g+72+(Ha*7768|0)+276+(ka<<2)>>2]=ha}}while(0);ka=ka+1|0;}while((ka|0)<(Ia|0))}else if((ia|0)==2){ka=(c[M>>2]|0)==0;K=ka?8749776:8749796;ja=ka?8749776:8749816;ka=d[la+(G>>>3)|0]|0;ga=((G|0)<(ma|0))+G|0;c[o>>2]=ga;if((ka&128>>>((G&7)>>>0)|0)==0){ka=c[f>>2]|0;if((ka|0)<0){w=ka;T=635;break j}else{Ka=ka}}else{ka=la+(ga>>>3)|0;La=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ga&7)>>>27;ka=ga+5|0;c[o>>2]=ma>>>0>ka>>>0?ka:ma;if((La|0)>(c[f>>2]|0)){T=189;break j}else{Ka=La}}if((Ka|0)<=0){break}ka=(Ha|0)==0;ga=K+4|0;ha=K|0;K=ja+4|0;_=ja|0;ja=0;da=0;while(1){do{if((c[g+72+(Ha*7768|0)+20+(da<<2)>>2]|0)==0){if(ka){Ma=ja;break}if((c[g+92+(da<<2)>>2]|0)==0){Ma=ja;break}aa=c[o>>2]|0;ca=d[la+(aa>>>3)|0]<<(aa&7)>>>7;c[o>>2]=((aa|0)<(c[q>>2]|0))+aa;c[g+72+(Ha*7768|0)+276+(da<<2)>>2]=ca&1;Ma=ja}else{if((da|0)==0){ca=c[ga>>2]|0;aa=c[ha>>2]|0;P=c[o>>2]|0;L=c[q>>2]|0;J=la+(P>>>3)|0;Z=(fe(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(P&7)>>>((32-aa|0)>>>0);aa=b[ca+(Z<<2)>>1]|0;J=(b[ca+(Z<<2)+2>>1]|0)+P|0;c[o>>2]=L>>>0>J>>>0?J:L;Na=aa}else{aa=c[K>>2]|0;L=c[_>>2]|0;J=c[o>>2]|0;P=c[q>>2]|0;Z=la+(J>>>3)|0;ca=(fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(J&7)>>>((32-L|0)>>>0);L=e[aa+(ca<<2)>>1]|0;Z=(b[aa+(ca<<2)+2>>1]|0)+J|0;c[o>>2]=P>>>0>Z>>>0?Z:P;Na=L+ja&oa}c[g+72+(Ha*7768|0)+276+(da<<2)>>2]=Na;Ma=Na}}while(0);L=da+1|0;if((L|0)<(Ka|0)){ja=Ma;da=L}else{break}}}else if((ia|0)==0){da=c[M>>2]|0;ja=da+2|0;_=d[la+(G>>>3)|0]|0;K=((G|0)<(ma|0))+G|0;c[o>>2]=K;if((_&128>>>((G&7)>>>0)|0)==0){_=c[f>>2]|0;if((_|0)<0){w=_;T=635;break j}else{Oa=_}}else{_=la+(K>>>3)|0;Pa=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(K&7)>>>27;_=K+5|0;c[o>>2]=ma>>>0>_>>>0?_:ma;if((Pa|0)>(c[f>>2]|0)){T=165;break j}else{Oa=Pa}}if((Oa|0)<=0){break}_=(Ha|0)==0;K=30-da|0;da=0;do{do{if((c[g+72+(Ha*7768|0)+20+(da<<2)>>2]|0)==0){if(_){break}if((c[g+92+(da<<2)>>2]|0)==0){break}ha=c[o>>2]|0;ga=d[la+(ha>>>3)|0]<<(ha&7)>>>7;c[o>>2]=((ha|0)<(c[q>>2]|0))+ha;c[g+72+(Ha*7768|0)+276+(da<<2)>>2]=ga&1}else{ga=c[o>>2]|0;ha=c[q>>2]|0;ka=la+(ga>>>3)|0;L=(fe(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ga&7)>>>(K>>>0);ka=ja+ga|0;c[o>>2]=ha>>>0>ka>>>0?ka:ha;c[g+72+(Ha*7768|0)+276+(da<<2)>>2]=L}}while(0);da=da+1|0;}while((da|0)<(Oa|0))}else if((ia|0)==3){if((Ha|0)==0){break}da=(c[M>>2]|0)!=0?8749836:8749776;ja=d[la+(G>>>3)|0]|0;K=((G|0)<(ma|0))+G|0;c[o>>2]=K;if((ja&128>>>((G&7)>>>0)|0)==0){ja=c[f>>2]|0;if((ja|0)<0){w=ja;T=635;break j}else{Qa=ja}}else{ja=la+(K>>>3)|0;Ra=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(K&7)>>>27;ja=K+5|0;c[o>>2]=ma>>>0>ja>>>0?ja:ma;if((Ra|0)>(c[f>>2]|0)){T=205;break j}else{Qa=Ra}}if((Qa|0)<=0){break}ja=da+4|0;K=da|0;da=0;do{do{if((c[g+72+(Ha*7768|0)+20+(da<<2)>>2]|0)==0){if((c[g+92+(da<<2)>>2]|0)==0){break}_=c[o>>2]|0;L=d[la+(_>>>3)|0]<<(_&7)>>>7;c[o>>2]=((_|0)<(c[q>>2]|0))+_;c[g+72+(Ha*7768|0)+276+(da<<2)>>2]=L&1}else{L=c[g+348+(da<<2)>>2]|0;_=c[ja>>2]|0;ha=c[K>>2]|0;ka=c[o>>2]|0;ga=c[q>>2]|0;P=la+(ka>>>3)|0;Z=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(ka&7)>>>((32-ha|0)>>>0);ha=e[_+(Z<<2)>>1]|0;P=(b[_+(Z<<2)+2>>1]|0)+ka|0;c[o>>2]=ga>>>0>P>>>0?P:ga;c[g+72+(Ha*7768|0)+276+(da<<2)>>2]=ha+L&oa}}while(0);da=da+1|0;}while((da|0)<(Qa|0))}}while(0);oa=Ha+1|0;if((oa|0)<(h|0)){Ha=oa}else{ra=t;T=215;break f}}if((T|0)==165){yDb(j,16,1998608,(v=i,i=i+8|0,c[v>>2]=Pa,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==177){yDb(j,16,1998608,(v=i,i=i+8|0,c[v>>2]=Ja,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==189){yDb(j,16,1998608,(v=i,i=i+8|0,c[v>>2]=La,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==205){yDb(j,16,1998608,(v=i,i=i+8|0,c[v>>2]=Ra,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==635){i=k;return w|0}}}while(0);do{if((T|0)==215){if(!u){T=458;break}Ra=g+24|0;La=b[630220]|0;Ja=0;do{TGb(g+72+(Ja*7768|0)+404|0,0,4096)|0;TGb(g+72+(Ja*7768|0)+4500|0,15,5)|0;do{if((c[f>>2]|0)>0){Pa=(Ja|0)==0;Ha=g+72+(Ja*7768|0)+16|0;Qa=0;Oa=La;while(1){Ma=Qa+1|0;Ka=b[1260440+(Ma<<1)>>1]|0;Na=1260440+(Qa<<1)|0;Ia=Oa&65535;Ga=(Ka&65535)-Ia|0;na=g+72+(Ja*7768|0)+20+(Qa<<2)|0;sa=c[na>>2]|0;Fa=c[g+72+(Ja*7768|0)+276+(Qa<<2)>>2]|0;do{if((sa|0)==0){if(Pa){break}Ea=g+92+(Qa<<2)|0;if(!((c[Ea>>2]|0)!=0&(Fa|0)==0)){break}UGb(g+72+(Ja*7768|0)+404+(Ia<<1)|0,g+476+(Ia<<1)|0,Ga<<1)|0;c[na>>2]=c[Ea>>2]}else{if((c[Ra>>2]|0)==0){Ea=sa-1|0;xa=c[Ha>>2]|0;Sa=d[1788368+(xa*28|0)+(Ea<<2)+Fa|0]|0;Ta=xa;Ua=Ea}else{Sa=Fa;Ta=c[Ha>>2]|0;Ua=sa-1|0}Ea=(((Ta<<3)+Sa|0)*7|0)+Ua|0;xa=c[1784188+(Ea<<4)>>2]|0;wa=(xa|0)>-1?xa:Ea;xa=e[Na>>1]|0;Da=a[1784184+(Ea<<4)|0]|0;Ca=Da&255;Ba=d[1784185+(Ea<<4)|0]|0;Aa=d[1784186+(Ea<<4)|0]|0;za=(1<<Aa)-1|0;if((Ga|0)<=0){break}ya=ba(Ba,Ca)|0;va=4284492+(wa*20|0)|0;ua=4284488+(wa*20|0)|0;wa=(a[1784187+(Ea<<4)|0]|0)==0;Ea=32-Aa|0;ta=Ba>>>0>1>>>0?Ba:1;qa=Da<<24>>24==1;Da=ba(ta,Ca>>>0>1>>>0?Ca:1)|0;t=0;M=c[o>>2]|0;while(1){if(qa){Va=M;Wa=c[q>>2]|0;Xa=c[s>>2]|0;T=228}else{oa=c[s>>2]|0;la=d[oa+(M>>>3)|0]|0;ma=c[q>>2]|0;G=((M|0)<(ma|0))+M|0;c[o>>2]=G;if((la&128>>>((M&7)>>>0)|0)==0){Ya=ya;Za=G}else{Va=G;Wa=ma;Xa=oa;T=228}}if((T|0)==228){T=0;oa=c[va>>2]|0;ma=t;G=0;la=Va;while(1){ia=c[ua>>2]|0;da=Xa+(la>>>3)|0;K=(fe(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(la&7)>>>((32-ia|0)>>>0);ia=b[oa+(K<<2)>>1]|0;da=(b[oa+(K<<2)+2>>1]|0)+la|0;K=Wa>>>0>da>>>0?da:Wa;c[o>>2]=K;da=ma;ja=ia<<16>>16;ia=0;L=K;while(1){K=ja&za;do{if(wa){ha=K&65535;if((K|0)==0){_a=ha;$a=L;break}ga=d[Xa+(L>>>3)|0]|0;P=((L|0)<(Wa|0))+L|0;c[o>>2]=P;if((ga&128>>>((L&7)>>>0)|0)==0){_a=ha;$a=P;break}_a=-K&65535;$a=P}else{_a=K<<Ea>>Ea&65535;$a=L}}while(0);b[g+72+(Ja*7768|0)+404+(da+xa<<1)>>1]=_a;K=ia+1|0;if((K|0)<(Ba|0)){da=da+1|0;ja=ja>>>(Aa>>>0);ia=K;L=$a}else{break}}L=G+1|0;if((L|0)<(Ca|0)){ma=ma+ta|0;G=L;la=$a}else{Ya=Da;Za=$a;break}}}la=t+Ya|0;if((la|0)<(Ga|0)){t=la;M=Za}else{break}}}}while(0);ab=c[f>>2]|0;if((Ma|0)<(ab|0)){Qa=Ma;Oa=Ka}else{break}}if((ab|0)<=2){break}Oa=c[1784120+((c[ra>>2]|0)-1<<2)>>2]|0;Qa=0;do{Ha=c[o>>2]|0;Pa=c[q>>2]|0;Ga=(c[s>>2]|0)+(Ha>>>3)|0;Na=(fe(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ha&7)>>>28;Ga=Ha+4|0;c[o>>2]=Pa>>>0>Ga>>>0?Ga:Pa;a[g+72+(Ja*7768|0)+4500+Qa|0]=Na;Qa=Qa+1|0;}while((Qa|0)<(Oa|0))}}while(0);Ja=Ja+1|0;}while((Ja|0)<(h|0));k:do{if((h|0)==2){Ja=g+40|0;Ra=c[ra>>2]|0;TGb(Ja|0,0,Ra|0)|0;La=c[o>>2]|0;Oa=c[s>>2]|0;Qa=d[Oa+(La>>>3)|0]|0;Na=c[q>>2]|0;Pa=((La|0)<(Na|0))+La|0;c[o>>2]=Pa;l:do{if((Qa&128>>>((La&7)>>>0)|0)!=0){Ga=d[Oa+(Pa>>>3)|0]|0;Ha=((Pa|0)<(Na|0))+Pa|0;c[o>>2]=Ha;if((Ga&128>>>((Pa&7)>>>0)|0)==0){TGb(Ja|0,1,Ra|0)|0;break}if((Ra|0)>0){bb=0;cb=Ha;db=Oa;eb=Na}else{break}while(1){Ha=d[db+(cb>>>3)|0]<<(cb&7)>>>7;c[o>>2]=((cb|0)<(eb|0))+cb;a[g+40+bb|0]=Ha&1;Ha=bb+1|0;if((Ha|0)>=(Ra|0)){break l}bb=Ha;cb=c[o>>2]|0;db=c[s>>2]|0;eb=c[q>>2]|0}}}while(0);Ra=g+56|0;Na=c[ra>>2]|0;TGb(Ra|0,0,Na|0)|0;Oa=c[o>>2]|0;Ja=c[s>>2]|0;Pa=d[Ja+(Oa>>>3)|0]|0;La=c[q>>2]|0;Qa=((Oa|0)<(La|0))+Oa|0;c[o>>2]=Qa;if((Pa&128>>>((Oa&7)>>>0)|0)==0){fb=1;break}Oa=d[Ja+(Qa>>>3)|0]|0;Pa=((Qa|0)<(La|0))+Qa|0;c[o>>2]=Pa;if((Oa&128>>>((Qa&7)>>>0)|0)==0){TGb(Ra|0,1,Na|0)|0;fb=1;break}if((Na|0)>0){gb=0;hb=Pa;ib=Ja;jb=La}else{fb=1;break}while(1){La=d[ib+(hb>>>3)|0]<<(hb&7)>>>7;c[o>>2]=((hb|0)<(jb|0))+hb;a[g+56+gb|0]=La&1;La=gb+1|0;if((La|0)>=(Na|0)){fb=1;break k}gb=La;hb=c[o>>2]|0;ib=c[s>>2]|0;jb=c[q>>2]|0}}else{fb=0}}while(0);Na=0;do{La=c[g+72+(Na*7768|0)+4540>>2]|0;Ja=c[pa>>2]|0;TGb(La|0,0,Ja|0)|0;Pa=c[o>>2]|0;Ra=c[s>>2]|0;Qa=d[Ra+(Pa>>>3)|0]|0;Oa=c[q>>2]|0;Ha=((Pa|0)<(Oa|0))+Pa|0;c[o>>2]=Ha;m:do{if((Qa&128>>>((Pa&7)>>>0)|0)!=0){Ga=d[Ra+(Ha>>>3)|0]|0;sa=((Ha|0)<(Oa|0))+Ha|0;c[o>>2]=sa;if((Ga&128>>>((Ha&7)>>>0)|0)==0){TGb(La|0,1,Ja|0)|0;break}if((Ja|0)>0){kb=0;lb=sa;mb=Ra;nb=Oa}else{break}while(1){sa=d[mb+(lb>>>3)|0]<<(lb&7)>>>7;c[o>>2]=((lb|0)<(nb|0))+lb;a[La+kb|0]=sa&1;sa=kb+1|0;if((sa|0)>=(Ja|0)){break m}kb=sa;lb=c[o>>2]|0;mb=c[s>>2]|0;nb=c[q>>2]|0}}}while(0);Na=Na+1|0;}while((Na|0)<(h|0));Na=g+6540|0;Ja=0;n:while(1){La=g+72+(Ja*7768|0)+6468|0;TGb(c[La>>2]|0,0,960)|0;Oa=c[o>>2]|0;Ra=c[s>>2]|0;Ha=d[Ra+(Oa>>>3)|0]|0;Pa=c[q>>2]|0;Qa=((Oa|0)<(Pa|0))+Oa|0;c[o>>2]=Qa;do{if((Ha&128>>>((Oa&7)>>>0)|0)==0){c[g+72+(Ja*7768|0)+6476>>2]=0}else{sa=Ra+(Qa>>>3)|0;Ga=(fe(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(Qa&7)>>>28;sa=Qa+4|0;Fa=Pa>>>0>sa>>>0?sa:Pa;c[o>>2]=Fa;sa=Ga+1|0;na=d[Ra+(Fa>>>3)|0]|0;Ia=((Fa|0)<(Pa|0))+Fa|0;c[o>>2]=Ia;if((na&128>>>((Fa&7)>>>0)|0)==0){c[g+72+(Ja*7768|0)+6476>>2]=sa}else{Fa=Ra+(Ia>>>3)|0;na=(fe(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ia&7)>>>28;Fa=Ia+4|0;c[o>>2]=Pa>>>0>Fa>>>0?Fa:Pa;c[g+72+(Ja*7768|0)+6476>>2]=na+1}na=c[o>>2]|0;Fa=c[q>>2]|0;Ia=Ra+(na>>>3)|0;M=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(na&7)>>>30;Ia=na+2|0;na=Fa>>>0>Ia>>>0?Ia:Fa;c[o>>2]=na;o:do{if((M|0)==2){if((Ja|0)==0){Ia=c[1305295]|0;t=c[1305294]|0;Da=Ra+(na>>>3)|0;ta=(fe(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(na&7)>>>((32-t|0)>>>0);t=b[Ia+(ta<<2)>>1]|0;Da=(b[Ia+(ta<<2)+2>>1]|0)+na|0;c[o>>2]=Fa>>>0>Da>>>0?Da:Fa;Da=c[Na>>2]|0;c[Da>>2]=t;if(!(sa>>>0>1>>>0)){break}t=c[1305300]|0;ta=1;do{Ia=c[1305299]|0;Ca=c[o>>2]|0;Aa=c[q>>2]|0;Ba=Ra+(Ca>>>3)|0;xa=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ca&7)>>>((32-Ia|0)>>>0);Ia=e[t+(xa<<2)>>1]|0;Ba=(b[t+(xa<<2)+2>>1]|0)+Ca|0;c[o>>2]=Aa>>>0>Ba>>>0?Ba:Aa;c[Da+(ta*60|0)>>2]=(c[Da+((ta-1|0)*60|0)>>2]|0)+Ia&7;ta=ta+1|0;}while((ta|0)<(sa|0))}else{ta=c[1305300]|0;Da=c[Na>>2]|0;t=c[La>>2]|0;Ka=0;Ma=na;Ia=Fa;while(1){Aa=c[1305299]|0;Ba=Ra+(Ma>>>3)|0;Ca=(fe(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ma&7)>>>((32-Aa|0)>>>0);Aa=e[ta+(Ca<<2)>>1]|0;Ba=(b[ta+(Ca<<2)+2>>1]|0)+Ma|0;c[o>>2]=Ia>>>0>Ba>>>0?Ba:Ia;c[t+(Ka*60|0)>>2]=(c[Da+(Ka*60|0)>>2]|0)+Aa&7;Aa=Ka+1|0;if((Aa|0)>=(sa|0)){break o}Ka=Aa;Ma=c[o>>2]|0;Ia=c[q>>2]|0}}}else if((M|0)==0){Ia=c[La>>2]|0;Ma=Ra+(na>>>3)|0;Ka=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(na&7)>>>29;Ma=na+3|0;c[o>>2]=Fa>>>0>Ma>>>0?Ma:Fa;c[Ia>>2]=Ka;if(sa>>>0>1>>>0){ob=1}else{break}do{Ka=c[o>>2]|0;Ma=c[q>>2]|0;Da=Ra+(Ka>>>3)|0;t=(fe(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Ka&7)>>>29;Da=Ka+3|0;c[o>>2]=Ma>>>0>Da>>>0?Da:Ma;c[Ia+(ob*60|0)>>2]=t;ob=ob+1|0;}while((ob|0)<(sa|0))}else if((M|0)==1){Ia=c[1305295]|0;t=c[La>>2]|0;Ma=0;Da=na;Ka=Fa;while(1){ta=c[1305294]|0;Aa=Ra+(Da>>>3)|0;Ba=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Da&7)>>>((32-ta|0)>>>0);ta=b[Ia+(Ba<<2)>>1]|0;Aa=(b[Ia+(Ba<<2)+2>>1]|0)+Da|0;c[o>>2]=Ka>>>0>Aa>>>0?Aa:Ka;c[t+(Ma*60|0)>>2]=ta;ta=Ma+1|0;if((ta|0)>=(sa|0)){break o}Ma=ta;Da=c[o>>2]|0;Ka=c[q>>2]|0}}else if((M|0)==3){if((Ja|0)!=0){Ka=c[Na>>2]|0;Da=c[La>>2]|0;Ma=0;while(1){c[Da+(Ma*60|0)>>2]=c[Ka+(Ma*60|0)>>2];Ma=Ma+1|0;if((Ma|0)>=(sa|0)){break o}}}Ma=Ra+(na>>>3)|0;Ka=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(na&7)>>>30;Ma=na+2|0;Da=Fa>>>0>Ma>>>0?Ma:Fa;c[o>>2]=Da;Ma=Ra+(Da>>>3)|0;t=(fe(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Da&7)>>>29;Ma=Da+3|0;c[o>>2]=Fa>>>0>Ma>>>0?Ma:Fa;Ma=32-Ka|0;if((Ka|0)==0){Da=c[Na>>2]|0;Ia=0;do{c[Da+(Ia*60|0)>>2]=t;Ia=Ia+1|0;}while((Ia|0)<(sa|0))}else{Ia=0;while(1){if((Ia|0)>=(sa|0)){break o}Da=c[o>>2]|0;ta=c[q>>2]|0;Aa=Ra+(Da>>>3)|0;Ba=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Da&7)>>>(Ma>>>0);Aa=Da+Ka|0;c[o>>2]=ta>>>0>Aa>>>0?Aa:ta;ta=Ba+t|0;c[(c[Na>>2]|0)+(Ia*60|0)>>2]=ta;if((ta|0)>7){w=-1094995529;T=635;break n}else{Ia=Ia+1|0}}}}}while(0);Fa=c[o>>2]|0;na=c[q>>2]|0;M=Ra+(Fa>>>3)|0;Ia=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Fa&7)>>>30;M=Fa+2|0;Fa=na>>>0>M>>>0?M:na;c[o>>2]=Fa;p:do{if((Ia|0)==3){if((Ja|0)==0){M=Ra+(Fa>>>3)|0;t=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Fa&7)>>>30;M=Fa+2|0;Ka=na>>>0>M>>>0?M:na;c[o>>2]=Ka;M=Ra+(Ka>>>3)|0;Ma=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Ka&7)>>>28;M=Ka+4|0;c[o>>2]=na>>>0>M>>>0?M:na;M=(t|0)==0;Ka=32-t|0;ta=c[Na>>2]|0;Ba=0;do{Aa=ta+(Ba*60|0)|0;Da=0;while(1){if((Da|0)>=(c[Aa>>2]|0)){break}if(M){pb=0}else{Ca=c[o>>2]|0;xa=c[q>>2]|0;Ea=Ra+(Ca>>>3)|0;wa=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ca&7)>>>(Ka>>>0);Ea=Ca+t|0;c[o>>2]=xa>>>0>Ea>>>0?Ea:xa;pb=wa}wa=pb+Ma|0;c[ta+(Ba*60|0)+4+(Da<<2)>>2]=wa;if((wa|0)>15){w=-1094995529;T=635;break n}else{Da=Da+1|0}}Ba=Ba+1|0;}while((Ba|0)<(sa|0))}else{Ba=c[La>>2]|0;ta=c[Na>>2]|0;Ma=0;do{t=Ba+(Ma*60|0)|0;if((c[t>>2]|0)>0){Ka=ta+(Ma*60|0)|0;M=0;do{if((M|0)<(c[Ka>>2]|0)){qb=c[ta+(Ma*60|0)+4+(M<<2)>>2]|0}else{qb=7}c[Ba+(Ma*60|0)+4+(M<<2)>>2]=qb;M=M+1|0;}while((M|0)<(c[t>>2]|0))}Ma=Ma+1|0;}while((Ma|0)<(sa|0))}}else if((Ia|0)==0){Ma=c[La>>2]|0;Ba=0;do{ta=Ma+(Ba*60|0)|0;if((c[ta>>2]|0)>0){t=0;do{M=c[o>>2]|0;Ka=c[q>>2]|0;Da=Ra+(M>>>3)|0;Aa=(fe(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(M&7)>>>28;Da=M+4|0;c[o>>2]=Ka>>>0>Da>>>0?Da:Ka;c[Ma+(Ba*60|0)+4+(t<<2)>>2]=Aa;t=t+1|0;}while((t|0)<(c[ta>>2]|0))}Ba=Ba+1|0;}while((Ba|0)<(sa|0))}else if((Ia|0)==1){if((Ja|0)==0){Ba=c[Na>>2]|0;Ma=0;while(1){ta=Ba+(Ma*60|0)|0;do{if((c[ta>>2]|0)>0){t=c[1305305]|0;Aa=c[1305304]|0;Ka=c[o>>2]|0;Da=c[q>>2]|0;M=Ra+(Ka>>>3)|0;wa=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Ka&7)>>>((32-Aa|0)>>>0);Aa=b[t+(wa<<2)>>1]|0;M=(b[t+(wa<<2)+2>>1]|0)+Ka|0;c[o>>2]=Da>>>0>M>>>0?M:Da;c[Ba+(Ma*60|0)+4>>2]=Aa;if((c[ta>>2]|0)<=1){break}Aa=c[1305310]|0;Da=1;do{M=c[1305309]|0;Ka=c[o>>2]|0;wa=c[q>>2]|0;t=Ra+(Ka>>>3)|0;xa=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(Ka&7)>>>((32-M|0)>>>0);M=e[Aa+(xa<<2)>>1]|0;t=(b[Aa+(xa<<2)+2>>1]|0)+Ka|0;c[o>>2]=wa>>>0>t>>>0?t:wa;c[Ba+(Ma*60|0)+4+(Da<<2)>>2]=(c[Ba+(Ma*60|0)+4+(Da-1<<2)>>2]|0)+M&15;Da=Da+1|0;}while((Da|0)<(c[ta>>2]|0))}}while(0);Ma=Ma+1|0;if((Ma|0)>=(sa|0)){break p}}}Ma=c[La>>2]|0;Ba=0;do{ta=Ma+(Ba*60|0)|0;if((c[ta>>2]|0)>0){Da=c[1305320]|0;Aa=c[Na>>2]|0;M=Aa+(Ba*60|0)|0;wa=0;do{t=c[1305319]|0;Ka=c[o>>2]|0;xa=c[q>>2]|0;Ea=Ra+(Ka>>>3)|0;Ca=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ka&7)>>>((32-t|0)>>>0);t=e[Da+(Ca<<2)>>1]|0;Ea=(b[Da+(Ca<<2)+2>>1]|0)+Ka|0;c[o>>2]=xa>>>0>Ea>>>0?Ea:xa;if((wa|0)<(c[M>>2]|0)){rb=c[Aa+(Ba*60|0)+4+(wa<<2)>>2]|0}else{rb=7}c[Ma+(Ba*60|0)+4+(wa<<2)>>2]=rb+t&15;wa=wa+1|0;}while((wa|0)<(c[ta>>2]|0))}Ba=Ba+1|0;}while((Ba|0)<(sa|0))}else if((Ia|0)==2){if((Ja|0)==0){Ba=c[Na>>2]|0;Ma=Ba|0;do{if((c[Ma>>2]|0)>0){ta=c[1305305]|0;wa=c[1305304]|0;Aa=Ra+(Fa>>>3)|0;M=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Fa&7)>>>((32-wa|0)>>>0);wa=b[ta+(M<<2)>>1]|0;Aa=(b[ta+(M<<2)+2>>1]|0)+Fa|0;c[o>>2]=na>>>0>Aa>>>0?Aa:na;c[Ba+4>>2]=wa;if((c[Ma>>2]|0)<=1){break}wa=c[1305310]|0;Aa=1;do{M=c[1305309]|0;ta=c[o>>2]|0;Da=c[q>>2]|0;t=Ra+(ta>>>3)|0;xa=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(ta&7)>>>((32-M|0)>>>0);M=e[wa+(xa<<2)>>1]|0;t=(b[wa+(xa<<2)+2>>1]|0)+ta|0;c[o>>2]=Da>>>0>t>>>0?t:Da;c[Ba+4+(Aa<<2)>>2]=(c[Ba+4+(Aa-1<<2)>>2]|0)+M&15;Aa=Aa+1|0;}while((Aa|0)<(c[Ma>>2]|0))}}while(0);if(sa>>>0>1>>>0){sb=1}else{break}while(1){Ma=Ba+(sb*60|0)|0;if((c[Ma>>2]|0)>0){Aa=sb-1|0;wa=c[1305315]|0;M=Ba+(Aa*60|0)|0;Da=0;do{t=c[1305314]|0;ta=c[o>>2]|0;xa=c[q>>2]|0;Ea=Ra+(ta>>>3)|0;Ka=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(ta&7)>>>((32-t|0)>>>0);t=e[wa+(Ka<<2)>>1]|0;Ea=(b[wa+(Ka<<2)+2>>1]|0)+ta|0;c[o>>2]=xa>>>0>Ea>>>0?Ea:xa;if((Da|0)<(c[M>>2]|0)){tb=c[Ba+(Aa*60|0)+4+(Da<<2)>>2]|0}else{tb=7}c[Ba+(sb*60|0)+4+(Da<<2)>>2]=tb+t&15;Da=Da+1|0;}while((Da|0)<(c[Ma>>2]|0))}sb=sb+1|0;if((sb|0)>=(sa|0)){break p}}}Ba=c[La>>2]|0;Ma=0;do{q:do{if((c[Ba+(Ma*60|0)>>2]|0)>0){Da=c[o>>2]|0;Aa=d[Ra+(Da>>>3)|0]|0;M=c[q>>2]|0;wa=((Da|0)<(M|0))+Da|0;c[o>>2]=wa;t=Ba+(Ma*60|0)|0;if((Aa&128>>>((Da&7)>>>0)|0)!=0){Da=t|0;if((c[Da>>2]|0)<=0){break}Aa=c[1305305]|0;xa=c[1305304]|0;Ea=Ra+(wa>>>3)|0;ta=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(wa&7)>>>((32-xa|0)>>>0);xa=b[Aa+(ta<<2)>>1]|0;Ea=(b[Aa+(ta<<2)+2>>1]|0)+wa|0;c[o>>2]=M>>>0>Ea>>>0?Ea:M;c[Ba+(Ma*60|0)+4>>2]=xa;if((c[Da>>2]|0)<=1){break}xa=c[1305310]|0;M=1;while(1){Ea=c[1305309]|0;wa=c[o>>2]|0;ta=c[q>>2]|0;Aa=Ra+(wa>>>3)|0;Ka=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(wa&7)>>>((32-Ea|0)>>>0);Ea=e[xa+(Ka<<2)>>1]|0;Aa=(b[xa+(Ka<<2)+2>>1]|0)+wa|0;c[o>>2]=ta>>>0>Aa>>>0?Aa:ta;c[Ba+(Ma*60|0)+4+(M<<2)>>2]=(c[Ba+(Ma*60|0)+4+(M-1<<2)>>2]|0)+Ea&15;M=M+1|0;if((M|0)>=(c[Da>>2]|0)){break q}}}Da=c[Na>>2]|0;M=t|0;if((c[M>>2]|0)<=0){break}xa=Da+(Ma*60|0)|0;Ea=0;do{if((Ea|0)<(c[xa>>2]|0)){ub=c[Da+(Ma*60|0)+4+(Ea<<2)>>2]|0}else{ub=7}c[Ba+(Ma*60|0)+4+(Ea<<2)>>2]=ub;Ea=Ea+1|0;}while((Ea|0)<(c[M>>2]|0))}}while(0);Ma=Ma+1|0;}while((Ma|0)<(sa|0))}}while(0);na=c[o>>2]|0;Fa=c[q>>2]|0;Ia=Ra+(na>>>3)|0;Ma=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(na&7)>>>30;Ia=na+2|0;na=Fa>>>0>Ia>>>0?Ia:Fa;c[o>>2]=na;r:do{if((Ma|0)==2){if((Ja|0)!=0){Ia=c[La>>2]|0;Ba=0;while(1){M=Ia+(Ba*60|0)|0;Ea=c[M>>2]|0;s:do{if((Ea|0)>=1){Da=c[Na>>2]|0;do{if((Ea|0)>(c[Da+(Ba*60|0)>>2]|0)){vb=Ea}else{xa=c[o>>2]|0;t=d[Ra+(xa>>>3)|0]|0;c[o>>2]=((xa|0)<(c[q>>2]|0))+xa;ta=c[M>>2]|0;if((t&128>>>((xa&7)>>>0)|0)!=0){vb=ta;break}if((ta|0)>0){wb=0}else{break s}while(1){c[Ia+(Ba*60|0)+32+(wb<<2)>>2]=c[Da+(Ba*60|0)+32+(wb<<2)>>2];wb=wb+1|0;if((wb|0)>=(c[M>>2]|0)){break s}}}}while(0);if((vb|0)<=0){break}Da=c[o>>2]|0;ta=c[q>>2]|0;xa=Ra+(Da>>>3)|0;t=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Da&7)>>>27;xa=Da+5|0;c[o>>2]=ta>>>0>xa>>>0?xa:ta;c[Ia+(Ba*60|0)+32>>2]=t;if((c[M>>2]|0)>1){xb=1;yb=t}else{break}do{t=(c[Ia+(Ba*60|0)+4+(xb<<2)>>2]|0)<=(c[Ia+(Ba*60|0)+4+(xb-1<<2)>>2]|0)?5221316:5221356;ta=c[t+4>>2]|0;xa=c[t>>2]|0;t=c[o>>2]|0;Da=c[q>>2]|0;Aa=Ra+(t>>>3)|0;wa=(fe(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(t&7)>>>((32-xa|0)>>>0);xa=b[ta+(wa<<2)>>1]|0;Aa=(b[ta+(wa<<2)+2>>1]|0)+t|0;c[o>>2]=Da>>>0>Aa>>>0?Aa:Da;yb=xa+yb|0;c[Ia+(Ba*60|0)+32+(xb<<2)>>2]=yb;xb=xb+1|0;}while((xb|0)<(c[M>>2]|0))}}while(0);Ba=Ba+1|0;if((Ba|0)>=(sa|0)){break r}}}Ba=c[Na>>2]|0;Ia=Ba|0;if((c[Ia>>2]|0)>0){M=0;do{do{if((M|0)==0){T=409}else{Ea=c[Ba+32+(M-1<<2)>>2]|0;if((Ea|0)<15){T=409;break}if((Ea|0)>29){c[Ba+32+(M<<2)>>2]=31;break}xa=30-Ea|0;Da=xa>>>0>65535>>>0;Aa=Da?xa>>>16:xa;xa=Da?16:0;if((Aa&65280|0)==0){zb=xa;Ab=Aa}else{zb=xa|8;Ab=Aa>>>8}Aa=(d[1191992+Ab|0]|0)+zb|0;xa=c[o>>2]|0;Da=c[q>>2]|0;t=Ra+(xa>>>3)|0;wa=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(xa&7)>>>((31-Aa|0)>>>0);t=xa+1+Aa|0;c[o>>2]=Da>>>0>t>>>0?t:Da;c[Ba+32+(M<<2)>>2]=Ea+1+wa}}while(0);if((T|0)==409){T=0;wa=c[o>>2]|0;Ea=c[q>>2]|0;Da=Ra+(wa>>>3)|0;t=(fe(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(wa&7)>>>27;Da=wa+5|0;c[o>>2]=Ea>>>0>Da>>>0?Da:Ea;c[Ba+32+(M<<2)>>2]=t}M=M+1|0;}while((M|0)<(c[Ia>>2]|0))}if(sa>>>0>1>>>0){Bb=1}else{break}do{Ia=Ba+(Bb*60|0)|0;t:do{if((c[Ia>>2]|0)>=1){M=c[1305325]|0;t=c[1305324]|0;Ea=c[o>>2]|0;Da=c[q>>2]|0;wa=Ra+(Ea>>>3)|0;Aa=(fe(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Ea&7)>>>((32-t|0)>>>0);t=e[M+(Aa<<2)>>1]|0;wa=(b[M+(Aa<<2)+2>>1]|0)+Ea|0;c[o>>2]=Da>>>0>wa>>>0?wa:Da;Da=Bb-1|0;wa=Ba+(Da*60|0)|0;Ea=c[wa>>2]|0;if((Ea|0)>0){Cb=c[Ba+(Da*60|0)+32>>2]|0}else{Cb=0}c[Ba+(Bb*60|0)+32>>2]=Cb+t&31;if((c[Ia>>2]|0)>1){Db=1;Eb=Ea}else{break}while(1){Ea=(Db|0)>=(Eb|0);t=Db-1|0;Aa=(((c[Ba+(Bb*60|0)+4+(Db<<2)>>2]|0)>(c[Ba+(Bb*60|0)+4+(t<<2)>>2]|0))<<1|Ea&1)+6|0;M=c[5221180+(Aa*20|0)>>2]|0;xa=c[5221176+(Aa*20|0)>>2]|0;Aa=c[o>>2]|0;ta=c[q>>2]|0;Ka=Ra+(Aa>>>3)|0;Ca=(fe(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Aa&7)>>>((32-xa|0)>>>0);xa=b[M+(Ca<<2)>>1]|0;Ka=(b[M+(Ca<<2)+2>>1]|0)+Aa|0;c[o>>2]=ta>>>0>Ka>>>0?Ka:ta;if(Ea){c[Ba+(Bb*60|0)+32+(Db<<2)>>2]=(c[Ba+(Bb*60|0)+32+(t<<2)>>2]|0)+xa}else{c[Ba+(Bb*60|0)+32+(Db<<2)>>2]=(c[Ba+(Da*60|0)+32+(Db<<2)>>2]|0)+xa&31}xa=Db+1|0;if((xa|0)>=(c[Ia>>2]|0)){break t}Db=xa;Eb=c[wa>>2]|0}}}while(0);Bb=Bb+1|0;}while((Bb|0)<(sa|0))}else if((Ma|0)==1){if((Ja|0)==0){Ba=c[Na>>2]|0;Ia=0;while(1){wa=Ba+(Ia*60|0)|0;do{if((c[wa>>2]|0)>0){Da=c[o>>2]|0;xa=c[q>>2]|0;t=Ra+(Da>>>3)|0;Ea=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(Da&7)>>>27;t=Da+5|0;c[o>>2]=xa>>>0>t>>>0?t:xa;c[Ba+(Ia*60|0)+32>>2]=Ea;if((c[wa>>2]|0)>1){Fb=1;Gb=Ea}else{break}do{Ea=(c[Ba+(Ia*60|0)+4+(Fb<<2)>>2]|0)<=(c[Ba+(Ia*60|0)+4+(Fb-1<<2)>>2]|0)?5221316:5221356;xa=c[Ea+4>>2]|0;t=c[Ea>>2]|0;Ea=c[o>>2]|0;Da=c[q>>2]|0;ta=Ra+(Ea>>>3)|0;Ka=(fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(Ea&7)>>>((32-t|0)>>>0);t=b[xa+(Ka<<2)>>1]|0;ta=(b[xa+(Ka<<2)+2>>1]|0)+Ea|0;c[o>>2]=Da>>>0>ta>>>0?ta:Da;Gb=t+Gb|0;c[Ba+(Ia*60|0)+32+(Fb<<2)>>2]=Gb;Fb=Fb+1|0;}while((Fb|0)<(c[wa>>2]|0))}}while(0);Ia=Ia+1|0;if((Ia|0)>=(sa|0)){break r}}}Ia=c[La>>2]|0;Ba=0;do{wa=Ia+(Ba*60|0)|0;do{if((c[wa>>2]|0)>=1){t=c[Na>>2]|0;Da=c[1305345]|0;ta=c[1305344]|0;Ea=c[o>>2]|0;Ka=c[q>>2]|0;xa=Ra+(Ea>>>3)|0;Aa=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ea&7)>>>((32-ta|0)>>>0);ta=e[Da+(Aa<<2)>>1]|0;xa=(b[Da+(Aa<<2)+2>>1]|0)+Ea|0;c[o>>2]=Ka>>>0>xa>>>0?xa:Ka;Ka=t+(Ba*60|0)|0;if((c[Ka>>2]|0)>0){Hb=c[t+(Ba*60|0)+32>>2]|0}else{Hb=0}c[Ia+(Ba*60|0)+32>>2]=Hb+ta&31;if((c[wa>>2]|0)>1){Ib=1}else{break}do{ta=(Ib|0)>=(c[Ka>>2]|0);xa=Ib-1|0;do{if((c[Ia+(Ba*60|0)+4+(Ib<<2)>>2]|0)>(c[Ia+(Ba*60|0)+4+(xa<<2)>>2]|0)){if(ta){Ea=c[1305340]|0;Aa=c[1305339]|0;Da=c[o>>2]|0;Ca=c[q>>2]|0;M=Ra+(Da>>>3)|0;za=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Da&7)>>>((32-Aa|0)>>>0);Aa=b[Ea+(za<<2)>>1]|0;M=(b[Ea+(za<<2)+2>>1]|0)+Da|0;c[o>>2]=Ca>>>0>M>>>0?M:Ca;c[Ia+(Ba*60|0)+32+(Ib<<2)>>2]=(c[Ia+(Ba*60|0)+32+(xa<<2)>>2]|0)+Aa;break}Aa=c[o>>2]|0;Ca=d[Ra+(Aa>>>3)|0]|0;M=c[q>>2]|0;Da=((Aa|0)<(M|0))+Aa|0;c[o>>2]=Da;if((Ca&128>>>((Aa&7)>>>0)|0)==0){c[Ia+(Ba*60|0)+32+(Ib<<2)>>2]=c[t+(Ba*60|0)+32+(Ib<<2)>>2];break}Aa=c[Ia+(Ba*60|0)+32+(xa<<2)>>2]|0;if((Aa|0)<15){Ca=Ra+(Da>>>3)|0;za=(fe(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(Da&7)>>>27;Ca=Da+5|0;c[o>>2]=M>>>0>Ca>>>0?Ca:M;c[Ia+(Ba*60|0)+32+(Ib<<2)>>2]=za;break}if((Aa|0)>29){c[Ia+(Ba*60|0)+32+(Ib<<2)>>2]=31;break}za=30-Aa|0;Ca=za>>>0>65535>>>0;Ea=Ca?za>>>16:za;za=Ca?16:0;if((Ea&65280|0)==0){Jb=za;Kb=Ea}else{Jb=za|8;Kb=Ea>>>8}Ea=(d[1191992+Kb|0]|0)+Jb|0;za=Ra+(Da>>>3)|0;Ca=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Da&7)>>>((31-Ea|0)>>>0);za=Da+1+Ea|0;c[o>>2]=M>>>0>za>>>0?za:M;c[Ia+(Ba*60|0)+32+(Ib<<2)>>2]=Aa+1+Ca}else{Ca=ta?5221316:5221376;Aa=c[Ca+4>>2]|0;M=c[Ca>>2]|0;Ca=c[o>>2]|0;za=c[q>>2]|0;Ea=Ra+(Ca>>>3)|0;Da=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ca&7)>>>((32-M|0)>>>0);M=b[Aa+(Da<<2)>>1]|0;Ea=(b[Aa+(Da<<2)+2>>1]|0)+Ca|0;c[o>>2]=za>>>0>Ea>>>0?Ea:za;if(ta){c[Ia+(Ba*60|0)+32+(Ib<<2)>>2]=(c[Ia+(Ba*60|0)+32+(xa<<2)>>2]|0)+M;break}else{c[Ia+(Ba*60|0)+32+(Ib<<2)>>2]=(c[t+(Ba*60|0)+32+(Ib<<2)>>2]|0)+M&31;break}}}while(0);Ib=Ib+1|0;}while((Ib|0)<(c[wa>>2]|0))}}while(0);Ba=Ba+1|0;}while((Ba|0)<(sa|0))}else if((Ma|0)==0){Ba=c[La>>2]|0;Ia=0;do{wa=Ba+(Ia*60|0)|0;if((c[wa>>2]|0)>0){t=0;do{do{if((t|0)==0){T=358}else{Ka=c[Ba+(Ia*60|0)+32+(t-1<<2)>>2]|0;if((Ka|0)<15){T=358;break}if((Ka|0)>29){c[Ba+(Ia*60|0)+32+(t<<2)>>2]=31;break}xa=30-Ka|0;ta=xa>>>0>65535>>>0;M=ta?xa>>>16:xa;xa=ta?16:0;if((M&65280|0)==0){Lb=xa;Mb=M}else{Lb=xa|8;Mb=M>>>8}M=(d[1191992+Mb|0]|0)+Lb|0;xa=c[o>>2]|0;ta=c[q>>2]|0;za=Ra+(xa>>>3)|0;Ea=(fe(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(xa&7)>>>((31-M|0)>>>0);za=xa+1+M|0;c[o>>2]=ta>>>0>za>>>0?za:ta;c[Ba+(Ia*60|0)+32+(t<<2)>>2]=Ka+1+Ea}}while(0);if((T|0)==358){T=0;Ea=c[o>>2]|0;Ka=c[q>>2]|0;ta=Ra+(Ea>>>3)|0;za=(fe(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(Ea&7)>>>27;ta=Ea+5|0;c[o>>2]=Ka>>>0>ta>>>0?ta:Ka;c[Ba+(Ia*60|0)+32+(t<<2)>>2]=za}t=t+1|0;}while((t|0)<(c[wa>>2]|0))}Ia=Ia+1|0;}while((Ia|0)<(sa|0))}else if((Ma|0)==3){if((Ja|0)==0){Ia=Ra+(na>>>3)|0;Ba=(fe(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(na&7)>>>30;Ia=na+2|0;wa=Fa>>>0>Ia>>>0?Ia:Fa;c[o>>2]=wa;Ia=Ba+1|0;t=Ra+(wa>>>3)|0;za=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(wa&7)>>>27;t=wa+5|0;c[o>>2]=Fa>>>0>t>>>0?t:Fa;t=Ba^31;Ba=c[Na>>2]|0;wa=0;while(1){Ka=Ba+(wa*60|0)|0;if((c[Ka>>2]|0)>0){ta=0;do{Ea=c[o>>2]|0;M=c[q>>2]|0;xa=Ra+(Ea>>>3)|0;Ca=(fe(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ea&7)>>>(t>>>0);xa=Ia+Ea|0;c[o>>2]=M>>>0>xa>>>0?xa:M;c[Ba+(wa*60|0)+32+(ta<<2)>>2]=ta+za+Ca;ta=ta+1|0;}while((ta|0)<(c[Ka>>2]|0))}wa=wa+1|0;if((wa|0)>=(sa|0)){break r}}}wa=c[La>>2]|0;za=0;do{Ba=wa+(za*60|0)|0;if((c[Ba>>2]|0)>0){Ia=c[Na>>2]|0;t=Ia+(za*60|0)|0;Ka=0;do{u:do{if((Ka|0)<(c[t>>2]|0)){c[wa+(za*60|0)+32+(Ka<<2)>>2]=c[Ia+(za*60|0)+32+(Ka<<2)>>2]}else{do{if((Ka|0)!=0){ta=c[wa+(za*60|0)+32+(Ka-1<<2)>>2]|0;if((ta|0)<15){break}if((ta|0)>29){c[wa+(za*60|0)+32+(Ka<<2)>>2]=31;break u}Ca=30-ta|0;M=Ca>>>0>65535>>>0;xa=M?Ca>>>16:Ca;Ca=M?16:0;if((xa&65280|0)==0){Nb=Ca;Ob=xa}else{Nb=Ca|8;Ob=xa>>>8}xa=(d[1191992+Ob|0]|0)+Nb|0;Ca=c[o>>2]|0;M=c[q>>2]|0;Ea=Ra+(Ca>>>3)|0;Da=(fe(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ca&7)>>>((31-xa|0)>>>0);Ea=Ca+1+xa|0;c[o>>2]=M>>>0>Ea>>>0?Ea:M;c[wa+(za*60|0)+32+(Ka<<2)>>2]=ta+1+Da;break u}}while(0);Da=c[o>>2]|0;ta=c[q>>2]|0;M=Ra+(Da>>>3)|0;Ea=(fe(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Da&7)>>>27;M=Da+5|0;c[o>>2]=ta>>>0>M>>>0?M:ta;c[wa+(za*60|0)+32+(Ka<<2)>>2]=Ea}}while(0);Ka=Ka+1|0;}while((Ka|0)<(c[Ba>>2]|0))}za=za+1|0;}while((za|0)<(sa|0))}}while(0);Fa=c[La>>2]|0;Pb=0;while(1){na=c[Fa+(Pb*60|0)>>2]|0;if((na|0)>0){Qb=0;while(1){Rb=c[Fa+(Pb*60|0)+32+(Qb<<2)>>2]|0;if(Rb>>>0>31>>>0){T=452;break n}if((Qb|0)!=0){if((Rb|0)<=(c[Fa+(Pb*60|0)+32+(Qb-1<<2)>>2]|0)){T=452;break n}}Ma=Qb+1|0;if((Ma|0)<(na|0)){Qb=Ma}else{break}}}na=Pb+1|0;if((na|0)<(sa|0)){Pb=na}else{break}}na=g+72+(Ja*7768|0)+6476|0;if((sa|0)>=(c[na>>2]|0)){break}UGb(Fa+(sa*60|0)|0,Fa+(Ga*60|0)|0,60)|0;Ma=Ga+2|0;if((Ma|0)<(c[na>>2]|0)){Sb=Ma}else{break}do{Ma=c[La>>2]|0;UGb(Ma+(Sb*60|0)|0,Ma+((Sb-1|0)*60|0)|0,60)|0;Sb=Sb+1|0;}while((Sb|0)<(c[na>>2]|0))}}while(0);La=Ja+1|0;if((La|0)<(h|0)){Ja=La}else{T=459;break}}if((T|0)==452){yDb(j,16,2043944,(v=i,i=i+32|0,c[v>>2]=Ja,c[v+8>>2]=Pb,c[v+16>>2]=Qb,c[v+24>>2]=Rb,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((T|0)==459){Na=m;La=n;Ra=0;while(1){TGb(c[g+72+(Ra*7768|0)+7760>>2]|0,0,640)|0;Pa=Ra+1|0;if((Pa|0)<(h|0)){Ra=Pa}else{Tb=fb;Ub=Na;Vb=La;break}}}else if((T|0)==635){i=k;return w|0}}}while(0);if((T|0)==458){Tb=0;Ub=m;Vb=n}n=c[o>>2]|0;Ub=c[s>>2]|0;fb=d[Ub+(n>>>3)|0]<<(n&7)>>>7;c[o>>2]=((n|0)<(c[q>>2]|0))+n;n=fb&1;fb=g+17272|0;Rb=c[fb>>2]|0;c[Rb>>2]=n;do{if((n|0)==0){Wb=Ub}else{TGb(Rb+64|0,0,768)|0;Qb=c[o>>2]|0;Pb=c[s>>2]|0;Sb=d[Pb+(Qb>>>3)|0]<<(Qb&7)>>>7;c[o>>2]=((Qb|0)<(c[q>>2]|0))+Qb;Qb=Sb&1;Sb=c[fb>>2]|0;c[Sb+4>>2]=Qb;if((Qb|0)==0){EDb(j,2305168,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1163346256;i=k;return w|0}Qb=c[714597]|0;Nb=c[714596]|0;Ob=c[o>>2]|0;Lb=c[q>>2]|0;Mb=Pb+(Ob>>>3)|0;Ib=(fe(d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0)|0)<<(Ob&7)>>>((32-Nb|0)>>>0);Nb=b[Qb+(Ib<<2)>>1]|0;Mb=(b[Qb+(Ib<<2)+2>>1]|0)+Ob|0;c[o>>2]=Lb>>>0>Mb>>>0?Mb:Lb;Lb=Nb+1|0;c[Sb+8>>2]=Lb;do{if(Tb){Nb=Sb+12|0;TGb(Nb|0,0,Lb|0)|0;Mb=c[o>>2]|0;Ob=c[s>>2]|0;Ib=d[Ob+(Mb>>>3)|0]|0;Qb=c[q>>2]|0;Jb=((Mb|0)<(Qb|0))+Mb|0;c[o>>2]=Jb;v:do{if((Ib&128>>>((Mb&7)>>>0)|0)!=0){Kb=d[Ob+(Jb>>>3)|0]|0;Hb=((Jb|0)<(Qb|0))+Jb|0;c[o>>2]=Hb;if((Kb&128>>>((Jb&7)>>>0)|0)==0){TGb(Nb|0,1,Lb|0)|0;break}if((Lb|0)>0){Xb=0;Yb=Hb;Zb=Ob;_b=Qb}else{break}while(1){Hb=d[Zb+(Yb>>>3)|0]<<(Yb&7)>>>7;c[o>>2]=((Yb|0)<(_b|0))+Yb;a[Sb+12+Xb|0]=Hb&1;Hb=Xb+1|0;if((Hb|0)>=(Lb|0)){break v}Xb=Hb;Yb=c[o>>2]|0;Zb=c[s>>2]|0;_b=c[q>>2]|0}}}while(0);Qb=c[fb>>2]|0;Ob=Qb+28|0;Nb=c[Qb+8>>2]|0;TGb(Ob|0,0,Nb|0)|0;Jb=c[o>>2]|0;Mb=c[s>>2]|0;Ib=d[Mb+(Jb>>>3)|0]|0;Hb=c[q>>2]|0;Kb=((Jb|0)<(Hb|0))+Jb|0;c[o>>2]=Kb;w:do{if((Ib&128>>>((Jb&7)>>>0)|0)!=0){Fb=d[Mb+(Kb>>>3)|0]|0;Gb=((Kb|0)<(Hb|0))+Kb|0;c[o>>2]=Gb;if((Fb&128>>>((Kb&7)>>>0)|0)==0){TGb(Ob|0,1,Nb|0)|0;break}if((Nb|0)>0){$b=0;ac=Gb;bc=Mb;cc=Hb}else{break}while(1){Gb=d[bc+(ac>>>3)|0]<<(ac&7)>>>7;c[o>>2]=((ac|0)<(cc|0))+ac;a[Qb+28+$b|0]=Gb&1;Gb=$b+1|0;if((Gb|0)>=(Nb|0)){break w}$b=Gb;ac=c[o>>2]|0;bc=c[s>>2]|0;cc=c[q>>2]|0}}}while(0);Nb=c[fb>>2]|0;Qb=Nb+44|0;Hb=c[Nb+8>>2]|0;TGb(Qb|0,0,Hb|0)|0;Mb=c[o>>2]|0;Ob=c[s>>2]|0;Kb=d[Ob+(Mb>>>3)|0]|0;Jb=c[q>>2]|0;Ib=((Mb|0)<(Jb|0))+Mb|0;c[o>>2]=Ib;if((Kb&128>>>((Mb&7)>>>0)|0)==0){dc=Ob;ec=c[fb>>2]|0;break}Mb=d[Ob+(Ib>>>3)|0]|0;Kb=((Ib|0)<(Jb|0))+Ib|0;c[o>>2]=Kb;x:do{if((Mb&128>>>((Ib&7)>>>0)|0)==0){TGb(Qb|0,1,Hb|0)|0}else{if((Hb|0)>0){fc=0;gc=Kb;hc=Ob;ic=Jb}else{break}while(1){Gb=d[hc+(gc>>>3)|0]<<(gc&7)>>>7;c[o>>2]=((gc|0)<(ic|0))+gc;a[Nb+44+fc|0]=Gb&1;Gb=fc+1|0;if((Gb|0)>=(Hb|0)){break x}fc=Gb;gc=c[o>>2]|0;hc=c[s>>2]|0;ic=c[q>>2]|0}}}while(0);EDb(j,2174528,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1163346256;i=k;return w|0}else{dc=Pb;ec=Sb}}while(0);Sb=ec+60|0;c[Sb>>2]=0;y:do{if(u){Pb=g+7832|0;Lb=ec+8|0;Hb=ec+4|0;Nb=0;Jb=c[Lb>>2]|0;z:while(1){if((Jb|0)>0){Ob=(Nb|0)==0;Kb=0;do{if(Ob){jc=1}else{jc=(a[ec+12+Kb|0]|0)==0|0}c[m+(Kb<<2)>>2]=jc;Kb=Kb+1|0;}while((Kb|0)<(Jb|0))}Kb=c[g+72+(Nb*7768|0)+7760>>2]|0;Ob=c[Pb>>2]|0;Qb=(Nb|0)==0;do{if(Qb){kc=Jb;T=495}else{Ib=c[o>>2]|0;Mb=d[dc+(Ib>>>3)|0]|0;c[o>>2]=((Ib|0)<(c[q>>2]|0))+Ib;Gb=c[Lb>>2]|0;if((Mb&128>>>((Ib&7)>>>0)|0)==0){kc=Gb;T=495;break}if((Gb|0)>0){lc=0;mc=Gb}else{break}while(1){if((c[m+(lc<<2)>>2]|0)==0){nc=mc}else{c[Kb+(lc*40|0)>>2]=c[Ob+(lc*40|0)>>2];c[Kb+(lc*40|0)+4>>2]=c[Ob+(lc*40|0)+4>>2];c[Kb+(lc*40|0)+8>>2]=c[Ob+(lc*40|0)+8>>2];c[Kb+(lc*40|0)+12>>2]=c[Ob+(lc*40|0)+12>>2];nc=c[Lb>>2]|0}Gb=lc+1|0;if((Gb|0)<(nc|0)){lc=Gb;mc=nc}else{break}}}}while(0);do{if((T|0)==495){T=0;if((kc|0)>0){oc=0;pc=kc}else{break}while(1){if((c[m+(oc<<2)>>2]|0)==0){qc=pc}else{Gb=c[o>>2]|0;Ib=d[dc+(Gb>>>3)|0]<<(Gb&7)>>>7;c[o>>2]=((Gb|0)<(c[q>>2]|0))+Gb;Gb=Ib&1;c[Kb+(oc*40|0)>>2]=Gb;if((Gb|0)==0){rc=-1}else{Gb=c[o>>2]|0;Ib=c[q>>2]|0;Mb=dc+(Gb>>>3)|0;Fb=(fe(d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0)|0)<<(Gb&7)>>>27;Mb=Gb+5|0;c[o>>2]=Ib>>>0>Mb>>>0?Mb:Ib;rc=Fb}c[Kb+(oc*40|0)+8>>2]=rc;Fb=c[o>>2]|0;Ib=d[dc+(Fb>>>3)|0]<<(Fb&7)>>>7;c[o>>2]=((Fb|0)<(c[q>>2]|0))+Fb;Fb=Ib&1;c[Kb+(oc*40|0)+4>>2]=Fb;if((Fb|0)==0){sc=32}else{Fb=c[o>>2]|0;Ib=c[q>>2]|0;Mb=dc+(Fb>>>3)|0;Gb=(fe(d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0)|0)<<(Fb&7)>>>27;Mb=Fb+5|0;c[o>>2]=Ib>>>0>Mb>>>0?Mb:Ib;sc=Gb}c[Kb+(oc*40|0)+12>>2]=sc;qc=c[Lb>>2]|0}Gb=oc+1|0;if((Gb|0)<(qc|0)){oc=Gb;pc=qc}else{break}}}}while(0);Gb=Nb+1|0;Ib=c[o>>2]|0;Mb=c[q>>2]|0;Fb=dc+(Ib>>>3)|0;Bb=31-Nb|0;Eb=(fe(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(Ib&7)>>>(Bb>>>0);Fb=Ib+Gb|0;c[o>>2]=Mb>>>0>Fb>>>0?Fb:Mb;do{if((Eb|0)==0){Mb=c[Lb>>2]|0;if((Mb|0)>0){tc=0;uc=Mb}else{vc=Mb;wc=Mb;break}while(1){if((c[m+(tc<<2)>>2]|0)==0){xc=uc}else{Mb=c[o>>2]|0;Fb=c[q>>2]|0;Ib=dc+(Mb>>>3)|0;Db=(fe(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)|0)<<(Mb&7)>>>28;Ib=Mb+4|0;c[o>>2]=Fb>>>0>Ib>>>0?Ib:Fb;c[Kb+(tc*40|0)+32>>2]=Db;xc=c[Lb>>2]|0}Db=tc+1|0;if((Db|0)<(xc|0)){tc=Db;uc=xc}else{yc=xc;T=512;break}}}else if((Eb|0)==3){Db=c[Lb>>2]|0;if((Db|0)>0){zc=0;Ac=Db}else{vc=Db;wc=Db;break}while(1){if((c[m+(zc<<2)>>2]|0)==0){Bc=Ac}else{c[Kb+(zc*40|0)+32>>2]=c[Ob+(zc*40|0)+32>>2];Bc=c[Lb>>2]|0}Db=zc+1|0;if((Db|0)<(Bc|0)){zc=Db;Ac=Bc}else{yc=Bc;T=512;break}}}else if((Eb|0)==2){Db=c[Lb>>2]|0;if((Db|0)>0){Cc=0;Dc=Db}else{vc=Db;wc=Db;break}while(1){if((c[m+(Cc<<2)>>2]|0)==0){Ec=Dc}else{Db=c[714607]|0;Fb=c[714606]|0;Ib=c[o>>2]|0;Mb=c[q>>2]|0;Cb=dc+(Ib>>>3)|0;zb=(fe(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0)<<(Ib&7)>>>((32-Fb|0)>>>0);Fb=e[Db+(zb<<2)>>1]|0;Cb=(b[Db+(zb<<2)+2>>1]|0)+Ib|0;c[o>>2]=Mb>>>0>Cb>>>0?Cb:Mb;c[Kb+(Cc*40|0)+32>>2]=(Fb<<29>>29)+(c[Ob+(Cc*40|0)+32>>2]|0)&15;Ec=c[Lb>>2]|0}Fb=Cc+1|0;if((Fb|0)<(Ec|0)){Cc=Fb;Dc=Ec}else{yc=Ec;T=512;break}}}else if((Eb|0)==1){Fb=c[Lb>>2]|0;if((Fb|0)>0){Fc=0;Gc=Fb}else{vc=Fb;wc=Fb;break}while(1){if((c[m+(Fc<<2)>>2]|0)==0){Hc=Gc}else{Fb=c[714602]|0;Mb=c[714601]|0;Cb=c[o>>2]|0;Ib=c[q>>2]|0;zb=dc+(Cb>>>3)|0;Db=(fe(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)|0)<<(Cb&7)>>>((32-Mb|0)>>>0);Mb=b[Fb+(Db<<2)>>1]|0;zb=(b[Fb+(Db<<2)+2>>1]|0)+Cb|0;c[o>>2]=Ib>>>0>zb>>>0?zb:Ib;c[Kb+(Fc*40|0)+32>>2]=Mb;Hc=c[Lb>>2]|0}Mb=Fc+1|0;if((Mb|0)<(Hc|0)){Fc=Mb;Gc=Hc}else{yc=Hc;T=512;break}}}else{yc=c[Lb>>2]|0;T=512}}while(0);do{if((T|0)==512){T=0;if((yc|0)>0){Ic=0;Jc=yc;Kc=yc}else{vc=yc;wc=yc;break}while(1){if((c[m+(Ic<<2)>>2]|0)==0){Lc=Jc;Mc=Kc}else{Eb=c[Sb>>2]|0;Mb=c[Kb+(Ic*40|0)+32>>2]|0;Nc=Mb+Eb|0;if((Nc|0)>48){break z}c[Kb+(Ic*40|0)+36>>2]=Eb;c[Sb>>2]=(c[Sb>>2]|0)+Mb;Mb=c[Lb>>2]|0;Lc=Mb;Mc=Mb}Mb=Ic+1|0;if((Mb|0)<(Lc|0)){Ic=Mb;Jc=Lc;Kc=Mc}else{vc=Lc;wc=Mc;break}}}}while(0);do{if(Qb){Oc=vc;Pc=wc;T=533}else{Mb=c[o>>2]|0;Eb=d[dc+(Mb>>>3)|0]|0;c[o>>2]=((Mb|0)<(c[q>>2]|0))+Mb;Ib=c[Lb>>2]|0;if((Eb&128>>>((Mb&7)>>>0)|0)==0){Oc=Ib;Pc=Ib;T=533;break}if((Ib|0)>0){Qc=0;Rc=Ib}else{break}while(1){do{if((c[m+(Qc<<2)>>2]|0)==0){Sc=Rc}else{Ib=Kb+(Qc*40|0)+32|0;Mb=c[Ib>>2]|0;if((Mb|0)==0){Sc=Rc;break}Eb=c[Ob+(Qc*40|0)+36>>2]|0;zb=c[Kb+(Qc*40|0)+36>>2]|0;if((Mb|0)<=0){Sc=Rc;break}Mb=Ob+(Qc*40|0)+32|0;Cb=Eb-1|0;Db=c[714627]|0;Fb=0;do{Ab=c[714626]|0;xb=c[o>>2]|0;yb=c[q>>2]|0;vb=dc+(xb>>>3)|0;wb=(fe(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(xb&7)>>>((32-Ab|0)>>>0);Ab=e[Db+(wb<<2)>>1]|0;vb=(b[Db+(wb<<2)+2>>1]|0)+xb|0;c[o>>2]=yb>>>0>vb>>>0?vb:yb;yb=Ab<<24>>24;Ab=c[Mb>>2]|0;do{if((Fb|0)<(Ab|0)){Tc=c[ec+64+(Fb+Eb<<4)>>2]|0}else{if((Ab|0)==0){Tc=0;break}Tc=c[ec+64+(Cb+Ab<<4)>>2]|0}}while(0);c[ec+64+(Fb+zb<<4)>>2]=Tc+yb&1023;Fb=Fb+1|0;}while((Fb|0)<(c[Ib>>2]|0));Sc=c[Lb>>2]|0}}while(0);Ib=Qc+1|0;if((Ib|0)<(Sc|0)){Qc=Ib;Rc=Sc}else{Uc=Sc;T=565;break}}}}while(0);do{if((T|0)==533){T=0;if((Oc|0)>0){Vc=0}else{Uc=Pc;T=565;break}while(1){A:do{if((c[m+(Vc<<2)>>2]|0)!=0){Ib=Kb+(Vc*40|0)+32|0;Fb=c[Ib>>2]|0;if((Fb|0)==0){break}zb=c[Kb+(Vc*40|0)+36>>2]|0;do{if((Fb|0)>1){Cb=c[o>>2]|0;Eb=d[dc+(Cb>>>3)|0]|0;Mb=c[q>>2]|0;Db=((Cb|0)<(Mb|0))+Cb|0;c[o>>2]=Db;Ab=c[Ib>>2]|0;if((Eb&128>>>((Cb&7)>>>0)|0)==0){Wc=Ab;break}if((Ab|0)==0){break A}Ab=dc+(Db>>>3)|0;Cb=(fe(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)|0)<<(Db&7)>>>22;Ab=Db+10|0;c[o>>2]=Mb>>>0>Ab>>>0?Ab:Mb;c[ec+64+(zb-1+(c[Ib>>2]|0)<<4)>>2]=Cb;Cb=(c[Ib>>2]|0)-2|0;if(!((Cb|0)>-1)){break A}Mb=zb+1|0;Ab=Cb;while(1){Cb=c[ec+64+(Mb+Ab<<4)>>2]|0;Db=Cb>>>0>65535>>>0;Eb=Db?Cb>>>16:Cb;Cb=Db?16:0;if((Eb&65280|0)==0){Xc=Cb;Yc=Eb}else{Xc=Cb|8;Yc=Eb>>>8}Eb=(d[1191992+Yc|0]|0)+Xc|0;Cb=c[o>>2]|0;Db=c[q>>2]|0;vb=dc+(Cb>>>3)|0;xb=(fe(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(Cb&7)>>>((31-Eb|0)>>>0);vb=Cb+1+Eb|0;c[o>>2]=Db>>>0>vb>>>0?vb:Db;c[ec+64+(Ab+zb<<4)>>2]=xb;if((Ab|0)>0){Ab=Ab-1|0}else{break A}}}else{Wc=Fb}}while(0);if((Wc|0)<=0){break}Fb=zb-1|0;Ab=0;do{do{if((Ab|0)==0){T=548}else{Mb=c[ec+64+(Fb+Ab<<4)>>2]|0;if((Mb|0)<512){T=548;break}yb=1023-Mb|0;Mb=yb>>>0>65535>>>0;xb=Mb?yb>>>16:yb;yb=Mb?16:0;if((xb&65280|0)==0){Zc=yb;_c=xb}else{Zc=yb|8;_c=xb>>>8}xb=(d[1191992+_c|0]|0)+Zc|0;yb=xb+1|0;Mb=c[o>>2]|0;Db=c[q>>2]|0;vb=dc+(Mb>>>3)|0;Eb=(fe(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(Mb&7)>>>((31-xb|0)>>>0);xb=yb+Mb|0;c[o>>2]=Db>>>0>xb>>>0?xb:Db;c[ec+64+(Ab+zb<<4)>>2]=(-1<<yb)+1024+Eb}}while(0);if((T|0)==548){T=0;Eb=c[o>>2]|0;yb=c[q>>2]|0;Db=dc+(Eb>>>3)|0;xb=(fe(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)|0)<<(Eb&7)>>>22;Db=Eb+10|0;c[o>>2]=yb>>>0>Db>>>0?Db:yb;c[ec+64+(Ab+zb<<4)>>2]=xb}Ab=Ab+1|0;}while((Ab|0)<(c[Ib>>2]|0))}}while(0);Ib=Vc+1|0;Ab=c[Lb>>2]|0;if((Ib|0)<(Ab|0)){Vc=Ib}else{Uc=Ab;T=565;break}}}}while(0);do{if((T|0)==565){T=0;if((Uc|0)>0&(Qb^1)){$c=0}else{break}do{do{if((c[m+($c<<2)>>2]|0)!=0){Ab=c[Kb+($c*40|0)+32>>2]|0;if((Ab|0)==0){break}Ib=c[Kb+($c*40|0)+36>>2]|0;zb=c[Ob+($c*40|0)+36>>2]|0;if((Ab|0)<=0){break}Fb=c[Ob+($c*40|0)+32>>2]|0;xb=(Fb|0)>0;yb=0;do{do{if(xb){Db=yb+Ib|0;Eb=c[ec+64+(Db<<4)>>2]|0;Mb=0;vb=1024;Cb=0;do{wb=Eb-(c[ec+64+(Cb+zb<<4)>>2]|0)|0;ub=(wb|0)>-1?wb:-wb|0;wb=(ub|0)<(vb|0);Mb=wb?Cb:Mb;vb=wb?ub:vb;Cb=Cb+1|0;}while((Cb|0)<(Fb|0));if((vb|0)>=8){T=575;break}c[l+(Db<<2)>>2]=Mb+zb}else{T=575}}while(0);do{if((T|0)==575){T=0;if((yb|0)<(Fb|0)){c[l+(yb+Ib<<2)>>2]=yb+zb;break}else{c[l+(yb+Ib<<2)>>2]=-1;break}}}while(0);yb=yb+1|0;}while((yb|0)<(Ab|0))}}while(0);$c=$c+1|0;}while(($c|0)<(Uc|0))}}while(0);Ob=c[o>>2]|0;Qb=c[q>>2]|0;Ab=dc+(Ob>>>3)|0;yb=(fe(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)|0)<<(Ob&7)>>>(Bb>>>0);Ab=Ob+Gb|0;c[o>>2]=Qb>>>0>Ab>>>0?Ab:Qb;do{if((yb|0)==3){Qb=c[Lb>>2]|0;if((Qb|0)>0){ad=0}else{bd=Qb;break}while(1){do{if((c[m+(ad<<2)>>2]|0)!=0){Ab=Kb+(ad*40|0)+32|0;if((c[Ab>>2]|0)<=0){break}Ob=Kb+(ad*40|0)+36|0;Ib=0;do{zb=(c[Ob>>2]|0)+Ib|0;Fb=c[l+(zb<<2)>>2]|0;if((Fb|0)>-1){cd=c[ec+64+(Fb<<4)+4>>2]|0}else{cd=32}c[ec+64+(zb<<4)+4>>2]=cd;Ib=Ib+1|0;}while((Ib|0)<(c[Ab>>2]|0))}}while(0);Ab=ad+1|0;if((Ab|0)<(Qb|0)){ad=Ab}else{dd=Qb;T=617;break}}}else if((yb|0)==2){Qb=c[Lb>>2]|0;if((Qb|0)>0){ed=0;fd=Qb}else{bd=Qb;break}while(1){do{if((c[m+(ed<<2)>>2]|0)==0){gd=fd}else{Qb=Kb+(ed*40|0)+32|0;if((c[Qb>>2]|0)<=0){gd=fd;break}Ab=Kb+(ed*40|0)+36|0;Ib=c[714622]|0;Ob=0;do{zb=c[714621]|0;Fb=c[o>>2]|0;xb=c[q>>2]|0;Cb=dc+(Fb>>>3)|0;Eb=(fe(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0)<<(Fb&7)>>>((32-zb|0)>>>0);zb=e[Ib+(Eb<<2)>>1]|0;Cb=(b[Ib+(Eb<<2)+2>>1]|0)+Fb|0;c[o>>2]=xb>>>0>Cb>>>0?Cb:xb;xb=(c[Ab>>2]|0)+Ob|0;Cb=c[l+(xb<<2)>>2]|0;if((Cb|0)>-1){hd=c[ec+64+(Cb<<4)+4>>2]|0}else{hd=34}c[ec+64+(xb<<4)+4>>2]=hd+(zb<<27>>27)&63;Ob=Ob+1|0;}while((Ob|0)<(c[Qb>>2]|0));gd=c[Lb>>2]|0}}while(0);Qb=ed+1|0;if((Qb|0)<(gd|0)){ed=Qb;fd=gd}else{dd=gd;T=617;break}}}else if((yb|0)==1){Qb=c[Lb>>2]|0;if((Qb|0)>0){id=0}else{bd=Qb;break}while(1){do{if((c[m+(id<<2)>>2]|0)!=0){Qb=Kb+(id*40|0)+32|0;Ob=c[Qb>>2]|0;if((Ob|0)==0){break}if((c[Hb>>2]|0)==0){Ab=c[714617]|0;Ib=c[714616]|0;zb=c[o>>2]|0;xb=c[q>>2]|0;Cb=dc+(zb>>>3)|0;Fb=(fe(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0)<<(zb&7)>>>((32-Ib|0)>>>0);Ib=b[Ab+(Fb<<2)>>1]|0;Cb=(b[Ab+(Fb<<2)+2>>1]|0)+zb|0;c[o>>2]=xb>>>0>Cb>>>0?Cb:xb;c[ec+64+(c[Kb+(id*40|0)+36>>2]<<4)+4>>2]=Ib+24;break}if((Ob|0)<=0){break}Ob=Kb+(id*40|0)+36|0;Ib=c[714612]|0;xb=0;do{Cb=c[714611]|0;zb=c[o>>2]|0;Fb=c[q>>2]|0;Ab=dc+(zb>>>3)|0;Eb=(fe(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)|0)<<(zb&7)>>>((32-Cb|0)>>>0);Cb=b[Ib+(Eb<<2)>>1]|0;Ab=(b[Ib+(Eb<<2)+2>>1]|0)+zb|0;c[o>>2]=Fb>>>0>Ab>>>0?Ab:Fb;c[ec+64+((c[Ob>>2]|0)+xb<<4)+4>>2]=Cb+20;xb=xb+1|0;}while((xb|0)<(c[Qb>>2]|0))}}while(0);Qb=id+1|0;xb=c[Lb>>2]|0;if((Qb|0)<(xb|0)){id=Qb}else{dd=xb;T=617;break}}}else if((yb|0)==0){xb=c[Lb>>2]|0;if((xb|0)>0){jd=0}else{bd=xb;break}while(1){do{if((c[m+(jd<<2)>>2]|0)!=0){xb=Kb+(jd*40|0)+32|0;Qb=c[xb>>2]|0;if((Qb|0)==0){break}if((c[Hb>>2]|0)==0){Ob=c[o>>2]|0;Ib=c[q>>2]|0;Cb=dc+(Ob>>>3)|0;Fb=(fe(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0)<<(Ob&7)>>>26;Cb=Ob+6|0;c[o>>2]=Ib>>>0>Cb>>>0?Cb:Ib;c[ec+64+(c[Kb+(jd*40|0)+36>>2]<<4)+4>>2]=Fb;break}if((Qb|0)<=0){break}Qb=Kb+(jd*40|0)+36|0;Fb=0;do{Ib=c[o>>2]|0;Cb=c[q>>2]|0;Ob=dc+(Ib>>>3)|0;Ab=(fe(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Ib&7)>>>26;Ob=Ib+6|0;c[o>>2]=Cb>>>0>Ob>>>0?Ob:Cb;c[ec+64+((c[Qb>>2]|0)+Fb<<4)+4>>2]=Ab;Fb=Fb+1|0;}while((Fb|0)<(c[xb>>2]|0))}}while(0);xb=jd+1|0;Fb=c[Lb>>2]|0;if((xb|0)<(Fb|0)){jd=xb}else{dd=Fb;T=617;break}}}else{dd=c[Lb>>2]|0;T=617}}while(0);do{if((T|0)==617){T=0;if((dd|0)>0){kd=0;ld=dd}else{bd=dd;break}while(1){do{if((c[m+(kd<<2)>>2]|0)==0){md=ld}else{yb=c[Kb+(kd*40|0)+36>>2]|0;Bb=Kb+(kd*40|0)+32|0;if((c[Bb>>2]|0)>0){nd=0}else{md=ld;break}do{Fb=c[o>>2]|0;xb=c[q>>2]|0;Qb=dc+(Fb>>>3)|0;Ab=(fe(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(Fb&7)>>>27;Qb=Fb+5|0;c[o>>2]=xb>>>0>Qb>>>0?Qb:xb;c[ec+64+(nd+yb<<4)+12>>2]=Ab;nd=nd+1|0;}while((nd|0)<(c[Bb>>2]|0));md=c[Lb>>2]|0}}while(0);Bb=kd+1|0;if((Bb|0)<(md|0)){kd=Bb;ld=md}else{bd=md;break}}}}while(0);if((Gb|0)<(h|0)){Nb=Gb;Jb=bd}else{break y}}Jb=c[j+428>>2]|0;yDb(j,16,2099288,(v=i,i=i+16|0,c[v>>2]=Nc,c[v+8>>2]=Jb,v)|0);i=v;w=-1094995529;i=k;return w|0}}while(0);if(!Tb){Wb=dc;break}if((c[ec+8>>2]|0)<=0){Wb=dc;break}Sb=g+15600|0;Jb=g+7832|0;Nb=0;Lb=ec;while(1){if((a[Lb+12+Nb|0]|0)==0){od=Lb}else{UGb((c[Sb>>2]|0)+(Nb*40|0)|0,(c[Jb>>2]|0)+(Nb*40|0)|0,40)|0;od=c[fb>>2]|0}if((a[od+28+Nb|0]|0)==0){pd=od}else{Hb=(c[Sb>>2]|0)+(Nb*40|0)|0;UGb(Vb|0,Hb|0,40)|0;UGb(Hb|0,(c[Jb>>2]|0)+(Nb*40|0)|0,40)|0;UGb((c[Jb>>2]|0)+(Nb*40|0)|0,Vb|0,40)|0;pd=c[fb>>2]|0}Hb=Nb+1|0;if((Hb|0)<(c[pd+8>>2]|0)){Nb=Hb;Lb=pd}else{break}}Wb=c[s>>2]|0}}while(0);s=c[o>>2]|0;pd=d[Wb+(s>>>3)|0]<<(s&7)>>>7;c[o>>2]=((s|0)<(c[q>>2]|0))+s;s=pd&1;c[g+28>>2]=s;if((s|0)==0){w=0;i=k;return w|0}s=c[o>>2]|0;pd=c[q>>2]|0;fb=Wb+(s>>>3)|0;Vb=(fe(d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0)|0)<<(s&7)>>>28;fb=s+4|0;c[o>>2]=pd>>>0>fb>>>0?fb:pd;c[g+32>>2]=Vb;Vb=c[o>>2]|0;pd=c[q>>2]|0;q=Wb+(Vb>>>3)|0;Wb=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(Vb&7)>>>28;q=Vb+4|0;c[o>>2]=pd>>>0>q>>>0?q:pd;c[g+36>>2]=Wb;w=0;i=k;return w|0}function Qhb(a,b){a=a|0;b=b|0;var d=0;c[b>>2]=a;d=a+116|0;c[b+4>>2]=c[d>>2];c[b+8>>2]=c[d>>2];c[b+16>>2]=0;return}function Rhb(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[a+16>>2]|0;if((d|0)!=0){yDb(c[a>>2]|0,24,2179496,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e}$Db(a+12|0);TGb(a|0,0,24)|0;i=b;return}function Shb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+8|0;e=d|0;f=a+12|0;g=a+16|0;h=jEb(c[f>>2]|0,a+20|0,(c[g>>2]<<4)+16|0)|0;j=h;if((h|0)==0){k=-12;i=d;return k|0}c[f>>2]=j;f=c[g>>2]|0;h=j+(f<<4)|0;l=b+76|0;m=c[l>>2]|0;n=j+(f<<4)+8|0;c[n>>2]=m;o=a+4|0;c[n>>2]=(c[o>>2]|0)+m;m=b+136|0;b=c[m>>2]|0;n=c[m+4>>2]|0;do{if((b|0)==0&(n|0)==(-2147483648|0)){m=h|0;c[m>>2]=0;c[m+4>>2]=-2147483648}else{m=a|0;p=c[m>>2]|0;c[e>>2]=1;c[e+4>>2]=c[p+412>>2];q=KDb(b,n,p+104|0,e)|0;p=h|0;r=c[o>>2]|0;s=ZGb(q,F,r,(r|0)<0|0?-1:0)|0;r=F;c[p>>2]=s;c[p+4>>2]=r;if((c[g>>2]|0)==0){break}p=j+(f-1<<4)|0;q=c[p+4>>2]|0;if((q|0)<(r|0)|(q|0)==(r|0)&(c[p>>2]|0)>>>0<s>>>0){break}yDb(c[m>>2]|0,24,2305088,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}}while(0);c[o>>2]=0;o=a+8|0;c[o>>2]=(c[o>>2]|0)+(c[l>>2]|0);c[g>>2]=(c[g>>2]|0)+1;k=0;i=d;return k|0}function Thb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=a+16|0;if((c[j>>2]|0)==0){if((c[a+20>>2]|0)==0){k=-2147483648;l=0}else{m=c[a+12>>2]|0;k=c[m+4>>2]|0;l=c[m>>2]|0}yDb(c[a>>2]|0,24,2174472,(n=i,i=i+8|0,c[n>>2]=b,n)|0);i=n;o=k;p=l}else{l=c[a+12>>2]|0;o=c[l+4>>2]|0;p=c[l>>2]|0}if((d|0)!=0){l=c[a>>2]|0;if((p|0)==0&(o|0)==(-2147483648|0)){q=-2147483648;r=0}else{c[h>>2]=1;c[h+4>>2]=c[l+412>>2];k=KDb(p,o,h,l+104|0)|0;q=F;r=k}c[d>>2]=r;c[d+4>>2]=q}do{if((b|0)==0){s=0;t=0;u=0;v=a+8|0;w=18}else{q=a+12|0;d=0;r=0;k=b;while(1){if(!(r>>>0<(c[j>>2]|0)>>>0)){x=d;y=r;z=k;A=1;break}l=c[q>>2]|0;h=l+(r<<4)+8|0;o=c[h>>2]|0;p=(o|0)>(k|0)?k:o;c[h>>2]=o-p;o=k-p|0;h=p+d|0;m=l+(r<<4)|0;l=c[m>>2]|0;B=c[m+4>>2]|0;if(!((l|0)==0&(B|0)==(-2147483648|0))){C=YGb(p,(p|0)<0|0?-1:0,l,B)|0;c[m>>2]=C;c[m+4>>2]=F}m=r+1|0;if((k|0)==(p|0)){x=h;y=m;z=o;A=0;break}else{d=h;r=m;k=o}}k=a+8|0;c[k>>2]=(c[k>>2]|0)-x;if((y|0)==0){s=A;t=z;u=x;v=k;w=18;break}r=c[a+12>>2]|0;D=(c[r+(y-1<<4)+8>>2]|0)!=0|0;E=r;G=A;H=z;I=y;J=x;K=k}}while(0);if((w|0)==18){D=0;E=c[a+12>>2]|0;G=s;H=t;I=0;J=u;K=v}v=I-D|0;D=a+12|0;VGb(E|0,E+(v<<4)|0,(c[j>>2]|0)-v<<4|0)|0;E=c[j>>2]|0;c[j>>2]=E-v;if(G){if((E|0)!=(v|0)){yDb(0,0,2099248,(n=i,i=i+24|0,c[n>>2]=2043920,c[n+8>>2]=1998576,c[n+16>>2]=105,n)|0);i=n;Cd()}if((c[K>>2]|0)!=(c[a+4>>2]|0)){yDb(0,0,2099248,(n=i,i=i+24|0,c[n>>2]=1961696,c[n+8>>2]=1998576,c[n+16>>2]=106,n)|0);i=n;Cd()}K=c[D>>2]|0;do{if((K|0)!=0){D=K|0;v=c[D>>2]|0;E=c[D+4>>2]|0;if((v|0)==0&(E|0)==(-2147483648|0)){break}G=YGb(v,E,H,(H|0)<0|0?-1:0)|0;c[D>>2]=G;c[D+4>>2]=F}}while(0);yDb(c[a>>2]|0,48,1933760,(n=i,i=i+8|0,c[n>>2]=H,n)|0);i=n}if((e|0)==0){i=f;return}n=c[a>>2]|0;c[g>>2]=1;c[g+4>>2]=c[n+412>>2];a=KDb(J,(J|0)<0|0?-1:0,g,n+104|0)|0;c[e>>2]=a;i=f;return}function Uhb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=a+16|0;c[a+12>>2]=b;c[a+20>>2]=b+e;e=b+1|0;c[f>>2]=e;g=(d[b]|0)<<18;h=a|0;c[h>>2]=g;i=b+2|0;c[f>>2]=i;j=(d[e]|0)<<10|g;c[h>>2]=j;c[f>>2]=b+3;c[h>>2]=(d[i]|0)<<2|j|2;c[a+4>>2]=510;return}function Vhb(){var b=0,c=0,d=0,e=0;if(a[1202568]|0){return}else{b=0}while(1){c=b<<1;d=a[765144+(b<<2)|0]|0;a[(c|1)+1208992|0]=d;a[c+1208992|0]=d;d=a[765145+(b<<2)|0]|0;a[(c+128|1)+1208992|0]=d;a[c+1209120|0]=d;d=a[765146+(b<<2)|0]|0;a[(c+256|1)+1208992|0]=d;a[c+1209248|0]=d;d=a[765147+(b<<2)|0]|0;a[(c+384|1)+1208992|0]=d;a[c+1209376|0]=d;d=a[644424+b|0]<<1;a[c+1209632|0]=d;a[c+1209633|0]=d|1;if((b|0)==0){d=128-c|0;a[d+1209503|0]=1;a[d+1209502|0]=0;b=b+1|0;continue}else{d=a[765080+b|0]<<1;e=128-c|0;a[e+1209503|0]=d;a[e+1209502|0]=d|1;d=b+1|0;if((d|0)<64){b=d;continue}else{break}}}UGb(1209760,858048,63)|0;a[1202568]=1;return}function Whb(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;g=e+1684|0;h=c[g>>2]|0;i=h<<4;j=c[e+2140>>2]|0;a[e+2224|0]=a[j+(i|15)|0]|0;k=(h*10|0)+8|0;h=e+2144|0;a[e+2225|0]=a[(c[h>>2]|0)+k|0]|0;l=e+2148|0;a[e+2226|0]=a[(c[l>>2]|0)+k|0]|0;k=e+1704|0;m=e+1972|0;UGb(j+i|0,(c[k>>2]|0)+((c[m>>2]|0)*15|0)|0,16)|0;i=e+1708|0;j=e+1976|0;n=(c[i>>2]|0)+((c[j>>2]|0)*7|0)|0;o=(c[h>>2]|0)+((c[g>>2]|0)*10|0|1)|0;h=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o|0;x=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=o+4|0;x=n;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=e+1712|0;n=(c[p>>2]|0)+((c[j>>2]|0)*7|0)|0;o=(c[l>>2]|0)+((c[g>>2]|0)*10|0|1)|0;l=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=o+4|0;x=n;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=0;while(1){n=h<<1;o=n|1;a[e+2152+o|0]=a[(c[k>>2]|0)+((ba(c[m>>2]|0,n)|0)+15)|0]|0;a[n+2+(e+2152)|0]=a[(c[k>>2]|0)+((ba(c[m>>2]|0,o)|0)+15)|0]|0;o=h+1|0;a[e+2178+o|0]=a[(c[i>>2]|0)+((ba(c[j>>2]|0,h)|0)+7)|0]|0;a[e+2188+o|0]=a[(c[p>>2]|0)+((ba(c[j>>2]|0,h)|0)+7)|0]|0;if((o|0)<8){h=o}else{break}}if((c[e+1668>>2]|0)!=0){q=e+1996|0;r=c[q>>2]|0;s=e+1716|0;c[s>>2]=r;t=r&255;u=c[g>>2]|0;v=e+1720|0;w=c[v>>2]|0;y=w+u|0;a[y]=t;return}do{if((f|0)==0){z=2;A=2;B=2;C=2;D=2;E=2;F=2;G=2}else{h=a[1255552+f|0]|0;do{if(h<<24>>24<0){o=f>>>0>5>>>0;n=b[e+1774>>1]|0;do{if(n<<16>>16==-2){H=2}else{l=b[e+1782>>1]|0;if(l<<16>>16==-2){H=2;break}I=(b[e+1768>>1]|0)-(b[e+1776>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){H=1;break}I=(b[e+1770>>1]|0)-(b[e+1778>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){H=1;break}if(o){I=(b[e+1864>>1]|0)-(b[e+1872>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){H=1;break}I=(b[e+1866>>1]|0)-(b[e+1874>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){H=1;break}}else{if(!(n<<16>>16==l<<16>>16)){H=1;break}}H=0}}while(0);n=b[e+1806>>1]|0;if(n<<16>>16==-2){J=H;K=2;break}l=b[e+1814>>1]|0;if(l<<16>>16==-2){J=H;K=2;break}I=(b[e+1800>>1]|0)-(b[e+1808>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){J=H;K=1;break}I=(b[e+1802>>1]|0)-(b[e+1810>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){J=H;K=1;break}if(o){I=(b[e+1896>>1]|0)-(b[e+1904>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){J=H;K=1;break}I=(b[e+1898>>1]|0)-(b[e+1906>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){J=H;K=1;break}}else{if(!(n<<16>>16==l<<16>>16)){J=H;K=1;break}}J=H;K=0}else{J=0;K=0}}while(0);do{if((h&64)==0){L=0;M=0}else{l=f>>>0>5>>>0;n=b[e+1774>>1]|0;do{if(n<<16>>16==-2){N=2}else{I=b[e+1806>>1]|0;if(I<<16>>16==-2){N=2;break}O=(b[e+1768>>1]|0)-(b[e+1800>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){N=1;break}O=(b[e+1770>>1]|0)-(b[e+1802>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){N=1;break}if(l){O=(b[e+1864>>1]|0)-(b[e+1896>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){N=1;break}O=(b[e+1866>>1]|0)-(b[e+1898>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){N=1;break}}else{if(!(n<<16>>16==I<<16>>16)){N=1;break}}N=0}}while(0);n=b[e+1782>>1]|0;if(n<<16>>16==-2){L=N;M=2;break}o=b[e+1814>>1]|0;if(o<<16>>16==-2){L=N;M=2;break}I=(b[e+1776>>1]|0)-(b[e+1808>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){L=N;M=1;break}I=(b[e+1778>>1]|0)-(b[e+1810>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){L=N;M=1;break}if(l){I=(b[e+1872>>1]|0)-(b[e+1904>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){L=N;M=1;break}I=(b[e+1874>>1]|0)-(b[e+1906>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){L=N;M=1;break}}else{if(!(n<<16>>16==o<<16>>16)){L=N;M=1;break}}L=N;M=0}}while(0);h=e+1768|0;o=f>>>0>5>>>0;n=b[e+1766>>1]|0;do{if(n<<16>>16==-2){P=2}else{I=b[e+1774>>1]|0;if(I<<16>>16==-2){P=2;break}O=(b[e+1760>>1]|0)-(b[h>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){P=1;break}O=(b[e+1762>>1]|0)-(b[e+1770>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){P=1;break}if(o){O=(b[e+1856>>1]|0)-(b[e+1864>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){P=1;break}O=(b[e+1858>>1]|0)-(b[e+1866>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){P=1;break}}else{if(!(n<<16>>16==I<<16>>16)){P=1;break}}P=0}}while(0);n=b[e+1798>>1]|0;do{if(n<<16>>16==-2){Q=2}else{I=b[e+1806>>1]|0;if(I<<16>>16==-2){Q=2;break}O=(b[e+1792>>1]|0)-(b[e+1800>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){Q=1;break}O=(b[e+1794>>1]|0)-(b[e+1802>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){Q=1;break}if(o){O=(b[e+1888>>1]|0)-(b[e+1896>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){Q=1;break}O=(b[e+1890>>1]|0)-(b[e+1898>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){Q=1;break}}else{if(!(n<<16>>16==I<<16>>16)){Q=1;break}}Q=0}}while(0);n=b[e+1742>>1]|0;do{if(n<<16>>16==-2){R=2}else{I=b[e+1774>>1]|0;if(I<<16>>16==-2){R=2;break}O=(b[e+1736>>1]|0)-(b[h>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){R=1;break}O=(b[e+1738>>1]|0)-(b[e+1770>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){R=1;break}if(o){O=(b[e+1832>>1]|0)-(b[e+1864>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){R=1;break}O=(b[e+1834>>1]|0)-(b[e+1866>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){R=1;break}}else{if(!(n<<16>>16==I<<16>>16)){R=1;break}}R=0}}while(0);n=b[e+1750>>1]|0;if(n<<16>>16==-2){z=P;A=Q;B=J;C=K;D=R;E=2;F=L;G=M;break}h=b[e+1782>>1]|0;if(h<<16>>16==-2){z=P;A=Q;B=J;C=K;D=R;E=2;F=L;G=M;break}I=(b[e+1744>>1]|0)-(b[e+1776>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}I=(b[e+1746>>1]|0)-(b[e+1778>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}if(o){I=(b[e+1840>>1]|0)-(b[e+1872>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}I=(b[e+1842>>1]|0)-(b[e+1874>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}}else{if(!(n<<16>>16==h<<16>>16)){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}}z=P;A=Q;B=J;C=K;D=R;E=0;F=L;G=M}}while(0);M=C&255;L=B&255;R=A&255;if((0<<16|0>>>16|(0<<24|0>>>8)|(0<<8|0>>>24)|(M<<24|0>>>8)|(L<<16|0>>>16)|(R<<8|0>>>24)|z&255|0)==0&((F&255)<<16|0>>>16|((G&255)<<24|0>>>8)|((E&255)<<8|0>>>24)|D&255|(0<<24|M>>>8)|(0<<16|L>>>16)|(0<<8|R>>>24)|0)==0){q=e+1996|0;r=c[q>>2]|0;s=e+1716|0;c[s>>2]=r;t=r&255;u=c[g>>2]|0;v=e+1720|0;w=c[v>>2]|0;y=w+u|0;a[y]=t;return}R=e+1696|0;L=e+1996|0;if((c[R>>2]&1|0)==0){S=e+1672|0}else{M=(c[L>>2]|0)+1+(c[e+1716>>2]|0)>>1;K=e+1672|0;J=M+(c[K>>2]|0)|0;if((J|0)<0){T=0}else{T=(J|0)>63?63:J}J=d[1797200+T|0]|0;Q=(c[e+1676>>2]|0)+M|0;if((Q|0)<0){U=0}else{U=(Q|0)>63?63:Q}Q=d[1732928+U|0]|0;U=d[189104+T|0]|0;T=z&255;z=A&255;Ke[c[e+1544>>2]&1023](c[k>>2]|0,c[m>>2]|0,J,Q,U,T,z);A=e+1552|0;Ke[c[A>>2]&1023](c[i>>2]|0,c[j>>2]|0,J,Q,U,T,z);Ke[c[A>>2]&1023](c[p>>2]|0,c[j>>2]|0,J,Q,U,T,z);S=K}K=c[L>>2]|0;z=(c[S>>2]|0)+K|0;if((z|0)<0){V=0}else{V=(z|0)>63?63:z}z=d[1797200+V|0]|0;T=e+1676|0;U=(c[T>>2]|0)+K|0;if((U|0)<0){W=0}else{W=(U|0)>63?63:U}U=d[1732928+W|0]|0;W=d[189104+V|0]|0;Ke[c[e+1544>>2]&1023]((c[k>>2]|0)+8|0,c[m>>2]|0,z,U,W,B&255,C&255);C=e+1548|0;B=c[m>>2]|0;Ke[c[C>>2]&1023]((c[k>>2]|0)+(B<<3)|0,B,z,U,W,F&255,G&255);if((c[R>>2]&2|0)==0){q=e+1996|0;r=c[q>>2]|0;s=e+1716|0;c[s>>2]=r;t=r&255;u=c[g>>2]|0;v=e+1720|0;w=c[v>>2]|0;y=w+u|0;a[y]=t;return}R=(c[L>>2]|0)+1+(d[(c[e+1720>>2]|0)+(c[g>>2]|0)|0]|0)>>1;L=R+(c[S>>2]|0)|0;if((L|0)<0){X=0}else{X=(L|0)>63?63:L}L=d[1797200+X|0]|0;S=(c[T>>2]|0)+R|0;if((S|0)<0){Y=0}else{Y=(S|0)>63?63:S}S=d[1732928+Y|0]|0;Y=d[189104+X|0]|0;X=D&255;D=E&255;Ke[c[C>>2]&1023](c[k>>2]|0,c[m>>2]|0,L,S,Y,X,D);m=e+1556|0;Ke[c[m>>2]&1023](c[i>>2]|0,c[j>>2]|0,L,S,Y,X,D);Ke[c[m>>2]&1023](c[p>>2]|0,c[j>>2]|0,L,S,Y,X,D);q=e+1996|0;r=c[q>>2]|0;s=e+1716|0;c[s>>2]=r;t=r&255;u=c[g>>2]|0;v=e+1720|0;w=c[v>>2]|0;y=w+u|0;a[y]=t;return}function Xhb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)==1){h=b+2198|0;c[f>>2]=h;i=c[b+1704>>2]|0;j=a[i+7|0]|0;a[b+2199|0]=j;k=c[b+1972>>2]|0;a[b+2200|0]=a[i+(k+7)|0]|0;a[b+2201|0]=a[i+((k<<1)+7)|0]|0;a[b+2202|0]=a[i+((k*3|0)+7)|0]|0;a[b+2203|0]=a[i+((k<<2)+7)|0]|0;a[b+2204|0]=a[i+((k*5|0)+7)|0]|0;a[b+2205|0]=a[i+((k*6|0)+7)|0]|0;TGb(b+2206|0,a[i+((k*7|0)+7)|0]|0,10)|0;a[h]=j;j=b+1684|0;k=b+2140|0;i=(c[k>>2]|0)+(c[j>>2]<<4|8)|0;l=e+1|0;m=i|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=i+4|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l|0;x=n;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+4|0;x=i;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=b+1696|0;l=e+9|0;o=(i>>>24|0<<8)&255;if((c[m>>2]&4|0)==0){TGb(l|0,o|0,9)|0;p=o}else{o=(c[k>>2]|0)+((c[j>>2]<<4)+16)|0;i=l;l=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=i|0;x=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=i+4|0;x=o;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;p=(o>>>24|0<<8)&255}a[e+17|0]=p;a[e]=n;if((c[m>>2]&2|0)==0){return}m=a[(c[k>>2]|0)+(c[j>>2]<<4|7)|0]|0;a[e]=m;a[h]=m;return}else if((g|0)==2){m=b+2160|0;c[f>>2]=m;h=e+1|0;UGb(h|0,(c[b+1704>>2]|0)+((c[b+1972>>2]|0)*7|0)|0,16)|0;a[e+17|0]=a[e+16|0]|0;a[e]=a[h]|0;if((c[b+1696>>2]&1|0)==0){return}a[e]=a[m]|0;return}else if((g|0)==3){c[f>>2]=b+2206;m=c[b+1704>>2]|0;h=c[b+1972>>2]|0;a[b+2207|0]=a[m+(h<<3|7)|0]|0;a[b+2208|0]=a[m+((h*9|0)+7)|0]|0;a[b+2209|0]=a[m+((h*10|0)+7)|0]|0;a[b+2210|0]=a[m+((h*11|0)+7)|0]|0;a[b+2211|0]=a[m+((h*12|0)+7)|0]|0;a[b+2212|0]=a[m+((h*13|0)+7)|0]|0;a[b+2213|0]=a[m+((h*14|0)+7)|0]|0;TGb(b+2214|0,a[m+((h*15|0)+7)|0]|0,10)|0;UGb(e|0,m+((h*7|0)+7)|0,9)|0;TGb(e+9|0,a[e+8|0]|0,9)|0;return}else if((g|0)==0){g=b+2152|0;c[f>>2]=g;a[g]=a[b+2153|0]|0;TGb(b+2169|0,a[b+2168|0]|0,9)|0;f=e+1|0;UGb(f|0,(c[b+2140>>2]|0)+(c[b+1684>>2]<<4)|0,16)|0;a[e+17|0]=a[e+16|0]|0;a[e]=a[f]|0;if((c[b+1696>>2]&3|0)!=3){return}f=a[b+2224|0]|0;a[e]=f;a[g]=f;return}else{return}}function Yhb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b+2178|0;a[b+2187|0]=a[b+2186|0]|0;e=b+2188|0;a[b+2197|0]=a[b+2196|0]|0;f=b+1684|0;g=(c[f>>2]|0)*10|0;h=b+2144|0;i=c[h>>2]|0;a[i+(g+9)|0]=a[i+(g+8)|0]|0;g=(c[f>>2]|0)*10|0;i=b+2148|0;j=c[i>>2]|0;a[j+(g+9)|0]=a[j+(g+8)|0]|0;g=c[f>>2]|0;do{if((g|0)!=0){if((c[b+1688>>2]|0)==0){break}j=a[b+2225|0]|0;a[d|0]=j;a[(c[h>>2]|0)+(g*10|0)|0]=j;j=a[b+2226|0]|0;a[e|0]=j;a[(c[i>>2]|0)+((c[f>>2]|0)*10|0)|0]=j;return}}while(0);a[d|0]=a[b+2179|0]|0;a[e|0]=a[b+2189|0]|0;b=g*10|0;g=c[h>>2]|0;a[g+b|0]=a[g+(b|1)|0]|0;b=(c[f>>2]|0)*10|0;f=c[i>>2]|0;a[f+b|0]=a[f+(b|1)|0]|0;return}function Zhb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b+1952|0;c[b+1944>>2]=c[f>>2];g=b+1964|0;c[b+1956>>2]=c[g>>2];h=b+1960|0;j=b+1684|0;k=c[b+1968>>2]|0;c[k+(c[j>>2]<<1<<2)>>2]=c[h>>2];c[k+((c[j>>2]<<1|1)<<2)>>2]=c[g>>2];g=b+1696|0;do{if((c[g>>2]&1|0)==0){j=b+1948|0;k=c[j>>2]|0;c[j>>2]=a[857912+k|0]|0;if((26>>>(k>>>0)&1|0)!=0){yDb(0,16,2178976,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[j>>2]=0}j=c[h>>2]|0;c[h>>2]=a[857912+j|0]|0;if((26>>>(j>>>0)&1|0)!=0){yDb(0,16,2178976,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[h>>2]=0}j=c[d>>2]|0;c[d>>2]=a[857920+j|0]|0;if(!((j|0)==3|(j|0)==1)){break}yDb(0,16,2178976,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[d>>2]=0}}while(0);if((c[g>>2]&2|0)!=0){i=e;return}g=b+1948|0;b=c[g>>2]|0;c[g>>2]=a[186048+b|0]|0;if((25>>>(b>>>0)&1|0)!=0){yDb(0,16,2178976,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[g>>2]=0}g=c[f>>2]|0;c[f>>2]=a[186048+g|0]|0;if((25>>>(g>>>0)&1|0)!=0){yDb(0,16,2178976,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[f>>2]=0}f=c[d>>2]|0;c[d>>2]=a[186056+f|0]|0;if(!((f-2|0)>>>0<2>>>0)){i=e;return}yDb(0,16,2178976,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[d>>2]=0;i=e;return}function _hb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=d+1704|0;g=c[f>>2]|0;h=d+1708|0;i=c[h>>2]|0;j=d+1712|0;k=c[j>>2]|0;if((a[1255552+e|0]|0)==0){e=d+1288|0;l=c[d+1248>>2]|0;m=c[d+1684>>2]<<3;n=c[d+1688>>2]<<3;o=b[d+1774>>1]|0;if(o<<16>>16>-1){p=c[d+1264>>2]|0;q=c[d+1596+(o<<16>>16<<3)>>2]|0;qib(d,c[q>>2]|0,c[q+4>>2]|0,c[q+8>>2]|0,8,g,i,k,m,n,e,l,b[d+1768>>1]|0,b[d+1770>>1]|0);r=p;s=d+1416|0}else{r=l;s=e}if(!((b[d+1870>>1]|0)>-1)){return}e=c[d+1596>>2]|0;qib(d,c[e>>2]|0,c[e+4>>2]|0,c[e+8>>2]|0,8,g,i,k,m,n,s,r,b[d+1864>>1]|0,b[d+1866>>1]|0);return}r=d+1352|0;s=d+1252|0;n=c[s>>2]|0;m=d+1480|0;e=d+1268|0;l=d+1684|0;p=c[l>>2]<<3;q=d+1688|0;o=c[q>>2]<<3;t=b[d+1774>>1]|0;if(t<<16>>16>-1){u=c[e>>2]|0;v=c[d+1596+(t<<16>>16<<3)>>2]|0;qib(d,c[v>>2]|0,c[v+4>>2]|0,c[v+8>>2]|0,4,g,i,k,p,o,r,n,b[d+1768>>1]|0,b[d+1770>>1]|0);w=u;x=m}else{w=n;x=r}if((b[d+1870>>1]|0)>-1){n=c[d+1596>>2]|0;qib(d,c[n>>2]|0,c[n+4>>2]|0,c[n+8>>2]|0,4,g,i,k,p,o,x,w,b[d+1864>>1]|0,b[d+1866>>1]|0)}w=c[s>>2]|0;x=(c[f>>2]|0)+8|0;o=(c[h>>2]|0)+4|0;p=(c[j>>2]|0)+4|0;k=c[l>>2]<<3|4;l=c[q>>2]<<3;q=b[d+1782>>1]|0;if(q<<16>>16>-1){i=c[e>>2]|0;g=c[d+1596+(q<<16>>16<<3)>>2]|0;qib(d,c[g>>2]|0,c[g+4>>2]|0,c[g+8>>2]|0,4,x,o,p,k,l,r,w,b[d+1776>>1]|0,b[d+1778>>1]|0);y=i;z=m}else{y=w;z=r}if((b[d+1878>>1]|0)>-1){w=c[d+1596>>2]|0;qib(d,c[w>>2]|0,c[w+4>>2]|0,c[w+8>>2]|0,4,x,o,p,k,l,z,y,b[d+1872>>1]|0,b[d+1874>>1]|0)}$hb(d,4,c[f>>2]|0,c[h>>2]|0,c[j>>2]|0,0,4,r,c[s>>2]|0,m,c[e>>2]|0,d+1800|0);$hb(d,4,c[f>>2]|0,c[h>>2]|0,c[j>>2]|0,4,4,r,c[s>>2]|0,m,c[e>>2]|0,d+1808|0);return}function $hb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0;o=e+((ba(c[a+1972>>2]|0,i)|0)+h<<1)|0;e=(ba(c[a+1976>>2]|0,i)|0)+h|0;p=f+e|0;f=g+e|0;e=(c[a+1684>>2]<<3)+h|0;h=(c[a+1688>>2]<<3)+i|0;i=b[n+6>>1]|0;if(i<<16>>16>-1){g=c[a+1596+(i<<16>>16<<3)>>2]|0;qib(a,c[g>>2]|0,c[g+4>>2]|0,c[g+8>>2]|0,d,o,p,f,e,h,j,k,b[n>>1]|0,b[n+2>>1]|0);q=m;r=l}else{q=k;r=j}if(!((b[n+102>>1]|0)>-1)){return}j=c[a+1596>>2]|0;qib(a,c[j>>2]|0,c[j+4>>2]|0,c[j+8>>2]|0,d,o,p,f,e,h,r,q,b[n+96>>1]|0,b[n+98>>1]|0);return}function aib(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;l=f+1728+(g<<3)|0;m=g-1|0;n=f+1728+(m<<3)|0;o=g-4|0;p=f+1728+(o<<3)|0;q=k&65535;b[f+1728+(g<<3)+6>>1]=q;r=c[f+1612+(q<<16>>16<<2)>>2]&65535;b[f+1728+(g<<3)+4>>1]=r;q=(b[f+1728+(h<<3)+6>>1]|0)==-1?g-5|0:h;h=f+1728+(q<<3)|0;s=b[f+1728+(m<<3)+6>>1]|0;do{if((i|0)==4){if(s<<16>>16==-1){t=163128;u=19;break}v=b[f+1728+(o<<3)+6>>1]|0;if(v<<16>>16==-1){t=163128;u=19;break}if((b[n>>1]|s|b[f+1728+(m<<3)+2>>1])<<16>>16==0){t=163128;u=19;break}if((b[p>>1]|v|b[f+1728+(o<<3)+2>>1])<<16>>16==0){t=163128;u=19}else{u=6}}else{u=6}}while(0);do{if((u|0)==6){v=b[f+1728+(o<<3)+6>>1]|0;do{if(s<<16>>16>-1){if(v<<16>>16<0){if((b[f+1728+(q<<3)+6>>1]|0)<0){w=n;u=18;break}}if(s<<16>>16<0){u=10}else{u=14}}else{u=10}}while(0);do{if((u|0)==10){if(v<<16>>16>-1){if((b[f+1728+(q<<3)+6>>1]|0)<0){w=p;u=18;break}}if(!((s&v)<<16>>16<0)){u=14;break}if((b[f+1728+(q<<3)+6>>1]|0)>-1){w=h;u=18}else{u=14}}}while(0);do{if((u|0)==14){if((i|0)==1){if((s<<16>>16|0)==(k|0)){w=n;u=18;break}else{break}}else if((i|0)==3){w=(b[f+1728+(q<<3)+6>>1]|0)==(k|0)?h:0;u=18;break}else if((i|0)==2){if((v<<16>>16|0)==(k|0)){w=p;u=18;break}else{break}}else{break}}}while(0);if((u|0)==18){if((w|0)!=0){t=w;u=19;break}}x=r<<16>>16;y=c[f+2304+(s<<16>>16<<2)>>2]|0;z=b[n>>1]|0;A=(z>>31)+256+(ba(ba(x,z)|0,y)|0)>>9;z=b[f+1728+(m<<3)+2>>1]|0;B=(z>>31)+256+(ba(ba(x,z)|0,y)|0)>>9;y=c[f+2304+(v<<16>>16<<2)>>2]|0;z=b[p>>1]|0;C=(z>>31)+256+(ba(ba(x,z)|0,y)|0)>>9;z=b[f+1728+(o<<3)+2>>1]|0;D=(z>>31)+256+(ba(ba(x,z)|0,y)|0)>>9;y=c[f+2304+(b[f+1728+(q<<3)+6>>1]<<2)>>2]|0;z=b[h>>1]|0;E=(z>>31)+256+(ba(ba(x,z)|0,y)|0)>>9;z=b[f+1728+(q<<3)+2>>1]|0;F=(z>>31)+256+(ba(ba(x,z)|0,y)|0)>>9;y=A-C|0;z=B-D|0;x=((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)|0;z=C-E|0;y=D-F|0;G=((z|0)>-1?z:-z|0)+((y|0)>-1?y:-y|0)|0;y=E-A|0;z=F-B|0;H=((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)|0;do{if((x|0)>(G|0)){if((H|0)<=(G|0)){I=G;break}I=(H|0)>(x|0)?x:H}else{if((G|0)<=(H|0)){I=G;break}I=(H|0)>(x|0)?H:x}}while(0);if((I|0)==(x|0)){b[l>>1]=E;b[f+1728+(g<<3)+2>>1]=F;break}if((I|0)==(G|0)){b[l>>1]=A;b[f+1728+(g<<3)+2>>1]=B;break}else{b[l>>1]=C;b[f+1728+(g<<3)+2>>1]=D;break}}}while(0);if((u|0)==19){b[l>>1]=b[t>>1]|0;b[f+1728+(g<<3)+2>>1]=b[t+2>>1]|0}if(i>>>0<4>>>0){i=f+1576|0;t=c[i>>2]|0;u=f+1584|0;I=c[u>>2]|0;q=f+1568|0;h=c[q>>2]|0;o=h+(t>>>3)|0;p=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(t&7);if(p>>>0>134217727>>>0){o=p>>>23;m=(d[1213744+o|0]|0)+t|0;c[i>>2]=I>>>0>m>>>0?m:I;J=a[1139096+o|0]|0}else{o=p>>>0>65535>>>0;m=o?p>>>16:p;p=o?16:0;if((m&65280|0)==0){K=p;L=m}else{K=p|8;L=m>>>8}m=(d[1191992+L|0]|0)+K|0;K=31-m+t|0;t=I>>>0>K>>>0?K:I;K=h+(t>>>3)|0;h=(fe(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(t&7)>>>(m>>>0);K=t+(32-m)|0;c[i>>2]=I>>>0>K>>>0?K:I;I=h>>>1;J=(h&1|0)==0?I:-I|0}I=l|0;b[I>>1]=(e[I>>1]|0)+J;J=c[i>>2]|0;I=c[u>>2]|0;u=c[q>>2]|0;q=u+(J>>>3)|0;h=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(J&7);if(h>>>0>134217727>>>0){q=h>>>23;K=(d[1213744+q|0]|0)+J|0;c[i>>2]=I>>>0>K>>>0?K:I;M=a[1139096+q|0]|0}else{q=h>>>0>65535>>>0;K=q?h>>>16:h;h=q?16:0;if((K&65280|0)==0){N=h;O=K}else{N=h|8;O=K>>>8}K=(d[1191992+O|0]|0)+N|0;N=31-K+J|0;J=I>>>0>N>>>0?N:I;N=u+(J>>>3)|0;u=(fe(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(J&7)>>>(K>>>0);N=J+(32-K)|0;c[i>>2]=I>>>0>N>>>0?N:I;I=u>>>1;M=(u&1|0)==0?I:-I|0}I=f+1728+(g<<3)+2|0;b[I>>1]=(e[I>>1]|0)+M}if((j|0)==2){M=l;I=f+1728+(g+4<<3)|0;u=c[M+4>>2]|0;c[I>>2]=c[M>>2];c[I+4>>2]=u;return}else if((j|0)==1){u=l;P=c[u+4>>2]|0;Q=c[u>>2]|0}else if((j|0)==0){j=l;l=f+1728+(g+4<<3)|0;u=c[j>>2]|0;I=c[j+4>>2]|0;c[l>>2]=u;c[l+4>>2]=I;l=f+1728+(g+5<<3)|0;c[l>>2]=u;c[l+4>>2]=I;P=I;Q=u}else{return}u=f+1728+(g+1<<3)|0;c[u>>2]=Q;c[u+4>>2]=P;return}function bib(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[a+1684>>2]|0;d=b<<1;e=c[a+1920>>2]|0;f=e+(d<<3)|0;g=a+1736|0;h=c[f+4>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;h=c[a+1924>>2]|0;f=h+(d<<3)|0;i=a+1832|0;j=c[f+4>>2]|0;c[i>>2]=c[f>>2];c[i+4>>2]=j;j=d|1;f=e+(j<<3)|0;k=a+1744|0;l=c[f+4>>2]|0;c[k>>2]=c[f>>2];c[k+4>>2]=l;l=h+(j<<3)|0;j=a+1840|0;f=c[l+4>>2]|0;c[j>>2]=c[l>>2];c[j+4>>2]=f;f=d+2|0;l=e+(f<<3)|0;e=a+1752|0;m=c[l+4>>2]|0;c[e>>2]=c[l>>2];c[e+4>>2]=m;m=h+(f<<3)|0;f=a+1848|0;h=c[m+4>>2]|0;c[f>>2]=c[m>>2];c[f+4>>2]=h;h=c[a+1968>>2]|0;m=a+1936|0;c[m>>2]=c[h+(d<<2)>>2];l=a+1940|0;c[l>>2]=c[h+((d|1)<<2)>>2];d=a+1696|0;h=c[d>>2]|0;do{if((h&2|0)==0){c[g>>2]=0;c[g+4>>2]=-65535;c[k>>2]=0;c[k+4>>2]=-65535;c[i>>2]=0;c[i+4>>2]=-65535;c[j>>2]=0;c[j+4>>2]=-65535;c[l>>2]=-1;c[m>>2]=-1;n=h&-13;c[d>>2]=n;o=b;p=n}else{if((b|0)==0){o=0;p=h;break}n=h|8;c[d>>2]=n;o=b;p=n}}while(0);if((o|0)==((c[a+1636>>2]|0)-1|0)){o=p&-5;c[d>>2]=o;q=o}else{q=p}if((q&4|0)==0){c[e>>2]=0;c[e+4>>2]=-65535;c[f>>2]=0;c[f+4>>2]=-65535}if((q&8|0)!=0){return}q=a+1728|0;c[q>>2]=0;c[q+4>>2]=-65535;q=a+1824|0;c[q>>2]=0;c[q+4>>2]=-65535;return}function cib(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=a+1696|0;c[b>>2]=c[b>>2]|1;d=a+1704|0;c[d>>2]=(c[d>>2]|0)+16;e=a+1708|0;c[e>>2]=(c[e>>2]|0)+8;f=a+1712|0;c[f>>2]=(c[f>>2]|0)+8;g=a+1744|0;h=a+1728|0;i=c[g+4>>2]|0;c[h>>2]=c[g>>2];c[h+4>>2]=i;i=a+1776|0;g=a+1760|0;j=c[i+4>>2]|0;c[g>>2]=c[i>>2];c[g+4>>2]=j;j=a+1808|0;i=a+1792|0;k=c[j+4>>2]|0;c[i>>2]=c[j>>2];c[i+4>>2]=k;k=a+1840|0;l=a+1824|0;m=c[k+4>>2]|0;c[l>>2]=c[k>>2];c[l+4>>2]=m;m=a+1872|0;k=a+1856|0;n=c[m+4>>2]|0;c[k>>2]=c[m>>2];c[k+4>>2]=n;n=a+1904|0;m=a+1888|0;o=c[n+4>>2]|0;c[m>>2]=c[n>>2];c[m+4>>2]=o;o=a+1684|0;p=a+1920|0;q=a+1800|0;r=(c[p>>2]|0)+(c[o>>2]<<1<<3)|0;s=c[q+4>>2]|0;c[r>>2]=c[q>>2];c[r+4>>2]=s;s=(c[p>>2]|0)+((c[o>>2]<<1|1)<<3)|0;p=c[j+4>>2]|0;c[s>>2]=c[j>>2];c[s+4>>2]=p;p=a+1924|0;s=a+1896|0;j=(c[p>>2]|0)+(c[o>>2]<<1<<3)|0;r=c[s+4>>2]|0;c[j>>2]=c[s>>2];c[j+4>>2]=r;r=(c[p>>2]|0)+((c[o>>2]<<1|1)<<3)|0;p=c[n+4>>2]|0;c[r>>2]=c[n>>2];c[r+4>>2]=p;p=a+1692|0;c[p>>2]=(c[p>>2]|0)+1;p=(c[o>>2]|0)+1|0;c[o>>2]=p;do{if((p|0)==(c[a+1636>>2]|0)){c[b>>2]=6;c[a+1956>>2]=-1;c[a+1944>>2]=-1;c[h>>2]=0;c[h+4>>2]=-65535;c[g>>2]=0;c[g+4>>2]=-65535;c[i>>2]=0;c[i+4>>2]=-65535;c[l>>2]=0;c[l+4>>2]=-65535;c[k>>2]=0;c[k+4>>2]=-65535;c[m>>2]=0;c[m+4>>2]=-65535;c[o>>2]=0;r=a+1688|0;n=(c[r>>2]|0)+1|0;c[r>>2]=n;r=c[a+1588>>2]|0;c[d>>2]=(c[r>>2]|0)+(ba(n<<4,c[a+1972>>2]|0)|0);j=ba(n<<3,c[a+1976>>2]|0)|0;c[e>>2]=(c[r+4>>2]|0)+j;c[f>>2]=(c[r+8>>2]|0)+j;if((n|0)==(c[a+1640>>2]|0)){t=0}else{break}return t|0}}while(0);t=1;return t|0}function dib(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+1728|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1760|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1792|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1824|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1856|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1888|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1864|0;d=1255592;e=c[d>>2]|0;f=c[d+4>>2]|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1896|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1904|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1872|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1768|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1800|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1808|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1776|0;c[b>>2]=e;c[b+4>>2]=f;c[a+1956>>2]=-1;c[a+1944>>2]=-1;f=c[a+1588>>2]|0;c[a+1704>>2]=c[f>>2];c[a+1708>>2]=c[f+4>>2];c[a+1712>>2]=c[f+8>>2];b=c[f+32>>2]|0;c[a+1972>>2]=b;c[a+1976>>2]=c[f+36>>2];f=b<<3;c[a+1988>>2]=f;c[a+1992>>2]=f+8;TGb(a+1684|0,0,16)|0;return 0}function eib(a){a=a|0;var b=0,d=0;b=a+1636|0;c[a+1720>>2]=cEb(c[b>>2]|0)|0;c[a+1920>>2]=cEb(c[b>>2]<<4|8)|0;c[a+1924>>2]=cEb(c[b>>2]<<4|8)|0;c[a+1968>>2]=cEb(c[b>>2]<<3)|0;c[a+2140>>2]=cEb((c[b>>2]<<4)+16|0)|0;c[a+2144>>2]=cEb((c[b>>2]|0)*10|0)|0;c[a+2148>>2]=cEb((c[b>>2]|0)*10|0)|0;d=a+1640|0;c[a+1928>>2]=cEb(ba(c[b>>2]<<5,c[d>>2]|0)|0)|0;c[a+2288>>2]=cEb(ba(c[d>>2]|0,c[b>>2]|0)|0)|0;c[a+2320>>2]=cEb(128)|0;return}function fib(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;Z3(b+4|0,a);pea(b+1248|0,8);T3a(b+1280|0,8);rib(b+1288|0,a);d=b+1132|0;y2(d,c[b+1564>>2]|0);x2(d,b+2008|0,1075976);c[b>>2]=a;c[a+140>>2]=0;d=b+1588|0;c[d>>2]=ICb()|0;e=b+1596|0;c[e>>2]=ICb()|0;f=ICb()|0;c[b+1604>>2]=f;do{if((c[d>>2]|0)!=0){if((c[e>>2]|0)==0|(f|0)==0){break}c[b+1980>>2]=0;c[b+1984>>2]=8;c[b+2228>>2]=810;c[b+2232>>2]=398;c[b+2236>>2]=452;c[b+2240>>2]=516;c[b+2244>>2]=126;c[b+2248>>2]=640;c[b+2252>>2]=820;c[b+2256>>2]=418;c[b+2260>>2]=452;c[b+2264>>2]=398;c[b+2268>>2]=810;c[b+2272>>2]=686;c[b+2276>>2]=640;c[b+2280>>2]=820;c[b+2284>>2]=418;g=b+1784|0;c[g>>2]=0;c[g+4>>2]=-65535;g=b+1880|0;c[g>>2]=0;c[g+4>>2]=-65535;h=0;return h|0}}while(0);gib(a)|0;h=-12;return h|0}function gib(a){a=a|0;var b=0;b=c[a+60>>2]|0;JCb(b+1588|0);JCb(b+1596|0);JCb(b+1604|0);ZDb(c[b+1720>>2]|0);ZDb(c[b+1920>>2]|0);ZDb(c[b+1924>>2]|0);ZDb(c[b+1968>>2]|0);ZDb(c[b+2140>>2]|0);ZDb(c[b+2144>>2]|0);ZDb(c[b+2148>>2]|0);ZDb(c[b+1928>>2]|0);ZDb(c[b+2288>>2]|0);ZDb(c[b+2320>>2]|0);$Db(b+2312|0);return 0}function hib(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;e=b+1|0;b=e|0;g=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a;c[b>>2]=g;c[b+4>>2]=e;b=a+f|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f*3|0)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f<<2)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f*5|0)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f*6|0)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f*7|0)|0;c[b>>2]=g;c[b+4>>2]=e;return}function iib(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;b=gHb(d[e+1|0]|0,0,16843009,16843009)|0;g=a;c[g>>2]=b;c[g+4>>2]=F;g=gHb(d[e+2|0]|0,0,16843009,16843009)|0;b=a+f|0;c[b>>2]=g;c[b+4>>2]=F;b=gHb(d[e+3|0]|0,0,16843009,16843009)|0;g=a+(f<<1)|0;c[g>>2]=b;c[g+4>>2]=F;g=gHb(d[e+4|0]|0,0,16843009,16843009)|0;b=a+(f*3|0)|0;c[b>>2]=g;c[b+4>>2]=F;b=gHb(d[e+5|0]|0,0,16843009,16843009)|0;g=a+(f<<2)|0;c[g>>2]=b;c[g+4>>2]=F;g=gHb(d[e+6|0]|0,0,16843009,16843009)|0;b=a+(f*5|0)|0;c[b>>2]=g;c[b+4>>2]=F;b=gHb(d[e+7|0]|0,0,16843009,16843009)|0;g=a+(f*6|0)|0;c[g>>2]=b;c[g+4>>2]=F;g=gHb(d[e+8|0]|0,0,16843009,16843009)|0;e=a+(f*7|0)|0;c[e>>2]=g;c[e+4>>2]=F;return}function jib(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=0;while(1){h=g+1|0;i=e+g|0;j=e+h|0;k=e+(g+2)|0;l=ba(g,f)|0;m=0;while(1){n=m+1|0;a[b+(m+l)|0]=((((d[i]|0)+2+((d[j]|0)<<1)+(d[k]|0)|0)>>>2)+(((d[c+m|0]|0)+2+((d[c+n|0]|0)<<1)+(d[c+(m+2)|0]|0)|0)>>>2)|0)>>>1;if((n|0)<8){m=n}else{break}}if((h|0)<8){g=h}else{break}}return}function kib(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=0;do{h=ba(g,f)|0;i=0;do{j=i+g|0;k=j+2|0;l=j+1|0;m=j+3|0;a[b+(i+h)|0]=((((d[e+l|0]|0)+2+((d[e+k|0]|0)<<1)+(d[e+m|0]|0)|0)>>>2)+(((d[c+l|0]|0)+2+((d[c+k|0]|0)<<1)+(d[c+m|0]|0)|0)>>>2)|0)>>>1;i=i+1|0;}while((i|0)<8);g=g+1|0;}while((g|0)<8);return}function lib(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e+1|0;h=c+1|0;i=0;do{j=ba(i,f)|0;k=0;do{do{if((k|0)==(i|0)){a[b+(i+j)|0]=((d[g]|0)+2+((d[c]|0)<<1)+(d[h]|0)|0)>>>2}else{if((k|0)>(i|0)){l=k-i|0;a[b+(k+j)|0]=((d[c+(l-1)|0]|0)+2+((d[c+l|0]|0)<<1)+(d[c+(l+1)|0]|0)|0)>>>2;break}else{l=i-k|0;a[b+(k+j)|0]=((d[e+(l-1)|0]|0)+2+((d[e+l|0]|0)<<1)+(d[e+(l+1)|0]|0)|0)>>>2;break}}}while(0);k=k+1|0;}while((k|0)<8);i=i+1|0;}while((i|0)<8);return}function mib(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c=0;while(1){g=c+1|0;h=e+c|0;i=e+g|0;j=e+(c+2)|0;k=ba(c,f)|0;a[b+k|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+1)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+2)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+3)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+4)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+5)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+6)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+7)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;if((g|0)<8){c=g}else{break}}return}function nib(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0;e=0;do{g=ba(e,f)|0;h=0;while(1){i=h+1|0;a[b+(h+g)|0]=((d[c+h|0]|0)+2+((d[c+i|0]|0)<<1)+(d[c+(h+2)|0]|0)|0)>>>2;if((i|0)<8){h=i}else{break}}e=e+1|0;}while((e|0)<8);return}function oib(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e<<1)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e*3|0)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e<<2)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e*5|0)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e*6|0)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e*7|0)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;return}function pib(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[c+8|0]|0;h=d[e+8|0]|0;i=(((g-(d[c]|0)<<2)+((((d[c+7|0]|0)-(d[c+1|0]|0)|0)*3|0)+(((d[c+6|0]|0)-(d[c+2|0]|0)<<1)+((d[c+5|0]|0)-(d[c+3|0]|0))))|0)*17|0)+16>>5;c=(((h-(d[e]|0)<<2)+((((d[e+7|0]|0)-(d[e+1|0]|0)|0)*3|0)+(((d[e+6|0]|0)-(d[e+2|0]|0)<<1)+((d[e+5|0]|0)-(d[e+3|0]|0))))|0)*17|0)+16>>5;e=(h+g<<4)+16|0;g=i*-3|0;h=0;do{j=e+(ba(h-3|0,c)|0)|0;k=ba(h,f)|0;a[b+k|0]=a[(j+g>>5)+1236056|0]|0;a[b+(k+1)|0]=a[(j+(i*-2|0)>>5)+1236056|0]|0;a[b+(k+2)|0]=a[(j-i>>5)+1236056|0]|0;a[b+(k+3)|0]=a[(j>>5)+1236056|0]|0;a[b+(k+4)|0]=a[(j+i>>5)+1236056|0]|0;a[b+(k+5)|0]=a[(j+(i<<1)>>5)+1236056|0]|0;a[b+(k+6)|0]=a[(j+(i*3|0)>>5)+1236056|0]|0;a[b+(k+7)|0]=a[(j+(i<<2)>>5)+1236056|0]|0;h=h+1|0;}while((h|0)<8);return}function qib(a,b,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;p=(n<<16>>16)+(j<<3)|0;j=(o<<16>>16)+(k<<3)|0;k=j<<2&12|p&3;o=p>>2;n=j>>2;q=a+1972|0;r=c[q>>2]|0;s=(ba(r,n)|0)+o|0;t=b+s|0;u=p>>3;v=j>>3;w=a+1976|0;x=(ba(c[w>>2]|0,v)|0)+u|0;y=d+x|0;d=e+x|0;x=c[a+1636>>2]|0;e=x<<4;z=c[a+1640>>2]|0;A=z<<4;if((b|0)==0){return}B=p&7;p=(B|0)==0?0:-3;C=j&7;j=(C|0)==0?0:-3;do{if((o|0)<(-p|0)){D=6}else{if((n|0)<(-j|0)){D=6;break}if((o+16|0)>(e+p|0)){D=6;break}if((n+16|0)>(A+j|0)){D=6;break}Xe[c[l+(k<<2)>>2]&4095](g,t,r);Se[m&511](h,y,c[w>>2]|0,f,B,C);E=d}}while(0);if((D|0)==6){D=a+1280|0;t=a+2312|0;Ne[c[D>>2]&127](c[t>>2]|0,b+(s-2-(r<<1))|0,r,r,21,21,o-2|0,n-2|0,e,A);A=c[q>>2]|0;Xe[c[l+(k<<2)>>2]&4095](g,(c[t>>2]|0)+((A<<1)+2)|0,A);A=c[w>>2]|0;g=x<<3;x=z<<3;Ne[c[D>>2]&127](c[t>>2]|0,y,A,A,9,9,u,v,g,x);Se[m&511](h,c[t>>2]|0,c[w>>2]|0,f,B,C);h=c[w>>2]|0;Ne[c[D>>2]&127](c[t>>2]|0,d,h,h,9,9,u,v,g,x);E=c[t>>2]|0}Se[m&511](i,E,c[w>>2]|0,f,B,C);return}function rib(a,b){a=a|0;b=b|0;c[a>>2]=932;c[a+4>>2]=820;c[a+8>>2]=1602;c[a+12>>2]=2130;c[a+16>>2]=638;c[a+20>>2]=1740;c[a+24>>2]=684;c[a+28>>2]=1814;c[a+32>>2]=1200;c[a+36>>2]=262;c[a+40>>2]=1012;c[a+44>>2]=352;c[a+48>>2]=1546;c[a+52>>2]=1132;c[a+56>>2]=546;c[a+60>>2]=26;c[a+64>>2]=1788;c[a+68>>2]=920;c[a+72>>2]=406;c[a+76>>2]=2276;c[a+80>>2]=1106;c[a+84>>2]=30;c[a+88>>2]=132;c[a+92>>2]=1350;c[a+96>>2]=2032;c[a+100>>2]=350;c[a+104>>2]=2204;c[a+108>>2]=790;c[a+112>>2]=1706;c[a+116>>2]=1816;c[a+120>>2]=1886;c[a+124>>2]=1962;c[a+128>>2]=514;c[a+132>>2]=2178;c[a+136>>2]=1646;c[a+140>>2]=1130;c[a+144>>2]=314;c[a+148>>2]=150;c[a+152>>2]=234;c[a+156>>2]=1466;c[a+160>>2]=908;c[a+164>>2]=1912;c[a+168>>2]=1074;c[a+172>>2]=1736;c[a+176>>2]=1836;c[a+180>>2]=968;c[a+184>>2]=1988;c[a+188>>2]=2068;c[a+192>>2]=1870;c[a+196>>2]=1918;c[a+200>>2]=650;c[a+204>>2]=1174;c[a+208>>2]=430;c[a+212>>2]=1580;c[a+216>>2]=2114;c[a+220>>2]=846;c[a+224>>2]=782;c[a+228>>2]=156;c[a+232>>2]=1238;c[a+236>>2]=308;c[a+240>>2]=2242;c[a+244>>2]=2184;c[a+248>>2]=336;c[a+252>>2]=2330;c[a+256>>2]=254;c[a+260>>2]=440;c[a+264>>2]=448;c[a+268>>2]=262;c[a+272>>2]=926;c[a+276>>2]=1;return}function sib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;bkb(a,b,c,c);bkb(a+8|0,b+8|0,c,c);d=c<<3;bkb(a+d|0,b+d|0,c,c);e=d+8|0;bkb(a+e|0,b+e|0,c,c);return}function tib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;akb(a,b,c,c);akb(a+8|0,b+8|0,c,c);d=c<<3;akb(a+d|0,b+d|0,c,c);e=d+8|0;akb(a+e|0,b+e|0,c,c);return}function uib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;$jb(a,b,c,c);$jb(a+8|0,b+8|0,c,c);d=c<<3;$jb(a+d|0,b+d|0,c,c);e=d+8|0;$jb(a+e|0,b+e|0,c,c);return}function vib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;_jb(a,b,c,c);_jb(a+8|0,b+8|0,c,c);d=c<<3;_jb(a+d|0,b+d|0,c,c);e=d+8|0;_jb(a+e|0,b+e|0,c,c);return}function wib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Sjb(a,b,b,c,c);d=b+8|0;Sjb(a+8|0,d,d,c,c);d=c<<3;e=b+d|0;Sjb(a+d|0,e,e,c,c);e=d+8|0;d=b+e|0;Sjb(a+e|0,d,d,c,c);return}function xib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Zjb(a,b,c,c);Zjb(a+8|0,b+8|0,c,c);d=c<<3;Zjb(a+d|0,b+d|0,c,c);e=d+8|0;Zjb(a+e|0,b+e|0,c,c);return}function yib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Sjb(a,b,b+1|0,c,c);Sjb(a+8|0,b+8|0,b+9|0,c,c);d=c<<3;Sjb(a+d|0,b+d|0,b+(d|1)|0,c,c);e=d+8|0;Sjb(a+e|0,b+e|0,b+(d+9)|0,c,c);return}function zib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Yjb(a,b,c,c);Yjb(a+8|0,b+8|0,c,c);d=c<<3;Yjb(a+d|0,b+d|0,c,c);e=d+8|0;Yjb(a+e|0,b+e|0,c,c);return}function Aib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Xjb(a,b,c,c);Xjb(a+8|0,b+8|0,c,c);d=c<<3;Xjb(a+d|0,b+d|0,c,c);e=d+8|0;Xjb(a+e|0,b+e|0,c,c);return}function Bib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Wjb(a,b,c,c);Wjb(a+8|0,b+8|0,c,c);d=c<<3;Wjb(a+d|0,b+d|0,c,c);e=d+8|0;Wjb(a+e|0,b+e|0,c,c);return}function Cib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Vjb(a,b,c,c);Vjb(a+8|0,b+8|0,c,c);d=c<<3;Vjb(a+d|0,b+d|0,c,c);e=d+8|0;Vjb(a+e|0,b+e|0,c,c);return}function Dib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Ujb(a,b,c,c);Ujb(a+8|0,b+8|0,c,c);d=c<<3;Ujb(a+d|0,b+d|0,c,c);e=d+8|0;Ujb(a+e|0,b+e|0,c,c);return}function Eib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Sjb(a,b,b+c|0,c,c);Sjb(a+8|0,b+8|0,b+(c+8)|0,c,c);d=c<<3;Sjb(a+d|0,b+d|0,b+(d+c)|0,c,c);e=d+8|0;Sjb(a+e|0,b+e|0,b+(e+c)|0,c,c);return}function Fib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Tjb(a,b,c,c);Tjb(a+8|0,b+8|0,c,c);d=c<<3;Tjb(a+d|0,b+d|0,c,c);e=d+8|0;Tjb(a+e|0,b+e|0,c,c);return}function Gib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=c+1|0;Sjb(a,b,b+d|0,c,c);Sjb(a+8|0,b+8|0,b+(c+9)|0,c,c);e=c<<3;Sjb(a+e|0,b+e|0,b+(d+e)|0,c,c);f=e+8|0;Sjb(a+f|0,b+f|0,b+(f+d)|0,c,c);return}function Hib(a,b,c){a=a|0;b=b|0;c=c|0;bkb(a,b,c,c);return}function Iib(a,b,c){a=a|0;b=b|0;c=c|0;akb(a,b,c,c);return}function Jib(a,b,c){a=a|0;b=b|0;c=c|0;$jb(a,b,c,c);return}function Kib(a,b,c){a=a|0;b=b|0;c=c|0;_jb(a,b,c,c);return}function Lib(a,b,c){a=a|0;b=b|0;c=c|0;Sjb(a,b,b,c,c);return}function Mib(a,b,c){a=a|0;b=b|0;c=c|0;Zjb(a,b,c,c);return}function Nib(a,b,c){a=a|0;b=b|0;c=c|0;Sjb(a,b,b+1|0,c,c);return}function Oib(a,b,c){a=a|0;b=b|0;c=c|0;Yjb(a,b,c,c);return}function Pib(a,b,c){a=a|0;b=b|0;c=c|0;Xjb(a,b,c,c);return}function Qib(a,b,c){a=a|0;b=b|0;c=c|0;Wjb(a,b,c,c);return}function Rib(a,b,c){a=a|0;b=b|0;c=c|0;Vjb(a,b,c,c);return}function Sib(a,b,c){a=a|0;b=b|0;c=c|0;Ujb(a,b,c,c);return}function Tib(a,b,c){a=a|0;b=b|0;c=c|0;Sjb(a,b,b+c|0,c,c);return}function Uib(a,b,c){a=a|0;b=b|0;c=c|0;Tjb(a,b,c,c);return}function Vib(a,b,c){a=a|0;b=b|0;c=c|0;Sjb(a,b,b+(c+1)|0,c,c);return}function Wib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Rjb(a,b,c,c);Rjb(a+8|0,b+8|0,c,c);d=c<<3;Rjb(a+d|0,b+d|0,c,c);e=d+8|0;Rjb(a+e|0,b+e|0,c,c);return}function Xib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Qjb(a,b,c,c);Qjb(a+8|0,b+8|0,c,c);d=c<<3;Qjb(a+d|0,b+d|0,c,c);e=d+8|0;Qjb(a+e|0,b+e|0,c,c);return}function Yib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Pjb(a,b,c,c);Pjb(a+8|0,b+8|0,c,c);d=c<<3;Pjb(a+d|0,b+d|0,c,c);e=d+8|0;Pjb(a+e|0,b+e|0,c,c);return}function Zib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Ojb(a,b,c,c);Ojb(a+8|0,b+8|0,c,c);d=c<<3;Ojb(a+d|0,b+d|0,c,c);e=d+8|0;Ojb(a+e|0,b+e|0,c,c);return}function _ib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Gjb(a,b,b,c,c);d=b+8|0;Gjb(a+8|0,d,d,c,c);d=c<<3;e=b+d|0;Gjb(a+d|0,e,e,c,c);e=d+8|0;d=b+e|0;Gjb(a+e|0,d,d,c,c);return}function $ib(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Njb(a,b,c,c);Njb(a+8|0,b+8|0,c,c);d=c<<3;Njb(a+d|0,b+d|0,c,c);e=d+8|0;Njb(a+e|0,b+e|0,c,c);return}function ajb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Gjb(a,b,b+1|0,c,c);Gjb(a+8|0,b+8|0,b+9|0,c,c);d=c<<3;Gjb(a+d|0,b+d|0,b+(d|1)|0,c,c);e=d+8|0;Gjb(a+e|0,b+e|0,b+(d+9)|0,c,c);return}function bjb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Mjb(a,b,c,c);Mjb(a+8|0,b+8|0,c,c);d=c<<3;Mjb(a+d|0,b+d|0,c,c);e=d+8|0;Mjb(a+e|0,b+e|0,c,c);return}function cjb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Ljb(a,b,c,c);Ljb(a+8|0,b+8|0,c,c);d=c<<3;Ljb(a+d|0,b+d|0,c,c);e=d+8|0;Ljb(a+e|0,b+e|0,c,c);return}function djb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Kjb(a,b,c,c);Kjb(a+8|0,b+8|0,c,c);d=c<<3;Kjb(a+d|0,b+d|0,c,c);e=d+8|0;Kjb(a+e|0,b+e|0,c,c);return}function ejb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Jjb(a,b,c,c);Jjb(a+8|0,b+8|0,c,c);d=c<<3;Jjb(a+d|0,b+d|0,c,c);e=d+8|0;Jjb(a+e|0,b+e|0,c,c);return}function fjb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Ijb(a,b,c,c);Ijb(a+8|0,b+8|0,c,c);d=c<<3;Ijb(a+d|0,b+d|0,c,c);e=d+8|0;Ijb(a+e|0,b+e|0,c,c);return}function gjb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Gjb(a,b,b+c|0,c,c);Gjb(a+8|0,b+8|0,b+(c+8)|0,c,c);d=c<<3;Gjb(a+d|0,b+d|0,b+(d+c)|0,c,c);e=d+8|0;Gjb(a+e|0,b+e|0,b+(e+c)|0,c,c);return}function hjb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Hjb(a,b,c,c);Hjb(a+8|0,b+8|0,c,c);d=c<<3;Hjb(a+d|0,b+d|0,c,c);e=d+8|0;Hjb(a+e|0,b+e|0,c,c);return}function ijb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=c+1|0;Gjb(a,b,b+d|0,c,c);Gjb(a+8|0,b+8|0,b+(c+9)|0,c,c);e=c<<3;Gjb(a+e|0,b+e|0,b+(d+e)|0,c,c);f=e+8|0;Gjb(a+f|0,b+f|0,b+(f+d)|0,c,c);return}function jjb(a,b,c){a=a|0;b=b|0;c=c|0;Rjb(a,b,c,c);return}function kjb(a,b,c){a=a|0;b=b|0;c=c|0;Qjb(a,b,c,c);return}function ljb(a,b,c){a=a|0;b=b|0;c=c|0;Pjb(a,b,c,c);return}function mjb(a,b,c){a=a|0;b=b|0;c=c|0;Ojb(a,b,c,c);return}function njb(a,b,c){a=a|0;b=b|0;c=c|0;Gjb(a,b,b,c,c);return}function ojb(a,b,c){a=a|0;b=b|0;c=c|0;Njb(a,b,c,c);return}function pjb(a,b,c){a=a|0;b=b|0;c=c|0;Gjb(a,b,b+1|0,c,c);return}function qjb(a,b,c){a=a|0;b=b|0;c=c|0;Mjb(a,b,c,c);return}function rjb(a,b,c){a=a|0;b=b|0;c=c|0;Ljb(a,b,c,c);return}function sjb(a,b,c){a=a|0;b=b|0;c=c|0;Kjb(a,b,c,c);return}function tjb(a,b,c){a=a|0;b=b|0;c=c|0;Jjb(a,b,c,c);return}function ujb(a,b,c){a=a|0;b=b|0;c=c|0;Ijb(a,b,c,c);return}function vjb(a,b,c){a=a|0;b=b|0;c=c|0;Gjb(a,b,b+c|0,c,c);return}function wjb(a,b,c){a=a|0;b=b|0;c=c|0;Hjb(a,b,c,c);return}function xjb(a,b,c){a=a|0;b=b|0;c=c|0;Gjb(a,b,b+(c+1)|0,c,c);return}function yjb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;if((f|0)==2){h=0;do{Ejb(a+(ba(h,b)|0)|0,1,c,d);h=h+1|0;}while((h|0)<16);return}else if((f|0)!=0){Fjb(a,1,c,d,e);Fjb(a+b|0,1,c,d,e);Fjb(a+(b<<1)|0,1,c,d,e);Fjb(a+(b*3|0)|0,1,c,d,e);Fjb(a+(b<<2)|0,1,c,d,e);Fjb(a+(b*5|0)|0,1,c,d,e);Fjb(a+(b*6|0)|0,1,c,d,e);Fjb(a+(b*7|0)|0,1,c,d,e)}if((g|0)==0){return}Fjb(a+(b<<3)|0,1,c,d,e);Fjb(a+(b*9|0)|0,1,c,d,e);Fjb(a+(b*10|0)|0,1,c,d,e);Fjb(a+(b*11|0)|0,1,c,d,e);Fjb(a+(b*12|0)|0,1,c,d,e);Fjb(a+(b*13|0)|0,1,c,d,e);Fjb(a+(b*14|0)|0,1,c,d,e);Fjb(a+(b*15|0)|0,1,c,d,e);return}function zjb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;if((f|0)==2){Ejb(a,b,c,d);Ejb(a+1|0,b,c,d);Ejb(a+2|0,b,c,d);Ejb(a+3|0,b,c,d);Ejb(a+4|0,b,c,d);Ejb(a+5|0,b,c,d);Ejb(a+6|0,b,c,d);Ejb(a+7|0,b,c,d);Ejb(a+8|0,b,c,d);Ejb(a+9|0,b,c,d);Ejb(a+10|0,b,c,d);Ejb(a+11|0,b,c,d);Ejb(a+12|0,b,c,d);Ejb(a+13|0,b,c,d);Ejb(a+14|0,b,c,d);Ejb(a+15|0,b,c,d);return}else if((f|0)!=0){Fjb(a,b,c,d,e);Fjb(a+1|0,b,c,d,e);Fjb(a+2|0,b,c,d,e);Fjb(a+3|0,b,c,d,e);Fjb(a+4|0,b,c,d,e);Fjb(a+5|0,b,c,d,e);Fjb(a+6|0,b,c,d,e);Fjb(a+7|0,b,c,d,e)}if((g|0)==0){return}Fjb(a+8|0,b,c,d,e);Fjb(a+9|0,b,c,d,e);Fjb(a+10|0,b,c,d,e);Fjb(a+11|0,b,c,d,e);Fjb(a+12|0,b,c,d,e);Fjb(a+13|0,b,c,d,e);Fjb(a+14|0,b,c,d,e);Fjb(a+15|0,b,c,d,e);return}function Ajb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((h|0)==2){Djb(b,1,e,f);Djb(b+c|0,1,e,f);Djb(b+(c<<1)|0,1,e,f);Djb(b+(c*3|0)|0,1,e,f);Djb(b+(c<<2)|0,1,e,f);Djb(b+(c*5|0)|0,1,e,f);Djb(b+(c*6|0)|0,1,e,f);Djb(b+(c*7|0)|0,1,e,f);return}else if((h|0)!=0){j=3}if((j|0)==3){j=-g|0;h=0;do{k=ba(h,c)|0;l=b+k|0;m=b+(k-1)|0;n=d[m]|0;o=d[l]|0;p=n-o|0;do{if((((p|0)>-1?p:-p|0)|0)<(e|0)){q=d[b+(k-2)|0]|0;r=q-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=d[b+(k+1)|0]|0;s=r-o|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=((o-n|0)*3|0)+4+q-r>>3;if((s|0)<(j|0)){t=j}else{t=(s|0)>(g|0)?g:s}s=t+n|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[m]=u;s=o-t|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[l]=v}}while(0);h=h+1|0;}while((h|0)<4)}if((i|0)==0){return}i=-g|0;h=4;do{v=ba(h,c)|0;t=b+v|0;u=b+(v-1)|0;j=d[u]|0;l=d[t]|0;o=j-l|0;do{if((((o|0)>-1?o:-o|0)|0)<(e|0)){m=d[b+(v-2)|0]|0;n=m-j|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=d[b+(v+1)|0]|0;k=n-l|0;if((((k|0)>-1?k:-k|0)|0)>=(f|0)){break}k=((l-j|0)*3|0)+4+m-n>>3;if((k|0)<(i|0)){w=i}else{w=(k|0)>(g|0)?g:k}k=w+j|0;if(k>>>0>255>>>0){x=-k>>31&255}else{x=k&255}a[u]=x;k=l-w|0;if(k>>>0>255>>>0){y=-k>>31&255}else{y=k&255}a[t]=y}}while(0);h=h+1|0;}while((h|0)<8);return}function Bjb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((h|0)==2){Djb(b,c,e,f);Djb(b+1|0,c,e,f);Djb(b+2|0,c,e,f);Djb(b+3|0,c,e,f);Djb(b+4|0,c,e,f);Djb(b+5|0,c,e,f);Djb(b+6|0,c,e,f);Djb(b+7|0,c,e,f);return}else if((h|0)!=0){j=3}if((j|0)==3){j=c*-2|0;h=-g|0;k=0;do{l=b+k|0;m=b+(k-c)|0;n=d[m]|0;o=d[l]|0;p=n-o|0;do{if((((p|0)>-1?p:-p|0)|0)<(e|0)){q=d[b+(k+j)|0]|0;r=q-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=d[b+(k+c)|0]|0;s=r-o|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=((o-n|0)*3|0)+4+q-r>>3;if((s|0)<(h|0)){t=h}else{t=(s|0)>(g|0)?g:s}s=t+n|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[m]=u;s=(d[l]|0)-t|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[l]=v}}while(0);k=k+1|0;}while((k|0)<4)}if((i|0)==0){return}i=c*-2|0;k=-g|0;v=4;do{t=b+v|0;u=b+(v-c)|0;h=d[u]|0;j=d[t]|0;l=h-j|0;do{if((((l|0)>-1?l:-l|0)|0)<(e|0)){m=d[b+(v+i)|0]|0;n=m-h|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=d[b+(v+c)|0]|0;o=n-j|0;if((((o|0)>-1?o:-o|0)|0)>=(f|0)){break}o=((j-h|0)*3|0)+4+m-n>>3;if((o|0)<(k|0)){w=k}else{w=(o|0)>(g|0)?g:o}o=w+h|0;if(o>>>0>255>>>0){x=-o>>31&255}else{x=o&255}a[u]=x;o=(d[t]|0)-w|0;if(o>>>0>255>>>0){y=-o>>31&255}else{y=o&255}a[t]=y}}while(0);v=v+1|0;}while((v|0)<8);return}function Cjb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=e;b[e>>1]=(b[e>>1]|0)+8;h=0;do{i=g+(h<<4)+2|0;j=b[i>>1]|0;k=g+(h<<4)+14|0;l=b[k>>1]|0;m=(j*3|0)-(l<<1)|0;n=g+(h<<4)+6|0;o=b[n>>1]|0;p=g+(h<<4)+10|0;q=b[p>>1]|0;r=(q<<1)+(o*3|0)|0;s=(q*-3|0)+(o<<1)|0;o=(l*3|0)+(j<<1)|0;j=(o+m+r<<1)+r|0;l=(m-r+s<<1)+m|0;q=(o-s-r<<1)+o|0;r=(m-o-s<<1)-s|0;s=g+(h<<4)+4|0;o=b[s>>1]|0;m=g+(h<<4)+12|0;t=b[m>>1]|0;u=(t*-10|0)+(o<<2)|0;v=(t<<2)+(o*10|0)|0;o=g+(h<<4)|0;t=b[o>>1]|0;w=g+(h<<4)+8|0;x=b[w>>1]|0;y=t-x<<3|4;z=x+t<<3|4;t=z+v|0;x=y+u|0;A=y-u|0;u=z-v|0;b[o>>1]=(t+j|0)>>>3;b[i>>1]=(x+l|0)>>>3;b[s>>1]=(A+q|0)>>>3;b[n>>1]=(u+r|0)>>>3;b[w>>1]=(u-r|0)>>>3;b[p>>1]=(A-q|0)>>>3;b[m>>1]=(x-l|0)>>>3;b[k>>1]=(t-j|0)>>>3;h=h+1|0;}while((h|0)<8);h=f<<1;g=f*3|0;j=f<<2;t=f*5|0;k=f*6|0;l=f*7|0;x=0;do{m=b[e+(x+8<<1)>>1]|0;q=b[e+(x+56<<1)>>1]|0;A=(m*3|0)-(q<<1)|0;p=b[e+(x+24<<1)>>1]|0;r=b[e+(x+40<<1)>>1]|0;u=(r<<1)+(p*3|0)|0;w=(r*-3|0)+(p<<1)|0;p=(q*3|0)+(m<<1)|0;m=(p+A+u<<1)+u|0;q=(A-u+w<<1)+A|0;r=(p-w-u<<1)+p|0;u=(A-p-w<<1)-w|0;w=b[e+(x+16<<1)>>1]|0;p=b[e+(x+48<<1)>>1]|0;A=(p*-10|0)+(w<<2)|0;n=(p<<2)+(w*10|0)|0;w=b[e+(x<<1)>>1]|0;p=b[e+(x+32<<1)>>1]|0;s=w-p<<3;i=p+w<<3;w=i+n|0;p=s+A|0;o=s-A|0;A=i-n|0;n=c+x|0;a[n]=a[1235032+((d[n]|1024)+(w+m>>7))|0]|0;n=c+(x+f)|0;a[n]=a[1235032+((d[n]|1024)+(p+q>>7))|0]|0;n=c+(x+h)|0;a[n]=a[1235032+((o+r>>7)+1024+(d[n]|0))|0]|0;n=c+(x+g)|0;a[n]=a[1235032+((A+u>>7)+1024+(d[n]|0))|0]|0;n=c+(x+j)|0;a[n]=a[1235032+((A-u>>7)+1024+(d[n]|0))|0]|0;n=c+(x+t)|0;a[n]=a[1235032+((o-r>>7)+1024+(d[n]|0))|0]|0;n=c+(x+k)|0;a[n]=a[1235032+((p-q>>7)+1024+(d[n]|0))|0]|0;n=c+(x+l)|0;a[n]=a[1235032+((w-m>>7)+1024+(d[n]|0))|0]|0;x=x+1|0;}while((x|0)<8);return}function Djb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b+(-c|0)|0;h=d[g]|0;i=d[b]|0;j=h-i|0;k=(j|0)>-1?j:-j|0;if((k|0)>=(e|0)){return}j=d[b+(c*-2|0)|0]|0;l=j-h|0;if((((l|0)>-1?l:-l|0)|0)>=(f|0)){return}l=b+c|0;m=(d[l]|0)-i|0;if((((m|0)>-1?m:-m|0)|0)>=(f|0)){return}m=h+2+i|0;n=(e>>2)+2|0;e=(d[b+(c*-3|0)|0]|0)-h|0;a[g]=(((((e|0)>-1?e:-e|0)|0)<(f|0)&(k|0)<(n|0)?j+h|0:j<<1)+m|0)>>>2;j=(d[b+(c<<1)|0]|0)-i|0;do{if((((j|0)>-1?j:-j|0)|0)<(f|0)){c=i-h|0;if((((c|0)>-1?c:-c|0)|0)>=(n|0)){break}a[b]=(m+i+(d[l]|0)|0)>>>2;return}}while(0);a[b]=(((d[l]|0)<<1)+m|0)>>>2;return}function Ejb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=b+(-c|0)|0;h=d[g]|0;i=d[b]|0;j=h-i|0;k=(j|0)>-1?j:-j|0;if((k|0)>=(e|0)){return}j=b+(c*-2|0)|0;l=d[j]|0;m=l-h|0;if((((m|0)>-1?m:-m|0)|0)>=(f|0)){return}m=b+c|0;n=(d[m]|0)-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){return}n=h+2+i|0;o=(e>>2)+2|0;e=(d[b+(c*-3|0)|0]|0)-h|0;if((((e|0)>-1?e:-e|0)|0)<(f|0)&(k|0)<(o|0)){a[g]=(n+h+l|0)>>>2;a[j]=(((d[j]|0)<<1)+n|0)>>>2}else{a[g]=((l<<1)+n|0)>>>2}l=(d[b+(c<<1)|0]|0)-i|0;do{if((((l|0)>-1?l:-l|0)|0)<(f|0)){c=i-h|0;if((((c|0)>-1?c:-c|0)|0)>=(o|0)){break}a[b]=(n+i+(d[m]|0)|0)>>>2;a[m]=(((d[m]|0)<<1)+n|0)>>>2;return}}while(0);a[b]=(((d[m]|0)<<1)+n|0)>>>2;return}function Fjb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=b+(-c|0)|0;i=d[h]|0;j=d[b]|0;k=i-j|0;if((((k|0)>-1?k:-k|0)|0)>=(e|0)){return}e=b+(c*-2|0)|0;k=d[e]|0;l=k-i|0;if((((l|0)>-1?l:-l|0)|0)>=(f|0)){return}l=b+c|0;m=d[l]|0;n=m-j|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){return}n=((j-i|0)*3|0)+4+k-m>>3;m=-g|0;if((n|0)<(m|0)){o=m}else{o=(n|0)>(g|0)?g:n}n=o+i|0;if(n>>>0>255>>>0){p=-n>>31&255}else{p=n&255}a[h]=p;p=j-o|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[b]=q;p=d[b+(c*-3|0)|0]|0;o=p-i|0;if((((o|0)>-1?o:-o|0)|0)<(f|0)){o=d[e]|0;i=p+4+(((d[h]|0)-o|0)*3|0)-(q&255)>>3;if((i|0)<(m|0)){r=m}else{r=(i|0)>(g|0)?g:i}i=r+o|0;if(i>>>0>255>>>0){s=-i>>31&255}else{s=i&255}a[e]=s}s=d[b+(c<<1)|0]|0;c=s-j|0;if((((c|0)>-1?c:-c|0)|0)>=(f|0)){return}f=d[l]|0;c=(d[h]|0)+4+((f-(d[b]|0)|0)*3|0)-s>>3;if((c|0)<(m|0)){t=m}else{t=(c|0)>(g|0)?g:c}c=f-t|0;if(c>>>0>255>>>0){u=-c>>31&255}else{u=c&255}a[l]=u;return}function Gjb(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;j=i;i=i+208|0;k=j|0;l=h<<1;m=0;n=k|0;o=e+(-l|0)|0;while(1){e=d[o]|0;p=d[o+1|0]|0;q=d[o+2|0]|0;b[n>>1]=((p+e&65535)*5&65535)-(q+(d[o-1|0]|0)&65535);r=d[o+3|0]|0;b[n+2>>1]=((q+p&65535)*5&65535)-(r+e&65535);e=d[o+4|0]|0;b[n+4>>1]=((r+q&65535)*5&65535)-(e+p&65535);p=d[o+5|0]|0;b[n+6>>1]=((e+r&65535)*5&65535)-(p+q&65535);q=d[o+6|0]|0;b[n+8>>1]=((p+e&65535)*5&65535)-(q+r&65535);r=d[o+7|0]|0;b[n+10>>1]=((q+p&65535)*5&65535)-(r+e&65535);e=d[o+8|0]|0;b[n+12>>1]=((r+q&65535)*5&65535)-(e+p&65535);b[n+14>>1]=((e+r&65535)*5&65535)-((d[o+9|0]|0)+q&65535);q=m+1|0;if((q|0)<13){m=q;n=n+16|0;o=o+h|0}else{break}}o=g<<1;n=g*3|0;m=h*3|0;q=g<<2;r=h<<2;e=g*5|0;p=h*5|0;s=g*6|0;t=h*6|0;u=g*7|0;v=h*7|0;w=0;x=k+32|0;k=f;f=c;while(1){c=b[x>>1]|0;y=b[x+16>>1]|0;z=b[x+32>>1]|0;A=b[x+48>>1]|0;B=b[x+64>>1]|0;C=b[x+80>>1]|0;D=b[x+96>>1]|0;E=b[x+112>>1]|0;F=b[x+128>>1]|0;G=b[x+144>>1]|0;H=y*5|0;a[f]=((d[f]|0)+1+(d[(64-(b[x-16>>1]|0)+(c*5|0)+H-z+(d[k]<<6)>>7)+1236056|0]|0)|0)>>>1;I=f+g|0;J=z*5|0;a[I]=((d[I]|0)+1+(d[(64-c+H+J-A+(d[k+h|0]<<6)>>7)+1236056|0]|0)|0)>>>1;H=f+o|0;c=A*5|0;a[H]=((d[H]|0)+1+(d[(64-y+J+c-B+(d[k+l|0]<<6)>>7)+1236056|0]|0)|0)>>>1;J=f+n|0;y=B*5|0;a[J]=((d[J]|0)+1+(d[(64-z+c+y-C+(d[k+m|0]<<6)>>7)+1236056|0]|0)|0)>>>1;c=f+q|0;z=C*5|0;a[c]=((d[c]|0)+1+(d[(64-A+y+z-D+(d[k+r|0]<<6)>>7)+1236056|0]|0)|0)>>>1;y=f+e|0;A=D*5|0;a[y]=((d[y]|0)+1+(d[(64-B+z+A-E+(d[k+p|0]<<6)>>7)+1236056|0]|0)|0)>>>1;z=f+s|0;B=E*5|0;a[z]=((d[z]|0)+1+(d[(64-C+A+B-F+(d[k+t|0]<<6)>>7)+1236056|0]|0)|0)>>>1;A=f+u|0;a[A]=((d[A]|0)+1+(d[(64-D+B+(F*5|0)-G+(d[k+v|0]<<6)>>7)+1236056|0]|0)|0)>>>1;G=w+1|0;if((G|0)<8){w=G;x=x+2|0;k=k+1|0;f=f+1|0}else{break}}i=j;return}function Hjb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n>>1]|0;q=b[n+16>>1]|0;r=b[n+32>>1]|0;s=b[n+48>>1]|0;t=b[n+64>>1]|0;u=b[n+80>>1]|0;v=b[n+96>>1]|0;w=b[n+112>>1]|0;x=b[n+128>>1]|0;y=b[n+144>>1]|0;z=b[n+160>>1]|0;a[j]=((d[j]|0)+1+(d[(((b[n-16>>1]|0)*-7|0)+512+(c*42|0)+(q*96|0)+(r*-2|0)-s>>10)+1236056|0]|0)|0)>>>1;A=j+f|0;a[A]=((d[A]|0)+1+(d[((c*-7|0)+512+(q*42|0)+(r*96|0)+(s*-2|0)-t>>10)+1236056|0]|0)|0)>>>1;c=j+g|0;a[c]=((d[c]|0)+1+(d[((q*-7|0)+512+(r*42|0)+(s*96|0)+(t*-2|0)-u>>10)+1236056|0]|0)|0)>>>1;q=j+m|0;a[q]=((d[q]|0)+1+(d[((r*-7|0)+512+(s*42|0)+(t*96|0)+(u*-2|0)-v>>10)+1236056|0]|0)|0)>>>1;r=j+l|0;a[r]=((d[r]|0)+1+(d[((s*-7|0)+512+(t*42|0)+(u*96|0)+(v*-2|0)-w>>10)+1236056|0]|0)|0)>>>1;s=j+k|0;a[s]=((d[s]|0)+1+(d[((t*-7|0)+512+(u*42|0)+(v*96|0)+(w*-2|0)-x>>10)+1236056|0]|0)|0)>>>1;t=j+o|0;a[t]=((d[t]|0)+1+(d[((u*-7|0)+512+(v*42|0)+(w*96|0)+(x*-2|0)-y>>10)+1236056|0]|0)|0)>>>1;u=j+p|0;a[u]=((d[u]|0)+1+(d[((v*-7|0)+512+(w*42|0)+(x*96|0)+(y*-2|0)-z>>10)+1236056|0]|0)|0)>>>1;z=e+1|0;if((z|0)<8){e=z;n=n+2|0;j=j+1|0}else{break}}i=h;return}function Ijb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=f*10|0;q=e<<1;r=e*3|0;s=e<<2;t=e*5|0;u=e*6|0;v=e*7|0;w=0;x=c;c=b;while(1){b=d[x]|0;y=d[x+f|0]|0;z=d[x+h|0]|0;A=d[x+i|0]|0;B=d[x+j|0]|0;C=d[x+k|0]|0;D=d[x+l|0]|0;E=d[x+m|0]|0;F=d[x+n|0]|0;G=d[x+o|0]|0;H=d[x+p|0]|0;a[c]=((d[c]|0)+1+(d[(((d[x+g|0]|0)*-7|0)+64+(b*42|0)+(y*96|0)+(z*-2|0)-A>>7)+1236056|0]|0)|0)>>>1;I=c+e|0;a[I]=((d[I]|0)+1+(d[((b*-7|0)+64+(y*42|0)+(z*96|0)+(A*-2|0)-B>>7)+1236056|0]|0)|0)>>>1;b=c+q|0;a[b]=((d[b]|0)+1+(d[((y*-7|0)+64+(z*42|0)+(A*96|0)+(B*-2|0)-C>>7)+1236056|0]|0)|0)>>>1;y=c+r|0;a[y]=((d[y]|0)+1+(d[((z*-7|0)+64+(A*42|0)+(B*96|0)+(C*-2|0)-D>>7)+1236056|0]|0)|0)>>>1;z=c+s|0;a[z]=((d[z]|0)+1+(d[((A*-7|0)+64+(B*42|0)+(C*96|0)+(D*-2|0)-E>>7)+1236056|0]|0)|0)>>>1;A=c+t|0;a[A]=((d[A]|0)+1+(d[((B*-7|0)+64+(C*42|0)+(D*96|0)+(E*-2|0)-F>>7)+1236056|0]|0)|0)>>>1;B=c+u|0;a[B]=((d[B]|0)+1+(d[((C*-7|0)+64+(D*42|0)+(E*96|0)+(F*-2|0)-G>>7)+1236056|0]|0)|0)>>>1;C=c+v|0;a[C]=((d[C]|0)+1+(d[((D*-7|0)+64+(E*42|0)+(F*96|0)+(G*-2|0)-H>>7)+1236056|0]|0)|0)>>>1;H=w+1|0;if((H|0)<8){w=H;x=x+1|0;c=c+1|0}else{break}}return}function Jjb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;p=d[m+3|0]|0;b[l>>1]=((((e*42&65535)+((d[m-1|0]|0)*-7&65535)&65535)+(n*96&65535)&65535)+(o*-2&65535)&65535)-p;q=d[m+4|0]|0;b[l+2>>1]=((((n*42&65535)+(e*-7&65535)&65535)+(o*96&65535)&65535)+(p*-2&65535)&65535)-q;e=d[m+5|0]|0;b[l+4>>1]=((((o*42&65535)+(n*-7&65535)&65535)+(p*96&65535)&65535)+(q*-2&65535)&65535)-e;n=d[m+6|0]|0;b[l+6>>1]=((((p*42&65535)+(o*-7&65535)&65535)+(q*96&65535)&65535)+(e*-2&65535)&65535)-n;o=d[m+7|0]|0;b[l+8>>1]=((((q*42&65535)+(p*-7&65535)&65535)+(e*96&65535)&65535)+(n*-2&65535)&65535)-o;p=d[m+8|0]|0;b[l+10>>1]=((((e*42&65535)+(q*-7&65535)&65535)+(n*96&65535)&65535)+(o*-2&65535)&65535)-p;q=d[m+9|0]|0;b[l+12>>1]=((((n*42&65535)+(e*-7&65535)&65535)+(o*96&65535)&65535)+(p*-2&65535)&65535)-q;b[l+14>>1]=((((o*42&65535)+(n*-7&65535)&65535)+(p*96&65535)&65535)+(q*-2&65535)&65535)-(d[m+10|0]|0);q=k+1|0;if((q|0)<13){k=q;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;q=f*6|0;p=f*7|0;n=0;o=j+32|0;j=c;while(1){c=b[o>>1]|0;e=b[o+16>>1]|0;r=b[o+32>>1]|0;s=b[o+48>>1]|0;t=b[o+64>>1]|0;u=b[o+80>>1]|0;v=b[o+96>>1]|0;w=b[o+112>>1]|0;x=b[o+128>>1]|0;y=b[o+144>>1]|0;z=e*5|0;a[j]=((d[j]|0)+1+(d[(512-(b[o-16>>1]|0)+(c*5|0)+z-r>>10)+1236056|0]|0)|0)>>>1;A=j+f|0;B=r*5|0;a[A]=((d[A]|0)+1+(d[(512-c+z+B-s>>10)+1236056|0]|0)|0)>>>1;z=j+g|0;c=s*5|0;a[z]=((d[z]|0)+1+(d[(512-e+B+c-t>>10)+1236056|0]|0)|0)>>>1;B=j+m|0;e=t*5|0;a[B]=((d[B]|0)+1+(d[(512-r+c+e-u>>10)+1236056|0]|0)|0)>>>1;c=j+l|0;r=u*5|0;a[c]=((d[c]|0)+1+(d[(512-s+e+r-v>>10)+1236056|0]|0)|0)>>>1;e=j+k|0;s=v*5|0;a[e]=((d[e]|0)+1+(d[(512-t+r+s-w>>10)+1236056|0]|0)|0)>>>1;r=j+q|0;t=w*5|0;a[r]=((d[r]|0)+1+(d[(512-u+s+t-x>>10)+1236056|0]|0)|0)>>>1;s=j+p|0;a[s]=((d[s]|0)+1+(d[(512-v+t+(x*5|0)-y>>10)+1236056|0]|0)|0)>>>1;y=n+1|0;if((y|0)<8){n=y;o=o+2|0;j=j+1|0}else{break}}i=h;return}function Kjb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n>>1]|0;q=b[n+16>>1]|0;r=b[n+32>>1]|0;s=b[n+48>>1]|0;t=b[n+64>>1]|0;u=b[n+80>>1]|0;v=b[n+96>>1]|0;w=b[n+112>>1]|0;x=b[n+128>>1]|0;y=b[n+144>>1]|0;z=q*5|0;a[j]=((d[j]|0)+1+(d[(32-(b[n-16>>1]|0)+(c*5|0)+z-r>>6)+1236056|0]|0)|0)>>>1;A=j+f|0;B=r*5|0;a[A]=((d[A]|0)+1+(d[(32-c+z+B-s>>6)+1236056|0]|0)|0)>>>1;z=j+g|0;c=s*5|0;a[z]=((d[z]|0)+1+(d[(32-q+B+c-t>>6)+1236056|0]|0)|0)>>>1;B=j+m|0;q=t*5|0;a[B]=((d[B]|0)+1+(d[(32-r+c+q-u>>6)+1236056|0]|0)|0)>>>1;c=j+l|0;r=u*5|0;a[c]=((d[c]|0)+1+(d[(32-s+q+r-v>>6)+1236056|0]|0)|0)>>>1;q=j+k|0;s=v*5|0;a[q]=((d[q]|0)+1+(d[(32-t+r+s-w>>6)+1236056|0]|0)|0)>>>1;r=j+o|0;t=w*5|0;a[r]=((d[r]|0)+1+(d[(32-u+s+t-x>>6)+1236056|0]|0)|0)>>>1;s=j+p|0;a[s]=((d[s]|0)+1+(d[(32-v+t+(x*5|0)-y>>6)+1236056|0]|0)|0)>>>1;y=e+1|0;if((y|0)<8){e=y;n=n+2|0;j=j+1|0}else{break}}i=h;return}function Ljb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m-1|0]|0;n=d[m]|0;o=d[m+1|0]|0;p=d[m+2|0]|0;b[l>>1]=((((e*-2&65535)-(d[m-2|0]|0)&65535)+(n*96&65535)&65535)+(o*42&65535)&65535)+(p*-7&65535);q=d[m+3|0]|0;b[l+2>>1]=((((n*-2&65535)-e&65535)+(o*96&65535)&65535)+(p*42&65535)&65535)+(q*-7&65535);e=d[m+4|0]|0;b[l+4>>1]=((((o*-2&65535)-n&65535)+(p*96&65535)&65535)+(q*42&65535)&65535)+(e*-7&65535);n=d[m+5|0]|0;b[l+6>>1]=((((p*-2&65535)-o&65535)+(q*96&65535)&65535)+(e*42&65535)&65535)+(n*-7&65535);o=d[m+6|0]|0;b[l+8>>1]=((((q*-2&65535)-p&65535)+(e*96&65535)&65535)+(n*42&65535)&65535)+(o*-7&65535);p=d[m+7|0]|0;b[l+10>>1]=((((e*-2&65535)-q&65535)+(n*96&65535)&65535)+(o*42&65535)&65535)+(p*-7&65535);q=d[m+8|0]|0;b[l+12>>1]=((((n*-2&65535)-e&65535)+(o*96&65535)&65535)+(p*42&65535)&65535)+(q*-7&65535);b[l+14>>1]=((((o*-2&65535)-n&65535)+(p*96&65535)&65535)+(q*42&65535)&65535)+((d[m+9|0]|0)*-7&65535);q=k+1|0;if((q|0)<13){k=q;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;q=f*6|0;p=f*7|0;n=0;o=j+32|0;j=c;while(1){c=b[o>>1]|0;e=b[o+16>>1]|0;r=b[o+32>>1]|0;s=b[o+48>>1]|0;t=b[o+64>>1]|0;u=b[o+80>>1]|0;v=b[o+96>>1]|0;w=b[o+112>>1]|0;x=b[o+128>>1]|0;y=b[o+144>>1]|0;z=e*5|0;a[j]=((d[j]|0)+1+(d[(512-(b[o-16>>1]|0)+(c*5|0)+z-r>>10)+1236056|0]|0)|0)>>>1;A=j+f|0;B=r*5|0;a[A]=((d[A]|0)+1+(d[(512-c+z+B-s>>10)+1236056|0]|0)|0)>>>1;z=j+g|0;c=s*5|0;a[z]=((d[z]|0)+1+(d[(512-e+B+c-t>>10)+1236056|0]|0)|0)>>>1;B=j+m|0;e=t*5|0;a[B]=((d[B]|0)+1+(d[(512-r+c+e-u>>10)+1236056|0]|0)|0)>>>1;c=j+l|0;r=u*5|0;a[c]=((d[c]|0)+1+(d[(512-s+e+r-v>>10)+1236056|0]|0)|0)>>>1;e=j+k|0;s=v*5|0;a[e]=((d[e]|0)+1+(d[(512-t+r+s-w>>10)+1236056|0]|0)|0)>>>1;r=j+q|0;t=w*5|0;a[r]=((d[r]|0)+1+(d[(512-u+s+t-x>>10)+1236056|0]|0)|0)>>>1;s=j+p|0;a[s]=((d[s]|0)+1+(d[(512-v+t+(x*5|0)-y>>10)+1236056|0]|0)|0)>>>1;y=n+1|0;if((y|0)<8){n=y;o=o+2|0;j=j+1|0}else{break}}i=h;return}function Mjb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=e<<1;q=e*3|0;r=e<<2;s=e*5|0;t=e*6|0;u=e*7|0;v=0;w=c;c=b;while(1){b=d[w]|0;x=d[w+f|0]|0;y=d[w+h|0]|0;z=d[w+i|0]|0;A=d[w+j|0]|0;B=d[w+k|0]|0;C=d[w+l|0]|0;D=d[w+m|0]|0;E=d[w+n|0]|0;F=d[w+o|0]|0;G=x*5|0;a[c]=((d[c]|0)+1+(d[(4-(d[w+g|0]|0)+(b*5|0)+G-y>>3)+1236056|0]|0)|0)>>>1;H=c+e|0;I=y*5|0;a[H]=((d[H]|0)+1+(d[(4-b+G+I-z>>3)+1236056|0]|0)|0)>>>1;G=c+p|0;b=z*5|0;a[G]=((d[G]|0)+1+(d[(4-x+I+b-A>>3)+1236056|0]|0)|0)>>>1;I=c+q|0;x=A*5|0;a[I]=((d[I]|0)+1+(d[(4-y+b+x-B>>3)+1236056|0]|0)|0)>>>1;b=c+r|0;y=B*5|0;a[b]=((d[b]|0)+1+(d[(4-z+x+y-C>>3)+1236056|0]|0)|0)>>>1;x=c+s|0;z=C*5|0;a[x]=((d[x]|0)+1+(d[(4-A+y+z-D>>3)+1236056|0]|0)|0)>>>1;y=c+t|0;A=D*5|0;a[y]=((d[y]|0)+1+(d[(4-B+z+A-E>>3)+1236056|0]|0)|0)>>>1;z=c+u|0;a[z]=((d[z]|0)+1+(d[(4-C+A+(E*5|0)-F>>3)+1236056|0]|0)|0)>>>1;F=v+1|0;if((F|0)<8){v=F;w=w+1|0;c=c+1|0}else{break}}return}function Njb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n-16>>1]|0;q=b[n>>1]|0;r=b[n+16>>1]|0;s=b[n+32>>1]|0;t=b[n+48>>1]|0;u=b[n+64>>1]|0;v=b[n+80>>1]|0;w=b[n+96>>1]|0;x=b[n+112>>1]|0;y=b[n+128>>1]|0;z=b[n+144>>1]|0;a[j]=((d[j]|0)+1+(d[(512-(b[n-32>>1]|0)+(c*-2|0)+(q*96|0)+(r*42|0)+(s*-7|0)>>10)+1236056|0]|0)|0)>>>1;A=j+f|0;a[A]=((d[A]|0)+1+(d[(512-c+(q*-2|0)+(r*96|0)+(s*42|0)+(t*-7|0)>>10)+1236056|0]|0)|0)>>>1;c=j+g|0;a[c]=((d[c]|0)+1+(d[(512-q+(r*-2|0)+(s*96|0)+(t*42|0)+(u*-7|0)>>10)+1236056|0]|0)|0)>>>1;q=j+m|0;a[q]=((d[q]|0)+1+(d[(512-r+(s*-2|0)+(t*96|0)+(u*42|0)+(v*-7|0)>>10)+1236056|0]|0)|0)>>>1;r=j+l|0;a[r]=((d[r]|0)+1+(d[(512-s+(t*-2|0)+(u*96|0)+(v*42|0)+(w*-7|0)>>10)+1236056|0]|0)|0)>>>1;s=j+k|0;a[s]=((d[s]|0)+1+(d[(512-t+(u*-2|0)+(v*96|0)+(w*42|0)+(x*-7|0)>>10)+1236056|0]|0)|0)>>>1;t=j+o|0;a[t]=((d[t]|0)+1+(d[(512-u+(v*-2|0)+(w*96|0)+(x*42|0)+(y*-7|0)>>10)+1236056|0]|0)|0)>>>1;u=j+p|0;a[u]=((d[u]|0)+1+(d[(512-v+(w*-2|0)+(x*96|0)+(y*42|0)+(z*-7|0)>>10)+1236056|0]|0)|0)>>>1;z=e+1|0;if((z|0)<8){e=z;n=n+2|0;j=j+1|0}else{break}}i=h;return}function Ojb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=f*-2|0;h=-f|0;i=f<<1;j=f*3|0;k=f<<2;l=f*5|0;m=f*6|0;n=f*7|0;o=f<<3;p=f*9|0;q=e<<1;r=e*3|0;s=e<<2;t=e*5|0;u=e*6|0;v=e*7|0;w=0;x=c;c=b;while(1){b=d[x+h|0]|0;y=d[x]|0;z=d[x+f|0]|0;A=d[x+i|0]|0;B=d[x+j|0]|0;C=d[x+k|0]|0;D=d[x+l|0]|0;E=d[x+m|0]|0;F=d[x+n|0]|0;G=d[x+o|0]|0;H=d[x+p|0]|0;a[c]=((d[c]|0)+1+(d[(64-(d[x+g|0]|0)+(b*-2|0)+(y*96|0)+(z*42|0)+(A*-7|0)>>7)+1236056|0]|0)|0)>>>1;I=c+e|0;a[I]=((d[I]|0)+1+(d[(64-b+(y*-2|0)+(z*96|0)+(A*42|0)+(B*-7|0)>>7)+1236056|0]|0)|0)>>>1;b=c+q|0;a[b]=((d[b]|0)+1+(d[(64-y+(z*-2|0)+(A*96|0)+(B*42|0)+(C*-7|0)>>7)+1236056|0]|0)|0)>>>1;y=c+r|0;a[y]=((d[y]|0)+1+(d[(64-z+(A*-2|0)+(B*96|0)+(C*42|0)+(D*-7|0)>>7)+1236056|0]|0)|0)>>>1;z=c+s|0;a[z]=((d[z]|0)+1+(d[(64-A+(B*-2|0)+(C*96|0)+(D*42|0)+(E*-7|0)>>7)+1236056|0]|0)|0)>>>1;A=c+t|0;a[A]=((d[A]|0)+1+(d[(64-B+(C*-2|0)+(D*96|0)+(E*42|0)+(F*-7|0)>>7)+1236056|0]|0)|0)>>>1;B=c+u|0;a[B]=((d[B]|0)+1+(d[(64-C+(D*-2|0)+(E*96|0)+(F*42|0)+(G*-7|0)>>7)+1236056|0]|0)|0)>>>1;C=c+v|0;a[C]=((d[C]|0)+1+(d[(64-D+(E*-2|0)+(F*96|0)+(G*42|0)+(H*-7|0)>>7)+1236056|0]|0)|0)>>>1;H=w+1|0;if((H|0)<8){w=H;x=x+1|0;c=c+1|0}else{break}}return}function Pjb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c;c=b;b=0;while(1){h=g+1|0;i=g+2|0;j=g+3|0;a[c]=((d[c]|0)+1+(d[(((d[g-1|0]|0)*-7|0)+64+((d[g]|0)*42|0)+((d[h]|0)*96|0)+((d[i]|0)*-2|0)-(d[j]|0)>>7)+1236056|0]|0)|0)>>>1;k=c+1|0;l=g+4|0;a[k]=((d[k]|0)+1+(d[(((d[g]|0)*-7|0)+64+((d[h]|0)*42|0)+((d[i]|0)*96|0)+((d[j]|0)*-2|0)-(d[l]|0)>>7)+1236056|0]|0)|0)>>>1;k=c+2|0;m=g+5|0;a[k]=((d[k]|0)+1+(d[(((d[h]|0)*-7|0)+64+((d[i]|0)*42|0)+((d[j]|0)*96|0)+((d[l]|0)*-2|0)-(d[m]|0)>>7)+1236056|0]|0)|0)>>>1;h=c+3|0;k=g+6|0;a[h]=((d[h]|0)+1+(d[(((d[i]|0)*-7|0)+64+((d[j]|0)*42|0)+((d[l]|0)*96|0)+((d[m]|0)*-2|0)-(d[k]|0)>>7)+1236056|0]|0)|0)>>>1;i=c+4|0;h=g+7|0;a[i]=((d[i]|0)+1+(d[(((d[j]|0)*-7|0)+64+((d[l]|0)*42|0)+((d[m]|0)*96|0)+((d[k]|0)*-2|0)-(d[h]|0)>>7)+1236056|0]|0)|0)>>>1;j=c+5|0;i=g+8|0;a[j]=((d[j]|0)+1+(d[(((d[l]|0)*-7|0)+64+((d[m]|0)*42|0)+((d[k]|0)*96|0)+((d[h]|0)*-2|0)-(d[i]|0)>>7)+1236056|0]|0)|0)>>>1;l=c+6|0;j=g+9|0;a[l]=((d[l]|0)+1+(d[(((d[m]|0)*-7|0)+64+((d[k]|0)*42|0)+((d[h]|0)*96|0)+((d[i]|0)*-2|0)-(d[j]|0)>>7)+1236056|0]|0)|0)>>>1;m=c+7|0;a[m]=((d[m]|0)+1+(d[(((d[k]|0)*-7|0)+64+((d[h]|0)*42|0)+((d[i]|0)*96|0)+((d[j]|0)*-2|0)-(d[g+10|0]|0)>>7)+1236056|0]|0)|0)>>>1;j=b+1|0;if((j|0)<8){g=g+f|0;c=c+e|0;b=j}else{break}}return}function Qjb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c;c=b;b=0;while(1){h=g+1|0;i=g+2|0;j=g+3|0;a[c]=((d[c]|0)+1+(d[(4-(d[g-1|0]|0)-(d[i]|0)+(((d[h]|0)+(d[g]|0)|0)*5|0)>>3)+1236056|0]|0)|0)>>>1;k=c+1|0;l=g+4|0;a[k]=((d[k]|0)+1+(d[(4-(d[g]|0)-(d[j]|0)+(((d[i]|0)+(d[h]|0)|0)*5|0)>>3)+1236056|0]|0)|0)>>>1;k=c+2|0;m=g+5|0;a[k]=((d[k]|0)+1+(d[(4-(d[h]|0)-(d[l]|0)+(((d[j]|0)+(d[i]|0)|0)*5|0)>>3)+1236056|0]|0)|0)>>>1;h=c+3|0;k=g+6|0;a[h]=((d[h]|0)+1+(d[(4-(d[i]|0)-(d[m]|0)+(((d[l]|0)+(d[j]|0)|0)*5|0)>>3)+1236056|0]|0)|0)>>>1;i=c+4|0;h=g+7|0;a[i]=((d[i]|0)+1+(d[(4-(d[j]|0)-(d[k]|0)+(((d[m]|0)+(d[l]|0)|0)*5|0)>>3)+1236056|0]|0)|0)>>>1;j=c+5|0;i=g+8|0;a[j]=((d[j]|0)+1+(d[(4-(d[l]|0)-(d[h]|0)+(((d[k]|0)+(d[m]|0)|0)*5|0)>>3)+1236056|0]|0)|0)>>>1;l=c+6|0;a[l]=((d[l]|0)+1+(d[(4-(d[m]|0)-(d[i]|0)+(((d[h]|0)+(d[k]|0)|0)*5|0)>>3)+1236056|0]|0)|0)>>>1;m=c+7|0;a[m]=((d[m]|0)+1+(d[(4-(d[k]|0)-(d[g+9|0]|0)+(((d[i]|0)+(d[h]|0)|0)*5|0)>>3)+1236056|0]|0)|0)>>>1;h=b+1|0;if((h|0)<8){g=g+f|0;c=c+e|0;b=h}else{break}}return}function Rjb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c;c=b;b=0;while(1){h=g-1|0;i=g+1|0;j=g+2|0;k=g+3|0;a[c]=((d[c]|0)+1+(d[(64-(d[g-2|0]|0)+((d[h]|0)*-2|0)+((d[g]|0)*96|0)+((d[i]|0)*42|0)+((d[j]|0)*-7|0)>>7)+1236056|0]|0)|0)>>>1;l=c+1|0;m=g+4|0;a[l]=((d[l]|0)+1+(d[(64-(d[h]|0)+((d[g]|0)*-2|0)+((d[i]|0)*96|0)+((d[j]|0)*42|0)+((d[k]|0)*-7|0)>>7)+1236056|0]|0)|0)>>>1;h=c+2|0;l=g+5|0;a[h]=((d[h]|0)+1+(d[(64-(d[g]|0)+((d[i]|0)*-2|0)+((d[j]|0)*96|0)+((d[k]|0)*42|0)+((d[m]|0)*-7|0)>>7)+1236056|0]|0)|0)>>>1;h=c+3|0;n=g+6|0;a[h]=((d[h]|0)+1+(d[(64-(d[i]|0)+((d[j]|0)*-2|0)+((d[k]|0)*96|0)+((d[m]|0)*42|0)+((d[l]|0)*-7|0)>>7)+1236056|0]|0)|0)>>>1;i=c+4|0;h=g+7|0;a[i]=((d[i]|0)+1+(d[(64-(d[j]|0)+((d[k]|0)*-2|0)+((d[m]|0)*96|0)+((d[l]|0)*42|0)+((d[n]|0)*-7|0)>>7)+1236056|0]|0)|0)>>>1;j=c+5|0;i=g+8|0;a[j]=((d[j]|0)+1+(d[(64-(d[k]|0)+((d[m]|0)*-2|0)+((d[l]|0)*96|0)+((d[n]|0)*42|0)+((d[h]|0)*-7|0)>>7)+1236056|0]|0)|0)>>>1;k=c+6|0;a[k]=((d[k]|0)+1+(d[(64-(d[m]|0)+((d[l]|0)*-2|0)+((d[n]|0)*96|0)+((d[h]|0)*42|0)+((d[i]|0)*-7|0)>>7)+1236056|0]|0)|0)>>>1;m=c+7|0;a[m]=((d[m]|0)+1+(d[(64-(d[l]|0)+((d[n]|0)*-2|0)+((d[h]|0)*96|0)+((d[i]|0)*42|0)+((d[g+9|0]|0)*-7|0)>>7)+1236056|0]|0)|0)>>>1;i=b+1|0;if((i|0)<8){g=g+f|0;c=c+e|0;b=i}else{break}}return}function Sjb(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;j=i;i=i+208|0;k=j|0;l=h<<1;m=0;n=k|0;o=e+(-l|0)|0;while(1){e=d[o]|0;p=d[o+1|0]|0;q=d[o+2|0]|0;b[n>>1]=((p+e&65535)*5&65535)-(q+(d[o-1|0]|0)&65535);r=d[o+3|0]|0;b[n+2>>1]=((q+p&65535)*5&65535)-(r+e&65535);e=d[o+4|0]|0;b[n+4>>1]=((r+q&65535)*5&65535)-(e+p&65535);p=d[o+5|0]|0;b[n+6>>1]=((e+r&65535)*5&65535)-(p+q&65535);q=d[o+6|0]|0;b[n+8>>1]=((p+e&65535)*5&65535)-(q+r&65535);r=d[o+7|0]|0;b[n+10>>1]=((q+p&65535)*5&65535)-(r+e&65535);e=d[o+8|0]|0;b[n+12>>1]=((r+q&65535)*5&65535)-(e+p&65535);b[n+14>>1]=((e+r&65535)*5&65535)-((d[o+9|0]|0)+q&65535);q=m+1|0;if((q|0)<13){m=q;n=n+16|0;o=o+h|0}else{break}}o=g<<1;n=h*3|0;m=g*3|0;q=h<<2;r=g<<2;e=h*5|0;p=g*5|0;s=h*6|0;t=g*6|0;u=h*7|0;v=g*7|0;w=0;x=k+32|0;k=f;f=c;while(1){c=b[x>>1]|0;y=b[x+16>>1]|0;z=b[x+32>>1]|0;A=b[x+48>>1]|0;B=b[x+64>>1]|0;C=b[x+80>>1]|0;D=b[x+96>>1]|0;E=b[x+112>>1]|0;F=b[x+128>>1]|0;G=b[x+144>>1]|0;H=y*5|0;a[f]=a[(64-(b[x-16>>1]|0)+(c*5|0)+H-z+(d[k]<<6)>>7)+1236056|0]|0;I=z*5|0;a[f+g|0]=a[(64-c+H+I-A+(d[k+h|0]<<6)>>7)+1236056|0]|0;H=A*5|0;a[f+o|0]=a[(64-y+I+H-B+(d[k+l|0]<<6)>>7)+1236056|0]|0;I=B*5|0;a[f+m|0]=a[(64-z+H+I-C+(d[k+n|0]<<6)>>7)+1236056|0]|0;H=C*5|0;a[f+r|0]=a[(64-A+I+H-D+(d[k+q|0]<<6)>>7)+1236056|0]|0;I=D*5|0;a[f+p|0]=a[(64-B+H+I-E+(d[k+e|0]<<6)>>7)+1236056|0]|0;H=E*5|0;a[f+t|0]=a[(64-C+I+H-F+(d[k+s|0]<<6)>>7)+1236056|0]|0;a[f+v|0]=a[(64-D+H+(F*5|0)-G+(d[k+u|0]<<6)>>7)+1236056|0]|0;G=w+1|0;if((G|0)<8){w=G;x=x+2|0;k=k+1|0;f=f+1|0}else{break}}i=j;return}function Tjb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n>>1]|0;q=b[n+16>>1]|0;r=b[n+32>>1]|0;s=b[n+48>>1]|0;t=b[n+64>>1]|0;u=b[n+80>>1]|0;v=b[n+96>>1]|0;w=b[n+112>>1]|0;x=b[n+128>>1]|0;y=b[n+144>>1]|0;z=b[n+160>>1]|0;a[j]=a[(((b[n-16>>1]|0)*-7|0)+512+(c*42|0)+(q*96|0)+(r*-2|0)-s>>10)+1236056|0]|0;a[j+f|0]=a[((c*-7|0)+512+(q*42|0)+(r*96|0)+(s*-2|0)-t>>10)+1236056|0]|0;a[j+g|0]=a[((q*-7|0)+512+(r*42|0)+(s*96|0)+(t*-2|0)-u>>10)+1236056|0]|0;a[j+m|0]=a[((r*-7|0)+512+(s*42|0)+(t*96|0)+(u*-2|0)-v>>10)+1236056|0]|0;a[j+l|0]=a[((s*-7|0)+512+(t*42|0)+(u*96|0)+(v*-2|0)-w>>10)+1236056|0]|0;a[j+k|0]=a[((t*-7|0)+512+(u*42|0)+(v*96|0)+(w*-2|0)-x>>10)+1236056|0]|0;a[j+o|0]=a[((u*-7|0)+512+(v*42|0)+(w*96|0)+(x*-2|0)-y>>10)+1236056|0]|0;a[j+p|0]=a[((v*-7|0)+512+(w*42|0)+(x*96|0)+(y*-2|0)-z>>10)+1236056|0]|0;z=e+1|0;if((z|0)<8){e=z;n=n+2|0;j=j+1|0}else{break}}i=h;return}function Ujb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=f*10|0;q=e<<1;r=e*3|0;s=e<<2;t=e*5|0;u=e*6|0;v=e*7|0;w=0;x=c;c=b;while(1){b=d[x]|0;y=d[x+f|0]|0;z=d[x+h|0]|0;A=d[x+i|0]|0;B=d[x+j|0]|0;C=d[x+k|0]|0;D=d[x+l|0]|0;E=d[x+m|0]|0;F=d[x+n|0]|0;G=d[x+o|0]|0;H=d[x+p|0]|0;a[c]=a[(((d[x+g|0]|0)*-7|0)+64+(b*42|0)+(y*96|0)+(z*-2|0)-A>>7)+1236056|0]|0;a[c+e|0]=a[((b*-7|0)+64+(y*42|0)+(z*96|0)+(A*-2|0)-B>>7)+1236056|0]|0;a[c+q|0]=a[((y*-7|0)+64+(z*42|0)+(A*96|0)+(B*-2|0)-C>>7)+1236056|0]|0;a[c+r|0]=a[((z*-7|0)+64+(A*42|0)+(B*96|0)+(C*-2|0)-D>>7)+1236056|0]|0;a[c+s|0]=a[((A*-7|0)+64+(B*42|0)+(C*96|0)+(D*-2|0)-E>>7)+1236056|0]|0;a[c+t|0]=a[((B*-7|0)+64+(C*42|0)+(D*96|0)+(E*-2|0)-F>>7)+1236056|0]|0;a[c+u|0]=a[((C*-7|0)+64+(D*42|0)+(E*96|0)+(F*-2|0)-G>>7)+1236056|0]|0;a[c+v|0]=a[((D*-7|0)+64+(E*42|0)+(F*96|0)+(G*-2|0)-H>>7)+1236056|0]|0;H=w+1|0;if((H|0)<8){w=H;x=x+1|0;c=c+1|0}else{break}}return}function Vjb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;p=d[m+3|0]|0;b[l>>1]=((((e*42&65535)+((d[m-1|0]|0)*-7&65535)&65535)+(n*96&65535)&65535)+(o*-2&65535)&65535)-p;q=d[m+4|0]|0;b[l+2>>1]=((((n*42&65535)+(e*-7&65535)&65535)+(o*96&65535)&65535)+(p*-2&65535)&65535)-q;e=d[m+5|0]|0;b[l+4>>1]=((((o*42&65535)+(n*-7&65535)&65535)+(p*96&65535)&65535)+(q*-2&65535)&65535)-e;n=d[m+6|0]|0;b[l+6>>1]=((((p*42&65535)+(o*-7&65535)&65535)+(q*96&65535)&65535)+(e*-2&65535)&65535)-n;o=d[m+7|0]|0;b[l+8>>1]=((((q*42&65535)+(p*-7&65535)&65535)+(e*96&65535)&65535)+(n*-2&65535)&65535)-o;p=d[m+8|0]|0;b[l+10>>1]=((((e*42&65535)+(q*-7&65535)&65535)+(n*96&65535)&65535)+(o*-2&65535)&65535)-p;q=d[m+9|0]|0;b[l+12>>1]=((((n*42&65535)+(e*-7&65535)&65535)+(o*96&65535)&65535)+(p*-2&65535)&65535)-q;b[l+14>>1]=((((o*42&65535)+(n*-7&65535)&65535)+(p*96&65535)&65535)+(q*-2&65535)&65535)-(d[m+10|0]|0);q=k+1|0;if((q|0)<13){k=q;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;q=f*6|0;p=f*7|0;n=0;o=j+32|0;j=c;while(1){c=b[o>>1]|0;e=b[o+16>>1]|0;r=b[o+32>>1]|0;s=b[o+48>>1]|0;t=b[o+64>>1]|0;u=b[o+80>>1]|0;v=b[o+96>>1]|0;w=b[o+112>>1]|0;x=b[o+128>>1]|0;y=b[o+144>>1]|0;z=e*5|0;a[j]=a[(512-(b[o-16>>1]|0)+(c*5|0)+z-r>>10)+1236056|0]|0;A=r*5|0;a[j+f|0]=a[(512-c+z+A-s>>10)+1236056|0]|0;z=s*5|0;a[j+g|0]=a[(512-e+A+z-t>>10)+1236056|0]|0;A=t*5|0;a[j+m|0]=a[(512-r+z+A-u>>10)+1236056|0]|0;z=u*5|0;a[j+l|0]=a[(512-s+A+z-v>>10)+1236056|0]|0;A=v*5|0;a[j+k|0]=a[(512-t+z+A-w>>10)+1236056|0]|0;z=w*5|0;a[j+q|0]=a[(512-u+A+z-x>>10)+1236056|0]|0;a[j+p|0]=a[(512-v+z+(x*5|0)-y>>10)+1236056|0]|0;y=n+1|0;if((y|0)<8){n=y;o=o+2|0;j=j+1|0}else{break}}i=h;return}function Wjb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n>>1]|0;q=b[n+16>>1]|0;r=b[n+32>>1]|0;s=b[n+48>>1]|0;t=b[n+64>>1]|0;u=b[n+80>>1]|0;v=b[n+96>>1]|0;w=b[n+112>>1]|0;x=b[n+128>>1]|0;y=b[n+144>>1]|0;z=q*5|0;a[j]=a[(32-(b[n-16>>1]|0)+(c*5|0)+z-r>>6)+1236056|0]|0;A=r*5|0;a[j+f|0]=a[(32-c+z+A-s>>6)+1236056|0]|0;z=s*5|0;a[j+g|0]=a[(32-q+A+z-t>>6)+1236056|0]|0;A=t*5|0;a[j+m|0]=a[(32-r+z+A-u>>6)+1236056|0]|0;z=u*5|0;a[j+l|0]=a[(32-s+A+z-v>>6)+1236056|0]|0;A=v*5|0;a[j+k|0]=a[(32-t+z+A-w>>6)+1236056|0]|0;z=w*5|0;a[j+o|0]=a[(32-u+A+z-x>>6)+1236056|0]|0;a[j+p|0]=a[(32-v+z+(x*5|0)-y>>6)+1236056|0]|0;y=e+1|0;if((y|0)<8){e=y;n=n+2|0;j=j+1|0}else{break}}i=h;return}function Xjb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m-1|0]|0;n=d[m]|0;o=d[m+1|0]|0;p=d[m+2|0]|0;b[l>>1]=((((e*-2&65535)-(d[m-2|0]|0)&65535)+(n*96&65535)&65535)+(o*42&65535)&65535)+(p*-7&65535);q=d[m+3|0]|0;b[l+2>>1]=((((n*-2&65535)-e&65535)+(o*96&65535)&65535)+(p*42&65535)&65535)+(q*-7&65535);e=d[m+4|0]|0;b[l+4>>1]=((((o*-2&65535)-n&65535)+(p*96&65535)&65535)+(q*42&65535)&65535)+(e*-7&65535);n=d[m+5|0]|0;b[l+6>>1]=((((p*-2&65535)-o&65535)+(q*96&65535)&65535)+(e*42&65535)&65535)+(n*-7&65535);o=d[m+6|0]|0;b[l+8>>1]=((((q*-2&65535)-p&65535)+(e*96&65535)&65535)+(n*42&65535)&65535)+(o*-7&65535);p=d[m+7|0]|0;b[l+10>>1]=((((e*-2&65535)-q&65535)+(n*96&65535)&65535)+(o*42&65535)&65535)+(p*-7&65535);q=d[m+8|0]|0;b[l+12>>1]=((((n*-2&65535)-e&65535)+(o*96&65535)&65535)+(p*42&65535)&65535)+(q*-7&65535);b[l+14>>1]=((((o*-2&65535)-n&65535)+(p*96&65535)&65535)+(q*42&65535)&65535)+((d[m+9|0]|0)*-7&65535);q=k+1|0;if((q|0)<13){k=q;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;q=f*6|0;p=f*7|0;n=0;o=j+32|0;j=c;while(1){c=b[o>>1]|0;e=b[o+16>>1]|0;r=b[o+32>>1]|0;s=b[o+48>>1]|0;t=b[o+64>>1]|0;u=b[o+80>>1]|0;v=b[o+96>>1]|0;w=b[o+112>>1]|0;x=b[o+128>>1]|0;y=b[o+144>>1]|0;z=e*5|0;a[j]=a[(512-(b[o-16>>1]|0)+(c*5|0)+z-r>>10)+1236056|0]|0;A=r*5|0;a[j+f|0]=a[(512-c+z+A-s>>10)+1236056|0]|0;z=s*5|0;a[j+g|0]=a[(512-e+A+z-t>>10)+1236056|0]|0;A=t*5|0;a[j+m|0]=a[(512-r+z+A-u>>10)+1236056|0]|0;z=u*5|0;a[j+l|0]=a[(512-s+A+z-v>>10)+1236056|0]|0;A=v*5|0;a[j+k|0]=a[(512-t+z+A-w>>10)+1236056|0]|0;z=w*5|0;a[j+q|0]=a[(512-u+A+z-x>>10)+1236056|0]|0;a[j+p|0]=a[(512-v+z+(x*5|0)-y>>10)+1236056|0]|0;y=n+1|0;if((y|0)<8){n=y;o=o+2|0;j=j+1|0}else{break}}i=h;return}function Yjb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=e<<1;q=e*3|0;r=e<<2;s=e*5|0;t=e*6|0;u=e*7|0;v=0;w=c;c=b;while(1){b=d[w]|0;x=d[w+f|0]|0;y=d[w+h|0]|0;z=d[w+i|0]|0;A=d[w+j|0]|0;B=d[w+k|0]|0;C=d[w+l|0]|0;D=d[w+m|0]|0;E=d[w+n|0]|0;F=d[w+o|0]|0;G=x*5|0;a[c]=a[(4-(d[w+g|0]|0)+(b*5|0)+G-y>>3)+1236056|0]|0;H=y*5|0;a[c+e|0]=a[(4-b+G+H-z>>3)+1236056|0]|0;G=z*5|0;a[c+p|0]=a[(4-x+H+G-A>>3)+1236056|0]|0;H=A*5|0;a[c+q|0]=a[(4-y+G+H-B>>3)+1236056|0]|0;G=B*5|0;a[c+r|0]=a[(4-z+H+G-C>>3)+1236056|0]|0;H=C*5|0;a[c+s|0]=a[(4-A+G+H-D>>3)+1236056|0]|0;G=D*5|0;a[c+t|0]=a[(4-B+H+G-E>>3)+1236056|0]|0;a[c+u|0]=a[(4-C+G+(E*5|0)-F>>3)+1236056|0]|0;F=v+1|0;if((F|0)<8){v=F;w=w+1|0;c=c+1|0}else{break}}return}function Zjb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n-16>>1]|0;q=b[n>>1]|0;r=b[n+16>>1]|0;s=b[n+32>>1]|0;t=b[n+48>>1]|0;u=b[n+64>>1]|0;v=b[n+80>>1]|0;w=b[n+96>>1]|0;x=b[n+112>>1]|0;y=b[n+128>>1]|0;z=b[n+144>>1]|0;a[j]=a[(512-(b[n-32>>1]|0)+(c*-2|0)+(q*96|0)+(r*42|0)+(s*-7|0)>>10)+1236056|0]|0;a[j+f|0]=a[(512-c+(q*-2|0)+(r*96|0)+(s*42|0)+(t*-7|0)>>10)+1236056|0]|0;a[j+g|0]=a[(512-q+(r*-2|0)+(s*96|0)+(t*42|0)+(u*-7|0)>>10)+1236056|0]|0;a[j+m|0]=a[(512-r+(s*-2|0)+(t*96|0)+(u*42|0)+(v*-7|0)>>10)+1236056|0]|0;a[j+l|0]=a[(512-s+(t*-2|0)+(u*96|0)+(v*42|0)+(w*-7|0)>>10)+1236056|0]|0;a[j+k|0]=a[(512-t+(u*-2|0)+(v*96|0)+(w*42|0)+(x*-7|0)>>10)+1236056|0]|0;a[j+o|0]=a[(512-u+(v*-2|0)+(w*96|0)+(x*42|0)+(y*-7|0)>>10)+1236056|0]|0;a[j+p|0]=a[(512-v+(w*-2|0)+(x*96|0)+(y*42|0)+(z*-7|0)>>10)+1236056|0]|0;z=e+1|0;if((z|0)<8){e=z;n=n+2|0;j=j+1|0}else{break}}i=h;return}function _jb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=f*-2|0;h=-f|0;i=f<<1;j=f*3|0;k=f<<2;l=f*5|0;m=f*6|0;n=f*7|0;o=f<<3;p=f*9|0;q=e<<1;r=e*3|0;s=e<<2;t=e*5|0;u=e*6|0;v=e*7|0;w=0;x=c;c=b;while(1){b=d[x+h|0]|0;y=d[x]|0;z=d[x+f|0]|0;A=d[x+i|0]|0;B=d[x+j|0]|0;C=d[x+k|0]|0;D=d[x+l|0]|0;E=d[x+m|0]|0;F=d[x+n|0]|0;G=d[x+o|0]|0;H=d[x+p|0]|0;a[c]=a[(64-(d[x+g|0]|0)+(b*-2|0)+(y*96|0)+(z*42|0)+(A*-7|0)>>7)+1236056|0]|0;a[c+e|0]=a[(64-b+(y*-2|0)+(z*96|0)+(A*42|0)+(B*-7|0)>>7)+1236056|0]|0;a[c+q|0]=a[(64-y+(z*-2|0)+(A*96|0)+(B*42|0)+(C*-7|0)>>7)+1236056|0]|0;a[c+r|0]=a[(64-z+(A*-2|0)+(B*96|0)+(C*42|0)+(D*-7|0)>>7)+1236056|0]|0;a[c+s|0]=a[(64-A+(B*-2|0)+(C*96|0)+(D*42|0)+(E*-7|0)>>7)+1236056|0]|0;a[c+t|0]=a[(64-B+(C*-2|0)+(D*96|0)+(E*42|0)+(F*-7|0)>>7)+1236056|0]|0;a[c+u|0]=a[(64-C+(D*-2|0)+(E*96|0)+(F*42|0)+(G*-7|0)>>7)+1236056|0]|0;a[c+v|0]=a[(64-D+(E*-2|0)+(F*96|0)+(G*42|0)+(H*-7|0)>>7)+1236056|0]|0;H=w+1|0;if((H|0)<8){w=H;x=x+1|0;c=c+1|0}else{break}}return}function $jb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=c;c=b;b=0;while(1){h=g+1|0;i=g+2|0;j=g+3|0;a[c]=a[(((d[g-1|0]|0)*-7|0)+64+((d[g]|0)*42|0)+((d[h]|0)*96|0)+((d[i]|0)*-2|0)-(d[j]|0)>>7)+1236056|0]|0;k=g+4|0;a[c+1|0]=a[(((d[g]|0)*-7|0)+64+((d[h]|0)*42|0)+((d[i]|0)*96|0)+((d[j]|0)*-2|0)-(d[k]|0)>>7)+1236056|0]|0;l=g+5|0;a[c+2|0]=a[(((d[h]|0)*-7|0)+64+((d[i]|0)*42|0)+((d[j]|0)*96|0)+((d[k]|0)*-2|0)-(d[l]|0)>>7)+1236056|0]|0;h=g+6|0;a[c+3|0]=a[(((d[i]|0)*-7|0)+64+((d[j]|0)*42|0)+((d[k]|0)*96|0)+((d[l]|0)*-2|0)-(d[h]|0)>>7)+1236056|0]|0;i=g+7|0;a[c+4|0]=a[(((d[j]|0)*-7|0)+64+((d[k]|0)*42|0)+((d[l]|0)*96|0)+((d[h]|0)*-2|0)-(d[i]|0)>>7)+1236056|0]|0;j=g+8|0;a[c+5|0]=a[(((d[k]|0)*-7|0)+64+((d[l]|0)*42|0)+((d[h]|0)*96|0)+((d[i]|0)*-2|0)-(d[j]|0)>>7)+1236056|0]|0;k=g+9|0;a[c+6|0]=a[(((d[l]|0)*-7|0)+64+((d[h]|0)*42|0)+((d[i]|0)*96|0)+((d[j]|0)*-2|0)-(d[k]|0)>>7)+1236056|0]|0;a[c+7|0]=a[(((d[h]|0)*-7|0)+64+((d[i]|0)*42|0)+((d[j]|0)*96|0)+((d[k]|0)*-2|0)-(d[g+10|0]|0)>>7)+1236056|0]|0;k=b+1|0;if((k|0)<8){g=g+f|0;c=c+e|0;b=k}else{break}}return}function akb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=c;c=b;b=0;while(1){h=g+1|0;i=g+2|0;j=g+3|0;a[c]=a[(4-(d[g-1|0]|0)-(d[i]|0)+(((d[h]|0)+(d[g]|0)|0)*5|0)>>3)+1236056|0]|0;k=g+4|0;a[c+1|0]=a[(4-(d[g]|0)-(d[j]|0)+(((d[i]|0)+(d[h]|0)|0)*5|0)>>3)+1236056|0]|0;l=g+5|0;a[c+2|0]=a[(4-(d[h]|0)-(d[k]|0)+(((d[j]|0)+(d[i]|0)|0)*5|0)>>3)+1236056|0]|0;h=g+6|0;a[c+3|0]=a[(4-(d[i]|0)-(d[l]|0)+(((d[k]|0)+(d[j]|0)|0)*5|0)>>3)+1236056|0]|0;i=g+7|0;a[c+4|0]=a[(4-(d[j]|0)-(d[h]|0)+(((d[l]|0)+(d[k]|0)|0)*5|0)>>3)+1236056|0]|0;j=g+8|0;a[c+5|0]=a[(4-(d[k]|0)-(d[i]|0)+(((d[h]|0)+(d[l]|0)|0)*5|0)>>3)+1236056|0]|0;a[c+6|0]=a[(4-(d[l]|0)-(d[j]|0)+(((d[i]|0)+(d[h]|0)|0)*5|0)>>3)+1236056|0]|0;a[c+7|0]=a[(4-(d[h]|0)-(d[g+9|0]|0)+(((d[j]|0)+(d[i]|0)|0)*5|0)>>3)+1236056|0]|0;i=b+1|0;if((i|0)<8){g=g+f|0;c=c+e|0;b=i}else{break}}return}function bkb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c;c=b;b=0;while(1){h=g-1|0;i=g+1|0;j=g+2|0;k=g+3|0;a[c]=a[(64-(d[g-2|0]|0)+((d[h]|0)*-2|0)+((d[g]|0)*96|0)+((d[i]|0)*42|0)+((d[j]|0)*-7|0)>>7)+1236056|0]|0;l=g+4|0;a[c+1|0]=a[(64-(d[h]|0)+((d[g]|0)*-2|0)+((d[i]|0)*96|0)+((d[j]|0)*42|0)+((d[k]|0)*-7|0)>>7)+1236056|0]|0;h=g+5|0;a[c+2|0]=a[(64-(d[g]|0)+((d[i]|0)*-2|0)+((d[j]|0)*96|0)+((d[k]|0)*42|0)+((d[l]|0)*-7|0)>>7)+1236056|0]|0;m=g+6|0;a[c+3|0]=a[(64-(d[i]|0)+((d[j]|0)*-2|0)+((d[k]|0)*96|0)+((d[l]|0)*42|0)+((d[h]|0)*-7|0)>>7)+1236056|0]|0;i=g+7|0;a[c+4|0]=a[(64-(d[j]|0)+((d[k]|0)*-2|0)+((d[l]|0)*96|0)+((d[h]|0)*42|0)+((d[m]|0)*-7|0)>>7)+1236056|0]|0;j=g+8|0;a[c+5|0]=a[(64-(d[k]|0)+((d[l]|0)*-2|0)+((d[h]|0)*96|0)+((d[m]|0)*42|0)+((d[i]|0)*-7|0)>>7)+1236056|0]|0;a[c+6|0]=a[(64-(d[l]|0)+((d[h]|0)*-2|0)+((d[m]|0)*96|0)+((d[i]|0)*42|0)+((d[j]|0)*-7|0)>>7)+1236056|0]|0;a[c+7|0]=a[(64-(d[h]|0)+((d[m]|0)*-2|0)+((d[i]|0)*96|0)+((d[j]|0)*42|0)+((d[g+9|0]|0)*-7|0)>>7)+1236056|0]|0;j=b+1|0;if((j|0)<8){g=g+f|0;c=c+e|0;b=j}else{break}}return}function ckb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=c[b>>2]|0;e=c[b+124>>2]|0;f=e+d|0;g=d-e<<1;gHb(g,(g|0)<0|0?-1:0,1075036753,0)|0;g=F;e=c[b+60>>2]|0;d=c[b+64>>2]|0;h=d+e|0;i=e-d<<5;gHb(i,(i|0)<0|0?-1:0,1367679739,0)|0;i=F;d=h+f|0;e=f-h<<1;gHb(e,(e|0)<0|0?-1:0,1078937202,0)|0;e=F;h=i+g|0;f=i-g<<1;gHb(f,(f|0)<0|0?-1:0,-1078937202,-1)|0;f=F;g=c[b+28>>2]|0;i=c[b+96>>2]|0;j=i+g|0;k=g-i<<1;gHb(k,(k|0)<0|0?-1:0,1449139879,0)|0;k=F;i=c[b+32>>2]|0;g=c[b+92>>2]|0;l=g+i|0;m=i-g<<1;gHb(m,(m|0)<0|0?-1:0,1598879467,0)|0;m=F;g=l+j|0;i=j-l<<4;gHb(i,(i|0)<0|0?-1:0,1369329156,0)|0;i=F;l=m+k|0;j=m-k<<4;gHb(j,(j|0)<0|0?-1:0,-1369329156,-1)|0;j=F;k=g+d|0;m=d-g<<1;gHb(m,(m|0)<0|0?-1:0,1094777670,0)|0;m=F;g=i+e|0;d=i-e<<1;gHb(d,(d|0)<0|0?-1:0,-1094777670,-1)|0;d=F;e=l+h|0;i=h-l<<1;gHb(i,(i|0)<0|0?-1:0,1094777670,0)|0;i=F;l=j+f|0;h=j-f<<1;gHb(h,(h|0)<0|0?-1:0,-1094777670,-1)|0;h=F;f=c[b+12>>2]|0;j=c[b+112>>2]|0;n=j+f|0;o=f-j<<1;gHb(o,(o|0)<0|0?-1:0,1140405281,0)|0;o=F;j=c[b+48>>2]|0;f=c[b+76>>2]|0;p=f+j|0;q=j-f<<2;gHb(q,(q|0)<0|0?-1:0,1593609622,0)|0;q=F;f=p+n|0;j=n-p<<1;gHb(j,(j|0)<0|0?-1:0,1389039203,0)|0;j=F;p=q+o|0;n=q-o<<1;gHb(n,(n|0)<0|0?-1:0,-1389039203,-1)|0;n=F;o=c[b+16>>2]|0;q=c[b+108>>2]|0;r=q+o|0;s=o-q<<1;gHb(s,(s|0)<0|0?-1:0,1187781572,0)|0;s=F;q=c[b+44>>2]|0;o=c[b+80>>2]|0;t=o+q|0;u=q-o<<2;gHb(u,(u|0)<0|0?-1:0,1255676567,0)|0;u=F;o=t+r|0;q=r-t<<1;gHb(q,(q|0)<0|0?-1:0,1692549166,0)|0;q=F;t=u+s|0;r=u-s<<1;gHb(r,(r|0)<0|0?-1:0,-1692549166,-1)|0;r=F;s=o+f|0;u=f-o<<3;gHb(u,(u|0)<0|0?-1:0,1375954754,0)|0;u=F;o=q+j|0;f=q-j<<3;gHb(f,(f|0)<0|0?-1:0,-1375954754,-1)|0;f=F;j=t+p|0;q=p-t<<3;gHb(q,(q|0)<0|0?-1:0,1375954754,0)|0;q=F;t=r+n|0;p=r-n<<3;gHb(p,(p|0)<0|0?-1:0,-1375954754,-1)|0;p=F;n=s+k|0;r=k-s<<1;gHb(r,(r|0)<0|0?-1:0,1162209775,0)|0;r=F;s=u+m|0;k=u-m<<1;gHb(k,(k|0)<0|0?-1:0,-1162209775,-1)|0;k=F;m=o+g|0;u=g-o<<1;gHb(u,(u|0)<0|0?-1:0,1162209775,0)|0;u=F;o=f+d|0;g=f-d<<1;gHb(g,(g|0)<0|0?-1:0,-1162209775,-1)|0;g=F;d=j+e|0;f=e-j<<1;gHb(f,(f|0)<0|0?-1:0,1162209775,0)|0;f=F;j=q+i|0;e=q-i<<1;gHb(e,(e|0)<0|0?-1:0,-1162209775,-1)|0;e=F;i=t+l|0;q=l-t<<1;gHb(q,(q|0)<0|0?-1:0,1162209775,0)|0;q=F;t=p+h|0;l=p-h<<1;gHb(l,(l|0)<0|0?-1:0,-1162209775,-1)|0;l=F;h=c[b+4>>2]|0;p=c[b+120>>2]|0;v=p+h|0;w=h-p<<1;gHb(w,(w|0)<0|0?-1:0,1085490621,0)|0;w=F;p=c[b+56>>2]|0;h=c[b+68>>2]|0;x=h+p|0;y=p-h<<3;gHb(y,(y|0)<0|0?-1:0,1829445839,0)|0;y=F;h=x+v|0;p=v-x<<1;gHb(p,(p|0)<0|0?-1:0,1122057232,0)|0;p=F;x=y+w|0;v=y-w<<1;gHb(v,(v|0)<0|0?-1:0,-1122057232,-1)|0;v=F;w=c[b+24>>2]|0;y=c[b+100>>2]|0;z=y+w|0;A=w-y<<1;gHb(A,(A|0)<0|0?-1:0,1336817425,0)|0;A=F;y=c[b+36>>2]|0;w=c[b+88>>2]|0;B=w+y|0;C=y-w<<1;gHb(C,(C|0)<0|0?-1:0,1802489638,0)|0;C=F;w=B+z|0;y=z-B<<2;gHb(y,(y|0)<0|0?-1:0,1849463489,0)|0;y=F;B=C+A|0;z=C-A<<2;gHb(z,(z|0)<0|0?-1:0,-1849463489,-1)|0;z=F;A=w+h|0;C=h-w<<1;gHb(C,(C|0)<0|0?-1:0,1291378312,0)|0;C=F;w=y+p|0;h=y-p<<1;gHb(h,(h|0)<0|0?-1:0,-1291378312,-1)|0;h=F;p=B+x|0;y=x-B<<1;gHb(y,(y|0)<0|0?-1:0,1291378312,0)|0;y=F;B=z+v|0;x=z-v<<1;gHb(x,(x|0)<0|0?-1:0,-1291378312,-1)|0;x=F;v=c[b+8>>2]|0;z=c[b+116>>2]|0;D=z+v|0;E=v-z<<1;gHb(E,(E|0)<0|0?-1:0,1106914669,0)|0;E=F;z=c[b+52>>2]|0;v=c[b+72>>2]|0;G=v+z|0;H=z-v<<3;gHb(H,(H|0)<0|0?-1:0,1104762768,0)|0;H=F;v=G+D|0;z=D-G<<1;gHb(z,(z|0)<0|0?-1:0,1217503044,0)|0;z=F;G=H+E|0;D=H-E<<1;gHb(D,(D|0)<0|0?-1:0,-1217503044,-1)|0;D=F;E=c[b+20>>2]|0;H=c[b+104>>2]|0;I=H+E|0;J=E-H<<1;gHb(J,(J|0)<0|0?-1:0,1251843312,0)|0;J=F;H=c[b+40>>2]|0;E=c[b+84>>2]|0;b=E+H|0;K=H-E<<1;gHb(K,(K|0)<0|0?-1:0,2088574387,0)|0;K=F;E=b+I|0;H=I-b<<2;gHb(H,(H|0)<0|0?-1:0,1138893993,0)|0;H=F;b=K+J|0;I=K-J<<2;gHb(I,(I|0)<0|0?-1:0,-1138893993,-1)|0;I=F;J=E+v|0;K=v-E<<1;gHb(K,(K|0)<0|0?-1:0,1932684223,0)|0;K=F;E=H+z|0;v=H-z<<1;gHb(v,(v|0)<0|0?-1:0,-1932684223,-1)|0;v=F;z=b+G|0;H=G-b<<1;gHb(H,(H|0)<0|0?-1:0,1932684223,0)|0;H=F;b=I+D|0;G=I-D<<1;gHb(G,(G|0)<0|0?-1:0,-1932684223,-1)|0;G=F;D=J+A|0;I=A-J<<2;gHb(I,(I|0)<0|0?-1:0,1402911301,0)|0;I=F;J=K+C|0;A=K-C<<2;gHb(A,(A|0)<0|0?-1:0,-1402911301,-1)|0;A=F;C=E+w|0;K=w-E<<2;gHb(K,(K|0)<0|0?-1:0,1402911301,0)|0;K=F;E=v+h|0;w=v-h<<2;gHb(w,(w|0)<0|0?-1:0,-1402911301,-1)|0;w=F;h=z+p|0;v=p-z<<2;gHb(v,(v|0)<0|0?-1:0,1402911301,0)|0;v=F;z=H+y|0;p=H-y<<2;gHb(p,(p|0)<0|0?-1:0,-1402911301,-1)|0;p=F;y=b+B|0;H=B-b<<2;gHb(H,(H|0)<0|0?-1:0,1402911301,0)|0;H=F;b=G+x|0;B=G-x<<2;gHb(B,(B|0)<0|0?-1:0,-1402911301,-1)|0;B=F;x=n-D<<1;gHb(x,(x|0)<0|0?-1:0,1518500250,0)|0;x=F;G=I-r<<1;gHb(G,(G|0)<0|0?-1:0,-1518500250,-1)|0;G=F;L=s-J<<1;gHb(L,(L|0)<0|0?-1:0,1518500250,0)|0;L=F;M=A-k<<1;gHb(M,(M|0)<0|0?-1:0,-1518500250,-1)|0;M=F;N=A+k+M|0;k=m-C<<1;gHb(k,(k|0)<0|0?-1:0,1518500250,0)|0;k=F;A=K-u<<1;gHb(A,(A|0)<0|0?-1:0,-1518500250,-1)|0;A=F;O=K+u+A|0;u=o-E<<1;gHb(u,(u|0)<0|0?-1:0,1518500250,0)|0;u=F;K=w-g<<1;gHb(K,(K|0)<0|0?-1:0,-1518500250,-1)|0;K=F;P=w+g+K|0;g=E+o+P|0;o=P+u|0;P=K+u|0;u=d-h<<1;gHb(u,(u|0)<0|0?-1:0,1518500250,0)|0;u=F;E=v-f<<1;gHb(E,(E|0)<0|0?-1:0,-1518500250,-1)|0;E=F;w=v+f+E|0;f=j-z<<1;gHb(f,(f|0)<0|0?-1:0,1518500250,0)|0;f=F;v=p-e<<1;gHb(v,(v|0)<0|0?-1:0,-1518500250,-1)|0;v=F;Q=p+e+v|0;e=z+j+Q|0;j=Q+f|0;Q=v+f|0;f=i-y<<1;gHb(f,(f|0)<0|0?-1:0,1518500250,0)|0;f=F;z=H-q<<1;gHb(z,(z|0)<0|0?-1:0,-1518500250,-1)|0;z=F;p=H+q+z|0;q=t-b<<1;gHb(q,(q|0)<0|0?-1:0,1518500250,0)|0;q=F;H=B-l<<1;gHb(H,(H|0)<0|0?-1:0,-1518500250,-1)|0;H=F;R=B+l+H|0;l=b+t+R|0;t=R+q|0;R=H+q|0;c[a>>2]=D+n;c[a+64>>2]=x;c[a+32>>2]=I+r+G;c[a+96>>2]=G;c[a+16>>2]=J+s+N;c[a+80>>2]=M+L;c[a+48>>2]=N+L;c[a+112>>2]=M;c[a+8>>2]=C+m+g;c[a+72>>2]=P+k;c[a+40>>2]=o+O;c[a+104>>2]=K+A;c[a+24>>2]=g+O;c[a+88>>2]=P+A;c[a+56>>2]=o+k;c[a+120>>2]=K;K=y+i+l|0;i=l+p|0;l=t+p|0;p=t+f|0;t=R+f|0;f=R+z|0;R=H+z|0;c[a+4>>2]=h+d+K;c[a+68>>2]=t+u;c[a+36>>2]=l+w;c[a+100>>2]=R+E;c[a+20>>2]=i+e;c[a+84>>2]=f+Q;c[a+52>>2]=p+j;c[a+116>>2]=H+v;c[a+12>>2]=K+e;c[a+76>>2]=t+Q;c[a+44>>2]=l+j;c[a+108>>2]=R+v;c[a+28>>2]=i+w;c[a+92>>2]=f+E;c[a+60>>2]=p+u;c[a+124>>2]=H;return}function dkb(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=e+8|0;h=c[g>>2]|0;i=-h&7;j=c[e+16>>2]|0;if((i|0)==0){k=h}else{l=i+h|0;h=j>>>0>l>>>0?l:j;c[g>>2]=h;k=h}h=((c[e+12>>2]|0)-k|0)/8|0;l=(h|0)<(f|0)?h:f;f=c[e>>2]|0;e=(k|0)/8|0;h=f+e|0;i=a+8|0;c[i>>2]=h;m=e+l|0;n=f+m|0;c[a+12>>2]=n;o=l<<3;l=-k|0;p=j-k|0;if((o|0)<(l|0)){q=l}else{q=(p|0)<(o|0)?p:o}c[g>>2]=q+k;k=a|0;c[k>>2]=0;if((e|0)<(m|0)){m=f+(e+1)|0;c[i>>2]=m;r=(d[h]|0)<<8;s=m}else{r=65280;s=h}c[k>>2]=r;if(s>>>0<n>>>0){h=s+1|0;c[i>>2]=h;t=r|(d[s]|0);u=h}else{t=r|255;u=s}s=t<<8;c[k>>2]=s;if(u>>>0<n>>>0){t=u+1|0;c[i>>2]=t;v=s|(d[u]|0);w=t}else{v=s|255;w=u}u=v<<8;c[k>>2]=u;if(w>>>0<n>>>0){c[i>>2]=w+1;x=u|(d[w]|0)}else{x=u|255}c[k>>2]=x;b[a+6>>1]=-16;b[a+4>>1]=-1;x=0;do{b[7558224+(x<<2)>>1]=b[1233056+(255-x<<1)>>1]|0;b[7558226+(x<<2)>>1]=-(b[1233056+(x<<1)>>1]|0);x=x+1|0;}while((x|0)<256);b[a+16>>1]=-32768;b[a+18>>1]=-32768;b[a+20>>1]=-32768;b[a+22>>1]=-32768;b[a+24>>1]=-32768;b[a+26>>1]=-32768;b[a+28>>1]=-32768;b[a+30>>1]=-32768;b[a+32>>1]=-32768;b[a+34>>1]=-32768;b[a+36>>1]=-32768;b[a+38>>1]=-32768;b[a+40>>1]=-32768;b[a+42>>1]=-32768;b[a+44>>1]=-32768;b[a+46>>1]=-32768;b[a+48>>1]=-32768;b[a+50>>1]=-32768;b[a+52>>1]=-32768;b[a+54>>1]=-32768;b[a+56>>1]=-32768;b[a+58>>1]=-32768;return}function ekb(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;k=i;c[a>>2]=b;c[a+8>>2]=d;c[a+12>>2]=e;c[a+16>>2]=f;c[a+20>>2]=h;c[a+4>>2]=j+16;a:do{if((h|0)>0){j=h;while(1){j=j-1|0;d=e>>j;l=f<<j;switch(g|0){case 8:{m=d-1|0;if(m>>>0<4294967292>>>0){n=m<<1;o=-4;while(1){p=((o|0)>0?n:0)-o|0;if(p>>>0>m>>>0){o=p}else{q=p;break}}}else{q=-4}c[a+56+(j*36|0)>>2]=b+((ba(q,l)|0)<<1);if(m>>>0<4294967293>>>0){o=m<<1;n=-3;while(1){p=((n|0)>0?o:0)-n|0;if(p>>>0>m>>>0){n=p}else{r=p;break}}}else{r=-3}c[a+56+(j*36|0)+4>>2]=b+((ba(r,l)|0)<<1);if(m>>>0<4294967294>>>0){n=m<<1;o=-2;while(1){p=((o|0)>0?n:0)-o|0;if(p>>>0>m>>>0){o=p}else{s=p;break}}}else{s=-2}c[a+56+(j*36|0)+8>>2]=b+((ba(s,l)|0)<<1);if((d|0)==0){t=-1}else{o=m<<1;n=-1;while(1){p=((n|0)>0?o:0)-n|0;if(p>>>0>m>>>0){n=p}else{t=p;break}}}c[a+56+(j*36|0)+12>>2]=b+((ba(t,l)|0)<<1);c[a+56+(j*36|0)+32>>2]=-3;break};case 5:case 6:{c[a+56+(j*36|0)+32>>2]=1;break};case 3:{n=d-1|0;if(n>>>0<4294967294>>>0){m=n<<1;o=-2;while(1){p=((o|0)>0?m:0)-o|0;if(p>>>0>n>>>0){o=p}else{u=p;break}}}else{u=-2}c[a+56+(j*36|0)>>2]=b+((ba(u,l)|0)<<1);if((d|0)==0){v=-1}else{o=n<<1;m=-1;while(1){p=((m|0)>0?o:0)-m|0;if(p>>>0>n>>>0){m=p}else{v=p;break}}}c[a+56+(j*36|0)+4>>2]=b+((ba(v,l)|0)<<1);c[a+56+(j*36|0)+32>>2]=-1;break};case 4:{m=d-2|0;c[a+56+(j*36|0)>>2]=b;n=d-1|0;o=b+(l<<1)|0;c[a+56+(j*36|0)+4>>2]=o;c[a+56+(j*36|0)+8>>2]=b;c[a+56+(j*36|0)+12>>2]=o;c[a+56+(j*36|0)+16>>2]=b;c[a+56+(j*36|0)+20>>2]=o;c[a+56+(j*36|0)+24>>2]=b+((ba((m|0)<0?m:0,l)|0)<<1);c[a+56+(j*36|0)+28>>2]=b+((ba((n|0)<1?n:1,l)|0)<<1);c[a+56+(j*36|0)+32>>2]=-5;break};case 2:{c[a+56+(j*36|0)>>2]=b;n=b+(l<<1)|0;c[a+56+(j*36|0)+4>>2]=n;c[a+56+(j*36|0)+8>>2]=b;c[a+56+(j*36|0)+12>>2]=n;c[a+56+(j*36|0)+16>>2]=b;c[a+56+(j*36|0)+20>>2]=n;c[a+56+(j*36|0)+32>>2]=-5;break};default:{c[a+56+(j*36|0)+32>>2]=0}}if((j|0)<=0){break a}}}}while(0);switch(g|0){case 2:{c[a+28>>2]=540;c[a+32>>2]=402;c[a+36>>2]=172;c[a+52>>2]=348;c[a+24>>2]=7;w=0;i=k;return w|0};case 7:{c[a+28>>2]=80;c[a+32>>2]=860;c[a+36>>2]=1040;c[a+52>>2]=1674;c[a+24>>2]=0;w=0;i=k;return w|0};case 5:case 6:{c[a+28>>2]=538;c[a+48>>2]=210;c[a+52>>2]=(g|0)==5?2254:1016;c[a+24>>2]=1;w=0;i=k;return w|0};case 8:{c[a+28>>2]=98;c[a+32>>2]=322;c[a+36>>2]=396;c[a+40>>2]=320;c[a+44>>2]=394;c[a+52>>2]=868;c[a+24>>2]=5;w=0;i=k;return w|0};case 4:{c[a+28>>2]=488;c[a+32>>2]=168;c[a+36>>2]=172;c[a+52>>2]=1520;c[a+24>>2]=7;w=0;i=k;return w|0};case 3:{c[a+28>>2]=168;c[a+32>>2]=402;c[a+36>>2]=600;c[a+52>>2]=302;c[a+24>>2]=3;w=0;i=k;return w|0};default:{yDb(0,16,2178600,(a=i,i=i+8|0,c[a>>2]=g,a)|0);i=a;w=-1;i=k;return w|0}}return 0}function fkb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;h=i;i=i+32|0;j=h;k=c[a+32>>2]|0;l=c[a+36>>2]|0;m=a+56+(b*36|0)+32|0;n=c[m>>2]|0;o=a+((b*36|0)+56)|0;c[j>>2]=c[o>>2];c[j+4>>2]=c[o+4>>2];c[j+8>>2]=c[o+8>>2];c[j+12>>2]=c[o+12>>2];c[j+16>>2]=c[o+16>>2];c[j+20>>2]=c[o+20>>2];j=c[a>>2]|0;b=n+5|0;p=e-2|0;if((b|0)<0){q=0}else{q=(b|0)>(p|0)?p:b}p=j+((ba(q,f)|0)<<1)|0;c[h+24>>2]=p;q=n+6|0;r=e-1|0;if((q|0)<1){s=1}else{s=(q|0)>(r|0)?r:q}q=j+((ba(s,f)|0)<<1)|0;c[h+28>>2]=q;if(b>>>0<e>>>0){cf[k&1023](c[h+20>>2]|0,p,q,d)}if((n+1|0)>>>0<e>>>0){Se[l&511](c[h>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0,c[h+16>>2]|0,p,d)}if((n-1|0)>>>0<e>>>0){Xe[c[a+52>>2]&4095](c[h>>2]|0,c[a+4>>2]|0,d)}if(n>>>0<e>>>0){Xe[c[a+52>>2]&4095](c[h+4>>2]|0,c[a+4>>2]|0,d)}d=h+8|0;c[o>>2]=c[d>>2];c[o+4>>2]=c[d+4>>2];c[o+8>>2]=c[d+8>>2];c[o+12>>2]=c[d+12>>2];c[o+16>>2]=c[d+16>>2];c[o+20>>2]=c[d+20>>2];c[m>>2]=(c[m>>2]|0)+2;i=g;return}function gkb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(e[h>>1]|0)-(((b[a+(g<<1)>>1]|0)+2+(b[d+(g<<1)>>1]|0)|0)>>>2);g=g+1|0;}while((g|0)<(f|0));return}function hkb(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;if((h|0)>0){i=0}else{return}do{j=d+(i<<1)|0;b[j>>1]=((8-(b[a+(i<<1)>>1]|0)-(b[g+(i<<1)>>1]|0)+(((b[f+(i<<1)>>1]|0)+(b[c+(i<<1)>>1]|0)|0)*9|0)|0)>>>4)+(e[j>>1]|0);i=i+1|0;}while((i|0)<(h|0));return}function ikb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;f=d>>1;d=(e[a>>1]|0)-(((b[a+(f<<1)>>1]<<1)+2|0)>>>2)&65535;b[c>>1]=d;if((f|0)>1){g=1;do{h=g+f|0;b[c+(g<<1)>>1]=(e[a+(g<<1)>>1]|0)-(((b[a+(h-1<<1)>>1]|0)+2+(b[a+(h<<1)>>1]|0)|0)>>>2);g=g+1|0;}while((g|0)<(f|0));i=b[c>>1]|0}else{i=d}b[c-2>>1]=i;i=b[c+(f-1<<1)>>1]|0;b[c+(f<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;if((f|0)>0){j=0}else{return}while(1){i=c+(j<<1)|0;d=j<<1;b[a+(d<<1)>>1]=((b[i>>1]|0)+1|0)>>>1;g=j+1|0;b[a+((d|1)<<1)>>1]=((b[a+(j+f<<1)>>1]|0)+1+((8-(b[c+(j-1<<1)>>1]|0)-(b[c+(j+2<<1)>>1]|0)+(((b[c+(g<<1)>>1]|0)+(b[i>>1]|0)|0)*9|0)|0)>>>4)|0)>>>1;if((g|0)<(f|0)){j=g}else{break}}return}function jkb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=a+56+(b*36|0)+32|0;h=c[g>>2]|0;i=a+56+(b*36|0)|0;j=c[i>>2]|0;k=a+56+(b*36|0)+4|0;b=c[k>>2]|0;l=c[a+32>>2]|0;m=c[a+36>>2]|0;n=c[a>>2]|0;o=h+1|0;p=e-1|0;if(o>>>0>p>>>0){q=p<<1;r=o;while(1){s=((r|0)>0?q:0)-r|0;if(s>>>0>p>>>0){r=s}else{t=s;break}}}else{t=o}r=n+((ba(t,f)|0)<<1)|0;t=h+2|0;if(t>>>0>p>>>0){q=p<<1;s=t;while(1){u=((s|0)>0?q:0)-s|0;if(u>>>0>p>>>0){s=u}else{v=u;break}}}else{v=t}t=n+((ba(v,f)|0)<<1)|0;if(o>>>0<e>>>0){cf[l&1023](b,r,t,d)}l=h>>>0<e>>>0;if(l){cf[m&1023](j,b,r,d)}if((h-1|0)>>>0<e>>>0){Xe[c[a+52>>2]&4095](j,c[a+4>>2]|0,d)}if(!l){c[i>>2]=r;c[k>>2]=t;w=c[g>>2]|0;x=w+2|0;c[g>>2]=x;return}Xe[c[a+52>>2]&4095](b,c[a+4>>2]|0,d);c[i>>2]=r;c[k>>2]=t;w=c[g>>2]|0;x=w+2|0;c[g>>2]=x;return}function kkb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(((b[a+(g<<1)>>1]|0)+1+(b[d+(g<<1)>>1]|0)|0)>>>1)+(e[h>>1]|0);g=g+1|0;}while((g|0)<(f|0));return}function lkb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d>>1;g=(e[a>>1]|0)-(((b[a+(f<<1)>>1]<<1)+2|0)>>>2)&65535;b[c>>1]=g;a:do{if((f|0)>1){h=1;i=g;while(1){j=h+f|0;k=j-1|0;l=a+(k<<1)|0;m=(e[a+(h<<1)>>1]|0)-(((b[l>>1]|0)+2+(b[a+(j<<1)>>1]|0)|0)>>>2)&65535;j=c+(h<<1)|0;b[j>>1]=m;b[c+(k<<1)>>1]=(((i<<16>>16)+1+(m<<16>>16)|0)>>>1)+(e[l>>1]|0);l=h+1|0;if((l|0)>=(f|0)){break a}h=l;i=b[j>>1]|0}}}while(0);g=d-1|0;b[c+(g<<1)>>1]=(b[c+(f-1<<1)>>1]|0)+(b[a+(g<<1)>>1]|0);if((f|0)>0){n=0}else{return}do{g=n<<1;b[a+(g<<1)>>1]=((b[c+(n<<1)>>1]|0)+1|0)>>>1;b[a+((g|1)<<1)>>1]=((b[c+(n+f<<1)>>1]|0)+1|0)>>>1;n=n+1|0;}while((n|0)<(f|0));return}function mkb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;h=i;i=i+40|0;j=c[a+32>>2]|0;k=c[a+36>>2]|0;l=a+56+(b*36|0)+32|0;m=c[l>>2]|0;n=a+((b*36|0)+56)|0;UGb(h|0,n|0,32)|0;b=c[a>>2]|0;o=m+7|0;p=e-2|0;if((o|0)<0){q=0}else{q=(o|0)>(p|0)?p:o}c[h+32>>2]=b+((ba(q,f)|0)<<1);q=m+8|0;o=e-1|0;if((q|0)<1){r=1}else{r=(q|0)>(o|0)?o:q}q=b+((ba(r,f)|0)<<1)|0;c[h+36>>2]=q;if((m+5|0)>>>0<e>>>0){Se[j&511](c[h+12>>2]|0,c[h+20>>2]|0,c[h+24>>2]|0,c[h+28>>2]|0,q,d)}if((m+1|0)>>>0<e>>>0){Se[k&511](c[h>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0,c[h+16>>2]|0,c[h+24>>2]|0,d)}if((m-1|0)>>>0<e>>>0){Xe[c[a+52>>2]&4095](c[h>>2]|0,c[a+4>>2]|0,d)}if(!(m>>>0<e>>>0)){s=h+8|0;t=s;UGb(n|0,t|0,32)|0;u=c[l>>2]|0;v=u+2|0;c[l>>2]=v;i=g;return}Xe[c[a+52>>2]&4095](c[h+4>>2]|0,c[a+4>>2]|0,d);s=h+8|0;t=s;UGb(n|0,t|0,32)|0;u=c[l>>2]|0;v=u+2|0;c[l>>2]=v;i=g;return}function nkb(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;if((h|0)>0){i=0}else{return}do{j=d+(i<<1)|0;b[j>>1]=(e[j>>1]|0)-((16-(b[a+(i<<1)>>1]|0)-(b[g+(i<<1)>>1]|0)+(((b[f+(i<<1)>>1]|0)+(b[c+(i<<1)>>1]|0)|0)*9|0)|0)>>>5);i=i+1|0;}while((i|0)<(h|0));return}function okb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>1;g=a+(f<<1)|0;h=b[g>>1]|0;i=f+1|0;j=a+(i<<1)|0;b[c>>1]=(e[a>>1]|0)-((16-h-(b[j>>1]|0)+(h*18|0)|0)>>>5);b[c+2>>1]=(e[a+2>>1]|0)-(((b[g>>1]<<3)+16+((b[j>>1]|0)*9|0)-(b[a+(f+2<<1)>>1]|0)|0)>>>5);j=f-1|0;if((j|0)>2){g=2;do{h=g+f|0;b[c+(g<<1)>>1]=(e[a+(g<<1)>>1]|0)-((16-(b[a+(h-2<<1)>>1]|0)-(b[a+(h+1<<1)>>1]|0)+(((b[a+(h<<1)>>1]|0)+(b[a+(h-1<<1)>>1]|0)|0)*9|0)|0)>>>5);g=g+1|0;}while((g|0)<(j|0))}g=b[a+(d-1<<1)>>1]|0;h=c+(j<<1)|0;b[h>>1]=(e[a+(j<<1)>>1]|0)-((16-(b[a+(d-3<<1)>>1]|0)-g+((g+(b[a+(d-2<<1)>>1]|0)|0)*9|0)|0)>>>5);b[c-2>>1]=b[c>>1]|0;d=b[h>>1]|0;b[c+(f<<1)>>1]=d;b[c+(i<<1)>>1]=d;if((f|0)>0){k=0}else{return}while(1){d=c+(k<<1)|0;i=k<<1;b[a+(i<<1)>>1]=((b[d>>1]|0)+1|0)>>>1;h=k+1|0;b[a+((i|1)<<1)>>1]=((b[a+(k+f<<1)>>1]|0)+1+((8-(b[c+(k-1<<1)>>1]|0)-(b[c+(k+2<<1)>>1]|0)+(((b[c+(h<<1)>>1]|0)+(b[d>>1]|0)|0)*9|0)|0)>>>4)|0)>>>1;if((h|0)<(f|0)){k=h}else{break}}return}function pkb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;e=a+56+(b*36|0)+32|0;b=c[e>>2]|0;g=c[a>>2]|0;h=g+((ba(b-1|0,f)|0)<<1)|0;i=g+((ba(b,f)|0)<<1)|0;Xe[c[a+48>>2]&4095](h,i,d);f=a+52|0;b=a+4|0;Xe[c[f>>2]&4095](h,c[b>>2]|0,d);Xe[c[f>>2]&4095](i,c[b>>2]|0,d);c[e>>2]=(c[e>>2]|0)+2;return}function qkb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0;if((d|0)>0){f=0}else{return}do{g=a+(f<<1)|0;h=c+(f<<1)|0;i=(e[g>>1]|0)-(((b[h>>1]|0)+1|0)>>>1)&65535;b[g>>1]=i;b[h>>1]=i+(b[h>>1]|0);f=f+1|0;}while((f|0)<(d|0));return}function rkb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;f=d>>1;if((f|0)>0){g=0}else{return}while(1){d=g+f|0;h=a+(d<<1)|0;i=(e[a+(g<<1)>>1]|0)-(((b[h>>1]|0)+1|0)>>>1)&65535;b[c+(g<<1)>>1]=i;b[c+(d<<1)>>1]=i+(b[h>>1]|0);h=g+1|0;if((h|0)<(f|0)){g=h}else{j=0;break}}do{g=j<<1;b[a+(g<<1)>>1]=b[c+(j<<1)>>1]|0;b[a+((g|1)<<1)>>1]=b[c+(j+f<<1)>>1]|0;j=j+1|0;}while((j|0)<(f|0));return}function skb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;f=d>>1;if((f|0)>0){g=0}else{return}while(1){d=g+f|0;h=a+(d<<1)|0;i=(e[a+(g<<1)>>1]|0)-(((b[h>>1]|0)+1|0)>>>1)&65535;b[c+(g<<1)>>1]=i;b[c+(d<<1)>>1]=i+(b[h>>1]|0);h=g+1|0;if((h|0)<(f|0)){g=h}else{j=0;break}}do{g=j<<1;b[a+(g<<1)>>1]=((b[c+(j<<1)>>1]|0)+1|0)>>>1;b[a+((g|1)<<1)>>1]=((b[c+(j+f<<1)>>1]|0)+1|0)>>>1;j=j+1|0;}while((j|0)<(f|0));return}function tkb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=i;i=i+32|0;h=g|0;j=c[a+32>>2]|0;k=c[a+36>>2]|0;if((e|0)>1){l=a|0;m=e-2|0;n=h|0;o=1;do{p=c[l>>2]|0;q=o-7|0;if((q|0)<0){r=0}else{r=(q|0)>(m|0)?m:q}c[n>>2]=p+((ba(r,f)|0)<<1);q=o-5|0;if((q|0)<0){s=0}else{s=(q|0)>(m|0)?m:q}c[h+4>>2]=p+((ba(s,f)|0)<<1);q=o-3|0;if((q|0)<0){t=0}else{t=(q|0)>(m|0)?m:q}c[h+8>>2]=p+((ba(t,f)|0)<<1);q=o-1|0;if((q|0)<0){u=0}else{u=(q|0)>(m|0)?m:q}c[h+12>>2]=p+((ba(u,f)|0)<<1);q=o+1|0;if((q|0)<0){v=0}else{v=(q|0)>(m|0)?m:q}c[h+16>>2]=p+((ba(v,f)|0)<<1);q=o+3|0;if((q|0)<0){w=0}else{w=(q|0)>(m|0)?m:q}c[h+20>>2]=p+((ba(w,f)|0)<<1);q=o+5|0;if((q|0)<0){x=0}else{x=(q|0)>(m|0)?m:q}c[h+24>>2]=p+((ba(x,f)|0)<<1);q=o+7|0;if((q|0)<0){y=0}else{y=(q|0)>(m|0)?m:q}c[h+28>>2]=p+((ba(y,f)|0)<<1);q=p+((ba(o,f)|0)<<1)|0;Xe[k&4095](q,n,d);o=o+2|0;}while((o|0)<(e|0))}o=(e|0)>0;if(!o){z=e+1|0;A=a+56+(b*36|0)+32|0;c[A>>2]=z;i=g;return}n=a|0;k=e-1|0;y=h|0;m=0;do{x=c[n>>2]|0;w=m-7|0;if((w|0)<1){B=1}else{B=(w|0)>(k|0)?k:w}c[y>>2]=x+((ba(B,f)|0)<<1);w=m-5|0;if((w|0)<1){C=1}else{C=(w|0)>(k|0)?k:w}c[h+4>>2]=x+((ba(C,f)|0)<<1);w=m-3|0;if((w|0)<1){D=1}else{D=(w|0)>(k|0)?k:w}c[h+8>>2]=x+((ba(D,f)|0)<<1);w=m-1|0;if((w|0)<1){E=1}else{E=(w|0)>(k|0)?k:w}c[h+12>>2]=x+((ba(E,f)|0)<<1);w=m|1;if((w|0)<1){F=1}else{F=(w|0)>(k|0)?k:w}c[h+16>>2]=x+((ba(F,f)|0)<<1);w=m+3|0;if((w|0)<1){G=1}else{G=(w|0)>(k|0)?k:w}c[h+20>>2]=x+((ba(G,f)|0)<<1);w=m+5|0;if((w|0)<1){H=1}else{H=(w|0)>(k|0)?k:w}c[h+24>>2]=x+((ba(H,f)|0)<<1);w=m+7|0;if((w|0)<1){I=1}else{I=(w|0)>(k|0)?k:w}c[h+28>>2]=x+((ba(I,f)|0)<<1);w=x+((ba(m,f)|0)<<1)|0;Xe[j&4095](w,y,d);m=m+2|0;}while((m|0)<(e|0));if(!o){z=e+1|0;A=a+56+(b*36|0)+32|0;c[A>>2]=z;i=g;return}o=a+52|0;m=a|0;y=a+4|0;j=0;do{I=(c[m>>2]|0)+((ba(j,f)|0)<<1)|0;Xe[c[o>>2]&4095](I,c[y>>2]|0,d);j=j+1|0;}while((j|0)<(e|0));z=e+1|0;A=a+56+(b*36|0)+32|0;c[A>>2]=z;i=g;return}function ukb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)<=0){return}g=c[d>>2]|0;h=c[d+28>>2]|0;i=c[d+4>>2]|0;j=c[d+24>>2]|0;k=c[d+8>>2]|0;l=c[d+20>>2]|0;m=c[d+12>>2]|0;n=c[d+16>>2]|0;d=0;do{o=a+(d<<1)|0;b[o>>1]=(e[o>>1]|0)-(((((b[h+(d<<1)>>1]|0)+(b[g+(d<<1)>>1]|0)|0)*-8|0)+128+(((b[j+(d<<1)>>1]|0)+(b[i+(d<<1)>>1]|0)|0)*21|0)+(((b[l+(d<<1)>>1]|0)+(b[k+(d<<1)>>1]|0)|0)*-46|0)+(((b[n+(d<<1)>>1]|0)+(b[m+(d<<1)>>1]|0)|0)*161|0)|0)>>>8);d=d+1|0;}while((d|0)<(f|0));return}function vkb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)<=0){return}g=c[d>>2]|0;h=c[d+28>>2]|0;i=c[d+4>>2]|0;j=c[d+24>>2]|0;k=c[d+8>>2]|0;l=c[d+20>>2]|0;m=c[d+12>>2]|0;n=c[d+16>>2]|0;d=0;do{o=a+(d<<1)|0;b[o>>1]=(((((b[h+(d<<1)>>1]|0)+(b[g+(d<<1)>>1]|0)|0)*-2|0)+128+(((b[j+(d<<1)>>1]|0)+(b[i+(d<<1)>>1]|0)|0)*10|0)+(((b[l+(d<<1)>>1]|0)+(b[k+(d<<1)>>1]|0)|0)*-25|0)+(((b[n+(d<<1)>>1]|0)+(b[m+(d<<1)>>1]|0)|0)*81|0)|0)>>>8)+(e[o>>1]|0);d=d+1|0;}while((d|0)<(f|0));return}function wkb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d>>1;d=(f|0)>0;if(!d){return}g=f-1|0;h=0;do{i=h-3|0;if((i|0)<0){j=0}else{j=(i|0)>(g|0)?g:i}i=h-2|0;if((i|0)<0){k=0}else{k=(i|0)>(g|0)?g:i}i=h-1|0;if((i|0)<0){l=0}else{l=(i|0)>(g|0)?g:i}i=h+1|0;m=h+2|0;n=h+3|0;o=h+4|0;b[c+(h<<1)>>1]=(((((b[a+(((o|0)>(g|0)?g:o)<<1)>>1]|0)+(b[a+(j<<1)>>1]|0)|0)*-2|0)+128+(((b[a+(((n|0)>(g|0)?g:n)<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*10|0)+(((b[a+(((m|0)>(g|0)?g:m)<<1)>>1]|0)+(b[a+(l<<1)>>1]|0)|0)*-25|0)+(((b[a+(((i|0)>(g|0)?g:i)<<1)>>1]|0)+(b[a+(h<<1)>>1]|0)|0)*81|0)|0)>>>8)+(e[a+(h+f<<1)>>1]|0);h=h+1|0;}while((h|0)<(f|0));if(!d){return}h=f-1|0;g=0;do{l=g-4|0;if((l|0)<0){p=0}else{p=(l|0)>(h|0)?h:l}l=g-3|0;if((l|0)<0){q=0}else{q=(l|0)>(h|0)?h:l}l=g-2|0;if((l|0)<0){r=0}else{r=(l|0)>(h|0)?h:l}l=g-1|0;if((l|0)<0){s=0}else{s=(l|0)>(h|0)?h:l}l=g+1|0;k=g+2|0;j=g+3|0;b[c+(g+f<<1)>>1]=(e[a+(g<<1)>>1]|0)-(((((b[c+(((j|0)>(h|0)?h:j)<<1)>>1]|0)+(b[c+(p<<1)>>1]|0)|0)*-8|0)+128+(((b[c+(((k|0)>(h|0)?h:k)<<1)>>1]|0)+(b[c+(q<<1)>>1]|0)|0)*21|0)+(((b[c+(((l|0)>(h|0)?h:l)<<1)>>1]|0)+(b[c+(r<<1)>>1]|0)|0)*-46|0)+(((b[c+(g<<1)>>1]|0)+(b[c+(s<<1)>>1]|0)|0)*161|0)|0)>>>8);g=g+1|0;}while((g|0)<(f|0));if(d){t=0}else{return}do{d=t<<1;b[a+(d<<1)>>1]=b[c+(t+f<<1)>>1]|0;b[a+((d|1)<<1)>>1]=b[c+(t<<1)>>1]|0;t=t+1|0;}while((t|0)<(f|0));return}function xkb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=i;i=i+24|0;j=h;k=c[a+32>>2]|0;l=c[a+36>>2]|0;m=c[a+40>>2]|0;n=c[a+44>>2]|0;o=a+56+(b*36|0)+32|0;p=c[o>>2]|0;q=a+((b*36|0)+56)|0;c[j>>2]=c[q>>2];c[j+4>>2]=c[q+4>>2];c[j+8>>2]=c[q+8>>2];c[j+12>>2]=c[q+12>>2];j=k;k=l;l=m;m=n;n=c[a>>2]|0;b=p+3|0;r=e-1|0;if(b>>>0>r>>>0){s=r<<1;t=b;while(1){u=((t|0)>0?s:0)-t|0;if(u>>>0>r>>>0){t=u}else{v=u;break}}}else{v=b}t=n+((ba(v,f)|0)<<1)|0;c[h+16>>2]=t;v=p+4|0;if(v>>>0>r>>>0){s=r<<1;u=v;while(1){w=((u|0)>0?s:0)-u|0;if(w>>>0>r>>>0){u=w}else{x=w;break}}}else{x=v}v=n+((ba(x,f)|0)<<1)|0;c[h+20>>2]=v;if(b>>>0<e>>>0){cf[l&1023](c[h+12>>2]|0,t,v,d)}if((p+2|0)>>>0<e>>>0){cf[m&1023](c[h+8>>2]|0,c[h+12>>2]|0,t,d)}if((p+1|0)>>>0<e>>>0){cf[j&1023](c[h+4>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0,d)}j=p>>>0<e>>>0;if(j){cf[k&1023](c[h>>2]|0,c[h+4>>2]|0,c[h+8>>2]|0,d)}if((p-1|0)>>>0<e>>>0){Xe[c[a+52>>2]&4095](c[h>>2]|0,c[a+4>>2]|0,d)}if(!j){y=h+8|0;z=y;c[q>>2]=c[z>>2];c[q+4>>2]=c[z+4>>2];c[q+8>>2]=c[z+8>>2];c[q+12>>2]=c[z+12>>2];A=c[o>>2]|0;B=A+2|0;c[o>>2]=B;i=g;return}Xe[c[a+52>>2]&4095](c[h+4>>2]|0,c[a+4>>2]|0,d);y=h+8|0;z=y;c[q>>2]=c[z>>2];c[q+4>>2]=c[z+4>>2];c[q+8>>2]=c[z+8>>2];c[q+12>>2]=c[z+12>>2];A=c[o>>2]|0;B=A+2|0;c[o>>2]=B;i=g;return}function ykb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(((((b[d+(g<<1)>>1]|0)+(b[a+(g<<1)>>1]|0)|0)*217|0)+2048|0)>>>12)+(e[h>>1]|0);g=g+1|0;}while((g|0)<(f|0));return}function zkb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(((((b[d+(g<<1)>>1]|0)+(b[a+(g<<1)>>1]|0)|0)*6497|0)+2048|0)>>>12)+(e[h>>1]|0);g=g+1|0;}while((g|0)<(f|0));return}function Akb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(e[h>>1]|0)-(((((b[d+(g<<1)>>1]|0)+(b[a+(g<<1)>>1]|0)|0)*1817|0)+2048|0)>>>12);g=g+1|0;}while((g|0)<(f|0));return}function Bkb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(e[h>>1]|0)-(((((b[d+(g<<1)>>1]|0)+(b[a+(g<<1)>>1]|0)|0)*113|0)+64|0)>>>7);g=g+1|0;}while((g|0)<(f|0));return}function Ckb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=d>>1;g=(e[a>>1]|0)-((((b[a+(f<<1)>>1]|0)*3634|0)+2048|0)>>>12)&65535;b[c>>1]=g;h=(f|0)>1;a:do{if(h){i=1;j=g;while(1){k=i+f|0;l=k-1|0;m=a+(l<<1)|0;n=(e[a+(i<<1)>>1]|0)-(((((b[a+(k<<1)>>1]|0)+(b[m>>1]|0)|0)*1817|0)+2048|0)>>>12)&65535;k=c+(i<<1)|0;b[k>>1]=n;b[c+(l<<1)>>1]=(e[m>>1]|0)-(((((n<<16>>16)+(j<<16>>16)|0)*113|0)+64|0)>>>7);n=i+1|0;if((n|0)>=(f|0)){break a}i=n;j=b[k>>1]|0}}}while(0);g=d-1|0;d=a+(g<<1)|0;j=c+(g<<1)|0;b[j>>1]=(e[d>>1]|0)-((((b[c+(f-1<<1)>>1]|0)*226|0)+64|0)>>>7);g=(((b[c+(f<<1)>>1]|0)*434|0)+2048>>12)+(b[c>>1]|0)|0;b[a>>1]=(g+1|0)>>>1;if(h){o=g;p=1}else{q=g;r=b[j>>1]|0;s=r<<16>>16;t=q*12994|0;u=t+2048|0;v=u>>>12;w=v+1|0;x=w+s|0;y=x>>>1;z=y&65535;b[d>>1]=z;return}while(1){g=p+f|0;h=b[c+(g-1<<1)>>1]|0;i=((((b[c+(g<<1)>>1]|0)+h|0)*217|0)+2048>>12)+(b[c+(p<<1)>>1]|0)|0;g=p<<1;b[a+(g-1<<1)>>1]=(h+1+((((i+o|0)*6497|0)+2048|0)>>>12)|0)>>>1;b[a+(g<<1)>>1]=(i+1|0)>>>1;g=p+1|0;if((g|0)<(f|0)){o=i;p=g}else{q=i;break}}r=b[j>>1]|0;s=r<<16>>16;t=q*12994|0;u=t+2048|0;v=u>>>12;w=v+1|0;x=w+s|0;y=x>>>1;z=y&65535;b[d>>1]=z;return}function Dkb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[a+24>>2]|0;e=c[a+20>>2]|0;if((e|0)<=0){return}f=a+8|0;g=a+12|0;h=a+16|0;i=a+28|0;j=e;do{j=j-1|0;e=c[f>>2]>>j;k=c[g>>2]>>j;l=c[h>>2]<<j;m=a+56+(j*36|0)+32|0;n=(b>>j)+d|0;o=(n|0)>(k|0)?k:n;if((c[m>>2]|0)<=(o|0)){do{le[c[i>>2]&1023](a,j,e,k,l);}while((c[m>>2]|0)<=(o|0))}}while((j|0)>0);return}function Ekb(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;e=c[a+16>>2]|0;f=c[a+12>>2]|0;g=ba(e*27|0,f)|0;h=c[a+4>>2]|0;if((h|0)==20){i=(c[a>>2]|0)==1?g-81|0:g}else if((h|0)==24){i=(c[a>>2]|0)==1?g-108|0:g}else{i=g}g=c[a+56>>2]|0;if((b[g+((i-1|0)*12|0)>>1]|0)==0&(e|0)>0){i=a|0;j=a+36|0;k=a+64|0;l=0;m=0;n=0;o=h;while(1){if((f|0)>0){p=(m|0)!=0;q=m*11|0;r=(m|0)==0;s=m<<2;t=-(m&1)|0;u=t&9;v=m>>>1;w=m*10|0;x=m>>1;y=x+4|0;z=t&6;t=x*45|0;x=l;A=0;B=n;C=o;while(1){D=(A|0)==11;E=(A|0)>9;F=(A+q|0)*27|0;G=r&D;H=(A+w|0)*27|0;I=(A|0)/5|0;J=0;K=x;L=B+6|0;M=C;while(1){N=(((J|0)%3|0|0)==0)+L|0;if((M|0)==20){if(p&(c[i>>2]|0)==1&D){O=K;P=20}else{Q=h;R=11}}else{Q=M;R=11}do{if((R|0)==11){R=0;if((Q|0)==24){if((c[i>>2]|0)==1&E){O=K;P=24;break}}S=J+F|0;T=S+s|0;U=((S|0)/11|0|0)%27|0;S=(U|0)/9|0;V=J+H|0;W=(V<<1)+s+I|0;X=((V|0)/5|0|0)%27|0;V=(X|0)%9|0;Y=(X|0)/9|0;Z=(J|0)/3|0;_=1347200+J|0;$=c[j>>2]|0;if(G){aa=V+u|0;ca=0;do{do{if(($|0)==960){da=((d[1347360+ca|0]|0)+W|0)%10|0;ea=(-(da&1)&3)+X|0;b[g+(K*12|0)+2+(ca<<1)>>1]=((ea|0)/6|0)+t+(d[1347376+da|0]|0)<<9|((ea|0)%6|0)+z+(d[1347152+ca|0]|0)<<1}else if(($|0)==1280){ea=aa+(d[1347160+ca|0]|0)|0;da=(((((d[1347360+ca|0]|0)+W|0)%10|0)*3|0)+Y<<1)+y|0;if((ea|0)>79){fa=d[1347233+(da<<1)|0]|0;ga=(d[1347232+(da<<1)|0]|0)+(ea-80<<((da|0)>59))|0}else{fa=da;ga=ea}b[g+(K*12|0)+2+(ca<<1)>>1]=fa<<9|ga<<1}else if(($|0)==720){ea=c[k>>2]|0;if((ea|0)==7){if((ca|0)==1){ha=3}else{ha=(ca|0)==2?3:0}da=ha+J|0;ia=(d[1347368+ca|0]|0)+((da|0)/6|0)|0;ja=(((d[1347360+ca|0]|0)+11|0)%(f|0)|0)*6|0;ka=(d[1347168+da|0]|0)+ja|0;if((ia|0)>21){la=(ka<<1)-ja|0}else{la=ka}b[g+(K*12|0)+2+(ca<<1)>>1]=la<<8|ia<<2;break}else if((ea|0)==4){b[g+(K*12|0)+2+(ca<<1)>>1]=((((d[1347360+ca|0]|0)+11|0)%(f|0)|0)*6|0)+(d[_]|0)<<8|(d[1347144+ca|0]|0)+Z<<1;break}else if((ea|0)==0){b[g+(K*12|0)+2+(ca<<1)>>1]=((((d[1347360+ca|0]|0)+11|0)%(f|0)|0)*3|0)+(d[_]|0)<<9|(d[1347144+ca|0]|0)+Z<<1;break}else{break}}else if(($|0)==1440){ea=(ca*27|0)+J|0;if((ea|0)<90){ma=0;na=ea}else{ma=34304;na=(ea<<1)-180|0}b[g+(K*12|0)+2+(ca<<1)>>1]=na<<1|ma}}while(0);ca=ca+1|0;}while((ca|0)<5)}else{ca=((U|0)%9|0)+u|0;aa=V+u|0;ea=0;do{do{if(($|0)==1440){b[g+(K*12|0)+2+(ea<<1)>>1]=(((((T+(d[1347360+ea|0]|0)|0)%11|0)*3|0)+S<<1)+v<<9)+512|ca+(d[1347160+ea|0]|0)<<1}else if(($|0)==1280){ia=aa+(d[1347160+ea|0]|0)|0;ka=(((((d[1347360+ea|0]|0)+W|0)%10|0)*3|0)+Y<<1)+y|0;if((ia|0)>79){oa=d[1347233+(ka<<1)|0]|0;pa=(d[1347232+(ka<<1)|0]|0)+(ia-80<<((ka|0)>59))|0}else{oa=ka;pa=ia}b[g+(K*12|0)+2+(ea<<1)>>1]=oa<<9|pa<<1}else if(($|0)==960){ia=((d[1347360+ea|0]|0)+W|0)%10|0;ka=(-(ia&1)&3)+X|0;b[g+(K*12|0)+2+(ea<<1)>>1]=((ka|0)/6|0)+t+(d[1347376+ia|0]|0)<<9|((ka|0)%6|0)+z+(d[1347152+ea|0]|0)<<1}else if(($|0)==720){ka=c[k>>2]|0;if((ka|0)==4){b[g+(K*12|0)+2+(ea<<1)>>1]=((((((d[1347360+ea|0]|0)+A|0)%(f|0)|0)<<1)+m|0)*3|0)+(d[_]|0)<<8|(d[1347144+ea|0]|0)+Z<<1;break}else if((ka|0)==0){b[g+(K*12|0)+2+(ea<<1)>>1]=((((d[1347360+ea|0]|0)+A|0)%(f|0)|0)*3|0)+(d[_]|0)<<9|(d[1347144+ea|0]|0)+Z<<1;break}else if((ka|0)==7){if((ea|0)==1){qa=3}else{qa=(ea|0)==2?3:0}ka=qa+J|0;ia=(d[1347368+ea|0]|0)+((ka|0)/6|0)|0;ja=(((d[1347360+ea|0]|0)+A|0)%(f|0)|0)*6|0;da=(d[1347168+ka|0]|0)+ja|0;if((ia|0)>21){ra=(da<<1)-ja|0}else{ra=da}b[g+(K*12|0)+2+(ea<<1)>>1]=ra<<8|ia<<2;break}else{break}}}while(0);ea=ea+1|0;}while((ea|0)<5)}b[g+(K*12|0)>>1]=N;O=K+1|0;P=Q}}while(0);sa=N+5|0;ea=J+1|0;if((ea|0)<27){J=ea;K=O;L=sa;M=P}else{break}}M=A+1|0;if((M|0)<(f|0)){x=O;A=M;B=sa;C=P}else{ta=O;ua=sa;va=P;break}}}else{ta=l;ua=n;va=o}C=m+1|0;if((C|0)<(e|0)){l=ta;m=C;n=ua;o=va}else{break}}}va=h&16;h=(va|0)!=0;o=c[a+60>>2]|0;if((c[o+((h?8191:5631)<<2)>>2]|0)!=0){return 0}ua=h?4096:2816;h=o+(ua<<2)|0;n=(c[a+32>>2]|0)==720;a=n?1228656:1229424;m=n?1228912:1229680;if((va|0)==0){va=0;n=o;ta=h;l=1228400;while(1){e=0;P=n;sa=ta;do{O=(d[1228216+(e<<2)|0]|0)+1|0;f=sa+24|0;Q=0;g=P;ra=sa;while(1){qa=c[l+(Q<<2)>>2]<<O;c[g>>2]=qa;c[ra>>2]=qa<<1;qa=Q+1|0;if((qa|0)<6){Q=qa;g=g+4|0;ra=ra+4|0}else{break}}ra=(d[1228217+(e<<2)|0]|0)+1|0;g=sa+84|0;Q=6;O=P+24|0;qa=f;while(1){k=c[l+(Q<<2)>>2]<<ra;c[O>>2]=k;c[qa>>2]=k<<1;k=Q+1|0;if((k|0)<21){Q=k;O=O+4|0;qa=qa+4|0}else{break}}qa=(d[1228218+(e<<2)|0]|0)+1|0;O=sa+172|0;Q=21;ra=P+84|0;f=g;while(1){k=c[l+(Q<<2)>>2]<<qa;c[ra>>2]=k;c[f>>2]=k<<1;k=Q+1|0;if((k|0)<43){Q=k;ra=ra+4|0;f=f+4|0}else{break}}f=(d[1228219+(e<<2)|0]|0)+1|0;sa=sa+256|0;ra=43;Q=P+172|0;qa=O;while(1){g=c[l+(ra<<2)>>2]<<f;c[Q>>2]=g;c[qa>>2]=g<<1;g=ra+1|0;if((g|0)<64){ra=g;Q=Q+4|0;qa=qa+4|0}else{break}}P=P+256|0;e=e+1|0;}while((e|0)<22);e=va+1|0;if((e|0)<2){va=e;n=P;ta=sa;l=1229168}else{break}}return 0}l=o+4096|0;ta=0;n=o;va=h;while(1){h=d[1348048+ta|0]<<9;e=va+256|0;qa=0;Q=n;ra=va;while(1){c[Q>>2]=ba(h,c[a+(qa<<2)>>2]|0)|0;c[ra>>2]=ba(h,c[m+(qa<<2)>>2]|0)|0;f=qa+1|0;if((f|0)<64){qa=f;Q=Q+4|0;ra=ra+4|0}else{break}}ra=ta+1|0;if((ra|0)<16){ta=ra;n=n+256|0;va=e}else{break}}va=ua|1024;ua=o+8192|0;n=0;ta=l;l=o+(va<<2)|0;while(1){ra=d[1348048+n|0]<<10;Q=l+256|0;qa=0;h=ta;sa=l;while(1){c[h>>2]=ba(ra,c[a+(qa<<2)>>2]|0)|0;c[sa>>2]=ba(ra,c[m+(qa<<2)>>2]|0)|0;P=qa+1|0;if((P|0)<64){qa=P;h=h+4|0;sa=sa+4|0}else{break}}sa=n+1|0;if((sa|0)<16){n=sa;ta=ta+256|0;l=Q}else{break}}l=o+12288|0;ta=0;n=ua;ua=o+(va+1024<<2)|0;while(1){sa=d[1348048+ta|0]<<11;h=ua+256|0;qa=0;ra=n;e=ua;while(1){c[ra>>2]=ba(sa,c[a+(qa<<2)>>2]|0)|0;c[e>>2]=ba(sa,c[m+(qa<<2)>>2]|0)|0;P=qa+1|0;if((P|0)<64){qa=P;ra=ra+4|0;e=e+4|0}else{break}}e=ta+1|0;if((e|0)<16){ta=e;n=n+256|0;ua=h}else{break}}ua=0;n=l;l=o+(va+2048<<2)|0;while(1){va=d[1348048+ua|0]<<12;o=l+256|0;ta=0;e=n;ra=l;while(1){c[e>>2]=ba(va,c[a+(ta<<2)>>2]|0)|0;c[ra>>2]=ba(va,c[m+(ta<<2)>>2]|0)|0;qa=ta+1|0;if((qa|0)<64){ta=qa;e=e+4|0;ra=ra+4|0}else{break}}ra=ua+1|0;if((ra|0)<16){ua=ra;n=n+256|0;l=o}else{break}}return 0}function Fkb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+6200|0;g=f|0;h=f+1248|0;j=f+1272|0;k=f+2912|0;l=f+3736|0;m=f+4560|0;n=c[e+60>>2]|0;if(!(a[1225512]|0)){a[1225512]=1;o=0;p=0;do{q=b[1227392+(p<<1)>>1]|0;r=j+(o<<1)|0;b[r>>1]=q;s=a[1226976+p|0]|0;t=k+o|0;a[t]=s;u=a[1226144+p|0]|0;a[l+o|0]=u;v=a[1226560+p|0]|0;w=v&255;b[m+(o<<1)>>1]=w;if(v<<24>>24==0){x=o}else{v=q<<1;b[r>>1]=v;r=s+1&255;a[t]=r;t=o+1|0;b[j+(t<<1)>>1]=v|1;a[k+t|0]=r;a[l+t|0]=u;b[m+(t<<1)>>1]=-w;x=t}p=p+1|0;o=x+1|0;}while((p|0)<409);N_(h,9,o,k|0,1,1,j,2,2,0,0,0,0)|0;j=c[h+8>>2]|0;if((j|0)>0){k=c[h+4>>2]|0;o=0;do{p=b[k+(o<<2)>>1]|0;x=p<<16>>16;t=b[k+(o<<2)+2>>1]|0;if(t<<16>>16<0){y=0;z=p}else{y=(a[l+x|0]|0)+1&255;z=b[m+(x<<1)>>1]|0}a[7553490+(o<<2)|0]=t;b[7553488+(o<<2)>>1]=z;a[7553491+(o<<2)|0]=y;o=o+1|0;}while((o|0)<(j|0))}Q_(h)}TGb(g|0,0,1244)|0;Z3(g,e);V3(g,g+484|0,c[e+244>>2]|0);c[n+144>>2]=c[g>>2];c[n+164>>2]=c[g+504>>2];c[n+148>>2]=c[g+1108>>2];c[n+156>>2]=c[g+1120>>2];h=0;do{a[n+(h+16)|0]=a[(d[1075976+h|0]|0)+(g+1128)|0]|0;h=h+1|0;}while((h|0)<64);c[n+152>>2]=c[g+1112>>2];c[n+160>>2]=534;if((c[e+800>>2]|0)==0){UGb(n+80|0,1076040,64)|0;A=n+8|0;B=A;c[B>>2]=e;C=e+400|0;c[C>>2]=3;i=f;return 0}else{h=0;do{j=d[1076040+h|0]|0;a[n+(h+80)|0]=a[(j<<2&32|j&7|j>>>1&24)+(g+1128)|0]|0;h=h+1|0;}while((h|0)<64);A=n+8|0;B=A;c[B>>2]=e;C=e+400|0;c[C>>2]=3;i=f;return 0}return 0}function Gkb(b){b=b|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0.0,N=0.0,O=0.0,P=0,Q=0,S=0,T=0,U=0,V=0;e=i;i=i+120|0;f=e|0;h=e+24|0;j=e+48|0;UGb(f|0,1225040,17)|0;k=b+904|0;l=c[k>>2]|0;m=b+908|0;n=c[m>>2]|0;if((n|0)>0){o=c[b+896>>2]|0;p=0;q=0;r=l;while(1){s=a[b+912+q|0]|0;t=s&255;if((t+r|0)>(o|0)){a[h+(p&255)|0]=r-l;a[f+q|0]=1;u=l;v=p+1&255}else{u=r;v=p}if(s<<24>>24==0){w=v;x=u}else{s=v;y=0;z=u;while(1){if((z|0)==(o|0)){a[h+(s&255)|0]=o-l;A=l;B=s+1&255}else{A=z;B=s}C=t-y|0;D=o-A|0;E=(C|0)>(D|0)?D:C;C=E+A|0;D=E+y|0;if((D|0)<(t|0)){s=B;y=D;z=C}else{w=B;x=C;break}}}z=q+1|0;if((z|0)<(n|0)){p=w;q=z;r=x}else{F=w;G=x;break}}}else{F=0;G=l}a[h+(F&255)|0]=G-l;l=b+44924|0;G=c[l>>2]|0;if((G|0)<1){i=e;return}x=F+1&255;F=b+896|0;w=x&255;r=x<<24>>24==0;x=b+54460|0;q=1;p=G;G=n;while(1){if((a[b+880+q|0]|0)==0){H=p;I=G}else{if(r){J=G}else{n=0;B=c[F>>2]|0;while(1){A=d[h+n|0]|0;UGb(b+63232+(q<<10)+(B<<2)|0,b+63232+(q<<10)+(c[k>>2]<<2)|0,A<<2)|0;o=n+1|0;if((o|0)>=(w|0)){break}n=o;B=A+B|0}J=c[m>>2]|0}B=(J|0)>0;if(B){n=0;A=c[F>>2]|0;while(1){o=a[b+912+n|0]|0;u=o&255;if(o<<24>>24==0){K=0.0;L=A}else{o=u>>>0>1>>>0?u:1;M=0.0;v=0;z=A;while(1){N=+g[b+63232+(q<<10)+(z<<2)>>2];O=M+N*N;y=v+1|0;if((y|0)<(u|0)){M=O;v=y;z=z+1|0}else{break}}K=O;L=A+o|0}g[j+(n<<2)>>2]=+R(K/+(u|0));z=n+1|0;if((z|0)<(J|0)){n=z;A=L}else{break}}}A=a[b+887+q|0]|0;a:do{if(A<<24>>24>-1){n=A<<24>>24;z=1223816+(n*12|0)|0;if(!B){P=J;break}v=1223820+(n*12|0)|0;y=1223824+(n*12|0)|0;n=0;s=(c[F>>2]|0)-2|0;t=J;while(1){if((a[f+n|0]|0)==0){Q=t}else{C=b+63232+(q<<10)+(s<<2)|0;M=+g[z>>2];g[C>>2]=M*+g[C>>2];N=+g[v>>2];C=b+63232+(q<<10)+(s+1<<2)|0;g[C>>2]=N*+g[C>>2];C=b+63232+(q<<10)+(s+2<<2)|0;g[C>>2]=+g[y>>2]*+g[C>>2];C=b+63232+(q<<10)+(s+3<<2)|0;g[C>>2]=N*+g[C>>2];C=b+63232+(q<<10)+(s+4<<2)|0;g[C>>2]=M*+g[C>>2];Q=c[m>>2]|0}C=n+1|0;if((C|0)>=(Q|0)){S=Q;T=32;break a}D=(d[b+912+n|0]|0)+s|0;n=C;s=D;t=Q}}else{S=J;T=32}}while(0);do{if((T|0)==32){T=0;if((S|0)<=0){P=S;break}B=0;A=c[F>>2]|0;t=S;while(1){M=+g[b+936+(q*68|0)+(B<<2)>>2]*+g[j+(B<<2)>>2]*-4.656612873077393e-10;N=+g[b+1412+(q*68|0)+(B<<2)>>2];s=b+912+B|0;if((a[s]|0)==0){U=A;V=t}else{n=0;y=A;do{v=c[x>>2]|0;c[b+54204+((v&63)<<2)>>2]=(c[b+54204+((v+9&63)<<2)>>2]|0)+(c[b+54204+((v+40&63)<<2)>>2]|0);v=c[x>>2]|0;c[x>>2]=v+1;z=b+63232+(q<<10)+(y<<2)|0;y=y+1|0;g[z>>2]=N*+g[z>>2]+M*+(c[b+54204+((v&63)<<2)>>2]|0);n=n+1|0;}while((n|0)<(d[s]|0));U=y;V=c[m>>2]|0}s=B+1|0;if((s|0)<(V|0)){B=s;A=U;t=V}else{P=V;break}}}}while(0);H=c[l>>2]|0;I=P}t=q+1|0;if((t|0)>(H|0)){break}else{q=t;p=H;G=I}}i=e;return}function Hkb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=i;i=i+1024|0;h=g|0;j=e+16|0;k=c[j>>2]|0;l=e+24|0;m=c[l>>2]|0;n=e+8|0;o=c[n>>2]|0;p=o+(k>>>3)|0;q=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(k&7);p=q>>>30;r=k+2|0;k=m>>>0>r>>>0?r:m;c[j>>2]=k;r=(q>>31&5)+12|0;q=p-1|0;do{if(q>>>0<2>>>0){s=e+45016+(f<<2)|0;t=c[s>>2]|0;u=e+45044+(f<<2)|0;v=c[u>>2]|0;if((t|0)<(v|0)){w=0;x=t;y=k;z=v}else{A=v;B=s;break}while(1){v=a[e+47176+(f<<8)+x|0]|0;if((v&255)>>>0>7>>>0&(v&255)>>>0<r>>>0){v=d[o+(y>>>3)|0]<<(y&7)>>>7;t=((y|0)<(m|0))+y|0;c[j>>2]=t;c[h+(w<<2)>>2]=(v&1)<<q;C=w+1|0;D=t;E=c[u>>2]|0}else{C=w;D=y;E=z}t=x+1|0;if((t|0)<(E|0)){w=C;x=t;y=D;z=E}else{A=E;B=s;break}}}else{if((p|0)!=3){A=c[e+45044+(f<<2)>>2]|0;B=e+45016+(f<<2)|0;break}s=e+45016+(f<<2)|0;u=c[s>>2]|0;t=e+45044+(f<<2)|0;v=c[t>>2]|0;if((u|0)>=(v|0)){A=v;B=s;break}G=e+4|0;H=2;I=0;J=u;u=v;while(1){do{if(((a[e+47176+(f<<8)+J|0]|0)-8&255)>>>0<9>>>0){if((H|0)!=2){K=I;L=H+1|0;M=u;break}v=c[j>>2]|0;N=c[l>>2]|0;O=(c[n>>2]|0)+(v>>>3)|0;P=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(v&7);O=v+5|0;c[j>>2]=N>>>0>O>>>0?O:N;if(P>>>0>3623878655>>>0){yDb(c[G>>2]|0,24,2178240,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;Q=26}else{Q=P>>>27}c[h+(I<<2)>>2]=d[1274768+(Q*3|0)|0]|0;c[h+(I+1<<2)>>2]=d[1274769+(Q*3|0)|0]|0;c[h+(I+2<<2)>>2]=d[1274770+(Q*3|0)|0]|0;K=I+3|0;L=0;M=c[t>>2]|0}else{K=I;L=H;M=u}}while(0);P=J+1|0;if((P|0)<(M|0)){H=L;I=K;J=P;u=M}else{A=M;B=s;break}}}}while(0);M=c[B>>2]|0;B=e+45044+(f<<2)|0;if((M|0)>=(A|0)){i=g;return}A=(p|0)!=0;p=e+54460|0;K=0;L=M;while(1){M=a[e+47176+(f<<8)+L|0]|0;Q=M&255;E=d[1225016+Q|0]|0;a:do{if(M<<24>>24==0){z=0;while(1){D=c[p>>2]|0;c[e+54204+((D&63)<<2)>>2]=(c[e+54204+((D+9&63)<<2)>>2]|0)+(c[e+54204+((D+40&63)<<2)>>2]|0);D=c[p>>2]|0;c[p>>2]=D+1;c[e+1916+(f*6144|0)+(L*24|0)+(z<<2)>>2]=(c[e+54204+((D&63)<<2)>>2]&8388607)-4194304;D=z+1|0;if((D|0)<6){z=D}else{R=K;break}}}else{if((M&255)>>>0<8>>>0){z=c[j>>2]|0;D=c[l>>2]|0;y=(c[n>>2]|0)+(z>>>3)|0;x=(fe(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(z&7)>>>((32-E|0)>>>0);y=z+E|0;c[j>>2]=D>>>0>y>>>0?y:D;D=c[1224288+(Q<<2)>>2]|0;c[e+1916+(f*6144|0)+(L*24|0)>>2]=b[D+(x*12|0)>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+4>>2]=b[D+(x*12|0)+2>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+8>>2]=b[D+(x*12|0)+4>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+12>>2]=b[D+(x*12|0)+6>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+16>>2]=b[D+(x*12|0)+8>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+20>>2]=b[D+(x*12|0)+10>>1]<<8;R=K;break}if(A&Q>>>0<r>>>0){S=c[h+(K<<2)>>2]|0;T=K+1|0}else{S=0;T=K}x=E-S|0;D=32-x|0;y=24-E|0;z=Q-8|0;C=1224464+(z<<1)|0;w=-1<<x-1;q=E-2+S|0;m=32-q|0;o=24-q|0;k=1<<23-S;s=S-1|0;u=1224424+(z<<2)+(s<<1)|0;J=1224384+(z<<2)+(s<<1)|0;if((S|0)==0){s=0;while(1){z=c[j>>2]|0;I=c[l>>2]|0;H=(c[n>>2]|0)+(z>>>3)|0;t=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=z+x|0;c[j>>2]=I>>>0>H>>>0?H:I;I=(fe(t|0)|0)<<(z&7)>>D<<y;z=b[C>>1]|0;t=I;H=(I|0)<0|0?-1:0;I=gHb(z<<16>>16,z<<16>>16<0|0?-1:0,t,H)|0;z=F;G=YGb(I>>>15|z<<17,z>>>15|0<<17,t,H)|0;c[e+1916+(f*6144|0)+(L*24|0)+(s<<2)>>2]=G;G=s+1|0;if((G|0)<6){s=G}else{R=T;break a}}}else{U=0}while(1){s=c[j>>2]|0;C=c[l>>2]|0;G=c[n>>2]|0;H=G+(s>>>3)|0;t=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(s&7)>>D;H=s+x|0;s=C>>>0>H>>>0?H:C;c[j>>2]=s;if((t|0)==(w|0)){H=G+(s>>>3)|0;G=(fe(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(s&7)>>m;H=s+q|0;c[j>>2]=C>>>0>H>>>0?H:C;C=G<<o;if((C|0)>-1){V=k}else{V=b[J>>1]<<8}G=b[u>>1]|0;H=C;s=(C|0)<0|0?-1:0;C=gHb(G<<16>>16,G<<16>>16<0|0?-1:0,H,s)|0;G=F;z=YGb(V,0,H,s)|0;s=YGb(z,F,C>>>15|G<<17,G>>>15|0<<17)|0;W=s}else{W=t<<y}c[e+1916+(f*6144|0)+(L*24|0)+(U<<2)>>2]=W;t=U+1|0;if((t|0)<6){U=t}else{R=T;break}}}}while(0);E=e+1916+(f*6144|0)+(L*24|0)|0;Q=e+1916+(f*6144|0)+(L*24|0)+4|0;M=c[Q>>2]|0;y=e+1916+(f*6144|0)+(L*24|0)+12|0;u=c[y>>2]|0;J=e+1916+(f*6144|0)+(L*24|0)+20|0;k=c[J>>2]|0;o=M-u-k|0;q=e+1916+(f*6144|0)+(L*24|0)+8|0;m=c[q>>2]|0;w=gHb(m,(m|0)<0|0?-1:0,10273905,0)|0;m=w>>>23|F<<9;w=e+1916+(f*6144|0)+(L*24|0)+16|0;x=c[w>>2]|0;D=gHb(x,(x|0)<0|0?-1:0,11863283,0)|0;x=D>>>23|F<<9;D=k+M|0;t=gHb(D,(D|0)<0|0?-1:0,3070444,0)|0;D=t>>>23|F<<9;t=c[E>>2]|0;s=(x>>1)+t|0;G=t-x|0;x=s+m|0;t=s-m|0;m=u+M+D|0;M=D+(k-u)|0;c[E>>2]=x+m;c[Q>>2]=G+o;c[q>>2]=t+M;c[y>>2]=t-M;c[w>>2]=G-o;c[J>>2]=x-m;m=L+1|0;if((m|0)<(c[B>>2]|0)){K=R;L=m}else{break}}i=g;return}function Ikb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;g=i;h=f+28|0;j=c[h>>2]|0;if((j|0)==3){yDb(c[f+4>>2]|0,16,2173976,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-84085770;i=g;return l|0}else if((j|0)==1){DDb(c[f+4>>2]|0,2304304,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-84085770;i=g;return l|0}else{if((c[f+32>>2]|0)!=0){DDb(c[f+4>>2]|0,2099056,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-84085770;i=g;return l|0}if((c[f+47080>>2]|0)==3){DDb(c[f+4>>2]|0,2043800,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=g;return l|0}m=f+16|0;n=f+24|0;o=c[n>>2]|0;p=(c[m>>2]|0)+5|0;q=o>>>0>p>>>0?p:o;c[m>>2]=q;p=f+60|0;r=f+8|0;s=c[r>>2]|0;t=0;u=q;while(1){q=u+5|0;v=o>>>0>q>>>0?q:o;c[m>>2]=v;q=((v|0)<(o|0))+v|0;if((128>>>((v&7)>>>0)&d[s+(v>>>3)|0]|0)==0){w=q;x=q}else{v=q+8|0;q=o>>>0>v>>>0?v:o;w=q;x=q}c[m>>2]=x;q=t+1|0;y=c[p>>2]|0;z=(y|0)!=0?1:2;if((q|0)<(z|0)){t=q;u=w}else{break}}do{if((j|0)==1){u=d[s+(w>>>3)|0]|0;t=((w|0)<(o|0))+w|0;c[m>>2]=t;if((u&128>>>((w&7)>>>0)|0)==0){A=t;break}u=t+16|0;t=o>>>0>u>>>0?u:o;c[m>>2]=t;A=t}else{A=w}}while(0);w=d[s+(A>>>3)|0]|0;t=((A|0)<(o|0))+A|0;c[m>>2]=t;do{if((w&128>>>((A&7)>>>0)|0)==0){B=t;C=j}else{do{if((y|0)>2){u=s+(t>>>3)|0;x=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7)>>>30;u=t+2|0;q=o>>>0>u>>>0?u:o;c[m>>2]=q;c[f+72>>2]=x;if((y&1|0)==0){D=q}else{x=s+(q>>>3)|0;u=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>29;x=q+3|0;q=o>>>0>x>>>0?x:o;c[m>>2]=q;c[f+80>>2]=u;u=s+(q>>>3)|0;x=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(q&7)>>>29;u=q+3|0;q=o>>>0>u>>>0?u:o;c[m>>2]=q;c[f+76>>2]=x;D=q}if((y&4|0)==0){E=D;break}q=s+(D>>>3)|0;x=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(D&7)>>>29;q=D+3|0;u=o>>>0>q>>>0?q:o;c[m>>2]=u;c[f+88>>2]=x>>>0<3>>>0?3:x;x=s+(u>>>3)|0;q=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(u&7)>>>29;x=u+3|0;u=o>>>0>x>>>0?x:o;c[m>>2]=u;c[f+84>>2]=q>>>0<3>>>0?3:q;E=u}else{E=t}}while(0);do{if((c[f+64>>2]|0)==0){F=E}else{u=d[s+(E>>>3)|0]<<(E&7)>>>7;q=((E|0)<(o|0))+E|0;c[m>>2]=q;x=u&1;c[f+92>>2]=x;if((x|0)==0){F=q;break}x=s+(q>>>3)|0;u=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>27;x=q+5|0;q=o>>>0>x>>>0?x:o;c[m>>2]=q;c[f+96>>2]=u;F=q}}while(0);if((j|0)==0){G=0;H=F}else{B=F;C=j;break}while(1){q=d[s+(H>>>3)|0]|0;I=((H|0)<(o|0))+H|0;c[m>>2]=I;J=(q&128>>>((H&7)>>>0)|0)!=0;if((G|0)>=(z|0)){break}if(J){q=I+6|0;u=o>>>0>q>>>0?q:o;c[m>>2]=u;K=u}else{K=I}G=G+1|0;H=K}if(J){u=I+6|0;q=o>>>0>u>>>0?u:o;c[m>>2]=q;L=q}else{L=I}q=s+(L>>>3)|0;u=(fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(L&7)>>>30;q=L+2|0;x=o>>>0>q>>>0?q:o;c[m>>2]=x;if((u|0)==1){q=x+5|0;v=o>>>0>q>>>0?q:o;c[m>>2]=v;M=v}else if((u|0)==2){v=x+12|0;q=o>>>0>v>>>0?v:o;c[m>>2]=q;M=q}else if((u|0)==3){u=s+(x>>>3)|0;q=(fe(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(x&7)>>>27;u=x+5|0;v=o>>>0>u>>>0?u:o;c[m>>2]=v;u=(q<<3)+16|0;q=-v|0;N=o-v|0;if((u|0)<(q|0)){O=q}else{O=(N|0)<(u|0)?N:u}u=O+v|0;c[m>>2]=u;M=u}else{M=x}if((y|0)<2){x=0;u=M;while(1){v=((u|0)<(o|0))+u|0;if((d[s+(u>>>3)|0]&128>>>((u&7)>>>0)|0)==0){P=v}else{N=v+8|0;v=(o>>>0>N>>>0?N:o)+6|0;P=o>>>0>v>>>0?v:o}c[m>>2]=P;v=x+1|0;if((v|0)<(z|0)){x=v;u=P}else{Q=P;break}}}else{Q=M}u=d[s+(Q>>>3)|0]|0;x=((Q|0)<(o|0))+Q|0;c[m>>2]=x;if((u&128>>>((Q&7)>>>0)|0)==0){B=x;C=0;break}u=c[f+48>>2]|0;if((u|0)>0){R=0;S=x}else{B=x;C=0;break}while(1){if((u|0)==1){T=S;U=45}else{x=((S|0)<(o|0))+S|0;if((d[s+(S>>>3)|0]&128>>>((S&7)>>>0)|0)==0){V=x}else{T=x;U=45}}if((U|0)==45){U=0;x=T+5|0;V=o>>>0>x>>>0?x:o}c[m>>2]=V;x=R+1|0;if((x|0)<(u|0)){R=x;S=V}else{B=V;C=0;break}}}}while(0);V=d[s+(B>>>3)|0]|0;S=((B|0)<(o|0))+B|0;c[m>>2]=S;if((V&128>>>((B&7)>>>0)|0)==0){W=S}else{B=s+(S>>>3)|0;V=(fe(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(S&7)>>>29;B=S+3|0;c[f+56>>2]=V;V=(o>>>0>B>>>0?B:o)+2|0;B=o>>>0>V>>>0?V:o;c[m>>2]=B;do{if((y|0)==2){V=s+(B>>>3)|0;S=(fe(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(B&7)>>>30;V=B+2|0;R=o>>>0>V>>>0?V:o;c[m>>2]=R;c[f+104>>2]=S;S=s+(R>>>3)|0;V=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(R&7)>>>30;S=R+2|0;R=o>>>0>S>>>0?S:o;c[m>>2]=R;c[f+112>>2]=V;X=0;Y=R}else{if((y|0)<=5){X=0;Y=B;break}R=s+(B>>>3)|0;V=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(B&7)>>>30;R=B+2|0;S=o>>>0>R>>>0?R:o;c[m>>2]=S;c[f+108>>2]=V;X=0;Y=S}}while(0);while(1){B=((Y|0)<(o|0))+Y|0;if((d[s+(Y>>>3)|0]&128>>>((Y&7)>>>0)|0)==0){Z=B}else{y=B+8|0;Z=o>>>0>y>>>0?y:o}c[m>>2]=Z;y=X+1|0;if((y|0)<(z|0)){X=y;Y=Z}else{break}}Y=Z+1|0;Z=o>>>0>Y>>>0?Y:o;c[m>>2]=Z;W=Z}do{if((C|0)==0){if((c[f+48>>2]|0)==6){_=W;break}Z=W+1|0;Y=o>>>0>Z>>>0?Z:o;c[m>>2]=Y;_=Y}else if((C|0)==2){if((c[f+48>>2]|0)==6){$=W}else{Y=d[s+(W>>>3)|0]|0;Z=((W|0)<(o|0))+W|0;c[m>>2]=Z;if((Y&128>>>((W&7)>>>0)|0)==0){_=Z;break}else{$=Z}}Z=$+6|0;Y=o>>>0>Z>>>0?Z:o;c[m>>2]=Y;_=Y}else{_=W}}while(0);W=d[s+(_>>>3)|0]|0;$=((_|0)<(o|0))+_|0;c[m>>2]=$;if((W&128>>>((_&7)>>>0)|0)==0){aa=$}else{_=s+($>>>3)|0;W=(fe(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<($&7)>>>26;_=$+6|0;$=o>>>0>_>>>0?_:o;c[m>>2]=$;_=W+1|0;W=0;C=$;do{$=C+8|0;C=o>>>0>$>>>0?$:o;W=W+1|0;}while((W|0)<(_|0));c[m>>2]=C;aa=C}C=f+48|0;if((c[C>>2]|0)==6){_=d[s+(aa>>>3)|0]<<(aa&7)>>>7;W=((aa|0)<(o|0))+aa|0;c[m>>2]=W;$=d[s+(W>>>3)|0]<<(W&7)>>>7;Y=((W|0)<(o|0))+W|0;c[m>>2]=Y;ca=_&1;da=$&1;ea=Y}else{ca=1;da=0;ea=aa}aa=s+(ea>>>3)|0;Y=(fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ea&7)>>>30;aa=ea+2|0;ea=o>>>0>aa>>>0?aa:o;c[m>>2]=ea;aa=f+136|0;c[aa>>2]=Y;Y=ea&7;$=d[s+(ea>>>3)|0]|0;_=((ea|0)<(o|0))+ea|0;c[m>>2]=_;ea=d[s+(_>>>3)|0]<<(_&7)>>>7;W=((_|0)<(o|0))+_|0;c[m>>2]=W;_=ea&1;c[f+140>>2]=_;if((_|0)==0){TGb(f+54464|0,0,28)|0}_=d[s+(W>>>3)|0]<<(W&7)>>>7;c[m>>2]=((W|0)<(o|0))+W;W=_&1;c[f+144>>2]=W;do{if((W|0)==0){_=f+44924|0;if((c[_>>2]|0)<1){break}else{fa=1}do{c[f+54176+(fa<<2)>>2]=1;fa=fa+1|0;}while((fa|0)<=(c[_>>2]|0))}}while(0);fa=f+44932|0;c[f+54176+(c[fa>>2]<<2)>>2]=0;c[f+54176>>2]=0;W=c[m>>2]|0;_=c[r>>2]|0;o=d[_+(W>>>3)|0]<<(W&7)>>>7;s=c[n>>2]|0;ea=((W|0)<(s|0))+W|0;c[m>>2]=ea;W=o&1;c[f+148>>2]=W;if((W|0)==0){c[f+47092>>2]=d[1274874]|0;c[f+47096>>2]=d[1275969]|0;c[f+47088>>2]=e[637433]|0;c[f+47100>>2]=e[638230]|0;c[f+47104>>2]=b[637923]|0}W=d[_+(ea>>>3)|0]<<(ea&7)>>>7;o=((ea|0)<(s|0))+ea|0;c[m>>2]=o;c[f+152>>2]=W&1;W=d[_+(o>>>3)|0]<<(o&7)>>>7;ea=((o|0)<(s|0))+o|0;c[m>>2]=ea;c[f+156>>2]=W&1;W=d[_+(ea>>>3)|0]<<(ea&7)>>>7;o=((ea|0)<(s|0))+ea|0;c[m>>2]=o;c[f+160>>2]=W&1;W=o&7;ea=d[_+(o>>>3)|0]|0;c[m>>2]=((o|0)<(s|0))+o;do{if((c[p>>2]|0)>1){if((c[C>>2]|0)>0){ga=0;ha=0}else{ia=0;break}while(1){do{if((ha|0)==0){c[f+188>>2]=1;U=80}else{o=c[m>>2]|0;s=d[(c[r>>2]|0)+(o>>>3)|0]<<(o&7);c[m>>2]=((o|0)<(c[n>>2]|0))+o;o=s&128;c[f+188+(ha<<2)>>2]=o>>>7;if((o|0)!=0){U=80;break}o=c[f+164+(ha-1<<2)>>2]|0;c[f+164+(ha<<2)>>2]=o;ja=o}}while(0);if((U|0)==80){U=0;o=c[m>>2]|0;s=d[(c[r>>2]|0)+(o>>>3)|0]<<(o&7)>>>7;c[m>>2]=((o|0)<(c[n>>2]|0))+o;o=s&1;c[f+164+(ha<<2)>>2]=o;ja=o}o=ja+ga|0;s=ha+1|0;if((s|0)<(c[C>>2]|0)){ga=o;ha=s}else{ia=o;break}}}else{TGb(f+164|0,0,24)|0;ia=0}}while(0);do{if((ca|0)==0){if((c[p>>2]|0)>1){ka=(ia|0)==0|0}else{ka=1}ha=f+44924|0;if((ka|0)>(c[ha>>2]|0)){break}else{la=ka}do{ga=c[m>>2]|0;ja=c[n>>2]|0;o=(c[r>>2]|0)+(ga>>>3)|0;s=(fe(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(ga&7)>>>27;o=ga+5|0;c[m>>2]=ja>>>0>o>>>0?o:ja;c[f+46912+(la<<2)>>2]=d[1224488+(s*6|0)|0]|0;c[f+46940+(la<<2)>>2]=d[1224489+(s*6|0)|0]|0;c[f+46968+(la<<2)>>2]=d[1224490+(s*6|0)|0]|0;c[f+46996+(la<<2)>>2]=d[1224491+(s*6|0)|0]|0;c[f+47024+(la<<2)>>2]=d[1224492+(s*6|0)|0]|0;c[f+47052+(la<<2)>>2]=d[1224493+(s*6|0)|0]|0;la=la+1|0;}while((la|0)<=(c[ha>>2]|0))}else{ha=c[C>>2]|0;if((ha|0)<=0){break}s=f+44924|0;ja=0;o=c[s>>2]|0;ga=ha;while(1){ha=(c[f+164+(ja<<2)>>2]|0)==0|0;if((ha|0)>(o|0)){ma=o;na=ga}else{_=ha;do{ha=c[m>>2]|0;Z=c[n>>2]|0;X=(c[r>>2]|0)+(ha>>>3)|0;z=(fe(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(ha&7)>>>30;X=ha+2|0;c[m>>2]=Z>>>0>X>>>0?X:Z;c[f+46912+(ja*28|0)+(_<<2)>>2]=z;_=_+1|0;oa=c[s>>2]|0;}while((_|0)<=(oa|0));ma=oa;na=c[C>>2]|0}_=ja+1|0;if((_|0)<(na|0)){ja=_;o=ma;ga=na}else{break}}}}while(0);do{if((c[f+64>>2]|0)!=0){if((c[C>>2]|0)>0){pa=0}else{break}do{na=c[m>>2]|0;ma=d[(c[r>>2]|0)+(na>>>3)|0]<<(na&7)>>>7;c[m>>2]=((na|0)<(c[n>>2]|0))+na;c[f+46912+(pa*28|0)+(c[fa>>2]<<2)>>2]=ma&1;pa=pa+1|0;}while((pa|0)<(c[C>>2]|0))}}while(0);do{if((c[h>>2]|0)==0){pa=c[m>>2]|0;if((c[C>>2]|0)==6){qa=pa;ra=c[n>>2]|0}else{fa=d[(c[r>>2]|0)+(pa>>>3)|0]|0;ma=c[n>>2]|0;na=((pa|0)<(ma|0))+pa|0;c[m>>2]=na;if((fa&128>>>((pa&7)>>>0)|0)==0){break}else{qa=na;ra=ma}}ma=qa+((c[f+44924>>2]|0)*5|0)|0;c[m>>2]=ra>>>0>ma>>>0?ma:ra}}while(0);ra=f+1888|0;do{if((da|0)==0){TGb(ra|0,0,28)|0}else{c[ra>>2]=0;qa=(ia|0)!=6|0;h=f+44928|0;if((qa|0)>(c[h>>2]|0)){break}else{sa=qa}do{do{if((sa|0)==0){if((c[f+46940>>2]|0)!=0){ta=0;break}if((c[f+192>>2]|0)!=0){ta=0;break}if((c[f+46968>>2]|0)!=0){ta=0;break}if((c[f+196>>2]|0)!=0){ta=0;break}if((c[f+46996>>2]|0)!=0){ta=0;break}if((c[f+200>>2]|0)!=0){ta=0;break}if((c[f+47024>>2]|0)!=0){ta=0;break}if((c[f+204>>2]|0)!=0){ta=0;break}if((c[f+47052>>2]|0)!=0){ta=0;break}if((c[f+208>>2]|0)==0){U=111}else{ta=0}}else{if((c[f+46940+(sa<<2)>>2]|0)!=0){ta=0;break}if((c[f+46968+(sa<<2)>>2]|0)!=0){ta=0;break}if((c[f+46996+(sa<<2)>>2]|0)!=0){ta=0;break}if((c[f+47024+(sa<<2)>>2]|0)!=0){ta=0;break}if((c[f+47052+(sa<<2)>>2]|0)==0){U=111}else{ta=0}}}while(0);if((U|0)==111){U=0;qa=c[m>>2]|0;ma=d[(c[r>>2]|0)+(qa>>>3)|0]<<(qa&7);c[m>>2]=((qa|0)<(c[n>>2]|0))+qa;ta=ma>>>7&1}c[f+1888+(sa<<2)>>2]=ta;sa=sa+1|0;}while((sa|0)<=(c[h>>2]|0))}}while(0);do{if((c[aa>>2]|0)==0){sa=c[m>>2]|0;ta=c[n>>2]|0;ia=c[r>>2]|0;ra=ia+(sa>>>3)|0;da=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>26;ra=sa+6|0;sa=ta>>>0>ra>>>0?ra:ta;c[m>>2]=sa;ra=ia+(sa>>>3)|0;ia=(fe(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>28;ra=sa+4|0;c[m>>2]=ta>>>0>ra>>>0?ra:ta;ta=(ia|(da<<4)+1073741584)<<2;da=f+44928|0;if((c[da>>2]|0)<0){break}else{ua=0}do{c[f+47120+(ua<<2)>>2]=ta;ua=ua+1|0;}while((ua|0)<=(c[da>>2]|0))}}while(0);ua=c[f+44924>>2]|0;do{if(($&128>>>(Y>>>0)|0)==0){U=121}else{if((ua|0)<1){va=ua;wa=f+44924|0;break}aa=c[r>>2]|0;da=c[n>>2]|0;ta=1;ia=c[m>>2]|0;while(1){ra=((ia|0)<(da|0))+ia|0;if((d[aa+(ia>>>3)|0]&128>>>((ia&7)>>>0)|0)==0){xa=ra}else{sa=ra+10|0;ra=(da>>>0>sa>>>0?sa:da)+8|0;xa=da>>>0>ra>>>0?ra:da}c[m>>2]=xa;ra=ta+1|0;if((ra|0)>(ua|0)){U=121;break}else{ta=ra;ia=xa}}}}while(0);a:do{if((U|0)==121){xa=f+44924|0;if((ua|0)<1){va=ua;wa=xa;break}if((ea&128>>>(W>>>0)|0)==0){Y=1;while(1){a[f+887+Y|0]=-1;$=c[xa>>2]|0;ia=Y+1|0;if((ia|0)>($|0)){va=$;wa=xa;break a}else{Y=ia}}}else{ya=1}while(1){Y=c[m>>2]|0;ia=c[r>>2]|0;$=d[ia+(Y>>>3)|0]|0;ta=c[n>>2]|0;da=((Y|0)<(ta|0))+Y|0;c[m>>2]=da;if(($&128>>>((Y&7)>>>0)|0)==0){a[f+887+ya|0]=-1}else{Y=ia+(da>>>3)|0;ia=(fe(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(da&7)>>>27;Y=da+5|0;c[m>>2]=ta>>>0>Y>>>0?Y:ta;a[f+887+ya|0]=ia}ia=ya+1|0;ta=c[xa>>2]|0;if((ia|0)>(ta|0)){va=ta;wa=xa;break}else{ya=ia}}}}while(0);ya=c[C>>2]|0;do{if((ya|0)>1){C=c[m>>2]|0;W=d[(c[r>>2]|0)+(C>>>3)|0]|0;ea=c[n>>2]|0;ua=((C|0)<(ea|0))+C|0;c[m>>2]=ua;if((W&128>>>((C&7)>>>0)|0)==0){za=va;break}C=(c[f+36>>2]|0)-2|0;W=C>>>0>65535>>>0;U=W?C>>>16:C;C=W?16:0;if((U&65280|0)==0){Aa=C;Ba=U}else{Aa=C|8;Ba=U>>>8}U=ba(Aa+4+(d[1191992+Ba|0]|0)|0,ya-1|0)|0;C=-ua|0;W=ea-ua|0;if((U|0)<(C|0)){Ca=C}else{Ca=(W|0)<(U|0)?W:U}c[m>>2]=Ca+ua;DDb(c[f+4>>2]|0,1998472,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;za=c[wa>>2]|0}else{za=va}}while(0);if((za|0)>=1){za=1;do{a[f+929+za|0]=1;c[f+344+(za<<2)>>2]=1;za=za+1|0;}while((za|0)<=(c[wa>>2]|0))}c[f+47116>>2]=1;l=0;i=g;return l|0}return 0}function Jkb(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=i;i=i+128|0;g=f|0;b[e>>1]=(b[e>>1]|0)+4;h=0;while(1){j=g+(h<<1)|0;k=e+(h<<1)|0;l=h+8|0;m=b[e+(l<<1)>>1]|0;n=m<<16>>16;o=h+16|0;p=b[e+(o<<1)>>1]|0;q=p<<16>>16;r=h+24|0;s=b[e+(r<<1)>>1]|0;t=s<<16>>16;u=h+32|0;v=b[e+(u<<1)>>1]|0;w=v<<16>>16;x=h+40|0;y=b[e+(x<<1)>>1]|0;z=y<<16>>16;A=h+48|0;B=b[e+(A<<1)>>1]|0;C=B<<16>>16;D=h+56|0;E=b[e+(D<<1)>>1]|0;F=E<<16>>16;if((p|m|s|v|y|B|E)<<16>>16==0){E=b[k>>1]|0;b[g+(D<<1)>>1]=E;b[g+(A<<1)>>1]=E;b[g+(x<<1)>>1]=E;b[g+(u<<1)>>1]=E;b[g+(r<<1)>>1]=E;b[g+(o<<1)>>1]=E;b[g+(l<<1)>>1]=E;b[j>>1]=E}else{E=F+n|0;B=n-F|0;F=z+t|0;n=z-t|0;t=C+q|0;z=((q-C|0)*181|0)>>8;C=b[k>>1]|0;k=C+w|0;q=C-w|0;w=(B*473|0)+(n*-196|0)>>9;C=E+F+w|0;y=((E-F|0)*181|0)>>8;F=w+y|0;w=(B*196|0)+(n*473|0)>>9;n=w+y|0;y=z+t+k|0;b[j>>1]=y+C;j=q+z|0;b[g+(l<<1)>>1]=j+F;l=q-z|0;b[g+(o<<1)>>1]=l+n;o=k-t-z|0;b[g+(r<<1)>>1]=o+w;b[g+(u<<1)>>1]=o-w;b[g+(x<<1)>>1]=l-n;b[g+(A<<1)>>1]=j-F;b[g+(D<<1)>>1]=y-C}C=h+1|0;if((C|0)<8){h=C}else{G=0;break}}do{h=G<<3;e=b[g+((h|1)<<1)>>1]|0;C=b[g+((h|7)<<1)>>1]|0;y=C+e|0;D=e-C|0;C=b[g+((h|5)<<1)>>1]|0;e=b[g+((h|3)<<1)>>1]|0;F=e+C|0;j=C-e|0;e=b[g+((h|2)<<1)>>1]|0;C=b[g+((h|6)<<1)>>1]|0;A=C+e|0;n=((e-C|0)*181|0)>>8;C=b[g+(h<<1)>>1]|0;e=b[g+((h|4)<<1)>>1]|0;h=e+C|0;l=C-e|0;e=(j*-196|0)+(D*473|0)>>9;C=F+y+e|0;x=((y-F|0)*181|0)>>8;F=e+x|0;e=(j*473|0)+(D*196|0)>>9;D=e+x|0;x=h+A+n|0;j=x+C>>4;if(j>>>0>255>>>0){H=-j>>31&255}else{H=j&255}j=ba(G,d)|0;a[c+j|0]=H;y=l+n|0;w=y+F>>4;if(w>>>0>255>>>0){I=-w>>31&255}else{I=w&255}a[c+(j+1)|0]=I;w=l-n|0;l=w+D>>4;if(l>>>0>255>>>0){J=-l>>31&255}else{J=l&255}a[c+(j+2)|0]=J;l=h-A-n|0;n=l+e>>4;if(n>>>0>255>>>0){K=-n>>31&255}else{K=n&255}a[c+(j+3)|0]=K;n=l-e>>4;if(n>>>0>255>>>0){L=-n>>31&255}else{L=n&255}a[c+(j+4)|0]=L;n=w-D>>4;if(n>>>0>255>>>0){M=-n>>31&255}else{M=n&255}a[c+(j+5)|0]=M;n=y-F>>4;if(n>>>0>255>>>0){N=-n>>31&255}else{N=n&255}a[c+(j+6)|0]=N;n=x-C>>4;if(n>>>0>255>>>0){O=-n>>31&255}else{O=n&255}a[c+(j+7)|0]=O;G=G+1|0;}while((G|0)<8);i=f;return}function Kkb(a){a=a|0;if((c[(c[a>>2]|0)+684>>2]|0)==0){return}TGb(c[a+40>>2]|0,127,ba(c[a+20>>2]|0,c[a+24>>2]|0)|0)|0;c[a+32>>2]=(c[a+12>>2]|0)*3|0;c[a+36>>2]=0;return}function Lkb(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=i;l=b+16|0;m=c[l>>2]|0;n=(ba(m,f)|0)+e|0;e=b+12|0;f=c[e>>2]|0;o=f-1|0;if((n|0)<0){p=0}else{p=(n|0)>(o|0)?o:n}n=(ba(m,h)|0)+g|0;if((n|0)<0){q=0}else{q=(n|0)>(f|0)?f:n}n=b+8|0;f=c[n>>2]|0;g=c[f+(p<<2)>>2]|0;h=c[f+(q<<2)>>2]|0;f=b|0;m=c[f>>2]|0;o=c[m+712>>2]|0;do{if((o|0)!=0){if((c[o+28>>2]|0)==0){break}i=k;return}}while(0);if((p|0)>(q|0)|(g|0)>(h|0)){yDb(m,16,2177920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;i=k;return}if((c[m+684>>2]|0)==0){i=k;return}if((j&18|0)==0){r=-2}else{m=b+32|0;c[m>>2]=p-1-q+(c[m>>2]|0);r=-20}if((j&36|0)==0){s=r}else{m=b+32|0;c[m>>2]=p-1-q+(c[m>>2]|0);s=r&-38}if((j&72|0)==0){t=s}else{r=b+32|0;c[r>>2]=p-1-q+(c[r>>2]|0);t=s&-73}if((j&14|0)!=0){c[b+36>>2]=1;c[b+32>>2]=2147483647}do{if((t|0)==-128){TGb((c[b+40>>2]|0)+g|0,0,h-g|0)|0}else{if((g|0)>=(h|0)){break}s=b+40|0;r=g;do{m=(c[s>>2]|0)+r|0;a[m]=(d[m]|0)&t;r=r+1|0;}while((r|0)<(h|0))}}while(0);if((q|0)==(c[e>>2]|0)){c[b+32>>2]=2147483647;u=b+40|0}else{e=b+40|0;q=(c[e>>2]|0)+h|0;a[q]=(d[q]|0)&t;t=(c[e>>2]|0)+h|0;a[t]=d[t]|0|j;u=e}e=(c[u>>2]|0)+g|0;a[e]=a[e]|1;if((g|0)<=0){i=k;return}g=c[f>>2]|0;if((c[g+816>>2]&2|0)!=0){i=k;return}f=c[g+712>>2]|0;do{if((f|0)!=0){if((c[f+28>>2]|0)==0){break}i=k;return}}while(0);if((c[(c[g+12>>2]|0)+16>>2]&128|0)!=0){i=k;return}f=c[b+132>>2]|0;if((f|0)==0){i=k;return}if((c[f+2164>>2]|0)!=0){i=k;return}if((ba(c[l>>2]|0,c[g+328>>2]|0)|0)>=(p|0)){i=k;return}if((a[(c[u>>2]|0)+(c[(c[n>>2]|0)+(p-1<<2)>>2]|0)|0]&-2)<<24>>24==112){i=k;return}c[b+36>>2]=1;c[b+32>>2]=2147483647;i=k;return}function Mkb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0;g=i;i=i+96|0;h=g|0;j=g+64|0;k=f+132|0;l=c[k>>2]|0;m=l+32|0;n=f+28|0;o=c[n>>2]|0;p=f+20|0;q=c[p>>2]|0;r=f|0;s=c[r>>2]|0;if((c[s+684>>2]|0)==0){i=g;return}t=c[f+32>>2]|0;if((t|0)==0){i=g;return}if((c[s+800>>2]|0)!=0){i=g;return}u=c[s+712>>2]|0;do{if((u|0)!=0){if((c[u+28>>2]|0)==0){break}i=g;return}}while(0);if((c[(c[s+12>>2]|0)+16>>2]&128|0)!=0|(l|0)==0){i=g;return}if((c[l+2164>>2]|0)!=0){i=g;return}u=f+16|0;v=c[u>>2]|0;w=v*3|0;x=c[s+328>>2]|0;y=c[s+332>>2]|0;if((t|0)==(ba(w,y+x|0)|0)){i=g;return}z=f+24|0;A=f+40|0;B=0;while(1){if((B|0)>=(v|0)){break}C=(ba(q-1|0,c[z>>2]|0)|0)+B|0;if((a[(c[A>>2]|0)+C|0]|0)==127){B=B+1|0}else{break}}do{if((B|0)==(v|0)){if((c[s+48>>2]|0)!=2){break}if((c[s+124>>2]&16|0)==0){break}if((t|0)!=(ba(w,x+1+y|0)|0)){break}yDb(s,48,2304232,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;i=g;return}}while(0);y=f+136|0;x=c[y>>2]|0;a:do{if((x|0)!=0){do{if((c[x+68>>2]|0)==(c[l+68>>2]|0)){if((c[x+72>>2]|0)!=(c[l+72>>2]|0)){break}if((c[x+80>>2]|0)==(c[l+80>>2]|0)){break a}}}while(0);yDb(s,24,2173920,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;c[y>>2]=0}}while(0);s=f+140|0;x=c[s>>2]|0;b:do{if((x|0)!=0){w=c[k>>2]|0;do{if((c[x+68>>2]|0)==(c[w+68>>2]|0)){if((c[x+72>>2]|0)!=(c[w+72>>2]|0)){break}if((c[x+80>>2]|0)==(c[w+80>>2]|0)){break b}}}while(0);yDb(c[r>>2]|0,24,2099008,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;c[s>>2]=0}}while(0);c:do{if((c[(c[k>>2]|0)+1524>>2]|0)==0){yDb(c[r>>2]|0,16,2043768,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;x=(ba(o<<3,q)|0)+16|0;w=VAb(ba(c[z>>2]<<2,c[p>>2]|0)|0)|0;c[(c[k>>2]|0)+1548>>2]=w;w=VAb(x)|0;c[(c[k>>2]|0)+1516>>2]=w;w=c[k>>2]|0;t=c[w+1548>>2]|0;do{if((t|0)==0){E=w}else{if((c[w+1516>>2]|0)==0){E=w;break}c[w+1556>>2]=c[t+4>>2];v=c[k>>2]|0;c[v+1524>>2]=(c[(c[v+1516>>2]|0)+4>>2]|0)+16;v=VAb(ba(c[z>>2]<<2,c[p>>2]|0)|0)|0;c[(c[k>>2]|0)+1552>>2]=v;v=VAb(x)|0;c[(c[k>>2]|0)+1520>>2]=v;v=c[k>>2]|0;B=c[v+1552>>2]|0;if((B|0)==0){E=v;break}if((c[v+1520>>2]|0)==0){E=v;break}c[v+1560>>2]=c[B+4>>2];B=c[k>>2]|0;c[B+1528>>2]=(c[(c[B+1520>>2]|0)+4>>2]|0)+16;break c}}while(0);XAb(E+1548|0);XAb((c[k>>2]|0)+1516|0);c[(c[k>>2]|0)+1556>>2]=0;c[(c[k>>2]|0)+1524>>2]=0;XAb((c[k>>2]|0)+1552|0);XAb((c[k>>2]|0)+1520|0);c[(c[k>>2]|0)+1560>>2]=0;c[(c[k>>2]|0)+1528>>2]=0;i=g;return}}while(0);do{if((c[(c[r>>2]|0)+688>>2]&1024|0)!=0){if((c[p>>2]|0)>0){F=0}else{break}do{if((c[u>>2]|0)>0){E=0;do{q=(ba(c[z>>2]|0,F)|0)+E|0;yDb(c[r>>2]|0,48,1998464,(D=i,i=i+8|0,c[D>>2]=d[(c[A>>2]|0)+q|0]|0,D)|0);i=D;E=E+1|0;}while((E|0)<(c[u>>2]|0))}yDb(c[r>>2]|0,48,1961624,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;F=F+1|0;}while((F|0)<(c[p>>2]|0))}}while(0);F=f+12|0;E=f+8|0;q=c[F>>2]|0;d:do{if((q|0)>0){o=0;x=q;while(1){t=x-1|0;w=(c[A>>2]|0)+(c[(c[E>>2]|0)+(t<<2)>>2]|0)|0;B=a[w]|0;v=B&255;C=(v&16|0)==0?(v&2|0)==0?o:1:1;if((C|0)==0){a[w]=B|2}if((t|0)<=0){break}o=(v&1|0)==0?C:0;x=t}x=c[F>>2]|0;if((x|0)>0){G=0;H=x}else{break}while(1){x=H-1|0;o=(c[A>>2]|0)+(c[(c[E>>2]|0)+(x<<2)>>2]|0)|0;t=a[o]|0;C=t&255;v=(C&32|0)==0?(C&4|0)==0?G:1:1;if((v|0)==0){a[o]=t|4}if((x|0)<=0){break}G=(C&1|0)==0?v:0;H=x}x=c[F>>2]|0;if((x|0)>0){I=0;J=x}else{break}while(1){x=J-1|0;v=(c[A>>2]|0)+(c[(c[E>>2]|0)+(x<<2)>>2]|0)|0;C=a[v]|0;t=C&255;o=(t&64|0)==0?(t&8|0)==0?I:1:1;if((o|0)==0){a[v]=C|8}if((x|0)<=0){break d}I=(t&1|0)==0?o:0;J=x}}}while(0);J=f+152|0;e:do{if((c[J>>2]|0)!=0){I=c[F>>2]|0;if((I|0)>0){K=0;L=I}else{break}while(1){I=L-1|0;H=(c[A>>2]|0)+(c[(c[E>>2]|0)+(I<<2)>>2]|0)|0;G=a[H]|0;q=G&255;x=(q&98|0)==0?(q&16|0)==0?K:0:1;if((x|0)==0){a[H]=G|2}if((I|0)<=0){break e}K=(q&1|0)==0?x:0;L=I}}}while(0);do{if((c[(c[r>>2]|0)+696>>2]&8|0)==0){M=49}else{L=c[F>>2]|0;K=L-2|0;I=c[u>>2]|0;if((K|0)<(I+100|0)){N=L;break}else{O=1;P=K;Q=I}while(1){I=c[E>>2]|0;K=c[A>>2]|0;L=K+(c[I+(P<<2)>>2]|0)|0;x=a[L]|0;q=x&255;G=(q&1|0)==0?O:1;if((a[K+(c[I+(P+1<<2)>>2]|0)|0]|0)!=127|x<<24>>24==127){R=G}else{R=(q&112|0)==0?G:0}if((R|0)==0){a[L]=x|14;S=c[u>>2]|0}else{S=Q}x=P-1|0;if((x|0)<(S+100|0)){M=49;break}else{O=R;P=x;Q=S}}}}while(0);if((M|0)==49){N=c[F>>2]|0}S=f+60|0;do{if((N|0)>0){Q=9999999;P=N;do{P=P-1|0;R=c[(c[E>>2]|0)+(P<<2)>>2]|0;O=(c[A>>2]|0)+R|0;x=a[O]|0;L=x&255;G=(L&2|0)==0?((a[(c[S>>2]|0)+R|0]|0)==0)+Q|0:0;do{if((c[J>>2]|0)==0){if((G|0)>=50){break}a[O]=x|2}else{if((G|0)>=100){break}a[O]=x|2}}while(0);Q=(L&1|0)==0?G:9999999;}while((P|0)>0);P=c[F>>2]|0;if((P|0)>0){T=Q;U=P}else{V=P;break}do{U=U-1|0;P=c[(c[E>>2]|0)+(U<<2)>>2]|0;x=(c[A>>2]|0)+P|0;O=a[x]|0;R=O&255;q=(R&4|0)==0?((a[(c[S>>2]|0)+P|0]|0)==0)+T|0:0;do{if((c[J>>2]|0)==0){if((q|0)>=50){break}a[x]=O|4}else{if((q|0)>=100){break}a[x]=O|4}}while(0);T=(R&1|0)==0?q:9999999;}while((U|0)>0);Q=c[F>>2]|0;if((Q|0)>0){W=T;X=Q}else{V=Q;break}while(1){Q=X-1|0;O=c[(c[E>>2]|0)+(Q<<2)>>2]|0;x=(c[A>>2]|0)+O|0;G=a[x]|0;L=G&255;P=(L&8|0)==0?((a[(c[S>>2]|0)+O|0]|0)==0)+W|0:0;do{if((c[J>>2]|0)==0){if((P|0)>=50){break}a[x]=G|8}else{if((P|0)>=100){break}a[x]=G|8}}while(0);if((Q|0)<=0){break}W=(L&1|0)==0?P:9999999;X=Q}G=c[F>>2]|0;if((G|0)>0){Y=0;Z=0;_=G}else{V=G;break}while(1){G=(c[A>>2]|0)+(c[(c[E>>2]|0)+(Z<<2)>>2]|0)|0;x=d[G]|0;q=x&14;if((x&1|0)==0){a[G]=x|Y;$=q|Y;aa=c[F>>2]|0}else{$=q;aa=_}q=Z+1|0;if((q|0)<(aa|0)){Y=$;Z=q;_=aa}else{V=aa;break}}}else{V=N}}while(0);do{if((c[J>>2]|0)==0){if((V|0)>0){ca=0}else{da=0;ea=0;fa=0;break}while(1){N=(c[A>>2]|0)+(c[(c[E>>2]|0)+(ca<<2)>>2]|0)|0;aa=a[N]|0;a[N]=(aa&14)==0?aa:aa|14;aa=ca+1|0;N=c[F>>2]|0;if((aa|0)<(N|0)){ca=aa}else{ga=N;M=69;break}}}else{ga=V;M=69}}while(0);do{if((M|0)==69){if((ga|0)<=0){da=0;ea=0;fa=0;break}V=c[E>>2]|0;ca=c[A>>2]|0;N=0;aa=0;_=0;Z=0;while(1){$=d[ca+(c[V+(Z<<2)>>2]|0)|0]|0;Y=($>>>2&1)+_|0;X=($>>>1&1)+N|0;W=($>>>3&1)+aa|0;$=Z+1|0;if(($|0)<(ga|0)){N=X;aa=W;_=Y;Z=$}else{da=X;ea=W;fa=Y;break}}}}while(0);ga=c[r>>2]|0;Z=(mGb(c[(c[k>>2]|0)+88>>2]|0)|0)<<24>>24;yDb(ga,32,1933696,(D=i,i=i+32|0,c[D>>2]=fa,c[D+8>>2]=da,c[D+16>>2]=ea,c[D+24>>2]=Z,D)|0);i=D;Z=c[y>>2]|0;do{if((Z|0)==0){ha=1}else{if((c[Z>>2]|0)==0){ha=1;break}ea=c[F>>2]|0;if((ea|0)>0){da=c[E>>2]|0;fa=c[A>>2]|0;ga=0;_=0;while(1){aa=((a[fa+(c[da+(_<<2)>>2]|0)|0]&12)!=12)+ga|0;N=_+1|0;if((N|0)<(ea|0)){ga=aa;_=N}else{ia=aa;break}}}else{ia=0}if((c[(c[r>>2]|0)+48>>2]|0)==28){if((c[f+156>>2]|0)<1){ha=1;break}}if((ia|0)<5){ha=0;break}if((ia|0)>99){ja=(ia|0)/50|0}else{ja=1}_=c[p>>2]|0;if((_-1|0)>0){ga=f+4|0;ea=0;da=0;fa=0;aa=c[u>>2]|0;N=_;while(1){if((aa|0)>0){_=ea<<4;V=0;ca=da;Y=fa;W=aa;while(1){X=(ba(c[z>>2]|0,ea)|0)+V|0;do{if((a[(c[A>>2]|0)+X|0]&12)==12){ka=Y;la=ca;ma=W}else{$=ca+1|0;if((($|0)%(ja|0)|0|0)!=0){ka=Y;la=$;ma=W;break}T=c[k>>2]|0;if((c[T+88>>2]|0)==1){U=T+32|0;q=c[U>>2]|0;x=(ba(_,q)|0)+(V<<4)|0;G=(c[T>>2]|0)+x|0;R=c[y>>2]|0;O=c[R>>2]|0;I=O+x|0;if((c[(c[r>>2]|0)+48>>2]|0)==28){na=q}else{Z0a(R+1496|0,ea,0);na=c[U>>2]|0}R=(Pe[c[(c[ga>>2]|0)+52>>2]&255](0,I,G,na,16)|0)+Y|0;G=c[U>>2]|0;U=R-(Pe[c[(c[ga>>2]|0)+52>>2]&255](0,I,O+((G<<4)+x)|0,G,16)|0)|0;ka=U;la=$;ma=c[u>>2]|0;break}else{if((c[(c[T+1536>>2]|0)+(X<<2)>>2]&7|0)==0){ka=Y-1|0;la=$;ma=W;break}else{ka=Y+1|0;la=$;ma=W;break}}}}while(0);X=V+1|0;if((X|0)<(ma|0)){V=X;ca=la;Y=ka;W=ma}else{break}}oa=la;pa=ka;qa=ma;ra=c[p>>2]|0}else{oa=da;pa=fa;qa=aa;ra=N}W=ea+1|0;if((W|0)<(ra-1|0)){ea=W;da=oa;fa=pa;aa=qa;N=ra}else{sa=pa;break}}}else{sa=0}ha=(sa|0)>0|0}}while(0);sa=c[F>>2]|0;if((sa|0)>0){pa=(ha|0)==0;ha=c[E>>2]|0;ra=c[A>>2]|0;qa=0;while(1){oa=c[ha+(qa<<2)>>2]|0;do{if((a[ra+oa|0]&12)==12){ma=(c[(c[k>>2]|0)+1536>>2]|0)+(oa<<2)|0;if(pa){c[ma>>2]=12296;break}else{c[ma>>2]=1;break}}}while(0);oa=qa+1|0;ma=c[F>>2]|0;if((oa|0)<(ma|0)){qa=oa}else{ta=ma;break}}}else{ta=sa}sa=c[y>>2]|0;if((sa|0)==0){M=109}else{if((c[sa>>2]|0)==0){M=109}}do{if((M|0)==109){sa=c[s>>2]|0;if((sa|0)==0){if((ta|0)<=0){break}}else{if(!((c[sa>>2]|0)==0&(ta|0)>0)){break}}sa=c[E>>2]|0;qa=c[(c[k>>2]|0)+1536>>2]|0;pa=0;ra=ta;while(1){ha=qa+(c[sa+(pa<<2)>>2]<<2)|0;if((c[ha>>2]&7|0)==0){c[ha>>2]=1;ua=c[F>>2]|0}else{ua=ra}ha=pa+1|0;if((ha|0)<(ua|0)){pa=ha;ra=ua}else{break}}}}while(0);ua=c[p>>2]|0;if((ua|0)>0){ta=f+68|0;ra=f+72|0;pa=f+160|0;sa=f+164|0;qa=f+68|0;ha=0;ma=c[u>>2]|0;oa=ua;while(1){if((ma|0)>0){ka=ha<<1;la=0;na=ma;while(1){ja=(ba(c[z>>2]|0,ha)|0)+la|0;ia=c[k>>2]|0;Z=c[(c[ia+1536>>2]|0)+(ja<<2)>>2]|0;N=c[y>>2]|0;if((N|0)==0){va=1}else{va=(c[N>>2]|0)==0}N=va&1;aa=va?2:1;do{if((Z&7|0)==0){if(!((a[(c[A>>2]|0)+ja|0]&10)==2)){wa=na;break}fa=c[n>>2]|0;da=(ba(fa,ka)|0)+(la<<1)|0;ea=c[ia+1524+(N<<2)>>2]|0;c[ta>>2]=b[ea+(da<<2)>>1]|0;c[ra>>2]=b[ea+(da<<2)+2>>1]|0;if((Z&64|0)==0){xa=0}else{ga=da|1;c[f+76>>2]=b[ea+(ga<<2)>>1]|0;c[f+80>>2]=b[ea+(ga<<2)+2>>1]|0;W=fa+da|0;c[f+84>>2]=b[ea+(W<<2)>>1]|0;c[f+88>>2]=b[ea+(W<<2)+2>>1]|0;W=fa+ga|0;c[f+92>>2]=b[ea+(W<<2)>>1]|0;c[f+96>>2]=b[ea+(W<<2)+2>>1]|0;xa=1}Le[c[pa>>2]&255](c[sa>>2]|0,0,aa,xa,qa,la,ha,0,0);wa=c[u>>2]|0}else{wa=na}}while(0);aa=la+1|0;if((aa|0)<(wa|0)){la=aa;na=wa}else{break}}ya=wa;za=c[p>>2]|0}else{ya=ma;za=oa}na=ha+1|0;if((na|0)<(za|0)){ha=na;ma=ya;oa=za}else{Aa=za;break}}}else{Aa=ua}ua=c[k>>2]|0;f:do{if((c[ua+88>>2]|0)==3){if((Aa|0)<=0){Ba=Aa;M=266;break}za=f+144|0;oa=f+68|0;ya=f+72|0;ma=f+100|0;ha=f+104|0;wa=f+160|0;qa=f+164|0;xa=f+68|0;sa=f+146|0;pa=0;ra=c[u>>2]|0;ta=Aa;g:while(1){if((ra|0)>0){va=pa<<1;na=0;la=ra;while(1){ka=(ba(va,c[n>>2]|0)|0)+(na<<1)|0;aa=(ba(c[z>>2]|0,pa)|0)+na|0;do{if((c[(c[(c[k>>2]|0)+1536>>2]|0)+(aa<<2)>>2]&7|0)==0){if(!((a[(c[A>>2]|0)+aa|0]&10)==10)){Ca=la;break}Z=c[y>>2]|0;if((Z|0)==0){M=139}else{if((c[Z>>2]|0)==0){M=139}else{Da=3}}if((M|0)==139){M=0;Da=2}Z=c[s>>2]|0;if((Z|0)==0){M=142}else{if((c[Z>>2]|0)==0){M=142}else{Ea=Da}}if((M|0)==142){M=0;Ea=Da&1}N=b[za>>1]|0;if(N<<16>>16==0){c[oa>>2]=0;c[ya>>2]=0;c[ma>>2]=0;Fa=0}else{ia=N&65535;N=e[sa>>1]|0;if((c[(c[r>>2]|0)+48>>2]|0)==28){break g}Z0a(Z+1496|0,pa,0);Z=c[(c[s>>2]|0)+1524>>2]|0;ja=b[Z+(ka<<2)>>1]|0;c[oa>>2]=(ba(ja,N)|0)/(ia|0)|0;W=b[Z+(ka<<2)+2>>1]|0;c[ya>>2]=(ba(W,N)|0)/(ia|0)|0;Z=N-ia|0;c[ma>>2]=(ba(ja,Z)|0)/(ia|0)|0;Fa=(ba(W,Z)|0)/(ia|0)|0}c[ha>>2]=Fa;Le[c[wa>>2]&255](c[qa>>2]|0,0,Ea,0,xa,na,pa,0,0);Ca=c[u>>2]|0}else{Ca=la}}while(0);ka=na+1|0;if((ka|0)<(Ca|0)){na=ka;la=Ca}else{break}}Ga=Ca;Ha=c[p>>2]|0}else{Ga=ra;Ha=ta}la=pa+1|0;if((la|0)<(Ha|0)){pa=la;ra=Ga;ta=Ha}else{Ia=Ha;M=265;break f}}yDb(0,0,1910824,(D=i,i=i+24|0,c[D>>2]=1890336,c[D+8>>2]=2347656,c[D+16>>2]=1166,D)|0);i=D;Cd()}else{ta=h;ra=j;pa=c[f+44>>2]|0;xa=c[z>>2]|0;qa=c[u>>2]|0;wa=c[r>>2]|0;do{if((c[wa+48>>2]|0)==28){if((c[f+148>>2]|0)==0){yDb(0,0,1910824,(D=i,i=i+24|0,c[D>>2]=2327392,c[D+8>>2]=2347656,c[D+16>>2]=45,D)|0);i=D;Cd()}else{Ja=qa<<2;Ka=4;break}}else{Ja=c[n>>2]|0;Ka=2}}while(0);if((c[F>>2]|0)>0){ha=0;ma=0;ya=ua;while(1){oa=c[(c[E>>2]|0)+(ma<<2)>>2]|0;sa=(a[(c[A>>2]|0)+oa|0]&8)==0?3:(c[(c[ya+1536>>2]|0)+(oa<<2)>>2]&7|0)==0?0:3;a[pa+oa|0]=sa;do{if((sa|0)==3){La=ha+1|0}else{za=c[y>>2]|0;if((c[za>>2]|0)==0){La=ha;break}la=c[za+1524>>2]|0;if((la|0)==0){La=ha;break}na=c[z>>2]|0;va=ba(((oa|0)%(na|0)|0)+(ba((oa|0)/(na|0)|0,Ja)|0)|0,Ka)|0;na=c[k>>2]|0;ka=c[na+1524>>2]|0;b[ka+(va<<2)>>1]=b[la+(va<<2)>>1]|0;b[ka+(va<<2)+2>>1]=b[la+(va<<2)+2>>1]|0;va=oa<<2;a[(c[na+1556>>2]|0)+va|0]=a[(c[za+1556>>2]|0)+va|0]|0;La=ha}}while(0);oa=ma+1|0;if((oa|0)>=(c[F>>2]|0)){break}ha=La;ma=oa;ya=c[k>>2]|0}Ma=La;Na=c[r>>2]|0}else{Ma=0;Na=wa}do{if((c[Na+684>>2]&1|0)!=0){if((Ma|0)<=((qa|0)/2|0|0)){break}ya=h|0;ma=h+4|0;ha=j|0;oa=ba(Ja,Ka)|0;sa=f+68|0;va=sa|0;za=f+72|0;na=f+160|0;la=f+164|0;ka=1;aa=0;ia=1;h:while(1){if((ka|0)==0){if((aa|0)>=2){M=263}}else{if((aa|0)>=10){M=263}}if((M|0)==263){M=0;if((ia|0)!=0){break}Z=c[F>>2]|0;if((Z|0)>0){Oa=0;Pa=Z}else{ka=1;aa=0;ia=1;continue}while(1){Z=pa+(c[(c[E>>2]|0)+(Oa<<2)>>2]|0)|0;if((a[Z]|0)==0){Qa=Pa}else{a[Z]=3;Qa=c[F>>2]|0}Z=Oa+1|0;if((Z|0)<(Qa|0)){Oa=Z;Pa=Qa}else{ka=1;aa=0;ia=1;continue h}}}Z=c[p>>2]|0;if((Z|0)>0){W=(aa|0)>1;ja=ia;N=0;ea=0;ga=c[u>>2]|0;fa=Z;while(1){if((ga|0)>0){Z=ba(N,Ja)|0;da=N^aa;Y=(N|0)>0;ca=N+1|0;V=(ca|0)<(Aa|0);_=N<<4;Q=ja;P=0;L=ea;while(1){X=c[z>>2]|0;$=(ba(X,N)|0)+P|0;TGb(ta|0,0,64)|0;TGb(ra|0,0,32)|0;T=P+Z|0;U=ba(T,Ka)|0;i:do{if(((da^P)&1|0)==0){G=pa+$|0;if((a[G]|0)==3){Ra=L;Sa=Q;break}x=(P|0)>0;if(x){Ta=(a[pa+($-1)|0]|0)==3|0}else{Ta=0}O=(P+1|0)<(qa|0);if(O){Ua=(a[pa+($+1)|0]|0)==3?1:Ta}else{Ua=Ta}if(Y){Va=(a[pa+($-xa)|0]|0)==3?1:Ua}else{Va=Ua}if(V){Wa=(a[pa+($+xa)|0]|0)==3?1:Va}else{Wa=Va}if((Wa|0)==0){Ra=L;Sa=Q;break}if(x){Xa=(a[pa+($-1)|0]|0)==2|0}else{Xa=0}if(O){Ya=(a[pa+($+1)|0]|0)==2?1:Xa}else{Ya=Xa}if(Y){Za=(a[pa+($-xa)|0]|0)==2?1:Ya}else{Za=Ya}if(V){_a=(a[pa+($+xa)|0]|0)==2?1:Za}else{_a=Za}if((_a|0)==0&W){Ra=L;Sa=Q;break}do{if(x){I=$-1|0;if((a[pa+I|0]|0)==0){$a=0;break}R=U-Ka|0;q=c[k>>2]|0;K=c[q+1524>>2]|0;c[ya>>2]=b[K+(R<<2)>>1]|0;c[ma>>2]=b[K+(R<<2)+2>>1]|0;c[ha>>2]=a[(c[q+1556>>2]|0)+(I<<2)|0]|0;$a=1}else{$a=0}}while(0);do{if(O){I=$+1|0;if((a[pa+I|0]|0)==0){ab=$a;break}q=U+Ka|0;R=c[k>>2]|0;K=c[R+1524>>2]|0;c[h+($a<<3)>>2]=b[K+(q<<2)>>1]|0;c[h+($a<<3)+4>>2]=b[K+(q<<2)+2>>1]|0;c[j+($a<<2)>>2]=a[(c[R+1556>>2]|0)+(I<<2)|0]|0;ab=$a+1|0}else{ab=$a}}while(0);do{if(Y){if((a[pa+($-xa)|0]|0)==0){bb=ab;break}I=U-oa|0;R=c[k>>2]|0;q=c[R+1524>>2]|0;c[h+(ab<<3)>>2]=b[q+(I<<2)>>1]|0;c[h+(ab<<3)+4>>2]=b[q+(I<<2)+2>>1]|0;c[j+(ab<<2)>>2]=a[(c[R+1556>>2]|0)+($-X<<2)|0]|0;bb=ab+1|0}else{bb=ab}}while(0);do{if(V){if((a[pa+($+xa)|0]|0)==0){cb=bb;break}R=ba(T+Ja|0,Ka)|0;I=c[k>>2]|0;q=c[I+1524>>2]|0;c[h+(bb<<3)>>2]=b[q+(R<<2)>>1]|0;c[h+(bb<<3)+4>>2]=b[q+(R<<2)+2>>1]|0;c[j+(bb<<2)>>2]=a[(c[I+1556>>2]|0)+($+X<<2)|0]|0;cb=bb+1|0}else{cb=bb}}while(0);if((cb|0)==0){Ra=L;Sa=0;break}j:do{if((cb|0)>1){I=0;R=0;q=0;K=0;do{R=(c[h+(I<<3)>>2]|0)+R|0;q=(c[h+(I<<3)+4>>2]|0)+q|0;H=c[j+(I<<2)>>2]|0;K=H+K|0;if((I|0)!=0){if((H|0)!=(c[j+(I-1<<2)>>2]|0)){db=cb;break j}}I=I+1|0;}while((I|0)<(cb|0));c[h+(cb<<3)>>2]=(R|0)/(I|0)|0;c[h+(cb<<3)+4>>2]=(q|0)/(I|0)|0;c[j+(cb<<2)>>2]=(K|0)/(I|0)|0;H=(cb|0)>2;o=H?-99999:0;t=H?99999:0;H=0;C=o;v=o;B=t;w=t;eb=o;o=t;do{t=c[h+(H<<3)>>2]|0;C=(C|0)>(t|0)?C:t;fb=c[h+(H<<3)+4>>2]|0;v=(v|0)>(fb|0)?v:fb;gb=c[j+(H<<2)>>2]|0;eb=(eb|0)>(gb|0)?eb:gb;B=(B|0)>(t|0)?t:B;w=(w|0)>(fb|0)?fb:w;o=(o|0)>(gb|0)?gb:o;H=H+1|0;}while((H|0)<(cb|0));H=R-C-B|0;I=cb+1|0;gb=h+(I<<3)|0;c[gb>>2]=H;fb=q-v-w|0;t=h+(I<<3)+4|0;c[t>>2]=fb;hb=K-eb-o|0;ib=j+(I<<2)|0;c[ib>>2]=hb;if((cb|0)==4){c[gb>>2]=(H|0)/2|0;c[t>>2]=(fb|0)/2|0;c[ib>>2]=(hb|0)/2|0}db=cb+2|0}else{db=cb}}while(0);hb=db+1|0;ib=c[k>>2]|0;fb=c[ib+1524>>2]|0;t=b[fb+(U<<2)>>1]|0;H=b[fb+(U<<2)+2>>1]|0;gb=a[(c[ib+1556>>2]|0)+($<<2)|0]|0;c[h+(hb<<3)>>2]=t;c[h+(hb<<3)+4>>2]=H;c[j+(hb<<2)>>2]=gb;gb=db+2|0;if((gb|0)>0){hb=P<<4;I=pa+($-1)|0;jb=pa+($+1)|0;kb=pa+($-xa)|0;lb=pa+($+xa)|0;mb=0;nb=1073741824;ob=0;pb=ib;ib=fb;while(1){qb=pb+32|0;rb=c[pb>>2]|0;sb=(ba(_,c[qb>>2]|0)|0)+hb|0;tb=c[h+(mb<<3)>>2]|0;c[va>>2]=tb;b[ib+(U<<2)>>1]=tb;tb=c[h+(mb<<3)+4>>2]|0;c[za>>2]=tb;b[ib+(U<<2)+2>>1]=tb;tb=c[j+(mb<<2)>>2]|0;if((tb|0)<0){ub=ob;vb=nb;wb=pb}else{Le[c[na>>2]&255](c[la>>2]|0,tb,1,0,sa,P,N,0,0);do{if(x){if((a[I]|0)==0){xb=0;break}tb=c[qb>>2]|0;yb=sb-1|0;zb=0;Ab=0;while(1){Bb=ba(Ab,tb)|0;Cb=(d[rb+(yb+Bb)|0]|0)-(d[rb+(Bb+sb)|0]|0)|0;Bb=((Cb|0)>-1?Cb:-Cb|0)+zb|0;Cb=Ab+1|0;if((Cb|0)<16){zb=Bb;Ab=Cb}else{xb=Bb;break}}}else{xb=0}}while(0);do{if(O){if((a[jb]|0)==0){Db=xb;break}o=c[qb>>2]|0;eb=sb|15;K=sb+16|0;w=xb;v=0;while(1){q=ba(v,o)|0;B=(d[rb+(q+eb)|0]|0)-(d[rb+(K+q)|0]|0)|0;q=((B|0)>-1?B:-B|0)+w|0;B=v+1|0;if((B|0)<16){w=q;v=B}else{Db=q;break}}}else{Db=xb}}while(0);do{if(Y){if((a[kb]|0)==0){Eb=Db;break}v=c[qb>>2]|0;w=Db;K=0;while(1){eb=K+sb|0;o=(d[rb+(eb-v)|0]|0)-(d[rb+eb|0]|0)|0;eb=((o|0)>-1?o:-o|0)+w|0;o=K+1|0;if((o|0)<16){w=eb;K=o}else{Eb=eb;break}}}else{Eb=Db}}while(0);do{if(V){if((a[lb]|0)==0){Fb=Eb;break}K=c[qb>>2]|0;w=K*15|0;v=K<<4;K=Eb;eb=0;while(1){o=eb+sb|0;q=(d[rb+(o+w)|0]|0)-(d[rb+(o+v)|0]|0)|0;o=((q|0)>-1?q:-q|0)+K|0;q=eb+1|0;if((q|0)<16){K=o;eb=q}else{Fb=o;break}}}else{Fb=Eb}}while(0);rb=(Fb|0)>(nb|0);ub=rb?ob:mb;vb=rb?nb:Fb;wb=c[k>>2]|0}rb=mb+1|0;sb=c[wb+1524>>2]|0;if((rb|0)<(gb|0)){mb=rb;nb=vb;ob=ub;pb=wb;ib=sb}else{Gb=ub;Hb=sb;break}}}else{Gb=0;Hb=fb}ib=c[h+(Gb<<3)>>2]|0;c[va>>2]=ib;pb=c[h+(Gb<<3)+4>>2]|0;c[za>>2]=pb;ob=ib&65535;ib=pb&65535;pb=0;do{nb=pb+U|0;mb=0;do{gb=nb+(ba(mb,Ja)|0)|0;b[Hb+(gb<<2)>>1]=ob;b[Hb+(gb<<2)+2>>1]=ib;mb=mb+1|0;}while((mb|0)<(Ka|0));pb=pb+1|0;}while((pb|0)<(Ka|0));Le[c[na>>2]&255](c[la>>2]|0,c[j+(Gb<<2)>>2]|0,1,0,sa,P,N,0,0);do{if((c[va>>2]|0)==(t|0)){if((c[za>>2]|0)!=(H|0)){break}a[G]=1;Ra=L;Sa=0;break i}}while(0);a[G]=2;Ra=L+1|0;Sa=0}else{Ra=L;Sa=Q}}while(0);U=P+1|0;Ib=c[u>>2]|0;if((U|0)<(Ib|0)){Q=Sa;P=U;L=Ra}else{break}}Jb=Sa;Kb=Ra;Lb=Ib;Mb=c[p>>2]|0;Nb=ca}else{Jb=ja;Kb=ea;Lb=ga;Mb=fa;Nb=N+1|0}if((Nb|0)<(Mb|0)){ja=Jb;N=Nb;ea=Kb;ga=Lb;fa=Mb}else{Ob=Jb;Pb=Kb;break}}}else{Ob=ia;Pb=0}ka=Pb;aa=aa+1|0;ia=Ob}Ia=c[p>>2]|0;M=265;break f}}while(0);xa=c[p>>2]|0;if((xa|0)<=0){Ba=xa;M=266;break}pa=f+68|0;qa=pa|0;ra=f+72|0;ta=f+160|0;wa=f+164|0;ia=0;aa=c[u>>2]|0;ka=xa;while(1){if((aa|0)>0){xa=0;za=aa;while(1){va=(ba(c[z>>2]|0,ia)|0)+xa|0;sa=c[y>>2]|0;if((sa|0)==0){Qb=2}else{Qb=(c[sa>>2]|0)!=0?1:2}do{if((c[(c[(c[k>>2]|0)+1536>>2]|0)+(va<<2)>>2]&7|0)==0){if((a[(c[A>>2]|0)+va|0]&8)==0){Rb=za;break}c[qa>>2]=0;c[ra>>2]=0;Le[c[ta>>2]&255](c[wa>>2]|0,0,Qb,0,pa,xa,ia,0,0);Rb=c[u>>2]|0}else{Rb=za}}while(0);va=xa+1|0;if((va|0)<(Rb|0)){xa=va;za=Rb}else{break}}Sb=Rb;Tb=c[p>>2]|0}else{Sb=aa;Tb=ka}za=ia+1|0;if((za|0)<(Tb|0)){ia=za;aa=Sb;ka=Tb}else{Ia=Tb;M=265;break}}}}while(0);do{if((M|0)==265){if((Ia|0)<=0){Ba=Ia;M=266;break}Tb=l+36|0;Sb=l+40|0;Rb=f+48|0;Qb=f+52|0;Ob=f+56|0;Pb=c[u>>2]|0;Kb=0;while(1){if((Pb|0)>0){Jb=Kb<<3;Mb=c[z>>2]|0;Lb=c[k>>2]|0;Nb=c[Lb+1536>>2]|0;Ib=0;do{Ra=(ba(Mb,Kb)|0)+Ib|0;if((c[Nb+(Ra<<2)>>2]&7|0)==0){M=276}else{if((c[J>>2]|0)==0){M=276}}if((M|0)==276){M=0;Sa=c[Lb>>2]|0;Gb=c[m>>2]|0;j=ba(Gb,Kb)|0;Ka=c[Lb+4>>2]|0;Hb=c[Tb>>2]|0;Ja=c[Lb+8>>2]|0;h=c[Sb>>2]|0;ub=c[n>>2]|0;wb=ba(ub,Kb)|0;vb=c[Rb>>2]|0;Fb=j+Ib<<4;j=wb+Ib<<1;wb=0;do{Eb=wb<<3&8;Db=wb>>>1<<3;xb=0;db=0;do{cb=ba(Gb,db+Db|0)|0;xb=(d[Sa+((Eb|7)+cb+Fb)|0]|0)+((d[Sa+((Eb|6)+cb+Fb)|0]|0)+((d[Sa+((Eb|5)+cb+Fb)|0]|0)+((d[Sa+((Eb|4)+cb+Fb)|0]|0)+((d[Sa+((Eb|3)+cb+Fb)|0]|0)+((d[Sa+((Eb|2)+cb+Fb)|0]|0)+((d[Sa+((Eb|1)+cb+Fb)|0]|0)+((d[Sa+(Eb+cb+Fb)|0]|0)+xb)))))))|0;db=db+1|0;}while((db|0)<8);b[vb+((ba(ub,wb>>1)|0)+(wb&1)+j<<1)>>1]=(xb+4|0)>>>3;wb=wb+1|0;}while((wb|0)<4);wb=Ib<<3;j=(ba(Hb,Jb)|0)+wb|0;ub=(ba(h,Jb)|0)+wb|0;wb=0;vb=0;Fb=0;do{Sa=ba(Hb,Fb)|0;Gb=ba(h,Fb)|0;wb=(d[Ka+((j|7)+Sa)|0]|0)+((d[Ka+((j|6)+Sa)|0]|0)+((d[Ka+((j|5)+Sa)|0]|0)+((d[Ka+((j|4)+Sa)|0]|0)+((d[Ka+((j|3)+Sa)|0]|0)+((d[Ka+((j|2)+Sa)|0]|0)+((d[Ka+((j|1)+Sa)|0]|0)+((d[Ka+(j+Sa)|0]|0)+wb)))))))|0;vb=(d[Ja+((ub|7)+Gb)|0]|0)+((d[Ja+((ub|6)+Gb)|0]|0)+((d[Ja+((ub|5)+Gb)|0]|0)+((d[Ja+((ub|4)+Gb)|0]|0)+((d[Ja+((ub|3)+Gb)|0]|0)+((d[Ja+((ub|2)+Gb)|0]|0)+((d[Ja+((ub|1)+Gb)|0]|0)+((d[Ja+(ub+Gb)|0]|0)+vb)))))))|0;Fb=Fb+1|0;}while((Fb|0)<8);b[(c[Qb>>2]|0)+(Ra<<1)>>1]=(wb+4|0)>>>3;b[(c[Ob>>2]|0)+(Ra<<1)>>1]=(vb+4|0)>>>3}Ib=Ib+1|0;}while((Ib|0)<(Pb|0))}Ib=Kb+1|0;if((Ib|0)<(Ia|0)){Kb=Ib}else{Ub=Rb;Vb=Qb;Wb=Ob;Xb=Ia;break}}}}while(0);if((M|0)==266){Ub=f+48|0;Vb=f+52|0;Wb=f+56|0;Xb=Ba}Nkb(f,c[Ub>>2]|0,c[u>>2]<<1,Xb<<1,c[n>>2]|0,1);Nkb(f,c[Vb>>2]|0,c[u>>2]|0,c[p>>2]|0,c[z>>2]|0,0);Nkb(f,c[Wb>>2]|0,c[u>>2]|0,c[p>>2]|0,c[z>>2]|0,0);Xb=c[Ub>>2]|0;Ba=c[u>>2]|0;M=c[p>>2]|0;Ia=c[n>>2]|0;J=(M<<1)-1|0;Ob=(Ba<<1)-1|0;do{if((J|0)>1&(Ob|0)>1){Qb=1;do{Rb=ba(Qb,Ia)|0;Kb=b[Xb+(Rb<<1)>>1]|0;Pb=1;while(1){Sb=Xb+(Pb+Rb<<1)|0;Tb=b[Sb>>1]|0;Ib=Pb+1|0;b[Sb>>1]=((((Tb<<3)-Kb-(b[Xb+(Ib+Rb<<1)>>1]|0)|0)*10923|0)+32768|0)>>>16;if((Ib|0)<(Ob|0)){Kb=Tb;Pb=Ib}else{break}}Qb=Qb+1|0;}while((Qb|0)<(J|0));if((Ob|0)<2){break}else{Yb=1}do{Qb=1;Pb=b[Xb+(Yb<<1)>>1]|0;while(1){Kb=Xb+((ba(Qb,Ia)|0)+Yb<<1)|0;Rb=b[Kb>>1]|0;Ib=Qb+1|0;b[Kb>>1]=((((Rb<<3)-Pb-(b[Xb+((ba(Ib,Ia)|0)+Yb<<1)>>1]|0)|0)*10923|0)+32768|0)>>>16;if((Ib|0)<(J|0)){Qb=Ib;Pb=Rb}else{break}}Yb=Yb+1|0;}while((Yb|0)<(Ob|0))}}while(0);if((M|0)>0){Ob=l+36|0;Yb=l+40|0;J=0;Ia=Ba;Xb=M;while(1){if((Ia|0)>0){Pb=J<<4;Qb=J<<3;Rb=J<<1;Ib=0;Kb=Ia;while(1){Tb=(ba(c[z>>2]|0,J)|0)+Ib|0;Sb=c[k>>2]|0;do{if((c[(c[Sb+1536>>2]|0)+(Tb<<2)>>2]&120|0)==0){if((a[(c[A>>2]|0)+Tb|0]&2)==0){Zb=Kb;break}Jb=c[Sb>>2]|0;Lb=(ba(Pb,c[m>>2]|0)|0)+(Ib<<4)|0;Nb=c[Sb+4>>2]|0;Mb=ba(c[Ob>>2]|0,Qb)|0;Fb=c[Sb+8>>2]|0;ub=ba(c[Yb>>2]|0,Qb)|0;Ja=Sb+32|0;j=Ib<<1;Ka=0;do{h=Ka&1;Hb=Ka>>1;Gb=(ba(Hb+Rb|0,c[n>>2]|0)|0)+(h|j)|0;Sa=b[(c[Ub>>2]|0)+(Gb<<1)>>1]|0;if(Sa<<16>>16<0){_b=0}else{_b=Sa<<16>>16>2040?-1:((Sa<<16>>16|0)/8|0)&255}Sa=Hb<<3;Hb=h<<3|Lb;h=Hb|1;Gb=Hb|2;db=Hb|3;Eb=Hb|4;Db=Hb|5;ca=Hb|6;cb=Hb|7;bb=0;do{ab=bb+Sa|0;a[Jb+(Hb+(ba(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(h+(ba(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(Gb+(ba(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(db+(ba(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(Eb+(ba(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(Db+(ba(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(ca+(ba(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(cb+(ba(c[Ja>>2]|0,ab)|0))|0]=_b;bb=bb+1|0;}while((bb|0)<8);Ka=Ka+1|0;}while((Ka|0)<4);Ka=Ib<<3;Ja=Mb+Ka|0;Jb=ub+Ka|0;Ka=(ba(c[z>>2]|0,J)|0)+Ib|0;Lb=b[(c[Vb>>2]|0)+(Ka<<1)>>1]|0;j=b[(c[Wb>>2]|0)+(Ka<<1)>>1]|0;if(Lb<<16>>16<0){$b=0}else{$b=Lb<<16>>16>2040?-1:((Lb<<16>>16|0)/8|0)&255}if(j<<16>>16<0){ac=0}else{ac=j<<16>>16>2040?-1:((j<<16>>16|0)/8|0)&255}j=Sb+36|0;Lb=Sb+40|0;Ka=Ja|1;vb=Jb|1;Ra=Ja|2;wb=Jb|2;bb=Ja|3;cb=Jb|3;ca=Ja|4;Db=Jb|4;Eb=Ja|5;db=Jb|5;Gb=Ja|6;h=Jb|6;Hb=Ja|7;Sa=Jb|7;xb=0;do{a[Nb+((ba(c[j>>2]|0,xb)|0)+Ja)|0]=$b;a[Fb+((ba(c[Lb>>2]|0,xb)|0)+Jb)|0]=ac;a[Nb+(Ka+(ba(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(vb+(ba(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(Ra+(ba(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(wb+(ba(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(bb+(ba(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(cb+(ba(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(ca+(ba(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(Db+(ba(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(Eb+(ba(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(db+(ba(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(Gb+(ba(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(h+(ba(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(Hb+(ba(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(Sa+(ba(c[Lb>>2]|0,xb)|0))|0]=ac;xb=xb+1|0;}while((xb|0)<8);Zb=c[u>>2]|0}else{Zb=Kb}}while(0);Sb=Ib+1|0;if((Sb|0)<(Zb|0)){Ib=Sb;Kb=Zb}else{break}}bc=Zb;cc=c[p>>2]|0}else{bc=Ia;cc=Xb}Kb=J+1|0;if((Kb|0)<(cc|0)){J=Kb;Ia=bc;Xb=cc}else{dc=cc;ec=bc;break}}}else{dc=M;ec=Ba}if((c[(c[r>>2]|0)+684>>2]&2|0)!=0){Okb(f,c[c[k>>2]>>2]|0,ec<<1,dc<<1,c[m>>2]|0,1);dc=l+36|0;Okb(f,c[(c[k>>2]|0)+4>>2]|0,c[u>>2]|0,c[p>>2]|0,c[dc>>2]|0,0);ec=l+40|0;Okb(f,c[(c[k>>2]|0)+8>>2]|0,c[u>>2]|0,c[p>>2]|0,c[ec>>2]|0,0);Pkb(f,c[c[k>>2]>>2]|0,c[u>>2]<<1,c[p>>2]<<1,c[m>>2]|0,1);Pkb(f,c[(c[k>>2]|0)+4>>2]|0,c[u>>2]|0,c[p>>2]|0,c[dc>>2]|0,0);Pkb(f,c[(c[k>>2]|0)+8>>2]|0,c[u>>2]|0,c[p>>2]|0,c[ec>>2]|0,0)}if((c[F>>2]|0)>0){ec=f+64|0;f=0;do{p=c[(c[E>>2]|0)+(f<<2)>>2]|0;do{if((c[(c[k>>2]|0)+88>>2]|0)!=3){if((a[(c[A>>2]|0)+p|0]&14)==0){break}a[(c[S>>2]|0)+p|0]=0}}while(0);a[(c[ec>>2]|0)+p|0]=1;f=f+1|0;}while((f|0)<(c[F>>2]|0))}c[k>>2]=0;c[s>>2]=0;c[y>>2]=0;i=g;return}function Nkb(d,e,f,g,h,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=ba(h,g)|0;o=WDb(n<<3)|0;p=o;c[l>>2]=p;q=WDb(n<<4)|0;n=q;c[m>>2]=n;if((o|0)==0|(q|0)==0){yDb(c[d>>2]|0,16,2303424,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=l;$Db(r);s=m;$Db(s);i=k;return}q=(g|0)>0;if(q){o=(f|0)>0;t=d+24|0;u=d+132|0;v=d+40|0;w=0;do{do{if(o){x=w>>j;y=ba(w,h)|0;z=c[(c[u>>2]|0)+1536>>2]|0;A=-1;B=1024;C=0;while(1){D=(ba(c[t>>2]|0,x)|0)+(C>>j)|0;do{if((c[z+(D<<2)>>2]&7|0)==0){E=12}else{if((a[(c[v>>2]|0)+D|0]&4)==0){E=12;break}G=B;H=A;I=C+y|0}}while(0);if((E|0)==12){E=0;D=C+y|0;G=b[e+(D<<1)>>1]|0;H=C;I=D}b[p+(I<<3)+2>>1]=G;c[n+(I<<4)+4>>2]=(H|0)>-1?C-H|0:9999;D=C+1|0;if((D|0)<(f|0)){A=H;B=G;C=D}else{break}}if(!o){break}C=w>>j;B=ba(w,h)|0;A=c[(c[u>>2]|0)+1536>>2]|0;y=-1;z=1024;x=f;while(1){D=x-1|0;J=(ba(c[t>>2]|0,C)|0)+(D>>j)|0;do{if((c[A+(J<<2)>>2]&7|0)==0){E=19}else{if((a[(c[v>>2]|0)+J|0]&4)==0){E=19;break}K=z;L=y;M=D+B|0}}while(0);if((E|0)==19){E=0;J=D+B|0;K=b[e+(J<<1)>>1]|0;L=D;M=J}b[p+(M<<3)>>1]=K;c[n+(M<<4)>>2]=(L|0)>-1?L-D|0:9999;if((D|0)>0){y=L;z=K;x=D}else{break}}}}while(0);w=w+1|0;}while((w|0)<(g|0))}w=(f|0)>0;if(w){K=d+24|0;L=d+132|0;M=d+40|0;v=0;do{do{if(q){t=v>>j;u=c[(c[L>>2]|0)+1536>>2]|0;o=-1;G=1024;H=0;while(1){I=(ba(c[K>>2]|0,H>>j)|0)+t|0;do{if((c[u+(I<<2)>>2]&7|0)==0){E=35}else{if((a[(c[M>>2]|0)+I|0]&4)==0){E=35;break}N=G;O=o;P=(ba(H,h)|0)+v|0}}while(0);if((E|0)==35){E=0;I=(ba(H,h)|0)+v|0;N=b[e+(I<<1)>>1]|0;O=H;P=I}b[p+(P<<3)+6>>1]=N;c[n+(P<<4)+12>>2]=(O|0)>-1?H-O|0:9999;I=H+1|0;if((I|0)<(g|0)){o=O;G=N;H=I}else{break}}if(!q){break}H=v>>j;G=c[(c[L>>2]|0)+1536>>2]|0;o=-1;u=1024;t=g;while(1){I=t-1|0;D=(ba(c[K>>2]|0,I>>j)|0)+H|0;do{if((c[G+(D<<2)>>2]&7|0)==0){E=42}else{if((a[(c[M>>2]|0)+D|0]&4)==0){E=42;break}Q=u;R=o;S=(ba(I,h)|0)+v|0}}while(0);if((E|0)==42){E=0;D=(ba(I,h)|0)+v|0;Q=b[e+(D<<1)>>1]|0;R=I;S=D}b[p+(S<<3)+4>>1]=Q;c[n+(S<<4)+8>>2]=(R|0)>-1?R-I|0:9999;if((I|0)>0){o=R;u=Q;t=I}else{break}}}}while(0);v=v+1|0;}while((v|0)<(f|0))}if(!q){r=l;$Db(r);s=m;$Db(s);i=k;return}q=d+24|0;v=d+132|0;Q=d+40|0;if(w){T=0}else{r=l;$Db(r);s=m;$Db(s);i=k;return}do{w=T>>j;d=ba(T,h)|0;R=c[q>>2]|0;S=c[(c[v>>2]|0)+1536>>2]|0;E=0;do{M=(ba(R,w)|0)+(E>>j)|0;do{if((c[S+(M<<2)>>2]&120|0)==0){if((a[(c[Q>>2]|0)+M|0]&4)==0){break}K=E+d|0;L=c[n+(K<<4)>>2]|0;N=268435456/((L>>>0>1>>>0?L:1)>>>0)|0;L=0;O=b[p+(K<<3)>>1]|0;P=gHb(O<<16>>16,O<<16>>16<0|0?-1:0,N,L)|0;O=F;t=c[n+(K<<4)+4>>2]|0;u=268435456/((t>>>0>1>>>0?t:1)>>>0)|0;t=0;o=b[p+(K<<3)+2>>1]|0;G=gHb(o<<16>>16,o<<16>>16<0|0?-1:0,u,t)|0;o=YGb(G,F,P,O)|0;O=F;P=YGb(u,t,N,L)|0;L=F;N=c[n+(K<<4)+8>>2]|0;t=268435456/((N>>>0>1>>>0?N:1)>>>0)|0;N=0;u=b[p+(K<<3)+4>>1]|0;G=gHb(u<<16>>16,u<<16>>16<0|0?-1:0,t,N)|0;u=YGb(G,F,o,O)|0;O=F;o=YGb(t,N,P,L)|0;L=F;P=c[n+(K<<4)+12>>2]|0;N=268435456/((P>>>0>1>>>0?P:1)>>>0)|0;P=0;t=b[p+(K<<3)+6>>1]|0;G=gHb(t<<16>>16,t<<16>>16<0|0?-1:0,N,P)|0;t=YGb(G,F,u,O)|0;O=F;u=YGb(N,P,o,L)|0;L=F;o=YGb(u>>>1|L<<31,L>>>1|0<<31,t,O)|0;O=eHb(o,F,u,L)|0;b[e+(K<<1)>>1]=O}}while(0);E=E+1|0;}while((E|0)<(f|0));T=T+1|0;}while((T|0)<(g|0));r=l;$Db(r);s=m;$Db(s);i=k;return}function Okb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;l=i;do{if((c[(c[e>>2]|0)+48>>2]|0)==28){if((c[e+148>>2]|0)==0){yDb(0,0,1910824,(m=i,i=i+24|0,c[m>>2]=2327392,c[m+8>>2]=2347656,c[m+16>>2]=45,m)|0);i=m;Cd()}else{n=c[e+16>>2]<<2;o=4;break}}else{n=c[e+28>>2]|0;o=2}}while(0);m=o>>>(k>>>0);o=ba(n,m)|0;if((h|0)<=0){i=l;return}n=g-1|0;g=(n|0)>0;p=e+24|0;q=e+40|0;r=e+132|0;e=j<<3;s=0;do{if(g){t=s>>k;u=ba(e,s)|0;v=ba(o,s)|0;w=0;while(1){x=ba(c[p>>2]|0,t)|0;y=x+(w>>k)|0;z=c[q>>2]|0;A=w+1|0;B=x+(A>>k)|0;x=c[r>>2]|0;C=c[x+1536>>2]|0;D=(w<<3)+u|0;E=(ba(w,m)|0)+v|0;F=c[x+1524>>2]|0;x=F+(E<<2)|0;G=(ba(A,m)|0)+v|0;H=F+(G<<2)|0;I=(a[z+y|0]&14)!=0;J=I^1;K=(a[z+B|0]&14)==0;do{if(!(K&J)){if(((c[C+(B<<2)>>2]|c[C+(y<<2)>>2])&7|0)==0){z=(b[x>>1]|0)-(b[H>>1]|0)|0;L=(b[F+(G<<2)+2>>1]|0)+(b[F+(E<<2)+2>>1]|0)|0;if((((L|0)>-1?L:-L|0)+((z|0)>-1?z:-z|0)|0)<2){break}}z=D|7;L=D|6;M=D+8|0;N=D+9|0;O=K|J;P=D|5;Q=D|4;R=D+10|0;S=D+11|0;T=0;do{U=ba(T,j)|0;V=f+(U+z)|0;W=d[V]|0;X=f+(U+L)|0;Y=W-(d[X]|0)|0;Z=f+(M+U)|0;_=d[Z]|0;$=_-W|0;aa=f+(N+U)|0;ca=(d[aa]|0)-_|0;_=(($|0)>-1?$:-$|0)-(((Y|0)>-1?Y:-Y|0)+1+((ca|0)>-1?ca:-ca|0)>>1)|0;ca=(_|0)>0?_:0;_=($|0)<0?-ca|0:ca;do{if((_|0)!=0){if(O){da=(_<<4|0)/9|0}else{da=_}if(I){a[V]=a[1235032+(((da*7|0)>>4)+1024+W)|0]|0;a[X]=a[1235032+(((da*5|0)>>4)+1024+(d[X]|0))|0]|0;ca=f+(U+P)|0;a[ca]=a[1235032+(((da*3|0)>>4)+1024+(d[ca]|0))|0]|0;ca=f+(U+Q)|0;a[ca]=a[1235032+((da>>4)+1024+(d[ca]|0))|0]|0}if(K){break}a[Z]=a[1235032+(1024-((da*7|0)>>4)+(d[Z]|0))|0]|0;a[aa]=a[1235032+(1024-((da*5|0)>>4)+(d[aa]|0))|0]|0;ca=f+(R+U)|0;a[ca]=a[1235032+(1024-((da*3|0)>>4)+(d[ca]|0))|0]|0;ca=f+(S+U)|0;a[ca]=a[1235032+(1024-(da>>4)+(d[ca]|0))|0]|0}}while(0);T=T+1|0;}while((T|0)<8)}}while(0);if((A|0)<(n|0)){w=A}else{break}}}s=s+1|0;}while((s|0)<(h|0));i=l;return}function Pkb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0;l=i;do{if((c[(c[e>>2]|0)+48>>2]|0)==28){if((c[e+148>>2]|0)==0){yDb(0,0,1910824,(m=i,i=i+24|0,c[m>>2]=2327392,c[m+8>>2]=2347656,c[m+16>>2]=45,m)|0);i=m;Cd()}else{n=c[e+16>>2]<<2;o=4;break}}else{n=c[e+28>>2]|0;o=2}}while(0);m=o>>>(k>>>0);o=ba(n,m)|0;n=h-1|0;if((n|0)<=0){i=l;return}h=(g|0)>0;p=e+24|0;q=e+40|0;r=e+132|0;e=j*7|0;s=j*6|0;t=j<<3;u=j*9|0;v=j*5|0;w=j<<2;x=j*10|0;y=j*11|0;z=0;while(1){if(h){A=z>>k;B=z+1|0;C=B>>k;D=ba(z,j)|0;E=ba(z,o)|0;F=ba(B,o)|0;G=0;while(1){H=G>>k;I=c[p>>2]|0;J=(ba(I,A)|0)+H|0;K=c[q>>2]|0;L=(ba(I,C)|0)+H|0;H=c[r>>2]|0;I=c[H+1536>>2]|0;M=ba(G,m)|0;N=M+E|0;O=c[H+1524>>2]|0;H=O+(N<<2)|0;P=M+F|0;M=O+(P<<2)|0;Q=(a[K+J|0]&14)!=0;R=Q^1;S=(a[K+L|0]&14)==0;do{if(!(S&R)){if(((c[I+(L<<2)>>2]|c[I+(J<<2)>>2])&7|0)==0){K=(b[H>>1]|0)-(b[M>>1]|0)|0;T=(b[O+(P<<2)+2>>1]|0)+(b[O+(N<<2)+2>>1]|0)|0;if((((T|0)>-1?T:-T|0)+((K|0)>-1?K:-K|0)|0)<2){break}}K=G+D<<3;T=S|R;U=0;do{V=K+U|0;W=f+(V+e)|0;X=d[W]|0;Y=f+(V+s)|0;Z=X-(d[Y]|0)|0;_=f+(V+t)|0;$=d[_]|0;aa=$-X|0;ca=f+(V+u)|0;da=(d[ca]|0)-$|0;$=((aa|0)>-1?aa:-aa|0)-(((Z|0)>-1?Z:-Z|0)+1+((da|0)>-1?da:-da|0)>>1)|0;da=($|0)>0?$:0;$=(aa|0)<0?-da|0:da;do{if(($|0)!=0){if(T){ea=($<<4|0)/9|0}else{ea=$}if(Q){a[W]=a[1235032+(((ea*7|0)>>4)+1024+X)|0]|0;a[Y]=a[1235032+(((ea*5|0)>>4)+1024+(d[Y]|0))|0]|0;da=f+(V+v)|0;a[da]=a[1235032+(((ea*3|0)>>4)+1024+(d[da]|0))|0]|0;da=f+(V+w)|0;a[da]=a[1235032+((ea>>4)+1024+(d[da]|0))|0]|0}if(S){break}a[_]=a[1235032+(1024-((ea*7|0)>>4)+(d[_]|0))|0]|0;a[ca]=a[1235032+(1024-((ea*5|0)>>4)+(d[ca]|0))|0]|0;da=f+(V+x)|0;a[da]=a[1235032+(1024-((ea*3|0)>>4)+(d[da]|0))|0]|0;da=f+(V+y)|0;a[da]=a[1235032+(1024-(ea>>4)+(d[da]|0))|0]|0}}while(0);U=U+1|0;}while((U|0)<8)}}while(0);S=G+1|0;if((S|0)<(g|0)){G=S}else{fa=B;break}}}else{fa=z+1|0}if((fa|0)<(n|0)){z=fa}else{break}}i=l;return}function Qkb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;i=i+40|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=F_a(d,e)|0;p=d|0;q=d+4|0;if(((c[q>>2]|0)-(c[p>>2]|0)|0)>>>0<(o*12|0)>>>0){r=-1094995529;i=h;return r|0}s=n;t=(f|0)>2;u=a;v=d+8|0;w=f+1|0;f=0;while(1){if((f|0)>=(o|0)){break}a:do{if(t){x=0}else{Q_a(d,e,k,m,l,j)|0;do{if((E_a(c[k>>2]|0)|0)==0){y=c[k>>2]&65535;z=0;while(1){if(!(z>>>0<117>>>0)){A=11;break}if((b[190120+(z*34|0)>>1]|0)==y<<16>>16){A=10;break}else{z=z+1|0}}if((A|0)==10){A=0;y=190088+(z*34|0)|0;c[n>>2]=y;B=1;C=y}else if((A|0)==11){A=0;c[n>>2]=0;y=WDb(7)|0;c[n>>2]=y;if((y|0)==0){x=-12;break a}Lb(y|0,7,2177352,(D=i,i=i+8|0,c[D>>2]=c[k>>2],D)|0)|0;i=D;B=0;C=c[n>>2]|0}y=c[l>>2]|0;E=c[m>>2]|0;switch(E|0){case 2:{F=O_a(y,C,d,e,g)|0;break};case 9:case 4:{F=K_a(y,C,0,d,e,g)|0;break};case 3:{F=M_a(y,C,0,d,e,g)|0;break};case 1:case 7:{F=N_a(y,C,0,d,e,g)|0;break};case 12:{F=L_a(y,C,0,d,e,g)|0;break};case 10:case 5:{F=J_a(y,C,0,d,e,g)|0;break};default:{DDb(u,2304096,(D=i,i=i+8|0,c[D>>2]=E,D)|0);i=D;F=0}}if(B){G=F;break}$Db(s);G=F}else{G=Qkb(a,d,e,w,g)|0}}while(0);E=c[j>>2]|0;y=c[v>>2]|0;H=(c[q>>2]|0)-y|0;if((E|0)<0){I=0}else{I=(H|0)<(E|0)?H:E}c[p>>2]=y+I;x=G}}while(0);if((x|0)<0){r=x;A=28;break}else{f=f+1|0}}if((A|0)==28){i=h;return r|0}r=G_a(d,e)|0;i=h;return r|0}function Rkb(){if(a[1244616]|0){return}c[2202851]=7957104;c[2202853]=528;c[2202856]=7954512;c[2202858]=648;N_(8811400,9,104,1502288,1,1,1502496,1,1,1502048,2,2,4)|0;N_(8811420,9,104,1502392,1,1,1502600,1,1,1502048,2,2,4)|0;c[2202861]=7952464;c[2202863]=512;N_(8811440,9,11,1502256,1,1,1502272,1,1,0,0,0,4)|0;a[1244616]=1;return}function Skb(a,e,f,g,h,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;m=i;i=i+24|0;n=m|0;o=a+120|0;p=(c[o>>2]|0)+2|0;q=p<<2;r=WDb(q)|0;s=r;t=WDb(q)|0;q=t;if((r|0)==0|(t|0)==0){u=s;v=q;w=-12;x=u;ZDb(x);y=v;ZDb(y);i=m;return w|0}c[q>>2]=c[o>>2];c[t+4>>2]=0;c[t+8>>2]=0;t=f<<3;f=t>>>0>2147483639>>>0|(e|0)==0;r=f?0:e;e=f?0:t;f=n|0;c[f>>2]=r;c[n+12>>2]=e;z=n+16|0;c[z>>2]=e+8;c[n+4>>2]=r+(e>>3);e=n+8|0;c[e>>2]=0;A=r;r=fe(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0;if((r&-1048576|0)==1048576){B=0}else{B=(r&-65536|0)!=65536}if((h|0)<=0){u=s;v=q;w=0;x=u;ZDb(x);y=v;ZDb(y);i=m;return w|0}r=(k|0)==2;A=r|B;B=a;C=a+696|0;D=(l&1|0)==0;l=q;q=s;s=0;E=g;a:while(1){g=q+(p<<2)|0;if((k|0)==4){F=Tkb(a,n,c[o>>2]|0,q,g,l)|0;if((F|0)<0){u=q;v=l;w=F;G=40;break}H=c[o>>2]|0;G=38}else if((k|0)==3){I=D;G=10}else{I=0;G=10}do{if((G|0)==10){G=0;if(!A){F=c[e>>2]|0;J=c[f>>2]|0;K=c[z>>2]|0;L=-1;M=t-F|0;N=F;while(1){if((M|0)<=0){u=q;v=l;w=0;G=40;break a}F=d[J+(N>>>3)|0]<<(N&7)>>>7;O=((N|0)<(K|0))+N|0;c[e>>2]=O;P=F&1|L<<1;if((P&4095|0)==1){break}else{L=P;M=M-1|0;N=O}}}do{if(r|I){Q=c[f>>2]|0;G=17}else{N=c[e>>2]|0;M=c[f>>2]|0;L=d[M+(N>>>3)|0]|0;c[e>>2]=((N|0)<(c[z>>2]|0))+N;if((L&128>>>((N&7)>>>0)|0)!=0){Q=M;G=17;break}R=Tkb(a,n,c[o>>2]|0,q,g,l)|0}}while(0);do{if((G|0)==17){G=0;M=0;N=c[o>>2]|0;L=q;b:while(1){K=c[8811404+(M*20|0)>>2]|0;J=c[z>>2]|0;O=0;P=c[e>>2]|0;while(1){F=Q+(P>>>3)|0;S=(fe(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(P&7)>>>23;F=b[K+(S<<2)>>1]|0;T=b[K+(S<<2)+2>>1]|0;S=T<<16>>16;if(T<<16>>16<0){T=P+9|0;U=J>>>0>T>>>0?T:J;T=Q+(U>>>3)|0;V=((fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(U&7)>>>((S+32|0)>>>0))+F|0;W=b[K+(V<<2)+2>>1]|0;X=b[K+(V<<2)>>1]|0;Y=U}else{W=S;X=F;Y=P}F=W+Y|0;Z=J>>>0>F>>>0?F:J;_=X+O|0;if(X>>>0<64>>>0){break}if((X|0)==-1){G=29;break b}else{O=_;P=Z}}c[e>>2]=Z;$=L+4|0;c[L>>2]=_;if(!($>>>0<g>>>0)){G=23;break}if(!(N>>>0>_>>>0)){G=25;break}M=M^1;N=N-_|0;L=$}if((G|0)==23){G=0;yDb(B,16,2177160,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;R=-1094995529;break}else if((G|0)==25){G=0;if((N|0)==(_|0)){c[$>>2]=0;R=0;break}else{yDb(B,16,2304e3,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;R=-1094995529;break}}else if((G|0)==29){G=0;c[e>>2]=Z;yDb(B,16,2173880,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;R=-1094995529;break}}}while(0);do{if(r){L=c[e>>2]|0;M=-L&7;if((M|0)==0){break}P=c[z>>2]|0;O=M+L|0;c[e>>2]=P>>>0>O>>>0?O:P}}while(0);P=(R|0)<0;if((c[C>>2]&8|0)!=0&P){u=q;v=l;w=R;G=40;break a}O=c[o>>2]|0;if(!P){H=O;G=38;break}Ukb(E,j,O,l);ba=q;ca=l}}while(0);if((G|0)==38){G=0;Ukb(E,j,H,q);ba=l;ca=q}g=s+1|0;if((g|0)<(h|0)){l=ca;q=ba;s=g;E=E+j|0}else{u=ba;v=ca;w=0;G=40;break}}if((G|0)==40){x=u;ZDb(x);y=v;ZDb(y);i=m;return w|0}return 0}function Tkb(a,e,f,g,h,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;k=i;if((f|0)==0){c[g>>2]=0;l=0;i=k;return l|0}m=e+8|0;n=e+16|0;o=c[2202861]|0;p=c[e>>2]|0;e=j+4|0;q=0;r=0;s=g;g=c[j>>2]|0;j=0;a:while(1){t=c[m>>2]|0;u=c[n>>2]|0;v=p+(t>>>3)|0;w=(fe(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(t&7)>>>23;v=b[o+(w<<2)>>1]|0;x=(b[o+(w<<2)+2>>1]|0)+t|0;t=u>>>0>x>>>0?x:u;c[m>>2]=t;if((v|0)==0){if(g>>>0<f>>>0){y=(c[e>>2]|0)+g|0;z=e+4|0}else{y=g;z=e}if(y>>>0<f>>>0){A=(c[z>>2]|0)+y|0;B=z+4|0}else{A=y;B=z}if(y>>>0>f>>>0){C=13;break}D=y;E=A;F=s;G=r-j+y|0;H=q;I=B}else if((v|0)==1){x=c[8811404+(q*20|0)>>2]|0;w=0;J=t;do{t=p+(J>>>3)|0;K=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(J&7)>>>23;t=b[x+(K<<2)>>1]|0;L=b[x+(K<<2)+2>>1]|0;K=L<<16>>16;if(L<<16>>16<0){L=J+9|0;M=u>>>0>L>>>0?L:u;L=p+(M>>>3)|0;N=((fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>((K+32|0)>>>0))+t|0;O=b[x+(N<<2)+2>>1]|0;P=b[x+(N<<2)>>1]|0;Q=M}else{O=K;P=t;Q=J}t=O+Q|0;J=u>>>0>t>>>0?t:u;c[m>>2]=J;if((P|0)==-1){C=18;break a}w=P+w|0;}while((P|0)>=64);J=s+4|0;c[s>>2]=w+r;if(!(J>>>0<h>>>0)){C=21;break}u=w+j|0;if(u>>>0>f>>>0|w>>>0>f>>>0){C=23;break}x=(q|0)==0;t=c[8811404+((x&1)*20|0)>>2]|0;K=c[n>>2]|0;M=0;N=c[m>>2]|0;do{L=p+(N>>>3)|0;R=(fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(N&7)>>>23;L=b[t+(R<<2)>>1]|0;S=b[t+(R<<2)+2>>1]|0;R=S<<16>>16;if(S<<16>>16<0){S=N+9|0;T=K>>>0>S>>>0?S:K;S=p+(T>>>3)|0;U=((fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(T&7)>>>((R+32|0)>>>0))+L|0;V=b[t+(U<<2)+2>>1]|0;W=b[t+(U<<2)>>1]|0;X=T}else{V=R;W=L;X=N}L=V+X|0;N=K>>>0>L>>>0?L:K;c[m>>2]=N;if((W|0)==-1){C=18;break a}M=W+M|0;}while((W|0)>=64);N=s+8|0;c[J>>2]=M;if(!(N>>>0<h>>>0)){C=21;break}K=M+u|0;if(K>>>0>f>>>0|M>>>0>f>>>0){C=23;break}D=K;E=g;F=N;G=0;H=x&1^1;I=e}else if((v|0)==(-1|0)){C=7;break}else{if((v-9|0)>>>0<2>>>0){C=26;break}N=v-5|0;K=N+(g-j)|0;t=e-4|0;w=g-(c[t>>2]|0)|0;L=N+g|0;if(L>>>0>f>>>0|K>>>0>f>>>0){C=28;break}N=s+4|0;c[s>>2]=K+r;if(!(N>>>0<h>>>0)){C=30;break}D=L;E=w;F=N;G=0;H=(q|0)==0|0;I=t}if(D>>>0>=f>>>0|E>>>0>D>>>0){Y=I;Z=E}else{t=I;N=E;while(1){w=t+8|0;L=(c[t>>2]|0)+N+(c[t+4>>2]|0)|0;if(L>>>0>D>>>0){Y=w;Z=L;break}else{t=w;N=L}}}if(D>>>0<f>>>0){e=Y;q=H;r=G;s=F;g=Z;j=D}else{C=34;break}}if((C|0)==7){yDb(a,16,2098960,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((C|0)==13){yDb(a,16,2304e3,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((C|0)==18){yDb(a,16,2173880,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((C|0)==21){yDb(a,16,2177160,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((C|0)==23){yDb(a,16,2304e3,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((C|0)==26){EDb(a,2043720,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1163346256;i=k;return l|0}else if((C|0)==28){yDb(a,16,2304e3,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((C|0)==30){yDb(a,16,2177160,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((C|0)==34){C=F+4|0;c[F>>2]=G;if((G|0)==0){l=0;i=k;return l|0}if(C>>>0<h>>>0){c[C>>2]=0;l=0;i=k;return l|0}else{yDb(a,16,2177160,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1;i=k;return l|0}}return 0}function Ukb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;h=0;if((e|0)>0){j=(d&268435456|0)!=0?0:b;k=32;l=-1;m=e;n=0;o=0}else{i=g;return}while(1){e=n+1|0;b=c[f+(n<<2)>>2]|0;d=~l;p=m-b|0;if((b|0)>16){q=d&65535;r=b-17&-16;s=j;t=k;u=b;v=o;while(1){if((t|0)>16){w=t-16|0;y=v<<16|q;z=s}else{A=s;x=fe(v<<t|q>>>((16-t|0)>>>0)|0)|0;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;w=t+16|0;y=q;z=s+4|0}h=y;A=u-16|0;if((A|0)>16){s=z;t=w;u=A;v=y}else{break}}B=z;C=w;D=b-16-r|0;E=y}else{B=j;C=k;D=b;E=o}if((D|0)==0){F=C;G=B;H=E}else{v=(1<<D)-1&d;if((C|0)>(D|0)){I=C;J=E<<D|v;K=B}else{u=B;x=fe(E<<C|v>>>((D-C|0)>>>0)|0)|0;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;I=C+32|0;J=v;K=B+4|0}h=J;F=I-D|0;G=K;H=J}if((p|0)>0){j=G;k=F;l=d;m=p;n=e;o=H}else{break}}if((F|0)>=32){i=g;return}o=H<<F;h=o;H=o>>>24&255;o=F;F=G;while(1){a[F]=H;G=h;h=G<<8;n=o+8|0;if((n|0)<32){H=G>>>16&255;o=n;F=F+1|0}else{break}}i=g;return}function Vkb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;d=a+120|0;if((c[d>>2]|0)==0){e=-1094995529;return e|0}f=a+124|0;if((c[f>>2]|0)==0){e=-1094995529;return e|0}c[b+4>>2]=a;c[b+4752>>2]=c[a+88>>2];g=b+4760|0;c[g>>2]=ICb()|0;h=ICb()|0;c[b+4772>>2]=h;if((c[g>>2]|0)==0|(h|0)==0){e=-12;return e|0}Z3(b+38528|0,a);c[b+4728>>2]=c[d>>2];c[b+4732>>2]=c[f>>2];c[b+40804>>2]=1;c[b+40800>>2]=1;e=0;return e|0}function Wkb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b+4792|0;c[d+4792>>2]=c[e>>2];c[d+4748>>2]=c[b+4748>>2];f=d+4796|0;g=c[f>>2]|0;a:do{if((c[e>>2]|0)>0){h=0;i=g;b:while(1){do{if((i|0)==0){j=d+4804+(h*2580|0)+2572|0;if((c[j>>2]|0)!=0){break}k=WDb((c[d+4804+(h*2580|0)+2564>>2]|0)*6|0)|0;c[j>>2]=k;if((k|0)==0){l=-12;m=10;break b}}else{k=d+4804+(h*2580|0)+2568|0;if((c[k>>2]|0)!=0){break}j=WDb(c[d+4804+(h*2580|0)+2564>>2]<<5)|0;c[k>>2]=j;if((j|0)==0){l=-12;m=10;break b}}}while(0);j=h+1|0;k=c[f>>2]|0;if((j|0)<(c[e>>2]|0)){h=j;i=k}else{n=k;break a}}if((m|0)==10){return l|0}}else{n=g}}while(0);if((n|0)>1){o=1}else{l=0;return l|0}while(1){n=a[b+38196+o|0]|0;a[d+280+o|0]=n;a[256-o+(d+24)|0]=-n;n=o+1|0;if((n|0)<256){o=n}else{l=0;break}}return l|0}function Xkb(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+40796|0;d=0;while(1){if((d|0)>=(c[b>>2]|0)){e=0;f=4;break}if((Wkb(a,c[a+39772+(d<<2)>>2]|0)|0)<0){e=-12;f=4;break}else{d=d+1|0}}if((f|0)==4){return e|0}return 0}function Ykb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;d=a+40804|0;e=a+40800|0;f=ba(c[e>>2]|0,c[d>>2]|0)|0;g=a+40796|0;c[g>>2]=f;if((f|0)<=0){yDb(0,0,2177008,(h=i,i=i+24|0,c[h>>2]=2303872,c[h+8>>2]=2173848,c[h+16>>2]=119,h)|0);i=h;Cd();return 0}h=a+4|0;j=a;k=0;l=f;while(1){if((k|0)>=(l|0)){m=0;n=8;break}f=cEb(40840)|0;o=c[d>>2]|0;p=(k|0)%(o|0)|0;q=(k|0)/(o|0)|0;r=c[h>>2]|0;s=c[r+120>>2]|0;t=(ba(s,p)|0)/(o|0)|0;u=c[r+124>>2]|0;r=ba(u,q)|0;v=c[e>>2]|0;w=(r|0)/(v|0)|0;if((f|0)==0){m=-12;n=8;break}r=(ba(u,q+1|0)|0)/(v|0)|0;v=(ba(s,p+1|0)|0)/(o|0)|0;c[a+39772+(k<<2)>>2]=f;UGb(f|0,j|0,40840)|0;TGb(f+4688|0,0,32)|0;c[f+40808>>2]=v-t;c[f+40812>>2]=r-w;c[f+40816>>2]=t;c[f+40820>>2]=w;w=WDb(((c[f+4728>>2]|0)*24|0)+144|0)|0;c[f+38492>>2]=w;if((w|0)==0){m=-12;n=8;break}k=k+1|0;l=c[g>>2]|0}if((n|0)==8){i=b;return m|0}return 0}function Zkb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+38524|0;if((c[b>>2]|0)>0){d=0}else{e=0;return e|0}while(1){f=a+38164+(d<<2)|0;g=WDb(c[f>>2]<<5)|0;c[a+38452+(d<<2)>>2]=g;if((g|0)==0){e=-12;h=4;break}TGb(g|0,-128|0,c[f>>2]<<5|0)|0;f=d+1|0;if((f|0)<(c[b>>2]|0)){d=f}else{e=0;h=4;break}}if((h|0)==4){return e|0}return 0}function _kb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d+4792|0;if((c[f>>2]|0)<=0){return}g=e+4796|0;h=0;do{a[e+4804+(h*2580|0)+2576|0]=-128;a[e+4804+(h*2580|0)+2577|0]=-128;do{if((c[g>>2]|0)==0){i=e+4804+(h*2580|0)+2564|0;if((c[i>>2]|0)<=0){break}j=e+4804+(h*2580|0)+2572|0;k=0;do{l=c[j>>2]|0;b[l+(k*6|0)>>1]=0;b[l+(k*6|0)+2>>1]=4;a[l+(k*6|0)+4|0]=0;a[(c[j>>2]|0)+(k*6|0)+5|0]=1;k=k+1|0;}while((k|0)<(c[i>>2]|0))}else{i=c[d+38452+(c[e+4804+(h*2580|0)+2560>>2]<<2)>>2]|0;k=c[e+4804+(h*2580|0)+2568>>2]|0;if((i|0)==0){TGb(k|0,-128|0,c[e+4804+(h*2580|0)+2564>>2]<<5|0)|0;break}else{UGb(k|0,i|0,c[e+4804+(h*2580|0)+2564>>2]<<5)|0;break}}}while(0);h=h+1|0;}while((h|0)<(c[f>>2]|0));return}function $kb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+60>>2]|0;d=b+4760|0;e=d;if((c[e>>2]|0)!=0){U0a(a,d)}JCb(e);e=b+4772|0;d=e;if((c[d>>2]|0)!=0){U0a(a,e)}JCb(d);d=b+40796|0;if((c[d>>2]|0)>0){e=b+39772|0;f=b+4792|0;g=0;do{h=c[e+(g<<2)>>2]|0;if((c[f>>2]|0)>0){i=0;do{$Db(h+4804+(i*2580|0)+2568|0);$Db(h+4804+(i*2580|0)+2572|0);i=i+1|0;}while((i|0)<(c[f>>2]|0))}$Db(h+38492|0);g=g+1|0;}while((g|0)<(c[d>>2]|0))}$Db(a+668|0);a=b+38524|0;if((c[a>>2]|0)>0){g=b+38452|0;f=b+4688|0;e=b+39772|0;i=0;do{$Db(g+(i<<2)|0);if((c[d>>2]|0)>0){j=0;do{$Db((c[e+(j<<2)>>2]|0)+4688+(i<<2)|0);j=j+1|0;}while((j|0)<(c[d>>2]|0))}$Db(f+(i<<2)|0);i=i+1|0;}while((i|0)<(c[a>>2]|0))}if((c[d>>2]|0)<=0){return 0}a=b+39772|0;b=0;do{$Db(a+(b<<2)|0);b=b+1|0;}while((b|0)<(c[d>>2]|0));return 0}function alb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;d=a+54|0;blb(a,(ba(b[1217752+(c<<1)>>1]|0,b[d>>1]|0)|0)>>10);e=a+52|0;a=(((b[e>>1]|0)*127|0)>>7)+(b[766632+(c<<1)>>1]|0)|0;if((a|0)<0){f=0}else{f=(a|0)>18432?18432:a&65535}b[e>>1]=f;e=(f<<16>>16)-16384|0;f=b[904992+((e>>>6&31)<<1)>>1]|0;a=e>>11;if((a|0)<0){g=f>>-a&65535;b[d>>1]=g;return}else{g=f<<a&65535;b[d>>1]=g;return}}function blb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=d+4|0;g=((c[f>>2]|0)+e|0)>>>31;h=d+8|0;i=a[h]|0;j=a[437840+((g|0)!=(i<<24>>24|0))|0]|0;k=d+9|0;l=a[437840+((g|0)==(a[k]|0))|0]|0;a[k]=i;a[h]=g;g=d+12|0;h=b[g>>1]|0;i=h<<16>>16;if(h<<16>>16<-8191){m=-8191}else{m=(i|0)>8191?8191:i}h=((ba(m,j)|0)>>5)+(l<<7)|0;l=d+14|0;m=h+(((b[l>>1]|0)*127|0)>>7)|0;if((m|0)<-12288){n=-12288}else{n=(m|0)>12288?12288:m&65535}b[l>>1]=n;l=n<<16>>16;n=15360-l|0;m=((i*255|0)>>8)+(j*-192|0)|0;j=-n|0;if((m|0)<(j|0)){o=j&65535}else{o=((m|0)>(n|0)?n:m)&65535}b[g>>1]=o;g=d+40|0;m=((b[g>>1]|0)*255|0)>>>8;if((e|0)==0){n=m&65535;b[g>>1]=n;j=d+42|0;i=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=i;j=d+44|0;h=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=h;j=d+46|0;k=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=k;j=d+48|0;p=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=p;j=d+50|0;q=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=q;r=c[d+32>>2]|0;s=c[d+28>>2]|0;t=c[d+24>>2]|0;u=c[d+20>>2]|0;v=c[d+16>>2]|0;w=q;x=p;y=k;z=h;A=i;B=n;C=d+36|0}else{n=c[d+16>>2]|0;i=((n^e)>>31&65280|128)+m&65535;b[g>>1]=i;g=d+42|0;m=c[d+20>>2]|0;h=((m^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=h;g=d+44|0;k=c[d+24>>2]|0;p=((k^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=p;g=d+46|0;q=c[d+28>>2]|0;j=((q^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=j;g=d+48|0;D=c[d+32>>2]|0;E=((D^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=E;g=d+50|0;F=d+36|0;G=((c[F>>2]^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=G;r=D;s=q;t=k;u=m;v=n;w=G;x=E;y=j;z=p;A=h;B=i;C=F}c[C>>2]=r;c[d+32>>2]=s;c[d+28>>2]=t;c[d+24>>2]=u;c[d+20>>2]=v;C=e<<1;if((C+32768|0)>>>0>65535>>>0){H=(C>>31^32767)&65535}else{H=C&65535}C=H<<16>>16;c[d+16>>2]=C;H=((ba(B<<16>>16,C)|0)>>15)+(((ba(A<<16>>16,v)|0)>>15)+(((ba(z<<16>>16,u)|0)>>15)+(((ba(y<<16>>16,t)|0)>>15)+(((ba(x<<16>>16,s)|0)>>15)+((ba(w<<16>>16,r)|0)>>15)))))|0;c[f>>2]=H;f=d|0;r=(b[f>>1]|0)+e<<1;if((r+32768|0)>>>0>65535>>>0){I=(r>>31^32767)&65535}else{I=r&65535}r=((ba(o<<16>>16,I<<16>>16)|0)>>15)+H|0;H=d+10|0;d=r+((ba(b[H>>1]|0,l)|0)>>15)|0;if(!((d+32768|0)>>>0>65535>>>0)){J=d&65535;b[f>>1]=J;b[H>>1]=I;return}J=(d>>31^32767)&65535;b[f>>1]=J;b[H>>1]=I;return}function clb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;blb(a,c);c=a+52|0;e=(((b[c>>1]|0)*127|0)>>7)+(b[948560+((d&1)<<1)>>1]|0)|0;if((e|0)<0){f=0}else{f=(e|0)>22528?22528:e&65535}b[c>>1]=f;c=(f<<16>>16)-20480|0;f=b[904992+((c>>>6&31)<<1)>>1]|0;e=c>>11;if((e|0)<0){g=f>>-e&65535;h=a+54|0;b[h>>1]=g;return}else{g=f<<e&65535;h=a+54|0;b[h>>1]=g;return}}function dlb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;c[d>>2]=0;c[e>>2]=0;f=0;g=0;while(1){h=f<<1;c[e>>2]=(ba(b[556352+(f<<1)>>1]|0,b[a+(h<<1)>>1]|0)|0)+g;i=ba(b[556352+(11-f<<1)>>1]|0,b[a+((h|1)<<1)>>1]|0)|0;c[d>>2]=i+(c[d>>2]|0);i=f+1|0;if((i|0)>=12){break}f=i;g=c[e>>2]|0}return}function elb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+148>>2]|0;d=c[a+152>>2]|0;e=c[a+12544>>2]|0;if((c[a+14680>>2]&8388608|0)==0){return}f=c[a+12552>>2]|0;g=c[a+12548>>2]|0;flb(e,b);flb(e+8|0,b);a=b<<3;flb(e+a|0,b);flb(e+(a+8)|0,b);flb(g,d);flb(f,d);return}function flb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+256|0;g=f|0;h=e*7|0;c[g>>2]=(d[b]|0)<<2;c[g+224>>2]=(d[b+h|0]|0)<<2;c[g+4>>2]=(d[b+1|0]|0)<<2;c[g+228>>2]=(d[b+(h+1)|0]|0)<<2;c[g+8>>2]=(d[b+2|0]|0)<<2;c[g+232>>2]=(d[b+(h+2)|0]|0)<<2;c[g+12>>2]=(d[b+3|0]|0)<<2;c[g+236>>2]=(d[b+(h+3)|0]|0)<<2;c[g+16>>2]=(d[b+4|0]|0)<<2;c[g+240>>2]=(d[b+(h+4)|0]|0)<<2;c[g+20>>2]=(d[b+5|0]|0)<<2;c[g+244>>2]=(d[b+(h+5)|0]|0)<<2;c[g+24>>2]=(d[b+6|0]|0)<<2;c[g+248>>2]=(d[b+(h+6)|0]|0)<<2;c[g+28>>2]=(d[b+7|0]|0)<<2;c[g+252>>2]=(d[b+(h+7)|0]|0)<<2;h=1;while(1){j=ba(h,e)|0;k=h<<3;l=0;do{m=l+j|0;c[g+(l+k<<2)>>2]=((d[b+m|0]|0)<<1)+(d[b+(m-e)|0]|0)+(d[b+(m+e)|0]|0);l=l+1|0;}while((l|0)<8);l=h+1|0;if((l|0)<7){h=l}else{n=0;break}}do{h=n<<3;l=c[g+(h<<2)>>2]|0;k=ba(n,e)|0;a[b+k|0]=(l+2|0)>>>2;a[b+(k+7)|0]=((c[g+((h|7)<<2)>>2]|0)+2|0)>>>2;j=h|1;a[b+(k+1)|0]=(l+8+(c[g+(j<<2)>>2]<<1)+(c[g+(j+1<<2)>>2]|0)|0)>>>4;j=h|2;a[b+(k+2)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+((h|3)<<2)>>2]|0)|0)>>>4;j=h|3;a[b+(k+3)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+(j+1<<2)>>2]|0)|0)>>>4;j=h|4;a[b+(k+4)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+((h|5)<<2)>>2]|0)|0)>>>4;j=h|5;a[b+(k+5)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+(j+1<<2)>>2]|0)|0)>>>4;j=h|6;a[b+(k+6)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+((h|7)<<2)>>2]|0)|0)>>>4;n=n+1|0;}while((n|0)<8);i=f;return}function glb(){if(a[1211976]|0){return}OOa(1211216,7553096);a[1211976]=1;return}function hlb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;if((e|0)>0){g=32;h=0}else{j=32;while(1){k=j-1|0;if((k|0)>0){j=k}else{l=0;break}}i=f;return l|0}while(1){j=0;k=h;while(1){if((d[b+j|0]|0|0)==(g|0)){c[a+(j<<2)>>2]=k;m=k+1|0}else{m=k}n=j+1|0;if((n|0)<(e|0)){j=n;k=m}else{break}}if((m&1|0)!=0){break}k=g-1|0;if((k|0)>0){g=k;h=m>>>1}else{l=0;o=10;break}}if((o|0)==10){i=f;return l|0}yDb(0,16,2175264,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;l=-1;i=f;return l|0}function ilb(a){a=a|0;var b=0,d=0,e=0;b=a+108|0;d=WDb((c[b>>2]<<2)+16|0)|0;c[a+132>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+144>>2]=d;d=WDb((c[b>>2]<<2)+16|0)|0;c[a+136>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+148>>2]=d;d=WDb((c[b>>2]<<2)+16|0)|0;c[a+140>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+152>>2]=d;e=0;return e|0}function jlb(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+116>>2]=c[a+88>>2];Z3(b+860488|0,a);Tlb(b+861732|0,a);c[b+108>>2]=c[a+120>>2];c[b+112>>2]=c[a+124>>2];return}function klb(a){a=a|0;$Db(a+132|0);c[a+144>>2]=0;$Db(a+136|0);c[a+148>>2]=0;$Db(a+140|0);c[a+152>>2]=0;return}function llb(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;c[a+512>>2]=b;f=0;g=0;h=0;while(1){c[5014620+(f*20|0)>>2]=2365840+(g<<2);j=e[2944+(h<<1)>>1]|0;c[5014628+(f*20|0)>>2]=j;k=j+g|0;N_(5014616+(f*20|0)|0,9,77,12986+(f*308|0)|0,4,2,12984+(f*308|0)|0,4,2,0,0,0,4)|0;c[5014780+(f*20|0)>>2]=2365840+(k<<2);j=e[2944+((h|1)<<1)>>1]|0;c[5014788+(f*20|0)>>2]=j;l=j+k|0;N_(5014776+(f*20|0)|0,9,77,8058+(f*308|0)|0,4,2,8056+(f*308|0)|0,4,2,0,0,0,4)|0;c[5014940+(f*20|0)>>2]=2365840+(l<<2);k=e[2944+((h|2)<<1)>>1]|0;c[5014948+(f*20|0)>>2]=k;j=k+l|0;N_(5014936+(f*20|0)|0,9,77,10522+(f*308|0)|0,4,2,10520+(f*308|0)|0,4,2,0,0,0,4)|0;c[5015100+(f*20|0)>>2]=2365840+(j<<2);l=e[2944+((h|3)<<1)>>1]|0;c[5015108+(f*20|0)>>2]=l;N_(5015096+(f*20|0)|0,9,77,5594+(f*308|0)|0,4,2,5592+(f*308|0)|0,4,2,0,0,0,4)|0;k=f+1|0;if((k|0)<8){f=k;g=l+j|0;h=h+4|0}else{m=0;n=18914;o=32;break}}while(1){c[5014300+(m*20|0)>>2]=2365840+(n<<2);h=e[2944+(o<<1)>>1]|0;c[5014308+(m*20|0)>>2]=h;g=h+n|0;N_(5014296+(m*20|0)|0,9,34,4506+(m*136|0)|0,4,2,4504+(m*136|0)|0,4,2,0,0,0,4)|0;c[5014460+(m*20|0)>>2]=2365840+(g<<2);h=e[2944+((o|1)<<1)>>1]|0;c[5014468+(m*20|0)>>2]=h;N_(5014456+(m*20|0)|0,9,34,3418+(m*136|0)|0,4,2,3416+(m*136|0)|0,4,2,0,0,0,4)|0;f=m+1|0;if((f|0)<8){m=f;n=h+g|0;o=o+2|0}else{break}}c[1253535]=2475368;c[1253537]=128;N_(5014136,7,12,3290,4,2,3288,4,2,0,0,0,4)|0;c[1253540]=2475880;c[1253542]=128;N_(5014156,7,12,3338,4,2,3336,4,2,0,0,0,4)|0;c[1253555]=2476392;c[1253557]=128;N_(5014216,7,12,3098,4,2,3096,4,2,0,0,0,4)|0;c[1253560]=2476904;c[1253562]=128;N_(5014236,7,12,3146,4,2,3144,4,2,0,0,0,4)|0;c[1253565]=2477416;c[1253567]=128;N_(5014256,7,12,3194,4,2,3192,4,2,0,0,0,4)|0;c[1253570]=2477928;c[1253572]=128;N_(5014276,7,12,3242,4,2,3240,4,2,0,0,0,4)|0;o=c[b+116>>2]|0;if((o|0)>0){c[a+36>>2]=cEb(o<<2)|0;_cb(a+436|0);o=a+448|0;y2(o,c[a+444>>2]|0);x2(o,a+40|0,1080496);x2(o,a+172|0,1080624);x2(o,a+304|0,1080688);plb(a+516|0);i=d;return}else{yDb(0,0,2175136,(d=i,i=i+24|0,c[d>>2]=2303600,c[d+8>>2]=2173296,c[d+16>>2]=695,d)|0);i=d;Cd()}}function mlb(a){a=a|0;$Db(a+36|0);return}function nlb(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;h=i;i=i+48|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=e+512|0;q=c[p>>2]|0;r=q+14128|0;s=c[r>>2]|0;t=d[(c[q+14120>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[q+14136>>2]|0))+s;c[e+32>>2]=t&1;c[e+580>>2]=f;t=f>>1;s=e+576|0;c[s>>2]=t;c[e+584>>2]=g;g=((f>>2)+65536|0)/(t|0)|0;c[e+592>>2]=g;if((t|0)<5){c[e+588>>2]=t;c[e+596>>2]=g}else{g=(t+3>>3)+t|0;c[e+588>>2]=g;c[e+596>>2]=((g>>1)+65536|0)/(g|0)|0}TGb(e|0,0,32)|0;g=q+13704|0;c[g>>2]=0;t=q+13708|0;c[t>>2]=0;f=q+12480|0;c[f>>2]=0;r=q+120|0;if((c[r>>2]<<1|0)<=0){u=0;v=q+12476|0;w=q+14424|0;x=c[g>>2]|0;y=c[t>>2]|0;z=c[v>>2]|0;A=z>>1;B=A-1|0;C=u>>1;D=C-1|0;Lkb(w,x,y,B,D,112);i=h;return 0}E=q+7656|0;F=q+7660|0;G=q+7624|0;H=q+12544|0;I=q+7628|0;J=q+12548|0;K=q+7632|0;L=q+12552|0;M=q+124|0;N=q+12476|0;O=q+116|0;P=e+600|0;Q=e+36|0;R=e+624|0;S=e+620|0;T=e+572|0;U=e+604|0;V=e+608|0;W=e+612|0;X=e+616|0;Y=e+588|0;Z=q+9928|0;_=q+9932|0;$=q+9136|0;aa=e+16|0;ca=0;a:while(1){da=c[F>>2]|0;ea=c[I>>2]|0;fa=c[K>>2]|0;c[H>>2]=(c[G>>2]|0)+(ba(ca<<3,c[E>>2]|0)|0);ga=ba(da<<2,ca&-2)|0;c[J>>2]=ea+ga;c[L>>2]=fa+ga;ga=c[M>>2]|0;c[N>>2]=0;if((c[O>>2]<<1|0)>0){fa=ba(ca>>1,ga)|0;while(1){ga=c[p>>2]|0;ea=ga+12476|0;da=(c[ea>>2]|0)==0|0;c[P>>2]=da;ha=ga+12480|0;ia=((c[ha>>2]|0)==0)<<1|da;c[P>>2]=ia;da=((c[ea>>2]|0)>=((c[ga+116>>2]<<1)-1|0))<<2|ia;c[P>>2]=da;do{if((ia|0)==1){c[R>>2]=(d[(c[Q>>2]|0)+(c[ha>>2]&1^1)|0]|0)>>>2;c[S>>2]=1}else if((ia|0)==2){c[R>>2]=(d[(c[Q>>2]|0)+((c[ea>>2]<<1)-2)|0]|0)>>>2;c[S>>2]=2}else if((ia|0)==3){c[R>>2]=16;c[S>>2]=0}else{ja=c[ea>>2]<<1;ka=c[ha>>2]&1;la=ka^1;ma=c[Q>>2]|0;na=d[ma+(la|ja)|0]|0;oa=ja-2|0;ja=d[ma+(oa|ka)|0]|0;ka=d[ma+(la|oa)|0]|0;oa=na>>>0>ja>>>0?ja:na;c[R>>2]=oa;if((c[ha>>2]&c[ea>>2]|0)==0){pa=oa}else{la=ka>>>0>oa>>>0?oa:ka;c[R>>2]=la;pa=la}c[R>>2]=pa>>2;la=-1379132>>>((ja<<3&24|na<<1&6)>>>0)&3;if((la|0)==3){c[S>>2]=16771800>>>((((c[s>>2]|0)>12)<<3|ka<<1&6)>>>0)&3;break}else{c[S>>2]=la;break}}}while(0);Se[c[T>>2]&511](c[ga+12544>>2]|0,c[ga+9944>>2]|0,c[ga+7656>>2]|0,j,k,da);ea=c[s>>2]|0;c[U>>2]=0;ha=c[j>>2]|0;ia=(ha|0)<3;do{if((ha|0)<(ea|0)|ia){c[S>>2]=0;if(!ia){break}c[U>>2]=1;la=(c[k>>2]|0)+9|0;c[k>>2]=la;c[V>>2]=(la*6899|0)>>17}}while(0);if((ha|0)<(ea<<1|0)){do{if((c[P>>2]&3|0)==0){ia=c[S>>2]|0;if((ia|0)==1){c[S>>2]=11;break}else if((ia|0)==2){c[S>>2]=10;break}else{break}}else{c[S>>2]=0}}while(0);c[W>>2]=0}else{ha=c[p>>2]|0;ia=c[aa>>2]|0;if((ia|0)==0){da=(ea|0)<13?2:1;ga=ha+14128|0;la=c[ga>>2]|0;ka=c[ha+14136>>2]|0;na=ha+14120|0;ja=(c[na>>2]|0)+(la>>>3)|0;oa=(fe(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(la&7)>>>((32-da|0)>>>0);ja=la+da|0;da=ka>>>0>ja>>>0?ja:ka;c[ga>>2]=da;ga=5014136+(((c[s>>2]|0)<13|0)*80|0)+(oa*20|0)|0;c[aa>>2]=ga;qa=ga;ra=da;sa=ka;ta=na}else{qa=ia;ra=c[ha+14128>>2]|0;sa=c[ha+14136>>2]|0;ta=ha+14120|0}ia=c[qa+4>>2]|0;na=(c[ta>>2]|0)+(ra>>>3)|0;ka=(fe(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ra&7)>>>25;na=b[ia+(ka<<2)>>1]|0;da=na<<16>>16;ga=(b[ia+(ka<<2)+2>>1]|0)+ra|0;c[ha+14128>>2]=sa>>>0>ga>>>0?ga:sa;c[W>>2]=da;if(na<<16>>16<0){break a}c[S>>2]=d[3056+((c[S>>2]|0)*12|0)+da|0]|0}if((olb(e,0)|0)!=0){break a}da=c[N>>2]|0;if((da&1&c[f>>2]|0)==0){ua=fa;va=da}else{da=c[p>>2]|0;na=da+12476|0;ga=(c[na>>2]|0)>>>0<2>>>0|0;c[P>>2]=ga;ha=((c[da+12480>>2]|0)>>>0<2>>>0)<<1|ga;c[P>>2]=ha;ga=((c[na>>2]|0)>=((c[da+116>>2]<<1)-1|0))<<2|ha;c[P>>2]=ga;c[W>>2]=0;if((ha|0)==0){wa=d[(c[Q>>2]|0)+((c[na>>2]<<1)-2)|0]<<2&12}else{wa=4<<(204>>>(ga>>>0)&1)}c[X>>2]=wa;Se[c[T>>2]&511](c[da+12548>>2]|0,c[da+9944>>2]|0,c[da+7660>>2]|0,l,m,ga);c[S>>2]=c[X>>2];ga=c[Y>>2]|0;c[U>>2]=0;da=c[l>>2]|0;na=(da|0)<3;do{if((da|0)<(ga|0)|na){c[S>>2]=0;if(!na){break}c[U>>2]=1;ha=(c[m>>2]|0)+9|0;c[m>>2]=ha;c[V>>2]=(ha*6899|0)>>17}}while(0);if((olb(e,1)|0)!=0){break a}na=c[p>>2]|0;Se[c[T>>2]&511](c[na+12552>>2]|0,c[na+9944>>2]|0,c[na+7660>>2]|0,n,o,c[P>>2]|0);c[S>>2]=c[X>>2];na=c[Y>>2]|0;c[U>>2]=0;ga=c[n>>2]|0;da=(ga|0)<3;do{if((ga|0)<(na|0)|da){c[S>>2]=0;if(!da){break}c[U>>2]=1;ea=(c[o>>2]|0)+9|0;c[o>>2]=ea;c[V>>2]=(ea*6899|0)>>17}}while(0);if((olb(e,2)|0)!=0){break a}c[J>>2]=(c[J>>2]|0)+8;c[L>>2]=(c[L>>2]|0)+8;a[(c[Z>>2]|0)+fa|0]=0;a[(c[_>>2]|0)+fa|0]=1;a[(c[$>>2]|0)+fa|0]=c[s>>2];ua=fa+1|0;va=c[N>>2]|0}c[H>>2]=(c[H>>2]|0)+8;da=va+1|0;c[N>>2]=da;if((da|0)<(c[O>>2]<<1|0)){fa=ua}else{break}}xa=c[f>>2]|0}else{xa=ca}if((xa&1|0)==0){ya=xa}else{_Oa(q,(xa<<3)-8|0,16);ya=c[f>>2]|0}fa=ya+1|0;c[f>>2]=fa;if((fa|0)<(c[r>>2]<<1|0)){ca=fa}else{u=fa;v=N;za=53;break}}if((za|0)==53){w=q+14424|0;x=c[g>>2]|0;y=c[t>>2]|0;z=c[v>>2]|0;A=z>>1;B=A-1|0;C=u>>1;D=C-1|0;Lkb(w,x,y,B,D,112);i=h;return 0}u=c[f>>2]|0;v=N;w=q+14424|0;x=c[g>>2]|0;y=c[t>>2]|0;z=c[v>>2]|0;A=z>>1;B=A-1|0;C=u>>1;D=C-1|0;Lkb(w,x,y,B,D,112);i=h;return 0}function olb(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;h=f+512|0;i=c[h>>2]|0;j=i+14340|0;me[c[i+10092>>2]&511](c[j>>2]|0);k=(g|0)!=0;if(k){l=2}else{l=(c[f+624>>2]|0)!=0|0}m=c[h>>2]|0;n=f+20+(l<<2)|0;l=c[n>>2]|0;o=m+14128|0;p=c[o>>2]|0;q=c[m+14136>>2]|0;r=m+14120|0;if((l|0)==0){m=(c[r>>2]|0)+(p>>>3)|0;s=(fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>29;m=p+3|0;t=q>>>0>m>>>0?m:q;c[o>>2]=t;m=5014296+(((c[f+576>>2]|0)<13|0)*160|0)+(s*20|0)|0;c[n>>2]=m;u=m;v=t}else{u=l;v=p}p=c[u+4>>2]|0;u=c[r>>2]|0;r=u+(v>>>3)|0;l=(fe(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(v&7)>>>23;r=b[p+(l<<2)>>1]|0;t=b[p+(l<<2)+2>>1]|0;l=t<<16>>16;if(t<<16>>16<0){t=v+9|0;m=q>>>0>t>>>0?t:q;t=u+(m>>>3)|0;n=((fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(m&7)>>>((l+32|0)>>>0))+r|0;w=b[p+(n<<2)+2>>1]|0;x=b[p+(n<<2)>>1]|0;y=m}else{w=l;x=r;y=v}v=w+y|0;y=q>>>0>v>>>0?v:q;c[o>>2]=y;v=(x|0)>16;w=-(v&1)&17;r=x-w|0;do{if((r|0)<1){if((x|0)==(w|0)){z=0;break}else{A=-1}return A|0}else{l=r+1>>1;m=l-((l|0)>1)|0;l=u+(y>>>3)|0;n=(fe(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(y&7)>>>((32-m|0)>>>0);l=m+y|0;c[o>>2]=q>>>0>l>>>0?l:q;l=n&1;z=((n>>1)+(d[1407944+r|0]|0)^-l)+l|0}}while(0);a:do{if(v){c[i+180>>2]=0;do{if((c[f+604>>2]|0)!=0){if(!((z+1|0)>>>0<3>>>0)){break}r=(ba(((ba(c[f+608>>2]|0,c[(k?f+596|0:f+592|0)>>2]|0)|0)+4096>>13)+z|0,c[(k?f+588|0:f+576|0)>>2]|0)|0)+4>>3;if(r>>>0>255>>>0){B=-r>>31&255}else{B=r&255}r=c[i+12544+(g<<2)>>2]|0;q=c[i+7656+((k&1)<<2)>>2]|0;TGb(r|0,B|0,8)|0;TGb(r+q|0,B|0,8)|0;o=q<<1;TGb(r+o|0,B|0,8)|0;y=o+q|0;TGb(r+y|0,B|0,8)|0;o=y+q|0;TGb(r+o|0,B|0,8)|0;y=o+q|0;TGb(r+y|0,B|0,8)|0;o=y+q|0;TGb(r+o|0,B|0,8)|0;TGb(r+(o+q)|0,B|0,8)|0;C=0;D=0;break a}}while(0);E=0;F=(z|0)==0|0;G=55}else{q=c[f+32>>2]|0;do{if(k){H=1;I=64;J=q}else{o=c[f+612>>2]|0;r=(o|0)<3?0:q;if((o|0)>4){H=0;I=64;J=r;break}o=c[f+624>>2]|0;y=(o|0)>1;H=y?2:3;I=y?o:64;J=r}}while(0);q=f+(H<<2)|0;r=c[q>>2]|0;if((r|0)==0){o=c[h>>2]|0;y=o+14128|0;u=c[y>>2]|0;w=c[o+14136>>2]|0;x=(c[o+14120>>2]|0)+(u>>>3)|0;o=(fe(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(u&7)>>>29;x=u+3|0;c[y>>2]=w>>>0>x>>>0?x:w;w=f+576|0;x=5014616+(((c[w>>2]|0)<13|0)*320|0)+((H>>>1)*160|0)+(o*20|0)|0;c[q>>2]=x;K=x;L=w}else{K=r;L=f+576|0}r=9602376>>>(c[f+620>>2]<<1>>>0)&3;w=f+580|0;x=f+584|0;q=i+14128|0;o=i+14120|0;y=i+14136|0;u=f+12|0;b:do{if((J|0)==0){l=0;n=0;m=K;while(1){p=n+1|0;do{if((p|0)<(I|0)){M=m}else{t=c[u>>2]|0;if((t|0)!=0){M=t;break}t=c[h>>2]|0;s=t+14128|0;N=c[s>>2]|0;O=c[t+14136>>2]|0;P=(c[t+14120>>2]|0)+(N>>>3)|0;t=(fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(N&7)>>>29;P=N+3|0;c[s>>2]=O>>>0>P>>>0?P:O;O=5014776+(((c[L>>2]|0)<13|0)*320|0)+(t*20|0)|0;c[u>>2]=O;M=O}}while(0);O=c[h>>2]|0;t=c[M+4>>2]|0;P=O+14128|0;s=c[P>>2]|0;N=c[O+14136>>2]|0;Q=c[O+14120>>2]|0;O=Q+(s>>>3)|0;R=(fe(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(s&7)>>>23;O=b[t+(R<<2)>>1]|0;S=b[t+(R<<2)+2>>1]|0;R=S<<16>>16;if(S<<16>>16<0){S=s+9|0;T=N>>>0>S>>>0?S:N;S=Q+(T>>>3)|0;U=((fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(T&7)>>>((R+32|0)>>>0))+O|0;V=b[t+(U<<2)+2>>1]|0;W=b[t+(U<<2)>>1]|0;X=T}else{V=R;W=O;X=s}s=V+X|0;O=N>>>0>s>>>0?s:N;c[P>>2]=O;do{if((W|0)<46){if((W|0)<0){Y=64;Z=64;_=64;break}s=(W|0)>22|0;R=W-(-s&23)|0;T=15007744>>>((R&30)>>>0)&3;Y=T;Z=66319>>>(T<<3>>>0)&R;_=s}else{if((W|0)<73){s=W-46|0;R=c[1862456+(s<<2)>>2]|0;T=R&15;U=Q+(O>>>3)|0;t=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(O&7)>>>((32-T|0)>>>0);U=T+O|0;c[P>>2]=N>>>0>U>>>0?U:N;U=R>>>8;Y=(t&((U|-256)^255))+(R>>>24)|0;Z=(U&255&t)+(R>>>16&255)|0;_=(s|0)>12|0;break}s=W&1;if((W|0)<75){R=Q+(O>>>3)|0;t=(fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>27;R=O+5|0;c[P>>2]=N>>>0>R>>>0?R:N;R=d[3384+t|0]|0;Y=R&15;Z=R>>>4;_=s^1;break}else{R=-s&3^7;s=Q+(O>>>3)|0;t=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(O&7)>>>((32-R|0)>>>0);s=O+R|0;R=N>>>0>s>>>0?s:N;c[P>>2]=R;s=Q+(R>>>3)|0;U=(fe(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(R&7)>>>26;s=R+6|0;R=N>>>0>s>>>0?s:N;c[P>>2]=R;s=d[Q+(R>>>3)|0]<<(R&7)>>>7;c[P>>2]=((R|0)<(N|0))+R;Y=t;Z=U;_=s&1;break}}}while(0);N=l+1+Z|0;if((N|0)>63){A=-1;break}P=ba(c[w>>2]|0,Y+1|0)|0;Q=P+(c[x>>2]|0)|0;P=c[q>>2]|0;O=d[(c[o>>2]|0)+(P>>>3)|0]<<(P&7)>>>7;c[q>>2]=((P|0)<(c[y>>2]|0))+P;P=O&1;b[(c[j>>2]|0)+(d[f+40+(r*132|0)+4+N|0]<<1)>>1]=(Q^-P)+P;if((_|0)==0){l=N;n=p;m=M}else{$=p;aa=N;break b}}return A|0}else{m=0;n=0;l=K;while(1){N=n+1|0;do{if((N|0)<(I|0)){ca=l}else{P=c[u>>2]|0;if((P|0)!=0){ca=P;break}P=c[h>>2]|0;Q=P+14128|0;O=c[Q>>2]|0;s=c[P+14136>>2]|0;U=(c[P+14120>>2]|0)+(O>>>3)|0;P=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(O&7)>>>29;U=O+3|0;c[Q>>2]=s>>>0>U>>>0?U:s;s=5014776+(((c[L>>2]|0)<13|0)*320|0)+(P*20|0)|0;c[u>>2]=s;ca=s}}while(0);p=c[h>>2]|0;s=c[ca+4>>2]|0;P=p+14128|0;U=c[P>>2]|0;Q=c[p+14136>>2]|0;O=c[p+14120>>2]|0;p=O+(U>>>3)|0;t=(fe(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(U&7)>>>23;p=b[s+(t<<2)>>1]|0;R=b[s+(t<<2)+2>>1]|0;t=R<<16>>16;if(R<<16>>16<0){R=U+9|0;T=Q>>>0>R>>>0?R:Q;R=O+(T>>>3)|0;S=((fe(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(T&7)>>>((t+32|0)>>>0))+p|0;da=b[s+(S<<2)+2>>1]|0;ea=b[s+(S<<2)>>1]|0;fa=T}else{da=t;ea=p;fa=U}U=da+fa|0;p=Q>>>0>U>>>0?U:Q;c[P>>2]=p;do{if((ea|0)<46){if((ea|0)<0){ga=64;ha=64;ia=64;break}U=(ea|0)>22|0;t=ea-(-U&23)|0;T=15007744>>>((t&30)>>>0)&3;ga=T;ha=66319>>>(T<<3>>>0)&t;ia=U}else{if((ea|0)<73){U=ea-46|0;t=c[1862456+(U<<2)>>2]|0;T=t&15;S=O+(p>>>3)|0;s=(fe(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(p&7)>>>((32-T|0)>>>0);S=T+p|0;c[P>>2]=Q>>>0>S>>>0?S:Q;S=t>>>8;ga=(s&((S|-256)^255))+(t>>>24)|0;ha=(S&255&s)+(t>>>16&255)|0;ia=(U|0)>12|0;break}U=ea&1;if((ea|0)<75){t=O+(p>>>3)|0;s=(fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(p&7)>>>27;t=p+5|0;c[P>>2]=Q>>>0>t>>>0?t:Q;t=d[3384+s|0]|0;ga=t&15;ha=t>>>4;ia=U^1;break}else{t=-U&3^7;U=O+(p>>>3)|0;s=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(p&7)>>>((32-t|0)>>>0);U=p+t|0;t=Q>>>0>U>>>0?U:Q;c[P>>2]=t;U=O+(t>>>3)|0;S=(fe(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(t&7)>>>26;U=t+6|0;t=Q>>>0>U>>>0?U:Q;c[P>>2]=t;U=d[O+(t>>>3)|0]<<(t&7)>>>7;c[P>>2]=((t|0)<(Q|0))+t;ga=s;ha=S;ia=U&1;break}}}while(0);Q=m+1+ha|0;if((Q|0)>63){A=-1;break}P=c[w>>2]|0;O=c[x>>2]|0;p=c[q>>2]|0;U=d[(c[o>>2]|0)+(p>>>3)|0]<<(p&7)>>>7;c[q>>2]=((p|0)<(c[y>>2]|0))+p;p=U&1;U=((ba(P,ga+1|0)|0)+O^-p)+p|0;p=(ba(b[552296+(Q<<1)>>1]|0,U)|0)>>>8&65535;b[(c[j>>2]|0)+(d[f+40+(r*132|0)+4+Q|0]<<1)>>1]=p;if((ia|0)==0){m=Q;n=N;l=ca}else{$=N;aa=Q;break b}}return A|0}}while(0);c[i+180>>2]=aa;E=$;F=0;G=55}}while(0);do{if((G|0)==55){if(k){$=(ba(c[f+588>>2]|0,z)|0)&65535;b[c[j>>2]>>1]=$;ja=$}else{$=(ba(c[f+576>>2]|0,z)|0)&65535;b[c[j>>2]>>1]=$;ja=$}do{if((z+1|0)>>>0>2>>>0){if((c[f+600>>2]&3|0)==3){break}$=6947196>>>(c[f+620>>2]<<1>>>0)&3;if(($|0)==3){break}aa=ja<<16>>16;ca=c[h>>2]|0;if(($|0)==0){ia=(aa*3811|0)+32768>>16;ga=c[ca+14340>>2]|0;ha=ga+(d[f+449|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+456|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ia=(aa*487|0)+32768>>16;ha=ga+(d[f+450|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+464|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ia=(aa*506|0)+32768>>16;ha=ga+(d[f+451|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+472|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ia=(aa*135|0)+32768>>16;ha=ga+(d[f+452|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+480|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+458|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+465|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+459|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+473|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ia=(aa*173|0)+32768>>16;ha=ga+(d[f+453|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+488|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ia=(aa*61|0)+32768>>16;ha=ga+(d[f+454|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+496|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+461|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+489|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ia=(aa*42|0)+32768>>16;ha=ga+(d[f+455|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+504|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+460|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+481|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+484|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ia=ga+(d[f+457|0]<<1)|0;b[ia>>1]=(e[ia>>1]|0)+(((aa*1084|0)+32768|0)>>>16);ia=ca+180|0;ga=c[ia>>2]|0;c[ia>>2]=(ga|0)>56?ga:56;break}else if(($|0)==1){ga=c[ca+14340>>2]|0;ia=ga+(d[f+456|0]<<1)|0;b[ia>>1]=(e[ia>>1]|0)-(((aa*6269|0)+32768|0)>>>16);ia=ga+(d[f+472|0]<<1)|0;b[ia>>1]=(e[ia>>1]|0)-(((aa*708|0)+32768|0)>>>16);ia=ga+(d[f+488|0]<<1)|0;b[ia>>1]=(e[ia>>1]|0)-(((aa*172|0)+32768|0)>>>16);ia=ga+(d[f+504|0]<<1)|0;b[ia>>1]=(e[ia>>1]|0)-(((aa*73|0)+32768|0)>>>16);ia=ca+180|0;ga=c[ia>>2]|0;c[ia>>2]=(ga|0)>56?ga:56;break}else if(($|0)==2){$=c[ca+14340>>2]|0;ga=$+(d[f+449|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*6269|0)+32768|0)>>>16);ga=$+(d[f+451|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*708|0)+32768|0)>>>16);ga=$+(d[f+453|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*172|0)+32768|0)>>>16);ga=$+(d[f+455|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*73|0)+32768|0)>>>16);aa=ca+180|0;ca=c[aa>>2]|0;c[aa>>2]=(ca|0)>7?ca:7;break}else{break}}}while(0);if((c[f+604>>2]|0)==0){Xe[c[f+524+(c[f+620>>2]<<2)>>2]&4095](c[i+9944>>2]|0,c[i+12544+(g<<2)>>2]|0,c[i+7656+((k&1)<<2)>>2]|0)}else{ca=c[f+608>>2]&255;aa=c[i+12544+(g<<2)>>2]|0;ga=c[i+7656+((k&1)<<2)>>2]|0;TGb(aa|0,ca|0,8)|0;TGb(aa+ga|0,ca|0,8)|0;$=ga<<1;TGb(aa+$|0,ca|0,8)|0;ia=$+ga|0;TGb(aa+ia|0,ca|0,8)|0;$=ia+ga|0;TGb(aa+$|0,ca|0,8)|0;ia=$+ga|0;TGb(aa+ia|0,ca|0,8)|0;$=ia+ga|0;TGb(aa+$|0,ca|0,8)|0;TGb(aa+($+ga)|0,ca|0,8)|0}if((F|0)!=0){C=E;D=F;break}Xe[c[f+436>>2]&4095](c[i+12544+(g<<2)>>2]|0,c[i+7656+((k&1)<<2)>>2]|0,c[j>>2]|0);C=E;D=0}}while(0);if(!k){E=c[f+620>>2]|0;j=c[h>>2]|0;a[(c[f+36>>2]|0)+(c[j+12480>>2]&1|c[j+12476>>2]<<1)|0]=(E|0)==4|C<<2|((E|0)==8)<<1}if((c[i+13836>>2]|0)==0){A=0;return A|0}E=c[i+12544+(g<<2)>>2]|0;g=c[i+7656+((k&1)<<2)>>2]|0;k=f+600|0;i=c[k>>2]|0;do{if((i&2|0)==0){if((D|0)!=0){if((c[f+620>>2]|4|0)==4){ka=i;break}}Xe[c[f+520>>2]&4095](E,g,c[f+576>>2]|0);ka=c[k>>2]|0}else{ka=i}}while(0);if((ka&1|0)!=0){A=0;return A|0}do{if((D|0)!=0){if((c[f+620>>2]|8|0)==8){A=0}else{break}return A|0}}while(0);Xe[c[f+516>>2]&4095](E,g,c[f+576>>2]|0);A=0;return A|0}function plb(a){a=a|0;c[a+4>>2]=1488;c[a>>2]=222;c[a+56>>2]=60;c[a+8>>2]=692;c[a+12>>2]=694;c[a+16>>2]=696;c[a+20>>2]=698;c[a+24>>2]=1758;c[a+28>>2]=686;c[a+32>>2]=688;c[a+36>>2]=690;c[a+40>>2]=700;c[a+44>>2]=702;c[a+48>>2]=2300;c[a+52>>2]=2302;return}function qlb(a,b,c){a=a|0;b=b|0;c=c|0;Flb(a,b,1,c);return}function rlb(a,b,c){a=a|0;b=b|0;c=c|0;Flb(a,1,b,c);return}function slb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;j=i&3;if((j|0)==3){c[h>>2]=2432;c[g>>2]=0;TGb(e|0,-128|0,41)|0;return}k=(i&1|0)!=0;if(k){l=0;m=-1;n=256}else{a[e+7|0]=a[b-2|0]|0;o=a[b-1|0]|0;p=o&255;a[e+15|0]=o;q=f-1|0;a[e+6|0]=a[b+(f-2)|0]|0;r=a[b+q|0]|0;s=r&255;t=(o&255)>>>0>(r&255)>>>0;o=t?s:p;u=t?p:s;a[e+14|0]=r;r=q+f|0;a[e+5|0]=a[b+(r-1)|0]|0;q=a[b+r|0]|0;t=q&255;v=o>>>0>t>>>0?t:o;o=u>>>0>t>>>0?u:t;a[e+13|0]=q;q=r+f|0;a[e+4|0]=a[b+(q-1)|0]|0;r=a[b+q|0]|0;u=r&255;w=v>>>0>u>>>0?u:v;v=o>>>0>u>>>0?o:u;a[e+12|0]=r;r=q+f|0;a[e+3|0]=a[b+(r-1)|0]|0;q=a[b+r|0]|0;o=q&255;y=w>>>0>o>>>0?o:w;w=v>>>0>o>>>0?v:o;a[e+11|0]=q;q=r+f|0;a[e+2|0]=a[b+(q-1)|0]|0;r=a[b+q|0]|0;v=r&255;z=y>>>0>v>>>0?v:y;y=w>>>0>v>>>0?w:v;a[e+10|0]=r;r=q+f|0;a[e+1|0]=a[b+(r-1)|0]|0;q=a[b+r|0]|0;w=q&255;A=z>>>0>w>>>0?w:z;z=y>>>0>w>>>0?y:w;a[e+9|0]=q;q=r+f|0;a[e]=a[b+(q-1)|0]|0;r=a[b+q|0]|0;q=r&255;a[e+8|0]=r;l=q+(w+(v+(o+(u+(t+(s+p))))))|0;m=(z|0)>(q|0)?z:q;n=(A|0)>(q|0)?q:A}if((i&2|0)==0){A=-f|0;q=b+A|0;z=d[q]|0;p=(n|0)>(z|0)?z:n;s=(m|0)>(z|0)?m:z;t=d[b+(1-f)|0]|0;u=(p|0)>(t|0)?t:p;p=(s|0)>(t|0)?s:t;s=d[b+(2-f)|0]|0;o=(u|0)>(s|0)?s:u;u=(p|0)>(s|0)?p:s;p=d[b+(3-f)|0]|0;v=(o|0)>(p|0)?p:o;o=(u|0)>(p|0)?u:p;u=d[b+(4-f)|0]|0;w=(v|0)>(u|0)?u:v;v=(o|0)>(u|0)?o:u;o=d[b+(5-f)|0]|0;r=(w|0)>(o|0)?o:w;w=(v|0)>(o|0)?v:o;v=d[b+(6-f)|0]|0;y=(r|0)>(v|0)?v:r;r=(w|0)>(v|0)?w:v;w=a[b+(7-f)|0]|0;B=w&255;if((i&4|0)==0){UGb(e+17|0,q|0,16)|0}else{TGb(e+25|0,w|0,8)|0;w=q;q=e+17|0;i=w|0;C=w+4|0;w=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;C=q|0;x=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=q+4|0;x=w;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x}C=b+(A<<1)|0;A=e+33|0;w=C|0;q=C+4|0;C=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=A|0;x=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;q=A+4|0;x=C;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;D=B+(v+(o+(u+(p+(s+(t+(z+l)))))))|0;E=(r|0)>(B|0)?r:B;F=(y|0)>(B|0)?B:y}else{D=l;E=m;F=n}if((j|0)==0){j=a[b+~f|0]|0;a[e+16|0]=j;G=j&255}else{j=D+4>>3;if(k){TGb(e|0,j&255|0,17)|0}else{TGb(e+16|0,j&255|0,25)|0}G=j*9|0}c[g>>2]=E-F;c[h>>2]=G+D+(d[e+25|0]|0)+(d[e+26|0]|0);return}function tlb(c,f,g){c=c|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+64|0;j=h|0;k=h+32|0;TGb(j|0,0,32)|0;TGb(k|0,0,32)|0;l=0;while(1){m=(d[c+(15-l)|0]|0)<<4;n=j+((l&1)<<4)|0;b[n>>1]=(e[n>>1]|0)+(m>>>(l>>>1>>>0));n=(l|0)>0?l-1|0:1-l|0;o=j+((n&1)<<4)+2|0;b[o>>1]=(e[o>>1]|0)+(m>>>(n>>>1>>>0));n=l-2|0;o=(n|0)>-1?n:2-l|0;n=j+((o&1)<<4)+4|0;b[n>>1]=(e[n>>1]|0)+(m>>>(o>>>1>>>0));o=l-3|0;n=(o|0)>-1?o:3-l|0;o=j+((n&1)<<4)+6|0;b[o>>1]=(e[o>>1]|0)+(m>>>(n>>>1>>>0));n=l-4|0;o=(n|0)>-1?n:4-l|0;n=j+((o&1)<<4)+8|0;b[n>>1]=(e[n>>1]|0)+(m>>>(o>>>1>>>0));o=l-5|0;n=(o|0)>-1?o:5-l|0;o=j+((n&1)<<4)+10|0;b[o>>1]=(e[o>>1]|0)+(m>>>(n>>>1>>>0));n=l-6|0;o=(n|0)>-1?n:6-l|0;n=j+((o&1)<<4)+12|0;b[n>>1]=(e[n>>1]|0)+(m>>>(o>>>1>>>0));o=l-7|0;n=(o|0)>-1?o:7-l|0;o=j+((n&1)<<4)+14|0;b[o>>1]=(e[o>>1]|0)+(m>>>(n>>>1>>>0));n=l+1|0;if((n|0)<8){l=n}else{p=0;break}}do{l=(d[c+(p+17)|0]|0)<<4;n=k+((p&1)<<4)|0;b[n>>1]=(e[n>>1]|0)+(l>>>(p>>>1>>>0));n=(p|0)>0?p-1|0:1-p|0;m=k+((n&1)<<4)+2|0;b[m>>1]=(e[m>>1]|0)+(l>>>(n>>>1>>>0));n=p-2|0;m=(n|0)>-1?n:2-p|0;n=k+((m&1)<<4)+4|0;b[n>>1]=(e[n>>1]|0)+(l>>>(m>>>1>>>0));m=p-3|0;n=(m|0)>-1?m:3-p|0;m=k+((n&1)<<4)+6|0;b[m>>1]=(e[m>>1]|0)+(l>>>(n>>>1>>>0));n=p-4|0;m=(n|0)>-1?n:4-p|0;n=k+((m&1)<<4)+8|0;b[n>>1]=(e[n>>1]|0)+(l>>>(m>>>1>>>0));m=p-5|0;n=(m|0)>-1?m:5-p|0;m=k+((n&1)<<4)+10|0;b[m>>1]=(e[m>>1]|0)+(l>>>(n>>>1>>>0));n=p-6|0;m=(n|0)>-1?n:6-p|0;n=k+((m&1)<<4)+12|0;b[n>>1]=(e[n>>1]|0)+(l>>>(m>>>1>>>0));m=p-7|0;n=(m|0)>-1?m:7-p|0;m=k+((n&1)<<4)+14|0;b[m>>1]=(e[m>>1]|0)+(l>>>(n>>>1>>>0));p=p+1|0;}while((p|0)<8);p=d[c+25|0]|0;n=p<<3;l=k+26|0;b[l>>1]=(e[l>>1]|0)+n;l=k+12|0;b[l>>1]=(e[l>>1]|0)+n;n=k+30|0;b[n>>1]=(e[n>>1]|0)+(p<<4);p=d[c+26|0]|0;n=p<<3;l=k+10|0;b[l>>1]=(e[l>>1]|0)+(p<<2);p=k+28|0;b[p>>1]=(e[p>>1]|0)+n;p=k+14|0;b[p>>1]=(e[p>>1]|0)+n;n=10;while(1){p=n-7|0;l=(p|0)>-1?p:7-n|0;p=k+((l&1)<<4)+14|0;b[p>>1]=(e[p>>1]|0)+((d[c+(n+17)|0]|0)<<4>>>(l>>>1>>>0));l=n+1|0;if((l|0)<12){n=l}else{q=0;break}}while(1){n=k+(q<<1)|0;b[n>>1]=((((e[k+16+(q<<1)>>1]|0)*181|0)+128|0)>>>8)+(e[n>>1]|0);n=j+(q<<1)|0;b[n>>1]=((((e[j+16+(q<<1)>>1]|0)*181|0)+128|0)>>>8)+(e[n>>1]|0);n=q+1|0;if((n|0)<8){q=n}else{r=f;s=0;break}}while(1){f=s<<4;q=j+(s<<1)|0;n=0;do{c=(n<<1)+f|0;l=ba(e[424+(c<<1)>>1]|0,e[k+(n<<1)>>1]|0)|0;a[r+n|0]=(l+32768+(ba(e[424+((c|1)<<1)>>1]|0,e[q>>1]|0)|0)|0)>>>16;n=n+1|0;}while((n|0)<8);n=s+1|0;if((n|0)<8){r=r+g|0;s=n}else{break}}i=h;return}function ulb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=0;while(1){f=c<<1;a[e]=a[b+((f+2|0)>15?32:f+19|0)|0]|0;g=f|1;a[e+1|0]=a[b+((g+2|0)>15?32:g+19|0)|0]|0;a[e+2|0]=a[b+((f+4|0)>15?32:f+21|0)|0]|0;a[e+3|0]=a[b+((f+5|0)>15?32:f+22|0)|0]|0;a[e+4|0]=a[b+((f+6|0)>15?32:f+23|0)|0]|0;a[e+5|0]=a[b+((f+7|0)>15?32:f+24|0)|0]|0;a[e+6|0]=a[b+((f+8|0)>15?32:f+25|0)|0]|0;a[e+7|0]=a[b+((f+9|0)>15?32:f+26|0)|0]|0;f=c+1|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function vlb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;e=c;c=0;while(1){a[e]=a[b+(c+18)|0]|0;a[e+1|0]=a[b+(c+19)|0]|0;a[e+2|0]=a[b+(c+20)|0]|0;a[e+3|0]=a[b+(c+21)|0]|0;a[e+4|0]=a[b+(c+22)|0]|0;a[e+5|0]=a[b+(c+23)|0]|0;a[e+6|0]=a[b+(c+24)|0]|0;a[e+7|0]=a[b+(c+25)|0]|0;f=c+1|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function wlb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=0;while(1){f=c+1|0;g=f>>1;a[e]=a[b+(g+17)|0]|0;a[e+1|0]=a[b+(g+18)|0]|0;a[e+2|0]=a[b+(g+19)|0]|0;a[e+3|0]=a[b+(g+20)|0]|0;a[e+4|0]=a[b+(g+21)|0]|0;a[e+5|0]=a[b+(g+22)|0]|0;a[e+6|0]=a[b+(g+23)|0]|0;a[e+7|0]=a[b+(g+24)|0]|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function xlb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=b+17|0;g=c;c=0;while(1){a[g]=((d[f]|0)+1+(d[b+33|0]|0)|0)>>>1;a[g+1|0]=((d[b+18|0]|0)+1+(d[b+34|0]|0)|0)>>>1;a[g+2|0]=((d[b+19|0]|0)+1+(d[b+35|0]|0)|0)>>>1;a[g+3|0]=((d[b+20|0]|0)+1+(d[b+36|0]|0)|0)>>>1;a[g+4|0]=((d[b+21|0]|0)+1+(d[b+37|0]|0)|0)>>>1;a[g+5|0]=((d[b+22|0]|0)+1+(d[b+38|0]|0)|0)>>>1;a[g+6|0]=((d[b+23|0]|0)+1+(d[b+39|0]|0)|0)>>>1;a[g+7|0]=((d[b+24|0]|0)+1+(d[b+40|0]|0)|0)>>>1;h=c+1|0;if((h|0)<8){g=g+e|0;c=h}else{break}}return}function ylb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c;c=0;while(1){f=17-c|0;g=c+1|0;h=17-(g>>1)|0;i=0;do{j=i<<1;if((j-c|0)<0){a[e+i|0]=a[b+(f+j)|0]|0}else{a[e+i|0]=a[b+(h+i)|0]|0}i=i+1|0;}while((i|0)<8);if((g|0)<8){e=e+d|0;c=g}else{break}}return}function zlb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;e=c;c=0;while(1){f=16-c|0;a[e]=a[b+f|0]|0;a[e+1|0]=a[b+(f+1)|0]|0;a[e+2|0]=a[b+(f+2)|0]|0;a[e+3|0]=a[b+(f+3)|0]|0;a[e+4|0]=a[b+(f+4)|0]|0;a[e+5|0]=a[b+(f+5)|0]|0;a[e+6|0]=a[b+(f+6)|0]|0;a[e+7|0]=a[b+(f+7)|0]|0;f=c+1|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function Alb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c;c=0;while(1){g=c<<1;h=15-g|0;i=16-g|0;j=16-c|0;k=0;do{if((k-g|0)>0){a[f+k|0]=((d[b+(h+k)|0]|0)+1+(d[b+(i+k)|0]|0)|0)>>>1}else{a[f+k|0]=a[b+(j+(k>>1))|0]|0}k=k+1|0;}while((k|0)<8);k=c+1|0;if((k|0)<8){f=f+e|0;c=k}else{break}}return}function Blb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=c;c=0;while(1){g=b+(7-c)|0;h=b+(15-c)|0;a[f]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+1|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+2|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+3|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+4|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+5|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+6|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+7|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;h=c+1|0;if((h|0)<8){f=f+e|0;c=h}else{break}}return}function Clb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;e=c;c=0;while(1){a[e]=a[b+((c|0)>6?8:14-c|0)|0]|0;f=c+1|0;a[e+1|0]=a[b+((f|0)>6?8:13-c|0)|0]|0;a[e+2|0]=a[b+((c+2|0)>6?8:12-c|0)|0]|0;a[e+3|0]=a[b+((c+3|0)>6?8:11-c|0)|0]|0;a[e+4|0]=a[b+((c+4|0)>6?8:10-c|0)|0]|0;a[e+5|0]=a[b+((c+5|0)>6?8:9-c|0)|0]|0;a[e+6|0]=a[b+((c|0)>0?8:8-c|0)|0]|0;a[e+7|0]=a[b+8|0]|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function Dlb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0;f=c;c=0;while(1){g=b+(15-c)|0;a[f]=a[g]|0;a[f+1|0]=(((d[g]|0)*7|0)+4+(d[b+18|0]|0)|0)>>>3;a[f+2|0]=(((d[g]|0)*6|0)+4+((d[b+19|0]|0)<<1)|0)>>>3;a[f+3|0]=(((d[g]|0)*5|0)+4+((d[b+20|0]|0)*3|0)|0)>>>3;a[f+4|0]=(((d[g]|0)<<2)+4+((d[b+21|0]|0)<<2)|0)>>>3;a[f+5|0]=(((d[g]|0)*3|0)+4+((d[b+22|0]|0)*5|0)|0)>>>3;a[f+6|0]=(((d[g]|0)<<1)+4+((d[b+23|0]|0)*6|0)|0)>>>3;a[f+7|0]=((d[g]|0)+4+((d[b+24|0]|0)*7|0)|0)>>>3;g=c+1|0;if((g|0)<8){f=f+e|0;c=g}else{break}}return}function Elb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0;f=c;c=0;while(1){g=b+(15-c)|0;h=8-c|0;i=ba(d[g]|0,c)|0;a[f]=(i+4+(ba(d[b+17|0]|0,h)|0)|0)>>>3;i=ba(d[g]|0,c)|0;a[f+1|0]=(i+4+(ba(d[b+18|0]|0,h)|0)|0)>>>3;i=ba(d[g]|0,c)|0;a[f+2|0]=(i+4+(ba(d[b+19|0]|0,h)|0)|0)>>>3;i=ba(d[g]|0,c)|0;a[f+3|0]=(i+4+(ba(d[b+20|0]|0,h)|0)|0)>>>3;i=ba(d[g]|0,c)|0;a[f+4|0]=(i+4+(ba(d[b+21|0]|0,h)|0)|0)>>>3;i=ba(d[g]|0,c)|0;a[f+5|0]=(i+4+(ba(d[b+22|0]|0,h)|0)|0)>>>3;i=ba(d[g]|0,c)|0;a[f+6|0]=(i+4+(ba(d[b+23|0]|0,h)|0)|0)>>>3;i=ba(d[g]|0,c)|0;a[f+7|0]=(i+4+(ba(d[b+24|0]|0,h)|0)|0)>>>3;h=c+1|0;if((h|0)<8){f=f+e|0;c=h}else{break}}return}function Flb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=f+10>>3;h=c*-4|0;i=c*-3|0;j=c*-2|0;k=-c|0;l=c<<1;m=c*3|0;n=c<<2;o=c*-5|0;p=f<<1;q=0;r=b;while(1){b=a[r+h|0]|0;s=b&255;t=d[r+i|0]|0;u=r+j|0;v=a[u]|0;w=v&255;x=r+k|0;y=d[x]|0;z=d[r]|0;A=r+c|0;B=d[A]|0;C=d[r+l|0]|0;D=d[r+m|0]|0;E=s-t|0;F=t-w|0;G=w-y|0;H=y-z|0;I=((((F|0)>-1?F:-F|0)|0)<=(g|0))+((((E|0)>-1?E:-E|0)|0)<=(g|0))+((((G|0)>-1?G:-G|0)|0)<=(g|0))+((((H|0)>-1?H:-H|0)|0)<=(g|0))|0;do{if((I|0)>0){G=z-B|0;E=B-C|0;F=C-D|0;J=D-(d[r+n|0]|0)|0;K=(d[r+o|0]|0)-s|0;if((I+((((G|0)>-1?G:-G|0)|0)<=(g|0))+((((E|0)>-1?E:-E|0)|0)<=(g|0))+((((F|0)>-1?F:-F|0)|0)<=(g|0))+((((J|0)>-1?J:-J|0)|0)<=(g|0))+((((K|0)>-1?K:-K|0)|0)<=(g|0))|0)<=5){L=7;break}K=(b&255)>>>0>(v&255)>>>0;J=K?w:s;F=K?s:w;K=J>>>0>z>>>0?z:J;J=F>>>0>z>>>0?F:z;F=K>>>0>D>>>0?D:K;K=J>>>0>D>>>0?J:D;if((K-F|0)>=(p|0)){L=7;break}J=F>>>0>t>>>0?t:F;F=K>>>0>t>>>0?K:t;K=J>>>0>y>>>0?y:J;J=F>>>0>y>>>0?F:y;F=K>>>0>B>>>0?B:K;K=J>>>0>B>>>0?J:B;if((((K|0)>(C|0)?K:C)-((F|0)>(C|0)?C:F)|0)>=(p|0)){L=7;break}a[u]=((t<<2)+4+(w*3|0)+C|0)>>>3;a[x]=(((y+t|0)*3|0)+4+(C<<1)|0)>>>3;a[r]=((t<<1)+4+((C+z|0)*3|0)|0)>>>3;a[A]=(t+4+(B*3|0)+(C<<2)|0)>>>3}else{L=7}}while(0);do{if((L|0)==7){L=0;A=(w<<1)+4-(B<<1)+((z-y|0)*5|0)>>3;u=(A|0)>-1?A:-A|0;if((u|0)>=(f|0)){break}v=(s<<1)+4-(y<<1)+((w-t|0)*5|0)>>3;b=(z<<1)+4-(D<<1)+((C-B|0)*5|0)>>3;I=(v|0)>-1?v:-v|0;v=(b|0)>-1?b:-b|0;b=u-((I|0)>(v|0)?v:I)|0;if((b|0)<=0){break}if((A^H|0)>=0){break}A=H>>31;I=(A^H)-A>>1;v=(b*5|0)>>3;b=(((v|0)>(I|0)?I:v)^A)-A|0;a[x]=y-b;a[r]=(d[r]|0)+b}}while(0);y=q+1|0;if((y|0)<8){q=y;r=r+e|0}else{break}}return}function Glb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;d=a;a=i;i=i+8|0;c[a>>2]=c[d>>2];c[a+4>>2]=c[d+4>>2];d=a|0;e=c[d>>2]|0;do{if((e|0)==0){c[d>>2]=1;c[a+4>>2]=1;f=0;g=0;h=1;j=0;k=1}else{l=c[a+4>>2]|0;m=l;n=(l|0)<0|0?-1:0;o=e;p=(e|0)<0|0?-1:0;q=e>>31;if((l|0)!=0){f=q;g=p;h=o;j=n;k=m;break}l=c[302600]|0;r=c[302601]|0;s=gHb(m,n,l,(l|0)<0|0?-1:0)|0;t=F;u=gHb(o,p,r,(r|0)<0|0?-1:0)|0;if((l|0)!=0&((s|0)==(u|0)&(t|0)==(F|0))&(l>>31|0)==(q|0)){v=1;i=b;return v|0}l=c[302602]|0;t=c[302603]|0;u=gHb(m,n,l,(l|0)<0|0?-1:0)|0;s=F;r=gHb(o,p,t,(t|0)<0|0?-1:0)|0;if((l|0)!=0&((u|0)==(r|0)&(s|0)==(F|0))&(l>>31|0)==(q|0)){v=2;i=b;return v|0}l=c[302604]|0;s=c[302605]|0;r=gHb(m,n,l,(l|0)<0|0?-1:0)|0;u=F;t=gHb(o,p,s,(s|0)<0|0?-1:0)|0;if((l|0)!=0&((r|0)==(t|0)&(u|0)==(F|0))&(l>>31|0)==(q|0)){v=3;i=b;return v|0}l=c[302606]|0;u=c[302607]|0;t=gHb(m,n,l,(l|0)<0|0?-1:0)|0;r=F;s=gHb(o,p,u,(u|0)<0|0?-1:0)|0;if((l|0)!=0&((t|0)==(s|0)&(r|0)==(F|0))&(l>>31|0)==(q|0)){v=4;i=b;return v|0}else{l=c[302608]|0;r=c[302609]|0;s=gHb(m,n,l,(l|0)<0|0?-1:0)|0;n=F;m=gHb(o,p,r,(r|0)<0|0?-1:0)|0;r=(l|0)!=0&((s|0)==(m|0)&(n|0)==(F|0))&(l>>31|0)==(q|0)?5:15;i=b;return r|0}}}while(0);e=c[302600]|0;a=c[302601]|0;d=gHb(k,j,e,(e|0)<0|0?-1:0)|0;r=F;q=gHb(h,g,a,(a|0)<0|0?-1:0)|0;do{if((d|0)==(q|0)&(r|0)==(F|0)){if((a|0)!=0){v=1;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=1}else{break}i=b;return v|0}}while(0);e=c[302602]|0;a=c[302603]|0;r=gHb(k,j,e,(e|0)<0|0?-1:0)|0;q=F;d=gHb(h,g,a,(a|0)<0|0?-1:0)|0;do{if((r|0)==(d|0)&(q|0)==(F|0)){if((a|0)!=0){v=2;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=2}else{break}i=b;return v|0}}while(0);e=c[302604]|0;a=c[302605]|0;q=gHb(k,j,e,(e|0)<0|0?-1:0)|0;d=F;r=gHb(h,g,a,(a|0)<0|0?-1:0)|0;do{if((q|0)==(r|0)&(d|0)==(F|0)){if((a|0)!=0){v=3;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=3}else{break}i=b;return v|0}}while(0);e=c[302606]|0;a=c[302607]|0;d=gHb(k,j,e,(e|0)<0|0?-1:0)|0;r=F;q=gHb(h,g,a,(a|0)<0|0?-1:0)|0;do{if((d|0)==(q|0)&(r|0)==(F|0)){if((a|0)!=0){v=4;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=4}else{break}i=b;return v|0}}while(0);e=c[302608]|0;a=c[302609]|0;r=gHb(k,j,e,(e|0)<0|0?-1:0)|0;j=F;k=gHb(h,g,a,(a|0)<0|0?-1:0)|0;do{if((r|0)==(k|0)&(j|0)==(F|0)){if((a|0)!=0){v=5;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=5}else{break}i=b;return v|0}}while(0);v=15;i=b;return v|0}function Hlb(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0;f=b+40|0;if((c[f>>2]|0)==0){g=60;h=5}else{i=c[b+4>>2]|0;j=c[i+104>>2]|0;k=gHb(j,(j|0)<0|0?-1:0,18e5,0)|0;j=F;l=c[i+108>>2]|0;i=l;m=(l|0)<0|0?-1:0;l=gHb(i,m,500,0)|0;n=YGb(l,F,k,j)|0;l=F;o=gHb(i,m,1e3,0)|0;p=F;q=eHb(n,l,o,p)|0;r=q;if((r|0)<1){s=1}else{s=(r|0)>127?127:r}r=gHb(s,(s|0)<0|0?-1:0,o,p)|0;p=ZGb(k,j,r,F)|0;r=F;o=-1;q=(r|0)>(o|0)|(r|0)==(o|0)&p>>>0>-1>>>0;o=ZGb(0,0,p,r)|0;t=F;u=q?p:o;q?r:t;t=u;u=gHb(i,m,1001,0)|0;m=F;i=eHb(n,l,u,m)|0;l=i;if((l|0)<1){v=1}else{v=(l|0)>127?127:l}l=gHb(v,(v|0)<0|0?-1:0,u,m)|0;m=ZGb(k,j,l,F)|0;l=F;j=-1;k=(l|0)>(j|0)|(l|0)==(j|0)&m>>>0>-1>>>0;j=ZGb(0,0,m,l)|0;u=F;i=k?m:j;k?l:u;u=(i|0)<(t|0);t=u?v:s;if(u){g=t;h=5}else{w=1;y=t;z=u&1}}if((h|0)==5){w=(g|0)!=60|0;y=g;z=1}g=b+13840|0;c[g>>2]=w;w=ba(z|1e3,y)|0;h=b+784|0;K_(h);u=b+796|0;t=c[u>>2]|0;c[b+14280>>2]=t;s=h|0;h=c[s>>2]|0;v=b+788|0;i=c[v>>2]|0;if((i|0)>22){A=i-22|0;B=h<<22|32;C=t}else{l=t;x=fe(32>>>((22-i|0)>>>0)|h<<i|0)|0;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;l=(c[u>>2]|0)+4|0;c[u>>2]=l;A=i+10|0;B=32;C=l}c[s>>2]=B;c[v>>2]=A;l=c[b+108>>2]|0;i=gHb(l,(l|0)<0|0?-1:0,18e5,0)|0;l=b+4|0;h=c[l>>2]|0;t=c[h+104>>2]|0;k=gHb(i,F,t,(t|0)<0|0?-1:0)|0;t=F;i=c[h+108>>2]|0;h=gHb(i,(i|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=eHb(k,t,h,F)|0;h=w;w=h&255;if((A|0)>8){D=A-8|0;E=B<<8|w;G=C}else{t=C;x=fe(w>>>((8-A|0)>>>0)|B<<A|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[u>>2]|0)+4|0;c[u>>2]=t;D=A+24|0;E=w;G=t}c[s>>2]=E;c[v>>2]=D;if((D|0)>1){H=D-1|0;I=E<<1|1;J=G}else{t=G;x=fe(1>>>((1-D|0)>>>0)|E<<D|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[u>>2]|0)+4|0;c[u>>2]=t;H=D+31|0;I=1;J=t}c[s>>2]=I;c[v>>2]=H;if((H|0)>1){K=H-1|0;L=I<<1;M=J}else{t=J;x=fe(I<<H|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[u>>2]|0)+4|0;c[u>>2]=t;K=H+31|0;L=0;M=t}c[s>>2]=L;c[v>>2]=K;if((K|0)>1){N=K-1|0;O=L<<1;P=M}else{t=M;x=fe(L<<K|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[u>>2]|0)+4|0;c[u>>2]=t;N=K+31|0;O=0;P=t}c[s>>2]=O;c[v>>2]=N;if((N|0)>1){Q=N-1|0;R=O<<1;S=P}else{t=P;x=fe(O<<N|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;t=(c[u>>2]|0)+4|0;c[u>>2]=t;Q=N+31|0;R=0;S=t}c[s>>2]=R;c[v>>2]=Q;if((Q|0)>1){T=Q-1|0;U=R<<1}else{t=S;x=fe(R<<Q|0)|0;a[t]=x;x=x>>8;a[t+1|0]=x;x=x>>8;a[t+2|0]=x;x=x>>8;a[t+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;T=Q+31|0;U=0}c[s>>2]=U;c[v>>2]=T;T=b+8|0;U=b+12|0;Q=Q0a(1210824,8,c[T>>2]|0,c[U>>2]|0)|0;t=c[s>>2]|0;R=c[v>>2]|0;S=(R|0)>3;do{if((c[f>>2]|0)==0){if(S){V=R-3|0;W=t<<3|Q}else{N=fe(Q>>>((3-R|0)>>>0)|t<<R|0)|0;O=c[u>>2]|0;x=N;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;V=R+29|0;W=Q}c[s>>2]=W;c[v>>2]=V;O=(c[b+9992>>2]|0)==2|0;if((V|0)>1){X=V-1|0;Y=W<<1|O}else{N=fe(O>>>((1-V|0)>>>0)|W<<V|0)|0;P=c[u>>2]|0;x=N;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;X=V+31|0;Y=O}c[s>>2]=Y;c[v>>2]=X;if((X|0)>1){Z=X-1|0;_=Y<<1}else{O=fe(Y<<X|0)|0;P=c[u>>2]|0;x=O;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Z=X+31|0;_=0}c[s>>2]=_;c[v>>2]=Z;if((Z|0)>1){$=Z-1|0;aa=_<<1}else{P=fe(_<<Z|0)|0;O=c[u>>2]|0;x=P;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;$=Z+31|0;aa=0}c[s>>2]=aa;c[v>>2]=$;O=c[b+13788>>2]|0;if(($|0)>1){ca=$-1|0;da=aa<<1|O}else{P=fe(aa<<$|O>>>((1-$|0)>>>0)|0)|0;N=c[u>>2]|0;x=P;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ca=$+31|0;da=O}c[s>>2]=da;c[v>>2]=ca;if((ca|0)>1){ea=ca-1|0;fa=da<<1}else{O=fe(da<<ca|0)|0;N=c[u>>2]|0;x=O;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ea=ca+31|0;fa=0}c[s>>2]=fa;c[v>>2]=ea;N=c[b+9960>>2]|0;if((ea|0)>5){ga=ea-5|0;ha=fa<<5|N}else{O=fe(fa<<ea|N>>>((5-ea|0)>>>0)|0)|0;P=c[u>>2]|0;x=O;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ga=ea+27|0;ha=N}c[s>>2]=ha;c[v>>2]=ga;if((ga|0)>1){ia=ga-1|0;ja=ha<<1;break}else{N=fe(ha<<ga|0)|0;P=c[u>>2]|0;x=N;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ia=ga+31|0;ja=0;break}}else{if(S){ka=R-3|0;la=t<<3|7}else{P=fe(7>>>((3-R|0)>>>0)|t<<R|0)|0;N=c[u>>2]|0;x=P;a[N]=x;x=x>>8;a[N+1|0]=x;x=x>>8;a[N+2|0]=x;x=x>>8;a[N+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ka=R+29|0;la=7}c[s>>2]=la;c[v>>2]=ka;if((ka|0)>3){ma=ka-3|0;na=la<<3|1}else{N=fe(1>>>((3-ka|0)>>>0)|la<<ka|0)|0;P=c[u>>2]|0;x=N;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ma=ka+29|0;na=1}c[s>>2]=na;c[v>>2]=ma;P=(Q|0)==8;N=(ma|0)>3;do{if(P){if(N){oa=ma-3|0;pa=na<<3|6;break}else{O=fe(6>>>((3-ma|0)>>>0)|na<<ma|0)|0;K=c[u>>2]|0;x=O;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;oa=ma+29|0;pa=6;break}}else{if(N){oa=ma-3|0;pa=na<<3|Q;break}else{K=fe(Q>>>((3-ma|0)>>>0)|na<<ma|0)|0;O=c[u>>2]|0;x=K;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;oa=ma+29|0;pa=Q;break}}}while(0);c[s>>2]=pa;c[v>>2]=oa;N=c[g>>2]|0;if((oa|0)>1){qa=oa-1|0;ra=pa<<1|N}else{O=fe(pa<<oa|N>>>((1-oa|0)>>>0)|0)|0;K=c[u>>2]|0;x=O;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;qa=oa+31|0;ra=N}c[s>>2]=ra;c[v>>2]=qa;N=b+13816|0;K=c[N>>2]|0;if((qa|0)>1){sa=qa-1|0;ta=ra<<1|K}else{O=fe(ra<<qa|K>>>((1-qa|0)>>>0)|0)|0;L=c[u>>2]|0;x=O;a[L]=x;x=x>>8;a[L+1|0]=x;x=x>>8;a[L+2|0]=x;x=x>>8;a[L+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;sa=qa+31|0;ta=K}c[s>>2]=ta;c[v>>2]=sa;if((sa|0)>1){ua=sa-1|0;va=ta<<1}else{K=fe(ta<<sa|0)|0;L=c[u>>2]|0;x=K;a[L]=x;x=x>>8;a[L+1|0]=x;x=x>>8;a[L+2|0]=x;x=x>>8;a[L+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ua=sa+31|0;va=0}c[s>>2]=va;c[v>>2]=ua;L=c[b+13788>>2]|0;if((ua|0)>1){wa=ua-1|0;xa=va<<1|L}else{K=fe(va<<ua|L>>>((1-ua|0)>>>0)|0)|0;O=c[u>>2]|0;x=K;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;wa=ua+31|0;xa=L}c[s>>2]=xa;c[v>>2]=wa;L=c[b+228>>2]|0;if((wa|0)>1){ya=wa-1|0;za=xa<<1|L}else{O=fe(xa<<wa|L>>>((1-wa|0)>>>0)|0)|0;K=c[u>>2]|0;x=O;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ya=wa+31|0;za=L}c[s>>2]=za;c[v>>2]=ya;L=c[b+13836>>2]|0;if((ya|0)>1){Aa=ya-1|0;Ba=za<<1|L}else{K=fe(za<<ya|L>>>((1-ya|0)>>>0)|0)|0;O=c[u>>2]|0;x=K;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Aa=ya+31|0;Ba=L}c[s>>2]=Ba;c[v>>2]=Aa;L=b+13824|0;O=c[L>>2]|0;if((Aa|0)>1){Ca=Aa-1|0;Da=Ba<<1|O}else{K=fe(Ba<<Aa|O>>>((1-Aa|0)>>>0)|0)|0;M=c[u>>2]|0;x=K;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Ca=Aa+31|0;Da=O}c[s>>2]=Da;c[v>>2]=Ca;if((Ca|0)>1){Ea=Ca-1|0;Fa=Da<<1}else{O=fe(Da<<Ca|0)|0;M=c[u>>2]|0;x=O;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Ea=Ca+31|0;Fa=0}c[s>>2]=Fa;c[v>>2]=Ea;if((Ea|0)>1){Ga=Ea-1|0;Ha=Fa<<1}else{M=fe(Fa<<Ea|0)|0;O=c[u>>2]|0;x=M;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Ga=Ea+31|0;Ha=0}c[s>>2]=Ha;c[v>>2]=Ga;O=c[b+13828>>2]|0;if((Ga|0)>1){Ia=Ga-1|0;Ja=Ha<<1|O}else{M=fe(Ha<<Ga|O>>>((1-Ga|0)>>>0)|0)|0;K=c[u>>2]|0;x=M;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Ia=Ga+31|0;Ja=O}c[s>>2]=Ja;c[v>>2]=Ia;O=c[b+13832>>2]|0;if((Ia|0)>1){Ka=Ia-1|0;La=Ja<<1|O}else{K=fe(Ja<<Ia|O>>>((1-Ia|0)>>>0)|0)|0;M=c[u>>2]|0;x=K;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Ka=Ia+31|0;La=O}c[s>>2]=La;c[v>>2]=Ka;if((Ka|0)>1){Ma=Ka-1|0;Na=La<<1|1}else{O=fe(1>>>((1-Ka|0)>>>0)|La<<Ka|0)|0;M=c[u>>2]|0;x=O;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Ma=Ka+31|0;Na=1}c[s>>2]=Na;c[v>>2]=Ma;if((Ma|0)>3){Oa=Ma-3|0;Pa=Na<<3}else{M=fe(Na<<Ma|0)|0;O=c[u>>2]|0;x=M;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Oa=Ma+29|0;Pa=0}c[s>>2]=Pa;c[v>>2]=Oa;O=(c[b+9992>>2]|0)==2|0;if((Oa|0)>3){Qa=Oa-3|0;Ra=Pa<<3|O}else{M=fe(O>>>((3-Oa|0)>>>0)|Pa<<Oa|0)|0;K=c[u>>2]|0;x=M;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Qa=Oa+29|0;Ra=O}c[s>>2]=Ra;c[v>>2]=Qa;if((Qa|0)>1){Sa=Qa-1|0;Ta=Ra<<1}else{O=fe(Ra<<Qa|0)|0;K=c[u>>2]|0;x=O;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Sa=Qa+31|0;Ta=0}c[s>>2]=Ta;c[v>>2]=Sa;if((Sa|0)>1){Ua=Sa-1|0;Va=Ta<<1}else{K=fe(Ta<<Sa|0)|0;O=c[u>>2]|0;x=K;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Ua=Sa+31|0;Va=0}c[s>>2]=Va;c[v>>2]=Ua;O=c[b+12472>>2]|0;if((Ua|0)>1){Wa=Ua-1|0;Xa=Va<<1|O}else{K=fe(Va<<Ua|O>>>((1-Ua|0)>>>0)|0)|0;M=c[u>>2]|0;x=K;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Wa=Ua+31|0;Xa=O}c[s>>2]=Xa;c[v>>2]=Wa;if((Wa|0)>2){Ya=Wa-2|0;Za=Xa<<2}else{O=fe(Xa<<Wa|0)|0;M=c[u>>2]|0;x=O;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Ya=Wa+30|0;Za=0}c[s>>2]=Za;c[v>>2]=Ya;if((Ya|0)>1){_a=Ya-1|0;$a=Za<<1|1}else{M=fe(1>>>((1-Ya|0)>>>0)|Za<<Ya|0)|0;O=c[u>>2]|0;x=M;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;_a=Ya+31|0;$a=1}c[s>>2]=$a;c[v>>2]=_a;if((_a|0)>1){ab=_a-1|0;bb=$a<<1}else{O=fe($a<<_a|0)|0;M=c[u>>2]|0;x=O;a[M]=x;x=x>>8;a[M+1|0]=x;x=x>>8;a[M+2|0]=x;x=x>>8;a[M+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ab=_a+31|0;bb=0}c[s>>2]=bb;c[v>>2]=ab;do{if(P){M=Glb((c[l>>2]|0)+224|0)|0;O=b+13928|0;c[O>>2]=M;K=c[s>>2]|0;H=c[v>>2]|0;if((H|0)>4){cb=H-4|0;db=K<<4|M}else{I=fe(M>>>((4-H|0)>>>0)|K<<H|0)|0;K=c[u>>2]|0;x=I;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;cb=H+28|0;db=M}c[s>>2]=db;c[v>>2]=cb;M=(c[T>>2]>>2)-1|0;if((cb|0)>9){eb=cb-9|0;fb=db<<9|M}else{H=fe(M>>>((9-cb|0)>>>0)|db<<cb|0)|0;K=c[u>>2]|0;x=H;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;eb=cb+23|0;fb=M}c[s>>2]=fb;c[v>>2]=eb;if((eb|0)>1){gb=eb-1|0;hb=fb<<1|1}else{M=fe(1>>>((1-eb|0)>>>0)|fb<<eb|0)|0;K=c[u>>2]|0;x=M;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;gb=eb+31|0;hb=1}c[s>>2]=hb;c[v>>2]=gb;K=c[U>>2]>>2;if((gb|0)>9){ib=gb-9|0;jb=hb<<9|K}else{M=fe(K>>>((9-gb|0)>>>0)|hb<<gb|0)|0;H=c[u>>2]|0;x=M;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ib=gb+23|0;jb=K}c[s>>2]=jb;c[v>>2]=ib;if((c[O>>2]|0)!=15){kb=ib;lb=jb;break}O=c[l>>2]|0;K=c[O+224>>2]|0;if((ib|0)>8){mb=ib-8|0;nb=jb<<8|K;ob=O}else{O=fe(jb<<ib|K>>>((8-ib|0)>>>0)|0)|0;H=c[u>>2]|0;x=O;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;mb=ib+24|0;nb=K;ob=c[l>>2]|0}c[s>>2]=nb;c[v>>2]=mb;K=c[ob+228>>2]|0;if((mb|0)>8){pb=mb-8|0;qb=nb<<8|K}else{H=fe(nb<<mb|K>>>((8-mb|0)>>>0)|0)|0;O=c[u>>2]|0;x=H;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;pb=mb+24|0;qb=K}c[s>>2]=qb;c[v>>2]=pb;kb=pb;lb=qb}else{kb=ab;lb=bb}}while(0);if((c[g>>2]|0)==0){rb=kb;sb=lb}else{if((kb|0)>1){tb=kb-1|0;ub=lb<<1|z}else{P=fe(z>>>((1-kb|0)>>>0)|lb<<kb|0)|0;K=c[u>>2]|0;x=P;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;tb=kb+31|0;ub=z}c[s>>2]=ub;c[v>>2]=tb;if((tb|0)>7){vb=tb-7|0;wb=ub<<7|y}else{K=fe(y>>>((7-tb|0)>>>0)|ub<<tb|0)|0;P=c[u>>2]|0;x=K;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;vb=tb+25|0;wb=y}c[s>>2]=wb;c[v>>2]=vb;P=h>>>8&3;if((vb|0)>2){xb=vb-2|0;yb=wb<<2|P}else{K=fe(P>>>((2-vb|0)>>>0)|wb<<vb|0)|0;O=c[u>>2]|0;x=K;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;xb=vb+30|0;yb=P}c[s>>2]=yb;c[v>>2]=xb;rb=xb;sb=yb}if((c[N>>2]|0)==0){zb=rb;Ab=sb}else{if((rb|0)>2){Bb=rb-2|0;Cb=sb<<2|1}else{P=fe(1>>>((2-rb|0)>>>0)|sb<<rb|0)|0;O=c[u>>2]|0;x=P;a[O]=x;x=x>>8;a[O+1|0]=x;x=x>>8;a[O+2|0]=x;x=x>>8;a[O+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Bb=rb+30|0;Cb=1}c[s>>2]=Cb;c[v>>2]=Bb;zb=Bb;Ab=Cb}if((c[L>>2]|0)==0){Db=zb;Eb=Ab}else{if((zb|0)>2){Fb=zb-2|0;Gb=Ab<<2}else{O=fe(Ab<<zb|0)|0;P=c[u>>2]|0;x=O;a[P]=x;x=x>>8;a[P+1|0]=x;x=x>>8;a[P+2|0]=x;x=x>>8;a[P+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Fb=zb+30|0;Gb=0}c[s>>2]=Gb;c[v>>2]=Fb;Db=Fb;Eb=Gb}P=c[b+9960>>2]|0;if((Db|0)>5){ia=Db-5|0;ja=Eb<<5|P;break}else{O=fe(Eb<<Db|P>>>((5-Db|0)>>>0)|0)|0;K=c[u>>2]|0;x=O;a[K]=x;x=x>>8;a[K+1|0]=x;x=x>>8;a[K+2|0]=x;x=x>>8;a[K+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;ia=Db+27|0;ja=P;break}}}while(0);c[s>>2]=ja;c[v>>2]=ia;if((ia|0)>1){Hb=ia-1|0;Ib=ja<<1}else{Db=fe(ja<<ia|0)|0;ja=c[u>>2]|0;x=Db;a[ja]=x;x=x>>8;a[ja+1|0]=x;x=x>>8;a[ja+2|0]=x;x=x>>8;a[ja+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Hb=ia+31|0;Ib=0}c[s>>2]=Ib;c[v>>2]=Hb;if((c[b+13824>>2]|0)!=0){if((Hb|0)>1){Jb=Hb-1|0;Kb=Ib<<1|1}else{ia=fe(Ib<<Hb|1>>>((1-Hb|0)>>>0)|0)|0;Ib=c[u>>2]|0;x=ia;a[Ib]=x;x=x>>8;a[Ib+1|0]=x;x=x>>8;a[Ib+2|0]=x;x=x>>8;a[Ib+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Jb=Hb+31|0;Kb=1}c[s>>2]=Kb;c[v>>2]=Jb;Hb=b+144|0;Ib=0;while(1){if((Ib|0)>=6){break}if(((c[Hb>>2]|0)-1|0)>(e[1191040+(Ib<<1)>>1]|0|0)){Ib=Ib+1|0}else{break}}Hb=(ba(c[b+12480>>2]|0,c[b+116>>2]|0)|0)+(c[b+12476>>2]|0)|0;ia=d[1191056+Ib|0]|0;if((Jb|0)>(ia|0)){Lb=Jb-ia|0;Mb=Kb<<ia|Hb}else{Ib=fe(Hb>>>((ia-Jb|0)>>>0)|Kb<<Jb|0)|0;Kb=c[u>>2]|0;x=Ib;a[Kb]=x;x=x>>8;a[Kb+1|0]=x;x=x>>8;a[Kb+2|0]=x;x=x>>8;a[Kb+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Lb=32-ia+Jb|0;Mb=Hb}c[b+784>>2]=Mb;c[v>>2]=Lb;if((Lb|0)>1){Nb=Lb-1|0;Ob=Mb<<1|1}else{Hb=fe(1>>>((1-Lb|0)>>>0)|Mb<<Lb|0)|0;Mb=c[u>>2]|0;x=Hb;a[Mb]=x;x=x>>8;a[Mb+1|0]=x;x=x>>8;a[Mb+2|0]=x;x=x>>8;a[Mb+3|0]=x;c[u>>2]=(c[u>>2]|0)+4;Nb=Lb+31|0;Ob=1}c[s>>2]=Ob;c[v>>2]=Nb}Nb=b+9892|0;if((c[b+228>>2]|0)==0){c[Nb>>2]=1179688;c[b+9888>>2]=1179688;return}else{c[Nb>>2]=1265888;c[b+9888>>2]=1265888;return}}function Ilb(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+144|0;g=0;while(1){if((g|0)>=6){break}if(((c[f>>2]|0)-1|0)>(e[1191040+(g<<1)>>1]|0|0)){g=g+1|0}else{break}}f=(ba(c[b+12480>>2]|0,c[b+116>>2]|0)|0)+(c[b+12476>>2]|0)|0;h=d[1191056+g|0]|0;g=b+784|0;i=c[g>>2]|0;j=b+788|0;k=c[j>>2]|0;if((k|0)>(h|0)){l=k-h|0;m=i<<h|f;c[g>>2]=m;c[j>>2]=l;return}else{n=fe(f>>>((h-k|0)>>>0)|i<<k|0)|0;i=b+796|0;b=c[i>>2]|0;x=n;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[i>>2]=(c[i>>2]|0)+4;l=32-h+k|0;m=f;c[g>>2]=m;c[j>>2]=l;return}}function Jlb(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=b+784|0;h=c[g>>2]|0;i=b+788|0;j=c[i>>2]|0;if((j|0)>17){k=j-17|0;l=h<<17|1}else{m=fe(1>>>((17-j|0)>>>0)|h<<j|0)|0;h=b+796|0;n=c[h>>2]|0;x=m;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;k=j+15|0;l=1}c[g>>2]=l;c[i>>2]=k;if((c[b+13824>>2]|0)==0){j=(f|0)/(c[b+13784>>2]|0)|0;if((k|0)>5){o=k-5|0;p=l<<5|j}else{f=fe(l<<k|j>>>((5-k|0)>>>0)|0)|0;h=b+796|0;n=c[h>>2]|0;x=f;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[h>>2]=(c[h>>2]|0)+4;o=k+27|0;p=j}c[g>>2]=p;c[i>>2]=o;j=(c[b+9992>>2]|0)==1|0;if((o|0)>2){q=o-2|0;r=p<<2|j}else{h=fe(j>>>((2-o|0)>>>0)|p<<o|0)|0;p=b+796|0;n=c[p>>2]|0;x=h;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;c[p>>2]=(c[p>>2]|0)+4;q=o+30|0;r=j}c[g>>2]=r;c[i>>2]=q;j=c[b+9960>>2]|0;if((q|0)>5){s=q-5|0;t=r<<5|j;c[g>>2]=t;c[i>>2]=s;return}else{o=fe(r<<q|j>>>((5-q|0)>>>0)|0)|0;r=b+796|0;p=c[r>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[r>>2]=(c[r>>2]|0)+4;s=q+27|0;t=j;c[g>>2]=t;c[i>>2]=s;return}}if((k|0)>1){u=k-1|0;v=l<<1|1}else{j=fe(l<<k|1>>>((1-k|0)>>>0)|0)|0;l=b+796|0;q=c[l>>2]|0;x=j;a[q]=x;x=x>>8;a[q+1|0]=x;x=x>>8;a[q+2|0]=x;x=x>>8;a[q+3|0]=x;c[l>>2]=(c[l>>2]|0)+4;u=k+31|0;v=1}c[g>>2]=v;c[i>>2]=u;k=b+144|0;l=0;while(1){if((l|0)>=6){break}if(((c[k>>2]|0)-1|0)>(e[1191040+(l<<1)>>1]|0|0)){l=l+1|0}else{break}}q=(ba(c[b+12480>>2]|0,c[b+116>>2]|0)|0)+(c[b+12476>>2]|0)|0;j=d[1191056+l|0]|0;if((u|0)>(j|0)){w=u-j|0;y=v<<j|q}else{l=fe(q>>>((j-u|0)>>>0)|v<<u|0)|0;v=b+796|0;r=c[v>>2]|0;x=l;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;c[v>>2]=(c[v>>2]|0)+4;w=32-j+u|0;y=q}c[g>>2]=y;c[i>>2]=w;if((c[k>>2]|0)>1583){if((w|0)>1){z=w-1|0;A=y<<1|1}else{k=fe(1>>>((1-w|0)>>>0)|y<<w|0)|0;q=b+796|0;u=c[q>>2]|0;x=k;a[u]=x;x=x>>8;a[u+1|0]=x;x=x>>8;a[u+2|0]=x;x=x>>8;a[u+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;z=w+31|0;A=1}c[g>>2]=A;c[i>>2]=z;B=z;C=A}else{B=w;C=y}y=c[b+9960>>2]|0;if((B|0)>5){D=B-5|0;E=C<<5|y}else{w=fe(C<<B|y>>>((5-B|0)>>>0)|0)|0;C=b+796|0;A=c[C>>2]|0;x=w;a[A]=x;x=x>>8;a[A+1|0]=x;x=x>>8;a[A+2|0]=x;x=x>>8;a[A+3|0]=x;c[C>>2]=(c[C>>2]|0)+4;D=B+27|0;E=y}c[g>>2]=E;c[i>>2]=D;if((D|0)>1){F=D-1|0;G=E<<1|1}else{y=fe(1>>>((1-D|0)>>>0)|E<<D|0)|0;E=b+796|0;B=c[E>>2]|0;x=y;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[E>>2]=(c[E>>2]|0)+4;F=D+31|0;G=1}c[g>>2]=G;c[i>>2]=F;D=(c[b+9992>>2]|0)==1|0;if((F|0)>2){s=F-2|0;t=G<<2|D;c[g>>2]=t;c[i>>2]=s;return}else{E=fe(D>>>((2-F|0)>>>0)|G<<F|0)|0;G=b+796|0;b=c[G>>2]|0;x=E;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;s=F+30|0;t=D;c[g>>2]=t;c[i>>2]=s;return}}function Klb(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[d+9136>>2]|0;kPa(d);f=d+144|0;g=c[f>>2]|0;if((g|0)>1){h=d+12556|0;i=1;j=g;while(1){k=c[h>>2]|0;l=e+(c[k+(i<<2)>>2]|0)|0;m=a[e+(c[k+(i-1<<2)>>2]|0)|0]|0;if(((a[l]|0)-(m<<24>>24)|0)>2){a[l]=m+2;n=c[f>>2]|0}else{n=j}m=i+1|0;if((m|0)<(n|0)){i=m;j=n}else{o=n;break}}}else{o=g}g=o-2|0;a:do{if((g|0)>-1){o=d+12556|0;n=g;while(1){j=c[o>>2]|0;i=e+(c[j+(n<<2)>>2]|0)|0;h=a[e+(c[j+(n+1<<2)>>2]|0)|0]|0;if(((a[i]|0)-(h<<24>>24)|0)>2){a[i]=h+2}if((n|0)<=0){break a}n=n-1|0}}}while(0);if((c[d+48>>2]|0)==20){return}g=c[f>>2]|0;if((g|0)<=1){return}f=d+12492|0;n=c[d+12556>>2]|0;d=1;o=c[n>>2]|0;while(1){h=c[n+(d<<2)>>2]|0;do{if((a[e+h|0]|0)!=(a[e+o|0]|0)){i=(c[f>>2]|0)+(h<<1)|0;j=b[i>>1]|0;if((j&4)==0){break}b[i>>1]=j|2}}while(0);j=d+1|0;if((j|0)<(g|0)){d=j;o=h}else{break}}return}function Llb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0;k=i;i=i+56|0;l=k|0;m=k+8|0;n=k+16|0;o=k+32|0;p=c[f+60>>2]&512;q=f+12488|0;do{if((c[q>>2]|0)==0){do{if((c[f+14404>>2]&8|0)==0){r=(c[f+180>>2]>>31)+32&-32;s=(c[f+184>>2]|0)>-1?r|16:r;r=(c[f+188>>2]|0)>-1?s|8:s;s=(c[f+192>>2]|0)>-1?r|4:r;r=(c[f+196>>2]|0)>-1?s|2:s;if(!((c[f+200>>2]|0)>-1)){t=r;break}t=r|1}else{r=(c[f+11740>>2]|0)==0;s=c[f+9984>>2]|0;u=((s|0)!=0?8:0)|(r?0:16);v=(c[f+9972>>2]|0)>>>1;w=ba(d[1210784+u|0]|0,v)|0;y=(w|0)==2147483647;z=ba(d[1210784+(u|1)|0]|0,v)|0;A=c[f+13132>>2]|0;B=z+A|0;z=(B|0)<(w|0);C=z?B:w;w=ba(d[1210784+(u|2)|0]|0,v)|0;B=c[f+13128>>2]|0;D=w+B|0;w=(D|0)<(C|0);E=w?D:C;C=B+A+(ba(d[1210784+(u|3)|0]|0,v)|0)|0;u=(C|0)<(E|0);A=u?C:E;E=f+13112|0;C=f+13116|0;B=f+13120|0;D=f+13124|0;F=2147483647;G=-1;H=0;do{I=ba(d[1211185+((H^15)<<1)|0]|0,v)|0;if((H&1|0)==0){J=I}else{J=(c[D>>2]|0)+I|0}if((H&2|0)==0){K=J}else{K=(c[B>>2]|0)+J|0}if((H&4|0)==0){L=K}else{L=(c[C>>2]|0)+K|0}if((H&8|0)==0){M=L}else{M=(c[E>>2]|0)+L|0}I=(M|0)<(F|0);F=I?M:F;G=I?H:G;H=H+1|0;}while((H|0)<16);H=(G<<2)+(u?3:w?2:z?1:y<<31>>31)|0;if((j|h|s|0)!=0|r^1){N=H}else{N=(A+(v<<1)+F|0)>-1?0:H}H=f+10092|0;E=f+14340|0;C=f+180|0;do{if((c[C>>2]|0)>-1){if((N&32|0)!=0){break}c[C>>2]=-1;me[c[H>>2]&511](c[E>>2]|0)}}while(0);C=f+184|0;do{if((c[C>>2]|0)>-1){if((N&16|0)!=0){break}c[C>>2]=-1;me[c[H>>2]&511]((c[E>>2]|0)+128|0)}}while(0);C=f+188|0;do{if((c[C>>2]|0)>-1){if((N&8|0)!=0){break}c[C>>2]=-1;me[c[H>>2]&511]((c[E>>2]|0)+256|0)}}while(0);C=f+192|0;do{if((c[C>>2]|0)>-1){if((N&4|0)!=0){break}c[C>>2]=-1;me[c[H>>2]&511]((c[E>>2]|0)+384|0)}}while(0);C=f+196|0;do{if((c[C>>2]|0)>-1){if((N&2|0)!=0){break}c[C>>2]=-1;me[c[H>>2]&511]((c[E>>2]|0)+512|0)}}while(0);C=f+200|0;if(!((c[C>>2]|0)>-1)){t=N;break}if((N&1|0)!=0){t=N;break}c[C>>2]=-1;me[c[H>>2]&511]((c[E>>2]|0)+640|0);t=N}}while(0);C=f+9984|0;F=c[C>>2]|0;v=f+11740|0;A=c[v>>2]|0;r=f+784|0;s=c[r>>2]|0;y=f+788|0;z=c[y>>2]|0;w=(z|0)>1;if((j|h|t|F|A|0)==0){if(w){O=z-1|0;P=s<<1|1}else{u=fe(1>>>((1-z|0)>>>0)|s<<z|0)|0;G=f+796|0;B=c[G>>2]|0;x=u;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[G>>2]=(c[G>>2]|0)+4;O=z+31|0;P=1}c[r>>2]=P;c[y>>2]=O;if((p|0)!=0){G=f+13696|0;c[G>>2]=(c[G>>2]|0)+1;G=f+13700|0;c[G>>2]=(c[G>>2]|0)+1}G=f+13692|0;c[G>>2]=(c[G>>2]|0)+1;i=k;return}if(w){Q=z-1|0;R=s<<1;S=F;T=A}else{A=fe(s<<z|0)|0;s=f+796|0;F=c[s>>2]|0;x=A;a[F]=x;x=x>>8;a[F+1|0]=x;x=x>>8;a[F+2|0]=x;x=x>>8;a[F+3|0]=x;c[s>>2]=(c[s>>2]|0)+4;Q=z+31|0;R=0;S=c[C>>2]|0;T=c[v>>2]|0}c[r>>2]=R;c[y>>2]=Q;v=t&3;z=t>>2;s=(c[f+13828>>2]|0)!=0&(v|0)==3?z:z^15;z=(S|0)==0?v:v|8;do{if((T|0)==0){v=d[1210784+z|0]|0;F=d[1210752+z|0]|0;if((Q|0)>(v|0)){U=Q;V=R<<v|F}else{A=fe(F>>>((v-Q|0)>>>0)|R<<Q|0)|0;w=f+796|0;G=c[w>>2]|0;x=A;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;U=Q+32|0;V=F}F=U-v|0;c[r>>2]=V;c[y>>2]=F;v=d[1211185+(s<<1)|0]|0;w=d[1211184+(s<<1)|0]|0;if((F|0)>(v|0)){W=F;X=V<<v|w}else{G=fe(w>>>((v-F|0)>>>0)|V<<F|0)|0;A=f+796|0;B=c[A>>2]|0;x=G;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;W=F+32|0;X=w}w=W-v|0;c[r>>2]=X;c[y>>2]=w;v=c[C>>2]|0;if((v|0)==0){Y=w}else{F=c[1349840+(v+2<<2)>>2]|0;if((w|0)>2){Z=w-2|0;_=X<<2|F}else{v=fe(X<<w|F>>>((2-w|0)>>>0)|0)|0;A=f+796|0;B=c[A>>2]|0;x=v;a[B]=x;x=x>>8;a[B+1|0]=x;x=x>>8;a[B+2|0]=x;x=x>>8;a[B+3|0]=x;c[A>>2]=(c[A>>2]|0)+4;Z=w+30|0;_=F}c[r>>2]=_;c[y>>2]=Z;Y=Z}if((p|0)!=0){F=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-Y)|0;w=f+13700|0;A=c[w>>2]|0;c[w>>2]=F;w=f+13696|0;c[w>>2]=(c[w>>2]|0)-A+F}Bca(f,0,0,l,m)|0;F=c[l>>2]|0;A=h-F|0;if((c[f+13816>>2]|0)!=0){Mlb(f,A);Mlb(f,j-(c[m>>2]|0)|0);if((h-(c[l>>2]|0)|0)!=1){break}if((j-(c[m>>2]|0)|0)!=1){break}w=c[r>>2]|0;B=c[y>>2]|0;if((B|0)>1){$=B-1|0;aa=w<<1|1}else{v=fe(1>>>((1-B|0)>>>0)|w<<B|0)|0;w=f+796|0;G=c[w>>2]|0;x=v;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;$=B+31|0;aa=1}c[r>>2]=aa;c[y>>2]=$;break}B=c[m>>2]|0;w=j-B|0;if((c[f+64>>2]&4|0)==0){Nlb(f,A,1);Nlb(f,w,1);break}if((F|0)==(h|0)){ca=d[1172137]|0}else{ca=(d[1172137+(A<<26>>26<<1)|0]|0)+1|0}if((B|0)==(j|0)){da=d[1172137]|0}else{da=(d[1172137+(w<<26>>26<<1)|0]|0)+1|0}w=(c[y>>2]|0)-(da+ca)|0;B=f+796|0;c[B>>2]=(c[B>>2]|0)+(-(w>>5<<2)|0);c[y>>2]=w&31}else{w=z|16;B=d[1210784+w|0]|0;A=d[1210752+w|0]|0;if((Q|0)>(B|0)){ea=Q;fa=R<<B|A}else{w=fe(A>>>((B-Q|0)>>>0)|R<<Q|0)|0;F=f+796|0;G=c[F>>2]|0;x=w;a[G]=x;x=x>>8;a[G+1|0]=x;x=x>>8;a[G+2|0]=x;x=x>>8;a[G+3|0]=x;c[F>>2]=(c[F>>2]|0)+4;ea=Q+32|0;fa=A}A=ea-B|0;c[r>>2]=fa;c[y>>2]=A;B=d[1211185+(s<<1)|0]|0;F=d[1211184+(s<<1)|0]|0;if((A|0)>(B|0)){ga=A;ha=fa<<B|F}else{G=fe(F>>>((B-A|0)>>>0)|fa<<A|0)|0;w=f+796|0;v=c[w>>2]|0;x=G;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;ga=A+32|0;ha=F}F=ga-B|0;c[r>>2]=ha;c[y>>2]=F;B=c[C>>2]|0;if((B|0)==0){ia=F}else{A=c[1349840+(B+2<<2)>>2]|0;if((F|0)>2){ja=F-2|0;ka=ha<<2|A}else{B=fe(ha<<F|A>>>((2-F|0)>>>0)|0)|0;w=f+796|0;v=c[w>>2]|0;x=B;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[w>>2]=(c[w>>2]|0)+4;ja=F+30|0;ka=A}c[r>>2]=ka;c[y>>2]=ja;ia=ja}if((p|0)==0){la=f+796|0}else{A=f+796|0;F=((c[A>>2]|0)-(c[f+792>>2]|0)<<3)+(32-ia)|0;w=f+13700|0;v=c[w>>2]|0;c[w>>2]=F;w=f+13696|0;c[w>>2]=(c[w>>2]|0)-v+F;la=A}A=f+9148|0;F=f+13816|0;v=f+64|0;w=d[1172137]|0;B=0;do{Bca(f,B,0,l,m)|0;G=c[f+12496+(B<<2)>>2]|0;u=c[A>>2]|0;D=b[u+(G<<2)>>1]|0;I=b[u+(G<<2)+2>>1]|0;G=c[l>>2]|0;u=D-G|0;do{if((c[F>>2]|0)==0){ma=c[m>>2]|0;na=I-ma|0;if((c[v>>2]&4|0)==0){Nlb(f,u,1);Nlb(f,na,1);break}if((D|0)==(G|0)){oa=w}else{oa=(d[1172137+(u<<26>>26<<1)|0]|0)+1|0}if((I|0)==(ma|0)){pa=w}else{pa=(d[1172137+(na<<26>>26<<1)|0]|0)+1|0}na=(c[y>>2]|0)-(pa+oa)|0;c[la>>2]=(c[la>>2]|0)+(-(na>>5<<2)|0);c[y>>2]=na&31}else{Mlb(f,u);Mlb(f,I-(c[m>>2]|0)|0);if((D-(c[l>>2]|0)|0)!=1){break}if((I-(c[m>>2]|0)|0)!=1){break}na=c[r>>2]|0;ma=c[y>>2]|0;if((ma|0)>1){qa=ma-1|0;ra=na<<1|1}else{sa=fe(1>>>((1-ma|0)>>>0)|na<<ma|0)|0;na=c[la>>2]|0;x=sa;a[na]=x;x=x>>8;a[na+1|0]=x;x=x>>8;a[na+2|0]=x;x=x>>8;a[na+3|0]=x;c[la>>2]=(c[la>>2]|0)+4;qa=ma+31|0;ra=1}c[r>>2]=ra;c[y>>2]=qa}}while(0);B=B+1|0;}while((B|0)<4)}}while(0);if((p|0)==0){break}r=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-(c[y>>2]|0))|0;C=f+13700|0;s=c[C>>2]|0;c[C>>2]=r;C=f+13664|0;c[C>>2]=(c[C>>2]|0)-s+r}else{r=f+228|0;do{if((c[r>>2]|0)==0){s=(c[f+180>>2]|0)>0?32:0;C=(c[f+184>>2]|0)>0?s|16:s;s=(c[f+188>>2]|0)>0?C|8:C;C=(c[f+192>>2]|0)>0?s|4:s;s=(c[f+196>>2]|0)>0?C|2:C;if((c[f+200>>2]|0)<=0){ta=s;break}ta=s|1}else{s=f+168|0;C=f+172|0;z=f+13832|0;B=0;w=0;while(1){v=g+(B<<7)|0;F=b[v>>1]|0;A=c[((B|0)<4?s:C)>>2]|0;E=o+(B<<2)|0;H=(yca(f,B,E)|0)<<16>>16;I=(F&65535)-H<<16;F=A>>1;D=((((I|0)>-65536?F:-F|0)+(I>>16)|0)/(A|0)|0)&65535;do{if(D<<16>>16==0){I=f+180+(B<<2)|0;if((c[I>>2]|0)!=0){break}c[I>>2]=-1}}while(0);do{if((c[z>>2]|0)==0){if(D<<16>>16<-127){ua=-127;break}ua=D<<16>>16>127?127:D}else{ua=D}}while(0);b[v>>1]=ua;D=n+(B<<1)|0;I=((ba(ua<<16>>16,A)|0)+H|1)&65535;b[D>>1]=I;do{if(I<<16>>16<0){b[D>>1]=0;va=0}else{if(!(I<<16>>16>2047)){va=I;break}b[D>>1]=2047;va=2047}}while(0);b[c[E>>2]>>1]=va;if((c[f+180+(B<<2)>>2]|0)>-1){wa=1<<5-B|w}else{wa=w}D=B+1|0;if((D|0)<6){B=D;w=wa}else{ta=wa;break}}}}while(0);y=ta&3;w=f+9984|0;B=(c[w>>2]|0)!=0;if((c[f+9992>>2]|0)==1){z=B?y|4:y;C=d[1210736+z|0]|0;s=d[1210720+z|0]|0;z=f+784|0;D=c[z>>2]|0;I=f+788|0;H=c[I>>2]|0;if((H|0)>(C|0)){xa=H-C|0;ya=D<<C|s}else{A=fe(s>>>((C-H|0)>>>0)|D<<H|0)|0;D=f+796|0;v=c[D>>2]|0;x=A;a[v]=x;x=x>>8;a[v+1|0]=x;x=x>>8;a[v+2|0]=x;x=x>>8;a[v+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;xa=32-C+H|0;ya=s}c[z>>2]=ya;c[I>>2]=xa;za=ya;Aa=xa}else{I=f+784|0;z=c[I>>2]|0;s=f+788|0;H=c[s>>2]|0;if((H|0)>1){Ba=H-1|0;Ca=z<<1}else{C=fe(z<<H|0)|0;z=f+796|0;D=c[z>>2]|0;x=C;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;Ba=H+31|0;Ca=0}c[I>>2]=Ca;c[s>>2]=Ba;H=(B?y|8:y)|4;y=d[1210784+H|0]|0;B=d[1210752+H|0]|0;if((Ba|0)>(y|0)){Da=Ba;Ea=Ca<<y|B}else{H=fe(B>>>((y-Ba|0)>>>0)|Ca<<Ba|0)|0;z=f+796|0;D=c[z>>2]|0;x=H;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;Da=Ba+32|0;Ea=B}B=Da-y|0;c[I>>2]=Ea;c[s>>2]=B;za=Ea;Aa=B}B=f+784|0;s=f+788|0;if((c[r>>2]|0)==0){Fa=za;Ga=Aa}else{if((Aa|0)>1){Ha=Aa-1|0;Ia=za<<1}else{I=fe(za<<Aa|0)|0;y=f+796|0;z=c[y>>2]|0;x=I;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;c[y>>2]=(c[y>>2]|0)+4;Ha=Aa+31|0;Ia=0}c[B>>2]=Ia;c[s>>2]=Ha;Fa=Ia;Ga=Ha}y=ta>>2;z=d[1211185+(y<<1)|0]|0;I=d[1211184+(y<<1)|0]|0;if((Ga|0)>(z|0)){Ja=Ga-z|0;Ka=Fa<<z|I}else{y=fe(I>>>((z-Ga|0)>>>0)|Fa<<Ga|0)|0;D=f+796|0;H=c[D>>2]|0;x=y;a[H]=x;x=x>>8;a[H+1|0]=x;x=x>>8;a[H+2|0]=x;x=x>>8;a[H+3|0]=x;c[D>>2]=(c[D>>2]|0)+4;Ja=32-z+Ga|0;Ka=I}c[B>>2]=Ka;c[s>>2]=Ja;I=c[w>>2]|0;if((I|0)==0){La=Ja}else{w=c[1349840+(I+2<<2)>>2]|0;if((Ja|0)>2){Ma=Ja-2|0;Na=Ka<<2|w}else{I=fe(Ka<<Ja|w>>>((2-Ja|0)>>>0)|0)|0;z=f+796|0;D=c[z>>2]|0;x=I;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;c[z>>2]=(c[z>>2]|0)+4;Ma=Ja+30|0;Na=w}c[B>>2]=Na;c[s>>2]=Ma;La=Ma}if((p|0)==0){break}s=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-La)|0;B=f+13700|0;w=c[B>>2]|0;c[B>>2]=s;B=f+13696|0;c[B>>2]=(c[B>>2]|0)-w+s}}while(0);La=f+228|0;Ma=f+13828|0;Na=f+784|0;Ja=Na|0;Ka=f+788|0;Ga=f+44|0;Fa=f+796|0;ta=0;Ha=c[La>>2]|0;do{Ia=g+(ta<<7)|0;Aa=(c[q>>2]|0)==0;za=(Ha|0)==0;a:do{if(Aa){if(za){Oa=1210184;Pa=168}else{Pa=167}}else{if(!za){Pa=167;break}Ea=b[Ia>>1]|0;do{if(Ea<<16>>16>254){Qa=254;Ra=254;Pa=155}else{if(Ea<<16>>16<1){Qa=1;Ra=1;Pa=155;break}if(!(Ea<<16>>16==128)){Sa=Ea<<16>>16;break}Da=c[Ja>>2]|0;Ba=c[Ka>>2]|0;if((Ba|0)>8){Ta=Ba-8|0;Ua=Da<<8|255}else{Ca=fe(255>>>((8-Ba|0)>>>0)|Da<<Ba|0)|0;Da=c[Fa>>2]|0;x=Ca;a[Da]=x;x=x>>8;a[Da+1|0]=x;x=x>>8;a[Da+2|0]=x;x=x>>8;a[Da+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;Ta=Ba+24|0;Ua=255}c[Ja>>2]=Ua;c[Ka>>2]=Ta;Va=1210184;Wa=1;break a}}while(0);if((Pa|0)==155){Pa=0;b[Ia>>1]=Ra;Sa=Qa}Ea=c[Ja>>2]|0;Ba=f+788|0;Da=c[Ba>>2]|0;if((Da|0)>8){Xa=Da-8|0;Ya=Ea<<8|Sa}else{Ca=fe(Sa>>>((8-Da|0)>>>0)|Ea<<Da|0)|0;Ea=f+796|0;xa=c[Ea>>2]|0;x=Ca;a[xa]=x;x=x>>8;a[xa+1|0]=x;x=x>>8;a[xa+2|0]=x;x=x>>8;a[xa+3|0]=x;c[Ea>>2]=(c[Ea>>2]|0)+4;Xa=Da+24|0;Ya=Sa}c[Ja>>2]=Ya;c[Ba>>2]=Xa;Va=1210184;Wa=1}}while(0);if((Pa|0)==167){Pa=0;Oa=Aa?1210184:1148376;Pa=168}do{if((Pa|0)==168){Pa=0;if((c[Ma>>2]|0)==0|Aa^1){Va=Oa;Wa=0;break}za=c[f+180+(ta<<2)>>2]|0;if((za|0)<0){Za=0;_a=0;$a=-1}else{r=Oa|0;Ba=c[287094]|0;Da=Oa+8|0;Ea=c[287096]|0;xa=0;Ca=-1;ya=0;wa=0;va=-1;while(1){ua=b[g+(ta<<7)+(d[f+368+xa|0]<<1)>>1]|0;o=ua<<16>>16;if(ua<<16>>16==0){ab=va;bb=wa;cb=ya;db=Ca}else{qa=xa-Ca|0;ra=qa-1|0;la=(xa|0)==(za|0)|0;m=ua<<16>>16<0?-o|0:o;o=d[(c[Oa+20+(la<<2)>>2]|0)+ra|0]|0;ua=c[r>>2]|0;do{if((o|0)<(ua|0)){if((a[(c[Oa+28+(la<<2)>>2]|0)+ra|0]|0)<(m|0)){eb=ua;break}eb=m-1+o|0}else{eb=ua}}while(0);o=d[(c[1148396+(la<<2)>>2]|0)+ra|0]|0;do{if((o|0)<(Ba|0)){if((a[(c[1148404+(la<<2)>>2]|0)+ra|0]|0)<(m|0)){fb=Ba;break}fb=m-1+o|0}else{fb=Ba}}while(0);o=wa+1+(e[(c[Da>>2]|0)+(eb<<2)+2>>1]|0)|0;m=ya+1+(e[Ea+(fb<<2)+2>>1]|0)|0;if((fb|0)==(Ba|0)){gb=qa;hb=m+14|0}else{gb=d[15768+fb|0]|0;hb=m}ab=gb+va|0;bb=(eb|0)==(ua|0)?o+14|0:o;cb=hb;db=xa}o=xa+1|0;if((o|0)>(za|0)){Za=cb;_a=bb;$a=ab;break}else{xa=o;Ca=db;ya=cb;wa=bb;va=ab}}}Va=(Za|0)<(_a|0)&($a|0)>63?1148376:Oa;Wa=0}}while(0);Aa=c[f+180+(ta<<2)>>2]|0;if((Wa|0)<=(Aa|0)){va=Va|0;wa=Va+8|0;ya=Wa;Ca=Wa-1|0;while(1){xa=b[g+(ta<<7)+(d[f+368+ya|0]<<1)>>1]|0;za=xa<<16>>16;do{if(xa<<16>>16==0){ib=Ca}else{Ba=ya-Ca-1|0;Ea=(ya|0)==(Aa|0)|0;Da=(xa&65535)>>>15&65535;r=xa<<16>>16<0?-za|0:za;o=d[(c[Va+20+(Ea<<2)>>2]|0)+Ba|0]|0;m=c[va>>2]|0;do{if((o|0)<(m|0)){if((a[(c[Va+28+(Ea<<2)>>2]|0)+Ba|0]|0)<(r|0)){jb=m;break}jb=r-1+o|0}else{jb=m}}while(0);m=c[wa>>2]|0;o=e[m+(jb<<2)+2>>1]|0;ua=e[m+(jb<<2)>>1]|0;m=c[Ja>>2]|0;qa=c[Ka>>2]|0;if((qa|0)>(o|0)){kb=qa-o|0;lb=m<<o|ua}else{ra=fe(ua>>>((o-qa|0)>>>0)|m<<qa|0)|0;m=c[Fa>>2]|0;x=ra;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;kb=32-o+qa|0;lb=ua}c[Ja>>2]=lb;c[Ka>>2]=kb;if((jb|0)!=(c[va>>2]|0)){if((kb|0)>1){mb=kb-1|0;nb=lb<<1|Da}else{ua=fe(Da>>>((1-kb|0)>>>0)|lb<<kb|0)|0;qa=c[Fa>>2]|0;x=ua;a[qa]=x;x=x>>8;a[qa+1|0]=x;x=x>>8;a[qa+2|0]=x;x=x>>8;a[qa+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;mb=kb+31|0;nb=Da}c[Ja>>2]=nb;c[Ka>>2]=mb;ib=ya;break}if((c[Ga>>2]|0)>=2){gba(Na,za,r,Ba,Ea);ib=ya;break}if((kb|0)>1){ob=kb-1|0;pb=lb<<1|Ea}else{qa=fe(Ea>>>((1-kb|0)>>>0)|lb<<kb|0)|0;ua=c[Fa>>2]|0;x=qa;a[ua]=x;x=x>>8;a[ua+1|0]=x;x=x>>8;a[ua+2|0]=x;x=x>>8;a[ua+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;ob=kb+31|0;pb=Ea}c[Ja>>2]=pb;c[Ka>>2]=ob;if((ob|0)>6){qb=ob-6|0;rb=pb<<6|Ba}else{ua=fe(Ba>>>((6-ob|0)>>>0)|pb<<ob|0)|0;qa=c[Fa>>2]|0;x=ua;a[qa]=x;x=x>>8;a[qa+1|0]=x;x=x>>8;a[qa+2|0]=x;x=x>>8;a[qa+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;qb=ob+26|0;rb=Ba}c[Ja>>2]=rb;c[Ka>>2]=qb;if((r|0)<128){qa=za&255;if((qb|0)>8){sb=qb-8|0;tb=rb<<8|qa}else{ua=fe(qa>>>((8-qb|0)>>>0)|rb<<qb|0)|0;o=c[Fa>>2]|0;x=ua;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;sb=qb+24|0;tb=qa}c[Ja>>2]=tb;c[Ka>>2]=sb;ib=ya;break}if((qb|0)>8){ub=qb-8|0;vb=rb<<8|128}else{qa=fe(128>>>((8-qb|0)>>>0)|rb<<qb|0)|0;o=c[Fa>>2]|0;x=qa;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;ub=qb+24|0;vb=128}c[Ja>>2]=vb;c[Ka>>2]=ub;o=za&31;if((ub|0)>5){wb=ub-5|0;xb=vb<<5|o}else{qa=fe(o>>>((5-ub|0)>>>0)|vb<<ub|0)|0;ua=c[Fa>>2]|0;x=qa;a[ua]=x;x=x>>8;a[ua+1|0]=x;x=x>>8;a[ua+2|0]=x;x=x>>8;a[ua+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;wb=ub+27|0;xb=o}c[Ja>>2]=xb;c[Ka>>2]=wb;o=za>>>5&63;if((wb|0)>6){yb=wb-6|0;zb=xb<<6|o}else{ua=fe(o>>>((6-wb|0)>>>0)|xb<<wb|0)|0;qa=c[Fa>>2]|0;x=ua;a[qa]=x;x=x>>8;a[qa+1|0]=x;x=x>>8;a[qa+2|0]=x;x=x>>8;a[qa+3|0]=x;c[Fa>>2]=(c[Fa>>2]|0)+4;yb=wb+26|0;zb=o}c[Ja>>2]=zb;c[Ka>>2]=yb;ib=ya}}while(0);za=ya+1|0;if((za|0)>(Aa|0)){break}else{ya=za;Ca=ib}}}Ha=c[La>>2]|0;do{if((Ha|0)!=0){if((c[q>>2]|0)==0){break}b[Ia>>1]=b[n+(ta<<1)>>1]|0}}while(0);ta=ta+1|0;}while((ta|0)<6);if((p|0)==0){i=k;return}p=(c[q>>2]|0)==0;q=((c[Fa>>2]|0)-(c[f+792>>2]|0)<<3)+(32-(c[Ka>>2]|0))|0;Ka=f+13700|0;Fa=c[Ka>>2]|0;c[Ka>>2]=q;Ka=q-Fa|0;if(p){p=f+13676|0;c[p>>2]=(c[p>>2]|0)+Ka;p=f+13684|0;c[p>>2]=(c[p>>2]|0)+1;i=k;return}else{p=f+13672|0;c[p>>2]=(c[p>>2]|0)+Ka;Ka=f+13680|0;c[Ka>>2]=(c[Ka>>2]|0)+1;i=k;return}}function Mlb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((d|0)==0){e=b+784|0;f=c[e>>2]|0;g=b+788|0;h=c[g>>2]|0;if((h|0)>1){i=h-1|0;j=f<<1|1}else{k=fe(1>>>((1-h|0)>>>0)|f<<h|0)|0;f=b+796|0;l=c[f>>2]|0;x=k;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;c[f>>2]=(c[f>>2]|0)+4;i=h+31|0;j=1}c[e>>2]=j;c[g>>2]=i;return}else if((d|0)==(-1|0)){i=b+784|0;g=c[i>>2]|0;j=b+788|0;e=c[j>>2]|0;if((e|0)>3){m=e-3|0;n=g<<3|2}else{h=fe(2>>>((3-e|0)>>>0)|g<<e|0)|0;g=b+796|0;f=c[g>>2]|0;x=h;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;c[g>>2]=(c[g>>2]|0)+4;m=e+29|0;n=2}c[i>>2]=n;c[j>>2]=m;return}else if((d|0)==1){m=b+784|0;j=c[m>>2]|0;n=b+788|0;i=c[n>>2]|0;if((i|0)>3){o=i-3|0;p=j<<3}else{e=fe(j<<i|0)|0;j=b+796|0;g=c[j>>2]|0;x=e;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;o=i+29|0;p=0}c[m>>2]=p;c[n>>2]=o;return}else{o=((d|0)<0?-d|0:d)&65535;do{if(o<<16>>16==0){q=0;r=0}else{n=0;p=o;while(1){m=p<<16>>16>>>1&65535;s=n+1&65535;if(m<<16>>16==0){break}else{n=s;p=m}}p=s<<16>>16;if(!(n<<16>>16>0)){q=0;r=p;break}m=o<<16>>16;i=0;j=n;do{g=(j<<16>>16)-1|0;i=i<<2|(1<<g&m)>>g<<1|1;j=j-1&65535;}while(j<<16>>16>0);q=i<<1;r=p}}while(0);o=(q|d>>>31)<<1;d=r<<1|1;r=b+784|0;q=c[r>>2]|0;s=b+788|0;j=c[s>>2]|0;if((j|0)>(d|0)){t=j-d|0;u=q<<d|o}else{m=fe(o>>>((d-j|0)>>>0)|q<<j|0)|0;q=b+796|0;b=c[q>>2]|0;x=m;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[q>>2]=(c[q>>2]|0)+4;t=32-d+j|0;u=o}c[r>>2]=u;c[s>>2]=t;return}}function Nlb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((e|0)==0){g=d[1172137]|0;h=d[1172136]|0;i=b+784|0;j=c[i>>2]|0;k=b+788|0;l=c[k>>2]|0;if((l|0)>(g|0)){m=l-g|0;n=j<<g|h}else{o=fe(h>>>((g-l|0)>>>0)|j<<l|0)|0;j=b+796|0;p=c[j>>2]|0;x=o;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;c[j>>2]=(c[j>>2]|0)+4;m=32-g+l|0;n=h}c[i>>2]=n;c[k>>2]=m;return}m=f-1|0;k=27-f|0;n=e<<k>>k;k=n>>31;e=(k^n)-k-1|0;n=(e>>m)+1|0;i=d[1172137+(n<<1)|0]|0;h=i+1|0;l=(d[1172136+(n<<1)|0]|0)<<1|k&1;k=b+784|0;n=c[k>>2]|0;g=b+788|0;j=c[g>>2]|0;if((j|0)>(h|0)){q=j-h|0;r=l|n<<h}else{p=fe(l>>>((h-j|0)>>>0)|n<<j|0)|0;n=b+796|0;h=c[n>>2]|0;x=p;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;c[n>>2]=(c[n>>2]|0)+4;q=31-i+j|0;r=l}c[k>>2]=r;c[g>>2]=q;if((m|0)<=0){return}l=e&(1<<m)-1;if((q|0)>(m|0)){s=q-m|0;t=r<<m|l}else{e=fe(r<<q|l>>>((m-q|0)>>>0)|0)|0;m=b+796|0;b=c[m>>2]|0;x=e;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;c[m>>2]=(c[m>>2]|0)+4;s=33-f+q|0;t=l}c[k>>2]=t;c[g>>2]=s;return}function Olb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if(!(a[1210960]|0)){a[1210960]=1;OOa(1210184,7402136);OOa(1148376,7402526);Plb(1148376,2766552);Plb(1210184,2782936);e=a[1172137]|0;f=d[1172201]|0;g=1;while(1){h=g-1|0;i=g+1|0;j=i+f|0;k=-4096;while(1){if((k|0)==0){a[4675920+(g*8193|0)|0]=e;k=1;continue}l=(((k|0)<0?-k|0:k)-1>>h)+1|0;if((l|0)<33){m=(d[1172137+(l<<1)|0]|0)+g&255}else{n=l>>5;l=n>>>0>65535>>>0;o=l?n>>>16:n;n=l?16:0;if((o&65280|0)==0){p=n;q=o}else{p=n|8;q=o>>>8}m=j+p+(d[1191992+q|0]|0)&255}a[k+4096+(4671824+(g*8193|0))|0]=m;k=k+1|0;if((k|0)>=4097){break}}if((i|0)<8){g=i}else{break}}TGb(8002976,7,4096)|0;TGb(8004e3,6,2048)|0;TGb(8004512,5,1024)|0;TGb(8004768,4,512)|0;TGb(8004896,3,256)|0;TGb(8004960,2,128)|0;TGb(8004992,1,64)|0;TGb(2819160,1,8193)|0}c[b+12460>>2]=4671824;c[b+13100>>2]=2782936;g=b+13092|0;c[g>>2]=2782936;c[b+13104>>2]=2791128;m=b+13096|0;c[m>>2]=2791128;if((c[b+228>>2]|0)!=0){c[g>>2]=2766552;c[m>>2]=2774744}c[b+13088>>2]=22;m=c[b+48>>2]|0;if((m|0)==22){g=b+13080|0;if((c[b+44>>2]|0)>1){c[g>>2]=-1023;c[b+13084>>2]=1023}else{c[g>>2]=-127;c[b+13084>>2]=127}c[b+9892>>2]=1179688;c[b+9888>>2]=1179688;return}else if((m|0)==13){c[b+11856>>2]=8000928;return}else if((m|0)==20){if((c[b+13816>>2]|0)!=0){c[b+11856>>2]=2819160}m=b+13080|0;if((c[b+13832>>2]|0)==0){c[m>>2]=-127;c[b+13084>>2]=127;return}else{c[m>>2]=-2047;c[b+13084>>2]=2047;return}}else{c[b+13080>>2]=-127;c[b+13084>>2]=127;c[b+9892>>2]=1179688;c[b+9888>>2]=1179688;return}}function Plb(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=b|0;h=b+8|0;i=-64;while(1){if((i|0)==0){i=i+1|0;continue}j=i+64|0;k=(i|0)<0?-i|0:i;l=k-1|0;m=0;do{n=j+(m<<7)|0;o=f+n|0;a[o]=100;p=d[(c[b+20>>2]|0)+m|0]|0;q=c[g>>2]|0;do{if((p|0)<(q|0)){if((a[(c[b+28>>2]|0)+m|0]|0)<(k|0)){r=7;break}s=l+p|0;t=c[h>>2]|0;u=(e[t+(s<<2)+2>>1]|0)+1|0;if(!((s|0)!=(q|0)&u>>>0<100>>>0)){v=q;w=t;x=100;break}a[o]=u;v=c[g>>2]|0;w=c[h>>2]|0;x=u&255}else{r=7}}while(0);if((r|0)==7){r=0;v=q;w=c[h>>2]|0;x=100}p=(e[w+(v<<2)+2>>1]|0)+15|0;if(p>>>0<x>>>0){a[o]=p}p=f+(n+8192)|0;a[p]=100;u=d[(c[b+24>>2]|0)+m|0]|0;t=c[g>>2]|0;do{if((u|0)<(t|0)){if((a[(c[b+32>>2]|0)+m|0]|0)<(k|0)){r=16;break}s=l+u|0;y=c[h>>2]|0;z=(e[y+(s<<2)+2>>1]|0)+1|0;if(!((s|0)!=(t|0)&z>>>0<100>>>0)){A=t;B=y;C=100;break}a[p]=z;A=c[g>>2]|0;B=c[h>>2]|0;C=z&255}else{r=16}}while(0);if((r|0)==16){r=0;A=t;B=c[h>>2]|0;C=100}u=(e[B+(A<<2)+2>>1]|0)+15|0;if(u>>>0<C>>>0){a[p]=u}m=m+1|0;}while((m|0)<64);i=i+1|0;if((i|0)>=64){break}}return}function Qlb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+5900>>2]<<1|1;c[a+5904>>2]=b;e=c[a+5892>>2]|0;f=((e-1+b|0)/(b|0)|0)+1|0;b=a+5896|0;c[b>>2]=f;g=0;while(1){if((1<<g|0)<(f|0)){g=g+1|0}else{break}}c[a+5888>>2]=g;h=e>>>0>65535>>>0;i=h?e>>>16:e;e=h?16:0;if((i&65280|0)==0){j=e;k=i}else{j=e|8;k=i>>>8}i=j+1+(d[1191992+k|0]|0)|0;k=(i|0)>2?i:2;c[a+5884>>2]=k;c[a+5876>>2]=(((k|0)>8?k:8)+k<<1)-g;g=0;k=f;while(1){f=k+32>>6;c[a+12+(g<<2)>>2]=(f|0)>2?f:2;c[a+4408+(g<<2)>>2]=1;f=g+1|0;if((f|0)>=367){break}g=f;k=c[b>>2]|0}return}function Rlb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a+5892|0;e=c[d>>2]|0;f=(b|0)==0;if((e|0)!=0&f){g=e}else{e=(1<<c[a+5884>>2])-1|0;c[d>>2]=e;g=e}do{if((g|0)>127){if((g|0)>4095){h=16}else{h=g+128>>8}e=a|0;d=c[e>>2]|0;if((d|0)!=0&f){i=d}else{d=c[a+5900>>2]|0;b=h+2+(d*3|0)|0;j=d+1|0;d=(b|0)>(g|0)|(b|0)<(j|0)?j:b;c[e>>2]=d;i=d}d=a+4|0;e=c[d>>2]|0;if((e|0)!=0&f){k=e}else{e=((c[a+5900>>2]|0)*5|0)+(h<<2|3)|0;b=(e|0)>(g|0)|(e|0)<(i|0)?i:e;c[d>>2]=b;k=b}b=a+8|0;if((c[b>>2]|0)!=0&f){break}d=(h*17|0)+4+((c[a+5900>>2]|0)*7|0)|0;c[b>>2]=(d|0)>(g|0)|(d|0)<(k|0)?k:d}else{d=256/(g+1|0)|0;b=a|0;e=c[b>>2]|0;if((e|0)!=0&f){l=e}else{e=c[a+5900>>2]|0;j=(e*3|0)+(3/(d|0)|0)|0;m=(j|0)<2?2:j;j=e+1|0;e=(m|0)>(g|0)|(m|0)<(j|0)?j:m;c[b>>2]=e;l=e}e=a+4|0;b=c[e>>2]|0;if((b|0)!=0&f){n=b}else{b=((c[a+5900>>2]|0)*5|0)+(7/(d|0)|0)|0;m=(b|0)<3?3:b;b=(m|0)>(g|0)|(m|0)<(l|0)?l:m;c[e>>2]=b;n=b}b=a+8|0;if((c[b>>2]|0)!=0&f){break}e=((c[a+5900>>2]|0)*7|0)+(21/(d|0)|0)|0;d=(e|0)<4?4:e;c[b>>2]=(d|0)>(g|0)|(d|0)<(n|0)?n:d}}while(0);n=a+5880|0;if((c[n>>2]|0)!=0&f){return}c[n>>2]=64;return}function Slb(a,b,d){a=a|0;b=+b;d=d|0;var e=0,f=0,j=0.0,k=0,l=0.0,m=0,n=0.0,o=0,p=0;e=i;i=i+8192|0;f=e|0;j=b*3.141592653589793/+(d|0);b=j*j;if((d|0)>=1025){yDb(0,0,2174e3,(k=i,i=i+24|0,c[k>>2]=2303456,c[k+8>>2]=2173200,c[k+16>>2]=33,k)|0);i=k;Cd()}k=(d|0)>0;if(k){l=0.0;m=0}else{i=e;return}do{j=b*+(ba(d-m|0,m)|0);n=1.0;o=50;do{n=j*n/+(ba(o,o)|0)+1.0;o=o-1|0;}while((o|0)>0);l=l+n;h[f+(m<<3)>>3]=l;m=m+1|0;}while((m|0)<(d|0));b=l+1.0;if(k){p=0}else{i=e;return}do{g[a+(p<<2)>>2]=+R(+h[f+(p<<3)>>3]/b);p=p+1|0;}while((p|0)<(d|0));i=e;return}function Tlb(a,b){a=a|0;b=b|0;c[a>>2]=236;c[a+4>>2]=142;c[a+16>>2]=116;c[a+12>>2]=570;c[a+8>>2]=368;return}function Ulb(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=(f>>>1)*65537|0;i=h+65537|0;j=g-2|0;if((j|0)<0){k=0}else{l=0;while(1){m=c[d+(l<<1)>>2]|0;n=a+(l<<1)|0;o=c[n>>2]|0;c[n>>2]=(o&h)+(m&h)^(o^m)&i;m=l+2|0;if((m|0)>(j|0)){k=m;break}else{l=m}}}if((k|0)<(g|0)){p=k}else{return}do{k=a+(p<<1)|0;b[k>>1]=(e[d+(p<<1)>>1]|0)+(e[k>>1]|0)&f;p=p+1|0;}while((p|0)<(g|0));return}function Vlb(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;do{if((f&3|0)==0){i=(g>>>1)*65537|0;j=i+65537|0;k=h-2|0;if((k|0)<0){l=0;break}else{m=0}while(1){n=c[d+(m<<1)>>2]|0;o=c[f+(m<<1)>>2]|0;c[a+(m<<1)>>2]=(n|j)-(o&i)^(o^~n)&j;n=m+2|0;if((n|0)>(k|0)){l=n;break}else{m=n}}}else{if((h|0)>3){p=0;q=3}else{l=0;break}while(1){b[a+(p<<1)>>1]=(e[d+(p<<1)>>1]|0)-(e[f+(p<<1)>>1]|0)&g;k=p|1;b[a+(k<<1)>>1]=(e[d+(k<<1)>>1]|0)-(e[f+(k<<1)>>1]|0)&g;k=p|2;b[a+(k<<1)>>1]=(e[d+(k<<1)>>1]|0)-(e[f+(k<<1)>>1]|0)&g;b[a+(q<<1)>>1]=(e[d+(q<<1)>>1]|0)-(e[f+(q<<1)>>1]|0)&g;k=p+4|0;j=k|3;if((j|0)<(h|0)){p=k;q=j}else{l=k;break}}}}while(0);if((l|0)<(h|0)){r=l}else{return}do{b[a+(r<<1)>>1]=(e[d+(r<<1)>>1]|0)-(e[f+(r<<1)>>1]|0)&g;r=r+1|0;}while((r|0)<(h|0));return}function Wlb(a,c,d,f,g){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=f-1|0;if((h|0)>0){i=g;j=0;while(1){k=(e[c+(j<<1)>>1]|0)+i|0;b[a+(j<<1)>>1]=k&d;l=j|1;m=k+(e[c+(l<<1)>>1]|0)|0;b[a+(l<<1)>>1]=m&d;l=j+2|0;if((l|0)<(h|0)){i=m;j=l}else{n=m;o=l;break}}}else{n=g;o=0}if((o|0)<(f|0)){p=n;q=o}else{r=n;return r|0}while(1){n=(e[c+(q<<1)>>1]|0)+p|0;b[a+(q<<1)>>1]=n&d;o=q+1|0;if((o|0)<(f|0)){p=n;q=o}else{r=n;break}}return r|0}function Xlb(a,d,f,g,h,i,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;k=c[i>>2]|0;l=c[j>>2]&65535;m=k&65535;if((h|0)<=0){n=l;o=m;c[i>>2]=o;p=n&65535;c[j>>2]=p;return}q=0;r=k&65535;k=l;l=m;while(1){m=b[d+(q<<1)>>1]|0;s=m&65535;t=l-(k&65535)+s&g;do{if((r&65535)>>>0>(m&65535)>>>0){if((t|0)<=(s|0)){u=s;break}u=(t|0)>(l|0)?l:t}else{if((s|0)<=(t|0)){u=s;break}u=(t|0)>(l|0)?t:l}}while(0);t=(e[f+(q<<1)>>1]|0)+u&g;s=t&65535;b[a+(q<<1)>>1]=s;v=q+1|0;w=t&65535;if((v|0)<(h|0)){q=v;r=s;k=m;l=w}else{n=m;o=w;break}}c[i>>2]=o;p=n&65535;c[j>>2]=p;return}function Ylb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=c[h>>2]|0;k=c[i>>2]&65535;l=j&65535;if((g|0)<=0){m=k;n=l;c[h>>2]=n;o=m&65535;c[i>>2]=o;return}p=j&65535;j=k;k=0;q=l;while(1){l=b[d+(k<<1)>>1]|0;r=l&65535;s=q-(j&65535)+r&f;do{if((p&65535)>>>0>(l&65535)>>>0){if((s|0)<=(r|0)){t=r;break}t=(s|0)>(q|0)?q:s}else{if((r|0)<=(s|0)){t=r;break}t=(s|0)>(q|0)?s:q}}while(0);s=b[e+(k<<1)>>1]|0;r=s&65535;b[a+(k<<1)>>1]=r-t&f;u=k+1|0;if((u|0)<(g|0)){p=s;j=l;k=u;q=r}else{m=l;n=r;break}}c[h>>2]=n;o=m&65535;c[i>>2]=o;return}function Zlb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=+f;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0,s=0.0,t=0.0,u=0,v=0,w=0;TGb(a|0,0,60)|0;g=1<<d;c[a+20>>2]=d;c[a+16>>2]=g;h=g>>2;i=a+60|0;c[i>>2]=0;do{if((Tpb(a,d-2|0,e)|0)<0){j=a+24|0}else{k=WDb(((g|0)/2|0)<<1)|0;l=k;m=a+24|0;c[m>>2]=l;if((k|0)==0){j=m;break}n=c[i>>2]|0;if((n|0)==0){c[a+28>>2]=l+(h<<1);o=1}else if((n|0)==1){c[a+28>>2]=k+2;o=2}else{j=m;break}p=(f<0.0?+(h|0):0.0)+.125;q=+R(+Q(+f));if((h|0)<=0){r=0;return r|0}s=+(g|0);k=a+28|0;n=0;while(1){t=(p+ +(n|0))*6.283185307179586/s;l=Gc(+(q*(-0.0- +T(t))*32768.0))|0;if((l|0)<-32767){u=-32767}else{u=(l|0)>32767?32767:l&65535}l=ba(n,o)|0;b[(c[m>>2]|0)+(l<<1)>>1]=u;v=Gc(+(q*(-0.0- +U(t))*32768.0))|0;if((v|0)<-32767){w=-32767}else{w=(v|0)>32767?32767:v&65535}b[(c[k>>2]|0)+(l<<1)>>1]=w;l=n+1|0;if((l|0)<(h|0)){n=l}else{r=0;break}}return r|0}}while(0);$Db(j);Xpb(a);r=-1;return r|0}function _lb(a){a=a|0;$Db(a+24|0);Xpb(a);return}function $lb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=d;d=1<<c[a+20>>2];k=d>>2;l=d>>3;if((k|0)>0){m=f+((d>>1)-1<<1)|0;d=f;f=0;while(1){n=e[g+(f<<1)>>1]|0;o=h+(f<<1)|0;p=ba(b[o>>1]|0,b[m>>1]|0)|0;q=i+(f<<1)|0;b[j+(n<<2)>>1]=(p-(ba(b[q>>1]|0,b[d>>1]|0)|0)|0)>>>15;p=ba(b[q>>1]|0,b[m>>1]|0)|0;b[j+(n<<2)+2>>1]=((ba(b[o>>1]|0,b[d>>1]|0)|0)+p|0)>>>15;p=f+1|0;if((p|0)<(k|0)){m=m-4|0;d=d+4|0;f=p}else{break}}}ne[c[a+36>>2]&1023](a,j);if((l|0)>0){r=0}else{return}do{a=l-r-1|0;f=j+(a<<2)+2|0;d=b[f>>1]|0;m=b[i+(a<<1)>>1]|0;k=ba(m,d)|0;g=j+(a<<2)|0;p=b[g>>1]|0;o=b[h+(a<<1)>>1]|0;a=(k-(ba(o,p)|0)|0)>>>15&65535;k=((ba(o,d)|0)+(ba(p,m)|0)|0)>>>15&65535;m=r+l|0;p=j+(m<<2)+2|0;d=b[p>>1]|0;o=b[i+(m<<1)>>1]|0;n=ba(o,d)|0;q=j+(m<<2)|0;s=b[q>>1]|0;t=b[h+(m<<1)>>1]|0;m=(n-(ba(t,s)|0)|0)>>>15&65535;n=((ba(t,d)|0)+(ba(s,o)|0)|0)>>>15&65535;b[g>>1]=a;b[f>>1]=n;b[q>>1]=m;b[p>>1]=k;r=r+1|0;}while((r|0)<(l|0));return}function amb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=1<<c[a+20>>2];g=f>>1;h=f>>2;$lb(a,d+(h<<1)|0,e);if((h|0)<=0){return}e=g-1|0;a=f-1|0;f=0;i=0;while(1){b[d+(f<<1)>>1]=-(b[d+(e+i<<1)>>1]|0);b[d+(a+i<<1)>>1]=b[d+(f+g<<1)>>1]|0;j=f+1|0;k=~f;if((j|0)<(h|0)){f=j;i=k}else{break}}return}function bmb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=d;d=1<<c[a+20>>2];k=d>>1;l=d>>2;m=d>>3;n=l*3|0;o=(m|0)>0;if(!o){ne[c[a+36>>2]&1023](a,j);return}p=n-1|0;q=l-1|0;r=k-1|0;s=d-1|0;d=0;do{t=d<<1;u=-((b[f+(p-t<<1)>>1]|0)+(b[f+(t+n<<1)>>1]|0)|0)>>1;v=(b[f+(q-t<<1)>>1]|0)-(b[f+(t+l<<1)>>1]|0)>>1;w=e[g+(d<<1)>>1]|0;x=h+(d<<1)|0;y=ba(b[x>>1]|0,-u|0)|0;z=i+(d<<1)|0;b[j+(w<<2)>>1]=(y-(ba(b[z>>1]|0,v)|0)|0)>>>15;y=ba(b[z>>1]|0,u)|0;b[j+(w<<2)+2>>1]=(y-(ba(b[x>>1]|0,v)|0)|0)>>>15;v=(b[f+(t<<1)>>1]|0)-(b[f+(r-t<<1)>>1]|0)>>1;x=-((b[f+(s-t<<1)>>1]|0)+(b[f+(t+k<<1)>>1]|0)|0)>>1;t=d+m|0;y=e[g+(t<<1)>>1]|0;w=h+(t<<1)|0;u=ba(b[w>>1]|0,-v|0)|0;z=i+(t<<1)|0;b[j+(y<<2)>>1]=(u-(ba(b[z>>1]|0,x)|0)|0)>>>15;u=ba(b[z>>1]|0,v)|0;b[j+(y<<2)+2>>1]=(u-(ba(b[w>>1]|0,x)|0)|0)>>>15;d=d+1|0;}while((d|0)<(m|0));ne[c[a+36>>2]&1023](a,j);if(o){A=0}else{return}do{o=m-A-1|0;a=j+(o<<2)|0;d=b[a>>1]|0;g=-(b[i+(o<<1)>>1]|0)|0;k=ba(d,g)|0;f=j+(o<<2)+2|0;s=b[f>>1]|0;r=b[h+(o<<1)>>1]|0;o=((ba(r,s)|0)+k|0)>>>15&65535;k=((ba(s,g)|0)-(ba(r,d)|0)|0)>>>15&65535;d=A+m|0;r=j+(d<<2)|0;g=b[r>>1]|0;s=-(b[i+(d<<1)>>1]|0)|0;l=ba(g,s)|0;q=j+(d<<2)+2|0;n=b[q>>1]|0;p=b[h+(d<<1)>>1]|0;d=((ba(p,n)|0)+l|0)>>>15&65535;l=((ba(n,s)|0)-(ba(p,g)|0)|0)>>>15&65535;b[a>>1]=k;b[f>>1]=d;b[r>>1]=l;b[q>>1]=o;A=A+1|0;}while((A|0)<(m|0));return}function cmb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=c[a+12>>2]|0;k=d;d=1<<c[a+20>>2];l=d>>1;m=d>>2;n=d>>3;o=m*3|0;p=(n|0)>0;if(!p){ne[c[a+36>>2]&1023](a,j);return}q=o-1|0;r=m-1|0;s=l-1|0;t=d-1|0;d=0;do{u=d<<1;v=-((b[f+(q-u<<1)>>1]|0)+(b[f+(u+o<<1)>>1]|0)|0)>>1;w=(b[f+(r-u<<1)>>1]|0)-(b[f+(u+m<<1)>>1]|0)>>1;x=e[g+(d<<1)>>1]|0;y=h+(d<<1)|0;z=ba(b[y>>1]|0,-v|0)|0;A=i+(d<<1)|0;b[j+(x<<2)>>1]=(z-(ba(b[A>>1]|0,w)|0)|0)>>>15;z=ba(b[A>>1]|0,v)|0;b[j+(x<<2)+2>>1]=(z-(ba(b[y>>1]|0,w)|0)|0)>>>15;w=(b[f+(u<<1)>>1]|0)-(b[f+(s-u<<1)>>1]|0)>>1;y=-((b[f+(t-u<<1)>>1]|0)+(b[f+(u+l<<1)>>1]|0)|0)>>1;u=d+n|0;z=e[g+(u<<1)>>1]|0;x=h+(u<<1)|0;v=ba(b[x>>1]|0,-w|0)|0;A=i+(u<<1)|0;b[j+(z<<2)>>1]=(v-(ba(b[A>>1]|0,y)|0)|0)>>>15;v=ba(b[A>>1]|0,w)|0;b[j+(z<<2)+2>>1]=(v-(ba(b[x>>1]|0,y)|0)|0)>>>15;d=d+1|0;}while((d|0)<(n|0));ne[c[a+36>>2]&1023](a,j);if(p){B=0}else{return}do{p=n-B-1|0;a=b[j+(p<<2)>>1]|0;d=-(b[i+(p<<1)>>1]|0)|0;g=ba(a,d)|0;l=b[j+(p<<2)+2>>1]|0;f=b[h+(p<<1)>>1]|0;t=(ba(f,l)|0)+g|0;g=(ba(l,d)|0)-(ba(f,a)|0)|0;a=B+n|0;f=b[j+(a<<2)>>1]|0;d=-(b[i+(a<<1)>>1]|0)|0;l=ba(f,d)|0;s=b[j+(a<<2)+2>>1]|0;m=b[h+(a<<1)>>1]|0;r=(ba(m,s)|0)+l|0;l=(ba(s,d)|0)-(ba(m,f)|0)|0;c[k+(p<<3)>>2]=g;c[k+(p<<3)+4>>2]=r;c[k+(a<<3)>>2]=l;c[k+(a<<3)+4>>2]=t;B=B+1|0;}while((B|0)<(n|0));return}function dmb(){if(a[1418088]|0){return}sBb(8750112,0,8,99,4096)|0;sBb(8758304,0,8,29,4096)|0;sBb(8754208,0,16,45,4096)|0;a[1418088]=1;return}function emb(a,b){a=a|0;b=b|0;var c=0,e=0;c=b-2|0;b=uBb(8754208,0,a,c)|0;e=a+c|0;return((d[e]|d[e+1|0]<<8)<<16>>16&65535^b)&65535|0}function fmb(a,b){a=a|0;b=b|0;var c=0;c=b-1|0;b=uBb(8750112,60,a,c)|0;return((d[a+c|0]|0)^b)&255|0}function gmb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=e+2|0;e=f>>>3;g=uBb(8758304,c[8758304+((a[b]&63)<<2)>>2]|0,b+1|0,e-2|0)|0;h=(d[b+(e-1)|0]|0)^g;g=f&7;if((g|0)==0){i=h&255;return i|0}f=d[b+e|0]|0;e=0;b=h;do{h=b<<1;b=f>>>((7-e|0)>>>0)&1^((h&256|0)==0?h:h^285);e=e+1|0;}while(e>>>0<g>>>0);i=b&255;return i|0}function hmb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=a+b|0;if((a&3|0)!=0&(b|0)>0){f=0;g=a;while(1){h=(d[g]|0)^f;i=g+1|0;if((i&3|0)!=0&i>>>0<e>>>0){f=h;g=i}else{j=h;k=i;break}}}else{j=0;k=a}g=a+(b-3)|0;if(k>>>0<g>>>0){b=j;a=k;while(1){f=c[a>>2]^b;i=a+4|0;if(i>>>0<g>>>0){b=f;a=i}else{l=f;m=i;break}}}else{l=j;m=k}k=l>>>16^l;l=k>>>8^k;if(!(m>>>0<e>>>0)){n=l&255;return n|0}k=l&255;l=m;do{k=(d[l]|0)^k;l=l+1|0;}while(l>>>0<e>>>0);n=k&255;return n|0}function imb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return jmb(a,b,c,d,e,f,g,h)|0}function jmb(a,b,f,g,h,i,j,k){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;l=c[a+12240>>2]|0;m=c[a+12252>>2]|0;n=m&1;o=n<<1|1;p=c[a+12464>>2]|0;q=c[a+12280>>2]|0;r=c[a+12284>>2]|0;s=c[a+10516+(i<<2)>>2]|0;t=i+1|0;u=c[a+10516+(t<<2)>>2]|0;v=n+1|0;w=b>>v;x=f>>v;y=o&b;z=o&f;do{if((m&4|0)==0){A=m&2;B=c[a+12416>>2]|0;C=c[a+12420>>2]|0;D=(z<<v)+y|0;E=(w<<v)+y|0;F=(x<<v)+z|0;G=a+12352+(h<<4)|0;H=a+12288+(g<<4)|0;if((D|0)==0){I=(c[G>>2]|0)+((ba(B,x)|0)+w)|0;J=Pe[s&255](a,c[H>>2]|0,I,B,j)|0;if((A|0)==0){K=J;break}L=J;M=x<<1&2|w&1}else{do{if((n|0)==0){J=(c[G>>2]|0)+((ba(B,x)|0)+w)|0;cf[c[(c[a+12444>>2]|0)+(i<<4)+(D<<2)>>2]&1023](c[a+12208>>2]|0,J,B,j);if((A|0)==0){N=0;break}N=x<<1&2|w&1|D}else{J=(c[G>>2]|0)+((ba(B,x)|0)+w)|0;Xe[c[(c[a+12452>>2]|0)+(i<<6)+(D<<2)>>2]&4095](c[a+12208>>2]|0,J,B);if((A|0)==0){N=0;break}J=(E|0)/2|0;I=(F|0)/2|0;N=(I<<1|I)&2|(J>>>1|J)&1}}while(0);L=Pe[s&255](a,c[a+12208>>2]|0,c[H>>2]|0,B,j)|0;M=N}if((A|0)==0){K=L;break}F=c[a+12208>>2]|0;E=B<<4;D=F+E|0;G=a+12444|0;J=(ba(C,x>>1)|0)+(w>>1)|0;I=j>>1;cf[c[(c[G>>2]|0)+(t<<4)+(M<<2)>>2]&1023](D,(c[a+12352+(h<<4)+4>>2]|0)+J|0,C,I);O=F+(E|8)|0;cf[c[(c[G>>2]|0)+(t<<4)+(M<<2)>>2]&1023](O,(c[a+12352+(h<<4)+8>>2]|0)+J|0,C,I);J=a;G=(Pe[u&255](J,D,c[a+12288+(g<<4)+4>>2]|0,C,I)|0)+L|0;K=G+(Pe[u&255](J,O,c[a+12288+(g<<4)+8>>2]|0,C,I)|0)|0}else{I=c[a+12416>>2]|0;O=(w<<v)+y|0;J=(x<<v)+z|0;G=a+12352+(h<<4)|0;D=a+12288+(g<<4)|0;if((c[a+12264>>2]|0)>(w|0)){K=536870912;break}if((O|0)>(c[a+12268>>2]<<v|0)){K=536870912;break}if((c[a+12272>>2]|0)>(x|0)){K=536870912;break}if((J|0)>(c[a+12276>>2]<<v|0)){K=536870912;break}E=e[a+13872>>1]|0;F=e[a+13874>>1]|0;a:do{if((c[a+11740>>2]|0)==1){P=F-E|0;Q=n|4;R=(J|0)==0;S=a+12208|0;T=I<<3;U=(n|0)==0;V=a+12444|0;W=a+12448|0;X=a+12352+(h<<4)+32|0;Y=a+12452|0;Z=a+12456|0;if((O|0)==0){_=0;while(1){$=c[a+12160+(_<<3)>>2]|0;aa=(c[a+12160+(_<<3)+4>>2]|0)+J|0;ca=((ba(c[a+12128+(_<<3)>>2]|0,P)|0)/(E|0)|0)+((_&1)<<Q)|0;da=c[a+12128+(_<<3)+4>>2]|0;if(R){ea=_>>1;fa=((ba(da,P)|0)/(E|0)|0)+(ea<<Q)|0;ga=ea}else{fa=aa-da|0;ga=_>>1}da=((aa&o)<<v)+($&o)|0;ea=((fa&o)<<v)+(ca&o)|0;ha=(c[S>>2]|0)+((ba(ga,T)|0)+(_<<3&8))|0;if(U){ia=(c[G>>2]|0)+((ba(aa>>1,I)|0)+($>>1))|0;cf[c[(c[V>>2]|0)+16+(da<<2)>>2]&1023](ha,ia,I,8);ia=(c[X>>2]|0)+((ba(fa>>1,I)|0)+(ca>>1))|0;cf[c[(c[W>>2]|0)+16+(ea<<2)>>2]&1023](ha,ia,I,8)}else{ia=(c[G>>2]|0)+((ba(aa>>2,I)|0)+($>>2))|0;Xe[c[(c[Y>>2]|0)+64+(da<<2)>>2]&4095](ha,ia,I);ia=(c[X>>2]|0)+((ba(fa>>2,I)|0)+(ca>>2))|0;Xe[c[(c[Z>>2]|0)+64+(ea<<2)>>2]&4095](ha,ia,I)}_=_+1|0;if((_|0)>=4){break a}}}if(R){_=0;do{ia=(c[a+12160+(_<<3)>>2]|0)+O|0;ha=c[a+12160+(_<<3)+4>>2]|0;ea=ia-(c[a+12128+(_<<3)>>2]|0)|0;ca=_>>1;da=((ba(c[a+12128+(_<<3)+4>>2]|0,P)|0)/(E|0)|0)+(ca<<Q)|0;$=((ha&o)<<v)+(ia&o)|0;aa=((da&o)<<v)+(ea&o)|0;ja=(c[S>>2]|0)+((_<<3&8)+(ba(ca,T)|0))|0;if(U){ca=(c[G>>2]|0)+((ba(ha>>1,I)|0)+(ia>>1))|0;cf[c[(c[V>>2]|0)+16+($<<2)>>2]&1023](ja,ca,I,8);ca=(c[X>>2]|0)+((ba(da>>1,I)|0)+(ea>>1))|0;cf[c[(c[W>>2]|0)+16+(aa<<2)>>2]&1023](ja,ca,I,8)}else{ca=(c[G>>2]|0)+((ba(ha>>2,I)|0)+(ia>>2))|0;Xe[c[(c[Y>>2]|0)+64+($<<2)>>2]&4095](ja,ca,I);ca=(c[X>>2]|0)+((ba(da>>2,I)|0)+(ea>>2))|0;Xe[c[(c[Z>>2]|0)+64+(aa<<2)>>2]&4095](ja,ca,I)}_=_+1|0;}while((_|0)<4)}else{_=0;do{Q=(c[a+12160+(_<<3)>>2]|0)+O|0;P=(c[a+12160+(_<<3)+4>>2]|0)+J|0;R=Q-(c[a+12128+(_<<3)>>2]|0)|0;ca=P-(c[a+12128+(_<<3)+4>>2]|0)|0;ja=((P&o)<<v)+(Q&o)|0;aa=((ca&o)<<v)+(R&o)|0;ea=(c[S>>2]|0)+((_<<3&8)+(ba(_>>1,T)|0))|0;if(U){da=(c[G>>2]|0)+((ba(P>>1,I)|0)+(Q>>1))|0;cf[c[(c[V>>2]|0)+16+(ja<<2)>>2]&1023](ea,da,I,8);da=(c[X>>2]|0)+((ba(ca>>1,I)|0)+(R>>1))|0;cf[c[(c[W>>2]|0)+16+(aa<<2)>>2]&1023](ea,da,I,8)}else{da=(c[G>>2]|0)+((ba(P>>2,I)|0)+(Q>>2))|0;Xe[c[(c[Y>>2]|0)+64+(ja<<2)>>2]&4095](ea,da,I);da=(c[X>>2]|0)+((ba(ca>>2,I)|0)+(R>>2))|0;Xe[c[(c[Z>>2]|0)+64+(aa<<2)>>2]&4095](ea,da,I)}_=_+1|0;}while((_|0)<4)}}else{_=(c[a+12160>>2]|0)+O|0;Z=(c[a+12164>>2]|0)+J|0;X=c[a+12128>>2]|0;if((O|0)==0){ka=(ba(X,F-E|0)|0)/(E|0)|0}else{ka=_-X|0}X=c[a+12132>>2]|0;if((J|0)==0){la=(ba(X,F-E|0)|0)/(E|0)|0}else{la=Z-X|0}X=((Z&o)<<v)+(_&o)|0;Y=((la&o)<<v)+(ka&o)|0;if((n|0)==0){W=a+12208|0;V=(c[G>>2]|0)+((ba(Z>>1,I)|0)+(_>>1))|0;cf[c[(c[a+12444>>2]|0)+(X<<2)>>2]&1023](c[W>>2]|0,V,I,16);V=(c[a+12352+(h<<4)+32>>2]|0)+((ba(la>>1,I)|0)+(ka>>1))|0;cf[c[(c[a+12448>>2]|0)+(Y<<2)>>2]&1023](c[W>>2]|0,V,I,16);break}else{V=a+12452|0;W=a+12208|0;U=(ba(Z>>2,I)|0)+(_>>2)|0;Xe[c[(c[V>>2]|0)+64+(X<<2)>>2]&4095](c[W>>2]|0,(c[G>>2]|0)+U|0,I);_=U+8|0;Xe[c[(c[V>>2]|0)+64+(X<<2)>>2]&4095]((c[W>>2]|0)+8|0,(c[G>>2]|0)+_|0,I);Z=I<<3;Xe[c[(c[V>>2]|0)+64+(X<<2)>>2]&4095]((c[W>>2]|0)+Z|0,(c[G>>2]|0)+(U+Z)|0,I);U=Z+8|0;Xe[c[(c[V>>2]|0)+64+(X<<2)>>2]&4095]((c[W>>2]|0)+U|0,(c[G>>2]|0)+(_+Z)|0,I);_=a+12456|0;X=a+12352+(h<<4)+32|0;V=(ba(la>>2,I)|0)+(ka>>2)|0;Xe[c[(c[_>>2]|0)+64+(Y<<2)>>2]&4095](c[W>>2]|0,(c[X>>2]|0)+V|0,I);T=V+8|0;Xe[c[(c[_>>2]|0)+64+(Y<<2)>>2]&4095]((c[W>>2]|0)+8|0,(c[X>>2]|0)+T|0,I);Xe[c[(c[_>>2]|0)+64+(Y<<2)>>2]&4095]((c[W>>2]|0)+Z|0,(c[X>>2]|0)+(V+Z)|0,I);Xe[c[(c[_>>2]|0)+64+(Y<<2)>>2]&4095]((c[W>>2]|0)+U|0,(c[X>>2]|0)+(T+Z)|0,I);break}}}while(0);K=Pe[s&255](a,c[a+12208>>2]|0,c[D>>2]|0,I,16)|0}}while(0);if((k|0)==0){ma=K;return ma|0}if(!((f|b|0)!=0|(i|0)>0)){ma=K;return ma|0}ma=(ba((d[p+(f-r)|0]|0)+(d[p+(b-q)|0]|0)|0,l)|0)+K|0;return ma|0}function kmb(a,f,h,j,k,l,m,n,o,p){a=a|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0;q=i;i=i+27720|0;r=c[(a+12244|0)>>2]|0;if((r|0)==0&(p|0)==16&(o|0)==0){s=q+8|0;c[(q+8|0)>>2]=0;c[(q+8|0)+4>>2]=0;t=c[a+124>>2]|0;u=(ba(c[(a+12480|0)>>2]|0,t)|0)+(c[(a+12476|0)>>2]|0)|0;v=c[(a+12220|0)>>2]|0;x=c[(a+12264|0)>>2]|0;y=c[(a+12272|0)>>2]|0;z=c[(a+12268|0)>>2]|0;A=c[(a+12276|0)>>2]|0;B=c[(a+12464|0)>>2]|0;C=c[(a+12280|0)>>2]|0;F=c[(a+12284|0)>>2]|0;G=c[(a+12216|0)>>2]|0;if((c[(a+12256|0)>>2]|0)==0){H=a+12232|0;I=a+10468|0}else{H=a+12228|0;I=a+10444|0}J=c[H>>2]|0;H=c[I>>2]|0;I=(c[(a+12224|0)>>2]|0)+4194304|0;c[(a+12224|0)>>2]=I;if((I|0)==0){c[(a+12224|0)>>2]=4194304;TGb(G|0,0,256)|0;K=c[(a+12224|0)>>2]|0}else{K=I}I=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,c[(a+12352+(l<<4)|0)>>2]|0,c[(a+12416|0)>>2]|0,16)|0;c[G>>2]=K;c[v>>2]=I;if((c[a+9992>>2]|0)==3){if((c[(a+12244|0)>>2]&4|0)==0){L=10}else{L=9}}else{L=9}if((L|0)==9){if((c[a+60>>2]&64|0)==0){M=I}else{L=10}}if((L|0)==10){M=(ba((d[B+F|0]|0)+(d[B+C|0]|0)|0,J)|0)+I|0}do{if((c[(a+14084|0)>>2]|0)==0){do{if((M|0)<(c[(c[a+4>>2]|0)+376>>2]|0)){if((c[j+12>>2]|c[j+8>>2]|c[j+16>>2]|c[j+20>>2]|c[j+24>>2]|c[j+28>>2]|0)!=0){break}c[f>>2]=0;c[h>>2]=0;c[a+12124>>2]=1;N=M;i=q;return N|0}}while(0);I=c[(j+36|0)>>2]|0;O=c[(j+32|0)>>2]|0;P=(O>>1)+K+(I>>1<<11)|0;do{if((c[(G+(((I>>1<<3)+(O>>1)&63)<<2)|0)>>2]|0)==(P|0)){Q=M;R=O;S=I;T=0;U=0}else{V=c[(a+12416|0)>>2]|0;W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V,I>>1)|0)+(O>>1))|0;X=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,W,V,16)|0;c[(G+(((I>>1<<3)+(O>>1)&63)<<2)|0)>>2]=P;c[v+(((I>>1<<3)+(O>>1)&63)<<2)>>2]=X;V=c[(j+32|0)>>2]|0;W=c[(j+36|0)>>2]|0;Y=(ba((d[B+((W>>1<<1)-F)|0]|0)+(d[B+((V>>1<<1)-C)|0]|0)|0,J)|0)+X|0;if((Y|0)>=(M|0)){Q=M;R=V;S=W;T=0;U=0;break}c[(q+8|0)>>2]=V>>1;c[s+4>>2]=W>>1;Q=Y;R=V;S=W;T=V>>1;U=W>>1}}while(0);O=R>>1;I=(S>>1)-1|0;P=(O|0)>(z|0)?z:O;O=(x|0)>(P|0)?x:P;P=(I|0)>(A|0)?A:I;I=(y|0)>(P|0)?y:P;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){Z=Q;_=T;$=U}else{W=c[(a+12416|0)>>2]|0;V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W,I)|0)+O)|0;Y=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,V,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=Y;W=(ba((d[B+((I<<1)-F)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+Y|0;if((W|0)>=(Q|0)){Z=Q;_=T;$=U;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;Z=W;_=O;$=I}}while(0);I=c[(j+32|0)>>2]>>1;O=(c[(j+36|0)>>2]>>1)+1|0;P=(I|0)>(z|0)?z:I;I=(x|0)>(P|0)?x:P;P=(O|0)>(A|0)?A:O;O=(y|0)>(P|0)?y:P;P=I+K+(O<<11)|0;do{if((c[(G+(((O<<3)+I&63)<<2)|0)>>2]|0)==(P|0)){aa=Z;ca=_;da=$}else{W=c[(a+12416|0)>>2]|0;Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W,O)|0)+I)|0;V=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Y,W,16)|0;c[(G+(((O<<3)+I&63)<<2)|0)>>2]=P;c[v+(((O<<3)+I&63)<<2)>>2]=V;W=(ba((d[B+((O<<1)-F)|0]|0)+(d[B+((I<<1)-C)|0]|0)|0,J)|0)+V|0;if((W|0)>=(Z|0)){aa=Z;ca=_;da=$;break}c[(q+8|0)>>2]=I;c[s+4>>2]=O;aa=W;ca=I;da=O}}while(0);O=(c[(j+32|0)>>2]>>1)-1|0;I=c[(j+36|0)>>2]>>1;P=(O|0)>(z|0)?z:O;O=(x|0)>(P|0)?x:P;P=(I|0)>(A|0)?A:I;I=(y|0)>(P|0)?y:P;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){ea=aa;fa=ca;ga=da}else{W=c[(a+12416|0)>>2]|0;V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W,I)|0)+O)|0;Y=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,V,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=Y;W=(ba((d[B+((I<<1)-F)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+Y|0;if((W|0)>=(aa|0)){ea=aa;fa=ca;ga=da;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;ea=W;fa=O;ga=I}}while(0);I=(c[(j+32|0)>>2]>>1)+1|0;O=c[(j+36|0)>>2]>>1;P=(I|0)>(z|0)?z:I;I=(x|0)>(P|0)?x:P;P=(O|0)>(A|0)?A:O;O=(y|0)>(P|0)?y:P;P=I+K+(O<<11)|0;do{if((c[(G+(((O<<3)+I&63)<<2)|0)>>2]|0)==(P|0)){ha=ea;ia=fa;ja=ga}else{W=c[(a+12416|0)>>2]|0;Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W,O)|0)+I)|0;V=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Y,W,16)|0;c[(G+(((O<<3)+I&63)<<2)|0)>>2]=P;c[v+(((O<<3)+I&63)<<2)>>2]=V;W=(ba((d[B+((O<<1)-F)|0]|0)+(d[B+((I<<1)-C)|0]|0)|0,J)|0)+V|0;if((W|0)>=(ea|0)){ha=ea;ia=fa;ja=ga;break}c[(q+8|0)>>2]=I;c[s+4>>2]=O;ha=W;ia=I;ja=O}}while(0);O=(ba(b[m+(u<<2)>>1]|0,n)|0)+32768>>16;I=(ba(b[m+(u<<2)+2>>1]|0,n)|0)+32768>>16;P=(O|0)>(z|0)?z:O;O=(x|0)>(P|0)?x:P;P=(I|0)>(A|0)?A:I;I=(y|0)>(P|0)?y:P;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){ka=ha;la=ia;ma=ja}else{W=c[(a+12416|0)>>2]|0;V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W,I)|0)+O)|0;Y=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,V,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=Y;W=(ba((d[B+((I<<1)-F)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+Y|0;if((W|0)>=(ha|0)){ka=ha;la=ia;ma=ja;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;ka=W;la=O;ma=I}}while(0);I=c[(j+12|0)>>2]>>1;O=c[(j+8|0)>>2]>>1;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){na=ka;oa=la;pa=ma}else{W=c[(a+12416|0)>>2]|0;Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W,I)|0)+O)|0;V=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Y,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=V;W=c[(j+8|0)>>2]>>1;Y=c[(j+12|0)>>2]>>1;X=(ba((d[B+((Y<<1)-F)|0]|0)+(d[B+((W<<1)-C)|0]|0)|0,J)|0)+V|0;if((X|0)>=(ka|0)){na=ka;oa=la;pa=ma;break}c[(q+8|0)>>2]=W;c[s+4>>2]=Y;na=X;oa=W;pa=Y}}while(0);O=c[(j+20|0)>>2]>>1;I=c[(j+16|0)>>2]>>1;P=I+K+(O<<11)|0;do{if((c[(G+(((O<<3)+I&63)<<2)|0)>>2]|0)==(P|0)){qa=na;ra=oa;sa=pa}else{Y=c[(a+12416|0)>>2]|0;W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Y,O)|0)+I)|0;X=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,W,Y,16)|0;c[(G+(((O<<3)+I&63)<<2)|0)>>2]=P;c[v+(((O<<3)+I&63)<<2)>>2]=X;Y=c[(j+16|0)>>2]>>1;W=c[(j+20|0)>>2]>>1;V=(ba((d[B+((W<<1)-F)|0]|0)+(d[B+((Y<<1)-C)|0]|0)|0,J)|0)+X|0;if((V|0)>=(na|0)){qa=na;ra=oa;sa=pa;break}c[(q+8|0)>>2]=Y;c[s+4>>2]=W;qa=V;ra=Y;sa=W}}while(0);I=c[(j+28|0)>>2]>>1;O=c[(j+24|0)>>2]>>1;P=O+K+(I<<11)|0;if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){ta=qa;ua=ra;va=sa;break}W=c[(a+12416|0)>>2]|0;Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W,I)|0)+O)|0;V=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Y,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=V;O=c[(j+24|0)>>2]>>1;I=c[(j+28|0)>>2]>>1;P=(ba((d[B+((I<<1)-F)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+V|0;if((P|0)>=(qa|0)){ta=qa;ua=ra;va=sa;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;ta=P;ua=O;va=I}else{I=c[(j+12|0)>>2]>>1;O=c[(j+8|0)>>2]>>1;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){wa=M;xa=0;ya=0}else{V=c[(a+12416|0)>>2]|0;W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(V,I)|0)+O)|0;Y=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,W,V,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=Y;V=c[(j+8|0)>>2]>>1;W=c[(j+12|0)>>2]>>1;X=(ba((d[B+((W<<1)-F)|0]|0)+(d[B+((V<<1)-C)|0]|0)|0,J)|0)+Y|0;if((X|0)>=(M|0)){wa=M;xa=0;ya=0;break}c[(q+8|0)>>2]=V;c[s+4>>2]=W;wa=X;xa=V;ya=W}}while(0);O=(ba(b[m+(u<<2)>>1]|0,n)|0)+32768>>16;I=(ba(b[m+(u<<2)+2>>1]|0,n)|0)+32768>>16;P=(O|0)>(z|0)?z:O;O=(x|0)>(P|0)?x:P;P=(I|0)>(A|0)?A:I;I=(y|0)>(P|0)?y:P;P=O+K+(I<<11)|0;if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){ta=wa;ua=xa;va=ya;break}W=c[(a+12416|0)>>2]|0;V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(W,I)|0)+O)|0;X=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,V,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=X;P=(ba((d[B+((I<<1)-F)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+X|0;if((P|0)>=(wa|0)){ta=wa;ua=xa;va=ya;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;ta=P;ua=O;va=I}}while(0);do{if((ta|0)>1024){if((c[(a+12256|0)>>2]|0)==0){ya=(ba(b[m+((u+1|0)<<2)>>1]|0,n)|0)+32768>>16;xa=(ba(b[m+((u+1|0)<<2)+2>>1]|0,n)|0)+32768>>16;wa=(ya|0)>(z|0)?z:ya;ya=(x|0)>(wa|0)?x:wa;wa=(xa|0)>(A|0)?A:xa;xa=(y|0)>(wa|0)?y:wa;wa=ya+K+(xa<<11)|0;do{if((c[(G+(((xa<<3)+ya&63)<<2)|0)>>2]|0)==(wa|0)){za=ta;Aa=ua;Ba=va}else{M=c[(a+12416|0)>>2]|0;sa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(M,xa)|0)+ya)|0;ra=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,sa,M,16)|0;c[(G+(((xa<<3)+ya&63)<<2)|0)>>2]=wa;c[v+(((xa<<3)+ya&63)<<2)>>2]=ra;M=(ba((d[B+((xa<<1)-F)|0]|0)+(d[B+((ya<<1)-C)|0]|0)|0,J)|0)+ra|0;if((M|0)>=(ta|0)){za=ta;Aa=ua;Ba=va;break}c[(q+8|0)>>2]=ya;c[s+4>>2]=xa;za=M;Aa=ya;Ba=xa}}while(0);if(((c[(a+12480|0)>>2]|0)+1|0)>=(c[a+812>>2]|0)){Ca=za;Da=Aa;Ea=Ba;break}xa=(ba(b[m+((u+t|0)<<2)>>1]|0,n)|0)+32768>>16;ya=(ba(b[m+((u+t|0)<<2)+2>>1]|0,n)|0)+32768>>16;wa=(xa|0)>(z|0)?z:xa;xa=(x|0)>(wa|0)?x:wa;wa=(ya|0)>(A|0)?A:ya;ya=(y|0)>(wa|0)?y:wa;wa=xa+K+(ya<<11)|0;if((c[(G+(((ya<<3)+xa&63)<<2)|0)>>2]|0)==(wa|0)){Ca=za;Da=Aa;Ea=Ba;break}M=c[(a+12416|0)>>2]|0;ra=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(M,ya)|0)+xa)|0;sa=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,ra,M,16)|0;c[(G+(((ya<<3)+xa&63)<<2)|0)>>2]=wa;c[v+(((ya<<3)+xa&63)<<2)>>2]=sa;wa=(ba((d[B+((ya<<1)-F)|0]|0)+(d[B+((xa<<1)-C)|0]|0)|0,J)|0)+sa|0;if((wa|0)>=(za|0)){Ca=za;Da=Aa;Ea=Ba;break}c[(q+8|0)>>2]=xa;c[s+4>>2]=ya;Ca=wa;Da=xa;Ea=ya;break}else{ya=(ba(b[m+((u-1|0)<<2)>>1]|0,n)|0)+32768>>16;xa=(ba(b[m+((u-1|0)<<2)+2>>1]|0,n)|0)+32768>>16;wa=(ya|0)>(z|0)?z:ya;ya=(x|0)>(wa|0)?x:wa;wa=(xa|0)>(A|0)?A:xa;xa=(y|0)>(wa|0)?y:wa;wa=ya+K+(xa<<11)|0;do{if((c[(G+(((xa<<3)+ya&63)<<2)|0)>>2]|0)==(wa|0)){Fa=ta;Ga=ua;Ha=va}else{sa=c[(a+12416|0)>>2]|0;M=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(sa,xa)|0)+ya)|0;ra=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,M,sa,16)|0;c[(G+(((xa<<3)+ya&63)<<2)|0)>>2]=wa;c[v+(((xa<<3)+ya&63)<<2)>>2]=ra;sa=(ba((d[B+((xa<<1)-F)|0]|0)+(d[B+((ya<<1)-C)|0]|0)|0,J)|0)+ra|0;if((sa|0)>=(ta|0)){Fa=ta;Ga=ua;Ha=va;break}c[(q+8|0)>>2]=ya;c[s+4>>2]=xa;Fa=sa;Ga=ya;Ha=xa}}while(0);if((c[(a+14084|0)>>2]|0)!=0){Ca=Fa;Da=Ga;Ea=Ha;break}xa=(ba(b[m+((u-t|0)<<2)>>1]|0,n)|0)+32768>>16;ya=(ba(b[m+((u-t|0)<<2)+2>>1]|0,n)|0)+32768>>16;wa=(xa|0)>(z|0)?z:xa;xa=(x|0)>(wa|0)?x:wa;wa=(ya|0)>(A|0)?A:ya;ya=(y|0)>(wa|0)?y:wa;wa=xa+K+(ya<<11)|0;if((c[(G+(((ya<<3)+xa&63)<<2)|0)>>2]|0)==(wa|0)){Ca=Fa;Da=Ga;Ea=Ha;break}sa=c[(a+12416|0)>>2]|0;ra=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(sa,ya)|0)+xa)|0;M=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,ra,sa,16)|0;c[(G+(((ya<<3)+xa&63)<<2)|0)>>2]=wa;c[v+(((ya<<3)+xa&63)<<2)>>2]=M;wa=(ba((d[B+((ya<<1)-F)|0]|0)+(d[B+((xa<<1)-C)|0]|0)|0,J)|0)+M|0;if((wa|0)>=(Fa|0)){Ca=Fa;Da=Ga;Ea=Ha;break}c[(q+8|0)>>2]=xa;c[s+4>>2]=ya;Ca=wa;Da=xa;Ea=ya;break}}else{Ca=ta;Da=ua;Ea=va}}while(0);va=c[(c[a+12120>>2]|0)+252>>2]|0;do{if((va|0)==0){Ia=Ca;Ja=Da;Ka=Ea}else{ua=c[(a+12476|0)>>2]|0;ta=(ua-va|0|0)<0?0:ua-va|0;Ha=c[(a+12480|0)>>2]|0;Ga=(Ha-va|0|0)<0?0:Ha-va|0;Fa=c[a+116>>2]|0;u=(Fa|0)>(ua+(va+1|0)|0|0)?ua+(va+1|0)|0:Fa;Fa=c[a+120>>2]|0;ua=(Fa|0)>(Ha+(va+1|0)|0|0)?Ha+(va+1|0)|0:Fa;if((Ga|0)>=(ua|0)){Ia=Ca;Ja=Da;Ka=Ea;break}Fa=Ga;Ga=Ca;Ha=Da;Ba=Ea;while(1){Aa=Fa+1|0;a:do{if((ta|0)<(u|0)){za=ba(Aa,t)|0;ya=ta;xa=Ga;wa=Ha;M=Ba;while(1){sa=ya;b:while(1){La=sa+1|0;Ma=(ba(b[m+((La+za|0)<<2)>>1]|0,n)|0)+32768>>16;Na=(ba(b[m+((La+za|0)<<2)+2>>1]|0,n)|0)+32768>>16;do{if(!((Ma|0)>(z|0)|(Ma|0)<(x|0)|(Na|0)>(A|0)|(Na|0)<(y|0))){ra=Ma+K+(Na<<11)|0;if((c[(G+(((Na<<3)+Ma&63)<<2)|0)>>2]|0)==(ra|0)){break}qa=c[(a+12416|0)>>2]|0;pa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(qa,Na)|0)+Ma)|0;oa=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,pa,qa,16)|0;c[(G+(((Na<<3)+Ma&63)<<2)|0)>>2]=ra;c[v+(((Na<<3)+Ma&63)<<2)>>2]=oa;Oa=(ba((d[B+((Na<<1)-F)|0]|0)+(d[B+((Ma<<1)-C)|0]|0)|0,J)|0)+oa|0;if((Oa|0)<(xa|0)){break b}}}while(0);if((La|0)<(u|0)){sa=La}else{Pa=xa;Qa=wa;Ra=M;break a}}c[(q+8|0)>>2]=Ma;c[(s+4|0)>>2]=Na;if((La|0)<(u|0)){ya=La;xa=Oa;wa=Ma;M=Na}else{Pa=Oa;Qa=Ma;Ra=Na;break}}}else{Pa=Ga;Qa=Ha;Ra=Ba}}while(0);if((Aa|0)<(ua|0)){Fa=Aa;Ga=Pa;Ha=Qa;Ba=Ra}else{Ia=Pa;Ja=Qa;Ka=Ra;break}}}}while(0);Ra=q+8|0;Qa=c[(a+12260|0)>>2]|0;c:do{if((Qa|0)==-1){Pa=c[(a+12220|0)>>2]|0;Na=c[(a+12264|0)>>2]|0;Ma=c[(a+12272|0)>>2]|0;Oa=c[(a+12268|0)>>2]|0;La=c[(a+12276|0)>>2]|0;C=c[(a+12464|0)>>2]|0;B=c[(a+12280|0)>>2]|0;F=c[(a+12284|0)>>2]|0;v=c[(a+12216|0)>>2]|0;G=c[(a+12224|0)>>2]|0;H=c[a+10468>>2]|0;K=Ia;y=Ka;A=Ja;d:while(1){x=1;z=K;t=y;Ea=A;while(1){do{if((x-1&x|0)==0){Da=x+A|0;if((Da|0)>(Oa|0)){Sa=z;Ta=t;Ua=Ea;break}Ca=A-x|0;if((Ca|0)<(Na|0)){Sa=z;Ta=t;Ua=Ea;break}va=x+y|0;if((va|0)>(La|0)){Sa=z;Ta=t;Ua=Ea;break}Ba=y-x|0;if((Ba|0)<(Ma|0)){Sa=z;Ta=t;Ua=Ea;break}else{Va=0;Wa=z;Xa=t;Ya=Ea}while(1){Ha=va-Va|0;Ga=Va+A|0;do{if((c[(v+(((Ha<<3)+Ga&63)<<2)|0)>>2]|0)==(Ga+G+(Ha<<11)|0|0)){Za=Wa;_a=Xa;$a=Ya}else{Fa=c[(a+12416|0)>>2]|0;ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Fa,Ha)|0)+Ga)|0;u=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,ua,Fa,16)|0;c[(v+(((Ha<<3)+Ga&63)<<2)|0)>>2]=Ga+G+(Ha<<11)|0;c[Pa+(((Ha<<3)+Ga&63)<<2)>>2]=u;Fa=(ba((d[C+((Ha<<1)-F)|0]|0)+(d[C+((Ga<<1)-B)|0]|0)|0,J)|0)+u|0;if((Fa|0)>=(Wa|0)){Za=Wa;_a=Xa;$a=Ya;break}c[Ra>>2]=Ga;c[(Ra+4|0)>>2]=Ha;Za=Fa;_a=Ha;$a=Ga}}while(0);Ga=y-Va|0;Ha=Da-Va|0;do{if((c[(v+(((Ga<<3)+Ha&63)<<2)|0)>>2]|0)==(Ha+G+(Ga<<11)|0|0)){ab=Za;bb=_a;cb=$a}else{Fa=c[(a+12416|0)>>2]|0;u=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Fa,Ga)|0)+Ha)|0;ua=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,u,Fa,16)|0;c[(v+(((Ga<<3)+Ha&63)<<2)|0)>>2]=Ha+G+(Ga<<11)|0;c[Pa+(((Ga<<3)+Ha&63)<<2)>>2]=ua;Fa=(ba((d[C+((Ga<<1)-F)|0]|0)+(d[C+((Ha<<1)-B)|0]|0)|0,J)|0)+ua|0;if((Fa|0)>=(Za|0)){ab=Za;bb=_a;cb=$a;break}c[Ra>>2]=Ha;c[(Ra+4|0)>>2]=Ga;ab=Fa;bb=Ga;cb=Ha}}while(0);Ha=Va+Ba|0;Ga=A-Va|0;do{if((c[(v+(((Ha<<3)+Ga&63)<<2)|0)>>2]|0)==(Ga+G+(Ha<<11)|0|0)){db=ab;eb=bb;fb=cb}else{Fa=c[(a+12416|0)>>2]|0;ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Fa,Ha)|0)+Ga)|0;u=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,ua,Fa,16)|0;c[(v+(((Ha<<3)+Ga&63)<<2)|0)>>2]=Ga+G+(Ha<<11)|0;c[Pa+(((Ha<<3)+Ga&63)<<2)>>2]=u;Fa=(ba((d[C+((Ha<<1)-F)|0]|0)+(d[C+((Ga<<1)-B)|0]|0)|0,J)|0)+u|0;if((Fa|0)>=(ab|0)){db=ab;eb=bb;fb=cb;break}c[Ra>>2]=Ga;c[(Ra+4|0)>>2]=Ha;db=Fa;eb=Ha;fb=Ga}}while(0);Ga=Va+y|0;Ha=Va+Ca|0;do{if((c[(v+(((Ga<<3)+Ha&63)<<2)|0)>>2]|0)==(Ha+G+(Ga<<11)|0|0)){gb=db;hb=eb;ib=fb}else{Fa=c[(a+12416|0)>>2]|0;u=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Fa,Ga)|0)+Ha)|0;ua=Pe[H&255](a,c[(a+12288+(k<<4)|0)>>2]|0,u,Fa,16)|0;c[(v+(((Ga<<3)+Ha&63)<<2)|0)>>2]=Ha+G+(Ga<<11)|0;c[Pa+(((Ga<<3)+Ha&63)<<2)>>2]=ua;Fa=(ba((d[C+((Ga<<1)-F)|0]|0)+(d[C+((Ha<<1)-B)|0]|0)|0,J)|0)+ua|0;if((Fa|0)>=(db|0)){gb=db;hb=eb;ib=fb;break}c[Ra>>2]=Ha;c[(Ra+4|0)>>2]=Ga;gb=Fa;hb=Ga;ib=Ha}}while(0);Ha=Va+2|0;if((Ha|0)<(x|0)){Va=Ha;Wa=gb;Xa=hb;Ya=ib}else{break}}if((A|0)!=(ib|0)){K=gb;y=hb;A=ib;continue d}if((y|0)==(hb|0)){Sa=gb;Ta=y;Ua=A}else{K=gb;y=hb;A=A;continue d}}else{Sa=z;Ta=t;Ua=Ea}}while(0);Ca=x+1|0;if((Ca|0)<5){x=Ca;z=Sa;t=Ta;Ea=Ua}else{jb=Sa;break c}}}}else{if((Qa|0)<-1){jb=Fmb(a,Ra,k,l,J,0,16,0)|0;break}if((Qa|0)<2){A=c[(a+12220|0)>>2]|0;y=c[(a+12264|0)>>2]|0;K=c[(a+12272|0)>>2]|0;B=c[(a+12268|0)>>2]|0;C=c[(a+12276|0)>>2]|0;F=c[(a+12464|0)>>2]|0;Pa=c[(a+12280|0)>>2]|0;G=c[(a+12284|0)>>2]|0;v=c[(a+12216|0)>>2]|0;H=c[(a+12224|0)>>2]|0;Ma=c[a+10468>>2]|0;La=(Ka<<11)+Ja+H|0;Na=(Ka<<3)+Ja&63;if((c[(v+(Na<<2)|0)>>2]|0)==(La|0)){kb=Ia;lb=-1;mb=Ja;nb=Ka}else{Oa=c[(a+12416|0)>>2]|0;Ea=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Oa,Ka)|0)+Ja)|0;c[A+(Na<<2)>>2]=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Ea,Oa,16)|0;c[(v+(Na<<2)|0)>>2]=La;kb=Ia;lb=-1;mb=Ja;nb=Ka}while(1){La=(mb|0)>(y|0);Na=mb-1|0;Oa=mb+H|0;Ea=F+((mb<<1)-Pa)|0;t=(mb|0)<(B|0);z=mb+1|0;x=kb;Aa=lb;Ca=nb;while(1){do{if((Aa|0)!=2&La){Ba=(Ca<<11)+H+Na|0;Da=Na+(Ca<<3)&63;if((c[(v+(Da<<2)|0)>>2]|0)==(Ba|0)){ob=x;pb=-1;qb=mb;break}va=c[(a+12416|0)>>2]|0;Ha=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(va,Ca)|0)+Na)|0;Ga=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Ha,va,16)|0;c[(v+(Da<<2)|0)>>2]=Ba;c[A+(Da<<2)>>2]=Ga;Da=(ba((d[F+((Ca<<1)-G)|0]|0)+(d[F+((Na<<1)-Pa)|0]|0)|0,J)|0)+Ga|0;if((Da|0)>=(x|0)){ob=x;pb=-1;qb=mb;break}c[Ra>>2]=Na;c[(Ra+4|0)>>2]=Ca;ob=Da;pb=0;qb=Na}else{ob=x;pb=-1;qb=mb}}while(0);do{if((Aa|0)!=3&(Ca|0)>(K|0)){Da=Ca-1|0;Ga=(Da<<3)+mb&63;if((c[(v+(Ga<<2)|0)>>2]|0)==(Oa+(Da<<11)|0|0)){rb=ob;sb=pb;tb=qb;ub=Ca;break}Ba=c[(a+12416|0)>>2]|0;va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ba,Da)|0)+mb)|0;Ha=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,va,Ba,16)|0;c[(v+(Ga<<2)|0)>>2]=Oa+(Da<<11)|0;c[A+(Ga<<2)>>2]=Ha;Ga=(ba((d[F+((Da<<1)-G)|0]|0)+(d[Ea]|0)|0,J)|0)+Ha|0;if((Ga|0)>=(ob|0)){rb=ob;sb=pb;tb=qb;ub=Ca;break}c[Ra>>2]=mb;c[(Ra+4|0)>>2]=Da;rb=Ga;sb=1;tb=mb;ub=Da}else{rb=ob;sb=pb;tb=qb;ub=Ca}}while(0);do{if((Aa|0)!=0&t){Da=(Ca<<11)+H+z|0;Ga=z+(Ca<<3)&63;if((c[(v+(Ga<<2)|0)>>2]|0)==(Da|0)){vb=rb;wb=sb;xb=tb;yb=ub;break}Ha=c[(a+12416|0)>>2]|0;Ba=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ha,Ca)|0)+z)|0;va=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Ba,Ha,16)|0;c[(v+(Ga<<2)|0)>>2]=Da;c[A+(Ga<<2)>>2]=va;Ga=(ba((d[F+((Ca<<1)-G)|0]|0)+(d[F+((z<<1)-Pa)|0]|0)|0,J)|0)+va|0;if((Ga|0)>=(rb|0)){vb=rb;wb=sb;xb=tb;yb=ub;break}c[Ra>>2]=z;c[(Ra+4|0)>>2]=Ca;vb=Ga;wb=2;xb=z;yb=Ca}else{vb=rb;wb=sb;xb=tb;yb=ub}}while(0);if(!((Aa|0)!=1&(Ca|0)<(C|0))){break}Ga=Ca+1|0;va=(Ga<<3)+mb&63;if((c[(v+(va<<2)|0)>>2]|0)==(Oa+(Ga<<11)|0|0)){break}Da=c[(a+12416|0)>>2]|0;Ha=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Da,Ga)|0)+mb)|0;Ba=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Ha,Da,16)|0;c[(v+(va<<2)|0)>>2]=Oa+(Ga<<11)|0;c[A+(va<<2)>>2]=Ba;va=(ba((d[F+((Ga<<1)-G)|0]|0)+(d[Ea]|0)|0,J)|0)+Ba|0;if((va|0)>=(vb|0)){break}c[Ra>>2]=mb;c[(Ra+4|0)>>2]=Ga;x=va;Aa=3;Ca=Ga}if((wb|0)==-1){jb=vb;break c}else{kb=vb;lb=wb;mb=xb;nb=yb}}}if((Qa|0)>1024){jb=Gmb(a,Ra,Ia,k,l,J,0,16,0)|0;break}if((Qa|0)>768){G=c[(a+12220|0)>>2]|0;F=c[(a+12264|0)>>2]|0;A=c[(a+12272|0)>>2]|0;v=c[(a+12268|0)>>2]|0;Ma=c[(a+12276|0)>>2]|0;C=c[(a+12464|0)>>2]|0;Pa=c[(a+12280|0)>>2]|0;H=c[(a+12284|0)>>2]|0;K=c[(a+12216|0)>>2]|0;B=c[(a+12224|0)>>2]|0;y=c[a+10468>>2]|0;Ca=Ja-(Qa&254)+1|0;Aa=(Ca|0)>(F|0)?Ca:F;Ca=Ja-1+(Qa&254)|0;x=(Ca|0)>(v|0)?v:Ca;if((Aa|0)>(x|0)){zb=Ia;Ab=Ja;Bb=Ka}else{Ca=B+(Ka<<11)|0;Ea=Ka<<3;Oa=C+((Ka<<1)-H)|0;z=Aa;Aa=Ia;t=Ja;Na=Ka;while(1){La=Ca+z|0;Ga=z+Ea&63;do{if((c[(K+(Ga<<2)|0)>>2]|0)==(La|0)){Cb=Aa;Db=t;Eb=Na}else{va=c[(a+12416|0)>>2]|0;Ba=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(va,Ka)|0)+z)|0;Da=Pe[y&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Ba,va,16)|0;c[(K+(Ga<<2)|0)>>2]=La;c[G+(Ga<<2)>>2]=Da;va=(ba((d[Oa]|0)+(d[C+((z<<1)-Pa)|0]|0)|0,J)|0)+Da|0;if((va|0)>=(Aa|0)){Cb=Aa;Db=t;Eb=Na;break}c[Ra>>2]=z;c[(Ra+4|0)>>2]=Ka;Cb=va;Db=z;Eb=Ka}}while(0);Ga=z+2|0;if((Ga|0)>(x|0)){zb=Cb;Ab=Db;Bb=Eb;break}else{z=Ga;Aa=Cb;t=Db;Na=Eb}}}Na=Ka-((Qa&254)>>>1)+1|0;t=(Na|0)>(A|0)?Na:A;Na=Ka-1+((Qa&254)>>>1)|0;Aa=(Na|0)>(Ma|0)?Ma:Na;if((t|0)>(Aa|0)){Fb=zb;Gb=Ab;Hb=Bb}else{Na=B+Ja|0;z=C+((Ja<<1)-Pa)|0;x=t;t=zb;Oa=Ab;Ea=Bb;while(1){Ca=Na+(x<<11)|0;Ga=(x<<3)+Ja&63;do{if((c[(K+(Ga<<2)|0)>>2]|0)==(Ca|0)){Ib=t;Jb=Oa;Kb=Ea}else{La=c[(a+12416|0)>>2]|0;va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(La,x)|0)+Ja)|0;Da=Pe[y&255](a,c[(a+12288+(k<<4)|0)>>2]|0,va,La,16)|0;c[(K+(Ga<<2)|0)>>2]=Ca;c[G+(Ga<<2)>>2]=Da;La=(ba((d[C+((x<<1)-H)|0]|0)+(d[z]|0)|0,J)|0)+Da|0;if((La|0)>=(t|0)){Ib=t;Jb=Oa;Kb=Ea;break}c[Ra>>2]=Ja;c[(Ra+4|0)>>2]=x;Ib=La;Jb=Ja;Kb=x}}while(0);Ga=x+2|0;if((Ga|0)>(Aa|0)){Fb=Ib;Gb=Jb;Hb=Kb;break}else{x=Ga;t=Ib;Oa=Jb;Ea=Kb}}}Ea=Hb-2|0;Oa=(Ea|0)>(A|0)?Ea:A;Ea=Hb+2|0;t=(Ea|0)>(Ma|0)?Ma:Ea;if((Oa|0)>(t|0)){Lb=Fb}else{Ea=Gb-2|0;x=(Ea|0)>(F|0)?Ea:F;Ea=Gb+2|0;Aa=(Ea|0)>(v|0)?v:Ea;Ea=Oa;Oa=Fb;while(1){if((x|0)>(Aa|0)){Mb=Oa}else{z=(Ea<<11)+B|0;Na=Ea<<3;Ga=C+((Ea<<1)-H)|0;Ca=x;La=Oa;while(1){Da=z+Ca|0;va=Ca+Na&63;do{if((c[(K+(va<<2)|0)>>2]|0)==(Da|0)){Nb=La}else{Ba=c[(a+12416|0)>>2]|0;Ha=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ba,Ea)|0)+Ca)|0;Fa=Pe[y&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Ha,Ba,16)|0;c[(K+(va<<2)|0)>>2]=Da;c[G+(va<<2)>>2]=Fa;Ba=(ba((d[Ga]|0)+(d[C+((Ca<<1)-Pa)|0]|0)|0,J)|0)+Fa|0;if((Ba|0)>=(La|0)){Nb=La;break}c[Ra>>2]=Ca;c[(Ra+4|0)>>2]=Ea;Nb=Ba}}while(0);va=Ca+1|0;if((va|0)>(Aa|0)){Mb=Nb;break}else{Ca=va;La=Nb}}}La=Ea+1|0;if((La|0)>(t|0)){Lb=Mb;break}else{Ea=La;Oa=Mb}}}if(((Qa&254)>>>2|0)==0){Ob=Lb}else{Oa=1;Ea=Lb;while(1){t=0;Aa=Ea;while(1){x=(ba(c[163152+(t<<3)>>2]|0,Oa)|0)+Gb|0;La=(ba(c[163156+(t<<3)>>2]|0,Oa)|0)+Hb|0;Ca=(x|0)>(v|0)?v:x;x=(F|0)>(Ca|0)?F:Ca;Ca=(La|0)>(Ma|0)?Ma:La;La=(A|0)>(Ca|0)?A:Ca;do{if((c[(K+(((La<<3)+x&63)<<2)|0)>>2]|0)==(x+B+(La<<11)|0|0)){Pb=Aa}else{Ca=c[(a+12416|0)>>2]|0;Ga=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ca,La)|0)+x)|0;Na=Pe[y&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Ga,Ca,16)|0;c[(K+(((La<<3)+x&63)<<2)|0)>>2]=x+B+(La<<11)|0;c[G+(((La<<3)+x&63)<<2)>>2]=Na;Ca=(ba((d[C+((La<<1)-H)|0]|0)+(d[C+((x<<1)-Pa)|0]|0)|0,J)|0)+Na|0;if((Ca|0)>=(Aa|0)){Pb=Aa;break}c[Ra>>2]=x;c[(Ra+4|0)>>2]=La;Pb=Ca}}while(0);La=t+1|0;if((La|0)<16){t=La;Aa=Pb}else{break}}Aa=Oa+1|0;if((Aa|0)>((Qa&254)>>>2|0)){Ob=Pb;break}else{Oa=Aa;Ea=Pb}}}jb=Hmb(a,Ra,Ob,k,l,J,0,16,0,2)|0;break}if((Qa|0)>512){jb=Hmb(a,Ra,Ia,k,l,J,0,16,0,Qa&255)|0;break}Ea=c[(a+12220|0)>>2]|0;Oa=c[(a+12264|0)>>2]|0;Pa=c[(a+12272|0)>>2]|0;C=c[(a+12268|0)>>2]|0;H=c[(a+12276|0)>>2]|0;G=c[(a+12464|0)>>2]|0;B=c[(a+12280|0)>>2]|0;K=c[(a+12284|0)>>2]|0;y=c[(a+12216|0)>>2]|0;A=c[(a+12224|0)>>2]|0;if((Qa|0)>256){Ma=c[a+10468>>2]|0;if((Qa&255|0)==0){Qb=Ia;Rb=Ja;Sb=Ka;Tb=Ra+4|0}else{F=Qa&255;v=Ia;Aa=Ka;t=Ja;while(1){La=v;x=Aa;Ca=t;while(1){Na=0;Ga=La;z=x;va=Ca;while(1){Da=(ba(c[862288+(Na<<3)>>2]|0,F)|0)+Ca|0;Ba=(ba(c[862292+(Na<<3)>>2]|0,F)|0)+x|0;Fa=(Da|0)>(C|0)?C:Da;Da=(Oa|0)>(Fa|0)?Oa:Fa;Fa=(Ba|0)>(H|0)?H:Ba;Ba=(Pa|0)>(Fa|0)?Pa:Fa;do{if((c[(y+(((Ba<<3)+Da&63)<<2)|0)>>2]|0)==(Da+A+(Ba<<11)|0|0)){Ub=Ga;Vb=z;Wb=va}else{Fa=c[(a+12416|0)>>2]|0;Ha=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Fa,Ba)|0)+Da)|0;ua=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Ha,Fa,16)|0;c[(y+(((Ba<<3)+Da&63)<<2)|0)>>2]=Da+A+(Ba<<11)|0;c[Ea+(((Ba<<3)+Da&63)<<2)>>2]=ua;Fa=(ba((d[G+((Ba<<1)-K)|0]|0)+(d[G+((Da<<1)-B)|0]|0)|0,J)|0)+ua|0;if((Fa|0)>=(Ga|0)){Ub=Ga;Vb=z;Wb=va;break}c[Ra>>2]=Da;c[(Ra+4|0)>>2]=Ba;Ub=Fa;Vb=Ba;Wb=Da}}while(0);Da=Na+1|0;if((Da|0)<8){Na=Da;Ga=Ub;z=Vb;va=Wb}else{break}}if((Wb|0)==(Ca|0)&(Vb|0)==(x|0)){break}else{La=Ub;x=Vb;Ca=Wb}}La=(Qa+255&(Qa&255)|0)!=0?F-1|0:F>>1;if((La|0)==0){Qb=Ub;Rb=Ca;Sb=x;Tb=Ra+4|0;break}else{F=La;v=Ub;Aa=x;t=Ca}}}t=Rb+1|0;Aa=(t|0)>(C|0)?C:t;t=(Oa|0)>(Aa|0)?Oa:Aa;Aa=(Sb|0)>(H|0)?H:Sb;v=(Pa|0)>(Aa|0)?Pa:Aa;do{if((c[(y+((t+(v<<3)&63)<<2)|0)>>2]|0)==(((v<<11)+A|0)+t|0|0)){Xb=Qb}else{Aa=c[(a+12416|0)>>2]|0;F=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Aa,v)|0)+t)|0;La=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,F,Aa,16)|0;c[(y+((t+(v<<3)&63)<<2)|0)>>2]=((v<<11)+A|0)+t|0;c[Ea+((t+(v<<3)&63)<<2)>>2]=La;Aa=(ba((d[G+((v<<1)-K)|0]|0)+(d[G+((t<<1)-B)|0]|0)|0,J)|0)+La|0;if((Aa|0)>=(Qb|0)){Xb=Qb;break}c[Ra>>2]=t;c[Tb>>2]=v;Xb=Aa}}while(0);t=Sb+1|0;Aa=(Rb|0)>(C|0)?C:Rb;La=(Oa|0)>(Aa|0)?Oa:Aa;Aa=(t|0)>(H|0)?H:t;t=(Pa|0)>(Aa|0)?Pa:Aa;do{if((c[(y+(((t<<3)+La&63)<<2)|0)>>2]|0)==((La+A|0)+(t<<11)|0|0)){Yb=Xb}else{Aa=c[(a+12416|0)>>2]|0;F=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Aa,t)|0)+La)|0;va=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,F,Aa,16)|0;c[(y+(((t<<3)+La&63)<<2)|0)>>2]=(La+A|0)+(t<<11)|0;c[Ea+(((t<<3)+La&63)<<2)>>2]=va;Aa=(ba((d[G+((t<<1)-K)|0]|0)+(d[G+((La<<1)-B)|0]|0)|0,J)|0)+va|0;if((Aa|0)>=(Xb|0)){Yb=Xb;break}c[Ra>>2]=La;c[Tb>>2]=t;Yb=Aa}}while(0);t=Rb-1|0;Aa=(t|0)>(C|0)?C:t;t=(Oa|0)>(Aa|0)?Oa:Aa;do{if((c[(y+((t+(v<<3)&63)<<2)|0)>>2]|0)==(((v<<11)+A|0)+t|0|0)){Zb=Yb}else{Aa=c[(a+12416|0)>>2]|0;va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Aa,v)|0)+t)|0;F=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,va,Aa,16)|0;c[(y+((t+(v<<3)&63)<<2)|0)>>2]=((v<<11)+A|0)+t|0;c[Ea+((t+(v<<3)&63)<<2)>>2]=F;Aa=(ba((d[G+((v<<1)-K)|0]|0)+(d[G+((t<<1)-B)|0]|0)|0,J)|0)+F|0;if((Aa|0)>=(Yb|0)){Zb=Yb;break}c[Ra>>2]=t;c[Tb>>2]=v;Zb=Aa}}while(0);v=Sb-1|0;t=(v|0)>(H|0)?H:v;v=(Pa|0)>(t|0)?Pa:t;if((c[(y+(((v<<3)+La&63)<<2)|0)>>2]|0)==((La+A|0)+(v<<11)|0|0)){jb=Zb;break}t=c[(a+12416|0)>>2]|0;Aa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(t,v)|0)+La)|0;F=Pe[Ma&255](a,c[(a+12288+(k<<4)|0)>>2]|0,Aa,t,16)|0;c[(y+(((v<<3)+La&63)<<2)|0)>>2]=(La+A|0)+(v<<11)|0;c[Ea+(((v<<3)+La&63)<<2)>>2]=F;t=(ba((d[G+((v<<1)-K)|0]|0)+(d[G+((La<<1)-B)|0]|0)|0,J)|0)+F|0;if((t|0)>=(Zb|0)){jb=Zb;break}c[Ra>>2]=La;c[Tb>>2]=v;jb=t;break}t=c[a+10468>>2]|0;v=1;F=Ia;Aa=Ja;va=Ka;while(1){z=v+va|0;Ga=(z-H|0|0)<0?0:z-H|0;Na=C-Aa+1|0;Da=(v|0)>(Na|0)?Na:v;if((Ga|0)<(Da|0)){Na=Ga;Ga=F;Ba=va;Fa=Aa;while(1){ua=z-Na|0;Ha=Na+Aa|0;do{if((c[(y+(((ua<<3)+Ha&63)<<2)|0)>>2]|0)==(Ha+A+(ua<<11)|0|0)){_b=Ga;$b=Ba;ac=Fa}else{u=c[(a+12416|0)>>2]|0;ta=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(u,ua)|0)+Ha)|0;M=Pe[t&255](a,c[(a+12288+(k<<4)|0)>>2]|0,ta,u,16)|0;c[(y+(((ua<<3)+Ha&63)<<2)|0)>>2]=Ha+A+(ua<<11)|0;c[Ea+(((ua<<3)+Ha&63)<<2)>>2]=M;u=(ba((d[G+((ua<<1)-K)|0]|0)+(d[G+((Ha<<1)-B)|0]|0)|0,J)|0)+M|0;if((u|0)>=(Ga|0)){_b=Ga;$b=Ba;ac=Fa;break}c[Ra>>2]=Ha;c[(Ra+4|0)>>2]=ua;_b=u;$b=ua;ac=Ha}}while(0);Ha=Na+1|0;if((Ha|0)<(Da|0)){Na=Ha;Ga=_b;Ba=$b;Fa=ac}else{bc=_b;cc=$b;dc=ac;break}}}else{bc=F;cc=va;dc=Aa}Fa=v+Aa|0;Ba=(Fa-C|0|0)<0?0:Fa-C|0;Ga=va-Pa+1|0;Na=(v|0)>(Ga|0)?Ga:v;if((Ba|0)<(Na|0)){Ga=Ba;Ba=bc;Da=cc;z=dc;while(1){Ca=va-Ga|0;x=Fa-Ga|0;do{if((c[(y+(((Ca<<3)+x&63)<<2)|0)>>2]|0)==(x+A+(Ca<<11)|0|0)){ec=Ba;fc=Da;gc=z}else{Ha=c[(a+12416|0)>>2]|0;ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ha,Ca)|0)+x)|0;u=Pe[t&255](a,c[(a+12288+(k<<4)|0)>>2]|0,ua,Ha,16)|0;c[(y+(((Ca<<3)+x&63)<<2)|0)>>2]=x+A+(Ca<<11)|0;c[Ea+(((Ca<<3)+x&63)<<2)>>2]=u;Ha=(ba((d[G+((Ca<<1)-K)|0]|0)+(d[G+((x<<1)-B)|0]|0)|0,J)|0)+u|0;if((Ha|0)>=(Ba|0)){ec=Ba;fc=Da;gc=z;break}c[Ra>>2]=x;c[(Ra+4|0)>>2]=Ca;ec=Ha;fc=Ca;gc=x}}while(0);x=Ga+1|0;if((x|0)<(Na|0)){Ga=x;Ba=ec;Da=fc;z=gc}else{hc=ec;ic=fc;jc=gc;break}}}else{hc=bc;ic=cc;jc=dc}z=v-va+Pa|0;Da=(z|0)<0?0:z;z=Aa-Oa+1|0;Ba=(v|0)>(z|0)?z:v;if((Da|0)<(Ba|0)){z=va-v|0;Ga=Da;Da=hc;Na=ic;Fa=jc;while(1){x=Ga+z|0;Ca=Aa-Ga|0;do{if((c[(y+(((x<<3)+Ca&63)<<2)|0)>>2]|0)==(Ca+A+(x<<11)|0|0)){kc=Da;lc=Na;mc=Fa}else{Ha=c[(a+12416|0)>>2]|0;u=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ha,x)|0)+Ca)|0;ua=Pe[t&255](a,c[(a+12288+(k<<4)|0)>>2]|0,u,Ha,16)|0;c[(y+(((x<<3)+Ca&63)<<2)|0)>>2]=Ca+A+(x<<11)|0;c[Ea+(((x<<3)+Ca&63)<<2)>>2]=ua;Ha=(ba((d[G+((x<<1)-K)|0]|0)+(d[G+((Ca<<1)-B)|0]|0)|0,J)|0)+ua|0;if((Ha|0)>=(Da|0)){kc=Da;lc=Na;mc=Fa;break}c[Ra>>2]=Ca;c[(Ra+4|0)>>2]=x;kc=Ha;lc=x;mc=Ca}}while(0);Ca=Ga+1|0;if((Ca|0)<(Ba|0)){Ga=Ca;Da=kc;Na=lc;Fa=mc}else{nc=kc;oc=lc;pc=mc;break}}}else{nc=hc;oc=ic;pc=jc}Fa=v-Aa+Oa|0;Na=(Fa|0)<0?0:Fa;Fa=H-va+1|0;Da=(v|0)>(Fa|0)?Fa:v;if((Na|0)<(Da|0)){Fa=Aa-v|0;Ga=Na;Na=nc;Ba=oc;z=pc;while(1){Ca=Ga+va|0;x=Ga+Fa|0;do{if((c[(y+(((Ca<<3)+x&63)<<2)|0)>>2]|0)==(x+A+(Ca<<11)|0|0)){qc=Na;rc=Ba;sc=z}else{Ha=c[(a+12416|0)>>2]|0;ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ha,Ca)|0)+x)|0;u=Pe[t&255](a,c[(a+12288+(k<<4)|0)>>2]|0,ua,Ha,16)|0;c[(y+(((Ca<<3)+x&63)<<2)|0)>>2]=x+A+(Ca<<11)|0;c[Ea+(((Ca<<3)+x&63)<<2)>>2]=u;Ha=(ba((d[G+((Ca<<1)-K)|0]|0)+(d[G+((x<<1)-B)|0]|0)|0,J)|0)+u|0;if((Ha|0)>=(Na|0)){qc=Na;rc=Ba;sc=z;break}c[Ra>>2]=x;c[(Ra+4|0)>>2]=Ca;qc=Ha;rc=Ca;sc=x}}while(0);x=Ga+1|0;if((x|0)<(Da|0)){Ga=x;Na=qc;Ba=rc;z=sc}else{tc=qc;uc=rc;vc=sc;break}}}else{tc=nc;uc=oc;vc=pc}z=(Aa|0)==(vc|0)&(va|0)==(uc|0);Ba=z?v+1|0:1;if((Ba|0)>(c[(a+12260|0)>>2]|0)){jb=tc;break}else{v=Ba;F=tc;Aa=vc;va=z?va:uc}}}}while(0);c[f>>2]=c[Ra>>2];c[h>>2]=c[s+4>>2];N=jb;i=q;return N|0}jb=q|0;c[(q|0)>>2]=0;c[(q|0)+4>>2]=0;s=c[a+124>>2]|0;Ra=(ba(c[(a+12480|0)>>2]|0,s)|0)+(c[(a+12476|0)>>2]|0)|0;uc=c[(a+12220|0)>>2]|0;vc=c[(a+12264|0)>>2]|0;tc=c[(a+12272|0)>>2]|0;pc=c[(a+12268|0)>>2]|0;oc=c[(a+12276|0)>>2]|0;nc=c[(a+12464|0)>>2]|0;sc=c[(a+12280|0)>>2]|0;rc=c[(a+12284|0)>>2]|0;qc=c[(a+12216|0)>>2]|0;J=(r&1)+1|0;if((c[(a+12256|0)>>2]|0)==0){wc=a+12232|0;xc=a+10468+(o<<2)|0;yc=a+10468+(o+1<<2)|0}else{wc=a+12228|0;xc=a+10444+(o<<2)|0;yc=a+10444+(o+1<<2)|0}jc=c[wc>>2]|0;wc=c[xc>>2]|0;xc=c[yc>>2]|0;yc=(c[(a+12224|0)>>2]|0)+4194304|0;c[(a+12224|0)>>2]=yc;if((yc|0)==0){c[(a+12224|0)>>2]=4194304;TGb(qc|0,0,256)|0;zc=c[(a+12224|0)>>2]|0}else{zc=yc}do{if((r&4|0)==0){yc=c[a+12416>>2]|0;ic=c[a+12420>>2]|0;hc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,c[a+12352+(l<<4)>>2]|0,yc,p)|0;if((r&2|0)==0){Ac=hc;break}mc=c[a+12208>>2]|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)>>2]&1023](mc+(yc<<4)|0,c[a+12352+(l<<4)+4>>2]|0,ic,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)>>2]&1023](mc+(yc<<4|8)|0,c[a+12352+(l<<4)+8>>2]|0,ic,p>>1);lc=(Pe[xc&255](a,mc+(yc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ic,p>>1)|0)+hc|0;Ac=lc+(Pe[xc&255](a,mc+(yc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ic,p>>1)|0)|0}else{ic=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>0){Ac=536870912;break}if((c[(a+12268|0)>>2]<<J|0)<0){Ac=536870912;break}if((c[(a+12272|0)>>2]|0)>0){Ac=536870912;break}if((c[(a+12276|0)>>2]<<J|0)<0){Ac=536870912;break}yc=e[a+13872>>1]|0;mc=e[a+13874>>1]|0;lc=(r&1)<<1|1;do{if((c[a+11740>>2]|0)==1){hc=0;do{kc=c[a+12160+(hc<<3)>>2]|0;dc=c[a+12160+(hc<<3)+4>>2]|0;cc=((ba(c[a+12128+(hc<<3)>>2]|0,mc-yc|0)|0)/(yc|0)|0)+((hc&1)<<(r&1|4))|0;bc=hc>>1;gc=((ba(c[a+12128+(hc<<3)+4>>2]|0,mc-yc|0)|0)/(yc|0)|0)+(bc<<(r&1|4))|0;fc=(c[(a+12208|0)>>2]|0)+((ba(ic<<3,bc)|0)+(hc<<3&8))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(dc>>1,ic)|0)+(kc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((dc&lc)<<J)+(kc&lc)|0)<<2)>>2]&1023](fc,bc,ic,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(gc>>1,ic)|0)+(cc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((gc&lc)<<J)+(cc&lc)|0)<<2)>>2]&1023](fc,bc,ic,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(dc>>2,ic)|0)+(kc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((dc&lc)<<J)+(kc&lc)|0)<<2)>>2]&4095](fc,bc,ic);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(gc>>2,ic)|0)+(cc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((gc&lc)<<J)+(cc&lc)|0)<<2)>>2]&4095](fc,bc,ic)}hc=hc+1|0;}while((hc|0)<4)}else{hc=c[a+12160>>2]|0;bc=c[a+12164>>2]|0;fc=(ba(c[a+12128>>2]|0,mc-yc|0)|0)/(yc|0)|0;cc=(ba(c[a+12132>>2]|0,mc-yc|0)|0)/(yc|0)|0;if((r&1|0)==0){gc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,ic)|0)+(hc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,gc,ic,16);gc=(c[a+12352+(l<<4)+32>>2]|0)+((ba(cc>>1,ic)|0)+(fc>>1))|0;cf[c[(c[a+12448>>2]|0)+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,gc,ic,16);break}else{gc=(ba(bc>>2,ic)|0)+(hc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+gc|0,ic);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(gc+8|0)|0,ic);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ic<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(gc+(ic<<3))|0,ic);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ic<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((gc+8|0)+(ic<<3))|0,ic);gc=(ba(cc>>2,ic)|0)+(fc>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+gc|0,ic);Xe[c[(c[(a+12456|0)>>2]|0)+64+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(gc+8|0)|0,ic);Xe[c[(c[(a+12456|0)>>2]|0)+64+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ic<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(gc+(ic<<3))|0,ic);Xe[c[(c[(a+12456|0)>>2]|0)+64+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ic<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((gc+8|0)+(ic<<3))|0,ic);break}}}while(0);Ac=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ic,16)|0}}while(0);c[qc>>2]=zc;c[uc>>2]=Ac;if((c[a+9992>>2]|0)==3){if((c[(a+12244|0)>>2]&4|0)==0){L=231}else{L=230}}else{L=230}if((L|0)==230){if((c[a+60>>2]&64|0)==0){Bc=Ac}else{L=231}}if((L|0)==231){Bc=(ba((d[nc+rc|0]|0)+(d[nc+sc|0]|0)|0,jc)|0)+Ac|0}do{Ac=1;if(Ac){Ac=0;if((c[(a+14084|0)>>2]|0)==0){L=ba(p,p)|0;do{if((Bc|0)<((ba(L,c[(c[a+4>>2]|0)+376>>2]|0)|0)>>8|0)){if((c[j+12>>2]|c[j+8>>2]|c[j+16>>2]|c[j+20>>2]|c[j+24>>2]|c[j+28>>2]|0)!=0){break}c[f>>2]=0;c[h>>2]=0;c[a+12124>>2]=1;N=Bc;i=q;return N|0}}while(0);L=c[(j+36|0)>>2]|0;ic=c[(j+32|0)>>2]|0;lc=(ic>>J)+zc+(L>>J<<11)|0;do{if((c[(qc+(((L>>J<<3)+(ic>>J)&63)<<2)|0)>>2]|0)==(lc|0)){Cc=Bc;Dc=ic;Ec=L;Fc=0;Gc=0}else{do{if((r&4|0)==0){yc=c[a+12416>>2]|0;mc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba(yc,L>>J)|0)+(ic>>J))|0;fc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,yc,p)|0;if((r&2|0)==0){Hc=fc;break}gc=c[a+12208>>2]|0;cc=(ba(mc,L>>J>>1)|0)+(ic>>J>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L>>J<<1&2|ic>>J&1)<<2)>>2]&1023](gc+(yc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+cc|0,mc,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L>>J<<1&2|ic>>J&1)<<2)>>2]&1023](gc+(yc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+cc|0,mc,p>>1);cc=(Pe[xc&255](a,gc+(yc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,mc,p>>1)|0)+fc|0;Hc=cc+(Pe[xc&255](a,gc+(yc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,mc,p>>1)|0)|0}else{mc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic>>J|0)){Hc=536870912;break}if((ic>>J<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Hc=536870912;break}if((c[(a+12272|0)>>2]|0)>(L>>J|0)){Hc=536870912;break}if((L>>J<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Hc=536870912;break}yc=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;cc=(r&1)<<1|1;e:do{if((c[a+11740>>2]|0)==1){if((ic>>J<<J|0)==0){fc=0;while(1){hc=c[a+12160+(fc<<3)>>2]|0;bc=(c[a+12160+(fc<<3)+4>>2]|0)+(L>>J<<J)|0;kc=((ba(c[a+12128+(fc<<3)>>2]|0,gc-yc|0)|0)/(yc|0)|0)+((fc&1)<<(r&1|4))|0;dc=c[a+12128+(fc<<3)+4>>2]|0;if((L>>J<<J|0)==0){ec=fc>>1;Ic=((ba(dc,gc-yc|0)|0)/(yc|0)|0)+(ec<<(r&1|4))|0;Jc=ec}else{Ic=bc-dc|0;Jc=fc>>1}dc=((Ic&cc)<<J)+(kc&cc)|0;ec=(c[(a+12208|0)>>2]|0)+((ba(Jc,mc<<3)|0)+(fc<<3&8))|0;if((r&1|0)==0){ac=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,mc)|0)+(hc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&1023](ec,ac,mc,8);ac=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ic>>1,mc)|0)+(kc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(dc<<2)>>2]&1023](ec,ac,mc,8)}else{ac=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>2,mc)|0)+(hc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&4095](ec,ac,mc);ac=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ic>>2,mc)|0)+(kc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](ec,ac,mc)}fc=fc+1|0;if((fc|0)>=4){break e}}}if((L>>J<<J|0)==0){fc=0;do{ac=(c[a+12160+(fc<<3)>>2]|0)+(ic>>J<<J)|0;ec=c[a+12160+(fc<<3)+4>>2]|0;dc=ac-(c[a+12128+(fc<<3)>>2]|0)|0;kc=fc>>1;hc=((ba(c[a+12128+(fc<<3)+4>>2]|0,gc-yc|0)|0)/(yc|0)|0)+(kc<<(r&1|4))|0;bc=(c[(a+12208|0)>>2]|0)+((fc<<3&8)+(ba(kc,mc<<3)|0))|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ec>>1,mc)|0)+(ac>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ec&cc)<<J)+(ac&cc)|0)<<2)>>2]&1023](bc,kc,mc,8);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(hc>>1,mc)|0)+(dc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((hc&cc)<<J)+(dc&cc)|0)<<2)>>2]&1023](bc,kc,mc,8)}else{kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ec>>2,mc)|0)+(ac>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(ac&cc)|0)<<2)>>2]&4095](bc,kc,mc);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(hc>>2,mc)|0)+(dc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((hc&cc)<<J)+(dc&cc)|0)<<2)>>2]&4095](bc,kc,mc)}fc=fc+1|0;}while((fc|0)<4)}else{fc=0;do{kc=(c[a+12160+(fc<<3)>>2]|0)+(ic>>J<<J)|0;bc=(c[a+12160+(fc<<3)+4>>2]|0)+(L>>J<<J)|0;dc=kc-(c[a+12128+(fc<<3)>>2]|0)|0;hc=bc-(c[a+12128+(fc<<3)+4>>2]|0)|0;ac=(c[(a+12208|0)>>2]|0)+((fc<<3&8)+(ba(fc>>1,mc<<3)|0))|0;if((r&1|0)==0){ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,mc)|0)+(kc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&cc)<<J)+(kc&cc)|0)<<2)>>2]&1023](ac,ec,mc,8);ec=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(hc>>1,mc)|0)+(dc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((hc&cc)<<J)+(dc&cc)|0)<<2)>>2]&1023](ac,ec,mc,8)}else{ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>2,mc)|0)+(kc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&cc)<<J)+(kc&cc)|0)<<2)>>2]&4095](ac,ec,mc);ec=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(hc>>2,mc)|0)+(dc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((hc&cc)<<J)+(dc&cc)|0)<<2)>>2]&4095](ac,ec,mc)}fc=fc+1|0;}while((fc|0)<4)}}else{fc=(c[a+12160>>2]|0)+(ic>>J<<J)|0;ec=(c[a+12164>>2]|0)+(L>>J<<J)|0;ac=c[a+12128>>2]|0;if((ic>>J<<J|0)==0){Kc=(ba(ac,gc-yc|0)|0)/(yc|0)|0}else{Kc=fc-ac|0}ac=c[a+12132>>2]|0;if((L>>J<<J|0)==0){Lc=(ba(ac,gc-yc|0)|0)/(yc|0)|0}else{Lc=ec-ac|0}ac=((Lc&cc)<<J)+(Kc&cc)|0;if((r&1|0)==0){dc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ec>>1,mc)|0)+(fc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,dc,mc,16);dc=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Lc>>1,mc)|0)+(Kc>>1))|0;cf[c[(c[a+12448>>2]|0)+(ac<<2)>>2]&1023](c[(a+12208|0)>>2]|0,dc,mc,16);break}else{dc=(ba(ec>>2,mc)|0)+(fc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+dc|0,mc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(dc+8|0)|0,mc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(mc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(dc+(mc<<3))|0,mc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((mc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((dc+8|0)+(mc<<3))|0,mc);dc=(ba(Lc>>2,mc)|0)+(Kc>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+dc|0,mc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(dc+8|0)|0,mc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(mc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(dc+(mc<<3))|0,mc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((mc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((dc+8|0)+(mc<<3))|0,mc);break}}}while(0);Hc=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,mc,16)|0}}while(0);c[(qc+(((L>>J<<3)+(ic>>J)&63)<<2)|0)>>2]=lc;c[uc+(((L>>J<<3)+(ic>>J)&63)<<2)>>2]=Hc;cc=c[(j+32|0)>>2]|0;yc=c[(j+36|0)>>2]|0;gc=(ba((d[nc+((yc>>J<<J)-rc)|0]|0)+(d[nc+((cc>>J<<J)-sc)|0]|0)|0,jc)|0)+Hc|0;if((gc|0)>=(Bc|0)){Cc=Bc;Dc=cc;Ec=yc;Fc=0;Gc=0;break}c[(q|0)>>2]=cc>>J;c[jb+4>>2]=yc>>J;Cc=gc;Dc=cc;Ec=yc;Fc=cc>>J;Gc=yc>>J}}while(0);ic=Dc>>J;L=(Ec>>J)-1|0;lc=(ic|0)>(pc|0)?pc:ic;ic=(vc|0)>(lc|0)?vc:lc;lc=(L|0)>(oc|0)?oc:L;L=(tc|0)>(lc|0)?tc:lc;lc=ic+zc+(L<<11)|0;do{if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){Mc=Cc;Nc=Fc;Oc=Gc}else{do{if((r&4|0)==0){yc=c[a+12416>>2]|0;cc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba(yc,L)|0)+ic)|0;dc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,yc,p)|0;if((r&2|0)==0){Pc=dc;break}gc=c[a+12208>>2]|0;ac=(ba(cc,L>>1)|0)+(ic>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+(yc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ac|0,cc,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+(yc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ac|0,cc,p>>1);ac=(Pe[xc&255](a,gc+(yc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,cc,p>>1)|0)+dc|0;Pc=ac+(Pe[xc&255](a,gc+(yc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,cc,p>>1)|0)|0}else{cc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){Pc=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Pc=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Pc=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Pc=536870912;break}yc=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;ac=(r&1)<<1|1;f:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){dc=0;while(1){fc=c[a+12160+(dc<<3)>>2]|0;ec=(c[a+12160+(dc<<3)+4>>2]|0)+(L<<J)|0;hc=((ba(c[a+12128+(dc<<3)>>2]|0,gc-yc|0)|0)/(yc|0)|0)+((dc&1)<<(r&1|4))|0;kc=c[a+12128+(dc<<3)+4>>2]|0;if((L<<J|0)==0){bc=dc>>1;Qc=((ba(kc,gc-yc|0)|0)/(yc|0)|0)+(bc<<(r&1|4))|0;Rc=bc}else{Qc=ec-kc|0;Rc=dc>>1}kc=((Qc&ac)<<J)+(hc&ac)|0;bc=(c[(a+12208|0)>>2]|0)+((ba(Rc,cc<<3)|0)+(dc<<3&8))|0;if((r&1|0)==0){$b=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ec>>1,cc)|0)+(fc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ec&ac)<<J)+(fc&ac)|0)<<2)>>2]&1023](bc,$b,cc,8);$b=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Qc>>1,cc)|0)+(hc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(kc<<2)>>2]&1023](bc,$b,cc,8)}else{$b=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ec>>2,cc)|0)+(fc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ec&ac)<<J)+(fc&ac)|0)<<2)>>2]&4095](bc,$b,cc);$b=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Qc>>2,cc)|0)+(hc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095](bc,$b,cc)}dc=dc+1|0;if((dc|0)>=4){break f}}}if((L<<J|0)==0){dc=0;do{$b=(c[a+12160+(dc<<3)>>2]|0)+(ic<<J)|0;bc=c[a+12160+(dc<<3)+4>>2]|0;kc=$b-(c[a+12128+(dc<<3)>>2]|0)|0;hc=dc>>1;fc=((ba(c[a+12128+(dc<<3)+4>>2]|0,gc-yc|0)|0)/(yc|0)|0)+(hc<<(r&1|4))|0;ec=(c[(a+12208|0)>>2]|0)+((dc<<3&8)+(ba(hc,cc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,cc)|0)+($b>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&ac)<<J)+($b&ac)|0)<<2)>>2]&1023](ec,hc,cc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(fc>>1,cc)|0)+(kc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((fc&ac)<<J)+(kc&ac)|0)<<2)>>2]&1023](ec,hc,cc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>2,cc)|0)+($b>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+($b&ac)|0)<<2)>>2]&4095](ec,hc,cc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(fc>>2,cc)|0)+(kc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((fc&ac)<<J)+(kc&ac)|0)<<2)>>2]&4095](ec,hc,cc)}dc=dc+1|0;}while((dc|0)<4)}else{dc=0;do{hc=(c[a+12160+(dc<<3)>>2]|0)+(ic<<J)|0;ec=(c[a+12160+(dc<<3)+4>>2]|0)+(L<<J)|0;kc=hc-(c[a+12128+(dc<<3)>>2]|0)|0;fc=ec-(c[a+12128+(dc<<3)+4>>2]|0)|0;$b=(c[(a+12208|0)>>2]|0)+((dc<<3&8)+(ba(dc>>1,cc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ec>>1,cc)|0)+(hc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ec&ac)<<J)+(hc&ac)|0)<<2)>>2]&1023]($b,bc,cc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(fc>>1,cc)|0)+(kc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((fc&ac)<<J)+(kc&ac)|0)<<2)>>2]&1023]($b,bc,cc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ec>>2,cc)|0)+(hc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ec&ac)<<J)+(hc&ac)|0)<<2)>>2]&4095]($b,bc,cc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(fc>>2,cc)|0)+(kc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((fc&ac)<<J)+(kc&ac)|0)<<2)>>2]&4095]($b,bc,cc)}dc=dc+1|0;}while((dc|0)<4)}}else{dc=(c[a+12160>>2]|0)+(ic<<J)|0;bc=(c[a+12164>>2]|0)+(L<<J)|0;$b=c[a+12128>>2]|0;if((ic<<J|0)==0){Sc=(ba($b,gc-yc|0)|0)/(yc|0)|0}else{Sc=dc-$b|0}$b=c[a+12132>>2]|0;if((L<<J|0)==0){Tc=(ba($b,gc-yc|0)|0)/(yc|0)|0}else{Tc=bc-$b|0}$b=((Tc&ac)<<J)+(Sc&ac)|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,cc)|0)+(dc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,kc,cc,16);kc=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Tc>>1,cc)|0)+(Sc>>1))|0;cf[c[(c[a+12448>>2]|0)+($b<<2)>>2]&1023](c[(a+12208|0)>>2]|0,kc,cc,16);break}else{kc=(ba(bc>>2,cc)|0)+(dc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+kc|0,cc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kc+8|0)|0,cc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(cc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kc+(cc<<3))|0,cc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((cc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((kc+8|0)+(cc<<3))|0,cc);kc=(ba(Tc>>2,cc)|0)+(Sc>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+kc|0,cc);Xe[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kc+8|0)|0,cc);Xe[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(cc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kc+(cc<<3))|0,cc);Xe[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((cc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((kc+8|0)+(cc<<3))|0,cc);break}}}while(0);Pc=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,cc,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=Pc;ac=(ba((d[nc+((L<<J)-rc)|0]|0)+(d[nc+((ic<<J)-sc)|0]|0)|0,jc)|0)+Pc|0;if((ac|0)>=(Cc|0)){Mc=Cc;Nc=Fc;Oc=Gc;break}c[(q|0)>>2]=ic;c[jb+4>>2]=L;Mc=ac;Nc=ic;Oc=L}}while(0);L=c[(j+32|0)>>2]>>J;ic=(c[(j+36|0)>>2]>>J)+1|0;lc=(L|0)>(pc|0)?pc:L;L=(vc|0)>(lc|0)?vc:lc;lc=(ic|0)>(oc|0)?oc:ic;ic=(tc|0)>(lc|0)?tc:lc;lc=L+zc+(ic<<11)|0;do{if((c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]|0)==(lc|0)){Uc=Mc;Vc=Nc;Wc=Oc}else{do{if((r&4|0)==0){ac=c[a+12416>>2]|0;yc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba(ac,ic)|0)+L)|0;mc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,ac,p)|0;if((r&2|0)==0){Xc=mc;break}gc=c[a+12208>>2]|0;kc=(ba(yc,ic>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&1023](gc+(ac<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+kc|0,yc,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&1023](gc+(ac<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+kc|0,yc,p>>1);kc=(Pe[xc&255](a,gc+(ac<<4)|0,c[a+12288+(k<<4)+4>>2]|0,yc,p>>1)|0)+mc|0;Xc=kc+(Pe[xc&255](a,gc+(ac<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,yc,p>>1)|0)|0}else{yc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Xc=536870912;break}if((L<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Xc=536870912;break}if((c[(a+12272|0)>>2]|0)>(ic|0)){Xc=536870912;break}if((ic<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Xc=536870912;break}ac=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;kc=(r&1)<<1|1;g:do{if((c[a+11740>>2]|0)==1){if((L<<J|0)==0){mc=0;while(1){$b=c[a+12160+(mc<<3)>>2]|0;dc=(c[a+12160+(mc<<3)+4>>2]|0)+(ic<<J)|0;bc=((ba(c[a+12128+(mc<<3)>>2]|0,gc-ac|0)|0)/(ac|0)|0)+((mc&1)<<(r&1|4))|0;fc=c[a+12128+(mc<<3)+4>>2]|0;if((ic<<J|0)==0){hc=mc>>1;Yc=((ba(fc,gc-ac|0)|0)/(ac|0)|0)+(hc<<(r&1|4))|0;Zc=hc}else{Yc=dc-fc|0;Zc=mc>>1}fc=((Yc&kc)<<J)+(bc&kc)|0;hc=(c[(a+12208|0)>>2]|0)+((ba(Zc,yc<<3)|0)+(mc<<3&8))|0;if((r&1|0)==0){ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(dc>>1,yc)|0)+($b>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((dc&kc)<<J)+($b&kc)|0)<<2)>>2]&1023](hc,ec,yc,8);ec=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Yc>>1,yc)|0)+(bc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(fc<<2)>>2]&1023](hc,ec,yc,8)}else{ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(dc>>2,yc)|0)+($b>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((dc&kc)<<J)+($b&kc)|0)<<2)>>2]&4095](hc,ec,yc);ec=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Yc>>2,yc)|0)+(bc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(fc<<2)>>2]&4095](hc,ec,yc)}mc=mc+1|0;if((mc|0)>=4){break g}}}if((ic<<J|0)==0){mc=0;do{ec=(c[a+12160+(mc<<3)>>2]|0)+(L<<J)|0;hc=c[a+12160+(mc<<3)+4>>2]|0;fc=ec-(c[a+12128+(mc<<3)>>2]|0)|0;bc=mc>>1;$b=((ba(c[a+12128+(mc<<3)+4>>2]|0,gc-ac|0)|0)/(ac|0)|0)+(bc<<(r&1|4))|0;dc=(c[(a+12208|0)>>2]|0)+((mc<<3&8)+(ba(bc,yc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>1,yc)|0)+(ec>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((hc&kc)<<J)+(ec&kc)|0)<<2)>>2]&1023](dc,bc,yc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($b>>1,yc)|0)+(fc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(((($b&kc)<<J)+(fc&kc)|0)<<2)>>2]&1023](dc,bc,yc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>2,yc)|0)+(ec>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(ec&kc)|0)<<2)>>2]&4095](dc,bc,yc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($b>>2,yc)|0)+(fc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(((($b&kc)<<J)+(fc&kc)|0)<<2)>>2]&4095](dc,bc,yc)}mc=mc+1|0;}while((mc|0)<4)}else{mc=0;do{bc=(c[a+12160+(mc<<3)>>2]|0)+(L<<J)|0;dc=(c[a+12160+(mc<<3)+4>>2]|0)+(ic<<J)|0;fc=bc-(c[a+12128+(mc<<3)>>2]|0)|0;$b=dc-(c[a+12128+(mc<<3)+4>>2]|0)|0;ec=(c[(a+12208|0)>>2]|0)+((mc<<3&8)+(ba(mc>>1,yc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(dc>>1,yc)|0)+(bc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((dc&kc)<<J)+(bc&kc)|0)<<2)>>2]&1023](ec,hc,yc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($b>>1,yc)|0)+(fc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(((($b&kc)<<J)+(fc&kc)|0)<<2)>>2]&1023](ec,hc,yc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(dc>>2,yc)|0)+(bc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((dc&kc)<<J)+(bc&kc)|0)<<2)>>2]&4095](ec,hc,yc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba($b>>2,yc)|0)+(fc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(((($b&kc)<<J)+(fc&kc)|0)<<2)>>2]&4095](ec,hc,yc)}mc=mc+1|0;}while((mc|0)<4)}}else{mc=(c[a+12160>>2]|0)+(L<<J)|0;hc=(c[a+12164>>2]|0)+(ic<<J)|0;ec=c[a+12128>>2]|0;if((L<<J|0)==0){_c=(ba(ec,gc-ac|0)|0)/(ac|0)|0}else{_c=mc-ec|0}ec=c[a+12132>>2]|0;if((ic<<J|0)==0){$c=(ba(ec,gc-ac|0)|0)/(ac|0)|0}else{$c=hc-ec|0}ec=(($c&kc)<<J)+(_c&kc)|0;if((r&1|0)==0){fc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>1,yc)|0)+(mc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,fc,yc,16);fc=(c[a+12352+(l<<4)+32>>2]|0)+((ba($c>>1,yc)|0)+(_c>>1))|0;cf[c[(c[a+12448>>2]|0)+(ec<<2)>>2]&1023](c[(a+12208|0)>>2]|0,fc,yc,16);break}else{fc=(ba(hc>>2,yc)|0)+(mc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+fc|0,yc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(fc+8|0)|0,yc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(yc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(fc+(yc<<3))|0,yc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((yc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((fc+8|0)+(yc<<3))|0,yc);fc=(ba($c>>2,yc)|0)+(_c>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+fc|0,yc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(fc+8|0)|0,yc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(yc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(fc+(yc<<3))|0,yc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((yc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((fc+8|0)+(yc<<3))|0,yc);break}}}while(0);Xc=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,yc,16)|0}}while(0);c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]=lc;c[uc+(((ic<<3)+L&63)<<2)>>2]=Xc;kc=(ba((d[nc+((ic<<J)-rc)|0]|0)+(d[nc+((L<<J)-sc)|0]|0)|0,jc)|0)+Xc|0;if((kc|0)>=(Mc|0)){Uc=Mc;Vc=Nc;Wc=Oc;break}c[(q|0)>>2]=L;c[jb+4>>2]=ic;Uc=kc;Vc=L;Wc=ic}}while(0);ic=(c[(j+32|0)>>2]>>J)-1|0;L=c[(j+36|0)>>2]>>J;lc=(ic|0)>(pc|0)?pc:ic;ic=(vc|0)>(lc|0)?vc:lc;lc=(L|0)>(oc|0)?oc:L;L=(tc|0)>(lc|0)?tc:lc;lc=ic+zc+(L<<11)|0;do{if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){ad=Uc;bd=Vc;cd=Wc}else{do{if((r&4|0)==0){kc=c[a+12416>>2]|0;ac=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba(kc,L)|0)+ic)|0;cc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,kc,p)|0;if((r&2|0)==0){dd=cc;break}gc=c[a+12208>>2]|0;fc=(ba(ac,L>>1)|0)+(ic>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+(kc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+fc|0,ac,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+(kc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+fc|0,ac,p>>1);fc=(Pe[xc&255](a,gc+(kc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ac,p>>1)|0)+cc|0;dd=fc+(Pe[xc&255](a,gc+(kc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ac,p>>1)|0)|0}else{ac=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){dd=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){dd=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){dd=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){dd=536870912;break}kc=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;fc=(r&1)<<1|1;h:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){cc=0;while(1){ec=c[a+12160+(cc<<3)>>2]|0;mc=(c[a+12160+(cc<<3)+4>>2]|0)+(L<<J)|0;hc=((ba(c[a+12128+(cc<<3)>>2]|0,gc-kc|0)|0)/(kc|0)|0)+((cc&1)<<(r&1|4))|0;$b=c[a+12128+(cc<<3)+4>>2]|0;if((L<<J|0)==0){bc=cc>>1;ed=((ba($b,gc-kc|0)|0)/(kc|0)|0)+(bc<<(r&1|4))|0;fd=bc}else{ed=mc-$b|0;fd=cc>>1}$b=((ed&fc)<<J)+(hc&fc)|0;bc=(c[(a+12208|0)>>2]|0)+((ba(fd,ac<<3)|0)+(cc<<3&8))|0;if((r&1|0)==0){dc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mc>>1,ac)|0)+(ec>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((mc&fc)<<J)+(ec&fc)|0)<<2)>>2]&1023](bc,dc,ac,8);dc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ed>>1,ac)|0)+(hc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+($b<<2)>>2]&1023](bc,dc,ac,8)}else{dc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mc>>2,ac)|0)+(ec>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((mc&fc)<<J)+(ec&fc)|0)<<2)>>2]&4095](bc,dc,ac);dc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ed>>2,ac)|0)+(hc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095](bc,dc,ac)}cc=cc+1|0;if((cc|0)>=4){break h}}}if((L<<J|0)==0){cc=0;do{dc=(c[a+12160+(cc<<3)>>2]|0)+(ic<<J)|0;bc=c[a+12160+(cc<<3)+4>>2]|0;$b=dc-(c[a+12128+(cc<<3)>>2]|0)|0;hc=cc>>1;ec=((ba(c[a+12128+(cc<<3)+4>>2]|0,gc-kc|0)|0)/(kc|0)|0)+(hc<<(r&1|4))|0;mc=(c[(a+12208|0)>>2]|0)+((cc<<3&8)+(ba(hc,ac<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,ac)|0)+(dc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&fc)<<J)+(dc&fc)|0)<<2)>>2]&1023](mc,hc,ac,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ec>>1,ac)|0)+($b>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ec&fc)<<J)+($b&fc)|0)<<2)>>2]&1023](mc,hc,ac,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>2,ac)|0)+(dc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(dc&fc)|0)<<2)>>2]&4095](mc,hc,ac);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ec>>2,ac)|0)+($b>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ec&fc)<<J)+($b&fc)|0)<<2)>>2]&4095](mc,hc,ac)}cc=cc+1|0;}while((cc|0)<4)}else{cc=0;do{hc=(c[a+12160+(cc<<3)>>2]|0)+(ic<<J)|0;mc=(c[a+12160+(cc<<3)+4>>2]|0)+(L<<J)|0;$b=hc-(c[a+12128+(cc<<3)>>2]|0)|0;ec=mc-(c[a+12128+(cc<<3)+4>>2]|0)|0;dc=(c[(a+12208|0)>>2]|0)+((cc<<3&8)+(ba(cc>>1,ac<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mc>>1,ac)|0)+(hc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((mc&fc)<<J)+(hc&fc)|0)<<2)>>2]&1023](dc,bc,ac,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ec>>1,ac)|0)+($b>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ec&fc)<<J)+($b&fc)|0)<<2)>>2]&1023](dc,bc,ac,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(mc>>2,ac)|0)+(hc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((mc&fc)<<J)+(hc&fc)|0)<<2)>>2]&4095](dc,bc,ac);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ec>>2,ac)|0)+($b>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ec&fc)<<J)+($b&fc)|0)<<2)>>2]&4095](dc,bc,ac)}cc=cc+1|0;}while((cc|0)<4)}}else{cc=(c[a+12160>>2]|0)+(ic<<J)|0;bc=(c[a+12164>>2]|0)+(L<<J)|0;dc=c[a+12128>>2]|0;if((ic<<J|0)==0){gd=(ba(dc,gc-kc|0)|0)/(kc|0)|0}else{gd=cc-dc|0}dc=c[a+12132>>2]|0;if((L<<J|0)==0){hd=(ba(dc,gc-kc|0)|0)/(kc|0)|0}else{hd=bc-dc|0}dc=((hd&fc)<<J)+(gd&fc)|0;if((r&1|0)==0){$b=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,ac)|0)+(cc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,$b,ac,16);$b=(c[a+12352+(l<<4)+32>>2]|0)+((ba(hd>>1,ac)|0)+(gd>>1))|0;cf[c[(c[a+12448>>2]|0)+(dc<<2)>>2]&1023](c[(a+12208|0)>>2]|0,$b,ac,16);break}else{$b=(ba(bc>>2,ac)|0)+(cc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+$b|0,ac);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($b+8|0)|0,ac);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ac<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($b+(ac<<3))|0,ac);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ac<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(($b+8|0)+(ac<<3))|0,ac);$b=(ba(hd>>2,ac)|0)+(gd>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+$b|0,ac);Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($b+8|0)|0,ac);Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ac<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($b+(ac<<3))|0,ac);Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ac<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(($b+8|0)+(ac<<3))|0,ac);break}}}while(0);dd=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ac,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=dd;fc=(ba((d[nc+((L<<J)-rc)|0]|0)+(d[nc+((ic<<J)-sc)|0]|0)|0,jc)|0)+dd|0;if((fc|0)>=(Uc|0)){ad=Uc;bd=Vc;cd=Wc;break}c[(q|0)>>2]=ic;c[jb+4>>2]=L;ad=fc;bd=ic;cd=L}}while(0);L=(c[(j+32|0)>>2]>>J)+1|0;ic=c[(j+36|0)>>2]>>J;lc=(L|0)>(pc|0)?pc:L;L=(vc|0)>(lc|0)?vc:lc;lc=(ic|0)>(oc|0)?oc:ic;ic=(tc|0)>(lc|0)?tc:lc;lc=L+zc+(ic<<11)|0;do{if((c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]|0)==(lc|0)){id=ad;jd=bd;kd=cd}else{do{if((r&4|0)==0){fc=c[a+12416>>2]|0;kc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba(fc,ic)|0)+L)|0;yc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,fc,p)|0;if((r&2|0)==0){ld=yc;break}gc=c[a+12208>>2]|0;$b=(ba(kc,ic>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&1023](gc+(fc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+$b|0,kc,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&1023](gc+(fc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+$b|0,kc,p>>1);$b=(Pe[xc&255](a,gc+(fc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,kc,p>>1)|0)+yc|0;ld=$b+(Pe[xc&255](a,gc+(fc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,kc,p>>1)|0)|0}else{kc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){ld=536870912;break}if((L<<J|0)>(c[(a+12268|0)>>2]<<J|0)){ld=536870912;break}if((c[(a+12272|0)>>2]|0)>(ic|0)){ld=536870912;break}if((ic<<J|0)>(c[(a+12276|0)>>2]<<J|0)){ld=536870912;break}fc=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;$b=(r&1)<<1|1;i:do{if((c[a+11740>>2]|0)==1){if((L<<J|0)==0){yc=0;while(1){dc=c[a+12160+(yc<<3)>>2]|0;cc=(c[a+12160+(yc<<3)+4>>2]|0)+(ic<<J)|0;bc=((ba(c[a+12128+(yc<<3)>>2]|0,gc-fc|0)|0)/(fc|0)|0)+((yc&1)<<(r&1|4))|0;ec=c[a+12128+(yc<<3)+4>>2]|0;if((ic<<J|0)==0){hc=yc>>1;md=((ba(ec,gc-fc|0)|0)/(fc|0)|0)+(hc<<(r&1|4))|0;nd=hc}else{md=cc-ec|0;nd=yc>>1}ec=((md&$b)<<J)+(bc&$b)|0;hc=(c[(a+12208|0)>>2]|0)+((ba(nd,kc<<3)|0)+(yc<<3&8))|0;if((r&1|0)==0){mc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(cc>>1,kc)|0)+(dc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((cc&$b)<<J)+(dc&$b)|0)<<2)>>2]&1023](hc,mc,kc,8);mc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(md>>1,kc)|0)+(bc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(ec<<2)>>2]&1023](hc,mc,kc,8)}else{mc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(cc>>2,kc)|0)+(dc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((cc&$b)<<J)+(dc&$b)|0)<<2)>>2]&4095](hc,mc,kc);mc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(md>>2,kc)|0)+(bc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095](hc,mc,kc)}yc=yc+1|0;if((yc|0)>=4){break i}}}if((ic<<J|0)==0){yc=0;do{mc=(c[a+12160+(yc<<3)>>2]|0)+(L<<J)|0;hc=c[a+12160+(yc<<3)+4>>2]|0;ec=mc-(c[a+12128+(yc<<3)>>2]|0)|0;bc=yc>>1;dc=((ba(c[a+12128+(yc<<3)+4>>2]|0,gc-fc|0)|0)/(fc|0)|0)+(bc<<(r&1|4))|0;cc=(c[(a+12208|0)>>2]|0)+((yc<<3&8)+(ba(bc,kc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>1,kc)|0)+(mc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((hc&$b)<<J)+(mc&$b)|0)<<2)>>2]&1023](cc,bc,kc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(dc>>1,kc)|0)+(ec>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((dc&$b)<<J)+(ec&$b)|0)<<2)>>2]&1023](cc,bc,kc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>2,kc)|0)+(mc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(mc&$b)|0)<<2)>>2]&4095](cc,bc,kc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(dc>>2,kc)|0)+(ec>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((dc&$b)<<J)+(ec&$b)|0)<<2)>>2]&4095](cc,bc,kc)}yc=yc+1|0;}while((yc|0)<4)}else{yc=0;do{bc=(c[a+12160+(yc<<3)>>2]|0)+(L<<J)|0;cc=(c[a+12160+(yc<<3)+4>>2]|0)+(ic<<J)|0;ec=bc-(c[a+12128+(yc<<3)>>2]|0)|0;dc=cc-(c[a+12128+(yc<<3)+4>>2]|0)|0;mc=(c[(a+12208|0)>>2]|0)+((yc<<3&8)+(ba(yc>>1,kc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(cc>>1,kc)|0)+(bc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((cc&$b)<<J)+(bc&$b)|0)<<2)>>2]&1023](mc,hc,kc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(dc>>1,kc)|0)+(ec>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((dc&$b)<<J)+(ec&$b)|0)<<2)>>2]&1023](mc,hc,kc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(cc>>2,kc)|0)+(bc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((cc&$b)<<J)+(bc&$b)|0)<<2)>>2]&4095](mc,hc,kc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(dc>>2,kc)|0)+(ec>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((dc&$b)<<J)+(ec&$b)|0)<<2)>>2]&4095](mc,hc,kc)}yc=yc+1|0;}while((yc|0)<4)}}else{yc=(c[a+12160>>2]|0)+(L<<J)|0;hc=(c[a+12164>>2]|0)+(ic<<J)|0;mc=c[a+12128>>2]|0;if((L<<J|0)==0){od=(ba(mc,gc-fc|0)|0)/(fc|0)|0}else{od=yc-mc|0}mc=c[a+12132>>2]|0;if((ic<<J|0)==0){pd=(ba(mc,gc-fc|0)|0)/(fc|0)|0}else{pd=hc-mc|0}mc=((pd&$b)<<J)+(od&$b)|0;if((r&1|0)==0){ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>1,kc)|0)+(yc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ec,kc,16);ec=(c[a+12352+(l<<4)+32>>2]|0)+((ba(pd>>1,kc)|0)+(od>>1))|0;cf[c[(c[a+12448>>2]|0)+(mc<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ec,kc,16);break}else{ec=(ba(hc>>2,kc)|0)+(yc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ec|0,kc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ec+8|0)|0,kc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(kc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ec+(kc<<3))|0,kc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((kc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ec+8|0)+(kc<<3))|0,kc);ec=(ba(pd>>2,kc)|0)+(od>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ec|0,kc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ec+8|0)|0,kc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(kc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ec+(kc<<3))|0,kc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((kc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ec+8|0)+(kc<<3))|0,kc);break}}}while(0);ld=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,kc,16)|0}}while(0);c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]=lc;c[uc+(((ic<<3)+L&63)<<2)>>2]=ld;$b=(ba((d[nc+((ic<<J)-rc)|0]|0)+(d[nc+((L<<J)-sc)|0]|0)|0,jc)|0)+ld|0;if(($b|0)>=(ad|0)){id=ad;jd=bd;kd=cd;break}c[(q|0)>>2]=L;c[jb+4>>2]=ic;id=$b;jd=L;kd=ic}}while(0);ic=(ba(b[m+(Ra<<2)>>1]|0,n)|0)+32768>>16;L=(ba(b[m+(Ra<<2)+2>>1]|0,n)|0)+32768>>16;lc=(ic|0)>(pc|0)?pc:ic;ic=(vc|0)>(lc|0)?vc:lc;lc=(L|0)>(oc|0)?oc:L;L=(tc|0)>(lc|0)?tc:lc;lc=ic+zc+(L<<11)|0;do{if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){qd=id;rd=jd;sd=kd}else{do{if((r&4|0)==0){$b=c[a+12416>>2]|0;fc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba($b,L)|0)+ic)|0;ac=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,$b,p)|0;if((r&2|0)==0){td=ac;break}gc=c[a+12208>>2]|0;ec=(ba(fc,L>>1)|0)+(ic>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+($b<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ec|0,fc,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+($b<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ec|0,fc,p>>1);ec=(Pe[xc&255](a,gc+($b<<4)|0,c[a+12288+(k<<4)+4>>2]|0,fc,p>>1)|0)+ac|0;td=ec+(Pe[xc&255](a,gc+($b<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,fc,p>>1)|0)|0}else{fc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){td=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){td=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){td=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){td=536870912;break}$b=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;ec=(r&1)<<1|1;j:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){ac=0;while(1){mc=c[a+12160+(ac<<3)>>2]|0;yc=(c[a+12160+(ac<<3)+4>>2]|0)+(L<<J)|0;hc=((ba(c[a+12128+(ac<<3)>>2]|0,gc-$b|0)|0)/($b|0)|0)+((ac&1)<<(r&1|4))|0;dc=c[a+12128+(ac<<3)+4>>2]|0;if((L<<J|0)==0){bc=ac>>1;ud=((ba(dc,gc-$b|0)|0)/($b|0)|0)+(bc<<(r&1|4))|0;vd=bc}else{ud=yc-dc|0;vd=ac>>1}dc=((ud&ec)<<J)+(hc&ec)|0;bc=(c[(a+12208|0)>>2]|0)+((ba(vd,fc<<3)|0)+(ac<<3&8))|0;if((r&1|0)==0){cc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(yc>>1,fc)|0)+(mc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((yc&ec)<<J)+(mc&ec)|0)<<2)>>2]&1023](bc,cc,fc,8);cc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ud>>1,fc)|0)+(hc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(dc<<2)>>2]&1023](bc,cc,fc,8)}else{cc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(yc>>2,fc)|0)+(mc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((yc&ec)<<J)+(mc&ec)|0)<<2)>>2]&4095](bc,cc,fc);cc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ud>>2,fc)|0)+(hc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](bc,cc,fc)}ac=ac+1|0;if((ac|0)>=4){break j}}}if((L<<J|0)==0){ac=0;do{cc=(c[a+12160+(ac<<3)>>2]|0)+(ic<<J)|0;bc=c[a+12160+(ac<<3)+4>>2]|0;dc=cc-(c[a+12128+(ac<<3)>>2]|0)|0;hc=ac>>1;mc=((ba(c[a+12128+(ac<<3)+4>>2]|0,gc-$b|0)|0)/($b|0)|0)+(hc<<(r&1|4))|0;yc=(c[(a+12208|0)>>2]|0)+((ac<<3&8)+(ba(hc,fc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,fc)|0)+(cc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&ec)<<J)+(cc&ec)|0)<<2)>>2]&1023](yc,hc,fc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(mc>>1,fc)|0)+(dc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((mc&ec)<<J)+(dc&ec)|0)<<2)>>2]&1023](yc,hc,fc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>2,fc)|0)+(cc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(cc&ec)|0)<<2)>>2]&4095](yc,hc,fc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(mc>>2,fc)|0)+(dc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((mc&ec)<<J)+(dc&ec)|0)<<2)>>2]&4095](yc,hc,fc)}ac=ac+1|0;}while((ac|0)<4)}else{ac=0;do{hc=(c[a+12160+(ac<<3)>>2]|0)+(ic<<J)|0;yc=(c[a+12160+(ac<<3)+4>>2]|0)+(L<<J)|0;dc=hc-(c[a+12128+(ac<<3)>>2]|0)|0;mc=yc-(c[a+12128+(ac<<3)+4>>2]|0)|0;cc=(c[(a+12208|0)>>2]|0)+((ac<<3&8)+(ba(ac>>1,fc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(yc>>1,fc)|0)+(hc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((yc&ec)<<J)+(hc&ec)|0)<<2)>>2]&1023](cc,bc,fc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(mc>>1,fc)|0)+(dc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((mc&ec)<<J)+(dc&ec)|0)<<2)>>2]&1023](cc,bc,fc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(yc>>2,fc)|0)+(hc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((yc&ec)<<J)+(hc&ec)|0)<<2)>>2]&4095](cc,bc,fc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(mc>>2,fc)|0)+(dc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((mc&ec)<<J)+(dc&ec)|0)<<2)>>2]&4095](cc,bc,fc)}ac=ac+1|0;}while((ac|0)<4)}}else{ac=(c[a+12160>>2]|0)+(ic<<J)|0;bc=(c[a+12164>>2]|0)+(L<<J)|0;cc=c[a+12128>>2]|0;if((ic<<J|0)==0){wd=(ba(cc,gc-$b|0)|0)/($b|0)|0}else{wd=ac-cc|0}cc=c[a+12132>>2]|0;if((L<<J|0)==0){xd=(ba(cc,gc-$b|0)|0)/($b|0)|0}else{xd=bc-cc|0}cc=((xd&ec)<<J)+(wd&ec)|0;if((r&1|0)==0){dc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,fc)|0)+(ac>>1))|0;cf[c[(c[a+12444>>2]|0)+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,dc,fc,16);dc=(c[a+12352+(l<<4)+32>>2]|0)+((ba(xd>>1,fc)|0)+(wd>>1))|0;cf[c[(c[a+12448>>2]|0)+(cc<<2)>>2]&1023](c[(a+12208|0)>>2]|0,dc,fc,16);break}else{dc=(ba(bc>>2,fc)|0)+(ac>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+dc|0,fc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(dc+8|0)|0,fc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(dc+(fc<<3))|0,fc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((dc+8|0)+(fc<<3))|0,fc);dc=(ba(xd>>2,fc)|0)+(wd>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+dc|0,fc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(dc+8|0)|0,fc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(dc+(fc<<3))|0,fc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((dc+8|0)+(fc<<3))|0,fc);break}}}while(0);td=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,fc,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=td;ec=(ba((d[nc+((L<<J)-rc)|0]|0)+(d[nc+((ic<<J)-sc)|0]|0)|0,jc)|0)+td|0;if((ec|0)>=(id|0)){qd=id;rd=jd;sd=kd;break}c[(q|0)>>2]=ic;c[jb+4>>2]=L;qd=ec;rd=ic;sd=L}}while(0);L=c[(j+12|0)>>2]>>J;ic=c[(j+8|0)>>2]>>J;lc=ic+zc+(L<<11)|0;do{if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){yd=qd;zd=rd;Ad=sd}else{do{if((r&4|0)==0){ec=c[a+12416>>2]|0;$b=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba(ec,L)|0)+ic)|0;kc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,ec,p)|0;if((r&2|0)==0){Bd=kc;break}gc=c[a+12208>>2]|0;dc=(ba($b,L>>1)|0)+(ic>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+(ec<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+dc|0,$b,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+(ec<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+dc|0,$b,p>>1);dc=(Pe[xc&255](a,gc+(ec<<4)|0,c[a+12288+(k<<4)+4>>2]|0,$b,p>>1)|0)+kc|0;Bd=dc+(Pe[xc&255](a,gc+(ec<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,$b,p>>1)|0)|0}else{$b=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){Bd=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Bd=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Bd=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Bd=536870912;break}ec=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;dc=(r&1)<<1|1;k:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){kc=0;while(1){cc=c[a+12160+(kc<<3)>>2]|0;ac=(c[a+12160+(kc<<3)+4>>2]|0)+(L<<J)|0;bc=((ba(c[a+12128+(kc<<3)>>2]|0,gc-ec|0)|0)/(ec|0)|0)+((kc&1)<<(r&1|4))|0;mc=c[a+12128+(kc<<3)+4>>2]|0;if((L<<J|0)==0){hc=kc>>1;Cd=((ba(mc,gc-ec|0)|0)/(ec|0)|0)+(hc<<(r&1|4))|0;Dd=hc}else{Cd=ac-mc|0;Dd=kc>>1}mc=((Cd&dc)<<J)+(bc&dc)|0;hc=(c[(a+12208|0)>>2]|0)+((ba(Dd,$b<<3)|0)+(kc<<3&8))|0;if((r&1|0)==0){yc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>1,$b)|0)+(cc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&dc)<<J)+(cc&dc)|0)<<2)>>2]&1023](hc,yc,$b,8);yc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Cd>>1,$b)|0)+(bc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(mc<<2)>>2]&1023](hc,yc,$b,8)}else{yc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>2,$b)|0)+(cc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ac&dc)<<J)+(cc&dc)|0)<<2)>>2]&4095](hc,yc,$b);yc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Cd>>2,$b)|0)+(bc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095](hc,yc,$b)}kc=kc+1|0;if((kc|0)>=4){break k}}}if((L<<J|0)==0){kc=0;do{yc=(c[a+12160+(kc<<3)>>2]|0)+(ic<<J)|0;hc=c[a+12160+(kc<<3)+4>>2]|0;mc=yc-(c[a+12128+(kc<<3)>>2]|0)|0;bc=kc>>1;cc=((ba(c[a+12128+(kc<<3)+4>>2]|0,gc-ec|0)|0)/(ec|0)|0)+(bc<<(r&1|4))|0;ac=(c[(a+12208|0)>>2]|0)+((kc<<3&8)+(ba(bc,$b<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>1,$b)|0)+(yc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((hc&dc)<<J)+(yc&dc)|0)<<2)>>2]&1023](ac,bc,$b,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(cc>>1,$b)|0)+(mc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((cc&dc)<<J)+(mc&dc)|0)<<2)>>2]&1023](ac,bc,$b,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>2,$b)|0)+(yc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(yc&dc)|0)<<2)>>2]&4095](ac,bc,$b);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(cc>>2,$b)|0)+(mc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((cc&dc)<<J)+(mc&dc)|0)<<2)>>2]&4095](ac,bc,$b)}kc=kc+1|0;}while((kc|0)<4)}else{kc=0;do{bc=(c[a+12160+(kc<<3)>>2]|0)+(ic<<J)|0;ac=(c[a+12160+(kc<<3)+4>>2]|0)+(L<<J)|0;mc=bc-(c[a+12128+(kc<<3)>>2]|0)|0;cc=ac-(c[a+12128+(kc<<3)+4>>2]|0)|0;yc=(c[(a+12208|0)>>2]|0)+((kc<<3&8)+(ba(kc>>1,$b<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>1,$b)|0)+(bc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&dc)<<J)+(bc&dc)|0)<<2)>>2]&1023](yc,hc,$b,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(cc>>1,$b)|0)+(mc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((cc&dc)<<J)+(mc&dc)|0)<<2)>>2]&1023](yc,hc,$b,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>2,$b)|0)+(bc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ac&dc)<<J)+(bc&dc)|0)<<2)>>2]&4095](yc,hc,$b);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(cc>>2,$b)|0)+(mc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((cc&dc)<<J)+(mc&dc)|0)<<2)>>2]&4095](yc,hc,$b)}kc=kc+1|0;}while((kc|0)<4)}}else{kc=(c[a+12160>>2]|0)+(ic<<J)|0;hc=(c[a+12164>>2]|0)+(L<<J)|0;yc=c[a+12128>>2]|0;if((ic<<J|0)==0){Ed=(ba(yc,gc-ec|0)|0)/(ec|0)|0}else{Ed=kc-yc|0}yc=c[a+12132>>2]|0;if((L<<J|0)==0){Fd=(ba(yc,gc-ec|0)|0)/(ec|0)|0}else{Fd=hc-yc|0}yc=((Fd&dc)<<J)+(Ed&dc)|0;if((r&1|0)==0){mc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>1,$b)|0)+(kc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,mc,$b,16);mc=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Fd>>1,$b)|0)+(Ed>>1))|0;cf[c[(c[a+12448>>2]|0)+(yc<<2)>>2]&1023](c[(a+12208|0)>>2]|0,mc,$b,16);break}else{mc=(ba(hc>>2,$b)|0)+(kc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+mc|0,$b);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(mc+8|0)|0,$b);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+($b<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(mc+($b<<3))|0,$b);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(($b<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((mc+8|0)+($b<<3))|0,$b);mc=(ba(Fd>>2,$b)|0)+(Ed>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+mc|0,$b);Xe[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(mc+8|0)|0,$b);Xe[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+($b<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(mc+($b<<3))|0,$b);Xe[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(($b<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((mc+8|0)+($b<<3))|0,$b);break}}}while(0);Bd=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,$b,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=Bd;dc=c[(j+8|0)>>2]>>J;ec=c[(j+12|0)>>2]>>J;gc=(ba((d[nc+((ec<<J)-rc)|0]|0)+(d[nc+((dc<<J)-sc)|0]|0)|0,jc)|0)+Bd|0;if((gc|0)>=(qd|0)){yd=qd;zd=rd;Ad=sd;break}c[(q|0)>>2]=dc;c[jb+4>>2]=ec;yd=gc;zd=dc;Ad=ec}}while(0);ic=c[(j+20|0)>>2]>>J;L=c[(j+16|0)>>2]>>J;lc=L+zc+(ic<<11)|0;do{if((c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]|0)==(lc|0)){Gd=yd;Hd=zd;Id=Ad}else{do{if((r&4|0)==0){ec=c[a+12416>>2]|0;dc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba(ec,ic)|0)+L)|0;fc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,ec,p)|0;if((r&2|0)==0){Jd=fc;break}gc=c[a+12208>>2]|0;mc=(ba(dc,ic>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&1023](gc+(ec<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+mc|0,dc,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&1023](gc+(ec<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+mc|0,dc,p>>1);mc=(Pe[xc&255](a,gc+(ec<<4)|0,c[a+12288+(k<<4)+4>>2]|0,dc,p>>1)|0)+fc|0;Jd=mc+(Pe[xc&255](a,gc+(ec<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,dc,p>>1)|0)|0}else{dc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Jd=536870912;break}if((L<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Jd=536870912;break}if((c[(a+12272|0)>>2]|0)>(ic|0)){Jd=536870912;break}if((ic<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Jd=536870912;break}ec=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;mc=(r&1)<<1|1;l:do{if((c[a+11740>>2]|0)==1){if((L<<J|0)==0){fc=0;while(1){yc=c[a+12160+(fc<<3)>>2]|0;kc=(c[a+12160+(fc<<3)+4>>2]|0)+(ic<<J)|0;hc=((ba(c[a+12128+(fc<<3)>>2]|0,gc-ec|0)|0)/(ec|0)|0)+((fc&1)<<(r&1|4))|0;cc=c[a+12128+(fc<<3)+4>>2]|0;if((ic<<J|0)==0){bc=fc>>1;Kd=((ba(cc,gc-ec|0)|0)/(ec|0)|0)+(bc<<(r&1|4))|0;Ld=bc}else{Kd=kc-cc|0;Ld=fc>>1}cc=((Kd&mc)<<J)+(hc&mc)|0;bc=(c[(a+12208|0)>>2]|0)+((ba(Ld,dc<<3)|0)+(fc<<3&8))|0;if((r&1|0)==0){ac=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kc>>1,dc)|0)+(yc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((kc&mc)<<J)+(yc&mc)|0)<<2)>>2]&1023](bc,ac,dc,8);ac=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Kd>>1,dc)|0)+(hc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(cc<<2)>>2]&1023](bc,ac,dc,8)}else{ac=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kc>>2,dc)|0)+(yc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((kc&mc)<<J)+(yc&mc)|0)<<2)>>2]&4095](bc,ac,dc);ac=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Kd>>2,dc)|0)+(hc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095](bc,ac,dc)}fc=fc+1|0;if((fc|0)>=4){break l}}}if((ic<<J|0)==0){fc=0;do{ac=(c[a+12160+(fc<<3)>>2]|0)+(L<<J)|0;bc=c[a+12160+(fc<<3)+4>>2]|0;cc=ac-(c[a+12128+(fc<<3)>>2]|0)|0;hc=fc>>1;yc=((ba(c[a+12128+(fc<<3)+4>>2]|0,gc-ec|0)|0)/(ec|0)|0)+(hc<<(r&1|4))|0;kc=(c[(a+12208|0)>>2]|0)+((fc<<3&8)+(ba(hc,dc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,dc)|0)+(ac>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&mc)<<J)+(ac&mc)|0)<<2)>>2]&1023](kc,hc,dc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(yc>>1,dc)|0)+(cc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((yc&mc)<<J)+(cc&mc)|0)<<2)>>2]&1023](kc,hc,dc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>2,dc)|0)+(ac>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(ac&mc)|0)<<2)>>2]&4095](kc,hc,dc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(yc>>2,dc)|0)+(cc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((yc&mc)<<J)+(cc&mc)|0)<<2)>>2]&4095](kc,hc,dc)}fc=fc+1|0;}while((fc|0)<4)}else{fc=0;do{hc=(c[a+12160+(fc<<3)>>2]|0)+(L<<J)|0;kc=(c[a+12160+(fc<<3)+4>>2]|0)+(ic<<J)|0;cc=hc-(c[a+12128+(fc<<3)>>2]|0)|0;yc=kc-(c[a+12128+(fc<<3)+4>>2]|0)|0;ac=(c[(a+12208|0)>>2]|0)+((fc<<3&8)+(ba(fc>>1,dc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kc>>1,dc)|0)+(hc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((kc&mc)<<J)+(hc&mc)|0)<<2)>>2]&1023](ac,bc,dc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(yc>>1,dc)|0)+(cc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((yc&mc)<<J)+(cc&mc)|0)<<2)>>2]&1023](ac,bc,dc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kc>>2,dc)|0)+(hc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((kc&mc)<<J)+(hc&mc)|0)<<2)>>2]&4095](ac,bc,dc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(yc>>2,dc)|0)+(cc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((yc&mc)<<J)+(cc&mc)|0)<<2)>>2]&4095](ac,bc,dc)}fc=fc+1|0;}while((fc|0)<4)}}else{fc=(c[a+12160>>2]|0)+(L<<J)|0;bc=(c[a+12164>>2]|0)+(ic<<J)|0;ac=c[a+12128>>2]|0;if((L<<J|0)==0){Md=(ba(ac,gc-ec|0)|0)/(ec|0)|0}else{Md=fc-ac|0}ac=c[a+12132>>2]|0;if((ic<<J|0)==0){Nd=(ba(ac,gc-ec|0)|0)/(ec|0)|0}else{Nd=bc-ac|0}ac=((Nd&mc)<<J)+(Md&mc)|0;if((r&1|0)==0){cc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(bc>>1,dc)|0)+(fc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,cc,dc,16);cc=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Nd>>1,dc)|0)+(Md>>1))|0;cf[c[(c[a+12448>>2]|0)+(ac<<2)>>2]&1023](c[(a+12208|0)>>2]|0,cc,dc,16);break}else{cc=(ba(bc>>2,dc)|0)+(fc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+cc|0,dc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(cc+8|0)|0,dc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(dc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(cc+(dc<<3))|0,dc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((dc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((cc+8|0)+(dc<<3))|0,dc);cc=(ba(Nd>>2,dc)|0)+(Md>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+cc|0,dc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(cc+8|0)|0,dc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(dc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(cc+(dc<<3))|0,dc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((dc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((cc+8|0)+(dc<<3))|0,dc);break}}}while(0);Jd=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,dc,16)|0}}while(0);c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]=lc;c[uc+(((ic<<3)+L&63)<<2)>>2]=Jd;mc=c[(j+16|0)>>2]>>J;ec=c[(j+20|0)>>2]>>J;gc=(ba((d[nc+((ec<<J)-rc)|0]|0)+(d[nc+((mc<<J)-sc)|0]|0)|0,jc)|0)+Jd|0;if((gc|0)>=(yd|0)){Gd=yd;Hd=zd;Id=Ad;break}c[(q|0)>>2]=mc;c[jb+4>>2]=ec;Gd=gc;Hd=mc;Id=ec}}while(0);L=c[(j+28|0)>>2]>>J;ic=c[(j+24|0)>>2]>>J;lc=ic+zc+(L<<11)|0;if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){Od=Gd;Pd=Hd;Qd=Id;break}do{if((r&4|0)==0){ec=c[a+12416>>2]|0;mc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba(ec,L)|0)+ic)|0;$b=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,ec,p)|0;if((r&2|0)==0){Rd=$b;break}gc=c[a+12208>>2]|0;cc=(ba(mc,L>>1)|0)+(ic>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+(ec<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+cc|0,mc,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&1023](gc+(ec<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+cc|0,mc,p>>1);cc=(Pe[xc&255](a,gc+(ec<<4)|0,c[a+12288+(k<<4)+4>>2]|0,mc,p>>1)|0)+$b|0;Rd=cc+(Pe[xc&255](a,gc+(ec<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,mc,p>>1)|0)|0}else{mc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){Rd=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Rd=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Rd=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Rd=536870912;break}ec=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;cc=(r&1)<<1|1;m:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){$b=0;while(1){ac=c[a+12160+($b<<3)>>2]|0;fc=(c[a+12160+($b<<3)+4>>2]|0)+(L<<J)|0;bc=((ba(c[a+12128+($b<<3)>>2]|0,gc-ec|0)|0)/(ec|0)|0)+(($b&1)<<(r&1|4))|0;yc=c[a+12128+($b<<3)+4>>2]|0;if((L<<J|0)==0){hc=$b>>1;Sd=((ba(yc,gc-ec|0)|0)/(ec|0)|0)+(hc<<(r&1|4))|0;Td=hc}else{Sd=fc-yc|0;Td=$b>>1}yc=((Sd&cc)<<J)+(bc&cc)|0;hc=(c[(a+12208|0)>>2]|0)+((ba(Td,mc<<3)|0)+($b<<3&8))|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(fc>>1,mc)|0)+(ac>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((fc&cc)<<J)+(ac&cc)|0)<<2)>>2]&1023](hc,kc,mc,8);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Sd>>1,mc)|0)+(bc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(yc<<2)>>2]&1023](hc,kc,mc,8)}else{kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(fc>>2,mc)|0)+(ac>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((fc&cc)<<J)+(ac&cc)|0)<<2)>>2]&4095](hc,kc,mc);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Sd>>2,mc)|0)+(bc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095](hc,kc,mc)}$b=$b+1|0;if(($b|0)>=4){break m}}}if((L<<J|0)==0){$b=0;do{dc=(c[a+12160+($b<<3)>>2]|0)+(ic<<J)|0;kc=c[a+12160+($b<<3)+4>>2]|0;hc=dc-(c[a+12128+($b<<3)>>2]|0)|0;yc=$b>>1;bc=((ba(c[a+12128+($b<<3)+4>>2]|0,gc-ec|0)|0)/(ec|0)|0)+(yc<<(r&1|4))|0;ac=(c[(a+12208|0)>>2]|0)+(($b<<3&8)+(ba(yc,mc<<3)|0))|0;if((r&1|0)==0){yc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kc>>1,mc)|0)+(dc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((kc&cc)<<J)+(dc&cc)|0)<<2)>>2]&1023](ac,yc,mc,8);yc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(bc>>1,mc)|0)+(hc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&1023](ac,yc,mc,8)}else{yc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kc>>2,mc)|0)+(dc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+(dc&cc)|0)<<2)>>2]&4095](ac,yc,mc);yc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(bc>>2,mc)|0)+(hc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&4095](ac,yc,mc)}$b=$b+1|0;}while(($b|0)<4)}else{$b=0;do{yc=(c[a+12160+($b<<3)>>2]|0)+(ic<<J)|0;ac=(c[a+12160+($b<<3)+4>>2]|0)+(L<<J)|0;hc=yc-(c[a+12128+($b<<3)>>2]|0)|0;bc=ac-(c[a+12128+($b<<3)+4>>2]|0)|0;dc=(c[(a+12208|0)>>2]|0)+(($b<<3&8)+(ba($b>>1,mc<<3)|0))|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>1,mc)|0)+(yc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&cc)<<J)+(yc&cc)|0)<<2)>>2]&1023](dc,kc,mc,8);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(bc>>1,mc)|0)+(hc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&1023](dc,kc,mc,8)}else{kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>2,mc)|0)+(yc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ac&cc)<<J)+(yc&cc)|0)<<2)>>2]&4095](dc,kc,mc);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(bc>>2,mc)|0)+(hc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&4095](dc,kc,mc)}$b=$b+1|0;}while(($b|0)<4)}}else{$b=(c[a+12160>>2]|0)+(ic<<J)|0;kc=(c[a+12164>>2]|0)+(L<<J)|0;dc=c[a+12128>>2]|0;if((ic<<J|0)==0){Ud=(ba(dc,gc-ec|0)|0)/(ec|0)|0}else{Ud=$b-dc|0}dc=c[a+12132>>2]|0;if((L<<J|0)==0){Vd=(ba(dc,gc-ec|0)|0)/(ec|0)|0}else{Vd=kc-dc|0}dc=((Vd&cc)<<J)+(Ud&cc)|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(kc>>1,mc)|0)+($b>>1))|0;cf[c[(c[a+12444>>2]|0)+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,hc,mc,16);hc=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Vd>>1,mc)|0)+(Ud>>1))|0;cf[c[(c[a+12448>>2]|0)+(dc<<2)>>2]&1023](c[(a+12208|0)>>2]|0,hc,mc,16);break}else{hc=(ba(kc>>2,mc)|0)+($b>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+hc|0,mc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(hc+8|0)|0,mc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(mc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(hc+(mc<<3))|0,mc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((mc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((hc+8|0)+(mc<<3))|0,mc);hc=(ba(Vd>>2,mc)|0)+(Ud>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+hc|0,mc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(hc+8|0)|0,mc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(mc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(hc+(mc<<3))|0,mc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((mc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((hc+8|0)+(mc<<3))|0,mc);break}}}while(0);Rd=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,mc,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=Rd;cc=c[(j+24|0)>>2]>>J;ec=c[(j+28|0)>>2]>>J;gc=(ba((d[nc+((ec<<J)-rc)|0]|0)+(d[nc+((cc<<J)-sc)|0]|0)|0,jc)|0)+Rd|0;if((gc|0)>=(Gd|0)){Od=Gd;Pd=Hd;Qd=Id;break}c[(q|0)>>2]=cc;c[jb+4>>2]=ec;Od=gc;Pd=cc;Qd=ec}else{Ac=1}}if(Ac){Ac=0;if(1){ec=c[(j+12|0)>>2]>>J;cc=c[(j+8|0)>>2]>>J;gc=cc+zc+(ec<<11)|0;do{if((c[(qc+(((ec<<3)+cc&63)<<2)|0)>>2]|0)==(gc|0)){Wd=Bc;Xd=0;Yd=0}else{do{if((r&4|0)==0){hc=c[a+12416>>2]|0;dc=c[a+12420>>2]|0;$b=(c[a+12352+(l<<4)>>2]|0)+((ba(hc,ec)|0)+cc)|0;kc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,$b,hc,p)|0;if((r&2|0)==0){Zd=kc;break}$b=c[a+12208>>2]|0;bc=(ba(dc,ec>>1)|0)+(cc>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ec<<1&2|cc&1)<<2)>>2]&1023]($b+(hc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+bc|0,dc,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ec<<1&2|cc&1)<<2)>>2]&1023]($b+(hc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+bc|0,dc,p>>1);bc=(Pe[xc&255](a,$b+(hc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,dc,p>>1)|0)+kc|0;Zd=bc+(Pe[xc&255](a,$b+(hc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,dc,p>>1)|0)|0}else{dc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(cc|0)){Zd=536870912;break}if((cc<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Zd=536870912;break}if((c[(a+12272|0)>>2]|0)>(ec|0)){Zd=536870912;break}if((ec<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Zd=536870912;break}hc=e[a+13872>>1]|0;$b=e[a+13874>>1]|0;bc=(r&1)<<1|1;n:do{if((c[a+11740>>2]|0)==1){if((cc<<J|0)==0){kc=0;while(1){yc=c[a+12160+(kc<<3)>>2]|0;ac=(c[a+12160+(kc<<3)+4>>2]|0)+(ec<<J)|0;fc=((ba(c[a+12128+(kc<<3)>>2]|0,$b-hc|0)|0)/(hc|0)|0)+((kc&1)<<(r&1|4))|0;_b=c[a+12128+(kc<<3)+4>>2]|0;if((ec<<J|0)==0){Ka=kc>>1;_d=((ba(_b,$b-hc|0)|0)/(hc|0)|0)+(Ka<<(r&1|4))|0;$d=Ka}else{_d=ac-_b|0;$d=kc>>1}_b=((_d&bc)<<J)+(fc&bc)|0;Ka=(c[(a+12208|0)>>2]|0)+((ba($d,dc<<3)|0)+(kc<<3&8))|0;if((r&1|0)==0){Ja=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>1,dc)|0)+(yc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&bc)<<J)+(yc&bc)|0)<<2)>>2]&1023](Ka,Ja,dc,8);Ja=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_d>>1,dc)|0)+(fc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(_b<<2)>>2]&1023](Ka,Ja,dc,8)}else{Ja=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>2,dc)|0)+(yc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ac&bc)<<J)+(yc&bc)|0)<<2)>>2]&4095](Ka,Ja,dc);Ja=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_d>>2,dc)|0)+(fc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(_b<<2)>>2]&4095](Ka,Ja,dc)}kc=kc+1|0;if((kc|0)>=4){break n}}}if((ec<<J|0)==0){kc=0;do{Ja=(c[a+12160+(kc<<3)>>2]|0)+(cc<<J)|0;Ka=c[a+12160+(kc<<3)+4>>2]|0;_b=Ja-(c[a+12128+(kc<<3)>>2]|0)|0;fc=kc>>1;yc=((ba(c[a+12128+(kc<<3)+4>>2]|0,$b-hc|0)|0)/(hc|0)|0)+(fc<<(r&1|4))|0;ac=(c[(a+12208|0)>>2]|0)+((kc<<3&8)+(ba(fc,dc<<3)|0))|0;if((r&1|0)==0){fc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ka>>1,dc)|0)+(Ja>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Ka&bc)<<J)+(Ja&bc)|0)<<2)>>2]&1023](ac,fc,dc,8);fc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(yc>>1,dc)|0)+(_b>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((yc&bc)<<J)+(_b&bc)|0)<<2)>>2]&1023](ac,fc,dc,8)}else{fc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ka>>2,dc)|0)+(Ja>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(Ja&bc)|0)<<2)>>2]&4095](ac,fc,dc);fc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(yc>>2,dc)|0)+(_b>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((yc&bc)<<J)+(_b&bc)|0)<<2)>>2]&4095](ac,fc,dc)}kc=kc+1|0;}while((kc|0)<4)}else{kc=0;do{fc=(c[a+12160+(kc<<3)>>2]|0)+(cc<<J)|0;ac=(c[a+12160+(kc<<3)+4>>2]|0)+(ec<<J)|0;_b=fc-(c[a+12128+(kc<<3)>>2]|0)|0;yc=ac-(c[a+12128+(kc<<3)+4>>2]|0)|0;Ja=(c[(a+12208|0)>>2]|0)+((kc<<3&8)+(ba(kc>>1,dc<<3)|0))|0;if((r&1|0)==0){Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>1,dc)|0)+(fc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&bc)<<J)+(fc&bc)|0)<<2)>>2]&1023](Ja,Ka,dc,8);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(yc>>1,dc)|0)+(_b>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((yc&bc)<<J)+(_b&bc)|0)<<2)>>2]&1023](Ja,Ka,dc,8)}else{Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ac>>2,dc)|0)+(fc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ac&bc)<<J)+(fc&bc)|0)<<2)>>2]&4095](Ja,Ka,dc);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(yc>>2,dc)|0)+(_b>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((yc&bc)<<J)+(_b&bc)|0)<<2)>>2]&4095](Ja,Ka,dc)}kc=kc+1|0;}while((kc|0)<4)}}else{kc=(c[a+12160>>2]|0)+(cc<<J)|0;Ka=(c[a+12164>>2]|0)+(ec<<J)|0;Ja=c[a+12128>>2]|0;if((cc<<J|0)==0){ae=(ba(Ja,$b-hc|0)|0)/(hc|0)|0}else{ae=kc-Ja|0}Ja=c[a+12132>>2]|0;if((ec<<J|0)==0){be=(ba(Ja,$b-hc|0)|0)/(hc|0)|0}else{be=Ka-Ja|0}Ja=((be&bc)<<J)+(ae&bc)|0;if((r&1|0)==0){_b=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ka>>1,dc)|0)+(kc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,_b,dc,16);_b=(c[a+12352+(l<<4)+32>>2]|0)+((ba(be>>1,dc)|0)+(ae>>1))|0;cf[c[(c[a+12448>>2]|0)+(Ja<<2)>>2]&1023](c[(a+12208|0)>>2]|0,_b,dc,16);break}else{_b=(ba(Ka>>2,dc)|0)+(kc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+_b|0,dc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_b+8|0)|0,dc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(dc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_b+(dc<<3))|0,dc);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((dc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((_b+8|0)+(dc<<3))|0,dc);_b=(ba(be>>2,dc)|0)+(ae>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+_b|0,dc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_b+8|0)|0,dc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(dc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_b+(dc<<3))|0,dc);Xe[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((dc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((_b+8|0)+(dc<<3))|0,dc);break}}}while(0);Zd=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,dc,16)|0}}while(0);c[(qc+(((ec<<3)+cc&63)<<2)|0)>>2]=gc;c[uc+(((ec<<3)+cc&63)<<2)>>2]=Zd;mc=c[(j+8|0)>>2]>>J;bc=c[(j+12|0)>>2]>>J;hc=(ba((d[nc+((bc<<J)-rc)|0]|0)+(d[nc+((mc<<J)-sc)|0]|0)|0,jc)|0)+Zd|0;if((hc|0)>=(Bc|0)){Wd=Bc;Xd=0;Yd=0;break}c[(q|0)>>2]=mc;c[jb+4>>2]=bc;Wd=hc;Xd=mc;Yd=bc}}while(0);cc=(ba(b[m+(Ra<<2)>>1]|0,n)|0)+32768>>16;ec=(ba(b[m+(Ra<<2)+2>>1]|0,n)|0)+32768>>16;gc=(cc|0)>(pc|0)?pc:cc;cc=(vc|0)>(gc|0)?vc:gc;gc=(ec|0)>(oc|0)?oc:ec;ec=(tc|0)>(gc|0)?tc:gc;gc=cc+zc+(ec<<11)|0;if((c[(qc+(((ec<<3)+cc&63)<<2)|0)>>2]|0)==(gc|0)){Od=Wd;Pd=Xd;Qd=Yd;break}do{if((r&4|0)==0){ic=c[a+12416>>2]|0;L=c[a+12420>>2]|0;lc=(c[a+12352+(l<<4)>>2]|0)+((ba(ic,ec)|0)+cc)|0;bc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,lc,ic,p)|0;if((r&2|0)==0){ce=bc;break}lc=c[a+12208>>2]|0;mc=(ba(L,ec>>1)|0)+(cc>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ec<<1&2|cc&1)<<2)>>2]&1023](lc+(ic<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+mc|0,L,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ec<<1&2|cc&1)<<2)>>2]&1023](lc+(ic<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+mc|0,L,p>>1);mc=(Pe[xc&255](a,lc+(ic<<4)|0,c[a+12288+(k<<4)+4>>2]|0,L,p>>1)|0)+bc|0;ce=mc+(Pe[xc&255](a,lc+(ic<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,L,p>>1)|0)|0}else{L=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(cc|0)){ce=536870912;break}if((cc<<J|0)>(c[(a+12268|0)>>2]<<J|0)){ce=536870912;break}if((c[(a+12272|0)>>2]|0)>(ec|0)){ce=536870912;break}if((ec<<J|0)>(c[(a+12276|0)>>2]<<J|0)){ce=536870912;break}ic=e[a+13872>>1]|0;lc=e[a+13874>>1]|0;mc=(r&1)<<1|1;o:do{if((c[a+11740>>2]|0)==1){if((cc<<J|0)==0){bc=0;while(1){hc=c[a+12160+(bc<<3)>>2]|0;$b=(c[a+12160+(bc<<3)+4>>2]|0)+(ec<<J)|0;_b=((ba(c[a+12128+(bc<<3)>>2]|0,lc-ic|0)|0)/(ic|0)|0)+((bc&1)<<(r&1|4))|0;Ja=c[a+12128+(bc<<3)+4>>2]|0;if((ec<<J|0)==0){kc=bc>>1;de=((ba(Ja,lc-ic|0)|0)/(ic|0)|0)+(kc<<(r&1|4))|0;ee=kc}else{de=$b-Ja|0;ee=bc>>1}Ja=((de&mc)<<J)+(_b&mc)|0;kc=(c[(a+12208|0)>>2]|0)+((ba(ee,L<<3)|0)+(bc<<3&8))|0;if((r&1|0)==0){Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba($b>>1,L)|0)+(hc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+(((($b&mc)<<J)+(hc&mc)|0)<<2)>>2]&1023](kc,Ka,L,8);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(de>>1,L)|0)+(_b>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(Ja<<2)>>2]&1023](kc,Ka,L,8)}else{Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba($b>>2,L)|0)+(hc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+(((($b&mc)<<J)+(hc&mc)|0)<<2)>>2]&4095](kc,Ka,L);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(de>>2,L)|0)+(_b>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095](kc,Ka,L)}bc=bc+1|0;if((bc|0)>=4){break o}}}if((ec<<J|0)==0){bc=0;do{dc=(c[a+12160+(bc<<3)>>2]|0)+(cc<<J)|0;Ka=c[a+12160+(bc<<3)+4>>2]|0;kc=dc-(c[a+12128+(bc<<3)>>2]|0)|0;Ja=bc>>1;_b=((ba(c[a+12128+(bc<<3)+4>>2]|0,lc-ic|0)|0)/(ic|0)|0)+(Ja<<(r&1|4))|0;hc=(c[(a+12208|0)>>2]|0)+((bc<<3&8)+(ba(Ja,L<<3)|0))|0;if((r&1|0)==0){Ja=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ka>>1,L)|0)+(dc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Ka&mc)<<J)+(dc&mc)|0)<<2)>>2]&1023](hc,Ja,L,8);Ja=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_b>>1,L)|0)+(kc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((_b&mc)<<J)+(kc&mc)|0)<<2)>>2]&1023](hc,Ja,L,8)}else{Ja=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ka>>2,L)|0)+(dc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(dc&mc)|0)<<2)>>2]&4095](hc,Ja,L);Ja=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_b>>2,L)|0)+(kc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((_b&mc)<<J)+(kc&mc)|0)<<2)>>2]&4095](hc,Ja,L)}bc=bc+1|0;}while((bc|0)<4)}else{bc=0;do{Ja=(c[a+12160+(bc<<3)>>2]|0)+(cc<<J)|0;hc=(c[a+12160+(bc<<3)+4>>2]|0)+(ec<<J)|0;kc=Ja-(c[a+12128+(bc<<3)>>2]|0)|0;_b=hc-(c[a+12128+(bc<<3)+4>>2]|0)|0;dc=(c[(a+12208|0)>>2]|0)+((bc<<3&8)+(ba(bc>>1,L<<3)|0))|0;if((r&1|0)==0){Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>1,L)|0)+(Ja>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((hc&mc)<<J)+(Ja&mc)|0)<<2)>>2]&1023](dc,Ka,L,8);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_b>>1,L)|0)+(kc>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((_b&mc)<<J)+(kc&mc)|0)<<2)>>2]&1023](dc,Ka,L,8)}else{Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(hc>>2,L)|0)+(Ja>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((hc&mc)<<J)+(Ja&mc)|0)<<2)>>2]&4095](dc,Ka,L);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(_b>>2,L)|0)+(kc>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((_b&mc)<<J)+(kc&mc)|0)<<2)>>2]&4095](dc,Ka,L)}bc=bc+1|0;}while((bc|0)<4)}}else{bc=(c[a+12160>>2]|0)+(cc<<J)|0;Ka=(c[a+12164>>2]|0)+(ec<<J)|0;dc=c[a+12128>>2]|0;if((cc<<J|0)==0){fe=(ba(dc,lc-ic|0)|0)/(ic|0)|0}else{fe=bc-dc|0}dc=c[a+12132>>2]|0;if((ec<<J|0)==0){ge=(ba(dc,lc-ic|0)|0)/(ic|0)|0}else{ge=Ka-dc|0}dc=((ge&mc)<<J)+(fe&mc)|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Ka>>1,L)|0)+(bc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,kc,L,16);kc=(c[a+12352+(l<<4)+32>>2]|0)+((ba(ge>>1,L)|0)+(fe>>1))|0;cf[c[(c[a+12448>>2]|0)+(dc<<2)>>2]&1023](c[(a+12208|0)>>2]|0,kc,L,16);break}else{kc=(ba(Ka>>2,L)|0)+(bc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+kc|0,L);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kc+8|0)|0,L);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kc+(L<<3))|0,L);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((kc+8|0)+(L<<3))|0,L);kc=(ba(ge>>2,L)|0)+(fe>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+kc|0,L);Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kc+8|0)|0,L);Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kc+(L<<3))|0,L);Xe[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((kc+8|0)+(L<<3))|0,L);break}}}while(0);ce=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,L,16)|0}}while(0);c[(qc+(((ec<<3)+cc&63)<<2)|0)>>2]=gc;c[uc+(((ec<<3)+cc&63)<<2)>>2]=ce;mc=(ba((d[nc+((ec<<J)-rc)|0]|0)+(d[nc+((cc<<J)-sc)|0]|0)|0,jc)|0)+ce|0;if((mc|0)>=(Wd|0)){Od=Wd;Pd=Xd;Qd=Yd;break}c[(q|0)>>2]=cc;c[jb+4>>2]=ec;Od=mc;Pd=cc;Qd=ec}else{Ac=1}}}while(0);do{if((Od|0)>(ba(p<<2,p)|0)){if((c[(a+12256|0)>>2]|0)==0){Yd=(ba(b[m+((Ra+1|0)<<2)>>1]|0,n)|0)+32768>>16;Xd=(ba(b[m+((Ra+1|0)<<2)+2>>1]|0,n)|0)+32768>>16;Wd=(Yd|0)>(pc|0)?pc:Yd;Yd=(vc|0)>(Wd|0)?vc:Wd;Wd=(Xd|0)>(oc|0)?oc:Xd;Xd=(tc|0)>(Wd|0)?tc:Wd;Wd=Yd+zc+(Xd<<11)|0;do{if((c[(qc+(((Xd<<3)+Yd&63)<<2)|0)>>2]|0)==(Wd|0)){he=Od;ie=Pd;je=Qd}else{do{if((r&4|0)==0){ce=c[a+12416>>2]|0;fe=c[a+12420>>2]|0;ge=(c[a+12352+(l<<4)>>2]|0)+((ba(ce,Xd)|0)+Yd)|0;de=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,ge,ce,p)|0;if((r&2|0)==0){ke=de;break}ge=c[a+12208>>2]|0;ee=(ba(fe,Xd>>1)|0)+(Yd>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Xd<<1&2|Yd&1)<<2)>>2]&1023](ge+(ce<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ee|0,fe,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Xd<<1&2|Yd&1)<<2)>>2]&1023](ge+(ce<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ee|0,fe,p>>1);ee=(Pe[xc&255](a,ge+(ce<<4)|0,c[a+12288+(k<<4)+4>>2]|0,fe,p>>1)|0)+de|0;ke=ee+(Pe[xc&255](a,ge+(ce<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,fe,p>>1)|0)|0}else{fe=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Yd|0)){ke=536870912;break}if((Yd<<J|0)>(c[(a+12268|0)>>2]<<J|0)){ke=536870912;break}if((c[(a+12272|0)>>2]|0)>(Xd|0)){ke=536870912;break}if((Xd<<J|0)>(c[(a+12276|0)>>2]<<J|0)){ke=536870912;break}ce=e[a+13872>>1]|0;ge=e[a+13874>>1]|0;ee=(r&1)<<1|1;p:do{if((c[a+11740>>2]|0)==1){if((Yd<<J|0)==0){de=0;while(1){Bc=c[a+12160+(de<<3)>>2]|0;Zd=(c[a+12160+(de<<3)+4>>2]|0)+(Xd<<J)|0;j=((ba(c[a+12128+(de<<3)>>2]|0,ge-ce|0)|0)/(ce|0)|0)+((de&1)<<(r&1|4))|0;ae=c[a+12128+(de<<3)+4>>2]|0;if((Xd<<J|0)==0){be=de>>1;le=((ba(ae,ge-ce|0)|0)/(ce|0)|0)+(be<<(r&1|4))|0;me=be}else{le=Zd-ae|0;me=de>>1}ae=((le&ee)<<J)+(j&ee)|0;be=(c[(a+12208|0)>>2]|0)+((ba(me,fe<<3)|0)+(de<<3&8))|0;if((r&1|0)==0){_d=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Zd>>1,fe)|0)+(Bc>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Zd&ee)<<J)+(Bc&ee)|0)<<2)>>2]&1023](be,_d,fe,8);_d=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(le>>1,fe)|0)+(j>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(ae<<2)>>2]&1023](be,_d,fe,8)}else{_d=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Zd>>2,fe)|0)+(Bc>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Zd&ee)<<J)+(Bc&ee)|0)<<2)>>2]&4095](be,_d,fe);_d=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(le>>2,fe)|0)+(j>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ae<<2)>>2]&4095](be,_d,fe)}de=de+1|0;if((de|0)>=4){break p}}}if((Xd<<J|0)==0){de=0;do{_d=(c[a+12160+(de<<3)>>2]|0)+(Yd<<J)|0;be=c[a+12160+(de<<3)+4>>2]|0;ae=_d-(c[a+12128+(de<<3)>>2]|0)|0;j=de>>1;Bc=((ba(c[a+12128+(de<<3)+4>>2]|0,ge-ce|0)|0)/(ce|0)|0)+(j<<(r&1|4))|0;Zd=(c[(a+12208|0)>>2]|0)+((de<<3&8)+(ba(j,fe<<3)|0))|0;if((r&1|0)==0){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(be>>1,fe)|0)+(_d>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((be&ee)<<J)+(_d&ee)|0)<<2)>>2]&1023](Zd,j,fe,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Bc>>1,fe)|0)+(ae>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((Bc&ee)<<J)+(ae&ee)|0)<<2)>>2]&1023](Zd,j,fe,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(be>>2,fe)|0)+(_d>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(_d&ee)|0)<<2)>>2]&4095](Zd,j,fe);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Bc>>2,fe)|0)+(ae>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((Bc&ee)<<J)+(ae&ee)|0)<<2)>>2]&4095](Zd,j,fe)}de=de+1|0;}while((de|0)<4)}else{de=0;do{j=(c[a+12160+(de<<3)>>2]|0)+(Yd<<J)|0;Zd=(c[a+12160+(de<<3)+4>>2]|0)+(Xd<<J)|0;ae=j-(c[a+12128+(de<<3)>>2]|0)|0;Bc=Zd-(c[a+12128+(de<<3)+4>>2]|0)|0;_d=(c[(a+12208|0)>>2]|0)+((de<<3&8)+(ba(de>>1,fe<<3)|0))|0;if((r&1|0)==0){be=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Zd>>1,fe)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Zd&ee)<<J)+(j&ee)|0)<<2)>>2]&1023](_d,be,fe,8);be=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Bc>>1,fe)|0)+(ae>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((Bc&ee)<<J)+(ae&ee)|0)<<2)>>2]&1023](_d,be,fe,8)}else{be=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Zd>>2,fe)|0)+(j>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Zd&ee)<<J)+(j&ee)|0)<<2)>>2]&4095](_d,be,fe);be=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Bc>>2,fe)|0)+(ae>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((Bc&ee)<<J)+(ae&ee)|0)<<2)>>2]&4095](_d,be,fe)}de=de+1|0;}while((de|0)<4)}}else{de=(c[a+12160>>2]|0)+(Yd<<J)|0;be=(c[a+12164>>2]|0)+(Xd<<J)|0;_d=c[a+12128>>2]|0;if((Yd<<J|0)==0){ne=(ba(_d,ge-ce|0)|0)/(ce|0)|0}else{ne=de-_d|0}_d=c[a+12132>>2]|0;if((Xd<<J|0)==0){oe=(ba(_d,ge-ce|0)|0)/(ce|0)|0}else{oe=be-_d|0}_d=((oe&ee)<<J)+(ne&ee)|0;if((r&1|0)==0){ae=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(be>>1,fe)|0)+(de>>1))|0;cf[c[(c[a+12444>>2]|0)+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ae,fe,16);ae=(c[a+12352+(l<<4)+32>>2]|0)+((ba(oe>>1,fe)|0)+(ne>>1))|0;cf[c[(c[a+12448>>2]|0)+(_d<<2)>>2]&1023](c[(a+12208|0)>>2]|0,ae,fe,16);break}else{ae=(ba(be>>2,fe)|0)+(de>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ae|0,fe);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ae+8|0)|0,fe);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fe<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ae+(fe<<3))|0,fe);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fe<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ae+8|0)+(fe<<3))|0,fe);ae=(ba(oe>>2,fe)|0)+(ne>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(_d<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ae|0,fe);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_d<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ae+8|0)|0,fe);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_d<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fe<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ae+(fe<<3))|0,fe);Xe[c[(c[(a+12456|0)>>2]|0)+64+(_d<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fe<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ae+8|0)+(fe<<3))|0,fe);break}}}while(0);ke=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,fe,16)|0}}while(0);c[(qc+(((Xd<<3)+Yd&63)<<2)|0)>>2]=Wd;c[uc+(((Xd<<3)+Yd&63)<<2)>>2]=ke;L=(ba((d[nc+((Xd<<J)-rc)|0]|0)+(d[nc+((Yd<<J)-sc)|0]|0)|0,jc)|0)+ke|0;if((L|0)>=(Od|0)){he=Od;ie=Pd;je=Qd;break}c[(q|0)>>2]=Yd;c[jb+4>>2]=Xd;he=L;ie=Yd;je=Xd}}while(0);if(((c[(a+12480|0)>>2]|0)+1|0)>=(c[a+812>>2]|0)){pe=he;qe=ie;re=je;break}Xd=(ba(b[m+((Ra+s|0)<<2)>>1]|0,n)|0)+32768>>16;Yd=(ba(b[m+((Ra+s|0)<<2)+2>>1]|0,n)|0)+32768>>16;Wd=(Xd|0)>(pc|0)?pc:Xd;Xd=(vc|0)>(Wd|0)?vc:Wd;Wd=(Yd|0)>(oc|0)?oc:Yd;Yd=(tc|0)>(Wd|0)?tc:Wd;Wd=Xd+zc+(Yd<<11)|0;if((c[(qc+(((Yd<<3)+Xd&63)<<2)|0)>>2]|0)==(Wd|0)){pe=he;qe=ie;re=je;break}do{if((r&4|0)==0){Ac=c[a+12416>>2]|0;ec=c[a+12420>>2]|0;cc=(c[a+12352+(l<<4)>>2]|0)+((ba(Ac,Yd)|0)+Xd)|0;gc=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,cc,Ac,p)|0;if((r&2|0)==0){se=gc;break}cc=c[a+12208>>2]|0;L=(ba(ec,Yd>>1)|0)+(Xd>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Yd<<1&2|Xd&1)<<2)>>2]&1023](cc+(Ac<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+L|0,ec,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Yd<<1&2|Xd&1)<<2)>>2]&1023](cc+(Ac<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+L|0,ec,p>>1);L=(Pe[xc&255](a,cc+(Ac<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ec,p>>1)|0)+gc|0;se=L+(Pe[xc&255](a,cc+(Ac<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ec,p>>1)|0)|0}else{ec=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Xd|0)){se=536870912;break}if((Xd<<J|0)>(c[(a+12268|0)>>2]<<J|0)){se=536870912;break}if((c[(a+12272|0)>>2]|0)>(Yd|0)){se=536870912;break}if((Yd<<J|0)>(c[(a+12276|0)>>2]<<J|0)){se=536870912;break}Ac=e[a+13872>>1]|0;cc=e[a+13874>>1]|0;L=(r&1)<<1|1;q:do{if((c[a+11740>>2]|0)==1){if((Xd<<J|0)==0){gc=0;while(1){ee=c[a+12160+(gc<<3)>>2]|0;ce=(c[a+12160+(gc<<3)+4>>2]|0)+(Yd<<J)|0;ge=((ba(c[a+12128+(gc<<3)>>2]|0,cc-Ac|0)|0)/(Ac|0)|0)+((gc&1)<<(r&1|4))|0;ae=c[a+12128+(gc<<3)+4>>2]|0;if((Yd<<J|0)==0){_d=gc>>1;te=((ba(ae,cc-Ac|0)|0)/(Ac|0)|0)+(_d<<(r&1|4))|0;ue=_d}else{te=ce-ae|0;ue=gc>>1}ae=((te&L)<<J)+(ge&L)|0;_d=(c[(a+12208|0)>>2]|0)+((ba(ue,ec<<3)|0)+(gc<<3&8))|0;if((r&1|0)==0){de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ce>>1,ec)|0)+(ee>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ce&L)<<J)+(ee&L)|0)<<2)>>2]&1023](_d,de,ec,8);de=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(te>>1,ec)|0)+(ge>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(ae<<2)>>2]&1023](_d,de,ec,8)}else{de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ce>>2,ec)|0)+(ee>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ce&L)<<J)+(ee&L)|0)<<2)>>2]&4095](_d,de,ec);de=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(te>>2,ec)|0)+(ge>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(ae<<2)>>2]&4095](_d,de,ec)}gc=gc+1|0;if((gc|0)>=4){break q}}}if((Yd<<J|0)==0){gc=0;do{fe=(c[a+12160+(gc<<3)>>2]|0)+(Xd<<J)|0;de=c[a+12160+(gc<<3)+4>>2]|0;_d=fe-(c[a+12128+(gc<<3)>>2]|0)|0;ae=gc>>1;ge=((ba(c[a+12128+(gc<<3)+4>>2]|0,cc-Ac|0)|0)/(Ac|0)|0)+(ae<<(r&1|4))|0;ee=(c[(a+12208|0)>>2]|0)+((gc<<3&8)+(ba(ae,ec<<3)|0))|0;if((r&1|0)==0){ae=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(de>>1,ec)|0)+(fe>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((de&L)<<J)+(fe&L)|0)<<2)>>2]&1023](ee,ae,ec,8);ae=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ge>>1,ec)|0)+(_d>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ge&L)<<J)+(_d&L)|0)<<2)>>2]&1023](ee,ae,ec,8)}else{ae=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(de>>2,ec)|0)+(fe>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(fe&L)|0)<<2)>>2]&4095](ee,ae,ec);ae=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ge>>2,ec)|0)+(_d>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ge&L)<<J)+(_d&L)|0)<<2)>>2]&4095](ee,ae,ec)}gc=gc+1|0;}while((gc|0)<4)}else{gc=0;do{ae=(c[a+12160+(gc<<3)>>2]|0)+(Xd<<J)|0;ee=(c[a+12160+(gc<<3)+4>>2]|0)+(Yd<<J)|0;_d=ae-(c[a+12128+(gc<<3)>>2]|0)|0;ge=ee-(c[a+12128+(gc<<3)+4>>2]|0)|0;fe=(c[(a+12208|0)>>2]|0)+((gc<<3&8)+(ba(gc>>1,ec<<3)|0))|0;if((r&1|0)==0){de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ee>>1,ec)|0)+(ae>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ee&L)<<J)+(ae&L)|0)<<2)>>2]&1023](fe,de,ec,8);de=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ge>>1,ec)|0)+(_d>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ge&L)<<J)+(_d&L)|0)<<2)>>2]&1023](fe,de,ec,8)}else{de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ee>>2,ec)|0)+(ae>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ee&L)<<J)+(ae&L)|0)<<2)>>2]&4095](fe,de,ec);de=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ge>>2,ec)|0)+(_d>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ge&L)<<J)+(_d&L)|0)<<2)>>2]&4095](fe,de,ec)}gc=gc+1|0;}while((gc|0)<4)}}else{gc=(c[a+12160>>2]|0)+(Xd<<J)|0;de=(c[a+12164>>2]|0)+(Yd<<J)|0;fe=c[a+12128>>2]|0;if((Xd<<J|0)==0){ve=(ba(fe,cc-Ac|0)|0)/(Ac|0)|0}else{ve=gc-fe|0}fe=c[a+12132>>2]|0;if((Yd<<J|0)==0){we=(ba(fe,cc-Ac|0)|0)/(Ac|0)|0}else{we=de-fe|0}fe=((we&L)<<J)+(ve&L)|0;if((r&1|0)==0){_d=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(de>>1,ec)|0)+(gc>>1))|0;cf[c[(c[a+12444>>2]|0)+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,_d,ec,16);_d=(c[a+12352+(l<<4)+32>>2]|0)+((ba(we>>1,ec)|0)+(ve>>1))|0;cf[c[(c[a+12448>>2]|0)+(fe<<2)>>2]&1023](c[(a+12208|0)>>2]|0,_d,ec,16);break}else{_d=(ba(de>>2,ec)|0)+(gc>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+_d|0,ec);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_d+8|0)|0,ec);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ec<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_d+(ec<<3))|0,ec);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ec<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((_d+8|0)+(ec<<3))|0,ec);_d=(ba(we>>2,ec)|0)+(ve>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+_d|0,ec);Xe[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_d+8|0)|0,ec);Xe[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ec<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_d+(ec<<3))|0,ec);Xe[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ec<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((_d+8|0)+(ec<<3))|0,ec);break}}}while(0);se=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ec,16)|0}}while(0);c[(qc+(((Yd<<3)+Xd&63)<<2)|0)>>2]=Wd;c[uc+(((Yd<<3)+Xd&63)<<2)>>2]=se;L=(ba((d[nc+((Yd<<J)-rc)|0]|0)+(d[nc+((Xd<<J)-sc)|0]|0)|0,jc)|0)+se|0;if((L|0)>=(he|0)){pe=he;qe=ie;re=je;break}c[(q|0)>>2]=Xd;c[jb+4>>2]=Yd;pe=L;qe=Xd;re=Yd;break}else{L=(ba(b[m+((Ra-1|0)<<2)>>1]|0,n)|0)+32768>>16;Ac=(ba(b[m+((Ra-1|0)<<2)+2>>1]|0,n)|0)+32768>>16;cc=(L|0)>(pc|0)?pc:L;L=(vc|0)>(cc|0)?vc:cc;cc=(Ac|0)>(oc|0)?oc:Ac;Ac=(tc|0)>(cc|0)?tc:cc;cc=L+zc+(Ac<<11)|0;do{if((c[(qc+(((Ac<<3)+L&63)<<2)|0)>>2]|0)==(cc|0)){xe=Od;ye=Pd;ze=Qd}else{do{if((r&4|0)==0){_d=c[a+12416>>2]|0;fe=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ba(_d,Ac)|0)+L)|0;de=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,gc,_d,p)|0;if((r&2|0)==0){Ae=de;break}gc=c[a+12208>>2]|0;ge=(ba(fe,Ac>>1)|0)+(L>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Ac<<1&2|L&1)<<2)>>2]&1023](gc+(_d<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ge|0,fe,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Ac<<1&2|L&1)<<2)>>2]&1023](gc+(_d<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ge|0,fe,p>>1);ge=(Pe[xc&255](a,gc+(_d<<4)|0,c[a+12288+(k<<4)+4>>2]|0,fe,p>>1)|0)+de|0;Ae=ge+(Pe[xc&255](a,gc+(_d<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,fe,p>>1)|0)|0}else{fe=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Ae=536870912;break}if((L<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Ae=536870912;break}if((c[(a+12272|0)>>2]|0)>(Ac|0)){Ae=536870912;break}if((Ac<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Ae=536870912;break}_d=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;ge=(r&1)<<1|1;r:do{if((c[a+11740>>2]|0)==1){if((L<<J|0)==0){de=0;while(1){ae=c[a+12160+(de<<3)>>2]|0;ee=(c[a+12160+(de<<3)+4>>2]|0)+(Ac<<J)|0;ce=((ba(c[a+12128+(de<<3)>>2]|0,gc-_d|0)|0)/(_d|0)|0)+((de&1)<<(r&1|4))|0;be=c[a+12128+(de<<3)+4>>2]|0;if((Ac<<J|0)==0){Bc=de>>1;Be=((ba(be,gc-_d|0)|0)/(_d|0)|0)+(Bc<<(r&1|4))|0;Ce=Bc}else{Be=ee-be|0;Ce=de>>1}be=((Be&ge)<<J)+(ce&ge)|0;Bc=(c[(a+12208|0)>>2]|0)+((ba(Ce,fe<<3)|0)+(de<<3&8))|0;if((r&1|0)==0){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ee>>1,fe)|0)+(ae>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ee&ge)<<J)+(ae&ge)|0)<<2)>>2]&1023](Bc,j,fe,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Be>>1,fe)|0)+(ce>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(be<<2)>>2]&1023](Bc,j,fe,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ee>>2,fe)|0)+(ae>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ee&ge)<<J)+(ae&ge)|0)<<2)>>2]&4095](Bc,j,fe);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Be>>2,fe)|0)+(ce>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(be<<2)>>2]&4095](Bc,j,fe)}de=de+1|0;if((de|0)>=4){break r}}}if((Ac<<J|0)==0){de=0;do{j=(c[a+12160+(de<<3)>>2]|0)+(L<<J)|0;Bc=c[a+12160+(de<<3)+4>>2]|0;be=j-(c[a+12128+(de<<3)>>2]|0)|0;ce=de>>1;ae=((ba(c[a+12128+(de<<3)+4>>2]|0,gc-_d|0)|0)/(_d|0)|0)+(ce<<(r&1|4))|0;ee=(c[(a+12208|0)>>2]|0)+((de<<3&8)+(ba(ce,fe<<3)|0))|0;if((r&1|0)==0){ce=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Bc>>1,fe)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Bc&ge)<<J)+(j&ge)|0)<<2)>>2]&1023](ee,ce,fe,8);ce=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ae>>1,fe)|0)+(be>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ae&ge)<<J)+(be&ge)|0)<<2)>>2]&1023](ee,ce,fe,8)}else{ce=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Bc>>2,fe)|0)+(j>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(j&ge)|0)<<2)>>2]&4095](ee,ce,fe);ce=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ae>>2,fe)|0)+(be>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ae&ge)<<J)+(be&ge)|0)<<2)>>2]&4095](ee,ce,fe)}de=de+1|0;}while((de|0)<4)}else{de=0;do{ce=(c[a+12160+(de<<3)>>2]|0)+(L<<J)|0;ee=(c[a+12160+(de<<3)+4>>2]|0)+(Ac<<J)|0;be=ce-(c[a+12128+(de<<3)>>2]|0)|0;ae=ee-(c[a+12128+(de<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((de<<3&8)+(ba(de>>1,fe<<3)|0))|0;if((r&1|0)==0){Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ee>>1,fe)|0)+(ce>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((ee&ge)<<J)+(ce&ge)|0)<<2)>>2]&1023](j,Bc,fe,8);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ae>>1,fe)|0)+(be>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((ae&ge)<<J)+(be&ge)|0)<<2)>>2]&1023](j,Bc,fe,8)}else{Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(ee>>2,fe)|0)+(ce>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((ee&ge)<<J)+(ce&ge)|0)<<2)>>2]&4095](j,Bc,fe);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(ae>>2,fe)|0)+(be>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((ae&ge)<<J)+(be&ge)|0)<<2)>>2]&4095](j,Bc,fe)}de=de+1|0;}while((de|0)<4)}}else{de=(c[a+12160>>2]|0)+(L<<J)|0;Bc=(c[a+12164>>2]|0)+(Ac<<J)|0;j=c[a+12128>>2]|0;if((L<<J|0)==0){De=(ba(j,gc-_d|0)|0)/(_d|0)|0}else{De=de-j|0}j=c[a+12132>>2]|0;if((Ac<<J|0)==0){Ee=(ba(j,gc-_d|0)|0)/(_d|0)|0}else{Ee=Bc-j|0}j=((Ee&ge)<<J)+(De&ge)|0;if((r&1|0)==0){be=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Bc>>1,fe)|0)+(de>>1))|0;cf[c[(c[a+12444>>2]|0)+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,be,fe,16);be=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Ee>>1,fe)|0)+(De>>1))|0;cf[c[(c[a+12448>>2]|0)+(j<<2)>>2]&1023](c[(a+12208|0)>>2]|0,be,fe,16);break}else{be=(ba(Bc>>2,fe)|0)+(de>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+be|0,fe);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(be+8|0)|0,fe);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fe<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(be+(fe<<3))|0,fe);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fe<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((be+8|0)+(fe<<3))|0,fe);be=(ba(Ee>>2,fe)|0)+(De>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+be|0,fe);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(be+8|0)|0,fe);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fe<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(be+(fe<<3))|0,fe);Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fe<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((be+8|0)+(fe<<3))|0,fe);break}}}while(0);Ae=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,fe,16)|0}}while(0);c[(qc+(((Ac<<3)+L&63)<<2)|0)>>2]=cc;c[uc+(((Ac<<3)+L&63)<<2)>>2]=Ae;ec=(ba((d[nc+((Ac<<J)-rc)|0]|0)+(d[nc+((L<<J)-sc)|0]|0)|0,jc)|0)+Ae|0;if((ec|0)>=(Od|0)){xe=Od;ye=Pd;ze=Qd;break}c[(q|0)>>2]=L;c[jb+4>>2]=Ac;xe=ec;ye=L;ze=Ac}}while(0);if((c[(a+14084|0)>>2]|0)!=0){pe=xe;qe=ye;re=ze;break}Ac=(ba(b[m+((Ra-s|0)<<2)>>1]|0,n)|0)+32768>>16;L=(ba(b[m+((Ra-s|0)<<2)+2>>1]|0,n)|0)+32768>>16;cc=(Ac|0)>(pc|0)?pc:Ac;Ac=(vc|0)>(cc|0)?vc:cc;cc=(L|0)>(oc|0)?oc:L;L=(tc|0)>(cc|0)?tc:cc;cc=Ac+zc+(L<<11)|0;if((c[(qc+(((L<<3)+Ac&63)<<2)|0)>>2]|0)==(cc|0)){pe=xe;qe=ye;re=ze;break}do{if((r&4|0)==0){Yd=c[a+12416>>2]|0;Xd=c[a+12420>>2]|0;Wd=(c[a+12352+(l<<4)>>2]|0)+((ba(Yd,L)|0)+Ac)|0;ec=Pe[wc&255](a,c[a+12288+(k<<4)>>2]|0,Wd,Yd,p)|0;if((r&2|0)==0){Fe=ec;break}Wd=c[a+12208>>2]|0;ge=(ba(Xd,L>>1)|0)+(Ac>>1)|0;cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|Ac&1)<<2)>>2]&1023](Wd+(Yd<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ge|0,Xd,p>>1);cf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|Ac&1)<<2)>>2]&1023](Wd+(Yd<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ge|0,Xd,p>>1);ge=(Pe[xc&255](a,Wd+(Yd<<4)|0,c[a+12288+(k<<4)+4>>2]|0,Xd,p>>1)|0)+ec|0;Fe=ge+(Pe[xc&255](a,Wd+(Yd<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,Xd,p>>1)|0)|0}else{Xd=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Ac|0)){Fe=536870912;break}if((Ac<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Fe=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Fe=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Fe=536870912;break}Yd=e[a+13872>>1]|0;Wd=e[a+13874>>1]|0;ge=(r&1)<<1|1;s:do{if((c[a+11740>>2]|0)==1){if((Ac<<J|0)==0){ec=0;while(1){_d=c[a+12160+(ec<<3)>>2]|0;gc=(c[a+12160+(ec<<3)+4>>2]|0)+(L<<J)|0;be=((ba(c[a+12128+(ec<<3)>>2]|0,Wd-Yd|0)|0)/(Yd|0)|0)+((ec&1)<<(r&1|4))|0;j=c[a+12128+(ec<<3)+4>>2]|0;if((L<<J|0)==0){de=ec>>1;Ge=((ba(j,Wd-Yd|0)|0)/(Yd|0)|0)+(de<<(r&1|4))|0;He=de}else{Ge=gc-j|0;He=ec>>1}j=((Ge&ge)<<J)+(be&ge)|0;de=(c[(a+12208|0)>>2]|0)+((ba(He,Xd<<3)|0)+(ec<<3&8))|0;if((r&1|0)==0){Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(gc>>1,Xd)|0)+(_d>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((gc&ge)<<J)+(_d&ge)|0)<<2)>>2]&1023](de,Bc,Xd,8);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ge>>1,Xd)|0)+(be>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+(j<<2)>>2]&1023](de,Bc,Xd,8)}else{Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(gc>>2,Xd)|0)+(_d>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((gc&ge)<<J)+(_d&ge)|0)<<2)>>2]&4095](de,Bc,Xd);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(Ge>>2,Xd)|0)+(be>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](de,Bc,Xd)}ec=ec+1|0;if((ec|0)>=4){break s}}}if((L<<J|0)==0){ec=0;do{fe=(c[a+12160+(ec<<3)>>2]|0)+(Ac<<J)|0;Bc=c[a+12160+(ec<<3)+4>>2]|0;de=fe-(c[a+12128+(ec<<3)>>2]|0)|0;j=ec>>1;be=((ba(c[a+12128+(ec<<3)+4>>2]|0,Wd-Yd|0)|0)/(Yd|0)|0)+(j<<(r&1|4))|0;_d=(c[(a+12208|0)>>2]|0)+((ec<<3&8)+(ba(j,Xd<<3)|0))|0;if((r&1|0)==0){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Bc>>1,Xd)|0)+(fe>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((Bc&ge)<<J)+(fe&ge)|0)<<2)>>2]&1023](_d,j,Xd,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(be>>1,Xd)|0)+(de>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((be&ge)<<J)+(de&ge)|0)<<2)>>2]&1023](_d,j,Xd,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Bc>>2,Xd)|0)+(fe>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(fe&ge)|0)<<2)>>2]&4095](_d,j,Xd);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(be>>2,Xd)|0)+(de>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((be&ge)<<J)+(de&ge)|0)<<2)>>2]&4095](_d,j,Xd)}ec=ec+1|0;}while((ec|0)<4)}else{ec=0;do{j=(c[a+12160+(ec<<3)>>2]|0)+(Ac<<J)|0;_d=(c[a+12160+(ec<<3)+4>>2]|0)+(L<<J)|0;de=j-(c[a+12128+(ec<<3)>>2]|0)|0;be=_d-(c[a+12128+(ec<<3)+4>>2]|0)|0;fe=(c[(a+12208|0)>>2]|0)+((ec<<3&8)+(ba(ec>>1,Xd<<3)|0))|0;if((r&1|0)==0){Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_d>>1,Xd)|0)+(j>>1))|0;cf[c[(c[(a+12444|0)>>2]|0)+16+((((_d&ge)<<J)+(j&ge)|0)<<2)>>2]&1023](fe,Bc,Xd,8);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(be>>1,Xd)|0)+(de>>1))|0;cf[c[(c[(a+12448|0)>>2]|0)+16+((((be&ge)<<J)+(de&ge)|0)<<2)>>2]&1023](fe,Bc,Xd,8)}else{Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(_d>>2,Xd)|0)+(j>>2))|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((_d&ge)<<J)+(j&ge)|0)<<2)>>2]&4095](fe,Bc,Xd);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ba(be>>2,Xd)|0)+(de>>2))|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+((((be&ge)<<J)+(de&ge)|0)<<2)>>2]&4095](fe,Bc,Xd)}ec=ec+1|0;}while((ec|0)<4)}}else{ec=(c[a+12160>>2]|0)+(Ac<<J)|0;Bc=(c[a+12164>>2]|0)+(L<<J)|0;fe=c[a+12128>>2]|0;if((Ac<<J|0)==0){Ie=(ba(fe,Wd-Yd|0)|0)/(Yd|0)|0}else{Ie=ec-fe|0}fe=c[a+12132>>2]|0;if((L<<J|0)==0){Je=(ba(fe,Wd-Yd|0)|0)/(Yd|0)|0}else{Je=Bc-fe|0}fe=((Je&ge)<<J)+(Ie&ge)|0;if((r&1|0)==0){de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ba(Bc>>1,Xd)|0)+(ec>>1))|0;cf[c[(c[a+12444>>2]|0)+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&1023](c[(a+12208|0)>>2]|0,de,Xd,16);de=(c[a+12352+(l<<4)+32>>2]|0)+((ba(Je>>1,Xd)|0)+(Ie>>1))|0;cf[c[(c[a+12448>>2]|0)+(fe<<2)>>2]&1023](c[(a+12208|0)>>2]|0,de,Xd,16);break}else{de=(ba(Bc>>2,Xd)|0)+(ec>>2)|0;Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+de|0,Xd);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(de+8|0)|0,Xd);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Xd<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(de+(Xd<<3))|0,Xd);Xe[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Xd<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((de+8|0)+(Xd<<3))|0,Xd);de=(ba(Je>>2,Xd)|0)+(Ie>>2)|0;Xe[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+de|0,Xd);Xe[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(de+8|0)|0,Xd);Xe[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Xd<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(de+(Xd<<3))|0,Xd);Xe[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Xd<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((de+8|0)+(Xd<<3))|0,Xd);break}}}while(0);Fe=Pe[wc&255](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,Xd,16)|0}}while(0);c[(qc+(((L<<3)+Ac&63)<<2)|0)>>2]=cc;c[uc+(((L<<3)+Ac&63)<<2)>>2]=Fe;ge=(ba((d[nc+((L<<J)-rc)|0]|0)+(d[nc+((Ac<<J)-sc)|0]|0)|0,jc)|0)+Fe|0;if((ge|0)>=(xe|0)){pe=xe;qe=ye;re=ze;break}c[(q|0)>>2]=Ac;c[jb+4>>2]=L;pe=ge;qe=Ac;re=L;break}}else{pe=Od;qe=Pd;re=Qd}}while(0);Qd=c[(c[a+12120>>2]|0)+252>>2]|0;c[q+24>>2]=a;c[q+32>>2]=f;c[q+40>>2]=h;c[q+56>>2]=k;c[q+64>>2]=l;c[q+72>>2]=m;c[q+80>>2]=n;c[q+88>>2]=o;c[q+96>>2]=p;c[q+104>>2]=r;c[q+5344>>2]=jb;c[q+5352>>2]=s;c[q+5368>>2]=uc;c[q+5376>>2]=vc;c[q+5384>>2]=tc;c[q+5392>>2]=pc;c[q+5400>>2]=oc;c[q+5408>>2]=nc;c[q+5416>>2]=sc;c[q+5424>>2]=rc;c[q+5432>>2]=qc;c[q+5440>>2]=J;c[q+5472>>2]=jc;c[q+5480>>2]=wc;c[q+5488>>2]=xc;c[q+5504>>2]=zc;c[q+13904>>2]=re;c[q+13912>>2]=qe;c[q+13920>>2]=pe;c[q+13928>>2]=Qd;c[q+27600>>2]=N;c[q+27640>>2]=0;c[q+27644>>2]=0;_ff_epzs_motion_search$0(q);N=c[q+27600>>2]|0;D=c[q+27640>>2]|0;w=c[q+27644>>2]|0;E=+g[q+27644>>2];c[q+27640>>2]=0;c[q+27644>>2]=0;if((D|0)==6){return w|0}return 0|0;return 0}function lmb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+4>>2]|0;e=c[d+248>>2]|0;f=(e|0)>-1?e:-e|0;g=c[d+264>>2]|0;h=(g|0)>-1?g:-g|0;j=(f&255)>>>0>(h&255)>>>0?f:h;if((((e|0)>(g|0)?g:e)|0)<-64){yDb(d,16,2173016,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}e=c[a+11732>>2]|0;do{if(!((e|0)==1|(e|0)==5|(e|0)==6)){if((c[d+48>>2]|0)==1397641047){break}yDb(d,16,2303264,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}}while(0);e=a+12120|0;c[e>>2]=d;do{if((j&255)>>>0>4>>>0){if((c[a+12416>>2]|0)!=0){m=d;break}yDb(d,32,2173128,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;m=c[e>>2]|0}else{m=d}}while(0);d=a+10056|0;V3(d,a+10444|0,c[m+260>>2]|0);V3(d,a+10468|0,c[(c[e>>2]|0)+232>>2]|0);V3(d,a+10492|0,c[(c[e>>2]|0)+236>>2]|0);V3(d,a+10516|0,c[(c[e>>2]|0)+240>>2]|0);d=c[e>>2]|0;e=d+232|0;m=d+88|0;c[a+12244>>2]=(c[m>>2]|0)>>>4&1|(c[e>>2]|0)>>>7&2;k=d+236|0;c[a+12248>>2]=(c[m>>2]|0)>>>4&1|(c[k>>2]|0)>>>7&2;j=d+240|0;c[a+12252>>2]=(c[m>>2]|0)>>>4&1|(c[j>>2]|0)>>>7&2;a:do{if((c[a+60>>2]&16|0)==0){m=c[k>>2]|0;if((m&256|0)!=0){c[a+12468>>2]=6;break}do{if((m|0)==0){if((c[e>>2]|0)!=0){break}if((c[j>>2]|0)!=0){break}c[a+12468>>2]=8;break a}}while(0);c[a+12468>>2]=6}else{c[a+12468>>2]=10;c[a+12456>>2]=a+10808;if((c[a+12472>>2]|0)==0){c[a+12452>>2]=a+10680;break}else{c[a+12452>>2]=a+10936;break}}}while(0);c[a+12448>>2]=a+11396;if((c[a+12472>>2]|0)==0){j=a+11332|0;c[a+12444>>2]=j;n=j}else{j=a+11460|0;c[a+12444>>2]=j;n=j}j=c[a+148>>2]|0;if((j|0)==0){m=c[a+116>>2]|0;c[a+12416>>2]=(m<<4)+32;c[a+12420>>2]=(m<<3)+16}else{c[a+12416>>2]=j;c[a+12420>>2]=c[a+152>>2]}j=c[a+48>>2]|0;if((j|0)==1397641047){l=0;i=b;return l|0}if((c[e>>2]&256|0)!=0){c[a+10476>>2]=200}do{if((c[k>>2]&256|0)!=0){e=a+10500|0;if((c[e>>2]|0)!=0){break}c[e>>2]=200}}while(0);k=a+12444|0;c[n+44>>2]=812;c[(c[k>>2]|0)+40>>2]=812;c[(c[k>>2]|0)+36>>2]=812;c[(c[k>>2]|0)+32>>2]=812;if((j|0)!=4){l=0;i=b;return l|0}c[a+12468>>2]=4;l=0;i=b;return l|0}function mmb(a,b,f,g,h,j,k,l){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;m=i;i=i+96|0;n=m|0;o=m+32|0;p=c[b>>2]|0;q=c[f>>2]|0;r=c[a+12236>>2]|0;s=c[a+12120>>2]|0;t=c[s+268>>2]|0;u=c[a+12220>>2]|0;v=a+12264|0;w=c[v>>2]|0;x=a+12272|0;y=c[x>>2]|0;z=a+12268|0;A=c[z>>2]|0;B=a+12276|0;C=c[B>>2]|0;D=c[a+12464>>2]|0;E=c[a+12280>>2]|0;G=c[a+12284>>2]|0;H=c[a+12248>>2]|0;I=c[a+10468+(k<<2)>>2]|0;J=k+1|0;K=c[a+10468+(J<<2)>>2]|0;L=c[a+10492+(k<<2)>>2]|0;M=c[a+10492+(J<<2)>>2]|0;if((c[a+12124>>2]|0)!=0){c[b>>2]=0;N=g;O=0;c[f>>2]=O;i=m;return N|0}do{if((c[s+232>>2]|0)==(c[s+236>>2]|0)){P=g}else{Q=H&1;do{if((H&4|0)==0){R=c[a+12416>>2]|0;S=c[a+12420>>2]|0;T=a;U=(c[a+12352+(j<<4)>>2]|0)+((ba(R,q)|0)+p)|0;V=Pe[L&255](T,c[a+12288+(h<<4)>>2]|0,U,R,l)|0;if((H&2|0)==0){W=V;break}U=q<<1&2|p&1;X=c[a+12208>>2]|0;Y=R<<4;R=X+Y|0;Z=a+12444|0;_=(ba(S,q>>1)|0)+(p>>1)|0;$=l>>1;cf[c[(c[Z>>2]|0)+(J<<4)+(U<<2)>>2]&1023](R,(c[a+12352+(j<<4)+4>>2]|0)+_|0,S,$);aa=X+(Y|8)|0;cf[c[(c[Z>>2]|0)+(J<<4)+(U<<2)>>2]&1023](aa,(c[a+12352+(j<<4)+8>>2]|0)+_|0,S,$);_=(Pe[M&255](T,R,c[a+12288+(h<<4)+4>>2]|0,S,$)|0)+V|0;W=_+(Pe[M&255](T,aa,c[a+12288+(h<<4)+8>>2]|0,S,$)|0)|0}else{$=c[a+12416>>2]|0;S=Q+1|0;aa=p<<S;T=q<<S;_=a+12352+(j<<4)|0;V=a+12288+(h<<4)|0;if((w|0)>(p|0)){W=536870912;break}if((aa|0)>(A<<S|0)|(y|0)>(q|0)){W=536870912;break}if((T|0)>(C<<S|0)){W=536870912;break}R=e[a+13872>>1]|0;U=e[a+13874>>1]|0;Z=Q<<1|1;a:do{if((c[a+11740>>2]|0)==1){Y=U-R|0;X=Q|4;ca=(T|0)==0;da=a+12208|0;ea=$<<3;fa=(Q|0)==0;ga=a+12444|0;ha=a+12448|0;ia=a+12352+(j<<4)+32|0;ja=a+12452|0;ka=a+12456|0;if((aa|0)==0){la=0;while(1){ma=c[a+12160+(la<<3)>>2]|0;na=(c[a+12160+(la<<3)+4>>2]|0)+T|0;oa=((ba(c[a+12128+(la<<3)>>2]|0,Y)|0)/(R|0)|0)+((la&1)<<X)|0;pa=c[a+12128+(la<<3)+4>>2]|0;if(ca){qa=la>>1;ra=((ba(pa,Y)|0)/(R|0)|0)+(qa<<X)|0;sa=qa}else{ra=na-pa|0;sa=la>>1}pa=((na&Z)<<S)+(ma&Z)|0;qa=((ra&Z)<<S)+(oa&Z)|0;ta=(c[da>>2]|0)+((ba(sa,ea)|0)+(la<<3&8))|0;if(fa){ua=(c[_>>2]|0)+((ba(na>>1,$)|0)+(ma>>1))|0;cf[c[(c[ga>>2]|0)+16+(pa<<2)>>2]&1023](ta,ua,$,8);ua=(c[ia>>2]|0)+((ba(ra>>1,$)|0)+(oa>>1))|0;cf[c[(c[ha>>2]|0)+16+(qa<<2)>>2]&1023](ta,ua,$,8)}else{ua=(c[_>>2]|0)+((ba(na>>2,$)|0)+(ma>>2))|0;Xe[c[(c[ja>>2]|0)+64+(pa<<2)>>2]&4095](ta,ua,$);ua=(c[ia>>2]|0)+((ba(ra>>2,$)|0)+(oa>>2))|0;Xe[c[(c[ka>>2]|0)+64+(qa<<2)>>2]&4095](ta,ua,$)}la=la+1|0;if((la|0)>=4){break a}}}if(ca){la=0;do{ua=(c[a+12160+(la<<3)>>2]|0)+aa|0;ta=c[a+12160+(la<<3)+4>>2]|0;qa=ua-(c[a+12128+(la<<3)>>2]|0)|0;oa=la>>1;pa=((ba(c[a+12128+(la<<3)+4>>2]|0,Y)|0)/(R|0)|0)+(oa<<X)|0;ma=((ta&Z)<<S)+(ua&Z)|0;na=((pa&Z)<<S)+(qa&Z)|0;va=(c[da>>2]|0)+((la<<3&8)+(ba(oa,ea)|0))|0;if(fa){oa=(c[_>>2]|0)+((ba(ta>>1,$)|0)+(ua>>1))|0;cf[c[(c[ga>>2]|0)+16+(ma<<2)>>2]&1023](va,oa,$,8);oa=(c[ia>>2]|0)+((ba(pa>>1,$)|0)+(qa>>1))|0;cf[c[(c[ha>>2]|0)+16+(na<<2)>>2]&1023](va,oa,$,8)}else{oa=(c[_>>2]|0)+((ba(ta>>2,$)|0)+(ua>>2))|0;Xe[c[(c[ja>>2]|0)+64+(ma<<2)>>2]&4095](va,oa,$);oa=(c[ia>>2]|0)+((ba(pa>>2,$)|0)+(qa>>2))|0;Xe[c[(c[ka>>2]|0)+64+(na<<2)>>2]&4095](va,oa,$)}la=la+1|0;}while((la|0)<4)}else{la=0;do{X=(c[a+12160+(la<<3)>>2]|0)+aa|0;Y=(c[a+12160+(la<<3)+4>>2]|0)+T|0;ca=X-(c[a+12128+(la<<3)>>2]|0)|0;oa=Y-(c[a+12128+(la<<3)+4>>2]|0)|0;va=((Y&Z)<<S)+(X&Z)|0;na=((oa&Z)<<S)+(ca&Z)|0;qa=(c[da>>2]|0)+((la<<3&8)+(ba(la>>1,ea)|0))|0;if(fa){pa=(c[_>>2]|0)+((ba(Y>>1,$)|0)+(X>>1))|0;cf[c[(c[ga>>2]|0)+16+(va<<2)>>2]&1023](qa,pa,$,8);pa=(c[ia>>2]|0)+((ba(oa>>1,$)|0)+(ca>>1))|0;cf[c[(c[ha>>2]|0)+16+(na<<2)>>2]&1023](qa,pa,$,8)}else{pa=(c[_>>2]|0)+((ba(Y>>2,$)|0)+(X>>2))|0;Xe[c[(c[ja>>2]|0)+64+(va<<2)>>2]&4095](qa,pa,$);pa=(c[ia>>2]|0)+((ba(oa>>2,$)|0)+(ca>>2))|0;Xe[c[(c[ka>>2]|0)+64+(na<<2)>>2]&4095](qa,pa,$)}la=la+1|0;}while((la|0)<4)}}else{la=(c[a+12160>>2]|0)+aa|0;ka=(c[a+12164>>2]|0)+T|0;ia=c[a+12128>>2]|0;if((aa|0)==0){wa=(ba(ia,U-R|0)|0)/(R|0)|0}else{wa=la-ia|0}ia=c[a+12132>>2]|0;if((T|0)==0){xa=(ba(ia,U-R|0)|0)/(R|0)|0}else{xa=ka-ia|0}ia=((ka&Z)<<S)+(la&Z)|0;ja=((xa&Z)<<S)+(wa&Z)|0;if((Q|0)==0){ha=a+12208|0;ga=(c[_>>2]|0)+((ba(ka>>1,$)|0)+(la>>1))|0;cf[c[(c[a+12444>>2]|0)+(ia<<2)>>2]&1023](c[ha>>2]|0,ga,$,16);ga=(c[a+12352+(j<<4)+32>>2]|0)+((ba(xa>>1,$)|0)+(wa>>1))|0;cf[c[(c[a+12448>>2]|0)+(ja<<2)>>2]&1023](c[ha>>2]|0,ga,$,16);break}else{ga=a+12452|0;ha=a+12208|0;fa=(ba(ka>>2,$)|0)+(la>>2)|0;Xe[c[(c[ga>>2]|0)+64+(ia<<2)>>2]&4095](c[ha>>2]|0,(c[_>>2]|0)+fa|0,$);la=fa+8|0;Xe[c[(c[ga>>2]|0)+64+(ia<<2)>>2]&4095]((c[ha>>2]|0)+8|0,(c[_>>2]|0)+la|0,$);ka=$<<3;Xe[c[(c[ga>>2]|0)+64+(ia<<2)>>2]&4095]((c[ha>>2]|0)+ka|0,(c[_>>2]|0)+(fa+ka)|0,$);fa=ka+8|0;Xe[c[(c[ga>>2]|0)+64+(ia<<2)>>2]&4095]((c[ha>>2]|0)+fa|0,(c[_>>2]|0)+(la+ka)|0,$);la=a+12456|0;ia=a+12352+(j<<4)+32|0;ga=(ba(xa>>2,$)|0)+(wa>>2)|0;Xe[c[(c[la>>2]|0)+64+(ja<<2)>>2]&4095](c[ha>>2]|0,(c[ia>>2]|0)+ga|0,$);ea=ga+8|0;Xe[c[(c[la>>2]|0)+64+(ja<<2)>>2]&4095]((c[ha>>2]|0)+8|0,(c[ia>>2]|0)+ea|0,$);Xe[c[(c[la>>2]|0)+64+(ja<<2)>>2]&4095]((c[ha>>2]|0)+ka|0,(c[ia>>2]|0)+(ga+ka)|0,$);Xe[c[(c[la>>2]|0)+64+(ja<<2)>>2]&4095]((c[ha>>2]|0)+fa|0,(c[ia>>2]|0)+(ea+ka)|0,$);break}}}while(0);W=Pe[L&255](a,c[a+12208>>2]|0,c[V>>2]|0,$,16)|0}}while(0);if(!((q|p|0)!=0|(k|0)>0)){P=W;break}P=(ba((d[D+((q<<2)-G)|0]|0)+(d[D+((p<<2)-E)|0]|0)|0,r)|0)+W|0}}while(0);W=p<<2;if(!((p|0)>(w|0)&(p|0)<(A|0)&(q|0)>(y|0)&(q|0)<(C|0))){c[b>>2]=W;N=P;O=q<<2;c[f>>2]=O;i=m;return N|0}C=q<<2;y=(q<<3)+p|0;A=c[u+((y+56&63)<<2)>>2]|0;w=c[u+((y+63&63)<<2)>>2]|0;L=c[u+((y+1&63)<<2)>>2]|0;wa=c[u+((y+8&63)<<2)>>2]|0;xa=c[u+((y&63)<<2)>>2]|0;TGb(n|0,64,32)|0;if((c[a+12260>>2]|0)>1){ra=c[u+((y+55&63)<<2)>>2]|0;sa=c[u+((y+7&63)<<2)>>2]|0;M=c[u+((y+57&63)<<2)>>2]|0;g=c[u+((y+9&63)<<2)>>2]|0;y=ra-(A<<1)+M|0;u=M-ra|0;ra=A<<5;M=L+w-(xa<<1)|0;s=L-w|0;Q=xa<<5;_=sa-(wa<<1)+g|0;Z=g-sa|0;sa=wa<<5;g=-3;do{S=ba(g,g)|0;R=0;U=g<<2;T=U;aa=(U|0)<0|0?-1:0;U=g+C|0;ka=D+(U-G)|0;ea=-3;do{ia=ba(ea,ea)|0;fa=ea<<2;ha=(ba(fa,u)|0)+ra+(ba(ia,y)|0)|0;ja=ha;la=(ha|0)<0|0?-1:0;ha=(ba(fa,s)|0)+Q+(ba(ia,M)|0)|0;ga=ha;da=(ha|0)<0|0?-1:0;ha=(ba(fa,Z)|0)+sa+(ba(ia,_)|0)|0;ia=ha;fa=(ha|0)<0|0?-1:0;b:do{if(((ea|g)&3|0)!=0){ha=ZGb(ia,fa,ja,la)|0;pa=F;qa=YGb(ia,fa,ja,la)|0;na=F;ca=YGb(ga<<5|0>>>27,da<<5|ga>>>27,512,0)|0;oa=F;va=gHb(ha,pa,T,aa)|0;pa=F;ha=ZGb(qa,na,ga<<1|0>>>31,da<<1|ga>>>31)|0;na=F;qa=YGb(ca,oa,va,pa)|0;pa=F;va=gHb(ha,na,S,R)|0;na=YGb(qa,pa,va,F)|0;va=ea+W|0;pa=(ba((d[ka]|0)+(d[D+(va-E)|0]|0)|0,r)|0)+(na>>>10|F<<22)|0;na=0;while(1){if((na|0)>=8){break b}ya=n+(na<<2)|0;za=na+1|0;if((pa|0)<(c[ya>>2]|0)){break}else{na=za}}qa=7-na|0;VGb(n+(za<<2)|0,ya|0,qa<<2|0)|0;ha=o+(na<<3)|0;VGb(o+(za<<3)|0,ha|0,qa<<3|0)|0;c[ya>>2]=pa;c[ha>>2]=va;c[o+(na<<3)+4>>2]=U}}while(0);ea=ea+1|0;}while((ea|0)<4);g=g+1|0;}while((g|0)<4)}else{g=L-w<<2;ya=xa<<1;za=L+w-ya|0;w=wa-A<<2;L=wa+A|0;A=L-ya|0;ya=p-1|0;p=q-1|0;q=H&1;do{if((H&4|0)==0){wa=c[a+12416>>2]|0;_=c[a+12420>>2]|0;sa=a;Z=(c[a+12352+(j<<4)>>2]|0)+((ba(wa,p)|0)+ya)|0;M=Pe[I&255](sa,c[a+12288+(h<<4)>>2]|0,Z,wa,l)|0;if((H&2|0)==0){Aa=M;break}Z=p<<1&2|ya&1;Q=c[a+12208>>2]|0;s=wa<<4;wa=Q+s|0;y=a+12444|0;ra=(ba(_,p>>1)|0)+(ya>>1)|0;u=l>>1;cf[c[(c[y>>2]|0)+(J<<4)+(Z<<2)>>2]&1023](wa,(c[a+12352+(j<<4)+4>>2]|0)+ra|0,_,u);ea=Q+(s|8)|0;cf[c[(c[y>>2]|0)+(J<<4)+(Z<<2)>>2]&1023](ea,(c[a+12352+(j<<4)+8>>2]|0)+ra|0,_,u);ra=(Pe[K&255](sa,wa,c[a+12288+(h<<4)+4>>2]|0,_,u)|0)+M|0;Aa=ra+(Pe[K&255](sa,ea,c[a+12288+(h<<4)+8>>2]|0,_,u)|0)|0}else{u=c[a+12416>>2]|0;_=q+1|0;ea=ya<<_;sa=p<<_;ra=a+12352+(j<<4)|0;M=a+12288+(h<<4)|0;if((c[v>>2]|0)>(ya|0)){Aa=536870912;break}if((ea|0)>(c[z>>2]<<_|0)){Aa=536870912;break}if((c[x>>2]|0)>(p|0)){Aa=536870912;break}if((sa|0)>(c[B>>2]<<_|0)){Aa=536870912;break}wa=e[a+13872>>1]|0;Z=e[a+13874>>1]|0;y=q<<1|1;c:do{if((c[a+11740>>2]|0)==1){s=Z-wa|0;Q=q|4;U=(sa|0)==0;ka=a+12208|0;R=u<<3;S=(q|0)==0;aa=a+12444|0;T=a+12448|0;ga=a+12352+(j<<4)+32|0;da=a+12452|0;la=a+12456|0;if((ea|0)==0){ja=0;while(1){fa=c[a+12160+(ja<<3)>>2]|0;ia=(c[a+12160+(ja<<3)+4>>2]|0)+sa|0;$=((ba(c[a+12128+(ja<<3)>>2]|0,s)|0)/(wa|0)|0)+((ja&1)<<Q)|0;V=c[a+12128+(ja<<3)+4>>2]|0;if(U){ha=ja>>1;Ba=((ba(V,s)|0)/(wa|0)|0)+(ha<<Q)|0;Ca=ha}else{Ba=ia-V|0;Ca=ja>>1}V=((ia&y)<<_)+(fa&y)|0;ha=((Ba&y)<<_)+($&y)|0;qa=(c[ka>>2]|0)+((ba(Ca,R)|0)+(ja<<3&8))|0;if(S){oa=(c[ra>>2]|0)+((ba(ia>>1,u)|0)+(fa>>1))|0;cf[c[(c[aa>>2]|0)+16+(V<<2)>>2]&1023](qa,oa,u,8);oa=(c[ga>>2]|0)+((ba(Ba>>1,u)|0)+($>>1))|0;cf[c[(c[T>>2]|0)+16+(ha<<2)>>2]&1023](qa,oa,u,8)}else{oa=(c[ra>>2]|0)+((ba(ia>>2,u)|0)+(fa>>2))|0;Xe[c[(c[da>>2]|0)+64+(V<<2)>>2]&4095](qa,oa,u);oa=(c[ga>>2]|0)+((ba(Ba>>2,u)|0)+($>>2))|0;Xe[c[(c[la>>2]|0)+64+(ha<<2)>>2]&4095](qa,oa,u)}ja=ja+1|0;if((ja|0)>=4){break c}}}if(U){ja=0;do{oa=(c[a+12160+(ja<<3)>>2]|0)+ea|0;qa=c[a+12160+(ja<<3)+4>>2]|0;ha=oa-(c[a+12128+(ja<<3)>>2]|0)|0;$=ja>>1;V=((ba(c[a+12128+(ja<<3)+4>>2]|0,s)|0)/(wa|0)|0)+($<<Q)|0;fa=((qa&y)<<_)+(oa&y)|0;ia=((V&y)<<_)+(ha&y)|0;ca=(c[ka>>2]|0)+((ja<<3&8)+(ba($,R)|0))|0;if(S){$=(c[ra>>2]|0)+((ba(qa>>1,u)|0)+(oa>>1))|0;cf[c[(c[aa>>2]|0)+16+(fa<<2)>>2]&1023](ca,$,u,8);$=(c[ga>>2]|0)+((ba(V>>1,u)|0)+(ha>>1))|0;cf[c[(c[T>>2]|0)+16+(ia<<2)>>2]&1023](ca,$,u,8)}else{$=(c[ra>>2]|0)+((ba(qa>>2,u)|0)+(oa>>2))|0;Xe[c[(c[da>>2]|0)+64+(fa<<2)>>2]&4095](ca,$,u);$=(c[ga>>2]|0)+((ba(V>>2,u)|0)+(ha>>2))|0;Xe[c[(c[la>>2]|0)+64+(ia<<2)>>2]&4095](ca,$,u)}ja=ja+1|0;}while((ja|0)<4)}else{ja=0;do{Q=(c[a+12160+(ja<<3)>>2]|0)+ea|0;s=(c[a+12160+(ja<<3)+4>>2]|0)+sa|0;U=Q-(c[a+12128+(ja<<3)>>2]|0)|0;$=s-(c[a+12128+(ja<<3)+4>>2]|0)|0;ca=((s&y)<<_)+(Q&y)|0;ia=(($&y)<<_)+(U&y)|0;ha=(c[ka>>2]|0)+((ja<<3&8)+(ba(ja>>1,R)|0))|0;if(S){V=(c[ra>>2]|0)+((ba(s>>1,u)|0)+(Q>>1))|0;cf[c[(c[aa>>2]|0)+16+(ca<<2)>>2]&1023](ha,V,u,8);V=(c[ga>>2]|0)+((ba($>>1,u)|0)+(U>>1))|0;cf[c[(c[T>>2]|0)+16+(ia<<2)>>2]&1023](ha,V,u,8)}else{V=(c[ra>>2]|0)+((ba(s>>2,u)|0)+(Q>>2))|0;Xe[c[(c[da>>2]|0)+64+(ca<<2)>>2]&4095](ha,V,u);V=(c[ga>>2]|0)+((ba($>>2,u)|0)+(U>>2))|0;Xe[c[(c[la>>2]|0)+64+(ia<<2)>>2]&4095](ha,V,u)}ja=ja+1|0;}while((ja|0)<4)}}else{ja=(c[a+12160>>2]|0)+ea|0;la=(c[a+12164>>2]|0)+sa|0;ga=c[a+12128>>2]|0;if((ea|0)==0){Da=(ba(ga,Z-wa|0)|0)/(wa|0)|0}else{Da=ja-ga|0}ga=c[a+12132>>2]|0;if((sa|0)==0){Ea=(ba(ga,Z-wa|0)|0)/(wa|0)|0}else{Ea=la-ga|0}ga=((la&y)<<_)+(ja&y)|0;da=((Ea&y)<<_)+(Da&y)|0;if((q|0)==0){T=a+12208|0;aa=(c[ra>>2]|0)+((ba(la>>1,u)|0)+(ja>>1))|0;cf[c[(c[a+12444>>2]|0)+(ga<<2)>>2]&1023](c[T>>2]|0,aa,u,16);aa=(c[a+12352+(j<<4)+32>>2]|0)+((ba(Ea>>1,u)|0)+(Da>>1))|0;cf[c[(c[a+12448>>2]|0)+(da<<2)>>2]&1023](c[T>>2]|0,aa,u,16);break}else{aa=a+12452|0;T=a+12208|0;S=(ba(la>>2,u)|0)+(ja>>2)|0;Xe[c[(c[aa>>2]|0)+64+(ga<<2)>>2]&4095](c[T>>2]|0,(c[ra>>2]|0)+S|0,u);ja=S+8|0;Xe[c[(c[aa>>2]|0)+64+(ga<<2)>>2]&4095]((c[T>>2]|0)+8|0,(c[ra>>2]|0)+ja|0,u);la=u<<3;Xe[c[(c[aa>>2]|0)+64+(ga<<2)>>2]&4095]((c[T>>2]|0)+la|0,(c[ra>>2]|0)+(S+la)|0,u);S=la+8|0;Xe[c[(c[aa>>2]|0)+64+(ga<<2)>>2]&4095]((c[T>>2]|0)+S|0,(c[ra>>2]|0)+(ja+la)|0,u);ja=a+12456|0;ga=a+12352+(j<<4)+32|0;aa=(ba(Ea>>2,u)|0)+(Da>>2)|0;Xe[c[(c[ja>>2]|0)+64+(da<<2)>>2]&4095](c[T>>2]|0,(c[ga>>2]|0)+aa|0,u);R=aa+8|0;Xe[c[(c[ja>>2]|0)+64+(da<<2)>>2]&4095]((c[T>>2]|0)+8|0,(c[ga>>2]|0)+R|0,u);Xe[c[(c[ja>>2]|0)+64+(da<<2)>>2]&4095]((c[T>>2]|0)+la|0,(c[ga>>2]|0)+(aa+la)|0,u);Xe[c[(c[ja>>2]|0)+64+(da<<2)>>2]&4095]((c[T>>2]|0)+S|0,(c[ga>>2]|0)+(R+la)|0,u);break}}}while(0);Aa=Pe[I&255](a,c[a+12208>>2]|0,c[M>>2]|0,u,16)|0}}while(0);Da=((w+g|0)/4|0)-(L+za)+(Aa<<1)|0;Aa=-3;do{L=Aa+C|0;Ea=D+(L-G)|0;q=(ba(Aa,Da)|0)+g|0;Ba=ba((ba(Aa,A)|0)+w|0,Aa)|0;Ca=-3;do{d:do{if(((Ca|Aa)&3|0)!=0){p=ba(Ca,za)|0;ya=Ca+W|0;ra=Ba+(ba(q+p|0,Ca)|0)+((ba((d[Ea]|0)+(d[D+(ya-E)|0]|0)|0,r)|0)+xa<<5)|0;p=0;while(1){if((p|0)>=8){break d}Fa=n+(p<<2)|0;Ga=p+1|0;if((ra|0)<(c[Fa>>2]|0)){break}else{p=Ga}}na=7-p|0;VGb(n+(Ga<<2)|0,Fa|0,na<<2|0)|0;va=o+(p<<3)|0;VGb(o+(Ga<<3)|0,va|0,na<<3|0)|0;c[Fa>>2]=ra;c[va>>2]=ya;c[o+(p<<3)+4>>2]=L}}while(0);Ca=Ca+1|0;}while((Ca|0)<4);Aa=Aa+1|0;}while((Aa|0)<4)}if((t|0)>0){Aa=(H&4|0)==0;Fa=a+12416|0;Ga=a+12420|0;n=a+12352+(j<<4)|0;xa=a+12288+(h<<4)|0;za=a;w=(H&2|0)==0;H=a+12208|0;A=a+12444|0;g=a+12352+(j<<4)+4|0;Da=l>>1;Ca=a+12352+(j<<4)+8|0;L=a+12288+(h<<4)+4|0;Ea=a+12288+(h<<4)+8|0;h=a+12452|0;q=a+13872|0;Ba=a+13874|0;u=a+11740|0;M=a+12352+(j<<4)+32|0;j=a+12456|0;va=a+12160|0;na=a+12164|0;pa=a+12128|0;y=a+12132|0;_=0;wa=C;Z=W;sa=P;while(1){ea=c[o+(_<<3)>>2]|0;la=c[o+(_<<3)+4>>2]|0;R=ea>>2;ga=ea&3;S=R<<2|ga;T=la>>2;da=la&3;ja=T<<2|da;aa=c[Fa>>2]|0;e:do{if(Aa){ka=c[Ga>>2]|0;V=da<<2|ga;do{if((V|0)==0){ha=(c[n>>2]|0)+((ba(aa,T)|0)+R)|0;ia=Pe[I&255](za,c[xa>>2]|0,ha,aa,l)|0;if(w){Ha=ia;break e}Ia=T<<1&2|R&1;Ja=ia}else{ia=(c[n>>2]|0)+((ba(aa,T)|0)+R)|0;Xe[c[(c[h>>2]|0)+(k<<6)+(V<<2)>>2]&4095](c[H>>2]|0,ia,aa);if(w){Ha=Pe[I&255](za,c[H>>2]|0,c[xa>>2]|0,aa,l)|0;break e}else{ia=(S|0)/2|0;ha=(ja|0)/2|0;Ia=(ha<<1|ha)&2|(ia>>>1|ia)&1;Ja=Pe[I&255](za,c[H>>2]|0,c[xa>>2]|0,aa,l)|0;break}}}while(0);V=c[H>>2]|0;ia=aa<<4;ha=V+ia|0;U=(ba(ka,la>>3)|0)+(ea>>3)|0;cf[c[(c[A>>2]|0)+(J<<4)+(Ia<<2)>>2]&1023](ha,(c[g>>2]|0)+U|0,ka,Da);$=V+(ia|8)|0;cf[c[(c[A>>2]|0)+(J<<4)+(Ia<<2)>>2]&1023]($,(c[Ca>>2]|0)+U|0,ka,Da);U=(Pe[K&255](za,ha,c[L>>2]|0,ka,Da)|0)+Ja|0;Ha=U+(Pe[K&255](za,$,c[Ea>>2]|0,ka,Da)|0)|0}else{if((c[v>>2]|0)>(R|0)){Ha=536870912;break}if((S|0)>(c[z>>2]<<2|0)){Ha=536870912;break}if((c[x>>2]|0)>(T|0)){Ha=536870912;break}if((ja|0)>(c[B>>2]<<2|0)){Ha=536870912;break}$=e[q>>1]|0;U=e[Ba>>1]|0;f:do{if((c[u>>2]|0)==1){ha=U-$|0;ia=(ja|0)==0;V=aa<<3;if((S|0)==0){Ka=0}else{if(ia){ca=0;while(1){Q=(c[a+12160+(ca<<3)>>2]|0)+S|0;s=c[a+12160+(ca<<3)+4>>2]|0;fa=Q-(c[a+12128+(ca<<3)>>2]|0)|0;oa=ca>>1;qa=((ba(c[a+12128+(ca<<3)+4>>2]|0,ha)|0)/($|0)|0)+(oa<<5)|0;X=(c[H>>2]|0)+((ca<<3&8)+(ba(oa,V)|0))|0;oa=(c[n>>2]|0)+((ba(s>>2,aa)|0)+(Q>>2))|0;Xe[c[(c[h>>2]|0)+64+((s<<2&12|Q&3)<<2)>>2]&4095](X,oa,aa);oa=(c[M>>2]|0)+((ba(qa>>2,aa)|0)+(fa>>2))|0;Xe[c[(c[j>>2]|0)+64+((qa<<2&12|fa&3)<<2)>>2]&4095](X,oa,aa);ca=ca+1|0;if((ca|0)>=4){break f}}}else{ca=0;while(1){p=(c[a+12160+(ca<<3)>>2]|0)+S|0;ya=(c[a+12160+(ca<<3)+4>>2]|0)+ja|0;ra=p-(c[a+12128+(ca<<3)>>2]|0)|0;oa=ya-(c[a+12128+(ca<<3)+4>>2]|0)|0;X=(c[H>>2]|0)+((ca<<3&8)+(ba(ca>>1,V)|0))|0;fa=(c[n>>2]|0)+((ba(ya>>2,aa)|0)+(p>>2))|0;Xe[c[(c[h>>2]|0)+64+((ya<<2&12|p&3)<<2)>>2]&4095](X,fa,aa);fa=(c[M>>2]|0)+((ba(oa>>2,aa)|0)+(ra>>2))|0;Xe[c[(c[j>>2]|0)+64+((oa<<2&12|ra&3)<<2)>>2]&4095](X,fa,aa);ca=ca+1|0;if((ca|0)>=4){break f}}}}do{ca=c[a+12160+(Ka<<3)>>2]|0;fa=(c[a+12160+(Ka<<3)+4>>2]|0)+ja|0;X=((ba(c[a+12128+(Ka<<3)>>2]|0,ha)|0)/($|0)|0)+(Ka<<5&32)|0;ra=c[a+12128+(Ka<<3)+4>>2]|0;if(ia){oa=Ka>>1;La=((ba(ra,ha)|0)/($|0)|0)+(oa<<5)|0;Ma=oa}else{La=fa-ra|0;Ma=Ka>>1}ra=(c[H>>2]|0)+((ba(Ma,V)|0)+(Ka<<3&8))|0;oa=(c[n>>2]|0)+((ba(fa>>2,aa)|0)+(ca>>2))|0;Xe[c[(c[h>>2]|0)+64+((fa<<2&12|ca&3)<<2)>>2]&4095](ra,oa,aa);oa=(c[M>>2]|0)+((ba(La>>2,aa)|0)+(X>>2))|0;Xe[c[(c[j>>2]|0)+64+((La<<2&12|X&3)<<2)>>2]&4095](ra,oa,aa);Ka=Ka+1|0;}while((Ka|0)<4)}else{V=(c[va>>2]|0)+S|0;ha=(c[na>>2]|0)+ja|0;ia=c[pa>>2]|0;if((S|0)==0){Na=(ba(ia,U-$|0)|0)/($|0)|0}else{Na=V-ia|0}ia=c[y>>2]|0;if((ja|0)==0){Oa=(ba(ia,U-$|0)|0)/($|0)|0}else{Oa=ha-ia|0}ia=ha<<2&12|V&3;oa=Oa<<2&12|Na&3;ra=(ba(ha>>2,aa)|0)+(V>>2)|0;Xe[c[(c[h>>2]|0)+64+(ia<<2)>>2]&4095](c[H>>2]|0,(c[n>>2]|0)+ra|0,aa);V=ra+8|0;Xe[c[(c[h>>2]|0)+64+(ia<<2)>>2]&4095]((c[H>>2]|0)+8|0,(c[n>>2]|0)+V|0,aa);ha=aa<<3;Xe[c[(c[h>>2]|0)+64+(ia<<2)>>2]&4095]((c[H>>2]|0)+ha|0,(c[n>>2]|0)+(ra+ha)|0,aa);ra=ha+8|0;Xe[c[(c[h>>2]|0)+64+(ia<<2)>>2]&4095]((c[H>>2]|0)+ra|0,(c[n>>2]|0)+(V+ha)|0,aa);V=(ba(Oa>>2,aa)|0)+(Na>>2)|0;Xe[c[(c[j>>2]|0)+64+(oa<<2)>>2]&4095](c[H>>2]|0,(c[M>>2]|0)+V|0,aa);ia=V+8|0;Xe[c[(c[j>>2]|0)+64+(oa<<2)>>2]&4095]((c[H>>2]|0)+8|0,(c[M>>2]|0)+ia|0,aa);Xe[c[(c[j>>2]|0)+64+(oa<<2)>>2]&4095]((c[H>>2]|0)+ha|0,(c[M>>2]|0)+(V+ha)|0,aa);Xe[c[(c[j>>2]|0)+64+(oa<<2)>>2]&4095]((c[H>>2]|0)+ra|0,(c[M>>2]|0)+(ia+ha)|0,aa)}}while(0);Ha=Pe[I&255](za,c[H>>2]|0,c[xa>>2]|0,aa,16)|0}}while(0);aa=(ba((d[D+(ja-G)|0]|0)+(d[D+(S-E)|0]|0)|0,r)|0)+Ha|0;T=(aa|0)<(sa|0);R=T?ja:wa;ea=T?S:Z;la=T?aa:sa;aa=_+1|0;if((aa|0)<(t|0)){_=aa;wa=R;Z=ea;sa=la}else{Pa=R;Qa=ea;Ra=la;break}}}else{Pa=C;Qa=W;Ra=P}c[b>>2]=Qa;N=Ra;O=Pa;c[f>>2]=O;i=m;return N|0}function nmb(a,b,f,g,h,i,j,k){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;l=c[b>>2]|0;m=c[f>>2]|0;n=c[a+12236>>2]|0;o=l<<1;p=m<<1;q=c[a+12220>>2]|0;r=c[a+12264>>2]|0;s=c[a+12272>>2]|0;t=c[a+12268>>2]|0;u=c[a+12276>>2]|0;v=c[a+12464>>2]|0;w=c[a+12280>>2]|0;x=c[a+12284>>2]|0;y=c[a+12248>>2]|0;z=c[a+10492+(j<<2)>>2]|0;A=j+1|0;B=c[a+10492+(A<<2)>>2]|0;if((c[a+12124>>2]|0)!=0){C=g;D=0;E=0;c[b>>2]=E;c[f>>2]=D;return C|0}F=c[a+12120>>2]|0;do{if((c[F+232>>2]|0)==(c[F+236>>2]|0)){G=g}else{H=y&1;do{if((y&4|0)==0){I=c[a+12416>>2]|0;J=c[a+12420>>2]|0;K=a;L=(c[a+12352+(i<<4)>>2]|0)+((ba(I,m)|0)+l)|0;M=Pe[z&255](K,c[a+12288+(h<<4)>>2]|0,L,I,k)|0;if((y&2|0)==0){N=M;break}L=p&2|l&1;O=c[a+12208>>2]|0;P=I<<4;I=O+P|0;Q=a+12444|0;R=(ba(J,m>>1)|0)+(l>>1)|0;S=k>>1;cf[c[(c[Q>>2]|0)+(A<<4)+(L<<2)>>2]&1023](I,(c[a+12352+(i<<4)+4>>2]|0)+R|0,J,S);T=O+(P|8)|0;cf[c[(c[Q>>2]|0)+(A<<4)+(L<<2)>>2]&1023](T,(c[a+12352+(i<<4)+8>>2]|0)+R|0,J,S);R=(Pe[B&255](K,I,c[a+12288+(h<<4)+4>>2]|0,J,S)|0)+M|0;N=R+(Pe[B&255](K,T,c[a+12288+(h<<4)+8>>2]|0,J,S)|0)|0}else{S=c[a+12416>>2]|0;J=H+1|0;T=l<<J;K=m<<J;R=a+12352+(i<<4)|0;M=a+12288+(h<<4)|0;if((r|0)>(l|0)){N=536870912;break}if((T|0)>(t<<J|0)|(s|0)>(m|0)){N=536870912;break}if((K|0)>(u<<J|0)){N=536870912;break}I=e[a+13872>>1]|0;L=e[a+13874>>1]|0;Q=H<<1|1;a:do{if((c[a+11740>>2]|0)==1){P=L-I|0;O=H|4;U=(K|0)==0;V=a+12208|0;W=S<<3;X=(H|0)==0;Y=a+12444|0;Z=a+12448|0;_=a+12352+(i<<4)+32|0;$=a+12452|0;aa=a+12456|0;if((T|0)==0){ca=0;while(1){da=c[a+12160+(ca<<3)>>2]|0;ea=(c[a+12160+(ca<<3)+4>>2]|0)+K|0;fa=((ba(c[a+12128+(ca<<3)>>2]|0,P)|0)/(I|0)|0)+((ca&1)<<O)|0;ga=c[a+12128+(ca<<3)+4>>2]|0;if(U){ha=ca>>1;ia=((ba(ga,P)|0)/(I|0)|0)+(ha<<O)|0;ja=ha}else{ia=ea-ga|0;ja=ca>>1}ga=((ea&Q)<<J)+(da&Q)|0;ha=((ia&Q)<<J)+(fa&Q)|0;ka=(c[V>>2]|0)+((ba(ja,W)|0)+(ca<<3&8))|0;if(X){la=(c[R>>2]|0)+((ba(ea>>1,S)|0)+(da>>1))|0;cf[c[(c[Y>>2]|0)+16+(ga<<2)>>2]&1023](ka,la,S,8);la=(c[_>>2]|0)+((ba(ia>>1,S)|0)+(fa>>1))|0;cf[c[(c[Z>>2]|0)+16+(ha<<2)>>2]&1023](ka,la,S,8)}else{la=(c[R>>2]|0)+((ba(ea>>2,S)|0)+(da>>2))|0;Xe[c[(c[$>>2]|0)+64+(ga<<2)>>2]&4095](ka,la,S);la=(c[_>>2]|0)+((ba(ia>>2,S)|0)+(fa>>2))|0;Xe[c[(c[aa>>2]|0)+64+(ha<<2)>>2]&4095](ka,la,S)}ca=ca+1|0;if((ca|0)>=4){break a}}}if(U){ca=0;do{la=(c[a+12160+(ca<<3)>>2]|0)+T|0;ka=c[a+12160+(ca<<3)+4>>2]|0;ha=la-(c[a+12128+(ca<<3)>>2]|0)|0;fa=ca>>1;ga=((ba(c[a+12128+(ca<<3)+4>>2]|0,P)|0)/(I|0)|0)+(fa<<O)|0;da=((ka&Q)<<J)+(la&Q)|0;ea=((ga&Q)<<J)+(ha&Q)|0;ma=(c[V>>2]|0)+((ca<<3&8)+(ba(fa,W)|0))|0;if(X){fa=(c[R>>2]|0)+((ba(ka>>1,S)|0)+(la>>1))|0;cf[c[(c[Y>>2]|0)+16+(da<<2)>>2]&1023](ma,fa,S,8);fa=(c[_>>2]|0)+((ba(ga>>1,S)|0)+(ha>>1))|0;cf[c[(c[Z>>2]|0)+16+(ea<<2)>>2]&1023](ma,fa,S,8)}else{fa=(c[R>>2]|0)+((ba(ka>>2,S)|0)+(la>>2))|0;Xe[c[(c[$>>2]|0)+64+(da<<2)>>2]&4095](ma,fa,S);fa=(c[_>>2]|0)+((ba(ga>>2,S)|0)+(ha>>2))|0;Xe[c[(c[aa>>2]|0)+64+(ea<<2)>>2]&4095](ma,fa,S)}ca=ca+1|0;}while((ca|0)<4)}else{ca=0;do{O=(c[a+12160+(ca<<3)>>2]|0)+T|0;P=(c[a+12160+(ca<<3)+4>>2]|0)+K|0;U=O-(c[a+12128+(ca<<3)>>2]|0)|0;fa=P-(c[a+12128+(ca<<3)+4>>2]|0)|0;ma=((P&Q)<<J)+(O&Q)|0;ea=((fa&Q)<<J)+(U&Q)|0;ha=(c[V>>2]|0)+((ca<<3&8)+(ba(ca>>1,W)|0))|0;if(X){ga=(c[R>>2]|0)+((ba(P>>1,S)|0)+(O>>1))|0;cf[c[(c[Y>>2]|0)+16+(ma<<2)>>2]&1023](ha,ga,S,8);ga=(c[_>>2]|0)+((ba(fa>>1,S)|0)+(U>>1))|0;cf[c[(c[Z>>2]|0)+16+(ea<<2)>>2]&1023](ha,ga,S,8)}else{ga=(c[R>>2]|0)+((ba(P>>2,S)|0)+(O>>2))|0;Xe[c[(c[$>>2]|0)+64+(ma<<2)>>2]&4095](ha,ga,S);ga=(c[_>>2]|0)+((ba(fa>>2,S)|0)+(U>>2))|0;Xe[c[(c[aa>>2]|0)+64+(ea<<2)>>2]&4095](ha,ga,S)}ca=ca+1|0;}while((ca|0)<4)}}else{ca=(c[a+12160>>2]|0)+T|0;aa=(c[a+12164>>2]|0)+K|0;_=c[a+12128>>2]|0;if((T|0)==0){na=(ba(_,L-I|0)|0)/(I|0)|0}else{na=ca-_|0}_=c[a+12132>>2]|0;if((K|0)==0){oa=(ba(_,L-I|0)|0)/(I|0)|0}else{oa=aa-_|0}_=((aa&Q)<<J)+(ca&Q)|0;$=((oa&Q)<<J)+(na&Q)|0;if((H|0)==0){Z=a+12208|0;Y=(c[R>>2]|0)+((ba(aa>>1,S)|0)+(ca>>1))|0;cf[c[(c[a+12444>>2]|0)+(_<<2)>>2]&1023](c[Z>>2]|0,Y,S,16);Y=(c[a+12352+(i<<4)+32>>2]|0)+((ba(oa>>1,S)|0)+(na>>1))|0;cf[c[(c[a+12448>>2]|0)+($<<2)>>2]&1023](c[Z>>2]|0,Y,S,16);break}else{Y=a+12452|0;Z=a+12208|0;X=(ba(aa>>2,S)|0)+(ca>>2)|0;Xe[c[(c[Y>>2]|0)+64+(_<<2)>>2]&4095](c[Z>>2]|0,(c[R>>2]|0)+X|0,S);ca=X+8|0;Xe[c[(c[Y>>2]|0)+64+(_<<2)>>2]&4095]((c[Z>>2]|0)+8|0,(c[R>>2]|0)+ca|0,S);aa=S<<3;Xe[c[(c[Y>>2]|0)+64+(_<<2)>>2]&4095]((c[Z>>2]|0)+aa|0,(c[R>>2]|0)+(X+aa)|0,S);X=aa+8|0;Xe[c[(c[Y>>2]|0)+64+(_<<2)>>2]&4095]((c[Z>>2]|0)+X|0,(c[R>>2]|0)+(ca+aa)|0,S);ca=a+12456|0;_=a+12352+(i<<4)+32|0;Y=(ba(oa>>2,S)|0)+(na>>2)|0;Xe[c[(c[ca>>2]|0)+64+($<<2)>>2]&4095](c[Z>>2]|0,(c[_>>2]|0)+Y|0,S);W=Y+8|0;Xe[c[(c[ca>>2]|0)+64+($<<2)>>2]&4095]((c[Z>>2]|0)+8|0,(c[_>>2]|0)+W|0,S);Xe[c[(c[ca>>2]|0)+64+($<<2)>>2]&4095]((c[Z>>2]|0)+aa|0,(c[_>>2]|0)+(Y+aa)|0,S);Xe[c[(c[ca>>2]|0)+64+($<<2)>>2]&4095]((c[Z>>2]|0)+X|0,(c[_>>2]|0)+(W+aa)|0,S);break}}}while(0);N=Pe[z&255](a,c[a+12208>>2]|0,c[M>>2]|0,S,16)|0}}while(0);if(!((m|l|0)!=0|(j|0)>0)){G=N;break}G=(ba((d[v+(p-x)|0]|0)+(d[v+(o-w)|0]|0)|0,n)|0)+N|0}}while(0);if(!((l|0)>(r|0)&(l|0)<(t|0)&(m|0)>(s|0)&(m|0)<(u|0))){C=G;D=p;E=o;c[b>>2]=E;c[f>>2]=D;return C|0}u=(m<<3)+l|0;s=v+(o-w)|0;t=d[s]|0;r=c[a+12232>>2]|0;N=(ba((d[v+(p-2-x)|0]|0)+t|0,r)|0)+(c[q+((u+56&63)<<2)>>2]|0)|0;na=v+(p-x)|0;oa=d[na]|0;ia=(ba(oa+(d[v+(o-2-w)|0]|0)|0,r)|0)+(c[q+((u+63&63)<<2)>>2]|0)|0;ja=(ba((d[v+(o+2-w)|0]|0)+oa|0,r)|0)+(c[q+((u+1&63)<<2)>>2]|0)|0;oa=(ba((d[v+(p+2-x)|0]|0)+t|0,r)|0)+(c[q+((u+8&63)<<2)>>2]|0)|0;if((N|0)>(oa|0)){if((ia|0)>(ja|0)){if((ja+N|0)>(oa+ia|0)){u=l-1|0;q=u<<1|1;r=p|1;t=Kmb(a,u,m,1,1,j,k,i,h,z,B,y)|0;u=v+(r-x)|0;A=(ba((d[u]|0)+(d[v+(q-w)|0]|0)|0,n)|0)+t|0;t=(A|0)<(G|0);g=o|1;pa=t?A:G;qa=t?q:o;ra=t?r:p;sa=g;ta=v+(g-w)|0;ua=r;va=u}else{u=o|1;r=m-1|0;g=r<<1|1;t=Kmb(a,l,r,1,1,j,k,i,h,z,B,y)|0;r=v+(u-w)|0;q=(ba((d[v+(g-x)|0]|0)+(d[r]|0)|0,n)|0)+t|0;t=(q|0)<(G|0);A=p|1;pa=t?q:G;qa=t?u:o;ra=t?g:p;sa=u;ta=r;ua=A;va=v+(A-x)|0}A=Kmb(a,l,m,1,0,j,k,i,h,z,B,y)|0;r=(ba((d[na]|0)+(d[ta]|0)|0,n)|0)+A|0;A=(r|0)<(pa|0);u=A?r:pa;pa=Kmb(a,l,m,1,1,j,k,i,h,z,B,y)|0;r=(ba((d[va]|0)+(d[ta]|0)|0,n)|0)+pa|0;pa=(r|0)<(u|0);wa=pa?r:u;xa=pa?sa:A?sa:qa;ya=pa?ua:A?p:ra}else{if((ia+N|0)>(oa+ja|0)){ra=o|1;A=p|1;ua=Kmb(a,l,m,1,1,j,k,i,h,z,B,y)|0;pa=v+(A-x)|0;qa=(ba((d[pa]|0)+(d[v+(ra-w)|0]|0)|0,n)|0)+ua|0;ua=(qa|0)<(G|0);sa=l-1|0;u=sa<<1|1;za=ua?qa:G;Aa=ua?ra:o;Ba=ua?A:p;Ca=sa;Da=u;Ea=v+(u-w)|0;Fa=A;Ga=pa}else{pa=l-1|0;A=pa<<1|1;u=m-1|0;sa=u<<1|1;ua=Kmb(a,pa,u,1,1,j,k,i,h,z,B,y)|0;u=v+(A-w)|0;ra=(ba((d[v+(sa-x)|0]|0)+(d[u]|0)|0,n)|0)+ua|0;ua=(ra|0)<(G|0);qa=p|1;za=ua?ra:G;Aa=ua?A:o;Ba=ua?sa:p;Ca=pa;Da=A;Ea=u;Fa=qa;Ga=v+(qa-x)|0}qa=Kmb(a,Ca,m,1,0,j,k,i,h,z,B,y)|0;u=(ba((d[na]|0)+(d[Ea]|0)|0,n)|0)+qa|0;qa=(u|0)<(za|0);A=qa?u:za;za=Kmb(a,Ca,m,1,1,j,k,i,h,z,B,y)|0;Ca=(ba((d[Ga]|0)+(d[Ea]|0)|0,n)|0)+za|0;za=(Ca|0)<(A|0);wa=za?Ca:A;xa=za?Da:qa?Da:Aa;ya=za?Fa:qa?p:Ba}Ba=p|1;qa=Kmb(a,l,m,0,1,j,k,i,h,z,B,y)|0;Fa=(ba((d[v+(Ba-x)|0]|0)+(d[s]|0)|0,n)|0)+qa|0;qa=(Fa|0)<(wa|0);C=qa?Fa:wa;D=qa?Ba:ya;E=qa?o:xa;c[b>>2]=E;c[f>>2]=D;return C|0}else{xa=m-1|0;qa=xa<<1|1;ya=Kmb(a,l,xa,0,1,j,k,i,h,z,B,y)|0;Ba=v+(qa-x)|0;wa=(ba((d[Ba]|0)+(d[s]|0)|0,n)|0)+ya|0;ya=(wa|0)<(G|0);s=ya?qa:p;Fa=ya?wa:G;if((ia|0)>(ja|0)){G=o|1;wa=Kmb(a,l,xa,1,1,j,k,i,h,z,B,y)|0;ya=v+(G-w)|0;za=(ba((d[Ba]|0)+(d[ya]|0)|0,n)|0)+wa|0;wa=(za|0)<(Fa|0);Aa=wa?qa:s;Da=wa?G:o;A=wa?za:Fa;if((ia+N|0)>(oa+ja|0)){za=p|1;wa=Kmb(a,l,m,1,1,j,k,i,h,z,B,y)|0;Ca=(ba((d[v+(za-x)|0]|0)+(d[ya]|0)|0,n)|0)+wa|0;wa=(Ca|0)<(A|0);Ha=wa?Ca:A;Ia=wa?G:Da;Ja=wa?za:Aa}else{za=l-1|0;wa=za<<1|1;Ca=Kmb(a,za,xa,1,1,j,k,i,h,z,B,y)|0;za=(ba((d[Ba]|0)+(d[v+(wa-w)|0]|0)|0,n)|0)+Ca|0;Ca=(za|0)<(A|0);Ha=Ca?za:A;Ia=Ca?wa:Da;Ja=Ca?qa:Aa}Aa=Kmb(a,l,m,1,0,j,k,i,h,z,B,y)|0;Ca=(ba((d[na]|0)+(d[ya]|0)|0,n)|0)+Aa|0;Aa=(Ca|0)<(Ha|0);C=Aa?Ca:Ha;D=Aa?p:Ja;E=Aa?G:Ia;c[b>>2]=E;c[f>>2]=D;return C|0}else{Ia=l-1|0;G=Ia<<1|1;Aa=Kmb(a,Ia,xa,1,1,j,k,i,h,z,B,y)|0;Ja=v+(G-w)|0;Ha=(ba((d[Ba]|0)+(d[Ja]|0)|0,n)|0)+Aa|0;Aa=(Ha|0)<(Fa|0);Ca=Aa?qa:s;s=Aa?G:o;ya=Aa?Ha:Fa;if((ja+N|0)>(oa+ia|0)){ia=p|1;oa=Kmb(a,Ia,m,1,1,j,k,i,h,z,B,y)|0;N=(ba((d[v+(ia-x)|0]|0)+(d[Ja]|0)|0,n)|0)+oa|0;oa=(N|0)<(ya|0);Ka=oa?N:ya;La=oa?G:s;Ma=oa?ia:Ca}else{ia=o|1;o=Kmb(a,l,xa,1,1,j,k,i,h,z,B,y)|0;xa=(ba((d[Ba]|0)+(d[v+(ia-w)|0]|0)|0,n)|0)+o|0;o=(xa|0)<(ya|0);Ka=o?xa:ya;La=o?ia:s;Ma=o?qa:Ca}Ca=Kmb(a,Ia,m,1,0,j,k,i,h,z,B,y)|0;y=(ba((d[na]|0)+(d[Ja]|0)|0,n)|0)+Ca|0;Ca=(y|0)<(Ka|0);C=Ca?y:Ka;D=Ca?p:Ma;E=Ca?G:La;c[b>>2]=E;c[f>>2]=D;return C|0}}return 0}function omb(a,b,e,f,g,h,i,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;k=c[a+12236>>2]|0;l=c[a+12416>>2]|0;m=c[a+12220>>2]|0;n=c[a+12464>>2]|0;o=c[a+12280>>2]|0;p=c[a+12284>>2]|0;if((c[a+12124>>2]|0)!=0){q=f;r=0;s=0;c[b>>2]=s;c[e>>2]=r;return q|0}t=c[a+12288+(g<<4)>>2]|0;g=c[b>>2]|0;u=c[e>>2]|0;v=c[a+12352+(h<<4)>>2]|0;h=(ba(u,l)|0)+g|0;if(!((g|0)>(c[a+12264>>2]|0)&(g|0)<(c[a+12268>>2]|0)&(u|0)>(c[a+12272>>2]|0)&(u|0)<(c[a+12276>>2]|0))){q=f;r=u<<1;s=g<<1;c[b>>2]=s;c[e>>2]=r;return q|0}w=(u<<3)+g|0;x=c[m+((w+56&63)<<2)>>2]|0;y=c[m+((w+63&63)<<2)>>2]|0;z=c[m+((w+1&63)<<2)>>2]|0;A=c[m+((w+8&63)<<2)>>2]|0;w=g<<1;g=u<<1;u=w+o|0;o=g+p|0;p=h-l|0;m=v+p|0;do{if((x|0)>(A|0)){if((y|0)>(z|0)){B=a+11096+(i<<4)+12|0;C=c[B>>2]|0;if((z+x|0)>(A+y|0)){D=Pe[C&255](0,t,v+(h-1)|0,l,j)|0;E=n+(o+1)|0;F=(ba((d[E]|0)+(d[n+(u-1)|0]|0)|0,k)|0)+D|0;D=(F|0)<(f|0);G=D?F:f;H=D<<31>>31;I=D&1;J=n+(u+1)|0;K=E}else{E=Pe[C&255](0,t,m,l,j)|0;C=n+(u+1)|0;D=(ba((d[n+(o-1)|0]|0)+(d[C]|0)|0,k)|0)+E|0;E=(D|0)<(f|0);G=E?D:f;H=E&1;I=E<<31>>31;J=C;K=n+(o+1)|0}C=v+h|0;E=Pe[c[a+11096+(i<<4)+4>>2]&255](0,t,C,l,j)|0;D=(ba((d[n+o|0]|0)+(d[J]|0)|0,k)|0)+E|0;E=(D|0)<(G|0);F=E?D:G;D=Pe[c[B>>2]&255](0,t,C,l,j)|0;B=(ba((d[K]|0)+(d[J]|0)|0,k)|0)+D|0;D=(B|0)<(F|0);L=D?B:F;M=C;N=D?1:E?1:H;O=D?1:E?0:I}else{if((y+x|0)>(A+z|0)){E=v+h|0;D=Pe[c[a+11096+(i<<4)+12>>2]&255](0,t,E,l,j)|0;C=n+(o+1)|0;F=(ba((d[C]|0)+(d[n+(u+1)|0]|0)|0,k)|0)+D|0;D=(F|0)<(f|0);P=D?F:f;Q=E;R=D&1;S=n+(u-1)|0;T=C}else{C=Pe[c[a+11096+(i<<4)+12>>2]&255](0,t,v+(p-1)|0,l,j)|0;D=n+(u-1)|0;E=(ba((d[n+(o-1)|0]|0)+(d[D]|0)|0,k)|0)+C|0;C=(E|0)<(f|0);P=C?E:f;Q=v+h|0;R=C<<31>>31;S=D;T=n+(o+1)|0}D=Q-1|0;C=Pe[c[a+11096+(i<<4)+4>>2]&255](0,t,D,l,j)|0;E=(ba((d[n+o|0]|0)+(d[S]|0)|0,k)|0)+C|0;C=(E|0)<(P|0);F=C?E:P;E=Pe[c[a+11096+(i<<4)+12>>2]&255](0,t,D,l,j)|0;D=(ba((d[T]|0)+(d[S]|0)|0,k)|0)+E|0;E=(D|0)<(F|0);L=E?D:F;M=Q;N=E?-1:C?-1:R;O=E?1:C?0:R}C=Pe[c[a+11096+(i<<4)+8>>2]&255](0,t,M,l,j)|0;E=(ba((d[n+(o+1)|0]|0)+(d[n+u|0]|0)|0,k)|0)+C|0;C=(E|0)<(L|0);U=C?E:L;V=C?0:N;W=C?1:O}else{C=Pe[c[a+11096+(i<<4)+8>>2]&255](0,t,m,l,j)|0;E=n+(o-1)|0;F=(ba((d[E]|0)+(d[n+u|0]|0)|0,k)|0)+C|0;C=(F|0)<(f|0);D=C<<31>>31;B=C?F:f;F=a+11096+(i<<4)+12|0;C=c[F>>2]|0;if((y|0)>(z|0)){X=Pe[C&255](0,t,m,l,j)|0;Y=n+(u+1)|0;Z=(ba((d[E]|0)+(d[Y]|0)|0,k)|0)+X|0;X=(Z|0)<(B|0);_=X?-1:D;$=X&1;aa=X?Z:B;if((y+x|0)>(A+z|0)){Z=v+h|0;X=Pe[c[F>>2]&255](0,t,Z,l,j)|0;ca=(ba((d[n+(o+1)|0]|0)+(d[Y]|0)|0,k)|0)+X|0;X=(ca|0)<(aa|0);da=X?ca:aa;ea=Z;fa=X?1:$;ga=X?1:_}else{X=Pe[c[F>>2]&255](0,t,v+(p-1)|0,l,j)|0;Z=(ba((d[E]|0)+(d[n+(u-1)|0]|0)|0,k)|0)+X|0;X=(Z|0)<(aa|0);da=X?Z:aa;ea=v+h|0;fa=X?-1:$;ga=X?-1:_}_=Pe[c[a+11096+(i<<4)+4>>2]&255](0,t,ea,l,j)|0;X=(ba((d[n+o|0]|0)+(d[Y]|0)|0,k)|0)+_|0;_=(X|0)<(da|0);U=_?X:da;V=_?1:fa;W=_?0:ga;break}else{_=Pe[C&255](0,t,v+(p-1)|0,l,j)|0;C=n+(u-1)|0;X=(ba((d[E]|0)+(d[C]|0)|0,k)|0)+_|0;_=(X|0)<(B|0);Y=_?-1:D;D=_<<31>>31;$=_?X:B;B=c[F>>2]|0;if((z+x|0)>(A+y|0)){F=v+(h-1)|0;X=Pe[B&255](0,t,F,l,j)|0;_=(ba((d[n+(o+1)|0]|0)+(d[C]|0)|0,k)|0)+X|0;X=(_|0)<($|0);ha=X?_:$;ia=X?-1:D;ja=X?1:Y;ka=F}else{F=Pe[B&255](0,t,m,l,j)|0;B=(ba((d[E]|0)+(d[n+(u+1)|0]|0)|0,k)|0)+F|0;F=(B|0)<($|0);ha=F?B:$;ia=F?1:D;ja=F?-1:Y;ka=v+(h-1)|0}Y=Pe[c[a+11096+(i<<4)+4>>2]&255](0,t,ka,l,j)|0;F=(ba((d[n+o|0]|0)+(d[C]|0)|0,k)|0)+Y|0;Y=(F|0)<(ha|0);U=Y?F:ha;V=Y?-1:ia;W=Y?0:ja;break}}}while(0);q=U;r=W+g|0;s=V+w|0;c[b>>2]=s;c[e>>2]=r;return q|0}function pmb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function qmb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return}function rmb(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[b>>2]=c[b>>2]<<1;c[d>>2]=c[d>>2]<<1;return e|0}function smb(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;h=i;i=i+96|0;j=h|0;k=h+8|0;l=h+16|0;m=c[e+13924>>2]|0;n=m+1|0;o=f<<4;p=g<<4;q=c[e+12416>>2]|0;r=(ba(q,p)|0)+o|0;s=c[e+12420>>2]|0;t=(ba(s,p)|0)+o>>1;u=e+12288|0;c[u>>2]=(c[e+5400>>2]|0)+r;v=e+12352|0;c[v>>2]=(c[e+952>>2]|0)+r;c[e+12292>>2]=(c[e+5404>>2]|0)+t;c[e+12356>>2]=(c[e+956>>2]|0)+t;c[e+12296>>2]=(c[e+5408>>2]|0)+t;c[e+12360>>2]=(c[e+960>>2]|0)+t;if(!(m>>>0<2>>>0)){yDb(0,0,2098584,(w=i,i=i+24|0,c[w>>2]=2043408,c[w+8>>2]=1998240,c[w+16>>2]=883,w)|0);i=w;Cd()}m=e+148|0;if((c[m>>2]|0)!=(q|0)){yDb(0,0,2098584,(w=i,i=i+24|0,c[w>>2]=1961472,c[w+8>>2]=1998240,c[w+16>>2]=884,w)|0);i=w;Cd()}if((c[e+152>>2]|0)!=(s|0)){yDb(0,0,2098584,(w=i,i=i+24|0,c[w>>2]=1933600,c[w+8>>2]=1998240,c[w+16>>2]=885,w)|0);i=w;Cd()}w=c[e+9968>>2]|0;s=e+9972|0;q=c[s>>2]|0;t=e+12120|0;r=c[t>>2]|0;switch(c[r+232>>2]&255|0){case 3:{x=(w*3|0)>>8;break};case 11:{x=w>>5;break};case 12:{x=w>>6;break};case 2:case 14:{x=w>>6;break};case 6:case 4:case 1:case 10:{x=q>>7;break};case 5:{x=1;break};default:{x=w>>7}}c[e+12232>>2]=x;switch(c[r+236>>2]&255|0){case 3:{y=(w*3|0)>>8;break};case 11:{y=w>>5;break};case 12:{y=w>>6;break};case 2:case 14:{y=w>>6;break};case 6:case 4:case 1:case 10:{y=q>>7;break};case 5:{y=1;break};default:{y=w>>7}}c[e+12236>>2]=y;switch(c[r+240>>2]&255|0){case 3:{z=(w*3|0)>>8;break};case 11:{z=w>>5;break};case 12:{z=w>>6;break};case 2:case 14:{z=w>>6;break};case 6:case 4:case 1:case 10:{z=q>>7;break};case 5:{z=1;break};default:{z=w>>7}}w=e+12240|0;c[w>>2]=z;c[e+12464>>2]=(c[e+12460>>2]|0)+((c[e+11556>>2]|0)*8193|0)+4096;tmb(e,o,p);p=e+12124|0;c[p>>2]=0;o=c[u>>2]|0;u=Oe[c[e+10100>>2]&1023](o,c[m>>2]|0)|0;z=(Oe[c[e+10104>>2]&1023](o,c[m>>2]|0)|0)-((ba(u,u)|0)>>>8)|0;q=z+500|0;r=u+128>>8;u=e+124|0;y=(ba(c[u>>2]|0,g)|0)+f|0;a[(c[e+9216>>2]|0)+y|0]=r;y=z+628>>8;x=(ba(c[u>>2]|0,g)|0)+f|0;b[(c[e+9192>>2]|0)+(x<<1)>>1]=y;x=e+12432|0;A=YGb(c[x>>2]|0,c[x+4>>2]|0,y,(y|0)<0|0?-1:0)|0;c[x>>2]=A;c[x+4>>2]=F;if(((c[e+11732>>2]|0)-5|0)>>>0<2>>>0){x=c[e+128>>2]|0;A=c[e+12496>>2]|0;y=A-1|0;B=c[e+9148>>2]|0;C=b[B+(y<<2)>>1]|0;D=l+8|0;c[D>>2]=C;E=b[B+(y<<2)+2>>1]|0;c[l+12>>2]=E;y=c[e+12268>>2]<<n;if((C|0)>(y|0)){c[D>>2]=y;G=y}else{G=C}do{if((c[e+14084>>2]|0)==0){C=A-x|0;y=b[B+(C<<2)>>1]|0;c[l+16>>2]=y;D=b[B+(C<<2)+2>>1]|0;H=l+20|0;c[H>>2]=D;I=C+2|0;C=b[B+(I<<2)>>1]|0;J=l+24|0;c[J>>2]=C;K=b[B+(I<<2)+2>>1]|0;I=l+28|0;c[I>>2]=K;L=c[e+12276>>2]<<n;if((D|0)>(L|0)){c[H>>2]=L;M=L}else{M=D}D=c[e+12264>>2]<<n;if((C|0)<(D|0)){c[J>>2]=D;N=D}else{N=C}if((K|0)>(L|0)){c[I>>2]=L;O=L}else{O=K}do{if((G|0)>(y|0)){if((N|0)<=(y|0)){P=y;break}P=(N|0)>(G|0)?G:N}else{if((y|0)<=(N|0)){P=y;break}P=(N|0)>(G|0)?N:G}}while(0);c[l+32>>2]=P;do{if((E|0)>(M|0)){if((O|0)<=(M|0)){Q=M;break}Q=(O|0)>(E|0)?E:O}else{if((M|0)<=(O|0)){Q=M;break}Q=(O|0)>(E|0)?O:E}}while(0);c[l+36>>2]=Q;y=e+12280|0;if((c[e+28>>2]|0)==2){c[y>>2]=P;c[e+12284>>2]=Q;break}else{c[y>>2]=G;c[e+12284>>2]=E;break}}else{c[e+12280>>2]=G;c[e+12284>>2]=E}}while(0);E=kmb(e,j,k,l|0,0,0,c[e+11636>>2]|0,65536>>>(n>>>0),0,16)|0;R=E;S=c[k>>2]|0;T=c[j>>2]|0}else{c[j>>2]=0;c[k>>2]=0;R=0;S=0;T=0}E=c[m>>2]|0;l=(c[v>>2]|0)+((ba(E,S)|0)+T)|0;v=Pe[c[e+10132>>2]&255](0,o,l,E,16)|0;E=v+128>>8;l=(ba(c[u>>2]|0,g)|0)+f|0;b[(c[e+9200>>2]|0)+(l<<1)>>1]=E;l=e+12424|0;G=YGb(c[l>>2]|0,c[l+4>>2]|0,E,(E|0)<0|0?-1:0)|0;c[l>>2]=G;c[l+4>>2]=F;if((c[(c[t>>2]|0)+296>>2]|0)>0){l=(c[s>>2]|0)>>>7;G=(l*100|0)+z|0;E=v>>>0>G>>>0?G:v;G=(l*20|0)+z|0;if(E>>>0<255>>>0){U=(d[E+1135649|0]|0)-1>>4}else{do{if(E>>>0<4096>>>0){V=(d[1135648+(E>>>4)|0]|0)>>>2}else{if(E>>>0<16384>>>0){V=(d[1135648+(E>>>6)|0]|0)>>>1;break}if(E>>>0<65536>>>0){V=d[1135648+(E>>>8)|0]|0;break}else{l=E>>>16;Q=(l&65280|0)==0;P=((d[1191992+(Q?l:E>>>24)|0]|0)+(Q?0:8)|0)>>>1;Q=E>>>((P+2|0)>>>0);l=d[1135648+(Q>>>((P+8|0)>>>0))|0]|0;gHb(Q,0,c[1199552+(l<<2)>>2]|0,0)|0;V=F+(l<<P)|0;break}}}while(0);U=V-((ba(V,V)|0)>>>0>E>>>0)|0}if(G>>>0<255>>>0){W=(d[G+1135649|0]|0)-1>>4}else{do{if(G>>>0<4096>>>0){X=(d[1135648+(G>>>4)|0]|0)>>>2}else{if(G>>>0<16384>>>0){X=(d[1135648+(G>>>6)|0]|0)>>>1;break}if(G>>>0<65536>>>0){X=d[1135648+(G>>>8)|0]|0;break}else{E=G>>>16;V=(E&65280|0)==0;P=((d[1191992+(V?E:G>>>24)|0]|0)+(V?0:8)|0)>>>1;V=G>>>((P+2|0)>>>0);E=d[1135648+(V>>>((P+8|0)>>>0))|0]|0;gHb(V,0,c[1199552+(E<<2)>>2]|0,0)|0;X=F+(E<<P)|0;break}}}while(0);W=X-((ba(X,X)|0)>>>0>G>>>0)|0}G=e+12440|0;c[G>>2]=U-W+(c[G>>2]|0);G=((v<<1)+51200|0)>(q|0)|0;do{if(((q<<1)+51200|0)>(v|0)){Y=77}else{if((c[e+9960>>2]|0)>24){Y=77;break}c[j>>2]=T<<n;c[k>>2]=S<<n;Z=G;_=c[e+60>>2]|0}}while(0);do{if((Y|0)==77){S=G|2;Ze[c[e+12468>>2]&15](e,j,k,R,0,0,0,16)|0;T=c[e+60>>2]|0;if((T&64|0)==0){Z=S;_=T;break}if((c[j>>2]|0)==0){if((c[k>>2]|0)==0){Z=S;_=T;break}}Z=G|10;_=T}}while(0);G=e+60|0;do{if((_&4|0)==0){Y=85}else{if(!((c[p>>2]|0)==0&(q|0)>12800&(v|0)>2560)){Y=85;break}T=(umb(e,c[j>>2]|0,c[k>>2]|0,n)|0)==2147483647;S=c[j>>2]|0;W=c[k>>2]|0;U=(ba(c[u>>2]|0,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;X=c[e+11636>>2]|0;b[X+(U<<2)>>1]=S;b[X+(U<<2)+2>>1]=W;$=T?Z:Z|4;aa=S;ca=W}}while(0);if((Y|0)==85){Y=c[j>>2]|0;_=c[k>>2]|0;W=(ba(c[u>>2]|0,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;S=Y&65535;T=c[e+11636>>2]|0;b[T+(W<<2)>>1]=S;U=_&65535;b[T+(W<<2)+2>>1]=U;W=c[e+12496>>2]|0;T=c[e+9148>>2]|0;b[T+(W<<2)>>1]=S;b[T+(W<<2)+2>>1]=U;X=W+1|0;b[T+(X<<2)>>1]=S;b[T+(X<<2)+2>>1]=U;X=(c[e+128>>2]|0)+W|0;b[T+(X<<2)>>1]=S;b[T+(X<<2)+2>>1]=U;W=X+1|0;b[T+(W<<2)>>1]=S;b[T+(W<<2)+2>>1]=U;$=Z;aa=Y;ca=_}_=$&65535;if((c[G>>2]&536870912|0)==0){da=_;ea=c[u>>2]|0;fa=ba(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}if((c[p>>2]|0)!=0){da=_;ea=c[u>>2]|0;fa=ba(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}if((vmb(e,0,e+11660|0,e+11708|0,aa,ca)|0)==2147483647){da=_;ea=c[u>>2]|0;fa=ba(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}da=($|256)&65535;ea=c[u>>2]|0;fa=ba(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}$=Ze[c[e+12468>>2]&15](e,j,k,R,0,0,0,16)|0;R=c[t>>2]|0;do{if((c[R+236>>2]|0)==(c[R+240>>2]|0)){ka=$}else{if((c[p>>2]|0)!=0){ka=$;break}ka=jmb(e,c[j>>2]|0,c[k>>2]|0,0,0,0,16,1)|0}}while(0);$=e+60|0;R=c[$>>2]|0;do{if((R&4|0)==0){la=ka;ma=2;na=R}else{if(!((c[p>>2]|0)==0&(q|0)>12800&(v|0)>2560)){la=ka;ma=2;na=R;break}_=umb(e,c[j>>2]|0,c[k>>2]|0,n)|0;ca=(_|0)<(ka|0);la=ca?_:ka;ma=ca?4:2;na=c[$>>2]|0}}while(0);do{if((na&536870912|0)==0){oa=la;pa=ma}else{if((c[p>>2]|0)!=0){oa=la;pa=ma;break}$=vmb(e,0,e+11660|0,e+11708|0,c[j>>2]|0,c[k>>2]|0)|0;ka=($|0)<(la|0);oa=ka?$:la;pa=ka?256:ma}}while(0);ma=c[k>>2]|0;k=c[u>>2]|0;la=(ba(k,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;p=c[j>>2]&65535;j=c[e+11636>>2]|0;b[j+(la<<2)>>1]=p;na=ma&65535;b[j+(la<<2)+2>>1]=na;if((pa|0)!=4){la=c[e+12496>>2]|0;j=c[e+9148>>2]|0;b[j+(la<<2)>>1]=p;b[j+(la<<2)+2>>1]=na;ma=la+1|0;b[j+(ma<<2)>>1]=p;b[j+(ma<<2)+2>>1]=na;ma=(c[e+128>>2]|0)+la|0;b[j+(ma<<2)>>1]=p;b[j+(ma<<2)+2>>1]=na;la=ma+1|0;b[j+(la<<2)>>1]=p;b[j+(la<<2)+2>>1]=na}if((c[(c[t>>2]|0)+240>>2]&255|0)==1){qa=z;ra=k}else{k=ba(r,16843009)|0;r=c[e+12192>>2]|0;t=0;do{c[r+(ba(c[m>>2]|0,t)|0)>>2]=k;c[r+((ba(c[m>>2]|0,t)|0)+4)>>2]=k;c[r+((ba(c[m>>2]|0,t)|0)+8)>>2]=k;c[r+((ba(c[m>>2]|0,t)|0)+12)>>2]=k;t=t+1|0;}while((t|0)<16);t=Pe[c[e+10516>>2]&255](e,r,o,c[m>>2]|0,16)|0;qa=t;ra=c[u>>2]|0}t=(ba(ra,g)|0)+f|0;ra=(c[e+9160>>2]|0)+(t<<2)|0;if(((c[w>>2]<<4)+qa|0)<(oa|0)){c[ra>>2]=1;sa=1}else{c[ra>>2]=0;sa=pa&65535}pa=(c[s>>2]|0)>>>7;s=(pa*100|0)+z|0;ra=v>>>0>s>>>0?s:v;v=(pa*20|0)+z|0;if(ra>>>0<255>>>0){ta=(d[ra+1135649|0]|0)-1>>4}else{do{if(ra>>>0<4096>>>0){ua=(d[1135648+(ra>>>4)|0]|0)>>>2}else{if(ra>>>0<16384>>>0){ua=(d[1135648+(ra>>>6)|0]|0)>>>1;break}if(ra>>>0<65536>>>0){ua=d[1135648+(ra>>>8)|0]|0;break}else{z=ra>>>16;pa=(z&65280|0)==0;s=((d[1191992+(pa?z:ra>>>24)|0]|0)+(pa?0:8)|0)>>>1;pa=ra>>>((s+2|0)>>>0);z=d[1135648+(pa>>>((s+8|0)>>>0))|0]|0;gHb(pa,0,c[1199552+(z<<2)>>2]|0,0)|0;ua=F+(z<<s)|0;break}}}while(0);ta=ua-((ba(ua,ua)|0)>>>0>ra>>>0)|0}if(v>>>0<255>>>0){va=(d[v+1135649|0]|0)-1>>4}else{do{if(v>>>0<4096>>>0){wa=(d[1135648+(v>>>4)|0]|0)>>>2}else{if(v>>>0<16384>>>0){wa=(d[1135648+(v>>>6)|0]|0)>>>1;break}if(v>>>0<65536>>>0){wa=d[1135648+(v>>>8)|0]|0;break}else{ra=v>>>16;ua=(ra&65280|0)==0;s=((d[1191992+(ua?ra:v>>>24)|0]|0)+(ua?0:8)|0)>>>1;ua=v>>>((s+2|0)>>>0);ra=d[1135648+(ua>>>((s+8|0)>>>0))|0]|0;gHb(ua,0,c[1199552+(ra<<2)>>2]|0,0)|0;wa=F+(ra<<s)|0;break}}}while(0);va=wa-((ba(wa,wa)|0)>>>0>v>>>0)|0}v=e+12440|0;c[v>>2]=ta-va+(c[v>>2]|0);da=sa;ea=c[u>>2]|0;fa=ba(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}function tmb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=-d|0;f=-b|0;g=(c[a+12244>>2]&1)+1|0;h=c[(c[a+12120>>2]|0)+276>>2]>>g;i=4096>>>(g>>>0);do{if((c[a+10048>>2]|0)==0){if((c[a+28>>2]|0)==1){g=(b|0)>15?-15:0;c[a+12264>>2]=g;j=(d|0)>15?-15:0;c[a+12272>>2]=j;k=((c[a+116>>2]<<4)-16|0)>(b|0)?15:0;c[a+12268>>2]=k;l=((c[a+120>>2]<<4)-16|0)>(d|0)?15:0;c[a+12276>>2]=l;m=g;n=k;o=j;p=l;break}else{c[a+12264>>2]=f;c[a+12272>>2]=e;l=-16-b+(c[a+116>>2]<<4)|0;c[a+12268>>2]=l;j=-16-d+(c[a+120>>2]<<4)|0;c[a+12276>>2]=j;m=f;n=l;o=e;p=j;break}}else{j=-16-b|0;c[a+12264>>2]=j;l=-16-d|0;c[a+12272>>2]=l;k=(c[a+8>>2]|0)-b|0;c[a+12268>>2]=k;g=(c[a+12>>2]|0)-d|0;c[a+12276>>2]=g;m=j;n=k;o=l;p=g}}while(0);d=(h|0)==0|(h|0)>(i|0)?i:h;if((d|0)==0){return}h=-d|0;c[a+12264>>2]=(m|0)>(h|0)?m:h;c[a+12268>>2]=(n|0)>(d|0)?d:n;c[a+12272>>2]=(o|0)>(h|0)?o:h;c[a+12276>>2]=(p|0)>(d|0)?d:p;return}function umb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;h=i;i=i+96|0;j=h|0;k=h+80|0;l=h+88|0;m=c[a+12416>>2]|0;n=c[a+12464>>2]|0;o=a+8|0;do{if((c[a+10048>>2]|0)==0){p=0}else{if((c[o>>2]&15|0)==0){p=0;break}p=(c[a+12>>2]&15|0)!=0}}while(0);q=c[a+12352>>2]|0;c[a+12368>>2]=q+8;r=m<<3;c[a+12384>>2]=q+r;s=r+8|0;c[a+12400>>2]=q+s;q=c[a+12288>>2]|0;c[a+12304>>2]=q+8;c[a+12320>>2]=q+r;c[a+12336>>2]=q+s;s=a+128|0;q=a+12476|0;r=a+12268|0;t=a+12480|0;u=a+12|0;v=a+12276|0;w=a+9148|0;x=j+8|0;y=j+12|0;z=a+14084|0;A=a+12280|0;B=a+12284|0;C=j+72|0;D=j+76|0;E=j|0;F=a+11636|0;G=65536>>>(g>>>0);H=a+12468|0;I=a+10492|0;J=a+10516|0;K=a+13924|0;L=a+12192|0;M=a+12472|0;N=a+12240|0;O=j+16|0;P=j+20|0;Q=j+24|0;R=j+28|0;S=a+12264|0;T=j+32|0;U=j+36|0;V=1;W=0;X=0;Y=0;Z=0;do{_=c[s>>2]|0;$=a+12496+(Z<<2)|0;aa=c[$>>2]|0;if(p){ca=(c[o>>2]|0)-(Z<<3&8)+((c[q>>2]|0)*-16|0)|0;c[r>>2]=ca;c[v>>2]=(c[u>>2]|0)-(Z>>1<<3)+((c[t>>2]|0)*-16|0);da=ca}else{da=c[r>>2]|0}ca=aa-1|0;ea=c[w>>2]|0;fa=b[ea+(ca<<2)>>1]|0;c[x>>2]=fa;ga=b[ea+(ca<<2)+2>>1]|0;c[y>>2]=ga;ca=da<<g;if((fa|0)>(ca|0)){c[x>>2]=ca;ha=ca}else{ha=fa}if((c[z>>2]|0)!=0&(Z|0)<2){ia=ga;ja=ha}else{fa=aa-_|0;_=b[ea+(fa<<2)>>1]|0;c[O>>2]=_;aa=b[ea+(fa<<2)+2>>1]|0;c[P>>2]=aa;ka=(c[985e3+(Z<<2)>>2]|0)+fa|0;fa=b[ea+(ka<<2)>>1]|0;c[Q>>2]=fa;la=b[ea+(ka<<2)+2>>1]|0;c[R>>2]=la;ka=c[v>>2]<<g;if((aa|0)>(ka|0)){c[P>>2]=ka;ma=ka}else{ma=aa}aa=c[S>>2]<<g;if((fa|0)<(aa|0)){c[Q>>2]=aa;na=aa}else{na=fa}if((na|0)>(ca|0)){c[Q>>2]=ca;oa=ca}else{oa=na}if((la|0)>(ka|0)){c[R>>2]=ka;pa=ka}else{pa=la}do{if((ha|0)>(_|0)){if((oa|0)<=(_|0)){qa=_;break}qa=(oa|0)>(ha|0)?ha:oa}else{if((_|0)<=(oa|0)){qa=_;break}qa=(oa|0)>(ha|0)?oa:ha}}while(0);c[T>>2]=qa;do{if((ga|0)>(ma|0)){if((pa|0)<=(ma|0)){ra=ma;break}ra=(pa|0)>(ga|0)?ga:pa}else{if((ma|0)<=(pa|0)){ra=ma;break}ra=(pa|0)>(ga|0)?pa:ga}}while(0);c[U>>2]=ra;ia=ra;ja=qa}c[A>>2]=ja;c[B>>2]=ia;c[C>>2]=e;c[D>>2]=f;do{if(p){_=c[v>>2]<<g;la=j|0;if((c[la>>2]|0)>(ca|0)){c[la>>2]=ca}la=j+4|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}if((ha|0)>(ca|0)){c[x>>2]=ca}if((ga|0)>(_|0)){c[y>>2]=_}if((c[O>>2]|0)>(ca|0)){c[O>>2]=ca}if((c[P>>2]|0)>(_|0)){c[P>>2]=_}if((c[Q>>2]|0)>(ca|0)){c[Q>>2]=ca}if((c[R>>2]|0)>(_|0)){c[R>>2]=_}if((c[T>>2]|0)>(ca|0)){c[T>>2]=ca}if((c[U>>2]|0)>(_|0)){c[U>>2]=_}la=j+40|0;if((c[la>>2]|0)>(ca|0)){c[la>>2]=ca}la=j+44|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}la=j+48|0;if((c[la>>2]|0)>(ca|0)){c[la>>2]=ca}la=j+52|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}la=j+56|0;if((c[la>>2]|0)>(ca|0)){c[la>>2]=ca}la=j+60|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}la=j+64|0;if((c[la>>2]|0)>(ca|0)){c[la>>2]=ca}la=j+68|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}if((ca|0)<(e|0)){c[C>>2]=ca}if((_|0)>=(f|0)){break}c[D>>2]=_}}while(0);ca=Jmb(a,k,l,E,Z,Z,c[F>>2]|0,G)|0;ga=Ze[c[H>>2]&15](a,k,l,ca,Z,Z,1,8)|0;if((c[I>>2]|0)==(c[J>>2]|0)){sa=ga;ta=c[k>>2]|0}else{ga=(ba(Z>>1,m)|0)+(Z&1)<<3;ca=(c[L>>2]|0)+ga|0;ga=c[a+12352+(Z<<4)>>2]|0;_=c[k>>2]|0;do{if((c[K>>2]|0)==0){la=c[l>>2]|0;ka=ga+((ba(la>>1,m)|0)+(_>>1))|0;fa=la<<1&2|_&1;if((c[M>>2]|0)==0){cf[c[a+11348+(fa<<2)>>2]&1023](ca,ka,m,8);break}else{cf[c[a+11476+(fa<<2)>>2]&1023](ca,ka,m,8);break}}else{ka=c[l>>2]|0;fa=ga+((ba(ka>>2,m)|0)+(_>>2))|0;la=ka<<2&12|_&3;if((c[M>>2]|0)==0){Xe[c[a+10744+(la<<2)>>2]&4095](ca,fa,m);break}else{Xe[c[a+11e3+(la<<2)>>2]&4095](ca,fa,m);break}}}while(0);ca=c[k>>2]|0;sa=ba((d[n+((c[l>>2]|0)-ia)|0]|0)+(d[n+(ca-ja)|0]|0)|0,c[N>>2]|0)|0;ta=ca}Y=sa+Y|0;if((c[K>>2]|0)==0){ca=c[l>>2]|0;ua=ta;va=ca;wa=ca}else{ca=c[l>>2]|0;ua=(ta|0)/2|0;va=(ca|0)/2|0;wa=ca}X=ua+X|0;W=va+W|0;ca=c[$>>2]|0;_=c[w>>2]|0;b[_+(ca<<2)>>1]=ta;b[_+(ca<<2)+2>>1]=wa;V=(ta|0)==(e|0)&(wa|0)==(f|0)?V:0;Z=Z+1|0;}while((Z|0)<4);if((V|0)!=0){xa=2147483647;i=h;return xa|0}V=c[J>>2]|0;if((c[I>>2]|0)==(V|0)){ya=Y}else{I=(c[a+5400>>2]|0)+((ba(c[t>>2]|0,m)|0)+(c[q>>2]|0)<<4)|0;ya=(Pe[V&255](a,I,c[L>>2]|0,m,16)|0)+Y|0}Y=a+12120|0;m=c[Y>>2]|0;if((c[m+240>>2]&256|0)==0){za=ya;Aa=m}else{m=(d[1210136+(X&15)|0]|0)+(X>>3)|0;X=(d[1210136+(W&15)|0]|0)+(W>>3)|0;W=X<<1&2|m&1;I=a+152|0;V=c[I>>2]|0;J=(c[q>>2]<<3)+(m>>1)+(ba((c[t>>2]<<3)+(X>>1)|0,V)|0)|0;if((c[M>>2]|0)==0){M=a+11348+(W<<2)|0;cf[c[M>>2]&1023](c[L>>2]|0,(c[a+956>>2]|0)+J|0,V,8);cf[c[M>>2]&1023]((c[L>>2]|0)+8|0,(c[a+960>>2]|0)+J|0,c[I>>2]|0,8)}else{M=a+11476+(W<<2)|0;cf[c[M>>2]&1023](c[L>>2]|0,(c[a+956>>2]|0)+J|0,V,8);cf[c[M>>2]&1023]((c[L>>2]|0)+8|0,(c[a+960>>2]|0)+J|0,c[I>>2]|0,8)}J=a+10520|0;M=a;V=c[I>>2]|0;W=(c[a+5404>>2]|0)+((ba(V,c[t>>2]|0)|0)+(c[q>>2]|0)<<3)|0;X=(Pe[c[J>>2]&255](M,W,c[L>>2]|0,V,8)|0)+ya|0;ya=c[I>>2]|0;I=(c[a+5408>>2]|0)+((ba(ya,c[t>>2]|0)|0)+(c[q>>2]|0)<<3)|0;q=X+(Pe[c[J>>2]&255](M,I,(c[L>>2]|0)+8|0,ya,8)|0)|0;za=q;Aa=c[Y>>2]|0}c[A>>2]=e;c[B>>2]=f;if((c[Aa+240>>2]&255|0)==6){xa=za;i=h;return xa|0}xa=((c[N>>2]|0)*11|0)+za|0;i=h;return xa|0}function vmb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;l=i;i=i+96|0;m=l|0;n=l+80|0;o=l+88|0;p=c[e+12464>>2]|0;q=c[e+148>>2]|0;r=q<<1;s=c[e+124>>2]|0;t=(ba(c[e+12480>>2]|0,s)|0)+(c[e+12476>>2]|0)|0;u=e+12272|0;c[u>>2]=c[u>>2]>>1;v=e+12276|0;c[v>>2]=c[v>>2]>>1;w=e+12416|0;c[w>>2]=c[w>>2]<<1;x=e+12420|0;c[x>>2]=c[x>>2]<<1;y=f+1|0;c[e+12352+(y<<4)>>2]=(c[e+12352+(f<<4)>>2]|0)+q;c[e+12304>>2]=(c[e+12288>>2]|0)+q;if((c[e+12244>>2]&2|0)!=0){q=e+152|0;z=c[q>>2]|0;c[e+12352+(y<<4)+4>>2]=(c[e+12352+(f<<4)+4>>2]|0)+z;c[e+12352+(y<<4)+8>>2]=(c[e+12352+(f<<4)+8>>2]|0)+z;z=c[q>>2]|0;c[e+12308>>2]=(c[e+12292>>2]|0)+z;c[e+12312>>2]=(c[e+12296>>2]|0)+z}z=t-1|0;q=m+8|0;y=m+12|0;A=e+12268|0;B=e+12280|0;C=e+12284|0;D=e+14084|0;E=t-s|0;s=m+16|0;F=m+20|0;G=E+1|0;H=m+24|0;I=m+28|0;J=e+12264|0;K=m+32|0;L=m+36|0;M=m+72|0;N=(k|0)/2|0;O=m+76|0;P=m|0;m=e+12468|0;Q=e+10492|0;R=e+10516|0;S=e+12240|0;T=e+12472|0;U=e+12192|0;V=e;W=0;X=1;Y=0;do{Z=e+12288+(Y<<4)|0;_=0;$=2147483647;aa=-1;do{ca=c[g+(Y<<3)+(_<<2)>>2]|0;da=b[ca+(z<<2)>>1]|0;c[q>>2]=da;ea=b[ca+(z<<2)+2>>1]|0;c[y>>2]=ea;fa=c[A>>2]<<1;if((da|0)>(fa|0)){c[q>>2]=fa;ga=fa}else{ga=da}c[B>>2]=ga;c[C>>2]=ea;if((c[D>>2]|0)==0){da=b[ca+(E<<2)>>1]|0;c[s>>2]=da;ha=b[ca+(E<<2)+2>>1]|0;c[F>>2]=ha;ia=b[ca+(G<<2)>>1]|0;c[H>>2]=ia;ja=b[ca+(G<<2)+2>>1]|0;c[I>>2]=ja;ka=c[v>>2]<<1;if((ha|0)>(ka|0)){c[F>>2]=ka;la=ka}else{la=ha}ha=c[J>>2]<<1;if((ia|0)<(ha|0)){c[H>>2]=ha;ma=ha}else{ma=ia}if((ma|0)>(fa|0)){c[H>>2]=fa;na=fa}else{na=ma}if((ja|0)>(ka|0)){c[I>>2]=ka;oa=ka}else{oa=ja}do{if((ga|0)>(da|0)){if((na|0)<=(da|0)){pa=da;break}pa=(na|0)>(ga|0)?ga:na}else{if((da|0)<=(na|0)){pa=da;break}pa=(na|0)>(ga|0)?na:ga}}while(0);c[K>>2]=pa;do{if((ea|0)>(la|0)){if((oa|0)<=(la|0)){qa=la;break}qa=(oa|0)>(ea|0)?ea:oa}else{if((la|0)<=(oa|0)){qa=la;break}qa=(oa|0)>(ea|0)?oa:ea}}while(0);c[L>>2]=qa}c[M>>2]=j;c[O>>2]=N;ea=_+f|0;da=Emb(e,n,o,P,Y,ea,ca)|0;ja=Ze[c[m>>2]&15](e,n,o,da,Y,ea,0,8)|0;da=c[n>>2]|0;b[ca+(t<<2)>>1]=da;ka=c[o>>2]|0;b[ca+(t<<2)+2>>1]=ka;if((c[Q>>2]|0)==(c[R>>2]|0)){ra=(c[S>>2]|0)+ja|0}else{ja=(c[e+12352+(ea<<4)>>2]|0)+((ba(ka>>1,r)|0)+(da>>1))|0;ea=ka<<1&2|da&1;if((c[T>>2]|0)==0){cf[c[e+11332+(ea<<2)>>2]&1023](c[U>>2]|0,ja,r,8)}else{cf[c[e+11460+(ea<<2)>>2]&1023](c[U>>2]|0,ja,r,8)}ja=Pe[c[R>>2]&255](V,c[Z>>2]|0,c[U>>2]|0,r,8)|0;ra=(ba((d[p+((c[n>>2]|0)-(c[B>>2]|0))|0]|0)+1+(d[p+((c[o>>2]|0)-(c[C>>2]|0))|0]|0)|0,c[S>>2]|0)|0)+ja|0}ja=ra+((_|0)!=(Y|0))|0;ea=(ja|0)<($|0);$=ea?ja:$;aa=ea?_:aa;_=_+1|0;}while((_|0)<2);_=c[g+(Y<<3)+(aa<<2)>>2]|0;Z=b[_+(t<<2)+2>>1]|0;X=(aa|0)==(Y|0)?(Z<<16>>16<<1|0)==(k|0)?(Z&1)==0?(b[_+(t<<2)>>1]|0)==(j|0)?X:0:0:0:0;a[(c[h+(Y<<2)>>2]|0)+t|0]=aa;W=$+W|0;Y=Y+1|0;}while((Y|0)<2);c[u>>2]=c[u>>2]<<1;c[v>>2]=c[v>>2]<<1;c[w>>2]=c[w>>2]>>1;c[x>>2]=c[x>>2]>>1;if((X|0)!=0){sa=2147483647;i=l;return sa|0}if((c[(c[e+12120>>2]|0)+240>>2]&255|0)==6){sa=W;i=l;return sa|0}sa=((c[S>>2]|0)*11|0)+W|0;i=l;return sa|0}function wmb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=i;i=i+96|0;g=f|0;h=f+8|0;j=f+16|0;k=c[a+13924>>2]|0;l=k+1|0;m=a+124|0;n=(ba(c[m>>2]|0,e)|0)+d|0;o=d<<4;d=e<<4;e=(ba(c[a+12416>>2]|0,d)|0)+o|0;p=(ba(c[a+12420>>2]|0,d)|0)+o>>1;c[a+12288>>2]=(c[a+5400>>2]|0)+e;c[a+12352>>2]=(c[a+952>>2]|0)+e;c[a+12292>>2]=(c[a+5404>>2]|0)+p;c[a+12356>>2]=(c[a+956>>2]|0)+p;c[a+12296>>2]=(c[a+5408>>2]|0)+p;c[a+12360>>2]=(c[a+960>>2]|0)+p;if(!(k>>>0<2>>>0)){yDb(0,0,2098584,(k=i,i=i+24|0,c[k>>2]=2043408,c[k+8>>2]=1998240,c[k+16>>2]=1082,k)|0);i=k;Cd();return 0}k=c[a+9968>>2]|0;switch(c[(c[a+12120>>2]|0)+260>>2]&255|0){case 3:{q=(k*3|0)>>8;break};case 11:{q=k>>5;break};case 12:{q=k>>6;break};case 2:case 14:{q=k>>6;break};case 6:case 4:case 1:case 10:{q=c[a+9972>>2]>>7;break};case 5:{q=1;break};default:{q=k>>7}}c[a+12228>>2]=q;c[a+12464>>2]=(c[a+12460>>2]|0)+((c[a+11556>>2]|0)*8193|0)+4096;tmb(a,o,d);c[a+12124>>2]=0;d=n+1|0;o=a+11636|0;q=c[o>>2]|0;k=b[q+(d<<2)>>1]|0;p=j+8|0;c[p>>2]=k;e=b[q+(d<<2)+2>>1]|0;c[j+12>>2]=e;d=c[a+12264>>2]<<l;if((k|0)<(d|0)){c[p>>2]=d;r=d}else{r=k}if((c[a+14084>>2]|0)!=0){c[a+12280>>2]=r;c[a+12284>>2]=e;TGb(j+16|0,0,24)|0;s=j|0;t=65536>>>(l>>>0);u=kmb(a,g,h,s,0,0,q,t,0,16)|0;v=c[g>>2]|0;w=v<<l;x=w&65535;y=c[o>>2]|0;z=y+(n<<2)|0;b[z>>1]=x;A=c[h>>2]|0;B=A<<l;C=B&65535;D=y+(n<<2)+2|0;b[D>>1]=C;i=f;return u|0}k=c[m>>2]|0;m=k+n|0;d=b[q+(m<<2)>>1]|0;c[j+16>>2]=d;p=b[q+(m<<2)+2>>1]|0;m=j+20|0;c[m>>2]=p;E=n-1+k|0;k=b[q+(E<<2)>>1]|0;F=j+24|0;c[F>>2]=k;G=b[q+(E<<2)+2>>1]|0;E=j+28|0;c[E>>2]=G;H=c[a+12272>>2]<<l;if((p|0)<(H|0)){c[m>>2]=H;I=H}else{I=p}p=c[a+12268>>2]<<l;if((k|0)>(p|0)){c[F>>2]=p;J=p}else{J=k}if((G|0)<(H|0)){c[E>>2]=H;K=H}else{K=G}do{if((r|0)>(d|0)){if((J|0)<=(d|0)){L=d;break}L=(J|0)>(r|0)?r:J}else{if((d|0)<=(J|0)){L=d;break}L=(J|0)>(r|0)?J:r}}while(0);c[j+32>>2]=L;do{if((e|0)>(I|0)){if((K|0)<=(I|0)){M=I;break}M=(K|0)>(e|0)?e:K}else{if((I|0)<=(K|0)){M=I;break}M=(K|0)>(e|0)?K:e}}while(0);c[j+36>>2]=M;c[a+12280>>2]=L;c[a+12284>>2]=M;s=j|0;t=65536>>>(l>>>0);u=kmb(a,g,h,s,0,0,q,t,0,16)|0;v=c[g>>2]|0;w=v<<l;x=w&65535;y=c[o>>2]|0;z=y+(n<<2)|0;b[z>>1]=x;A=c[h>>2]|0;B=A<<l;C=B&65535;D=y+(n<<2)+2|0;b[D>>1]=C;i=f;return u|0}function xmb(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0;h=i;i=i+256|0;j=h|0;k=c[e+12240>>2]|0;l=e+124|0;m=(ba(c[l>>2]|0,g)|0)+f|0;n=f<<4;o=g<<4;p=(ba(c[e+12416>>2]|0,o)|0)+n|0;q=(ba(c[e+12420>>2]|0,o)|0)+n>>1;c[e+12288>>2]=(c[e+5400>>2]|0)+p;c[e+12352>>2]=(c[e+952>>2]|0)+p;c[e+12292>>2]=(c[e+5404>>2]|0)+q;c[e+12356>>2]=(c[e+956>>2]|0)+q;c[e+12296>>2]=(c[e+5408>>2]|0)+q;c[e+12360>>2]=(c[e+960>>2]|0)+q;c[e+12384>>2]=(c[e+3176>>2]|0)+p;c[e+12388>>2]=(c[e+3180>>2]|0)+q;c[e+12392>>2]=(c[e+3184>>2]|0)+q;tmb(e,n,o);o=e+12124|0;c[o>>2]=0;n=e+48|0;do{if((c[n>>2]|0)==13){q=(a[(c[e+4720>>2]|0)+m|0]|0)==0;p=ymb(e,f,g)|0;if(q){r=p;break}q=((ba(p,p)|0)+32768|0)>>>16;p=e+12424|0;s=YGb(q,0,c[p>>2]|0,c[p+4>>2]|0)|0;c[p>>2]=s;c[p+4>>2]=F;p=(ba(c[l>>2]|0,g)|0)+f|0;b[(c[e+9200>>2]|0)+(p<<1)>>1]=q;b[(c[e+12492>>2]|0)+(p<<1)>>1]=4096;i=h;return}else{r=2147483647}}while(0);c[o>>2]=0;p=e+11640|0;q=e+11556|0;s=(zmb(e,f,g,c[p>>2]|0,0,c[q>>2]|0)|0)+(k*3|0)|0;c[o>>2]=0;t=e+11644|0;u=e+11560|0;v=(zmb(e,f,g,c[t>>2]|0,2,c[u>>2]|0)|0)+(k<<1)|0;c[o>>2]=0;w=(ba(c[l>>2]|0,g)|0)+f|0;x=w-1|0;y=e+11648|0;z=c[y>>2]|0;A=b[z+(x<<2)>>1]|0;B=b[z+(x<<2)+2>>1]|0;C=e+11652|0;D=c[C>>2]|0;E=b[D+(x<<2)>>1]|0;G=b[D+(x<<2)+2>>1]|0;x=c[p>>2]|0;H=b[x+(w<<2)>>1]|0;b[z+(w<<2)>>1]=H;I=H<<16>>16;J=b[x+(w<<2)+2>>1]|0;b[z+(w<<2)+2>>1]=J;z=J<<16>>16;x=c[t>>2]|0;K=b[x+(w<<2)>>1]|0;b[D+(w<<2)>>1]=K;L=K<<16>>16;M=b[x+(w<<2)+2>>1]|0;b[D+(w<<2)+2>>1]=M;D=M<<16>>16;x=(c[e+12248>>2]&1)+1|0;N=c[e+12264>>2]<<x;O=c[e+12272>>2]<<x;P=c[e+12268>>2]<<x;Q=c[e+12276>>2]<<x;x=(z*17|0)+I+(L*63|0)+(D*117|0)|0;TGb(j|0,0,256)|0;a[j+(x&255)|0]=1;R=Dmb(e,I,z,L,D,A,B,E,G)|0;S=c[(c[e+4>>2]|0)+352>>2]|0;if((S|0)==0){T=R;U=H;V=J;W=K;X=M}else{M=d[1731992+S|0]|0;K=S>>>0>1>>>0;S=R;R=I;I=z;z=L;L=D;D=x;while(1){x=D+117|0;J=j+(x&255)|0;do{if((a[J]|0)==0){H=L+1|0;if((H|0)>(Q|0)){Y=S;Z=L;_=D;$=1;break}a[J]=1;aa=Dmb(e,R,I,z,H,A,B,E,G)|0;ca=(aa|0)<(S|0);Y=ca?aa:S;Z=ca?H:L;_=ca?x:D;$=ca&1^1}else{Y=S;Z=L;_=D;$=1}}while(0);x=_-117|0;J=j+(x&255)|0;do{if((a[J]|0)==0){ca=Z-1|0;if((ca|0)<(O|0)){da=Y;ea=Z;fa=_;ga=$;break}a[J]=1;H=Dmb(e,R,I,z,ca,A,B,E,G)|0;aa=(H|0)<(Y|0);da=aa?H:Y;ea=aa?ca:Z;fa=aa?x:_;ga=aa?0:$}else{da=Y;ea=Z;fa=_;ga=$}}while(0);x=fa+63|0;J=j+(x&255)|0;do{if((a[J]|0)==0){aa=z+1|0;if((aa|0)>(P|0)){ha=da;ia=z;ja=fa;ka=ga;break}a[J]=1;ca=Dmb(e,R,I,aa,ea,A,B,E,G)|0;H=(ca|0)<(da|0);ha=H?ca:da;ia=H?aa:z;ja=H?x:fa;ka=H?0:ga}else{ha=da;ia=z;ja=fa;ka=ga}}while(0);x=ja-63|0;J=j+(x&255)|0;do{if((a[J]|0)==0){H=ia-1|0;if((H|0)<(N|0)){la=ha;ma=ia;na=ja;oa=ka;break}a[J]=1;aa=Dmb(e,R,I,H,ea,A,B,E,G)|0;ca=(aa|0)<(ha|0);la=ca?aa:ha;ma=ca?H:ia;na=ca?x:ja;oa=ca?0:ka}else{la=ha;ma=ia;na=ja;oa=ka}}while(0);x=na+17|0;J=j+(x&255)|0;do{if((a[J]|0)==0){ca=I+1|0;if((ca|0)>(Q|0)){pa=la;qa=I;ra=na;sa=oa;break}a[J]=1;H=Dmb(e,R,ca,ma,ea,A,B,E,G)|0;aa=(H|0)<(la|0);pa=aa?H:la;qa=aa?ca:I;ra=aa?x:na;sa=aa?0:oa}else{pa=la;qa=I;ra=na;sa=oa}}while(0);x=ra-17|0;J=j+(x&255)|0;do{if((a[J]|0)==0){aa=qa-1|0;if((aa|0)<(O|0)){ta=pa;ua=qa;va=ra;wa=sa;break}a[J]=1;ca=Dmb(e,R,aa,ma,ea,A,B,E,G)|0;H=(ca|0)<(pa|0);ta=H?ca:pa;ua=H?aa:qa;va=H?x:ra;wa=H?0:sa}else{ta=pa;ua=qa;va=ra;wa=sa}}while(0);x=va+1|0;J=j+(x&255)|0;do{if((a[J]|0)==0){H=R+1|0;if((H|0)>(P|0)){xa=ta;ya=R;za=va;Aa=wa;break}a[J]=1;aa=Dmb(e,H,ua,ma,ea,A,B,E,G)|0;ca=(aa|0)<(ta|0);xa=ca?aa:ta;ya=ca?H:R;za=ca?x:va;Aa=ca?0:wa}else{xa=ta;ya=R;za=va;Aa=wa}}while(0);x=za-1|0;J=j+(x&255)|0;do{if((a[J]|0)==0){ca=ya-1|0;if((ca|0)<(N|0)){Ba=xa;Ca=ya;Da=za;Ea=Aa;break}a[J]=1;H=Dmb(e,ca,ua,ma,ea,A,B,E,G)|0;aa=(H|0)<(xa|0);Ba=aa?H:xa;Ca=aa?ca:ya;Da=aa?x:za;Ea=aa?0:Aa}else{Ba=xa;Ca=ya;Da=za;Ea=Aa}}while(0);if(K){x=0;J=8;aa=Ea;ca=Da;H=ea;Fa=ma;Ga=ua;Ha=Ca;Ia=Ba;while(1){Ja=(a[1731672+(J<<2)|0]|0)+Ha|0;Ka=(a[1731673+(J<<2)|0]|0)+Ga|0;La=(a[1731674+(J<<2)|0]|0)+Fa|0;Ma=(a[1731675+(J<<2)|0]|0)+H|0;do{if((x|0)<1){Na=(Ja|0)>(La|0);Oa=(Ka|0)>(Ma|0);if((P-(Na?Ja:La)|(Na?La:Ja)-N|(Oa?Ma:Ka)-O|Q-(Oa?Ka:Ma)|0)>=0){break}a[j+((d[1732e3+J|0]|0)+ca&255)|0]=1}}while(0);Oa=(d[1732e3+J|0]|0)+ca|0;Na=j+(Oa&255)|0;do{if((a[Na]|0)==0){a[Na]=1;Pa=Dmb(e,Ja,Ka,La,Ma,A,B,E,G)|0;if((Pa|0)>=(Ia|0)){Qa=Ia;Ra=Ha;Sa=Ga;Ta=Fa;Ua=H;Va=ca;Wa=aa;Xa=x;break}Ya=x-1|0;if((Ya|0)>=1){Qa=Pa;Ra=Ja;Sa=Ka;Ta=La;Ua=Ma;Va=Oa;Wa=0;Xa=Ya;break}Ya=(Ja|0)>(La|0);Za=P-(Ya?Ja:La)|0;_a=(Ya?La:Ja)-N|0;Ya=(Za|0)>(_a|0)?_a:Za;Za=(Ka|0)>(Ma|0);_a=Q-(Za?Ka:Ma)|0;$a=(Za?Ma:Ka)-O|0;Za=(_a|0)>($a|0)?$a:_a;Qa=Pa;Ra=Ja;Sa=Ka;Ta=La;Ua=Ma;Va=Oa;Wa=0;Xa=(Ya|0)>(Za|0)?Za:Ya}else{Qa=Ia;Ra=Ha;Sa=Ga;Ta=Fa;Ua=H;Va=ca;Wa=aa;Xa=x}}while(0);Oa=J+1|0;if((Oa|0)<(M|0)){x=Xa;J=Oa;aa=Wa;ca=Va;H=Ua;Fa=Ta;Ga=Sa;Ha=Ra;Ia=Qa}else{ab=Wa;bb=Va;cb=Ua;db=Ta;eb=Sa;fb=Ra;gb=Qa;break}}}else{ab=Ea;bb=Da;cb=ea;db=ma;eb=ua;fb=Ca;gb=Ba}if((ab|0)==0){S=gb;R=fb;I=eb;z=db;L=cb;D=bb}else{break}}T=gb;U=fb&65535;V=eb&65535;W=db&65535;X=cb&65535}cb=c[y>>2]|0;b[cb+(w<<2)>>1]=U;b[cb+(w<<2)+2>>1]=V;V=c[C>>2]|0;b[V+(w<<2)>>1]=W;b[V+(w<<2)+2>>1]=X;X=T+k|0;k=e+60|0;if((c[k>>2]&536870912|0)==0){hb=2147483647;ib=2147483647}else{c[o>>2]=0;o=e+12460|0;T=e+12464|0;c[T>>2]=(c[o>>2]|0)+((c[q>>2]|0)*8193|0)+4096;q=c[p>>2]|0;p=vmb(e,0,e+11676|0,e+11716|0,b[q+(m<<2)>>1]|0,b[q+(m<<2)+2>>1]|0)|0;c[T>>2]=(c[o>>2]|0)+((c[u>>2]|0)*8193|0)+4096;u=c[t>>2]|0;hb=vmb(e,2,e+11692|0,e+11724|0,b[u+(m<<2)>>1]|0,b[u+(m<<2)+2>>1]|0)|0;ib=p}p=(r|0)>(s|0);u=p?s:r;s=(v|0)<(u|0);t=s?v:u;u=(X|0)<(t|0);v=u?X:t;t=(ib|0)<(v|0);X=t?ib:v;v=(hb|0)<(X|0);o=v?1024:t?512:u?128:s?64:p?32:16;p=v?hb:X;X=((ba(p,p)|0)+32768|0)>>>16;p=e+12424|0;v=YGb(X,0,c[p>>2]|0,c[p+4>>2]|0)|0;c[p>>2]=v;c[p+4>>2]=F;p=(ba(c[l>>2]|0,g)|0)+f|0;b[(c[e+9200>>2]|0)+(p<<1)>>1]=X;do{if((c[(c[e+12120>>2]|0)+296>>2]|0)>0){X=(ib|0)!=2147483647;f=X?752:240;g=(hb|0)!=2147483647;l=g?f|1024:f;if(X){jb=g?l|2048:f}else{jb=l}l=(r|0)>1048576?jb&-17:jb;f=l&65535;if((c[n>>2]|0)!=13){kb=f;break}if((l&16|0)==0){kb=f;break}if((c[k>>2]&64|0)==0){kb=f;break}if((c[(c[e+11656>>2]|0)+(m<<2)>>2]|0)==0){kb=f;break}kb=(l|4096)&65535}else{kb=o}}while(0);b[(c[e+12492>>2]|0)+(p<<1)>>1]=kb;i=h;return}function ymb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0;g=i;i=i+96|0;h=g|0;j=g+80|0;k=g+88|0;l=c[a+124>>2]|0;m=(ba(l,f)|0)+d|0;n=c[a+13924>>2]|0;o=n+1|0;p=e[a+13872>>1]|0;q=e[a+13874>>1]|0;r=a+11656|0;s=c[r>>2]|0;c[a+12464>>2]=(c[a+12460>>2]|0)+12289;t=-32>>o;u=31>>>(o>>>0);v=a+11740|0;c[v>>2]=(c[(c[a+4712>>2]|0)+(m<<2)>>2]|0)>>>6&1;w=a+4700|0;x=n+4|0;y=d<<4;d=y|1;z=a+8|0;A=-15-y|0;B=f<<4;f=B|1;C=a+12|0;D=-15-B|0;E=u;F=t;G=u;u=t;t=0;while(1){if((t|0)>=4){H=E;I=F;J=G;K=u;break}L=c[a+12496+(t<<2)>>2]|0;M=c[w>>2]|0;N=b[M+(L<<2)>>1]|0;O=N<<16>>16;c[a+12128+(t<<3)>>2]=O;P=b[M+(L<<2)+2>>1]|0;L=P<<16>>16;c[a+12128+(t<<3)+4>>2]=L;M=((ba(O,q)|0)/(p|0)|0)+((t&1)<<x)|0;c[a+12160+(t<<3)>>2]=M;Q=((ba(L,q)|0)/(p|0)|0)+(t>>1<<x)|0;c[a+12160+(t<<3)+4>>2]=Q;R=N<<16>>16>0;N=M-O|0;O=(c[z>>2]|0)-d-((R?M:N)>>o)|0;S=(G|0)>(O|0)?O:G;O=A-((R?N:M)>>o)|0;M=(u|0)>(O|0)?u:O;O=P<<16>>16>0;P=Q-L|0;L=(c[C>>2]|0)-f-((O?Q:P)>>o)|0;N=(E|0)>(L|0)?L:E;L=D-((O?P:Q)>>o)|0;Q=(F|0)>(L|0)?F:L;if((c[v>>2]|0)==0){H=N;I=Q;J=S;K=M;break}else{E=N;F=Q;G=S;u=M;t=t+1|0}}if((J|0)<0|(K|0)>0|(H|0)<0|(I|0)>0){t=c[r>>2]|0;b[t+(m<<2)>>1]=0;b[t+(m<<2)+2>>1]=0;T=1073741824;i=g;return T|0}c[a+12264>>2]=K;c[a+12272>>2]=I;c[a+12268>>2]=J;c[a+12276>>2]=H;t=a+12244|0;c[t>>2]=c[t>>2]|4;r=a+12248|0;c[r>>2]=c[r>>2]|4;c[a+12280>>2]=0;c[a+12284>>2]=0;u=m-1|0;G=b[s+(u<<2)>>1]|0;F=K<<o;K=J<<o;if((G|0)<(F|0)){U=F}else{U=(G|0)>(K|0)?K:G}c[h+8>>2]=U;G=b[s+(u<<2)+2>>1]|0;u=I<<o;I=H<<o;if((G|0)<(u|0)){V=u}else{V=(G|0)>(I|0)?I:G}c[h+12>>2]=V;if((c[a+14084>>2]|0)==0){G=m-l|0;l=b[s+(G<<2)>>1]|0;if((l|0)<(F|0)){W=F}else{W=(l|0)>(K|0)?K:l}c[h+16>>2]=W;l=b[s+(G<<2)+2>>1]|0;if((l|0)<(u|0)){X=u}else{X=(l|0)>(I|0)?I:l}c[h+20>>2]=X;l=G+1|0;G=b[s+(l<<2)>>1]|0;if((G|0)<(F|0)){Y=F}else{Y=(G|0)>(K|0)?K:G}c[h+24>>2]=Y;G=b[s+(l<<2)+2>>1]|0;if((G|0)<(u|0)){Z=u}else{Z=(G|0)>(I|0)?I:G}c[h+28>>2]=Z;do{if((U|0)>(W|0)){if((Y|0)<=(W|0)){_=W;break}_=(Y|0)>(U|0)?U:Y}else{if((W|0)<=(Y|0)){_=W;break}_=(Y|0)>(U|0)?Y:U}}while(0);c[h+32>>2]=_;do{if((V|0)>(X|0)){if((Z|0)<=(X|0)){$=X;break}$=(Z|0)>(V|0)?V:Z}else{if((X|0)<=(Z|0)){$=X;break}$=(Z|0)>(V|0)?Z:V}}while(0);c[h+36>>2]=$}$=kmb(a,j,k,h|0,0,0,s,1<<15-n,0,16)|0;if((c[r>>2]&1|0)==0){aa=nmb(a,j,k,$,0,0,0,16)|0}else{aa=mmb(a,j,k,$,0,0,0,16)|0}$=c[a+12120>>2]|0;do{if((c[$+236>>2]|0)==(c[$+240>>2]|0)){ca=aa}else{if((c[a+12124>>2]|0)!=0){ca=aa;break}ca=jmb(a,c[j>>2]|0,c[k>>2]|0,0,0,0,16,1)|0}}while(0);tmb(a,y,B);b[s+(m<<2)>>1]=c[j>>2];b[s+(m<<2)+2>>1]=c[k>>2];c[t>>2]=c[t>>2]&-5;c[r>>2]=c[r>>2]&-5;T=ca;i=g;return T|0}function zmb(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;k=i;i=i+96|0;l=k|0;m=k+8|0;n=k+16|0;o=(c[a+13924>>2]|0)+1|0;p=c[a+124>>2]|0;q=(ba(p,f)|0)+d|0;r=(c[a+12460>>2]|0)+(j*8193|0)+4096|0;j=c[a+9968>>2]|0;s=c[a+9972>>2]|0;t=a+12120|0;u=c[t>>2]|0;switch(c[u+232>>2]&255|0){case 12:{v=j>>6;break};case 2:case 14:{v=j>>6;break};case 6:case 4:case 1:case 10:{v=s>>7;break};case 5:{v=1;break};case 3:{v=(j*3|0)>>8;break};case 11:{v=j>>5;break};default:{v=j>>7}}c[a+12232>>2]=v;switch(c[u+236>>2]&255|0){case 3:{w=(j*3|0)>>8;break};case 12:{w=j>>6;break};case 6:case 4:case 1:case 10:{w=s>>7;break};case 2:case 14:{w=j>>6;break};case 5:{w=1;break};case 11:{w=j>>5;break};default:{w=j>>7}}c[a+12236>>2]=w;switch(c[u+240>>2]&255|0){case 2:case 14:{x=j>>6;break};case 11:{x=j>>5;break};case 12:{x=j>>6;break};case 3:{x=(j*3|0)>>8;break};case 5:{x=1;break};case 6:case 4:case 1:case 10:{x=s>>7;break};default:{x=j>>7}}c[a+12240>>2]=x;c[a+12464>>2]=r;tmb(a,d<<4,f<<4);if(((c[a+11732>>2]|0)-5|0)>>>0<2>>>0){f=q-1|0;d=b[g+(f<<2)>>1]|0;r=n+8|0;c[r>>2]=d;x=b[g+(f<<2)+2>>1]|0;c[n+12>>2]=x;f=c[a+12268>>2]<<o;if((d|0)>(f|0)){c[r>>2]=f;y=f}else{y=d}if((c[a+14084>>2]|0)==0){d=q-p|0;p=b[g+(d<<2)>>1]|0;c[n+16>>2]=p;f=b[g+(d<<2)+2>>1]|0;r=n+20|0;c[r>>2]=f;j=d+1|0;d=b[g+(j<<2)>>1]|0;s=n+24|0;c[s>>2]=d;u=b[g+(j<<2)+2>>1]|0;j=n+28|0;c[j>>2]=u;w=c[a+12276>>2]<<o;if((f|0)>(w|0)){c[r>>2]=w;z=w}else{z=f}f=c[a+12264>>2]<<o;if((d|0)<(f|0)){c[s>>2]=f;A=f}else{A=d}if((u|0)>(w|0)){c[j>>2]=w;B=w}else{B=u}do{if((y|0)>(p|0)){if((A|0)<=(p|0)){C=p;break}C=(A|0)>(y|0)?y:A}else{if((p|0)<=(A|0)){C=p;break}C=(A|0)>(y|0)?A:y}}while(0);c[n+32>>2]=C;do{if((x|0)>(z|0)){if((B|0)<=(z|0)){D=z;break}D=(B|0)>(x|0)?x:B}else{if((z|0)<=(B|0)){D=z;break}D=(B|0)>(x|0)?B:x}}while(0);c[n+36>>2]=D}c[a+12280>>2]=y;c[a+12284>>2]=x;x=e[a+13874>>1]|0;if((c[a+11640>>2]|0)==(g|0)){E=(x<<16|0)/(e[a+13872>>1]<<o|0)|0}else{y=e[a+13872>>1]|0;E=(x-y<<16|0)/(y<<o|0)|0}F=kmb(a,l,m,n|0,0,h,c[a+11636>>2]|0,E,0,16)|0}else{c[l>>2]=0;c[m>>2]=0;F=0}E=Ze[c[a+12468>>2]&15](a,l,m,F,0,h,0,16)|0;F=c[t>>2]|0;if((c[F+236>>2]|0)==(c[F+240>>2]|0)){G=E;H=c[l>>2]|0;I=H&65535;J=g+(q<<2)|0;b[J>>1]=I;K=c[m>>2]|0;L=K&65535;M=g+(q<<2)+2|0;b[M>>1]=L;i=k;return G|0}if((c[a+12124>>2]|0)!=0){G=E;H=c[l>>2]|0;I=H&65535;J=g+(q<<2)|0;b[J>>1]=I;K=c[m>>2]|0;L=K&65535;M=g+(q<<2)+2|0;b[M>>1]=L;i=k;return G|0}G=jmb(a,c[l>>2]|0,c[m>>2]|0,0,h,0,16,1)|0;H=c[l>>2]|0;I=H&65535;J=g+(q<<2)|0;b[J>>1]=I;K=c[m>>2]|0;L=K&65535;M=g+(q<<2)+2|0;b[M>>1]=L;i=k;return G|0}function Amb(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;h=i;i=i+32|0;j=h|0;if((c[d+11732>>2]|0)<=4){k=1;i=h;return k|0}l=c[d+4>>2]|0;m=c[l+276>>2]|0;n=(m|0)==0?1073741823:m;m=c[d+11856>>2]|0;do{if((c[d+14092>>2]|0)==0){if((c[d+48>>2]|0)!=2){o=n;break}if(!((c[l+680>>2]|0)>-1)){o=n;break}o=(n|0)>256?256:n}else{o=(n|0)>16?16:n}}while(0);n=c[d+144>>2]|0;c[j>>2]=n<<3;l=n*7|0;p=j+4|0;c[p>>2]=l;q=n*6|0;r=j+8|0;c[r>>2]=q;s=n*5|0;t=j+12|0;c[t>>2]=s;u=n<<2;v=j+16|0;c[v>>2]=u;w=n*3|0;x=j+20|0;c[x>>2]=w;y=n<<1;z=j+24|0;c[z>>2]=y;A=j+28|0;c[A>>2]=n;B=c[d+120>>2]|0;if((B|0)>0){C=c[d+124>>2]|0;D=c[d+116>>2]|0;E=(D|0)>0;F=d+12492|0;G=-o|0;H=d+9992|0;I=d+9200|0;J=d+9192|0;d=0;do{if(E){K=ba(C,d)|0;L=c[F>>2]|0;M=0;N=K;while(1){do{if((e[L+(N<<1)>>1]&g|0)==0){O=22}else{K=b[f+(N<<2)>>1]|0;P=b[f+(N<<2)+2>>1]|0;Q=a[m+(K+4096)|0]|0;R=a[m+(P+4096)|0]|0;S=(Q&255)>>>0>(R&255)>>>0?Q:R;R=S&255;if((K|0)>=(o|0)){T=N;break}if((P|0)>=(o|0)|(K|0)<(G|0)|(P|0)<(G|0)){T=N;break}if(S<<24>>24==0){O=22;break}S=(c[H>>2]|0)==3;P=0;while(1){if(S){O=20}else{if((e[(c[I>>2]|0)+(N<<1)>>1]|0)>>>0<(e[(c[J>>2]|0)+(N<<1)>>1]|0)>>>0){O=20}}if((O|0)==20){O=0;K=j+(P<<2)|0;c[K>>2]=(c[K>>2]|0)-170}K=P+1|0;if((K|0)<(R|0)&(K|0)<8){P=K}else{O=22;break}}}}while(0);if((O|0)==22){O=0;T=N+1|0}P=M+1|0;if((P|0)<(D|0)){M=P;N=T}else{break}}}d=d+1|0;}while((d|0)<(B|0));U=c[p>>2]|0;V=c[r>>2]|0;W=c[t>>2]|0;X=c[v>>2]|0;Y=c[x>>2]|0;Z=c[z>>2]|0;_=c[A>>2]|0}else{U=l;V=q;W=s;X=u;Y=w;Z=y;_=n}n=(U|0)>-1e7;y=n?U:-1e7;U=(V|0)>(y|0);w=U?V:y;y=(W|0)>(w|0);V=y?W:w;w=(X|0)>(V|0);W=w?X:V;V=(Y|0)>(W|0);X=V?Y:W;W=(Z|0)>(X|0);k=(_|0)>((W?Z:X)|0)?7:W?6:V?5:w?4:y?3:U?2:n?1:-1;i=h;return k|0}function Bmb(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=i;e=c[a+11556>>2]|0;if((c[a+9992>>2]|0)!=2){yDb(0,0,2098584,(f=i,i=i+24|0,c[f>>2]=1910736,c[f+8>>2]=1998240,c[f+16>>2]=1676,f)|0);i=f;Cd()}if((c[a+28>>2]|0)==0){g=8}else{g=(c[a+14092>>2]|0)!=0?8:16}h=g<<e;do{if((h|0)>=17){if((c[a+14092>>2]|0)!=0){yDb(0,0,2098584,(f=i,i=i+24|0,c[f>>2]=1890288,c[f+8>>2]=1998240,c[f+16>>2]=1680,f)|0);i=f;Cd()}if((h|0)<257){break}if((c[a+48>>2]|0)!=2){break}if(!((c[(c[a+4>>2]|0)+680>>2]|0)>-1)){break}yDb(0,0,2098584,(f=i,i=i+24|0,c[f>>2]=2347536,c[f+8>>2]=1998240,c[f+16>>2]=1681,f)|0);i=f;Cd()}}while(0);f=c[(c[a+12120>>2]|0)+276>>2]|0;e=(f|0)!=0&(h|0)>(f|0)?f:h;if((c[a+60>>2]&4|0)==0){i=d;return}h=c[a+128>>2]|0;f=a+120|0;g=c[f>>2]|0;if((g|0)<=0){i=d;return}j=h<<1;k=a+124|0;l=a+116|0;m=a+12492|0;n=a+9148|0;o=-e|0;p=a+9160|0;a=0;q=c[l>>2]|0;r=g;while(1){if((q|0)>0){g=ba(c[k>>2]|0,a)|0;s=ba(j,a)|0;t=c[m>>2]|0;u=g;g=0;v=s;s=q;while(1){w=t+(u<<1)|0;x=b[w>>1]|0;if((x&4)==0){y=s}else{z=c[n>>2]|0;A=b[z+(v<<2)>>1]|0;B=b[z+(v<<2)+2>>1]|0;if((A|0)<(e|0)){if((B|0)>=(e|0)|(A|0)<(o|0)|(B|0)<(o|0)){C=20}else{D=x}}else{C=20}if((C|0)==20){C=0;B=x&-6|1;b[w>>1]=B;c[(c[p>>2]|0)+(u<<2)>>2]=1;D=B}B=v+1|0;x=b[z+(B<<2)>>1]|0;A=b[z+(B<<2)+2>>1]|0;if((x|0)<(e|0)){if((A|0)>=(e|0)|(x|0)<(o|0)|(A|0)<(o|0)){C=27}else{E=D}}else{C=27}if((C|0)==27){C=0;A=D&-6|1;b[w>>1]=A;c[(c[p>>2]|0)+(u<<2)>>2]=1;E=A}A=v+h|0;x=b[z+(A<<2)>>1]|0;F=b[z+(A<<2)+2>>1]|0;if((x|0)<(e|0)){if((F|0)>=(e|0)|(x|0)<(o|0)|(F|0)<(o|0)){C=30}else{G=E}}else{C=30}if((C|0)==30){C=0;F=E&-6|1;b[w>>1]=F;c[(c[p>>2]|0)+(u<<2)>>2]=1;G=F}F=B+h|0;B=b[z+(F<<2)>>1]|0;x=b[z+(F<<2)+2>>1]|0;if((B|0)<(e|0)){if((x|0)>=(e|0)|(B|0)<(o|0)|(x|0)<(o|0)){C=33}}else{C=33}if((C|0)==33){C=0;b[w>>1]=G&-6|1;c[(c[p>>2]|0)+(u<<2)>>2]=1}y=c[l>>2]|0}w=g+1|0;if((w|0)<(y|0)){u=u+1|0;g=w;v=v+2|0;s=y}else{break}}H=y;I=c[f>>2]|0}else{H=q;I=r}s=a+1|0;if((s|0)<(I|0)){a=s;q=H;r=I}else{break}}i=d;return}function Cmb(a,f,g,h,i,j,k){a=a|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((c[a+28>>2]|0)==0){l=8}else{l=(c[a+14092>>2]|0)!=0?8:16}m=l<<i;i=c[(c[a+12120>>2]|0)+276>>2]|0;l=(i|0)!=0&(m|0)>(i|0)?i:m;m=l>>((f|0)!=0);i=c[a+120>>2]|0;if((i|0)<=0){return}n=a+124|0;o=a+12492|0;p=(f|0)==0;q=-l|0;r=(k|0)==0;k=j^65534;s=l-1|0;t=s&65535;u=m-1|0;v=u&65535;w=-m|0;x=w&65535;y=q&65535;z=c[a+116>>2]|0;a=0;do{if((z|0)>0){A=ba(c[n>>2]|0,a)|0;B=c[o>>2]|0;C=0;D=A;while(1){A=B+(D<<1)|0;E=e[A>>1]|0;do{if((E&j|0)!=0){if(!p){if((d[f+D|0]|0)!=(g|0)){break}}F=h+(D<<2)|0;G=b[F>>1]|0;H=(G|0)<(q|0);if(!((G|0)>=(l|0)|H)){I=b[h+(D<<2)+2>>1]|0;if(!((I|0)>=(m|0)|(I|0)<(w|0))){break}}if(r){b[A>>1]=E&k&65535|1;b[h+(D<<2)+2>>1]=0;b[F>>1]=0;break}do{if((G|0)>(s|0)){b[F>>1]=t}else{if(!H){break}b[F>>1]=y}}while(0);F=h+(D<<2)+2|0;H=b[F>>1]|0;if((H|0)>(u|0)){b[F>>1]=v;break}if((H|0)>=(w|0)){break}b[F>>1]=x}}while(0);E=C+1|0;if((E|0)<(z|0)){C=E;D=D+1|0}else{break}}}a=a+1|0;}while((a|0)<(i|0));return}function Dmb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=c[a+11556>>2]|0;m=c[a+12460>>2]|0;n=c[a+11560>>2]|0;o=c[a+12416>>2]|0;p=c[a+12192>>2]|0;q=a+12352|0;r=a+12384|0;if((c[a+13924>>2]|0)==0){s=(c[q>>2]|0)+((ba(o,e>>1)|0)+(b>>1))|0;cf[c[a+11332+((e<<1&2|b&1)<<2)>>2]&1023](p,s,o,16);s=(c[r>>2]|0)+((ba(o,g>>1)|0)+(f>>1))|0;cf[c[a+11396+((g<<1&2|f&1)<<2)>>2]&1023](p,s,o,16)}else{s=(c[q>>2]|0)+((ba(o,e>>2)|0)+(b>>2))|0;Xe[c[a+10680+((e<<2&12|b&3)<<2)>>2]&4095](p,s,o);s=(c[r>>2]|0)+((ba(o,g>>2)|0)+(f>>2))|0;Xe[c[a+10808+((g<<2&12|f&3)<<2)>>2]&4095](p,s,o)}s=ba((d[e+4096-i+(m+(l*8193|0))|0]|0)+(d[b+4096-h+(m+(l*8193|0))|0]|0)+(d[f+4096-j+(m+(n*8193|0))|0]|0)+(d[g+4096-k+(m+(n*8193|0))|0]|0)|0,c[a+12240>>2]|0)|0;return s+(Pe[c[a+10516>>2]&255](a,c[a+12288>>2]|0,p,o,16)|0)|0}function _ff_epzs_motion_search$0(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0;f=c[a+24>>2]|0;g=c[a+32>>2]|0;h=c[a+40>>2]|0;j=c[a+56>>2]|0;k=c[a+64>>2]|0;l=c[a+72>>2]|0;m=c[a+80>>2]|0;n=c[a+88>>2]|0;o=c[a+96>>2]|0;p=c[a+104>>2]|0;q=c[a+5344>>2]|0;r=c[a+5352>>2]|0;s=c[a+5368>>2]|0;t=c[a+5376>>2]|0;u=c[a+5384>>2]|0;v=c[a+5392>>2]|0;w=c[a+5400>>2]|0;x=c[a+5408>>2]|0;y=c[a+5416>>2]|0;z=c[a+5424>>2]|0;A=c[a+5432>>2]|0;B=c[a+5440>>2]|0;C=c[a+5472>>2]|0;D=c[a+5480>>2]|0;E=c[a+5488>>2]|0;F=c[a+5504>>2]|0;G=c[a+13904>>2]|0;H=c[a+13912>>2]|0;I=c[a+13920>>2]|0;J=c[a+13928>>2]|0;K=c[a+27600>>2]|0;a:do{do{if((J|0)==0){L=I;M=H;N=G}else{O=c[(f+12476|0)>>2]|0;P=(O-J|0|0)<0?0:O-J|0;Q=c[(f+12480|0)>>2]|0;R=(Q-J|0|0)<0?0:Q-J|0;S=c[f+116>>2]|0;T=(S|0)>(O+(J+1|0)|0|0)?O+(J+1|0)|0:S;S=c[f+120>>2]|0;O=(S|0)>(Q+(J+1|0)|0|0)?Q+(J+1|0)|0:S;if((R|0)>=(O|0)){L=I;M=H;N=G;break}S=(p&1)<<1|1;Q=R;R=I;U=H;V=G;while(1){W=Q+1|0;b:do{if((P|0)<(T|0)){X=ba(W,r)|0;Y=P;Z=R;_=U;$=V;while(1){aa=Y;c:while(1){ca=aa+1|0;da=(ba(b[l+((ca+X|0)<<2)>>1]|0,m)|0)+32768|0;ea=(ba(b[l+((ca+X|0)<<2)+2>>1]|0,m)|0)+32768|0;do{if(!((da>>16|0)>(v|0)|(da>>16|0)<(t|0)|(ea>>16|0)>(w|0)|(ea>>16|0)<(u|0))){fa=(da>>16)+F+(ea>>16<<11)|0;if((c[(A+(((ea>>16<<3)+(da>>16)&63)<<2)|0)>>2]|0)==(fa|0)){break}ga=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ha=c[(f+12420|0)>>2]|0;ia=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ga,ea>>16)|0)+(da>>16))|0;ja=Pe[D&255](f,c[(f+12288+(j<<4)|0)>>2]|0,ia,ga,o)|0;if((p&2|0)==0){ka=ja;break}ia=c[(f+12208|0)>>2]|0;la=(ba(ha,ea>>17)|0)+(da>>17)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ea>>16<<1&2|da>>16&1)<<2)>>2]&1023](ia+(ga<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+la|0,ha,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ea>>16<<1&2|da>>16&1)<<2)>>2]&1023](ia+(ga<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+la|0,ha,o>>1);la=(Pe[E&255](f,ia+(ga<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ha,o>>1)|0)+ja|0;ka=la+(Pe[E&255](f,ia+(ga<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ha,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(da>>16|0)){ka=536870912;break}if((da>>16<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ka=536870912;break}if((c[(f+12272|0)>>2]|0)>(ea>>16|0)){ka=536870912;break}if((ea>>16<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ka=536870912;break}ha=e[(f+13872|0)>>1]|0;ia=e[(f+13874|0)>>1]|0;d:do{if((c[(f+11740|0)>>2]|0)==1){if((da>>16<<B|0)==0){la=0;while(1){ja=c[f+12160+(la<<3)>>2]|0;ma=(c[f+12160+(la<<3)+4>>2]|0)+(ea>>16<<B)|0;na=((ba(c[f+12128+(la<<3)>>2]|0,ia-ha|0)|0)/(ha|0)|0)+((la&1)<<(p&1|4))|0;oa=c[f+12128+(la<<3)+4>>2]|0;if((ea>>16<<B|0)==0){pa=la>>1;qa=((ba(oa,ia-ha|0)|0)/(ha|0)|0)+(pa<<(p&1|4))|0;ra=pa}else{qa=ma-oa|0;ra=la>>1}oa=((qa&S)<<B)+(na&S)|0;pa=(c[(f+12208|0)>>2]|0)+((ba(ra,ga<<3)|0)+(la<<3&8))|0;if((p&1|0)==0){sa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ma>>1,ga)|0)+(ja>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ma&S)<<B)+(ja&S)|0)<<2)>>2]&1023](pa,sa,ga,8);sa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(qa>>1,ga)|0)+(na>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(oa<<2)>>2]&1023](pa,sa,ga,8)}else{sa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ma>>2,ga)|0)+(ja>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ma&S)<<B)+(ja&S)|0)<<2)>>2]&4095](pa,sa,ga);sa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(qa>>2,ga)|0)+(na>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(oa<<2)>>2]&4095](pa,sa,ga)}la=la+1|0;if((la|0)>=4){break d}}}if((ea>>16<<B|0)==0){la=0;do{sa=(c[f+12160+(la<<3)>>2]|0)+(da>>16<<B)|0;pa=c[f+12160+(la<<3)+4>>2]|0;oa=sa-(c[f+12128+(la<<3)>>2]|0)|0;na=la>>1;ja=((ba(c[f+12128+(la<<3)+4>>2]|0,ia-ha|0)|0)/(ha|0)|0)+(na<<(p&1|4))|0;ma=(c[(f+12208|0)>>2]|0)+((la<<3&8)+(ba(na,ga<<3)|0))|0;if((p&1|0)==0){na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(pa>>1,ga)|0)+(sa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((pa&S)<<B)+(sa&S)|0)<<2)>>2]&1023](ma,na,ga,8);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ja>>1,ga)|0)+(oa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ja&S)<<B)+(oa&S)|0)<<2)>>2]&1023](ma,na,ga,8)}else{na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(pa>>2,ga)|0)+(sa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(sa&S)|0)<<2)>>2]&4095](ma,na,ga);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ja>>2,ga)|0)+(oa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ja&S)<<B)+(oa&S)|0)<<2)>>2]&4095](ma,na,ga)}la=la+1|0;}while((la|0)<4)}else{la=0;do{na=(c[f+12160+(la<<3)>>2]|0)+(da>>16<<B)|0;ma=(c[f+12160+(la<<3)+4>>2]|0)+(ea>>16<<B)|0;oa=na-(c[f+12128+(la<<3)>>2]|0)|0;ja=ma-(c[f+12128+(la<<3)+4>>2]|0)|0;sa=(c[(f+12208|0)>>2]|0)+((la<<3&8)+(ba(la>>1,ga<<3)|0))|0;if((p&1|0)==0){pa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ma>>1,ga)|0)+(na>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ma&S)<<B)+(na&S)|0)<<2)>>2]&1023](sa,pa,ga,8);pa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ja>>1,ga)|0)+(oa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ja&S)<<B)+(oa&S)|0)<<2)>>2]&1023](sa,pa,ga,8)}else{pa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ma>>2,ga)|0)+(na>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ma&S)<<B)+(na&S)|0)<<2)>>2]&4095](sa,pa,ga);pa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ja>>2,ga)|0)+(oa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ja&S)<<B)+(oa&S)|0)<<2)>>2]&4095](sa,pa,ga)}la=la+1|0;}while((la|0)<4)}}else{la=(c[(f+12160|0)>>2]|0)+(da>>16<<B)|0;pa=(c[(f+12164|0)>>2]|0)+(ea>>16<<B)|0;sa=c[(f+12128|0)>>2]|0;if((da>>16<<B|0)==0){ta=(ba(sa,ia-ha|0)|0)/(ha|0)|0}else{ta=la-sa|0}sa=c[(f+12132|0)>>2]|0;if((ea>>16<<B|0)==0){ua=(ba(sa,ia-ha|0)|0)/(ha|0)|0}else{ua=pa-sa|0}sa=((ua&S)<<B)+(ta&S)|0;if((p&1|0)==0){oa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(pa>>1,ga)|0)+(la>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,oa,ga,16);oa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ua>>1,ga)|0)+(ta>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(sa<<2)>>2]&1023](c[(f+12208|0)>>2]|0,oa,ga,16);break}else{oa=(ba(pa>>2,ga)|0)+(la>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+oa|0,ga);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(oa+8|0)|0,ga);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ga<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(oa+(ga<<3))|0,ga);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ga<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((oa+8|0)+(ga<<3))|0,ga);oa=(ba(ua>>2,ga)|0)+(ta>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(sa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+oa|0,ga);Xe[c[(c[(f+12456|0)>>2]|0)+64+(sa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(oa+8|0)|0,ga);Xe[c[(c[(f+12456|0)>>2]|0)+64+(sa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ga<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(oa+(ga<<3))|0,ga);Xe[c[(c[(f+12456|0)>>2]|0)+64+(sa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ga<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((oa+8|0)+(ga<<3))|0,ga);break}}}while(0);ka=Pe[D&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ga,16)|0}}while(0);c[(A+(((ea>>16<<3)+(da>>16)&63)<<2)|0)>>2]=fa;c[s+(((ea>>16<<3)+(da>>16)&63)<<2)>>2]=ka;va=(ba((d[x+((ea>>16<<B)-z)|0]|0)+(d[x+((da>>16<<B)-y)|0]|0)|0,C)|0)+ka|0;if((va|0)<(Z|0)){break c}}}while(0);if((ca|0)<(T|0)){aa=ca}else{wa=Z;xa=_;ya=$;break b}}c[(a|0)>>2]=da>>16;c[(q+4|0)>>2]=ea>>16;if((ca|0)<(T|0)){Y=ca;Z=va;_=da>>16;$=ea>>16}else{wa=va;xa=da>>16;ya=ea>>16;break}}}else{wa=R;xa=U;ya=V}}while(0);if((W|0)<(O|0)){Q=W;R=wa;U=xa;V=ya}else{L=wa;M=xa;N=ya;break}}}}while(0);V=a|0;U=c[(f+12260|0)>>2]|0;e:do{R=1;if(R){R=0;if((U|0)==-1){Q=c[(f+12220|0)>>2]|0;O=c[(f+12264|0)>>2]|0;T=c[(f+12272|0)>>2]|0;S=c[(f+12268|0)>>2]|0;P=c[(f+12276|0)>>2]|0;$=c[(f+12464|0)>>2]|0;_=c[(f+12280|0)>>2]|0;Z=c[(f+12284|0)>>2]|0;Y=c[(f+12216|0)>>2]|0;X=c[(f+12224|0)>>2]|0;aa=c[f+10468+(n<<2)>>2]|0;ga=c[f+10468+((n+1|0)<<2)>>2]|0;ha=(p&1)<<1|1;ia=p&1|4;oa=(p&1|0)==0;sa=L;la=N;pa=M;f:while(1){ja=1;na=sa;ma=la;za=pa;while(1){do{if((ja-1&ja|0)==0){Aa=ja+pa|0;if((Aa|0)>(S|0)){Ba=na;Ca=ma;Da=za;break}Ea=pa-ja|0;if((Ea|0)<(O|0)){Ba=na;Ca=ma;Da=za;break}Fa=ja+la|0;if((Fa|0)>(P|0)){Ba=na;Ca=ma;Da=za;break}Ga=la-ja|0;if((Ga|0)<(T|0)){Ba=na;Ca=ma;Da=za;break}else{Ha=0;Ia=na;Ja=ma;Ka=za}while(1){La=Fa-Ha|0;Ma=Ha+pa|0;do{if((c[(Y+(((La<<3)+Ma&63)<<2)|0)>>2]|0)==(Ma+X+(La<<11)|0|0)){Na=Ia;Oa=Ja;Pa=Ka}else{Qa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Ra=c[(f+12420|0)>>2]|0;Sa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa,La)|0)+Ma)|0;Ta=Pe[aa&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Sa,Qa,o)|0;if((p&2|0)==0){Ua=Ta;break}Sa=c[(f+12208|0)>>2]|0;Va=(ba(Ra,La>>1)|0)+(Ma>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((La<<1&2|Ma&1)<<2)>>2]&1023](Sa+(Qa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Va|0,Ra,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((La<<1&2|Ma&1)<<2)>>2]&1023](Sa+(Qa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Va|0,Ra,o>>1);Va=(Pe[ga&255](f,Sa+(Qa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Ra,o>>1)|0)+Ta|0;Ua=Va+(Pe[ga&255](f,Sa+(Qa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Ra,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(Ma|0)){Ua=536870912;break}if((Ma<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Ua=536870912;break}if((c[(f+12272|0)>>2]|0)>(La|0)){Ua=536870912;break}if((La<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Ua=536870912;break}Ra=e[(f+13872|0)>>1]|0;Sa=e[(f+13874|0)>>1]|0;g:do{if((c[(f+11740|0)>>2]|0)==1){if((Ma<<B|0)==0){Va=0;while(1){Ta=c[f+12160+(Va<<3)>>2]|0;Wa=(c[f+12160+(Va<<3)+4>>2]|0)+(La<<B)|0;Xa=((ba(c[f+12128+(Va<<3)>>2]|0,Sa-Ra|0)|0)/(Ra|0)|0)+((Va&1)<<ia)|0;Ya=c[f+12128+(Va<<3)+4>>2]|0;if((La<<B|0)==0){Za=Va>>1;_a=((ba(Ya,Sa-Ra|0)|0)/(Ra|0)|0)+(Za<<ia)|0;$a=Za}else{_a=Wa-Ya|0;$a=Va>>1}Ya=((_a&ha)<<B)+(Xa&ha)|0;Za=(c[(f+12208|0)>>2]|0)+((ba($a,Qa<<3)|0)+(Va<<3&8))|0;if(oa){ab=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Wa>>1,Qa)|0)+(Ta>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Wa&ha)<<B)+(Ta&ha)|0)<<2)>>2]&1023](Za,ab,Qa,8);ab=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(_a>>1,Qa)|0)+(Xa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Ya<<2)>>2]&1023](Za,ab,Qa,8)}else{ab=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Wa>>2,Qa)|0)+(Ta>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Wa&ha)<<B)+(Ta&ha)|0)<<2)>>2]&4095](Za,ab,Qa);ab=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(_a>>2,Qa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095](Za,ab,Qa)}Va=Va+1|0;if((Va|0)>=4){break g}}}if((La<<B|0)==0){Va=0;do{ab=(c[f+12160+(Va<<3)>>2]|0)+(Ma<<B)|0;Za=c[f+12160+(Va<<3)+4>>2]|0;Ya=ab-(c[f+12128+(Va<<3)>>2]|0)|0;Xa=Va>>1;Ta=((ba(c[f+12128+(Va<<3)+4>>2]|0,Sa-Ra|0)|0)/(Ra|0)|0)+(Xa<<ia)|0;Wa=(c[(f+12208|0)>>2]|0)+((Va<<3&8)+(ba(Xa,Qa<<3)|0))|0;if(oa){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Za>>1,Qa)|0)+(ab>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Za&ha)<<B)+(ab&ha)|0)<<2)>>2]&1023](Wa,Xa,Qa,8);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ta>>1,Qa)|0)+(Ya>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&1023](Wa,Xa,Qa,8)}else{Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Za>>2,Qa)|0)+(ab>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095](Wa,Xa,Qa);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ta>>2,Qa)|0)+(Ya>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095](Wa,Xa,Qa)}Va=Va+1|0;}while((Va|0)<4)}else{Va=0;do{Xa=(c[f+12160+(Va<<3)>>2]|0)+(Ma<<B)|0;Wa=(c[f+12160+(Va<<3)+4>>2]|0)+(La<<B)|0;Ya=Xa-(c[f+12128+(Va<<3)>>2]|0)|0;Ta=Wa-(c[f+12128+(Va<<3)+4>>2]|0)|0;ab=(c[(f+12208|0)>>2]|0)+((Va<<3&8)+(ba(Va>>1,Qa<<3)|0))|0;if(oa){Za=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Wa>>1,Qa)|0)+(Xa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Wa&ha)<<B)+(Xa&ha)|0)<<2)>>2]&1023](ab,Za,Qa,8);Za=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ta>>1,Qa)|0)+(Ya>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&1023](ab,Za,Qa,8)}else{Za=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Wa>>2,Qa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Wa&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095](ab,Za,Qa);Za=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ta>>2,Qa)|0)+(Ya>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095](ab,Za,Qa)}Va=Va+1|0;}while((Va|0)<4)}}else{Va=(c[(f+12160|0)>>2]|0)+(Ma<<B)|0;Za=(c[(f+12164|0)>>2]|0)+(La<<B)|0;ab=c[(f+12128|0)>>2]|0;if((Ma<<B|0)==0){bb=(ba(ab,Sa-Ra|0)|0)/(Ra|0)|0}else{bb=Va-ab|0}ab=c[(f+12132|0)>>2]|0;if((La<<B|0)==0){cb=(ba(ab,Sa-Ra|0)|0)/(Ra|0)|0}else{cb=Za-ab|0}ab=((cb&ha)<<B)+(bb&ha)|0;if(oa){Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Za>>1,Qa)|0)+(Va>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ya,Qa,16);Ya=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(cb>>1,Qa)|0)+(bb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(ab<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ya,Qa,16);break}else{Ya=(ba(Za>>2,Qa)|0)+(Va>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ya|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ya+8|0)|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ya+(Qa<<3))|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ya+8|0)+(Qa<<3))|0,Qa);Ya=(ba(cb>>2,Qa)|0)+(bb>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ya|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ya+8|0)|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ya+(Qa<<3))|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ya+8|0)+(Qa<<3))|0,Qa);break}}}while(0);Ua=Pe[aa&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Qa,16)|0}}while(0);c[(Y+(((La<<3)+Ma&63)<<2)|0)>>2]=Ma+X+(La<<11)|0;c[Q+(((La<<3)+Ma&63)<<2)>>2]=Ua;Qa=(ba((d[$+((La<<B)-Z)|0]|0)+(d[$+((Ma<<B)-_)|0]|0)|0,C)|0)+Ua|0;if((Qa|0)>=(Ia|0)){Na=Ia;Oa=Ja;Pa=Ka;break}c[V>>2]=Ma;c[(V+4|0)>>2]=La;Na=Qa;Oa=La;Pa=Ma}}while(0);Ma=la-Ha|0;La=Aa-Ha|0;do{if((c[(Y+(((Ma<<3)+La&63)<<2)|0)>>2]|0)==(La+X+(Ma<<11)|0|0)){db=Na;eb=Oa;fb=Pa}else{Qa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){fa=c[(f+12420|0)>>2]|0;Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa,Ma)|0)+La)|0;Sa=Pe[aa&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ra,Qa,o)|0;if((p&2|0)==0){gb=Sa;break}Ra=c[(f+12208|0)>>2]|0;Ya=(ba(fa,Ma>>1)|0)+(La>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ma<<1&2|La&1)<<2)>>2]&1023](Ra+(Qa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Ya|0,fa,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ma<<1&2|La&1)<<2)>>2]&1023](Ra+(Qa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Ya|0,fa,o>>1);Ya=(Pe[ga&255](f,Ra+(Qa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,fa,o>>1)|0)+Sa|0;gb=Ya+(Pe[ga&255](f,Ra+(Qa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,fa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(La|0)){gb=536870912;break}if((La<<B|0)>(c[(f+12268|0)>>2]<<B|0)){gb=536870912;break}if((c[(f+12272|0)>>2]|0)>(Ma|0)){gb=536870912;break}if((Ma<<B|0)>(c[(f+12276|0)>>2]<<B|0)){gb=536870912;break}fa=e[(f+13872|0)>>1]|0;Ra=e[(f+13874|0)>>1]|0;h:do{if((c[(f+11740|0)>>2]|0)==1){if((La<<B|0)==0){Ya=0;while(1){Sa=c[f+12160+(Ya<<3)>>2]|0;ab=(c[f+12160+(Ya<<3)+4>>2]|0)+(Ma<<B)|0;Va=((ba(c[f+12128+(Ya<<3)>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+((Ya&1)<<ia)|0;Za=c[f+12128+(Ya<<3)+4>>2]|0;if((Ma<<B|0)==0){Ta=Ya>>1;hb=((ba(Za,Ra-fa|0)|0)/(fa|0)|0)+(Ta<<ia)|0;ib=Ta}else{hb=ab-Za|0;ib=Ya>>1}Za=((hb&ha)<<B)+(Va&ha)|0;Ta=(c[(f+12208|0)>>2]|0)+((ba(ib,Qa<<3)|0)+(Ya<<3&8))|0;if(oa){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ab>>1,Qa)|0)+(Sa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ab&ha)<<B)+(Sa&ha)|0)<<2)>>2]&1023](Ta,Xa,Qa,8);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(hb>>1,Qa)|0)+(Va>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Za<<2)>>2]&1023](Ta,Xa,Qa,8)}else{Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ab>>2,Qa)|0)+(Sa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ab&ha)<<B)+(Sa&ha)|0)<<2)>>2]&4095](Ta,Xa,Qa);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(hb>>2,Qa)|0)+(Va>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095](Ta,Xa,Qa)}Ya=Ya+1|0;if((Ya|0)>=4){break h}}}if((Ma<<B|0)==0){Ya=0;do{Xa=(c[f+12160+(Ya<<3)>>2]|0)+(La<<B)|0;Ta=c[f+12160+(Ya<<3)+4>>2]|0;Za=Xa-(c[f+12128+(Ya<<3)>>2]|0)|0;Va=Ya>>1;Sa=((ba(c[f+12128+(Ya<<3)+4>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+(Va<<ia)|0;ab=(c[(f+12208|0)>>2]|0)+((Ya<<3&8)+(ba(Va,Qa<<3)|0))|0;if(oa){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>1,Qa)|0)+(Xa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ta&ha)<<B)+(Xa&ha)|0)<<2)>>2]&1023](ab,Va,Qa,8);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>1,Qa)|0)+(Za>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&1023](ab,Va,Qa,8)}else{Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>2,Qa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095](ab,Va,Qa);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>2,Qa)|0)+(Za>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](ab,Va,Qa)}Ya=Ya+1|0;}while((Ya|0)<4)}else{Ya=0;do{Va=(c[f+12160+(Ya<<3)>>2]|0)+(La<<B)|0;ab=(c[f+12160+(Ya<<3)+4>>2]|0)+(Ma<<B)|0;Za=Va-(c[f+12128+(Ya<<3)>>2]|0)|0;Sa=ab-(c[f+12128+(Ya<<3)+4>>2]|0)|0;Xa=(c[(f+12208|0)>>2]|0)+((Ya<<3&8)+(ba(Ya>>1,Qa<<3)|0))|0;if(oa){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ab>>1,Qa)|0)+(Va>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ab&ha)<<B)+(Va&ha)|0)<<2)>>2]&1023](Xa,Ta,Qa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>1,Qa)|0)+(Za>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&1023](Xa,Ta,Qa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ab>>2,Qa)|0)+(Va>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ab&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095](Xa,Ta,Qa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>2,Qa)|0)+(Za>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](Xa,Ta,Qa)}Ya=Ya+1|0;}while((Ya|0)<4)}}else{Ya=(c[(f+12160|0)>>2]|0)+(La<<B)|0;Ta=(c[(f+12164|0)>>2]|0)+(Ma<<B)|0;Xa=c[(f+12128|0)>>2]|0;if((La<<B|0)==0){jb=(ba(Xa,Ra-fa|0)|0)/(fa|0)|0}else{jb=Ya-Xa|0}Xa=c[(f+12132|0)>>2]|0;if((Ma<<B|0)==0){kb=(ba(Xa,Ra-fa|0)|0)/(fa|0)|0}else{kb=Ta-Xa|0}Xa=((kb&ha)<<B)+(jb&ha)|0;if(oa){Za=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>1,Qa)|0)+(Ya>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Za,Qa,16);Za=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(kb>>1,Qa)|0)+(jb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(Xa<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Za,Qa,16);break}else{Za=(ba(Ta>>2,Qa)|0)+(Ya>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Za|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Za+8|0)|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Za+(Qa<<3))|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Za+8|0)+(Qa<<3))|0,Qa);Za=(ba(kb>>2,Qa)|0)+(jb>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Za|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Za+8|0)|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Za+(Qa<<3))|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Za+8|0)+(Qa<<3))|0,Qa);break}}}while(0);gb=Pe[aa&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Qa,16)|0}}while(0);c[(Y+(((Ma<<3)+La&63)<<2)|0)>>2]=La+X+(Ma<<11)|0;c[Q+(((Ma<<3)+La&63)<<2)>>2]=gb;Qa=(ba((d[$+((Ma<<B)-Z)|0]|0)+(d[$+((La<<B)-_)|0]|0)|0,C)|0)+gb|0;if((Qa|0)>=(Na|0)){db=Na;eb=Oa;fb=Pa;break}c[V>>2]=La;c[(V+4|0)>>2]=Ma;db=Qa;eb=Ma;fb=La}}while(0);La=Ha+Ga|0;Ma=pa-Ha|0;do{if((c[(Y+(((La<<3)+Ma&63)<<2)|0)>>2]|0)==(Ma+X+(La<<11)|0|0)){lb=db;mb=eb;nb=fb}else{Qa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){fa=c[(f+12420|0)>>2]|0;Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa,La)|0)+Ma)|0;Za=Pe[aa&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ra,Qa,o)|0;if((p&2|0)==0){ob=Za;break}Ra=c[(f+12208|0)>>2]|0;Xa=(ba(fa,La>>1)|0)+(Ma>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((La<<1&2|Ma&1)<<2)>>2]&1023](Ra+(Qa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Xa|0,fa,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((La<<1&2|Ma&1)<<2)>>2]&1023](Ra+(Qa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Xa|0,fa,o>>1);Xa=(Pe[ga&255](f,Ra+(Qa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,fa,o>>1)|0)+Za|0;ob=Xa+(Pe[ga&255](f,Ra+(Qa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,fa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(Ma|0)){ob=536870912;break}if((Ma<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ob=536870912;break}if((c[(f+12272|0)>>2]|0)>(La|0)){ob=536870912;break}if((La<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ob=536870912;break}fa=e[(f+13872|0)>>1]|0;Ra=e[(f+13874|0)>>1]|0;i:do{if((c[(f+11740|0)>>2]|0)==1){if((Ma<<B|0)==0){Xa=0;while(1){Za=c[f+12160+(Xa<<3)>>2]|0;Ya=(c[f+12160+(Xa<<3)+4>>2]|0)+(La<<B)|0;Ta=((ba(c[f+12128+(Xa<<3)>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+((Xa&1)<<ia)|0;Sa=c[f+12128+(Xa<<3)+4>>2]|0;if((La<<B|0)==0){Va=Xa>>1;pb=((ba(Sa,Ra-fa|0)|0)/(fa|0)|0)+(Va<<ia)|0;qb=Va}else{pb=Ya-Sa|0;qb=Xa>>1}Sa=((pb&ha)<<B)+(Ta&ha)|0;Va=(c[(f+12208|0)>>2]|0)+((ba(qb,Qa<<3)|0)+(Xa<<3&8))|0;if(oa){ab=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ya>>1,Qa)|0)+(Za>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ya&ha)<<B)+(Za&ha)|0)<<2)>>2]&1023](Va,ab,Qa,8);ab=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(pb>>1,Qa)|0)+(Ta>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Sa<<2)>>2]&1023](Va,ab,Qa,8)}else{ab=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ya>>2,Qa)|0)+(Za>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ya&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](Va,ab,Qa);ab=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(pb>>2,Qa)|0)+(Ta>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Sa<<2)>>2]&4095](Va,ab,Qa)}Xa=Xa+1|0;if((Xa|0)>=4){break i}}}if((La<<B|0)==0){Xa=0;do{ab=(c[f+12160+(Xa<<3)>>2]|0)+(Ma<<B)|0;Va=c[f+12160+(Xa<<3)+4>>2]|0;Sa=ab-(c[f+12128+(Xa<<3)>>2]|0)|0;Ta=Xa>>1;Za=((ba(c[f+12128+(Xa<<3)+4>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+(Ta<<ia)|0;Ya=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ba(Ta,Qa<<3)|0))|0;if(oa){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Va>>1,Qa)|0)+(ab>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Va&ha)<<B)+(ab&ha)|0)<<2)>>2]&1023](Ya,Ta,Qa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Za>>1,Qa)|0)+(Sa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Za&ha)<<B)+(Sa&ha)|0)<<2)>>2]&1023](Ya,Ta,Qa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Va>>2,Qa)|0)+(ab>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095](Ya,Ta,Qa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Za>>2,Qa)|0)+(Sa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Za&ha)<<B)+(Sa&ha)|0)<<2)>>2]&4095](Ya,Ta,Qa)}Xa=Xa+1|0;}while((Xa|0)<4)}else{Xa=0;do{Ta=(c[f+12160+(Xa<<3)>>2]|0)+(Ma<<B)|0;Ya=(c[f+12160+(Xa<<3)+4>>2]|0)+(La<<B)|0;Sa=Ta-(c[f+12128+(Xa<<3)>>2]|0)|0;Za=Ya-(c[f+12128+(Xa<<3)+4>>2]|0)|0;ab=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ba(Xa>>1,Qa<<3)|0))|0;if(oa){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ya>>1,Qa)|0)+(Ta>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ya&ha)<<B)+(Ta&ha)|0)<<2)>>2]&1023](ab,Va,Qa,8);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Za>>1,Qa)|0)+(Sa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Za&ha)<<B)+(Sa&ha)|0)<<2)>>2]&1023](ab,Va,Qa,8)}else{Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ya>>2,Qa)|0)+(Ta>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ya&ha)<<B)+(Ta&ha)|0)<<2)>>2]&4095](ab,Va,Qa);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Za>>2,Qa)|0)+(Sa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Za&ha)<<B)+(Sa&ha)|0)<<2)>>2]&4095](ab,Va,Qa)}Xa=Xa+1|0;}while((Xa|0)<4)}}else{Xa=(c[(f+12160|0)>>2]|0)+(Ma<<B)|0;Va=(c[(f+12164|0)>>2]|0)+(La<<B)|0;ab=c[(f+12128|0)>>2]|0;if((Ma<<B|0)==0){rb=(ba(ab,Ra-fa|0)|0)/(fa|0)|0}else{rb=Xa-ab|0}ab=c[(f+12132|0)>>2]|0;if((La<<B|0)==0){sb=(ba(ab,Ra-fa|0)|0)/(fa|0)|0}else{sb=Va-ab|0}ab=((sb&ha)<<B)+(rb&ha)|0;if(oa){Sa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Va>>1,Qa)|0)+(Xa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Sa,Qa,16);Sa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(sb>>1,Qa)|0)+(rb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(ab<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Sa,Qa,16);break}else{Sa=(ba(Va>>2,Qa)|0)+(Xa>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Sa|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Sa+8|0)|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Sa+(Qa<<3))|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Sa+8|0)+(Qa<<3))|0,Qa);Sa=(ba(sb>>2,Qa)|0)+(rb>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Sa|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Sa+8|0)|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Sa+(Qa<<3))|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Sa+8|0)+(Qa<<3))|0,Qa);break}}}while(0);ob=Pe[aa&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Qa,16)|0}}while(0);c[(Y+(((La<<3)+Ma&63)<<2)|0)>>2]=Ma+X+(La<<11)|0;c[Q+(((La<<3)+Ma&63)<<2)>>2]=ob;Qa=(ba((d[$+((La<<B)-Z)|0]|0)+(d[$+((Ma<<B)-_)|0]|0)|0,C)|0)+ob|0;if((Qa|0)>=(db|0)){lb=db;mb=eb;nb=fb;break}c[V>>2]=Ma;c[(V+4|0)>>2]=La;lb=Qa;mb=La;nb=Ma}}while(0);Ma=Ha+la|0;La=Ha+Ea|0;do{if((c[(Y+(((Ma<<3)+La&63)<<2)|0)>>2]|0)==(La+X+(Ma<<11)|0|0)){tb=lb;ub=mb;vb=nb}else{Qa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){fa=c[(f+12420|0)>>2]|0;Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa,Ma)|0)+La)|0;Sa=Pe[aa&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ra,Qa,o)|0;if((p&2|0)==0){wb=Sa;break}Ra=c[(f+12208|0)>>2]|0;ab=(ba(fa,Ma>>1)|0)+(La>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ma<<1&2|La&1)<<2)>>2]&1023](Ra+(Qa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+ab|0,fa,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ma<<1&2|La&1)<<2)>>2]&1023](Ra+(Qa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+ab|0,fa,o>>1);ab=(Pe[ga&255](f,Ra+(Qa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,fa,o>>1)|0)+Sa|0;wb=ab+(Pe[ga&255](f,Ra+(Qa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,fa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(La|0)){wb=536870912;break}if((La<<B|0)>(c[(f+12268|0)>>2]<<B|0)){wb=536870912;break}if((c[(f+12272|0)>>2]|0)>(Ma|0)){wb=536870912;break}if((Ma<<B|0)>(c[(f+12276|0)>>2]<<B|0)){wb=536870912;break}fa=e[(f+13872|0)>>1]|0;Ra=e[(f+13874|0)>>1]|0;j:do{if((c[(f+11740|0)>>2]|0)==1){if((La<<B|0)==0){ab=0;while(1){Sa=c[f+12160+(ab<<3)>>2]|0;Xa=(c[f+12160+(ab<<3)+4>>2]|0)+(Ma<<B)|0;Va=((ba(c[f+12128+(ab<<3)>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+((ab&1)<<ia)|0;Za=c[f+12128+(ab<<3)+4>>2]|0;if((Ma<<B|0)==0){Ta=ab>>1;xb=((ba(Za,Ra-fa|0)|0)/(fa|0)|0)+(Ta<<ia)|0;yb=Ta}else{xb=Xa-Za|0;yb=ab>>1}Za=((xb&ha)<<B)+(Va&ha)|0;Ta=(c[(f+12208|0)>>2]|0)+((ba(yb,Qa<<3)|0)+(ab<<3&8))|0;if(oa){Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Xa>>1,Qa)|0)+(Sa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Xa&ha)<<B)+(Sa&ha)|0)<<2)>>2]&1023](Ta,Ya,Qa,8);Ya=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(xb>>1,Qa)|0)+(Va>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Za<<2)>>2]&1023](Ta,Ya,Qa,8)}else{Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Xa>>2,Qa)|0)+(Sa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Xa&ha)<<B)+(Sa&ha)|0)<<2)>>2]&4095](Ta,Ya,Qa);Ya=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(xb>>2,Qa)|0)+(Va>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095](Ta,Ya,Qa)}ab=ab+1|0;if((ab|0)>=4){break j}}}if((Ma<<B|0)==0){ab=0;do{Ya=(c[f+12160+(ab<<3)>>2]|0)+(La<<B)|0;Ta=c[f+12160+(ab<<3)+4>>2]|0;Za=Ya-(c[f+12128+(ab<<3)>>2]|0)|0;Va=ab>>1;Sa=((ba(c[f+12128+(ab<<3)+4>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+(Va<<ia)|0;Xa=(c[(f+12208|0)>>2]|0)+((ab<<3&8)+(ba(Va,Qa<<3)|0))|0;if(oa){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>1,Qa)|0)+(Ya>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&1023](Xa,Va,Qa,8);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>1,Qa)|0)+(Za>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&1023](Xa,Va,Qa,8)}else{Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>2,Qa)|0)+(Ya>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095](Xa,Va,Qa);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>2,Qa)|0)+(Za>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](Xa,Va,Qa)}ab=ab+1|0;}while((ab|0)<4)}else{ab=0;do{Va=(c[f+12160+(ab<<3)>>2]|0)+(La<<B)|0;Xa=(c[f+12160+(ab<<3)+4>>2]|0)+(Ma<<B)|0;Za=Va-(c[f+12128+(ab<<3)>>2]|0)|0;Sa=Xa-(c[f+12128+(ab<<3)+4>>2]|0)|0;Ya=(c[(f+12208|0)>>2]|0)+((ab<<3&8)+(ba(ab>>1,Qa<<3)|0))|0;if(oa){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Xa>>1,Qa)|0)+(Va>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Xa&ha)<<B)+(Va&ha)|0)<<2)>>2]&1023](Ya,Ta,Qa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>1,Qa)|0)+(Za>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&1023](Ya,Ta,Qa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Xa>>2,Qa)|0)+(Va>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Xa&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095](Ya,Ta,Qa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>2,Qa)|0)+(Za>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](Ya,Ta,Qa)}ab=ab+1|0;}while((ab|0)<4)}}else{ab=(c[(f+12160|0)>>2]|0)+(La<<B)|0;Ta=(c[(f+12164|0)>>2]|0)+(Ma<<B)|0;Ya=c[(f+12128|0)>>2]|0;if((La<<B|0)==0){zb=(ba(Ya,Ra-fa|0)|0)/(fa|0)|0}else{zb=ab-Ya|0}Ya=c[(f+12132|0)>>2]|0;if((Ma<<B|0)==0){Ab=(ba(Ya,Ra-fa|0)|0)/(fa|0)|0}else{Ab=Ta-Ya|0}Ya=((Ab&ha)<<B)+(zb&ha)|0;if(oa){Za=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>1,Qa)|0)+(ab>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Za,Qa,16);Za=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ab>>1,Qa)|0)+(zb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(Ya<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Za,Qa,16);break}else{Za=(ba(Ta>>2,Qa)|0)+(ab>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Za|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Za+8|0)|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Za+(Qa<<3))|0,Qa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Za+8|0)+(Qa<<3))|0,Qa);Za=(ba(Ab>>2,Qa)|0)+(zb>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Za|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Za+8|0)|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Za+(Qa<<3))|0,Qa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Za+8|0)+(Qa<<3))|0,Qa);break}}}while(0);wb=Pe[aa&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Qa,16)|0}}while(0);c[(Y+(((Ma<<3)+La&63)<<2)|0)>>2]=La+X+(Ma<<11)|0;c[Q+(((Ma<<3)+La&63)<<2)>>2]=wb;Qa=(ba((d[$+((Ma<<B)-Z)|0]|0)+(d[$+((La<<B)-_)|0]|0)|0,C)|0)+wb|0;if((Qa|0)>=(lb|0)){tb=lb;ub=mb;vb=nb;break}c[V>>2]=La;c[(V+4|0)>>2]=Ma;tb=Qa;ub=Ma;vb=La}}while(0);La=Ha+2|0;if((La|0)<(ja|0)){Ha=La;Ia=tb;Ja=ub;Ka=vb}else{break}}if((pa|0)!=(vb|0)){sa=tb;la=ub;pa=vb;continue f}if((la|0)==(ub|0)){Ba=tb;Ca=la;Da=pa}else{sa=tb;la=ub;pa=pa;continue f}}else{Ba=na;Ca=ma;Da=za}}while(0);Ea=ja+1|0;if((Ea|0)<5){ja=Ea;na=Ba;ma=Ca;za=Da}else{Bb=Ba;break e}}}}else{R=1}}if(R){R=0;if(1){if((U|0)<-1){Bb=Fmb(f,V,j,k,C,n,o,p)|0;break}if((U|0)<2){pa=c[(f+12220|0)>>2]|0;la=c[(f+12264|0)>>2]|0;sa=c[(f+12272|0)>>2]|0;_=c[(f+12268|0)>>2]|0;$=c[(f+12276|0)>>2]|0;Z=c[(f+12464|0)>>2]|0;Q=c[(f+12280|0)>>2]|0;X=c[(f+12284|0)>>2]|0;Y=c[(f+12216|0)>>2]|0;aa=c[(f+12224|0)>>2]|0;ha=c[f+10468+(n<<2)>>2]|0;oa=c[f+10468+((n+1|0)<<2)>>2]|0;ia=(N<<11)+M+aa|0;ga=(N<<3)+M&63;if((c[(Y+(ga<<2)|0)>>2]|0)!=(ia|0)){do{if((p&4|0)==0){T=c[f+12416>>2]|0;P=c[f+12420>>2]|0;O=(c[f+12352+(k<<4)>>2]|0)+((ba(T,N)|0)+M)|0;S=Pe[ha&255](f,c[f+12288+(j<<4)>>2]|0,O,T,o)|0;if((p&2|0)==0){Cb=S;break}O=N<<1&2|M&1;za=c[f+12208>>2]|0;ma=(ba(P,N>>1)|0)+(M>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(O<<2)>>2]&1023](za+(T<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+ma|0,P,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(O<<2)>>2]&1023](za+(T<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+ma|0,P,o>>1);ma=(Pe[oa&255](f,za+(T<<4)|0,c[f+12288+(j<<4)+4>>2]|0,P,o>>1)|0)+S|0;Cb=ma+(Pe[oa&255](f,za+(T<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,P,o>>1)|0)|0}else{P=c[f+12416>>2]|0;T=M<<B;za=N<<B;if((la|0)>(M|0)){Cb=536870912;break}if((T|0)>(_<<B|0)|(sa|0)>(N|0)){Cb=536870912;break}if((za|0)>($<<B|0)){Cb=536870912;break}ma=e[f+13872>>1]|0;S=e[f+13874>>1]|0;O=(p&1)<<1|1;k:do{if((c[f+11740>>2]|0)==1){if((T|0)==0){na=0;while(1){ja=c[f+12160+(na<<3)>>2]|0;W=(c[f+12160+(na<<3)+4>>2]|0)+za|0;Ea=((ba(c[f+12128+(na<<3)>>2]|0,S-ma|0)|0)/(ma|0)|0)+((na&1)<<(p&1|4))|0;Ga=c[f+12128+(na<<3)+4>>2]|0;if((za|0)==0){Aa=na>>1;Db=((ba(Ga,S-ma|0)|0)/(ma|0)|0)+(Aa<<(p&1|4))|0;Eb=Aa}else{Db=W-Ga|0;Eb=na>>1}Ga=((Db&O)<<B)+(Ea&O)|0;Aa=(c[(f+12208|0)>>2]|0)+((ba(Eb,P<<3)|0)+(na<<3&8))|0;if((p&1|0)==0){Fa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(W>>1,P)|0)+(ja>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((W&O)<<B)+(ja&O)|0)<<2)>>2]&1023](Aa,Fa,P,8);Fa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Db>>1,P)|0)+(Ea>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Ga<<2)>>2]&1023](Aa,Fa,P,8)}else{Fa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(W>>2,P)|0)+(ja>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((W&O)<<B)+(ja&O)|0)<<2)>>2]&4095](Aa,Fa,P);Fa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Db>>2,P)|0)+(Ea>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095](Aa,Fa,P)}na=na+1|0;if((na|0)>=4){break k}}}if((za|0)==0){na=0;do{Fa=(c[f+12160+(na<<3)>>2]|0)+T|0;Aa=c[f+12160+(na<<3)+4>>2]|0;Ga=Fa-(c[f+12128+(na<<3)>>2]|0)|0;Ea=na>>1;ja=((ba(c[f+12128+(na<<3)+4>>2]|0,S-ma|0)|0)/(ma|0)|0)+(Ea<<(p&1|4))|0;W=(c[(f+12208|0)>>2]|0)+((na<<3&8)+(ba(Ea,P<<3)|0))|0;if((p&1|0)==0){Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Aa>>1,P)|0)+(Fa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Aa&O)<<B)+(Fa&O)|0)<<2)>>2]&1023](W,Ea,P,8);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ja>>1,P)|0)+(Ga>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ja&O)<<B)+(Ga&O)|0)<<2)>>2]&1023](W,Ea,P,8)}else{Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Aa>>2,P)|0)+(Fa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(Fa&O)|0)<<2)>>2]&4095](W,Ea,P);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ja>>2,P)|0)+(Ga>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ja&O)<<B)+(Ga&O)|0)<<2)>>2]&4095](W,Ea,P)}na=na+1|0;}while((na|0)<4)}else{na=0;do{Ea=(c[f+12160+(na<<3)>>2]|0)+T|0;W=(c[f+12160+(na<<3)+4>>2]|0)+za|0;Ga=Ea-(c[f+12128+(na<<3)>>2]|0)|0;ja=W-(c[f+12128+(na<<3)+4>>2]|0)|0;Fa=(c[(f+12208|0)>>2]|0)+((na<<3&8)+(ba(na>>1,P<<3)|0))|0;if((p&1|0)==0){Aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(W>>1,P)|0)+(Ea>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((W&O)<<B)+(Ea&O)|0)<<2)>>2]&1023](Fa,Aa,P,8);Aa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ja>>1,P)|0)+(Ga>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ja&O)<<B)+(Ga&O)|0)<<2)>>2]&1023](Fa,Aa,P,8)}else{Aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(W>>2,P)|0)+(Ea>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((W&O)<<B)+(Ea&O)|0)<<2)>>2]&4095](Fa,Aa,P);Aa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ja>>2,P)|0)+(Ga>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ja&O)<<B)+(Ga&O)|0)<<2)>>2]&4095](Fa,Aa,P)}na=na+1|0;}while((na|0)<4)}}else{na=(c[f+12160>>2]|0)+T|0;Aa=(c[f+12164>>2]|0)+za|0;Fa=c[f+12128>>2]|0;if((T|0)==0){Fb=(ba(Fa,S-ma|0)|0)/(ma|0)|0}else{Fb=na-Fa|0}Fa=c[f+12132>>2]|0;if((za|0)==0){Gb=(ba(Fa,S-ma|0)|0)/(ma|0)|0}else{Gb=Aa-Fa|0}Fa=((Gb&O)<<B)+(Fb&O)|0;if((p&1|0)==0){Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Aa>>1,P)|0)+(na>>1))|0;cf[c[(c[f+12444>>2]|0)+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ga,P,16);Ga=(c[f+12352+(k<<4)+32>>2]|0)+((ba(Gb>>1,P)|0)+(Fb>>1))|0;cf[c[(c[f+12448>>2]|0)+(Fa<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ga,P,16);break}else{Ga=(ba(Aa>>2,P)|0)+(na>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ga|0,P);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ga+8|0)|0,P);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(P<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ga+(P<<3))|0,P);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((P<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ga+8|0)+(P<<3))|0,P);Ga=(ba(Gb>>2,P)|0)+(Fb>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Fa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ga|0,P);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Fa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ga+8|0)|0,P);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Fa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(P<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ga+(P<<3))|0,P);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Fa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((P<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ga+8|0)+(P<<3))|0,P);break}}}while(0);Cb=Pe[ha&255](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,P,16)|0}}while(0);c[pa+(ga<<2)>>2]=Cb;c[(Y+(ga<<2)|0)>>2]=ia}O=(p&1)<<1|1;ma=p&1|4;S=(p&1|0)==0;za=L;T=-1;Ga=M;Fa=N;while(1){na=(Ga|0)>(la|0);Aa=Ga-1|0;ja=Ga+aa|0;Ea=Ga&1;W=Ga>>1;La=Ga<<B;Ma=(Ga|0)<(_|0);Qa=Ga+1|0;fa=za;Ra=T;Za=Fa;while(1){do{if((Ra|0)!=2&na){Ya=(Za<<11)+aa+Aa|0;ab=Aa+(Za<<3)&63;if((c[(Y+(ab<<2)|0)>>2]|0)==(Ya|0)){Hb=fa;Ib=-1;Jb=Ga;break}Ta=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Sa=c[(f+12420|0)>>2]|0;Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta,Za)|0)+Aa)|0;Xa=Pe[ha&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Va,Ta,o)|0;if((p&2|0)==0){Kb=Xa;break}Va=Aa&1|Za<<1&2;Wa=c[(f+12208|0)>>2]|0;Lb=(ba(Sa,Za>>1)|0)+(Aa>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Va<<2)>>2]&1023](Wa+(Ta<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Lb|0,Sa,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Va<<2)>>2]&1023](Wa+(Ta<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Lb|0,Sa,o>>1);Lb=(Pe[oa&255](f,Wa+(Ta<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Sa,o>>1)|0)+Xa|0;Kb=Lb+(Pe[oa&255](f,Wa+(Ta<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Sa,o>>1)|0)|0}else{Sa=Za<<B;if((c[(f+12264|0)>>2]|0)>(Aa|0)){Kb=536870912;break}if((Aa<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Kb=536870912;break}if((c[(f+12272|0)>>2]|0)>(Za|0)){Kb=536870912;break}if((Sa|0)>(c[(f+12276|0)>>2]<<B|0)){Kb=536870912;break}Wa=e[(f+13872|0)>>1]|0;Lb=e[(f+13874|0)>>1]|0;l:do{if((c[(f+11740|0)>>2]|0)==1){if((Aa<<B|0)==0){Xa=0;while(1){Va=c[f+12160+(Xa<<3)>>2]|0;Mb=(c[f+12160+(Xa<<3)+4>>2]|0)+Sa|0;Nb=((ba(c[f+12128+(Xa<<3)>>2]|0,Lb-Wa|0)|0)/(Wa|0)|0)+((Xa&1)<<ma)|0;Ob=c[f+12128+(Xa<<3)+4>>2]|0;if((Sa|0)==0){Pb=Xa>>1;Qb=((ba(Ob,Lb-Wa|0)|0)/(Wa|0)|0)+(Pb<<ma)|0;Rb=Pb}else{Qb=Mb-Ob|0;Rb=Xa>>1}Ob=((Qb&O)<<B)+(Nb&O)|0;Pb=(c[(f+12208|0)>>2]|0)+((ba(Rb,Ta<<3)|0)+(Xa<<3&8))|0;if(S){Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>1,Ta)|0)+(Va>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(Va&O)|0)<<2)>>2]&1023](Pb,Sb,Ta,8);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Qb>>1,Ta)|0)+(Nb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Ob<<2)>>2]&1023](Pb,Sb,Ta,8)}else{Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>2,Ta)|0)+(Va>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Va&O)|0)<<2)>>2]&4095](Pb,Sb,Ta);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Qb>>2,Ta)|0)+(Nb>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ob<<2)>>2]&4095](Pb,Sb,Ta)}Xa=Xa+1|0;if((Xa|0)>=4){break l}}}if((Sa|0)==0){Xa=0;do{Sb=(c[f+12160+(Xa<<3)>>2]|0)+(Aa<<B)|0;Pb=c[f+12160+(Xa<<3)+4>>2]|0;Ob=Sb-(c[f+12128+(Xa<<3)>>2]|0)|0;Nb=Xa>>1;Va=((ba(c[f+12128+(Xa<<3)+4>>2]|0,Lb-Wa|0)|0)/(Wa|0)|0)+(Nb<<ma)|0;Mb=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ba(Nb,Ta<<3)|0))|0;if(S){Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>1,Ta)|0)+(Sb>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Pb&O)<<B)+(Sb&O)|0)<<2)>>2]&1023](Mb,Nb,Ta,8);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Va>>1,Ta)|0)+(Ob>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Va&O)<<B)+(Ob&O)|0)<<2)>>2]&1023](Mb,Nb,Ta,8)}else{Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>2,Ta)|0)+(Sb>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Sb&O)|0)<<2)>>2]&4095](Mb,Nb,Ta);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Va>>2,Ta)|0)+(Ob>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Va&O)<<B)+(Ob&O)|0)<<2)>>2]&4095](Mb,Nb,Ta)}Xa=Xa+1|0;}while((Xa|0)<4)}else{Xa=0;do{Nb=(c[f+12160+(Xa<<3)>>2]|0)+(Aa<<B)|0;Mb=(c[f+12160+(Xa<<3)+4>>2]|0)+Sa|0;Ob=Nb-(c[f+12128+(Xa<<3)>>2]|0)|0;Va=Mb-(c[f+12128+(Xa<<3)+4>>2]|0)|0;Sb=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ba(Xa>>1,Ta<<3)|0))|0;if(S){Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>1,Ta)|0)+(Nb>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(Nb&O)|0)<<2)>>2]&1023](Sb,Pb,Ta,8);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Va>>1,Ta)|0)+(Ob>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Va&O)<<B)+(Ob&O)|0)<<2)>>2]&1023](Sb,Pb,Ta,8)}else{Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>2,Ta)|0)+(Nb>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](Sb,Pb,Ta);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Va>>2,Ta)|0)+(Ob>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Va&O)<<B)+(Ob&O)|0)<<2)>>2]&4095](Sb,Pb,Ta)}Xa=Xa+1|0;}while((Xa|0)<4)}}else{Xa=(c[(f+12160|0)>>2]|0)+(Aa<<B)|0;Pb=(c[(f+12164|0)>>2]|0)+Sa|0;Sb=c[(f+12128|0)>>2]|0;if((Aa<<B|0)==0){Tb=(ba(Sb,Lb-Wa|0)|0)/(Wa|0)|0}else{Tb=Xa-Sb|0}Sb=c[(f+12132|0)>>2]|0;if((Sa|0)==0){Ub=(ba(Sb,Lb-Wa|0)|0)/(Wa|0)|0}else{Ub=Pb-Sb|0}Sb=((Ub&O)<<B)+(Tb&O)|0;if(S){Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>1,Ta)|0)+(Xa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ob,Ta,16);Ob=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ub>>1,Ta)|0)+(Tb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(Sb<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ob,Ta,16);break}else{Ob=(ba(Pb>>2,Ta)|0)+(Xa>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ob|0,Ta);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ob+8|0)|0,Ta);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ta<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ob+(Ta<<3))|0,Ta);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ta<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ob+8|0)+(Ta<<3))|0,Ta);Ob=(ba(Ub>>2,Ta)|0)+(Tb>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ob|0,Ta);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ob+8|0)|0,Ta);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ta<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ob+(Ta<<3))|0,Ta);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ta<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ob+8|0)+(Ta<<3))|0,Ta);break}}}while(0);Kb=Pe[ha&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Ta,16)|0}}while(0);c[(Y+(ab<<2)|0)>>2]=Ya;c[pa+(ab<<2)>>2]=Kb;Ta=(ba((d[Z+((Za<<B)-X)|0]|0)+(d[Z+((Aa<<B)-Q)|0]|0)|0,C)|0)+Kb|0;if((Ta|0)>=(fa|0)){Hb=fa;Ib=-1;Jb=Ga;break}c[V>>2]=Aa;c[(V+4|0)>>2]=Za;Hb=Ta;Ib=0;Jb=Aa}else{Hb=fa;Ib=-1;Jb=Ga}}while(0);do{if((Ra|0)!=3&(Za|0)>(sa|0)){Ta=Za-1|0;Wa=(Ta<<3)+Ga&63;if((c[(Y+(Wa<<2)|0)>>2]|0)==(ja+(Ta<<11)|0|0)){Vb=Hb;Wb=Ib;Xb=Jb;Yb=Za;break}Lb=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Sa=c[(f+12420|0)>>2]|0;Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Lb,Ta)|0)+Ga)|0;Sb=Pe[ha&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ob,Lb,o)|0;if((p&2|0)==0){Zb=Sb;break}Ob=c[(f+12208|0)>>2]|0;Xa=(ba(Sa,Ta>>1)|0)+W|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ta<<1&2|Ea)<<2)>>2]&1023](Ob+(Lb<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Xa|0,Sa,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ta<<1&2|Ea)<<2)>>2]&1023](Ob+(Lb<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Xa|0,Sa,o>>1);Xa=(Pe[oa&255](f,Ob+(Lb<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Sa,o>>1)|0)+Sb|0;Zb=Xa+(Pe[oa&255](f,Ob+(Lb<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Sa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(Ga|0)){Zb=536870912;break}if((La|0)>(c[(f+12268|0)>>2]<<B|0)){Zb=536870912;break}if((c[(f+12272|0)>>2]|0)>(Ta|0)){Zb=536870912;break}if((Ta<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Zb=536870912;break}Sa=e[(f+13872|0)>>1]|0;Ob=e[(f+13874|0)>>1]|0;m:do{if((c[(f+11740|0)>>2]|0)==1){if((La|0)==0){Xa=0;while(1){Sb=c[f+12160+(Xa<<3)>>2]|0;Pb=(c[f+12160+(Xa<<3)+4>>2]|0)+(Ta<<B)|0;Va=((ba(c[f+12128+(Xa<<3)>>2]|0,Ob-Sa|0)|0)/(Sa|0)|0)+((Xa&1)<<ma)|0;Nb=c[f+12128+(Xa<<3)+4>>2]|0;if((Ta<<B|0)==0){Mb=Xa>>1;_b=((ba(Nb,Ob-Sa|0)|0)/(Sa|0)|0)+(Mb<<ma)|0;$b=Mb}else{_b=Pb-Nb|0;$b=Xa>>1}Nb=((_b&O)<<B)+(Va&O)|0;Mb=(c[(f+12208|0)>>2]|0)+((ba($b,Lb<<3)|0)+(Xa<<3&8))|0;if(S){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>1,Lb)|0)+(Sb>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Pb&O)<<B)+(Sb&O)|0)<<2)>>2]&1023](Mb,ac,Lb,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(_b>>1,Lb)|0)+(Va>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Nb<<2)>>2]&1023](Mb,ac,Lb,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>2,Lb)|0)+(Sb>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Sb&O)|0)<<2)>>2]&4095](Mb,ac,Lb);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(_b>>2,Lb)|0)+(Va>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Nb<<2)>>2]&4095](Mb,ac,Lb)}Xa=Xa+1|0;if((Xa|0)>=4){break m}}}if((Ta<<B|0)==0){Xa=0;do{ac=(c[f+12160+(Xa<<3)>>2]|0)+La|0;Mb=c[f+12160+(Xa<<3)+4>>2]|0;Nb=ac-(c[f+12128+(Xa<<3)>>2]|0)|0;Va=Xa>>1;Sb=((ba(c[f+12128+(Xa<<3)+4>>2]|0,Ob-Sa|0)|0)/(Sa|0)|0)+(Va<<ma)|0;Pb=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ba(Va,Lb<<3)|0))|0;if(S){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>1,Lb)|0)+(ac>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(ac&O)|0)<<2)>>2]&1023](Pb,Va,Lb,8);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sb>>1,Lb)|0)+(Nb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Sb&O)<<B)+(Nb&O)|0)<<2)>>2]&1023](Pb,Va,Lb,8)}else{Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>2,Lb)|0)+(ac>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(ac&O)|0)<<2)>>2]&4095](Pb,Va,Lb);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sb>>2,Lb)|0)+(Nb>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Sb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](Pb,Va,Lb)}Xa=Xa+1|0;}while((Xa|0)<4)}else{Xa=0;do{Va=(c[f+12160+(Xa<<3)>>2]|0)+La|0;Pb=(c[f+12160+(Xa<<3)+4>>2]|0)+(Ta<<B)|0;Nb=Va-(c[f+12128+(Xa<<3)>>2]|0)|0;Sb=Pb-(c[f+12128+(Xa<<3)+4>>2]|0)|0;ac=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ba(Xa>>1,Lb<<3)|0))|0;if(S){Mb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>1,Lb)|0)+(Va>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Pb&O)<<B)+(Va&O)|0)<<2)>>2]&1023](ac,Mb,Lb,8);Mb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sb>>1,Lb)|0)+(Nb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Sb&O)<<B)+(Nb&O)|0)<<2)>>2]&1023](ac,Mb,Lb,8)}else{Mb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>2,Lb)|0)+(Va>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Va&O)|0)<<2)>>2]&4095](ac,Mb,Lb);Mb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sb>>2,Lb)|0)+(Nb>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Sb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](ac,Mb,Lb)}Xa=Xa+1|0;}while((Xa|0)<4)}}else{Xa=(c[(f+12160|0)>>2]|0)+La|0;Mb=(c[(f+12164|0)>>2]|0)+(Ta<<B)|0;ac=c[(f+12128|0)>>2]|0;if((La|0)==0){bc=(ba(ac,Ob-Sa|0)|0)/(Sa|0)|0}else{bc=Xa-ac|0}ac=c[(f+12132|0)>>2]|0;if((Ta<<B|0)==0){cc=(ba(ac,Ob-Sa|0)|0)/(Sa|0)|0}else{cc=Mb-ac|0}ac=((cc&O)<<B)+(bc&O)|0;if(S){Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>1,Lb)|0)+(Xa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Nb,Lb,16);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(cc>>1,Lb)|0)+(bc>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(ac<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Nb,Lb,16);break}else{Nb=(ba(Mb>>2,Lb)|0)+(Xa>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Nb|0,Lb);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Nb+8|0)|0,Lb);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Lb<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Nb+(Lb<<3))|0,Lb);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Lb<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Nb+8|0)+(Lb<<3))|0,Lb);Nb=(ba(cc>>2,Lb)|0)+(bc>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Nb|0,Lb);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Nb+8|0)|0,Lb);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Lb<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Nb+(Lb<<3))|0,Lb);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Lb<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Nb+8|0)+(Lb<<3))|0,Lb);break}}}while(0);Zb=Pe[ha&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Lb,16)|0}}while(0);c[(Y+(Wa<<2)|0)>>2]=ja+(Ta<<11)|0;c[pa+(Wa<<2)>>2]=Zb;Lb=(ba((d[Z+((Ta<<B)-X)|0]|0)+(d[Z+(La-Q)|0]|0)|0,C)|0)+Zb|0;if((Lb|0)>=(Hb|0)){Vb=Hb;Wb=Ib;Xb=Jb;Yb=Za;break}c[V>>2]=Ga;c[(V+4|0)>>2]=Ta;Vb=Lb;Wb=1;Xb=Ga;Yb=Ta}else{Vb=Hb;Wb=Ib;Xb=Jb;Yb=Za}}while(0);do{if((Ra|0)!=0&Ma){Lb=(Za<<11)+aa+Qa|0;ab=Qa+(Za<<3)&63;if((c[(Y+(ab<<2)|0)>>2]|0)==(Lb|0)){dc=Vb;ec=Wb;fc=Xb;gc=Yb;break}Ya=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Sa=c[(f+12420|0)>>2]|0;Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ya,Za)|0)+Qa)|0;Nb=Pe[ha&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ob,Ya,o)|0;if((p&2|0)==0){hc=Nb;break}Ob=Qa&1|Za<<1&2;ac=c[(f+12208|0)>>2]|0;Xa=(ba(Sa,Za>>1)|0)+(Qa>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Ob<<2)>>2]&1023](ac+(Ya<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Xa|0,Sa,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Ob<<2)>>2]&1023](ac+(Ya<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Xa|0,Sa,o>>1);Xa=(Pe[oa&255](f,ac+(Ya<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Sa,o>>1)|0)+Nb|0;hc=Xa+(Pe[oa&255](f,ac+(Ya<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Sa,o>>1)|0)|0}else{Sa=Za<<B;if((c[(f+12264|0)>>2]|0)>(Qa|0)){hc=536870912;break}if((Qa<<B|0)>(c[(f+12268|0)>>2]<<B|0)){hc=536870912;break}if((c[(f+12272|0)>>2]|0)>(Za|0)){hc=536870912;break}if((Sa|0)>(c[(f+12276|0)>>2]<<B|0)){hc=536870912;break}ac=e[(f+13872|0)>>1]|0;Xa=e[(f+13874|0)>>1]|0;n:do{if((c[(f+11740|0)>>2]|0)==1){if((Qa<<B|0)==0){Nb=0;while(1){Ob=c[f+12160+(Nb<<3)>>2]|0;Mb=(c[f+12160+(Nb<<3)+4>>2]|0)+Sa|0;Sb=((ba(c[f+12128+(Nb<<3)>>2]|0,Xa-ac|0)|0)/(ac|0)|0)+((Nb&1)<<ma)|0;Va=c[f+12128+(Nb<<3)+4>>2]|0;if((Sa|0)==0){Pb=Nb>>1;ic=((ba(Va,Xa-ac|0)|0)/(ac|0)|0)+(Pb<<ma)|0;jc=Pb}else{ic=Mb-Va|0;jc=Nb>>1}Va=((ic&O)<<B)+(Sb&O)|0;Pb=(c[(f+12208|0)>>2]|0)+((ba(jc,Ya<<3)|0)+(Nb<<3&8))|0;if(S){kc=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>1,Ya)|0)+(Ob>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(Ob&O)|0)<<2)>>2]&1023](Pb,kc,Ya,8);kc=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ic>>1,Ya)|0)+(Sb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Va<<2)>>2]&1023](Pb,kc,Ya,8)}else{kc=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>2,Ya)|0)+(Ob>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Ob&O)|0)<<2)>>2]&4095](Pb,kc,Ya);kc=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ic>>2,Ya)|0)+(Sb>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](Pb,kc,Ya)}Nb=Nb+1|0;if((Nb|0)>=4){break n}}}if((Sa|0)==0){Nb=0;do{kc=(c[f+12160+(Nb<<3)>>2]|0)+(Qa<<B)|0;Pb=c[f+12160+(Nb<<3)+4>>2]|0;Va=kc-(c[f+12128+(Nb<<3)>>2]|0)|0;Sb=Nb>>1;Ob=((ba(c[f+12128+(Nb<<3)+4>>2]|0,Xa-ac|0)|0)/(ac|0)|0)+(Sb<<ma)|0;Mb=(c[(f+12208|0)>>2]|0)+((Nb<<3&8)+(ba(Sb,Ya<<3)|0))|0;if(S){Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>1,Ya)|0)+(kc>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Pb&O)<<B)+(kc&O)|0)<<2)>>2]&1023](Mb,Sb,Ya,8);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ob>>1,Ya)|0)+(Va>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&1023](Mb,Sb,Ya,8)}else{Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>2,Ya)|0)+(kc>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(kc&O)|0)<<2)>>2]&4095](Mb,Sb,Ya);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ob>>2,Ya)|0)+(Va>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095](Mb,Sb,Ya)}Nb=Nb+1|0;}while((Nb|0)<4)}else{Nb=0;do{Sb=(c[f+12160+(Nb<<3)>>2]|0)+(Qa<<B)|0;Mb=(c[f+12160+(Nb<<3)+4>>2]|0)+Sa|0;Va=Sb-(c[f+12128+(Nb<<3)>>2]|0)|0;Ob=Mb-(c[f+12128+(Nb<<3)+4>>2]|0)|0;kc=(c[(f+12208|0)>>2]|0)+((Nb<<3&8)+(ba(Nb>>1,Ya<<3)|0))|0;if(S){Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>1,Ya)|0)+(Sb>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(Sb&O)|0)<<2)>>2]&1023](kc,Pb,Ya,8);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ob>>1,Ya)|0)+(Va>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&1023](kc,Pb,Ya,8)}else{Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Mb>>2,Ya)|0)+(Sb>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Sb&O)|0)<<2)>>2]&4095](kc,Pb,Ya);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ob>>2,Ya)|0)+(Va>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095](kc,Pb,Ya)}Nb=Nb+1|0;}while((Nb|0)<4)}}else{Nb=(c[(f+12160|0)>>2]|0)+(Qa<<B)|0;Pb=(c[(f+12164|0)>>2]|0)+Sa|0;kc=c[(f+12128|0)>>2]|0;if((Qa<<B|0)==0){lc=(ba(kc,Xa-ac|0)|0)/(ac|0)|0}else{lc=Nb-kc|0}kc=c[(f+12132|0)>>2]|0;if((Sa|0)==0){mc=(ba(kc,Xa-ac|0)|0)/(ac|0)|0}else{mc=Pb-kc|0}kc=((mc&O)<<B)+(lc&O)|0;if(S){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Pb>>1,Ya)|0)+(Nb>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Va,Ya,16);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(mc>>1,Ya)|0)+(lc>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(kc<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Va,Ya,16);break}else{Va=(ba(Pb>>2,Ya)|0)+(Nb>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Va|0,Ya);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Va+8|0)|0,Ya);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ya<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Va+(Ya<<3))|0,Ya);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ya<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Va+8|0)+(Ya<<3))|0,Ya);Va=(ba(mc>>2,Ya)|0)+(lc>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Va|0,Ya);Xe[c[(c[(f+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Va+8|0)|0,Ya);Xe[c[(c[(f+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ya<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Va+(Ya<<3))|0,Ya);Xe[c[(c[(f+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ya<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Va+8|0)+(Ya<<3))|0,Ya);break}}}while(0);hc=Pe[ha&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Ya,16)|0}}while(0);c[(Y+(ab<<2)|0)>>2]=Lb;c[pa+(ab<<2)>>2]=hc;Ya=(ba((d[Z+((Za<<B)-X)|0]|0)+(d[Z+((Qa<<B)-Q)|0]|0)|0,C)|0)+hc|0;if((Ya|0)>=(Vb|0)){dc=Vb;ec=Wb;fc=Xb;gc=Yb;break}c[V>>2]=Qa;c[(V+4|0)>>2]=Za;dc=Ya;ec=2;fc=Qa;gc=Za}else{dc=Vb;ec=Wb;fc=Xb;gc=Yb}}while(0);if(!((Ra|0)!=1&(Za|0)<($|0))){break}Ya=Za+1|0;Ta=(Ya<<3)+Ga&63;if((c[(Y+(Ta<<2)|0)>>2]|0)==(ja+(Ya<<11)|0|0)){break}Wa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ac=c[(f+12420|0)>>2]|0;Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Wa,Ya)|0)+Ga)|0;Sa=Pe[ha&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Xa,Wa,o)|0;if((p&2|0)==0){nc=Sa;break}Xa=c[(f+12208|0)>>2]|0;Va=(ba(ac,Ya>>1)|0)+W|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ya<<1&2|Ea)<<2)>>2]&1023](Xa+(Wa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Va|0,ac,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ya<<1&2|Ea)<<2)>>2]&1023](Xa+(Wa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Va|0,ac,o>>1);Va=(Pe[oa&255](f,Xa+(Wa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ac,o>>1)|0)+Sa|0;nc=Va+(Pe[oa&255](f,Xa+(Wa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ac,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(Ga|0)){nc=536870912;break}if((La|0)>(c[(f+12268|0)>>2]<<B|0)){nc=536870912;break}if((c[(f+12272|0)>>2]|0)>(Ya|0)){nc=536870912;break}if((Ya<<B|0)>(c[(f+12276|0)>>2]<<B|0)){nc=536870912;break}ac=e[(f+13872|0)>>1]|0;Xa=e[(f+13874|0)>>1]|0;o:do{if((c[(f+11740|0)>>2]|0)==1){if((La|0)==0){Va=0;while(1){Sa=c[f+12160+(Va<<3)>>2]|0;kc=(c[f+12160+(Va<<3)+4>>2]|0)+(Ya<<B)|0;Nb=((ba(c[f+12128+(Va<<3)>>2]|0,Xa-ac|0)|0)/(ac|0)|0)+((Va&1)<<ma)|0;Pb=c[f+12128+(Va<<3)+4>>2]|0;if((Ya<<B|0)==0){Ob=Va>>1;oc=((ba(Pb,Xa-ac|0)|0)/(ac|0)|0)+(Ob<<ma)|0;pc=Ob}else{oc=kc-Pb|0;pc=Va>>1}Pb=((oc&O)<<B)+(Nb&O)|0;Ob=(c[(f+12208|0)>>2]|0)+((ba(pc,Wa<<3)|0)+(Va<<3&8))|0;if(S){Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(kc>>1,Wa)|0)+(Sa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((kc&O)<<B)+(Sa&O)|0)<<2)>>2]&1023](Ob,Sb,Wa,8);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(oc>>1,Wa)|0)+(Nb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Pb<<2)>>2]&1023](Ob,Sb,Wa,8)}else{Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(kc>>2,Wa)|0)+(Sa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((kc&O)<<B)+(Sa&O)|0)<<2)>>2]&4095](Ob,Sb,Wa);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(oc>>2,Wa)|0)+(Nb>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Pb<<2)>>2]&4095](Ob,Sb,Wa)}Va=Va+1|0;if((Va|0)>=4){break o}}}if((Ya<<B|0)==0){Va=0;do{Sb=(c[f+12160+(Va<<3)>>2]|0)+La|0;Ob=c[f+12160+(Va<<3)+4>>2]|0;Pb=Sb-(c[f+12128+(Va<<3)>>2]|0)|0;Nb=Va>>1;Sa=((ba(c[f+12128+(Va<<3)+4>>2]|0,Xa-ac|0)|0)/(ac|0)|0)+(Nb<<ma)|0;kc=(c[(f+12208|0)>>2]|0)+((Va<<3&8)+(ba(Nb,Wa<<3)|0))|0;if(S){Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ob>>1,Wa)|0)+(Sb>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ob&O)<<B)+(Sb&O)|0)<<2)>>2]&1023](kc,Nb,Wa,8);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>1,Wa)|0)+(Pb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&O)<<B)+(Pb&O)|0)<<2)>>2]&1023](kc,Nb,Wa,8)}else{Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ob>>2,Wa)|0)+(Sb>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Sb&O)|0)<<2)>>2]&4095](kc,Nb,Wa);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>2,Wa)|0)+(Pb>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&O)<<B)+(Pb&O)|0)<<2)>>2]&4095](kc,Nb,Wa)}Va=Va+1|0;}while((Va|0)<4)}else{Va=0;do{Nb=(c[f+12160+(Va<<3)>>2]|0)+La|0;kc=(c[f+12160+(Va<<3)+4>>2]|0)+(Ya<<B)|0;Pb=Nb-(c[f+12128+(Va<<3)>>2]|0)|0;Sa=kc-(c[f+12128+(Va<<3)+4>>2]|0)|0;Sb=(c[(f+12208|0)>>2]|0)+((Va<<3&8)+(ba(Va>>1,Wa<<3)|0))|0;if(S){Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(kc>>1,Wa)|0)+(Nb>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((kc&O)<<B)+(Nb&O)|0)<<2)>>2]&1023](Sb,Ob,Wa,8);Ob=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>1,Wa)|0)+(Pb>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&O)<<B)+(Pb&O)|0)<<2)>>2]&1023](Sb,Ob,Wa,8)}else{Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(kc>>2,Wa)|0)+(Nb>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((kc&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](Sb,Ob,Wa);Ob=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sa>>2,Wa)|0)+(Pb>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&O)<<B)+(Pb&O)|0)<<2)>>2]&4095](Sb,Ob,Wa)}Va=Va+1|0;}while((Va|0)<4)}}else{Va=(c[(f+12160|0)>>2]|0)+La|0;Ob=(c[(f+12164|0)>>2]|0)+(Ya<<B)|0;Sb=c[(f+12128|0)>>2]|0;if((La|0)==0){qc=(ba(Sb,Xa-ac|0)|0)/(ac|0)|0}else{qc=Va-Sb|0}Sb=c[(f+12132|0)>>2]|0;if((Ya<<B|0)==0){rc=(ba(Sb,Xa-ac|0)|0)/(ac|0)|0}else{rc=Ob-Sb|0}Sb=((rc&O)<<B)+(qc&O)|0;if(S){Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ob>>1,Wa)|0)+(Va>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Pb,Wa,16);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(rc>>1,Wa)|0)+(qc>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(Sb<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Pb,Wa,16);break}else{Pb=(ba(Ob>>2,Wa)|0)+(Va>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Pb|0,Wa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Pb+8|0)|0,Wa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Wa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Pb+(Wa<<3))|0,Wa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Wa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Pb+8|0)+(Wa<<3))|0,Wa);Pb=(ba(rc>>2,Wa)|0)+(qc>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Pb|0,Wa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Pb+8|0)|0,Wa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Wa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Pb+(Wa<<3))|0,Wa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Wa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Pb+8|0)+(Wa<<3))|0,Wa);break}}}while(0);nc=Pe[ha&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Wa,16)|0}}while(0);c[(Y+(Ta<<2)|0)>>2]=ja+(Ya<<11)|0;c[pa+(Ta<<2)>>2]=nc;Wa=(ba((d[Z+((Ya<<B)-X)|0]|0)+(d[Z+(La-Q)|0]|0)|0,C)|0)+nc|0;if((Wa|0)>=(dc|0)){break}c[V>>2]=Ga;c[(V+4|0)>>2]=Ya;fa=Wa;Ra=3;Za=Ya}if((ec|0)==-1){Bb=dc;break e}else{za=dc;T=ec;Ga=fc;Fa=gc}}}if((U|0)>1024){Bb=Gmb(f,V,L,j,k,C,n,o,p)|0;break}if((U|0)>768){Fa=c[(f+12220|0)>>2]|0;Ga=c[(f+12264|0)>>2]|0;T=c[(f+12272|0)>>2]|0;za=c[(f+12268|0)>>2]|0;Q=c[(f+12276|0)>>2]|0;Z=c[(f+12464|0)>>2]|0;X=c[(f+12280|0)>>2]|0;pa=c[(f+12284|0)>>2]|0;Y=c[(f+12216|0)>>2]|0;ha=c[(f+12224|0)>>2]|0;O=c[f+10468+(n<<2)>>2]|0;S=c[f+10468+((n+1|0)<<2)>>2]|0;ma=M-(U&254)+1|0;oa=(ma|0)>(Ga|0)?ma:Ga;ma=M-1+(U&254)|0;$=(ma|0)>(za|0)?za:ma;if((oa|0)>($|0)){sc=L;tc=M;uc=N}else{ma=ha+(N<<11)|0;aa=N<<3;sa=N<<1&2;_=N>>1;la=N<<B;ia=(p&1)<<1|1;ga=oa;oa=L;Za=M;Ra=N;while(1){fa=ma+ga|0;La=ga+aa&63;do{if((c[(Y+(La<<2)|0)>>2]|0)==(fa|0)){vc=oa;wc=Za;xc=Ra}else{ja=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Ea=c[(f+12420|0)>>2]|0;W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja,N)|0)+ga)|0;Qa=Pe[O&255](f,c[(f+12288+(j<<4)|0)>>2]|0,W,ja,o)|0;if((p&2|0)==0){yc=Qa;break}W=ga&1|sa;Ma=c[(f+12208|0)>>2]|0;Aa=(ba(Ea,_)|0)+(ga>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(W<<2)>>2]&1023](Ma+(ja<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Aa|0,Ea,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(W<<2)>>2]&1023](Ma+(ja<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Aa|0,Ea,o>>1);Aa=(Pe[S&255](f,Ma+(ja<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Ea,o>>1)|0)+Qa|0;yc=Aa+(Pe[S&255](f,Ma+(ja<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Ea,o>>1)|0)|0}else{Ea=ga<<B;if((c[(f+12264|0)>>2]|0)>(ga|0)){yc=536870912;break}if((Ea|0)>(c[(f+12268|0)>>2]<<B|0)){yc=536870912;break}if((c[(f+12272|0)>>2]|0)>(N|0)){yc=536870912;break}if((la|0)>(c[(f+12276|0)>>2]<<B|0)){yc=536870912;break}Ma=e[(f+13872|0)>>1]|0;Aa=e[(f+13874|0)>>1]|0;p:do{if((c[(f+11740|0)>>2]|0)==1){if((Ea|0)==0){Qa=0;while(1){W=c[f+12160+(Qa<<3)>>2]|0;na=(c[f+12160+(Qa<<3)+4>>2]|0)+la|0;P=((ba(c[f+12128+(Qa<<3)>>2]|0,Aa-Ma|0)|0)/(Ma|0)|0)+((Qa&1)<<(p&1|4))|0;Wa=c[f+12128+(Qa<<3)+4>>2]|0;if((la|0)==0){ac=Qa>>1;zc=((ba(Wa,Aa-Ma|0)|0)/(Ma|0)|0)+(ac<<(p&1|4))|0;Ac=ac}else{zc=na-Wa|0;Ac=Qa>>1}Wa=((zc&ia)<<B)+(P&ia)|0;ac=(c[(f+12208|0)>>2]|0)+((ba(Ac,ja<<3)|0)+(Qa<<3&8))|0;if((p&1|0)==0){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>1,ja)|0)+(W>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((na&ia)<<B)+(W&ia)|0)<<2)>>2]&1023](ac,Xa,ja,8);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(zc>>1,ja)|0)+(P>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Wa<<2)>>2]&1023](ac,Xa,ja,8)}else{Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>2,ja)|0)+(W>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((na&ia)<<B)+(W&ia)|0)<<2)>>2]&4095](ac,Xa,ja);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(zc>>2,ja)|0)+(P>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Wa<<2)>>2]&4095](ac,Xa,ja)}Qa=Qa+1|0;if((Qa|0)>=4){break p}}}if((la|0)==0){Qa=0;do{Xa=(c[f+12160+(Qa<<3)>>2]|0)+Ea|0;ac=c[f+12160+(Qa<<3)+4>>2]|0;Wa=Xa-(c[f+12128+(Qa<<3)>>2]|0)|0;P=Qa>>1;W=((ba(c[f+12128+(Qa<<3)+4>>2]|0,Aa-Ma|0)|0)/(Ma|0)|0)+(P<<(p&1|4))|0;na=(c[(f+12208|0)>>2]|0)+((Qa<<3&8)+(ba(P,ja<<3)|0))|0;if((p&1|0)==0){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ac>>1,ja)|0)+(Xa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ac&ia)<<B)+(Xa&ia)|0)<<2)>>2]&1023](na,P,ja,8);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(W>>1,ja)|0)+(Wa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((W&ia)<<B)+(Wa&ia)|0)<<2)>>2]&1023](na,P,ja,8)}else{P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ac>>2,ja)|0)+(Xa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Xa&ia)|0)<<2)>>2]&4095](na,P,ja);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(W>>2,ja)|0)+(Wa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((W&ia)<<B)+(Wa&ia)|0)<<2)>>2]&4095](na,P,ja)}Qa=Qa+1|0;}while((Qa|0)<4)}else{Qa=0;do{P=(c[f+12160+(Qa<<3)>>2]|0)+Ea|0;na=(c[f+12160+(Qa<<3)+4>>2]|0)+la|0;Wa=P-(c[f+12128+(Qa<<3)>>2]|0)|0;W=na-(c[f+12128+(Qa<<3)+4>>2]|0)|0;Xa=(c[(f+12208|0)>>2]|0)+((Qa<<3&8)+(ba(Qa>>1,ja<<3)|0))|0;if((p&1|0)==0){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>1,ja)|0)+(P>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((na&ia)<<B)+(P&ia)|0)<<2)>>2]&1023](Xa,ac,ja,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(W>>1,ja)|0)+(Wa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((W&ia)<<B)+(Wa&ia)|0)<<2)>>2]&1023](Xa,ac,ja,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>2,ja)|0)+(P>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((na&ia)<<B)+(P&ia)|0)<<2)>>2]&4095](Xa,ac,ja);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(W>>2,ja)|0)+(Wa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((W&ia)<<B)+(Wa&ia)|0)<<2)>>2]&4095](Xa,ac,ja)}Qa=Qa+1|0;}while((Qa|0)<4)}}else{Qa=(c[(f+12160|0)>>2]|0)+Ea|0;ac=(c[(f+12164|0)>>2]|0)+la|0;Xa=c[(f+12128|0)>>2]|0;if((Ea|0)==0){Bc=(ba(Xa,Aa-Ma|0)|0)/(Ma|0)|0}else{Bc=Qa-Xa|0}Xa=c[(f+12132|0)>>2]|0;if((la|0)==0){Cc=(ba(Xa,Aa-Ma|0)|0)/(Ma|0)|0}else{Cc=ac-Xa|0}Xa=((Cc&ia)<<B)+(Bc&ia)|0;if((p&1|0)==0){Wa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ac>>1,ja)|0)+(Qa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Wa,ja,16);Wa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Cc>>1,ja)|0)+(Bc>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(Xa<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Wa,ja,16);break}else{Wa=(ba(ac>>2,ja)|0)+(Qa>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Wa|0,ja);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Wa+8|0)|0,ja);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ja<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Wa+(ja<<3))|0,ja);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Wa+8|0)+(ja<<3))|0,ja);Wa=(ba(Cc>>2,ja)|0)+(Bc>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Wa|0,ja);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Wa+8|0)|0,ja);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ja<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Wa+(ja<<3))|0,ja);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Wa+8|0)+(ja<<3))|0,ja);break}}}while(0);yc=Pe[O&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ja,16)|0}}while(0);c[(Y+(La<<2)|0)>>2]=fa;c[Fa+(La<<2)>>2]=yc;ja=(ba((d[Z+(la-pa)|0]|0)+(d[Z+((ga<<B)-X)|0]|0)|0,C)|0)+yc|0;if((ja|0)>=(oa|0)){vc=oa;wc=Za;xc=Ra;break}c[V>>2]=ga;c[(V+4|0)>>2]=N;vc=ja;wc=ga;xc=N}}while(0);La=ga+2|0;if((La|0)>($|0)){sc=vc;tc=wc;uc=xc;break}else{ga=La;oa=vc;Za=wc;Ra=xc}}}Ra=N-((U&254)>>>1)+1|0;Za=(Ra|0)>(T|0)?Ra:T;Ra=N-1+((U&254)>>>1)|0;oa=(Ra|0)>(Q|0)?Q:Ra;if((Za|0)>(oa|0)){Dc=sc;Ec=tc;Fc=uc}else{Ra=ha+M|0;ga=M&1;$=M>>1;la=M<<B;ia=(p&1)<<1|1;_=Za;Za=sc;sa=tc;aa=uc;while(1){ma=Ra+(_<<11)|0;La=(_<<3)+M&63;do{if((c[(Y+(La<<2)|0)>>2]|0)==(ma|0)){Gc=Za;Hc=sa;Ic=aa}else{fa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ja=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(fa,_)|0)+M)|0;Ta=Pe[O&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,fa,o)|0;if((p&2|0)==0){Jc=Ta;break}Ya=_<<1&2|ga;Ma=c[(f+12208|0)>>2]|0;Aa=(ba(ja,_>>1)|0)+$|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Ya<<2)>>2]&1023](Ma+(fa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Aa|0,ja,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Ya<<2)>>2]&1023](Ma+(fa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Aa|0,ja,o>>1);Aa=(Pe[S&255](f,Ma+(fa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ja,o>>1)|0)+Ta|0;Jc=Aa+(Pe[S&255](f,Ma+(fa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ja,o>>1)|0)|0}else{ja=_<<B;if((c[(f+12264|0)>>2]|0)>(M|0)){Jc=536870912;break}if((la|0)>(c[(f+12268|0)>>2]<<B|0)){Jc=536870912;break}if((c[(f+12272|0)>>2]|0)>(_|0)){Jc=536870912;break}if((ja|0)>(c[(f+12276|0)>>2]<<B|0)){Jc=536870912;break}Ma=e[(f+13872|0)>>1]|0;Aa=e[(f+13874|0)>>1]|0;q:do{if((c[(f+11740|0)>>2]|0)==1){if((la|0)==0){Ta=0;while(1){Ya=c[f+12160+(Ta<<3)>>2]|0;Ea=(c[f+12160+(Ta<<3)+4>>2]|0)+ja|0;Wa=((ba(c[f+12128+(Ta<<3)>>2]|0,Aa-Ma|0)|0)/(Ma|0)|0)+((Ta&1)<<(p&1|4))|0;Xa=c[f+12128+(Ta<<3)+4>>2]|0;if((ja|0)==0){Qa=Ta>>1;Kc=((ba(Xa,Aa-Ma|0)|0)/(Ma|0)|0)+(Qa<<(p&1|4))|0;Lc=Qa}else{Kc=Ea-Xa|0;Lc=Ta>>1}Xa=((Kc&ia)<<B)+(Wa&ia)|0;Qa=(c[(f+12208|0)>>2]|0)+((ba(Lc,fa<<3)|0)+(Ta<<3&8))|0;if((p&1|0)==0){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>1,fa)|0)+(Ya>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&ia)<<B)+(Ya&ia)|0)<<2)>>2]&1023](Qa,ac,fa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Kc>>1,fa)|0)+(Wa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Xa<<2)>>2]&1023](Qa,ac,fa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>2,fa)|0)+(Ya>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&ia)<<B)+(Ya&ia)|0)<<2)>>2]&4095](Qa,ac,fa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Kc>>2,fa)|0)+(Wa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](Qa,ac,fa)}Ta=Ta+1|0;if((Ta|0)>=4){break q}}}if((ja|0)==0){Ta=0;do{ac=(c[f+12160+(Ta<<3)>>2]|0)+la|0;Qa=c[f+12160+(Ta<<3)+4>>2]|0;Xa=ac-(c[f+12128+(Ta<<3)>>2]|0)|0;Wa=Ta>>1;Ya=((ba(c[f+12128+(Ta<<3)+4>>2]|0,Aa-Ma|0)|0)/(Ma|0)|0)+(Wa<<(p&1|4))|0;Ea=(c[(f+12208|0)>>2]|0)+((Ta<<3&8)+(ba(Wa,fa<<3)|0))|0;if((p&1|0)==0){Wa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa>>1,fa)|0)+(ac>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Qa&ia)<<B)+(ac&ia)|0)<<2)>>2]&1023](Ea,Wa,fa,8);Wa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ya>>1,fa)|0)+(Xa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ya&ia)<<B)+(Xa&ia)|0)<<2)>>2]&1023](Ea,Wa,fa,8)}else{Wa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa>>2,fa)|0)+(ac>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(ac&ia)|0)<<2)>>2]&4095](Ea,Wa,fa);Wa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ya>>2,fa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ya&ia)<<B)+(Xa&ia)|0)<<2)>>2]&4095](Ea,Wa,fa)}Ta=Ta+1|0;}while((Ta|0)<4)}else{Ta=0;do{Wa=(c[f+12160+(Ta<<3)>>2]|0)+la|0;Ea=(c[f+12160+(Ta<<3)+4>>2]|0)+ja|0;Xa=Wa-(c[f+12128+(Ta<<3)>>2]|0)|0;Ya=Ea-(c[f+12128+(Ta<<3)+4>>2]|0)|0;ac=(c[(f+12208|0)>>2]|0)+((Ta<<3&8)+(ba(Ta>>1,fa<<3)|0))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>1,fa)|0)+(Wa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&ia)<<B)+(Wa&ia)|0)<<2)>>2]&1023](ac,Qa,fa,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ya>>1,fa)|0)+(Xa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ya&ia)<<B)+(Xa&ia)|0)<<2)>>2]&1023](ac,Qa,fa,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>2,fa)|0)+(Wa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&ia)<<B)+(Wa&ia)|0)<<2)>>2]&4095](ac,Qa,fa);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ya>>2,fa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ya&ia)<<B)+(Xa&ia)|0)<<2)>>2]&4095](ac,Qa,fa)}Ta=Ta+1|0;}while((Ta|0)<4)}}else{Ta=(c[(f+12160|0)>>2]|0)+la|0;Qa=(c[(f+12164|0)>>2]|0)+ja|0;ac=c[(f+12128|0)>>2]|0;if((la|0)==0){Mc=(ba(ac,Aa-Ma|0)|0)/(Ma|0)|0}else{Mc=Ta-ac|0}ac=c[(f+12132|0)>>2]|0;if((ja|0)==0){Nc=(ba(ac,Aa-Ma|0)|0)/(Ma|0)|0}else{Nc=Qa-ac|0}ac=((Nc&ia)<<B)+(Mc&ia)|0;if((p&1|0)==0){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa>>1,fa)|0)+(Ta>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Xa,fa,16);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Nc>>1,fa)|0)+(Mc>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(ac<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Xa,fa,16);break}else{Xa=(ba(Qa>>2,fa)|0)+(Ta>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Xa|0,fa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+8|0)|0,fa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(fa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+(fa<<3))|0,fa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((fa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Xa+8|0)+(fa<<3))|0,fa);Xa=(ba(Nc>>2,fa)|0)+(Mc>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Xa|0,fa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+8|0)|0,fa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(fa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+(fa<<3))|0,fa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((fa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Xa+8|0)+(fa<<3))|0,fa);break}}}while(0);Jc=Pe[O&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,fa,16)|0}}while(0);c[(Y+(La<<2)|0)>>2]=ma;c[Fa+(La<<2)>>2]=Jc;fa=(ba((d[Z+((_<<B)-pa)|0]|0)+(d[Z+(la-X)|0]|0)|0,C)|0)+Jc|0;if((fa|0)>=(Za|0)){Gc=Za;Hc=sa;Ic=aa;break}c[V>>2]=M;c[(V+4|0)>>2]=_;Gc=fa;Hc=M;Ic=_}}while(0);La=_+2|0;if((La|0)>(oa|0)){Dc=Gc;Ec=Hc;Fc=Ic;break}else{_=La;Za=Gc;sa=Hc;aa=Ic}}}aa=Fc-2|0;sa=(aa|0)>(T|0)?aa:T;aa=Fc+2|0;Za=(aa|0)>(Q|0)?Q:aa;if((sa|0)>(Za|0)){Oc=Dc}else{aa=Ec-2|0;_=(aa|0)>(Ga|0)?aa:Ga;aa=Ec+2|0;oa=(aa|0)>(za|0)?za:aa;aa=(p&1)<<1|1;la=sa;sa=Dc;while(1){if((_|0)>(oa|0)){Pc=sa}else{ia=(la<<11)+ha|0;$=la<<3;ga=la<<1&2;Ra=la>>1;La=la<<B;ma=_;fa=sa;while(1){Ma=ia+ma|0;Aa=ma+$&63;do{if((c[(Y+(Aa<<2)|0)>>2]|0)==(Ma|0)){Qc=fa}else{ja=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Xa=c[(f+12420|0)>>2]|0;ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja,la)|0)+ma)|0;Ta=Pe[O&255](f,c[(f+12288+(j<<4)|0)>>2]|0,ac,ja,o)|0;if((p&2|0)==0){Rc=Ta;break}ac=ma&1|ga;Qa=c[(f+12208|0)>>2]|0;Ya=(ba(Xa,Ra)|0)+(ma>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(ac<<2)>>2]&1023](Qa+(ja<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Ya|0,Xa,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(ac<<2)>>2]&1023](Qa+(ja<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Ya|0,Xa,o>>1);Ya=(Pe[S&255](f,Qa+(ja<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Xa,o>>1)|0)+Ta|0;Rc=Ya+(Pe[S&255](f,Qa+(ja<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Xa,o>>1)|0)|0}else{Xa=ma<<B;if((c[(f+12264|0)>>2]|0)>(ma|0)){Rc=536870912;break}if((Xa|0)>(c[(f+12268|0)>>2]<<B|0)){Rc=536870912;break}if((c[(f+12272|0)>>2]|0)>(la|0)){Rc=536870912;break}if((La|0)>(c[(f+12276|0)>>2]<<B|0)){Rc=536870912;break}Qa=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;r:do{if((c[(f+11740|0)>>2]|0)==1){if((Xa|0)==0){Ta=0;while(1){ac=c[f+12160+(Ta<<3)>>2]|0;Wa=(c[f+12160+(Ta<<3)+4>>2]|0)+La|0;Ea=((ba(c[f+12128+(Ta<<3)>>2]|0,Ya-Qa|0)|0)/(Qa|0)|0)+((Ta&1)<<(p&1|4))|0;W=c[f+12128+(Ta<<3)+4>>2]|0;if((La|0)==0){P=Ta>>1;Sc=((ba(W,Ya-Qa|0)|0)/(Qa|0)|0)+(P<<(p&1|4))|0;Tc=P}else{Sc=Wa-W|0;Tc=Ta>>1}W=((Sc&aa)<<B)+(Ea&aa)|0;P=(c[(f+12208|0)>>2]|0)+((ba(Tc,ja<<3)|0)+(Ta<<3&8))|0;if((p&1|0)==0){na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Wa>>1,ja)|0)+(ac>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Wa&aa)<<B)+(ac&aa)|0)<<2)>>2]&1023](P,na,ja,8);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sc>>1,ja)|0)+(Ea>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(W<<2)>>2]&1023](P,na,ja,8)}else{na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Wa>>2,ja)|0)+(ac>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Wa&aa)<<B)+(ac&aa)|0)<<2)>>2]&4095](P,na,ja);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Sc>>2,ja)|0)+(Ea>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](P,na,ja)}Ta=Ta+1|0;if((Ta|0)>=4){break r}}}if((La|0)==0){Ta=0;do{na=(c[f+12160+(Ta<<3)>>2]|0)+Xa|0;P=c[f+12160+(Ta<<3)+4>>2]|0;W=na-(c[f+12128+(Ta<<3)>>2]|0)|0;Ea=Ta>>1;ac=((ba(c[f+12128+(Ta<<3)+4>>2]|0,Ya-Qa|0)|0)/(Qa|0)|0)+(Ea<<(p&1|4))|0;Wa=(c[(f+12208|0)>>2]|0)+((Ta<<3&8)+(ba(Ea,ja<<3)|0))|0;if((p&1|0)==0){Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(P>>1,ja)|0)+(na>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((P&aa)<<B)+(na&aa)|0)<<2)>>2]&1023](Wa,Ea,ja,8);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ac>>1,ja)|0)+(W>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ac&aa)<<B)+(W&aa)|0)<<2)>>2]&1023](Wa,Ea,ja,8)}else{Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(P>>2,ja)|0)+(na>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(na&aa)|0)<<2)>>2]&4095](Wa,Ea,ja);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ac>>2,ja)|0)+(W>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ac&aa)<<B)+(W&aa)|0)<<2)>>2]&4095](Wa,Ea,ja)}Ta=Ta+1|0;}while((Ta|0)<4)}else{Ta=0;do{Ea=(c[f+12160+(Ta<<3)>>2]|0)+Xa|0;Wa=(c[f+12160+(Ta<<3)+4>>2]|0)+La|0;W=Ea-(c[f+12128+(Ta<<3)>>2]|0)|0;ac=Wa-(c[f+12128+(Ta<<3)+4>>2]|0)|0;na=(c[(f+12208|0)>>2]|0)+((Ta<<3&8)+(ba(Ta>>1,ja<<3)|0))|0;if((p&1|0)==0){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Wa>>1,ja)|0)+(Ea>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Wa&aa)<<B)+(Ea&aa)|0)<<2)>>2]&1023](na,P,ja,8);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ac>>1,ja)|0)+(W>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ac&aa)<<B)+(W&aa)|0)<<2)>>2]&1023](na,P,ja,8)}else{P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Wa>>2,ja)|0)+(Ea>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Wa&aa)<<B)+(Ea&aa)|0)<<2)>>2]&4095](na,P,ja);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ac>>2,ja)|0)+(W>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ac&aa)<<B)+(W&aa)|0)<<2)>>2]&4095](na,P,ja)}Ta=Ta+1|0;}while((Ta|0)<4)}}else{Ta=(c[(f+12160|0)>>2]|0)+Xa|0;P=(c[(f+12164|0)>>2]|0)+La|0;na=c[(f+12128|0)>>2]|0;if((Xa|0)==0){Uc=(ba(na,Ya-Qa|0)|0)/(Qa|0)|0}else{Uc=Ta-na|0}na=c[(f+12132|0)>>2]|0;if((La|0)==0){Vc=(ba(na,Ya-Qa|0)|0)/(Qa|0)|0}else{Vc=P-na|0}na=((Vc&aa)<<B)+(Uc&aa)|0;if((p&1|0)==0){W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(P>>1,ja)|0)+(Ta>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,W,ja,16);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Vc>>1,ja)|0)+(Uc>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(na<<2)>>2]&1023](c[(f+12208|0)>>2]|0,W,ja,16);break}else{W=(ba(P>>2,ja)|0)+(Ta>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+W|0,ja);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(W+8|0)|0,ja);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ja<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(W+(ja<<3))|0,ja);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((W+8|0)+(ja<<3))|0,ja);W=(ba(Vc>>2,ja)|0)+(Uc>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+W|0,ja);Xe[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(W+8|0)|0,ja);Xe[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ja<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(W+(ja<<3))|0,ja);Xe[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((W+8|0)+(ja<<3))|0,ja);break}}}while(0);Rc=Pe[O&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ja,16)|0}}while(0);c[(Y+(Aa<<2)|0)>>2]=Ma;c[Fa+(Aa<<2)>>2]=Rc;ja=(ba((d[Z+(La-pa)|0]|0)+(d[Z+((ma<<B)-X)|0]|0)|0,C)|0)+Rc|0;if((ja|0)>=(fa|0)){Qc=fa;break}c[V>>2]=ma;c[(V+4|0)>>2]=la;Qc=ja}}while(0);Aa=ma+1|0;if((Aa|0)>(oa|0)){Pc=Qc;break}else{ma=Aa;fa=Qc}}}fa=la+1|0;if((fa|0)>(Za|0)){Oc=Pc;break}else{la=fa;sa=Pc}}}if(((U&254)>>>2|0)==0){Wc=Oc}else{sa=(p&1)<<1|1;la=1;Za=Oc;while(1){oa=0;aa=Za;while(1){_=(ba(c[163152+(oa<<3)>>2]|0,la)|0)+Ec|0;fa=(ba(c[163156+(oa<<3)>>2]|0,la)|0)+Fc|0;ma=(_|0)>(za|0)?za:_;_=(Ga|0)>(ma|0)?Ga:ma;ma=(fa|0)>(Q|0)?Q:fa;fa=(T|0)>(ma|0)?T:ma;do{if((c[(Y+(((fa<<3)+_&63)<<2)|0)>>2]|0)==(_+ha+(fa<<11)|0|0)){Xc=aa}else{ma=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){La=c[(f+12420|0)>>2]|0;Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ma,fa)|0)+_)|0;ga=Pe[O&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ra,ma,o)|0;if((p&2|0)==0){Yc=ga;break}Ra=c[(f+12208|0)>>2]|0;$=(ba(La,fa>>1)|0)+(_>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((fa<<1&2|_&1)<<2)>>2]&1023](Ra+(ma<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+$|0,La,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((fa<<1&2|_&1)<<2)>>2]&1023](Ra+(ma<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+$|0,La,o>>1);$=(Pe[S&255](f,Ra+(ma<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,La,o>>1)|0)+ga|0;Yc=$+(Pe[S&255](f,Ra+(ma<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,La,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(_|0)){Yc=536870912;break}if((_<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Yc=536870912;break}if((c[(f+12272|0)>>2]|0)>(fa|0)){Yc=536870912;break}if((fa<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Yc=536870912;break}La=e[(f+13872|0)>>1]|0;Ra=e[(f+13874|0)>>1]|0;s:do{if((c[(f+11740|0)>>2]|0)==1){if((_<<B|0)==0){$=0;while(1){ga=c[f+12160+($<<3)>>2]|0;ia=(c[f+12160+($<<3)+4>>2]|0)+(fa<<B)|0;Aa=((ba(c[f+12128+($<<3)>>2]|0,Ra-La|0)|0)/(La|0)|0)+(($&1)<<(p&1|4))|0;Ma=c[f+12128+($<<3)+4>>2]|0;if((fa<<B|0)==0){ja=$>>1;Zc=((ba(Ma,Ra-La|0)|0)/(La|0)|0)+(ja<<(p&1|4))|0;_c=ja}else{Zc=ia-Ma|0;_c=$>>1}Ma=((Zc&sa)<<B)+(Aa&sa)|0;ja=(c[(f+12208|0)>>2]|0)+((ba(_c,ma<<3)|0)+($<<3&8))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ia>>1,ma)|0)+(ga>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ia&sa)<<B)+(ga&sa)|0)<<2)>>2]&1023](ja,Qa,ma,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Zc>>1,ma)|0)+(Aa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Ma<<2)>>2]&1023](ja,Qa,ma,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ia>>2,ma)|0)+(ga>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ia&sa)<<B)+(ga&sa)|0)<<2)>>2]&4095](ja,Qa,ma);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Zc>>2,ma)|0)+(Aa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ma<<2)>>2]&4095](ja,Qa,ma)}$=$+1|0;if(($|0)>=4){break s}}}if((fa<<B|0)==0){$=0;do{Qa=(c[f+12160+($<<3)>>2]|0)+(_<<B)|0;ja=c[f+12160+($<<3)+4>>2]|0;Ma=Qa-(c[f+12128+($<<3)>>2]|0)|0;Aa=$>>1;ga=((ba(c[f+12128+($<<3)+4>>2]|0,Ra-La|0)|0)/(La|0)|0)+(Aa<<(p&1|4))|0;ia=(c[(f+12208|0)>>2]|0)+(($<<3&8)+(ba(Aa,ma<<3)|0))|0;if((p&1|0)==0){Aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>1,ma)|0)+(Qa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ja&sa)<<B)+(Qa&sa)|0)<<2)>>2]&1023](ia,Aa,ma,8);Aa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>1,ma)|0)+(Ma>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&sa)<<B)+(Ma&sa)|0)<<2)>>2]&1023](ia,Aa,ma,8)}else{Aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>2,ma)|0)+(Qa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+(Qa&sa)|0)<<2)>>2]&4095](ia,Aa,ma);Aa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>2,ma)|0)+(Ma>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ga&sa)<<B)+(Ma&sa)|0)<<2)>>2]&4095](ia,Aa,ma)}$=$+1|0;}while(($|0)<4)}else{$=0;do{Aa=(c[f+12160+($<<3)>>2]|0)+(_<<B)|0;ia=(c[f+12160+($<<3)+4>>2]|0)+(fa<<B)|0;Ma=Aa-(c[f+12128+($<<3)>>2]|0)|0;ga=ia-(c[f+12128+($<<3)+4>>2]|0)|0;Qa=(c[(f+12208|0)>>2]|0)+(($<<3&8)+(ba($>>1,ma<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ia>>1,ma)|0)+(Aa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ia&sa)<<B)+(Aa&sa)|0)<<2)>>2]&1023](Qa,ja,ma,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>1,ma)|0)+(Ma>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&sa)<<B)+(Ma&sa)|0)<<2)>>2]&1023](Qa,ja,ma,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ia>>2,ma)|0)+(Aa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ia&sa)<<B)+(Aa&sa)|0)<<2)>>2]&4095](Qa,ja,ma);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>2,ma)|0)+(Ma>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ga&sa)<<B)+(Ma&sa)|0)<<2)>>2]&4095](Qa,ja,ma)}$=$+1|0;}while(($|0)<4)}}else{$=(c[(f+12160|0)>>2]|0)+(_<<B)|0;ja=(c[(f+12164|0)>>2]|0)+(fa<<B)|0;Qa=c[(f+12128|0)>>2]|0;if((_<<B|0)==0){$c=(ba(Qa,Ra-La|0)|0)/(La|0)|0}else{$c=$-Qa|0}Qa=c[(f+12132|0)>>2]|0;if((fa<<B|0)==0){ad=(ba(Qa,Ra-La|0)|0)/(La|0)|0}else{ad=ja-Qa|0}Qa=((ad&sa)<<B)+($c&sa)|0;if((p&1|0)==0){Ma=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>1,ma)|0)+($>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ma,ma,16);Ma=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ad>>1,ma)|0)+($c>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(Qa<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ma,ma,16);break}else{Ma=(ba(ja>>2,ma)|0)+($>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ma|0,ma);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ma+8|0)|0,ma);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ma<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ma+(ma<<3))|0,ma);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ma+8|0)+(ma<<3))|0,ma);Ma=(ba(ad>>2,ma)|0)+($c>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Qa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ma|0,ma);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Qa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ma+8|0)|0,ma);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Qa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ma<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ma+(ma<<3))|0,ma);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Qa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ma+8|0)+(ma<<3))|0,ma);break}}}while(0);Yc=Pe[O&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(Y+(((fa<<3)+_&63)<<2)|0)>>2]=_+ha+(fa<<11)|0;c[Fa+(((fa<<3)+_&63)<<2)>>2]=Yc;ma=(ba((d[Z+((fa<<B)-pa)|0]|0)+(d[Z+((_<<B)-X)|0]|0)|0,C)|0)+Yc|0;if((ma|0)>=(aa|0)){Xc=aa;break}c[V>>2]=_;c[(V+4|0)>>2]=fa;Xc=ma}}while(0);fa=oa+1|0;if((fa|0)<16){oa=fa;aa=Xc}else{break}}aa=la+1|0;if((aa|0)>((U&254)>>>2|0)){Wc=Xc;break}else{la=aa;Za=Xc}}}Bb=Hmb(f,V,Wc,j,k,C,n,o,p,2)|0;break}if((U|0)>512){Bb=Hmb(f,V,L,j,k,C,n,o,p,U&255)|0;break}Za=c[(f+12220|0)>>2]|0;la=c[(f+12264|0)>>2]|0;X=c[(f+12272|0)>>2]|0;Z=c[(f+12268|0)>>2]|0;pa=c[(f+12276|0)>>2]|0;Fa=c[(f+12464|0)>>2]|0;ha=c[(f+12280|0)>>2]|0;Y=c[(f+12284|0)>>2]|0;O=c[(f+12216|0)>>2]|0;sa=c[(f+12224|0)>>2]|0;if((U|0)<=256){S=c[f+10468+(n<<2)>>2]|0;T=c[f+10468+((n+1|0)<<2)>>2]|0;Q=(p&1)<<1|1;Ga=p&1|4;za=(p&1|0)==0;aa=1;oa=L;fa=M;_=N;while(1){ma=aa+_|0;La=(ma-pa|0|0)<0?0:ma-pa|0;Ra=Z-fa+1|0;Ma=(aa|0)>(Ra|0)?Ra:aa;if((La|0)<(Ma|0)){Ra=La;La=oa;Qa=_;$=fa;while(1){ja=ma-Ra|0;ga=Ra+fa|0;do{if((c[(O+(((ja<<3)+ga&63)<<2)|0)>>2]|0)==(ga+sa+(ja<<11)|0|0)){bd=La;cd=Qa;dd=$}else{Aa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ia=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Aa,ja)|0)+ga)|0;Xa=Pe[S&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,Aa,o)|0;if((p&2|0)==0){ed=Xa;break}Ya=c[(f+12208|0)>>2]|0;W=(ba(ia,ja>>1)|0)+(ga>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|ga&1)<<2)>>2]&1023](Ya+(Aa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+W|0,ia,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|ga&1)<<2)>>2]&1023](Ya+(Aa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+W|0,ia,o>>1);W=(Pe[T&255](f,Ya+(Aa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ia,o>>1)|0)+Xa|0;ed=W+(Pe[T&255](f,Ya+(Aa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ia,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(ga|0)){ed=536870912;break}if((ga<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ed=536870912;break}if((c[(f+12272|0)>>2]|0)>(ja|0)){ed=536870912;break}if((ja<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ed=536870912;break}ia=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;t:do{if((c[(f+11740|0)>>2]|0)==1){if((ga<<B|0)==0){W=0;while(1){Xa=c[f+12160+(W<<3)>>2]|0;na=(c[f+12160+(W<<3)+4>>2]|0)+(ja<<B)|0;Ta=((ba(c[f+12128+(W<<3)>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+((W&1)<<Ga)|0;P=c[f+12128+(W<<3)+4>>2]|0;if((ja<<B|0)==0){ac=W>>1;fd=((ba(P,Ya-ia|0)|0)/(ia|0)|0)+(ac<<Ga)|0;gd=ac}else{fd=na-P|0;gd=W>>1}P=((fd&Q)<<B)+(Ta&Q)|0;ac=(c[(f+12208|0)>>2]|0)+((ba(gd,Aa<<3)|0)+(W<<3&8))|0;if(za){Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>1,Aa)|0)+(Xa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((na&Q)<<B)+(Xa&Q)|0)<<2)>>2]&1023](ac,Ea,Aa,8);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(fd>>1,Aa)|0)+(Ta>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(P<<2)>>2]&1023](ac,Ea,Aa,8)}else{Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>2,Aa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((na&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](ac,Ea,Aa);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(fd>>2,Aa)|0)+(Ta>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(P<<2)>>2]&4095](ac,Ea,Aa)}W=W+1|0;if((W|0)>=4){break t}}}if((ja<<B|0)==0){W=0;do{Ea=(c[f+12160+(W<<3)>>2]|0)+(ga<<B)|0;ac=c[f+12160+(W<<3)+4>>2]|0;P=Ea-(c[f+12128+(W<<3)>>2]|0)|0;Ta=W>>1;Xa=((ba(c[f+12128+(W<<3)+4>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+(Ta<<Ga)|0;na=(c[(f+12208|0)>>2]|0)+((W<<3&8)+(ba(Ta,Aa<<3)|0))|0;if(za){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ac>>1,Aa)|0)+(Ea>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ac&Q)<<B)+(Ea&Q)|0)<<2)>>2]&1023](na,Ta,Aa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Xa>>1,Aa)|0)+(P>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&1023](na,Ta,Aa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ac>>2,Aa)|0)+(Ea>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095](na,Ta,Aa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Xa>>2,Aa)|0)+(P>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](na,Ta,Aa)}W=W+1|0;}while((W|0)<4)}else{W=0;do{Ta=(c[f+12160+(W<<3)>>2]|0)+(ga<<B)|0;na=(c[f+12160+(W<<3)+4>>2]|0)+(ja<<B)|0;P=Ta-(c[f+12128+(W<<3)>>2]|0)|0;Xa=na-(c[f+12128+(W<<3)+4>>2]|0)|0;Ea=(c[(f+12208|0)>>2]|0)+((W<<3&8)+(ba(W>>1,Aa<<3)|0))|0;if(za){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>1,Aa)|0)+(Ta>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((na&Q)<<B)+(Ta&Q)|0)<<2)>>2]&1023](Ea,ac,Aa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Xa>>1,Aa)|0)+(P>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&1023](Ea,ac,Aa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>2,Aa)|0)+(Ta>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((na&Q)<<B)+(Ta&Q)|0)<<2)>>2]&4095](Ea,ac,Aa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Xa>>2,Aa)|0)+(P>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](Ea,ac,Aa)}W=W+1|0;}while((W|0)<4)}}else{W=(c[(f+12160|0)>>2]|0)+(ga<<B)|0;ac=(c[(f+12164|0)>>2]|0)+(ja<<B)|0;Ea=c[(f+12128|0)>>2]|0;if((ga<<B|0)==0){hd=(ba(Ea,Ya-ia|0)|0)/(ia|0)|0}else{hd=W-Ea|0}Ea=c[(f+12132|0)>>2]|0;if((ja<<B|0)==0){id=(ba(Ea,Ya-ia|0)|0)/(ia|0)|0}else{id=ac-Ea|0}Ea=((id&Q)<<B)+(hd&Q)|0;if(za){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ac>>1,Aa)|0)+(W>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,P,Aa,16);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(id>>1,Aa)|0)+(hd>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(Ea<<2)>>2]&1023](c[(f+12208|0)>>2]|0,P,Aa,16);break}else{P=(ba(ac>>2,Aa)|0)+(W>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+P|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(P+8|0)|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(P+(Aa<<3))|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((P+8|0)+(Aa<<3))|0,Aa);P=(ba(id>>2,Aa)|0)+(hd>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+P|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(P+8|0)|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(P+(Aa<<3))|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((P+8|0)+(Aa<<3))|0,Aa);break}}}while(0);ed=Pe[S&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Aa,16)|0}}while(0);c[(O+(((ja<<3)+ga&63)<<2)|0)>>2]=ga+sa+(ja<<11)|0;c[Za+(((ja<<3)+ga&63)<<2)>>2]=ed;Aa=(ba((d[Fa+((ja<<B)-Y)|0]|0)+(d[Fa+((ga<<B)-ha)|0]|0)|0,C)|0)+ed|0;if((Aa|0)>=(La|0)){bd=La;cd=Qa;dd=$;break}c[V>>2]=ga;c[(V+4|0)>>2]=ja;bd=Aa;cd=ja;dd=ga}}while(0);ga=Ra+1|0;if((ga|0)<(Ma|0)){Ra=ga;La=bd;Qa=cd;$=dd}else{jd=bd;kd=cd;ld=dd;break}}}else{jd=oa;kd=_;ld=fa}$=aa+fa|0;Qa=($-Z|0|0)<0?0:$-Z|0;La=_-X+1|0;Ra=(aa|0)>(La|0)?La:aa;if((Qa|0)<(Ra|0)){La=Qa;Qa=jd;Ma=kd;ma=ld;while(1){ga=_-La|0;ja=$-La|0;do{if((c[(O+(((ga<<3)+ja&63)<<2)|0)>>2]|0)==(ja+sa+(ga<<11)|0|0)){md=Qa;nd=Ma;od=ma}else{Aa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ia=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Aa,ga)|0)+ja)|0;P=Pe[S&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,Aa,o)|0;if((p&2|0)==0){pd=P;break}Ya=c[(f+12208|0)>>2]|0;Ea=(ba(ia,ga>>1)|0)+(ja>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ga<<1&2|ja&1)<<2)>>2]&1023](Ya+(Aa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Ea|0,ia,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ga<<1&2|ja&1)<<2)>>2]&1023](Ya+(Aa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Ea|0,ia,o>>1);Ea=(Pe[T&255](f,Ya+(Aa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ia,o>>1)|0)+P|0;pd=Ea+(Pe[T&255](f,Ya+(Aa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ia,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(ja|0)){pd=536870912;break}if((ja<<B|0)>(c[(f+12268|0)>>2]<<B|0)){pd=536870912;break}if((c[(f+12272|0)>>2]|0)>(ga|0)){pd=536870912;break}if((ga<<B|0)>(c[(f+12276|0)>>2]<<B|0)){pd=536870912;break}ia=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;u:do{if((c[(f+11740|0)>>2]|0)==1){if((ja<<B|0)==0){Ea=0;while(1){P=c[f+12160+(Ea<<3)>>2]|0;W=(c[f+12160+(Ea<<3)+4>>2]|0)+(ga<<B)|0;ac=((ba(c[f+12128+(Ea<<3)>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+((Ea&1)<<Ga)|0;Xa=c[f+12128+(Ea<<3)+4>>2]|0;if((ga<<B|0)==0){Ta=Ea>>1;qd=((ba(Xa,Ya-ia|0)|0)/(ia|0)|0)+(Ta<<Ga)|0;rd=Ta}else{qd=W-Xa|0;rd=Ea>>1}Xa=((qd&Q)<<B)+(ac&Q)|0;Ta=(c[(f+12208|0)>>2]|0)+((ba(rd,Aa<<3)|0)+(Ea<<3&8))|0;if(za){na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(W>>1,Aa)|0)+(P>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((W&Q)<<B)+(P&Q)|0)<<2)>>2]&1023](Ta,na,Aa,8);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(qd>>1,Aa)|0)+(ac>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Xa<<2)>>2]&1023](Ta,na,Aa,8)}else{na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(W>>2,Aa)|0)+(P>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((W&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](Ta,na,Aa);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(qd>>2,Aa)|0)+(ac>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](Ta,na,Aa)}Ea=Ea+1|0;if((Ea|0)>=4){break u}}}if((ga<<B|0)==0){Ea=0;do{na=(c[f+12160+(Ea<<3)>>2]|0)+(ja<<B)|0;Ta=c[f+12160+(Ea<<3)+4>>2]|0;Xa=na-(c[f+12128+(Ea<<3)>>2]|0)|0;ac=Ea>>1;P=((ba(c[f+12128+(Ea<<3)+4>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+(ac<<Ga)|0;W=(c[(f+12208|0)>>2]|0)+((Ea<<3&8)+(ba(ac,Aa<<3)|0))|0;if(za){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>1,Aa)|0)+(na>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ta&Q)<<B)+(na&Q)|0)<<2)>>2]&1023](W,ac,Aa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(P>>1,Aa)|0)+(Xa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&1023](W,ac,Aa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>2,Aa)|0)+(na>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(na&Q)|0)<<2)>>2]&4095](W,ac,Aa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(P>>2,Aa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](W,ac,Aa)}Ea=Ea+1|0;}while((Ea|0)<4)}else{Ea=0;do{ac=(c[f+12160+(Ea<<3)>>2]|0)+(ja<<B)|0;W=(c[f+12160+(Ea<<3)+4>>2]|0)+(ga<<B)|0;Xa=ac-(c[f+12128+(Ea<<3)>>2]|0)|0;P=W-(c[f+12128+(Ea<<3)+4>>2]|0)|0;na=(c[(f+12208|0)>>2]|0)+((Ea<<3&8)+(ba(Ea>>1,Aa<<3)|0))|0;if(za){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(W>>1,Aa)|0)+(ac>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((W&Q)<<B)+(ac&Q)|0)<<2)>>2]&1023](na,Ta,Aa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(P>>1,Aa)|0)+(Xa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&1023](na,Ta,Aa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(W>>2,Aa)|0)+(ac>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((W&Q)<<B)+(ac&Q)|0)<<2)>>2]&4095](na,Ta,Aa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(P>>2,Aa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](na,Ta,Aa)}Ea=Ea+1|0;}while((Ea|0)<4)}}else{Ea=(c[(f+12160|0)>>2]|0)+(ja<<B)|0;Ta=(c[(f+12164|0)>>2]|0)+(ga<<B)|0;na=c[(f+12128|0)>>2]|0;if((ja<<B|0)==0){sd=(ba(na,Ya-ia|0)|0)/(ia|0)|0}else{sd=Ea-na|0}na=c[(f+12132|0)>>2]|0;if((ga<<B|0)==0){td=(ba(na,Ya-ia|0)|0)/(ia|0)|0}else{td=Ta-na|0}na=((td&Q)<<B)+(sd&Q)|0;if(za){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>1,Aa)|0)+(Ea>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Xa,Aa,16);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(td>>1,Aa)|0)+(sd>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(na<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Xa,Aa,16);break}else{Xa=(ba(Ta>>2,Aa)|0)+(Ea>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Xa|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+8|0)|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+(Aa<<3))|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Xa+8|0)+(Aa<<3))|0,Aa);Xa=(ba(td>>2,Aa)|0)+(sd>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Xa|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+8|0)|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+(Aa<<3))|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Xa+8|0)+(Aa<<3))|0,Aa);break}}}while(0);pd=Pe[S&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Aa,16)|0}}while(0);c[(O+(((ga<<3)+ja&63)<<2)|0)>>2]=ja+sa+(ga<<11)|0;c[Za+(((ga<<3)+ja&63)<<2)>>2]=pd;Aa=(ba((d[Fa+((ga<<B)-Y)|0]|0)+(d[Fa+((ja<<B)-ha)|0]|0)|0,C)|0)+pd|0;if((Aa|0)>=(Qa|0)){md=Qa;nd=Ma;od=ma;break}c[V>>2]=ja;c[(V+4|0)>>2]=ga;md=Aa;nd=ga;od=ja}}while(0);ja=La+1|0;if((ja|0)<(Ra|0)){La=ja;Qa=md;Ma=nd;ma=od}else{ud=md;vd=nd;wd=od;break}}}else{ud=jd;vd=kd;wd=ld}ma=aa-_+X|0;Ma=(ma|0)<0?0:ma;ma=fa-la+1|0;Qa=(aa|0)>(ma|0)?ma:aa;if((Ma|0)<(Qa|0)){ma=_-aa|0;La=Ma;Ma=ud;Ra=vd;$=wd;while(1){ja=La+ma|0;ga=fa-La|0;do{if((c[(O+(((ja<<3)+ga&63)<<2)|0)>>2]|0)==(ga+sa+(ja<<11)|0|0)){xd=Ma;yd=Ra;zd=$}else{Aa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ia=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Aa,ja)|0)+ga)|0;Xa=Pe[S&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,Aa,o)|0;if((p&2|0)==0){Ad=Xa;break}Ya=c[(f+12208|0)>>2]|0;na=(ba(ia,ja>>1)|0)+(ga>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|ga&1)<<2)>>2]&1023](Ya+(Aa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+na|0,ia,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|ga&1)<<2)>>2]&1023](Ya+(Aa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+na|0,ia,o>>1);na=(Pe[T&255](f,Ya+(Aa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ia,o>>1)|0)+Xa|0;Ad=na+(Pe[T&255](f,Ya+(Aa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ia,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(ga|0)){Ad=536870912;break}if((ga<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Ad=536870912;break}if((c[(f+12272|0)>>2]|0)>(ja|0)){Ad=536870912;break}if((ja<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Ad=536870912;break}ia=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;v:do{if((c[(f+11740|0)>>2]|0)==1){if((ga<<B|0)==0){na=0;while(1){Xa=c[f+12160+(na<<3)>>2]|0;Ea=(c[f+12160+(na<<3)+4>>2]|0)+(ja<<B)|0;Ta=((ba(c[f+12128+(na<<3)>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+((na&1)<<Ga)|0;P=c[f+12128+(na<<3)+4>>2]|0;if((ja<<B|0)==0){ac=na>>1;Bd=((ba(P,Ya-ia|0)|0)/(ia|0)|0)+(ac<<Ga)|0;Cd=ac}else{Bd=Ea-P|0;Cd=na>>1}P=((Bd&Q)<<B)+(Ta&Q)|0;ac=(c[(f+12208|0)>>2]|0)+((ba(Cd,Aa<<3)|0)+(na<<3&8))|0;if(za){W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>1,Aa)|0)+(Xa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&Q)<<B)+(Xa&Q)|0)<<2)>>2]&1023](ac,W,Aa,8);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Bd>>1,Aa)|0)+(Ta>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(P<<2)>>2]&1023](ac,W,Aa,8)}else{W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>2,Aa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](ac,W,Aa);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Bd>>2,Aa)|0)+(Ta>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(P<<2)>>2]&4095](ac,W,Aa)}na=na+1|0;if((na|0)>=4){break v}}}if((ja<<B|0)==0){na=0;do{W=(c[f+12160+(na<<3)>>2]|0)+(ga<<B)|0;ac=c[f+12160+(na<<3)+4>>2]|0;P=W-(c[f+12128+(na<<3)>>2]|0)|0;Ta=na>>1;Xa=((ba(c[f+12128+(na<<3)+4>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+(Ta<<Ga)|0;Ea=(c[(f+12208|0)>>2]|0)+((na<<3&8)+(ba(Ta,Aa<<3)|0))|0;if(za){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ac>>1,Aa)|0)+(W>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&1023](Ea,Ta,Aa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Xa>>1,Aa)|0)+(P>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&1023](Ea,Ta,Aa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ac>>2,Aa)|0)+(W>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095](Ea,Ta,Aa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Xa>>2,Aa)|0)+(P>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](Ea,Ta,Aa)}na=na+1|0;}while((na|0)<4)}else{na=0;do{Ta=(c[f+12160+(na<<3)>>2]|0)+(ga<<B)|0;Ea=(c[f+12160+(na<<3)+4>>2]|0)+(ja<<B)|0;P=Ta-(c[f+12128+(na<<3)>>2]|0)|0;Xa=Ea-(c[f+12128+(na<<3)+4>>2]|0)|0;W=(c[(f+12208|0)>>2]|0)+((na<<3&8)+(ba(na>>1,Aa<<3)|0))|0;if(za){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>1,Aa)|0)+(Ta>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&Q)<<B)+(Ta&Q)|0)<<2)>>2]&1023](W,ac,Aa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Xa>>1,Aa)|0)+(P>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&1023](W,ac,Aa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>2,Aa)|0)+(Ta>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&Q)<<B)+(Ta&Q)|0)<<2)>>2]&4095](W,ac,Aa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Xa>>2,Aa)|0)+(P>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](W,ac,Aa)}na=na+1|0;}while((na|0)<4)}}else{na=(c[(f+12160|0)>>2]|0)+(ga<<B)|0;ac=(c[(f+12164|0)>>2]|0)+(ja<<B)|0;W=c[(f+12128|0)>>2]|0;if((ga<<B|0)==0){Dd=(ba(W,Ya-ia|0)|0)/(ia|0)|0}else{Dd=na-W|0}W=c[(f+12132|0)>>2]|0;if((ja<<B|0)==0){Ed=(ba(W,Ya-ia|0)|0)/(ia|0)|0}else{Ed=ac-W|0}W=((Ed&Q)<<B)+(Dd&Q)|0;if(za){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ac>>1,Aa)|0)+(na>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,P,Aa,16);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ed>>1,Aa)|0)+(Dd>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(W<<2)>>2]&1023](c[(f+12208|0)>>2]|0,P,Aa,16);break}else{P=(ba(ac>>2,Aa)|0)+(na>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+P|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(P+8|0)|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(P+(Aa<<3))|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((P+8|0)+(Aa<<3))|0,Aa);P=(ba(Ed>>2,Aa)|0)+(Dd>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+P|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(P+8|0)|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(P+(Aa<<3))|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((P+8|0)+(Aa<<3))|0,Aa);break}}}while(0);Ad=Pe[S&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Aa,16)|0}}while(0);c[(O+(((ja<<3)+ga&63)<<2)|0)>>2]=ga+sa+(ja<<11)|0;c[Za+(((ja<<3)+ga&63)<<2)>>2]=Ad;Aa=(ba((d[Fa+((ja<<B)-Y)|0]|0)+(d[Fa+((ga<<B)-ha)|0]|0)|0,C)|0)+Ad|0;if((Aa|0)>=(Ma|0)){xd=Ma;yd=Ra;zd=$;break}c[V>>2]=ga;c[(V+4|0)>>2]=ja;xd=Aa;yd=ja;zd=ga}}while(0);ga=La+1|0;if((ga|0)<(Qa|0)){La=ga;Ma=xd;Ra=yd;$=zd}else{Fd=xd;Gd=yd;Hd=zd;break}}}else{Fd=ud;Gd=vd;Hd=wd}$=aa-fa+la|0;Ra=($|0)<0?0:$;$=pa-_+1|0;Ma=(aa|0)>($|0)?$:aa;if((Ra|0)<(Ma|0)){$=fa-aa|0;La=Ra;Ra=Fd;Qa=Gd;ma=Hd;while(1){ga=La+_|0;ja=La+$|0;do{if((c[(O+(((ga<<3)+ja&63)<<2)|0)>>2]|0)==(ja+sa+(ga<<11)|0|0)){Id=Ra;Jd=Qa;Kd=ma}else{Aa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ia=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Aa,ga)|0)+ja)|0;P=Pe[S&255](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,Aa,o)|0;if((p&2|0)==0){Ld=P;break}Ya=c[(f+12208|0)>>2]|0;W=(ba(ia,ga>>1)|0)+(ja>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ga<<1&2|ja&1)<<2)>>2]&1023](Ya+(Aa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+W|0,ia,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ga<<1&2|ja&1)<<2)>>2]&1023](Ya+(Aa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+W|0,ia,o>>1);W=(Pe[T&255](f,Ya+(Aa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ia,o>>1)|0)+P|0;Ld=W+(Pe[T&255](f,Ya+(Aa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ia,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(ja|0)){Ld=536870912;break}if((ja<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Ld=536870912;break}if((c[(f+12272|0)>>2]|0)>(ga|0)){Ld=536870912;break}if((ga<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Ld=536870912;break}ia=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;w:do{if((c[(f+11740|0)>>2]|0)==1){if((ja<<B|0)==0){W=0;while(1){P=c[f+12160+(W<<3)>>2]|0;na=(c[f+12160+(W<<3)+4>>2]|0)+(ga<<B)|0;ac=((ba(c[f+12128+(W<<3)>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+((W&1)<<Ga)|0;Xa=c[f+12128+(W<<3)+4>>2]|0;if((ga<<B|0)==0){Ta=W>>1;Md=((ba(Xa,Ya-ia|0)|0)/(ia|0)|0)+(Ta<<Ga)|0;Nd=Ta}else{Md=na-Xa|0;Nd=W>>1}Xa=((Md&Q)<<B)+(ac&Q)|0;Ta=(c[(f+12208|0)>>2]|0)+((ba(Nd,Aa<<3)|0)+(W<<3&8))|0;if(za){Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>1,Aa)|0)+(P>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((na&Q)<<B)+(P&Q)|0)<<2)>>2]&1023](Ta,Ea,Aa,8);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Md>>1,Aa)|0)+(ac>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Xa<<2)>>2]&1023](Ta,Ea,Aa,8)}else{Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>2,Aa)|0)+(P>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((na&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](Ta,Ea,Aa);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Md>>2,Aa)|0)+(ac>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](Ta,Ea,Aa)}W=W+1|0;if((W|0)>=4){break w}}}if((ga<<B|0)==0){W=0;do{Ea=(c[f+12160+(W<<3)>>2]|0)+(ja<<B)|0;Ta=c[f+12160+(W<<3)+4>>2]|0;Xa=Ea-(c[f+12128+(W<<3)>>2]|0)|0;ac=W>>1;P=((ba(c[f+12128+(W<<3)+4>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+(ac<<Ga)|0;na=(c[(f+12208|0)>>2]|0)+((W<<3&8)+(ba(ac,Aa<<3)|0))|0;if(za){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>1,Aa)|0)+(Ea>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&1023](na,ac,Aa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(P>>1,Aa)|0)+(Xa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&1023](na,ac,Aa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>2,Aa)|0)+(Ea>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095](na,ac,Aa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(P>>2,Aa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](na,ac,Aa)}W=W+1|0;}while((W|0)<4)}else{W=0;do{ac=(c[f+12160+(W<<3)>>2]|0)+(ja<<B)|0;na=(c[f+12160+(W<<3)+4>>2]|0)+(ga<<B)|0;Xa=ac-(c[f+12128+(W<<3)>>2]|0)|0;P=na-(c[f+12128+(W<<3)+4>>2]|0)|0;Ea=(c[(f+12208|0)>>2]|0)+((W<<3&8)+(ba(W>>1,Aa<<3)|0))|0;if(za){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>1,Aa)|0)+(ac>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((na&Q)<<B)+(ac&Q)|0)<<2)>>2]&1023](Ea,Ta,Aa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(P>>1,Aa)|0)+(Xa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&1023](Ea,Ta,Aa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(na>>2,Aa)|0)+(ac>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((na&Q)<<B)+(ac&Q)|0)<<2)>>2]&4095](Ea,Ta,Aa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(P>>2,Aa)|0)+(Xa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](Ea,Ta,Aa)}W=W+1|0;}while((W|0)<4)}}else{W=(c[(f+12160|0)>>2]|0)+(ja<<B)|0;Ta=(c[(f+12164|0)>>2]|0)+(ga<<B)|0;Ea=c[(f+12128|0)>>2]|0;if((ja<<B|0)==0){Od=(ba(Ea,Ya-ia|0)|0)/(ia|0)|0}else{Od=W-Ea|0}Ea=c[(f+12132|0)>>2]|0;if((ga<<B|0)==0){Pd=(ba(Ea,Ya-ia|0)|0)/(ia|0)|0}else{Pd=Ta-Ea|0}Ea=((Pd&Q)<<B)+(Od&Q)|0;if(za){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ta>>1,Aa)|0)+(W>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Xa,Aa,16);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Pd>>1,Aa)|0)+(Od>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(Ea<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Xa,Aa,16);break}else{Xa=(ba(Ta>>2,Aa)|0)+(W>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Xa|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+8|0)|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+(Aa<<3))|0,Aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Xa+8|0)+(Aa<<3))|0,Aa);Xa=(ba(Pd>>2,Aa)|0)+(Od>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Xa|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+8|0)|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+(Aa<<3))|0,Aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Xa+8|0)+(Aa<<3))|0,Aa);break}}}while(0);Ld=Pe[S&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Aa,16)|0}}while(0);c[(O+(((ga<<3)+ja&63)<<2)|0)>>2]=ja+sa+(ga<<11)|0;c[Za+(((ga<<3)+ja&63)<<2)>>2]=Ld;Aa=(ba((d[Fa+((ga<<B)-Y)|0]|0)+(d[Fa+((ja<<B)-ha)|0]|0)|0,C)|0)+Ld|0;if((Aa|0)>=(Ra|0)){Id=Ra;Jd=Qa;Kd=ma;break}c[V>>2]=ja;c[(V+4|0)>>2]=ga;Id=Aa;Jd=ga;Kd=ja}}while(0);ja=La+1|0;if((ja|0)<(Ma|0)){La=ja;Ra=Id;Qa=Jd;ma=Kd}else{Qd=Id;Rd=Jd;Sd=Kd;break}}}else{Qd=Fd;Rd=Gd;Sd=Hd}ma=(fa|0)==(Sd|0)&(_|0)==(Rd|0);Qa=ma?aa+1|0:1;if((Qa|0)>(c[(f+12260|0)>>2]|0)){Bb=Qd;break e}else{aa=Qa;oa=Qd;fa=Sd;_=ma?_:Rd}}}_=c[f+10468+(n<<2)>>2]|0;fa=c[f+10468+((n+1|0)<<2)>>2]|0;if((U&255|0)==0){Td=L;Ud=M;Vd=N;Wd=V+4|0}else{oa=(p&1)<<1|1;aa=U&255;S=L;Q=N;za=M;while(1){Ga=S;T=Q;ma=za;while(1){Qa=0;Ra=Ga;La=T;Ma=ma;while(1){$=(ba(c[862288+(Qa<<3)>>2]|0,aa)|0)+ma|0;ja=(ba(c[862292+(Qa<<3)>>2]|0,aa)|0)+T|0;ga=($|0)>(Z|0)?Z:$;$=(la|0)>(ga|0)?la:ga;ga=(ja|0)>(pa|0)?pa:ja;ja=(X|0)>(ga|0)?X:ga;do{if((c[(O+(((ja<<3)+$&63)<<2)|0)>>2]|0)==($+sa+(ja<<11)|0|0)){Xd=Ra;Yd=La;Zd=Ma}else{ga=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Aa=c[(f+12420|0)>>2]|0;ia=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ga,ja)|0)+$)|0;Ya=Pe[_&255](f,c[(f+12288+(j<<4)|0)>>2]|0,ia,ga,o)|0;if((p&2|0)==0){_d=Ya;break}ia=c[(f+12208|0)>>2]|0;Xa=(ba(Aa,ja>>1)|0)+($>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|$&1)<<2)>>2]&1023](ia+(ga<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Xa|0,Aa,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|$&1)<<2)>>2]&1023](ia+(ga<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Xa|0,Aa,o>>1);Xa=(Pe[fa&255](f,ia+(ga<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Aa,o>>1)|0)+Ya|0;_d=Xa+(Pe[fa&255](f,ia+(ga<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Aa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>($|0)){_d=536870912;break}if(($<<B|0)>(c[(f+12268|0)>>2]<<B|0)){_d=536870912;break}if((c[(f+12272|0)>>2]|0)>(ja|0)){_d=536870912;break}if((ja<<B|0)>(c[(f+12276|0)>>2]<<B|0)){_d=536870912;break}Aa=e[(f+13872|0)>>1]|0;ia=e[(f+13874|0)>>1]|0;x:do{if((c[(f+11740|0)>>2]|0)==1){if(($<<B|0)==0){Xa=0;while(1){Ya=c[f+12160+(Xa<<3)>>2]|0;Ea=(c[f+12160+(Xa<<3)+4>>2]|0)+(ja<<B)|0;W=((ba(c[f+12128+(Xa<<3)>>2]|0,ia-Aa|0)|0)/(Aa|0)|0)+((Xa&1)<<(p&1|4))|0;Ta=c[f+12128+(Xa<<3)+4>>2]|0;if((ja<<B|0)==0){P=Xa>>1;$d=((ba(Ta,ia-Aa|0)|0)/(Aa|0)|0)+(P<<(p&1|4))|0;ae=P}else{$d=Ea-Ta|0;ae=Xa>>1}Ta=(($d&oa)<<B)+(W&oa)|0;P=(c[(f+12208|0)>>2]|0)+((ba(ae,ga<<3)|0)+(Xa<<3&8))|0;if((p&1|0)==0){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>1,ga)|0)+(Ya>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&oa)<<B)+(Ya&oa)|0)<<2)>>2]&1023](P,ac,ga,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba($d>>1,ga)|0)+(W>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Ta<<2)>>2]&1023](P,ac,ga,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>2,ga)|0)+(Ya>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&oa)<<B)+(Ya&oa)|0)<<2)>>2]&4095](P,ac,ga);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba($d>>2,ga)|0)+(W>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ta<<2)>>2]&4095](P,ac,ga)}Xa=Xa+1|0;if((Xa|0)>=4){break x}}}if((ja<<B|0)==0){Xa=0;do{ac=(c[f+12160+(Xa<<3)>>2]|0)+($<<B)|0;P=c[f+12160+(Xa<<3)+4>>2]|0;Ta=ac-(c[f+12128+(Xa<<3)>>2]|0)|0;W=Xa>>1;Ya=((ba(c[f+12128+(Xa<<3)+4>>2]|0,ia-Aa|0)|0)/(Aa|0)|0)+(W<<(p&1|4))|0;Ea=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ba(W,ga<<3)|0))|0;if((p&1|0)==0){W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(P>>1,ga)|0)+(ac>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((P&oa)<<B)+(ac&oa)|0)<<2)>>2]&1023](Ea,W,ga,8);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ya>>1,ga)|0)+(Ta>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ya&oa)<<B)+(Ta&oa)|0)<<2)>>2]&1023](Ea,W,ga,8)}else{W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(P>>2,ga)|0)+(ac>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(ac&oa)|0)<<2)>>2]&4095](Ea,W,ga);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ya>>2,ga)|0)+(Ta>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ya&oa)<<B)+(Ta&oa)|0)<<2)>>2]&4095](Ea,W,ga)}Xa=Xa+1|0;}while((Xa|0)<4)}else{Xa=0;do{W=(c[f+12160+(Xa<<3)>>2]|0)+($<<B)|0;Ea=(c[f+12160+(Xa<<3)+4>>2]|0)+(ja<<B)|0;Ta=W-(c[f+12128+(Xa<<3)>>2]|0)|0;Ya=Ea-(c[f+12128+(Xa<<3)+4>>2]|0)|0;ac=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ba(Xa>>1,ga<<3)|0))|0;if((p&1|0)==0){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>1,ga)|0)+(W>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&oa)<<B)+(W&oa)|0)<<2)>>2]&1023](ac,P,ga,8);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ya>>1,ga)|0)+(Ta>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ya&oa)<<B)+(Ta&oa)|0)<<2)>>2]&1023](ac,P,ga,8)}else{P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ea>>2,ga)|0)+(W>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&oa)<<B)+(W&oa)|0)<<2)>>2]&4095](ac,P,ga);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ya>>2,ga)|0)+(Ta>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ya&oa)<<B)+(Ta&oa)|0)<<2)>>2]&4095](ac,P,ga)}Xa=Xa+1|0;}while((Xa|0)<4)}}else{Xa=(c[(f+12160|0)>>2]|0)+($<<B)|0;P=(c[(f+12164|0)>>2]|0)+(ja<<B)|0;ac=c[(f+12128|0)>>2]|0;if(($<<B|0)==0){be=(ba(ac,ia-Aa|0)|0)/(Aa|0)|0}else{be=Xa-ac|0}ac=c[(f+12132|0)>>2]|0;if((ja<<B|0)==0){ce=(ba(ac,ia-Aa|0)|0)/(Aa|0)|0}else{ce=P-ac|0}ac=((ce&oa)<<B)+(be&oa)|0;if((p&1|0)==0){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(P>>1,ga)|0)+(Xa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ta,ga,16);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ce>>1,ga)|0)+(be>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+(ac<<2)>>2]&1023](c[(f+12208|0)>>2]|0,Ta,ga,16);break}else{Ta=(ba(P>>2,ga)|0)+(Xa>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ta|0,ga);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ta+8|0)|0,ga);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ga<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ta+(ga<<3))|0,ga);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ga<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ta+8|0)+(ga<<3))|0,ga);Ta=(ba(ce>>2,ga)|0)+(be>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ta|0,ga);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ta+8|0)|0,ga);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ga<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ta+(ga<<3))|0,ga);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ga<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ta+8|0)+(ga<<3))|0,ga);break}}}while(0);_d=Pe[_&255](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ga,16)|0}}while(0);c[(O+(((ja<<3)+$&63)<<2)|0)>>2]=$+sa+(ja<<11)|0;c[Za+(((ja<<3)+$&63)<<2)>>2]=_d;ga=(ba((d[Fa+((ja<<B)-Y)|0]|0)+(d[Fa+(($<<B)-ha)|0]|0)|0,C)|0)+_d|0;if((ga|0)>=(Ra|0)){Xd=Ra;Yd=La;Zd=Ma;break}c[V>>2]=$;c[(V+4|0)>>2]=ja;Xd=ga;Yd=ja;Zd=$}}while(0);$=Qa+1|0;if(($|0)<8){Qa=$;Ra=Xd;La=Yd;Ma=Zd}else{break}}if((Zd|0)==(ma|0)&(Yd|0)==(T|0)){break}else{Ga=Xd;T=Yd;ma=Zd}}Ga=(U+255&(U&255)|0)!=0?aa-1|0:aa>>1;if((Ga|0)==0){Td=Xd;Ud=ma;Vd=T;Wd=V+4|0;break}else{aa=Ga;S=Xd;Q=T;za=ma}}}za=Ud+1|0;Q=(za|0)>(Z|0)?Z:za;za=(la|0)>(Q|0)?la:Q;Q=(Vd|0)>(pa|0)?pa:Vd;S=(X|0)>(Q|0)?X:Q;do{if((c[(O+((za+(S<<3)&63)<<2)|0)>>2]|0)==(((S<<11)+sa|0)+za|0|0)){de=Td}else{do{if((p&4|0)==0){Q=c[f+12416>>2]|0;aa=c[f+12420>>2]|0;oa=(c[f+12352+(k<<4)>>2]|0)+((ba(Q,S)|0)+za)|0;Ga=Pe[_&255](f,c[f+12288+(j<<4)>>2]|0,oa,Q,o)|0;if((p&2|0)==0){ee=Ga;break}oa=c[f+12208>>2]|0;Ma=(ba(aa,S>>1)|0)+(za>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za&1|S<<1&2)<<2)>>2]&1023](oa+(Q<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+Ma|0,aa,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za&1|S<<1&2)<<2)>>2]&1023](oa+(Q<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+Ma|0,aa,o>>1);Ma=(Pe[fa&255](f,oa+(Q<<4)|0,c[f+12288+(j<<4)+4>>2]|0,aa,o>>1)|0)+Ga|0;ee=Ma+(Pe[fa&255](f,oa+(Q<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,aa,o>>1)|0)|0}else{aa=c[f+12416>>2]|0;if((c[(f+12264|0)>>2]|0)>(za|0)){ee=536870912;break}if((za<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ee=536870912;break}if((c[(f+12272|0)>>2]|0)>(S|0)){ee=536870912;break}if((S<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ee=536870912;break}Q=e[f+13872>>1]|0;oa=e[f+13874>>1]|0;Ma=(p&1)<<1|1;y:do{if((c[f+11740>>2]|0)==1){if((za<<B|0)==0){Ga=0;while(1){La=c[f+12160+(Ga<<3)>>2]|0;Ra=(c[f+12160+(Ga<<3)+4>>2]|0)+(S<<B)|0;Qa=((ba(c[f+12128+(Ga<<3)>>2]|0,oa-Q|0)|0)/(Q|0)|0)+((Ga&1)<<(p&1|4))|0;$=c[f+12128+(Ga<<3)+4>>2]|0;if((S<<B|0)==0){ja=Ga>>1;fe=((ba($,oa-Q|0)|0)/(Q|0)|0)+(ja<<(p&1|4))|0;ge=ja}else{fe=Ra-$|0;ge=Ga>>1}$=((fe&Ma)<<B)+(Qa&Ma)|0;ja=(c[(f+12208|0)>>2]|0)+((ba(ge,aa<<3)|0)+(Ga<<3&8))|0;if((p&1|0)==0){ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ra>>1,aa)|0)+(La>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ra&Ma)<<B)+(La&Ma)|0)<<2)>>2]&1023](ja,ga,aa,8);ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(fe>>1,aa)|0)+(Qa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+($<<2)>>2]&1023](ja,ga,aa,8)}else{ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ra>>2,aa)|0)+(La>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ra&Ma)<<B)+(La&Ma)|0)<<2)>>2]&4095](ja,ga,aa);ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(fe>>2,aa)|0)+(Qa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+($<<2)>>2]&4095](ja,ga,aa)}Ga=Ga+1|0;if((Ga|0)>=4){break y}}}if((S<<B|0)==0){Ga=0;do{ga=(c[f+12160+(Ga<<3)>>2]|0)+(za<<B)|0;ja=c[f+12160+(Ga<<3)+4>>2]|0;$=ga-(c[f+12128+(Ga<<3)>>2]|0)|0;Qa=Ga>>1;La=((ba(c[f+12128+(Ga<<3)+4>>2]|0,oa-Q|0)|0)/(Q|0)|0)+(Qa<<(p&1|4))|0;Ra=(c[(f+12208|0)>>2]|0)+((Ga<<3&8)+(ba(Qa,aa<<3)|0))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>1,aa)|0)+(ga>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ja&Ma)<<B)+(ga&Ma)|0)<<2)>>2]&1023](Ra,Qa,aa,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(La>>1,aa)|0)+($>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((La&Ma)<<B)+($&Ma)|0)<<2)>>2]&1023](Ra,Qa,aa,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>2,aa)|0)+(ga>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(ga&Ma)|0)<<2)>>2]&4095](Ra,Qa,aa);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(La>>2,aa)|0)+($>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((La&Ma)<<B)+($&Ma)|0)<<2)>>2]&4095](Ra,Qa,aa)}Ga=Ga+1|0;}while((Ga|0)<4)}else{Ga=0;do{Qa=(c[f+12160+(Ga<<3)>>2]|0)+(za<<B)|0;Ra=(c[f+12160+(Ga<<3)+4>>2]|0)+(S<<B)|0;$=Qa-(c[f+12128+(Ga<<3)>>2]|0)|0;La=Ra-(c[f+12128+(Ga<<3)+4>>2]|0)|0;ga=(c[(f+12208|0)>>2]|0)+((Ga<<3&8)+(ba(Ga>>1,aa<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ra>>1,aa)|0)+(Qa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ra&Ma)<<B)+(Qa&Ma)|0)<<2)>>2]&1023](ga,ja,aa,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(La>>1,aa)|0)+($>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((La&Ma)<<B)+($&Ma)|0)<<2)>>2]&1023](ga,ja,aa,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ra>>2,aa)|0)+(Qa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ra&Ma)<<B)+(Qa&Ma)|0)<<2)>>2]&4095](ga,ja,aa);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(La>>2,aa)|0)+($>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((La&Ma)<<B)+($&Ma)|0)<<2)>>2]&4095](ga,ja,aa)}Ga=Ga+1|0;}while((Ga|0)<4)}}else{Ga=(c[f+12160>>2]|0)+(za<<B)|0;ja=(c[f+12164>>2]|0)+(S<<B)|0;ga=c[f+12128>>2]|0;if((za<<B|0)==0){he=(ba(ga,oa-Q|0)|0)/(Q|0)|0}else{he=Ga-ga|0}ga=c[f+12132>>2]|0;if((S<<B|0)==0){ie=(ba(ga,oa-Q|0)|0)/(Q|0)|0}else{ie=ja-ga|0}ga=((ie&Ma)<<B)+(he&Ma)|0;if((p&1|0)==0){$=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>1,aa)|0)+(Ga>>1))|0;cf[c[(c[f+12444>>2]|0)+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,$,aa,16);$=(c[f+12352+(k<<4)+32>>2]|0)+((ba(ie>>1,aa)|0)+(he>>1))|0;cf[c[(c[f+12448>>2]|0)+(ga<<2)>>2]&1023](c[(f+12208|0)>>2]|0,$,aa,16);break}else{$=(ba(ja>>2,aa)|0)+(Ga>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+$|0,aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+($+8|0)|0,aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+($+(aa<<3))|0,aa);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(($+8|0)+(aa<<3))|0,aa);$=(ba(ie>>2,aa)|0)+(he>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+$|0,aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+($+8|0)|0,aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+($+(aa<<3))|0,aa);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(($+8|0)+(aa<<3))|0,aa);break}}}while(0);ee=Pe[_&255](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,aa,16)|0}}while(0);c[(O+((za+(S<<3)&63)<<2)|0)>>2]=((S<<11)+sa|0)+za|0;c[Za+((za+(S<<3)&63)<<2)>>2]=ee;ma=(ba((d[Fa+((S<<B)-Y)|0]|0)+(d[Fa+((za<<B)-ha)|0]|0)|0,C)|0)+ee|0;if((ma|0)>=(Td|0)){de=Td;break}c[V>>2]=za;c[Wd>>2]=S;de=ma}}while(0);za=Vd+1|0;ma=(Ud|0)>(Z|0)?Z:Ud;T=(la|0)>(ma|0)?la:ma;ma=(za|0)>(pa|0)?pa:za;za=(X|0)>(ma|0)?X:ma;do{if((c[(O+(((za<<3)+T&63)<<2)|0)>>2]|0)==((T+sa|0)+(za<<11)|0|0)){je=de}else{do{if((p&4|0)==0){ma=c[f+12416>>2]|0;Ma=c[f+12420>>2]|0;Q=(c[f+12352+(k<<4)>>2]|0)+((ba(ma,za)|0)+T)|0;oa=Pe[_&255](f,c[f+12288+(j<<4)>>2]|0,Q,ma,o)|0;if((p&2|0)==0){ke=oa;break}Q=c[f+12208>>2]|0;$=(ba(Ma,za>>1)|0)+(T>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za<<1&2|T&1)<<2)>>2]&1023](Q+(ma<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+$|0,Ma,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za<<1&2|T&1)<<2)>>2]&1023](Q+(ma<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+$|0,Ma,o>>1);$=(Pe[fa&255](f,Q+(ma<<4)|0,c[f+12288+(j<<4)+4>>2]|0,Ma,o>>1)|0)+oa|0;ke=$+(Pe[fa&255](f,Q+(ma<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,Ma,o>>1)|0)|0}else{Ma=c[f+12416>>2]|0;if((c[(f+12264|0)>>2]|0)>(T|0)){ke=536870912;break}if((T<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ke=536870912;break}if((c[(f+12272|0)>>2]|0)>(za|0)){ke=536870912;break}if((za<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ke=536870912;break}ma=e[f+13872>>1]|0;Q=e[f+13874>>1]|0;$=(p&1)<<1|1;z:do{if((c[f+11740>>2]|0)==1){if((T<<B|0)==0){oa=0;while(1){ga=c[f+12160+(oa<<3)>>2]|0;Ga=(c[f+12160+(oa<<3)+4>>2]|0)+(za<<B)|0;ja=((ba(c[f+12128+(oa<<3)>>2]|0,Q-ma|0)|0)/(ma|0)|0)+((oa&1)<<(p&1|4))|0;La=c[f+12128+(oa<<3)+4>>2]|0;if((za<<B|0)==0){Qa=oa>>1;le=((ba(La,Q-ma|0)|0)/(ma|0)|0)+(Qa<<(p&1|4))|0;me=Qa}else{le=Ga-La|0;me=oa>>1}La=((le&$)<<B)+(ja&$)|0;Qa=(c[(f+12208|0)>>2]|0)+((ba(me,Ma<<3)|0)+(oa<<3&8))|0;if((p&1|0)==0){Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ga>>1,Ma)|0)+(ga>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ga&$)<<B)+(ga&$)|0)<<2)>>2]&1023](Qa,Ra,Ma,8);Ra=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(le>>1,Ma)|0)+(ja>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(La<<2)>>2]&1023](Qa,Ra,Ma,8)}else{Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ga>>2,Ma)|0)+(ga>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ga&$)<<B)+(ga&$)|0)<<2)>>2]&4095](Qa,Ra,Ma);Ra=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(le>>2,Ma)|0)+(ja>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(La<<2)>>2]&4095](Qa,Ra,Ma)}oa=oa+1|0;if((oa|0)>=4){break z}}}if((za<<B|0)==0){oa=0;do{Ra=(c[f+12160+(oa<<3)>>2]|0)+(T<<B)|0;Qa=c[f+12160+(oa<<3)+4>>2]|0;La=Ra-(c[f+12128+(oa<<3)>>2]|0)|0;ja=oa>>1;ga=((ba(c[f+12128+(oa<<3)+4>>2]|0,Q-ma|0)|0)/(ma|0)|0)+(ja<<(p&1|4))|0;Ga=(c[(f+12208|0)>>2]|0)+((oa<<3&8)+(ba(ja,Ma<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa>>1,Ma)|0)+(Ra>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Qa&$)<<B)+(Ra&$)|0)<<2)>>2]&1023](Ga,ja,Ma,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>1,Ma)|0)+(La>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&$)<<B)+(La&$)|0)<<2)>>2]&1023](Ga,ja,Ma,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa>>2,Ma)|0)+(Ra>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(Ra&$)|0)<<2)>>2]&4095](Ga,ja,Ma);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>2,Ma)|0)+(La>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ga&$)<<B)+(La&$)|0)<<2)>>2]&4095](Ga,ja,Ma)}oa=oa+1|0;}while((oa|0)<4)}else{oa=0;do{ja=(c[f+12160+(oa<<3)>>2]|0)+(T<<B)|0;Ga=(c[f+12160+(oa<<3)+4>>2]|0)+(za<<B)|0;La=ja-(c[f+12128+(oa<<3)>>2]|0)|0;ga=Ga-(c[f+12128+(oa<<3)+4>>2]|0)|0;Ra=(c[(f+12208|0)>>2]|0)+((oa<<3&8)+(ba(oa>>1,Ma<<3)|0))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ga>>1,Ma)|0)+(ja>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ga&$)<<B)+(ja&$)|0)<<2)>>2]&1023](Ra,Qa,Ma,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>1,Ma)|0)+(La>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&$)<<B)+(La&$)|0)<<2)>>2]&1023](Ra,Qa,Ma,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ga>>2,Ma)|0)+(ja>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ga&$)<<B)+(ja&$)|0)<<2)>>2]&4095](Ra,Qa,Ma);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>2,Ma)|0)+(La>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ga&$)<<B)+(La&$)|0)<<2)>>2]&4095](Ra,Qa,Ma)}oa=oa+1|0;}while((oa|0)<4)}}else{oa=(c[f+12160>>2]|0)+(T<<B)|0;Qa=(c[f+12164>>2]|0)+(za<<B)|0;Ra=c[f+12128>>2]|0;if((T<<B|0)==0){ne=(ba(Ra,Q-ma|0)|0)/(ma|0)|0}else{ne=oa-Ra|0}Ra=c[f+12132>>2]|0;if((za<<B|0)==0){oe=(ba(Ra,Q-ma|0)|0)/(ma|0)|0}else{oe=Qa-Ra|0}Ra=((oe&$)<<B)+(ne&$)|0;if((p&1|0)==0){La=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Qa>>1,Ma)|0)+(oa>>1))|0;cf[c[(c[f+12444>>2]|0)+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,La,Ma,16);La=(c[f+12352+(k<<4)+32>>2]|0)+((ba(oe>>1,Ma)|0)+(ne>>1))|0;cf[c[(c[f+12448>>2]|0)+(Ra<<2)>>2]&1023](c[(f+12208|0)>>2]|0,La,Ma,16);break}else{La=(ba(Qa>>2,Ma)|0)+(oa>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+La|0,Ma);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(La+8|0)|0,Ma);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ma<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(La+(Ma<<3))|0,Ma);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ma<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((La+8|0)+(Ma<<3))|0,Ma);La=(ba(oe>>2,Ma)|0)+(ne>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ra<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+La|0,Ma);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ra<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(La+8|0)|0,Ma);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ra<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ma<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(La+(Ma<<3))|0,Ma);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ra<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ma<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((La+8|0)+(Ma<<3))|0,Ma);break}}}while(0);ke=Pe[_&255](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Ma,16)|0}}while(0);c[(O+(((za<<3)+T&63)<<2)|0)>>2]=(T+sa|0)+(za<<11)|0;c[Za+(((za<<3)+T&63)<<2)>>2]=ke;$=(ba((d[Fa+((za<<B)-Y)|0]|0)+(d[Fa+((T<<B)-ha)|0]|0)|0,C)|0)+ke|0;if(($|0)>=(de|0)){je=de;break}c[V>>2]=T;c[Wd>>2]=za;je=$}}while(0);za=Ud-1|0;$=(za|0)>(Z|0)?Z:za;za=(la|0)>($|0)?la:$;do{if((c[(O+((za+(S<<3)&63)<<2)|0)>>2]|0)==(((S<<11)+sa|0)+za|0|0)){pe=je}else{do{if((p&4|0)==0){$=c[f+12416>>2]|0;ma=c[f+12420>>2]|0;Q=(c[f+12352+(k<<4)>>2]|0)+((ba($,S)|0)+za)|0;aa=Pe[_&255](f,c[f+12288+(j<<4)>>2]|0,Q,$,o)|0;if((p&2|0)==0){qe=aa;break}Q=c[f+12208>>2]|0;La=(ba(ma,S>>1)|0)+(za>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za&1|S<<1&2)<<2)>>2]&1023](Q+($<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+La|0,ma,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za&1|S<<1&2)<<2)>>2]&1023](Q+($<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+La|0,ma,o>>1);La=(Pe[fa&255](f,Q+($<<4)|0,c[f+12288+(j<<4)+4>>2]|0,ma,o>>1)|0)+aa|0;qe=La+(Pe[fa&255](f,Q+($<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,ma,o>>1)|0)|0}else{ma=c[f+12416>>2]|0;if((c[(f+12264|0)>>2]|0)>(za|0)){qe=536870912;break}if((za<<B|0)>(c[(f+12268|0)>>2]<<B|0)){qe=536870912;break}if((c[(f+12272|0)>>2]|0)>(S|0)){qe=536870912;break}if((S<<B|0)>(c[(f+12276|0)>>2]<<B|0)){qe=536870912;break}$=e[f+13872>>1]|0;Q=e[f+13874>>1]|0;La=(p&1)<<1|1;A:do{if((c[f+11740>>2]|0)==1){if((za<<B|0)==0){aa=0;while(1){Ra=c[f+12160+(aa<<3)>>2]|0;oa=(c[f+12160+(aa<<3)+4>>2]|0)+(S<<B)|0;Qa=((ba(c[f+12128+(aa<<3)>>2]|0,Q-$|0)|0)/($|0)|0)+((aa&1)<<(p&1|4))|0;ga=c[f+12128+(aa<<3)+4>>2]|0;if((S<<B|0)==0){ja=aa>>1;re=((ba(ga,Q-$|0)|0)/($|0)|0)+(ja<<(p&1|4))|0;se=ja}else{re=oa-ga|0;se=aa>>1}ga=((re&La)<<B)+(Qa&La)|0;ja=(c[(f+12208|0)>>2]|0)+((ba(se,ma<<3)|0)+(aa<<3&8))|0;if((p&1|0)==0){Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(oa>>1,ma)|0)+(Ra>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((oa&La)<<B)+(Ra&La)|0)<<2)>>2]&1023](ja,Ga,ma,8);Ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(re>>1,ma)|0)+(Qa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(ga<<2)>>2]&1023](ja,Ga,ma,8)}else{Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(oa>>2,ma)|0)+(Ra>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((oa&La)<<B)+(Ra&La)|0)<<2)>>2]&4095](ja,Ga,ma);Ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(re>>2,ma)|0)+(Qa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](ja,Ga,ma)}aa=aa+1|0;if((aa|0)>=4){break A}}}if((S<<B|0)==0){aa=0;do{Ga=(c[f+12160+(aa<<3)>>2]|0)+(za<<B)|0;ja=c[f+12160+(aa<<3)+4>>2]|0;ga=Ga-(c[f+12128+(aa<<3)>>2]|0)|0;Qa=aa>>1;Ra=((ba(c[f+12128+(aa<<3)+4>>2]|0,Q-$|0)|0)/($|0)|0)+(Qa<<(p&1|4))|0;oa=(c[(f+12208|0)>>2]|0)+((aa<<3&8)+(ba(Qa,ma<<3)|0))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>1,ma)|0)+(Ga>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ja&La)<<B)+(Ga&La)|0)<<2)>>2]&1023](oa,Qa,ma,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ra>>1,ma)|0)+(ga>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ra&La)<<B)+(ga&La)|0)<<2)>>2]&1023](oa,Qa,ma,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>2,ma)|0)+(Ga>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(Ga&La)|0)<<2)>>2]&4095](oa,Qa,ma);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ra>>2,ma)|0)+(ga>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ra&La)<<B)+(ga&La)|0)<<2)>>2]&4095](oa,Qa,ma)}aa=aa+1|0;}while((aa|0)<4)}else{aa=0;do{Qa=(c[f+12160+(aa<<3)>>2]|0)+(za<<B)|0;oa=(c[f+12160+(aa<<3)+4>>2]|0)+(S<<B)|0;ga=Qa-(c[f+12128+(aa<<3)>>2]|0)|0;Ra=oa-(c[f+12128+(aa<<3)+4>>2]|0)|0;Ga=(c[(f+12208|0)>>2]|0)+((aa<<3&8)+(ba(aa>>1,ma<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(oa>>1,ma)|0)+(Qa>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((oa&La)<<B)+(Qa&La)|0)<<2)>>2]&1023](Ga,ja,ma,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ra>>1,ma)|0)+(ga>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((Ra&La)<<B)+(ga&La)|0)<<2)>>2]&1023](Ga,ja,ma,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(oa>>2,ma)|0)+(Qa>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((oa&La)<<B)+(Qa&La)|0)<<2)>>2]&4095](Ga,ja,ma);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(Ra>>2,ma)|0)+(ga>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((Ra&La)<<B)+(ga&La)|0)<<2)>>2]&4095](Ga,ja,ma)}aa=aa+1|0;}while((aa|0)<4)}}else{aa=(c[f+12160>>2]|0)+(za<<B)|0;ja=(c[f+12164>>2]|0)+(S<<B)|0;Ga=c[f+12128>>2]|0;if((za<<B|0)==0){te=(ba(Ga,Q-$|0)|0)/($|0)|0}else{te=aa-Ga|0}Ga=c[f+12132>>2]|0;if((S<<B|0)==0){ue=(ba(Ga,Q-$|0)|0)/($|0)|0}else{ue=ja-Ga|0}Ga=((ue&La)<<B)+(te&La)|0;if((p&1|0)==0){ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>1,ma)|0)+(aa>>1))|0;cf[c[(c[f+12444>>2]|0)+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,ga,ma,16);ga=(c[f+12352+(k<<4)+32>>2]|0)+((ba(ue>>1,ma)|0)+(te>>1))|0;cf[c[(c[f+12448>>2]|0)+(Ga<<2)>>2]&1023](c[(f+12208|0)>>2]|0,ga,ma,16);break}else{ga=(ba(ja>>2,ma)|0)+(aa>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+ga|0,ma);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(ga+8|0)|0,ma);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ma<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(ga+(ma<<3))|0,ma);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((ga+8|0)+(ma<<3))|0,ma);ga=(ba(ue>>2,ma)|0)+(te>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+ga|0,ma);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(ga+8|0)|0,ma);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ma<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(ga+(ma<<3))|0,ma);Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ga+8|0)+(ma<<3))|0,ma);break}}}while(0);qe=Pe[_&255](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(O+((za+(S<<3)&63)<<2)|0)>>2]=((S<<11)+sa|0)+za|0;c[Za+((za+(S<<3)&63)<<2)>>2]=qe;La=(ba((d[Fa+((S<<B)-Y)|0]|0)+(d[Fa+((za<<B)-ha)|0]|0)|0,C)|0)+qe|0;if((La|0)>=(je|0)){pe=je;break}c[V>>2]=za;c[Wd>>2]=S;pe=La}}while(0);S=Vd-1|0;za=(S|0)>(pa|0)?pa:S;S=(X|0)>(za|0)?X:za;if((c[(O+(((S<<3)+T&63)<<2)|0)>>2]|0)==((T+sa|0)+(S<<11)|0|0)){Bb=pe;break}do{if((p&4|0)==0){za=c[f+12416>>2]|0;la=c[f+12420>>2]|0;Z=(c[f+12352+(k<<4)>>2]|0)+((ba(za,S)|0)+T)|0;La=Pe[_&255](f,c[f+12288+(j<<4)>>2]|0,Z,za,o)|0;if((p&2|0)==0){ve=La;break}Z=c[f+12208>>2]|0;$=(ba(la,S>>1)|0)+(T>>1)|0;cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((S<<1&2|T&1)<<2)>>2]&1023](Z+(za<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+$|0,la,o>>1);cf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((S<<1&2|T&1)<<2)>>2]&1023](Z+(za<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+$|0,la,o>>1);$=(Pe[fa&255](f,Z+(za<<4)|0,c[f+12288+(j<<4)+4>>2]|0,la,o>>1)|0)+La|0;ve=$+(Pe[fa&255](f,Z+(za<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,la,o>>1)|0)|0}else{la=c[f+12416>>2]|0;if((c[(f+12264|0)>>2]|0)>(T|0)){ve=536870912;break}if((T<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ve=536870912;break}if((c[(f+12272|0)>>2]|0)>(S|0)){ve=536870912;break}if((S<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ve=536870912;break}za=e[f+13872>>1]|0;Z=e[f+13874>>1]|0;$=(p&1)<<1|1;B:do{if((c[f+11740>>2]|0)==1){if((T<<B|0)==0){La=0;while(1){Q=c[f+12160+(La<<3)>>2]|0;Ma=(c[f+12160+(La<<3)+4>>2]|0)+(S<<B)|0;ga=((ba(c[f+12128+(La<<3)>>2]|0,Z-za|0)|0)/(za|0)|0)+((La&1)<<(p&1|4))|0;Ga=c[f+12128+(La<<3)+4>>2]|0;if((S<<B|0)==0){aa=La>>1;we=((ba(Ga,Z-za|0)|0)/(za|0)|0)+(aa<<(p&1|4))|0;xe=aa}else{we=Ma-Ga|0;xe=La>>1}Ga=((we&$)<<B)+(ga&$)|0;aa=(c[(f+12208|0)>>2]|0)+((ba(xe,la<<3)|0)+(La<<3&8))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ma>>1,la)|0)+(Q>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Ma&$)<<B)+(Q&$)|0)<<2)>>2]&1023](aa,ja,la,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(we>>1,la)|0)+(ga>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+(Ga<<2)>>2]&1023](aa,ja,la,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Ma>>2,la)|0)+(Q>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Ma&$)<<B)+(Q&$)|0)<<2)>>2]&4095](aa,ja,la);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(we>>2,la)|0)+(ga>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095](aa,ja,la)}La=La+1|0;if((La|0)>=4){break B}}}if((S<<B|0)==0){La=0;do{ma=(c[f+12160+(La<<3)>>2]|0)+(T<<B)|0;ja=c[f+12160+(La<<3)+4>>2]|0;aa=ma-(c[f+12128+(La<<3)>>2]|0)|0;Ga=La>>1;ga=((ba(c[f+12128+(La<<3)+4>>2]|0,Z-za|0)|0)/(za|0)|0)+(Ga<<(p&1|4))|0;Q=(c[(f+12208|0)>>2]|0)+((La<<3&8)+(ba(Ga,la<<3)|0))|0;if((p&1|0)==0){Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>1,la)|0)+(ma>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((ja&$)<<B)+(ma&$)|0)<<2)>>2]&1023](Q,Ga,la,8);Ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>1,la)|0)+(aa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&$)<<B)+(aa&$)|0)<<2)>>2]&1023](Q,Ga,la,8)}else{Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>2,la)|0)+(ma>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(ma&$)|0)<<2)>>2]&4095](Q,Ga,la);Ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>2,la)|0)+(aa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ga&$)<<B)+(aa&$)|0)<<2)>>2]&4095](Q,Ga,la)}La=La+1|0;}while((La|0)<4)}else{La=0;do{Ga=(c[f+12160+(La<<3)>>2]|0)+(T<<B)|0;Q=(c[f+12160+(La<<3)+4>>2]|0)+(S<<B)|0;aa=Ga-(c[f+12128+(La<<3)>>2]|0)|0;ga=Q-(c[f+12128+(La<<3)+4>>2]|0)|0;ma=(c[(f+12208|0)>>2]|0)+((La<<3&8)+(ba(La>>1,la<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Q>>1,la)|0)+(Ga>>1))|0;cf[c[(c[(f+12444|0)>>2]|0)+16+((((Q&$)<<B)+(Ga&$)|0)<<2)>>2]&1023](ma,ja,la,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>1,la)|0)+(aa>>1))|0;cf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&$)<<B)+(aa&$)|0)<<2)>>2]&1023](ma,ja,la,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(Q>>2,la)|0)+(Ga>>2))|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((Q&$)<<B)+(Ga&$)|0)<<2)>>2]&4095](ma,ja,la);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ba(ga>>2,la)|0)+(aa>>2))|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+((((ga&$)<<B)+(aa&$)|0)<<2)>>2]&4095](ma,ja,la)}La=La+1|0;}while((La|0)<4)}}else{La=(c[f+12160>>2]|0)+(T<<B)|0;ja=(c[f+12164>>2]|0)+(S<<B)|0;ma=c[f+12128>>2]|0;if((T<<B|0)==0){ye=(ba(ma,Z-za|0)|0)/(za|0)|0}else{ye=La-ma|0}ma=c[f+12132>>2]|0;if((S<<B|0)==0){ze=(ba(ma,Z-za|0)|0)/(za|0)|0}else{ze=ja-ma|0}ma=((ze&$)<<B)+(ye&$)|0;if((p&1|0)==0){aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ba(ja>>1,la)|0)+(La>>1))|0;cf[c[(c[f+12444>>2]|0)+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&1023](c[(f+12208|0)>>2]|0,aa,la,16);aa=(c[f+12352+(k<<4)+32>>2]|0)+((ba(ze>>1,la)|0)+(ye>>1))|0;cf[c[(c[f+12448>>2]|0)+(ma<<2)>>2]&1023](c[(f+12208|0)>>2]|0,aa,la,16);break}else{aa=(ba(ja>>2,la)|0)+(La>>2)|0;Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+aa|0,la);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(aa+8|0)|0,la);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(la<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(aa+(la<<3))|0,la);Xe[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((la<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((aa+8|0)+(la<<3))|0,la);aa=(ba(ze>>2,la)|0)+(ye>>2)|0;Xe[c[(c[(f+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+aa|0,la);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(aa+8|0)|0,la);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(la<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(aa+(la<<3))|0,la);Xe[c[(c[(f+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((la<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((aa+8|0)+(la<<3))|0,la);break}}}while(0);ve=Pe[_&255](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,la,16)|0}}while(0);c[(O+(((S<<3)+T&63)<<2)|0)>>2]=(T+sa|0)+(S<<11)|0;c[Za+(((S<<3)+T&63)<<2)>>2]=ve;_=(ba((d[Fa+((S<<B)-Y)|0]|0)+(d[Fa+((T<<B)-ha)|0]|0)|0,C)|0)+ve|0;if((_|0)>=(pe|0)){Bb=pe;break}c[V>>2]=T;c[Wd>>2]=S;Bb=_}else{R=1}}}while(0);c[g>>2]=c[V>>2];c[h>>2]=c[q+4>>2];K=Bb;i=a;c[a+27640>>2]=6;c[a+27644>>2]=K|0;break a}while(0);c[a+27600>>2]=K}



function Awb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;y=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ba((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ba((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ba(c[p>>2]|0,y)|0;z=ba(c[q>>2]|0,y)|0;y=(ba(c[r>>2]|0,w)|0)+z|0;z=ba(c[s>>2]|0,w)|0;w=bFb(41)|0;if((w|0)==0){D=5;break}v=A+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=de(E|0)|0}x=F;a[u]=x;x=x>>8;a[u+1|0]=x;w=bFb(41)|0;if((w|0)==0){D=11;break}v=y+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;x=G;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+2|0;x=de(G|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(41)|0;if((w|0)==0){D=18;break}v=z+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;x=H;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+4|0;x=de(H|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(41)|0;if((w|0)==0){D=25;break}v=A+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+6|0;x=I;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+6|0;x=de(I|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(41)|0;if((w|0)==0){D=32;break}v=y+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;x=J;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+8|0;x=de(J|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(41)|0;if((w|0)==0){D=39;break}v=z+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;x=K;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+10|0;x=de(K|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=t+1|0;if((w|0)<(k|0)){t=w;u=u+12|0}else{D=90;break}}if((D|0)==5){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==11){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==18){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==25){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==32){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==39){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==90){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ba((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ba((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ba(c[k>>2]|0,F)|0;E=ba(c[K>>2]|0,F)|0;F=(ba(c[J>>2]|0,G)|0)+E|0;E=ba(c[I>>2]|0,G)|0;G=bFb(41)|0;if((G|0)==0){D=49;break}d=s+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[H]=x;x=x>>8;a[H+1|0]=x;G=bFb(41)|0;if((G|0)==0){D=55;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;x=O;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+2|0;x=de(O|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(41)|0;if((G|0)==0){D=62;break}d=E+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;x=P;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+4|0;x=de(P|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(41)|0;if((G|0)==0){D=69;break}d=s+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+6|0;x=Q;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+6|0;x=de(Q|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(41)|0;if((G|0)==0){D=76;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;x=R;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+8|0;x=de(R|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(41)|0;if((G|0)==0){D=83;break}d=E+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;x=S;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+10|0;x=de(S|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=b+1|0;if((G|0)<(f|0)){b=G;H=H+12|0}else{D=90;break}}if((D|0)==49){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==55){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==62){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==69){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==76){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==83){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==90){i=l;return}}}function Bwb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;y=h;while(1){h=b<<1;z=ba(c[g+(h<<2)>>2]|0,f)|0;A=(ba(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ba(c[g+(z<<2)>>2]|0,f)|0;B=(ba(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ba(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ba(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ba(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ba(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ba(A-h|0,D)|0)+8192|0;A=(ba(B-h|0,D)|0)+8192|0;D=ba(C,c[t>>2]|0)|0;h=ba(c[u>>2]|0,C)|0;C=(ba(c[v>>2]|0,z)|0)+h|0;h=ba(c[w>>2]|0,z)|0;z=bFb(41)|0;if((z|0)==0){F=4;break}B=D+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=de(G|0)|0}x=H;a[y]=x;x=x>>8;a[y+1|0]=x;z=bFb(41)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+2|0;x=I;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+2|0;x=de(I|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(41)|0;if((z|0)==0){F=17;break}B=h+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+4|0;x=J;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+4|0;x=de(J|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(41)|0;if((z|0)==0){F=24;break}B=D+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+6|0;x=K;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+6|0;x=de(K|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(41)|0;if((z|0)==0){F=31;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+8|0;x=L;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+8|0;x=de(L|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(41)|0;if((z|0)==0){F=38;break}B=h+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+10|0;x=M;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+10|0;x=de(M|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=b+1|0;if((z|0)<(r|0)){b=z;y=y+12|0}else{F=45;break}}if((F|0)==4){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==10){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==17){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==24){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==31){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==38){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==45){i=m;return}}function Cwb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;y=n;while(1){if(o){n=d<<1;z=n|1;A=-1073741824;B=-1073741824;C=0;do{D=c[f+(C<<2)>>2]|0;E=b[e+(C<<1)>>1]|0;A=(ba(E,c[D+(n<<2)>>2]|0)|0)+A|0;B=(ba(c[D+(z<<2)>>2]|0,E)|0)+B|0;C=C+1|0;}while((C|0)<(g|0));F=(A>>14)+65536|0;G=(B>>14)+65536|0}else{F=0;G=0}if(q){C=-1073741824;z=-1073741824;n=0;do{E=b[h+(n<<1)>>1]|0;C=(ba(E,c[(c[j+(n<<2)>>2]|0)+(d<<2)>>2]|0)|0)+C|0;z=(ba(c[(c[k+(n<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+z|0;n=n+1|0;}while((n|0)<(l|0));H=C>>14;I=z>>14}else{H=-65536;I=-65536}n=c[r>>2]|0;B=c[s>>2]|0;A=(ba(F-n|0,B)|0)+8192|0;E=(ba(G-n|0,B)|0)+8192|0;B=ba(c[t>>2]|0,I)|0;n=ba(c[u>>2]|0,I)|0;D=(ba(c[v>>2]|0,H)|0)+n|0;n=ba(c[w>>2]|0,H)|0;J=bFb(41)|0;if((J|0)==0){K=11;break}L=B+A|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[y]=x;x=x>>8;a[y+1|0]=x;J=bFb(41)|0;if((J|0)==0){K=17;break}L=D+A|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+2|0;x=O;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+2|0;x=de(O|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(41)|0;if((J|0)==0){K=24;break}L=n+A|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+4|0;x=P;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+4|0;x=de(P|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(41)|0;if((J|0)==0){K=31;break}L=B+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+6|0;x=Q;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+6|0;x=de(Q|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(41)|0;if((J|0)==0){K=38;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+8|0;x=R;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+8|0;x=de(R|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(41)|0;if((J|0)==0){K=45;break}L=n+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+10|0;x=S;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+10|0;x=de(S|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=d+1|0;if((J|0)<(m|0)){d=J;y=y+12|0}else{K=52;break}}if((K|0)==11){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==17){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==24){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==31){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==38){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==45){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==52){i=p;return}}function Dwb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;y=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ba((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ba((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ba(c[p>>2]|0,y)|0;z=ba(c[q>>2]|0,y)|0;y=(ba(c[r>>2]|0,w)|0)+z|0;z=ba(c[s>>2]|0,w)|0;w=bFb(68)|0;if((w|0)==0){D=5;break}v=z+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=de(E|0)|0}x=F;a[u]=x;x=x>>8;a[u+1|0]=x;w=bFb(68)|0;if((w|0)==0){D=11;break}v=y+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;x=G;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+2|0;x=de(G|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(68)|0;if((w|0)==0){D=18;break}v=A+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;x=H;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+4|0;x=de(H|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(68)|0;if((w|0)==0){D=25;break}v=z+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+6|0;x=I;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+6|0;x=de(I|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(68)|0;if((w|0)==0){D=32;break}v=y+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;x=J;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+8|0;x=de(J|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(68)|0;if((w|0)==0){D=39;break}v=A+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;x=K;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+10|0;x=de(K|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=t+1|0;if((w|0)<(k|0)){t=w;u=u+12|0}else{D=90;break}}if((D|0)==5){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==11){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==18){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==25){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==32){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==39){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==90){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ba((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ba((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ba(c[k>>2]|0,F)|0;E=ba(c[K>>2]|0,F)|0;F=(ba(c[J>>2]|0,G)|0)+E|0;E=ba(c[I>>2]|0,G)|0;G=bFb(68)|0;if((G|0)==0){D=49;break}d=E+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[H]=x;x=x>>8;a[H+1|0]=x;G=bFb(68)|0;if((G|0)==0){D=55;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;x=O;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+2|0;x=de(O|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(68)|0;if((G|0)==0){D=62;break}d=s+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;x=P;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+4|0;x=de(P|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(68)|0;if((G|0)==0){D=69;break}d=E+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+6|0;x=Q;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+6|0;x=de(Q|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(68)|0;if((G|0)==0){D=76;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;x=R;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+8|0;x=de(R|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(68)|0;if((G|0)==0){D=83;break}d=s+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;x=S;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+10|0;x=de(S|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=b+1|0;if((G|0)<(f|0)){b=G;H=H+12|0}else{D=90;break}}if((D|0)==49){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==55){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==62){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==69){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==76){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==83){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==90){i=l;return}}}function Ewb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;y=h;while(1){h=b<<1;z=ba(c[g+(h<<2)>>2]|0,f)|0;A=(ba(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ba(c[g+(z<<2)>>2]|0,f)|0;B=(ba(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ba(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ba(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ba(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ba(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ba(A-h|0,D)|0)+8192|0;A=(ba(B-h|0,D)|0)+8192|0;D=ba(C,c[t>>2]|0)|0;h=ba(c[u>>2]|0,C)|0;C=(ba(c[v>>2]|0,z)|0)+h|0;h=ba(c[w>>2]|0,z)|0;z=bFb(68)|0;if((z|0)==0){F=4;break}B=h+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=de(G|0)|0}x=H;a[y]=x;x=x>>8;a[y+1|0]=x;z=bFb(68)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+2|0;x=I;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+2|0;x=de(I|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(68)|0;if((z|0)==0){F=17;break}B=D+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+4|0;x=J;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+4|0;x=de(J|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(68)|0;if((z|0)==0){F=24;break}B=h+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+6|0;x=K;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+6|0;x=de(K|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(68)|0;if((z|0)==0){F=31;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+8|0;x=L;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+8|0;x=de(L|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(68)|0;if((z|0)==0){F=38;break}B=D+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+10|0;x=M;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+10|0;x=de(M|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=b+1|0;if((z|0)<(r|0)){b=z;y=y+12|0}else{F=45;break}}if((F|0)==4){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==10){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==17){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==24){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==31){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==38){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==45){i=m;return}}function Fwb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;y=n;while(1){if(o){n=d<<1;z=n|1;A=-1073741824;B=-1073741824;C=0;do{D=c[f+(C<<2)>>2]|0;E=b[e+(C<<1)>>1]|0;A=(ba(E,c[D+(n<<2)>>2]|0)|0)+A|0;B=(ba(c[D+(z<<2)>>2]|0,E)|0)+B|0;C=C+1|0;}while((C|0)<(g|0));F=(A>>14)+65536|0;G=(B>>14)+65536|0}else{F=0;G=0}if(q){C=-1073741824;z=-1073741824;n=0;do{E=b[h+(n<<1)>>1]|0;C=(ba(E,c[(c[j+(n<<2)>>2]|0)+(d<<2)>>2]|0)|0)+C|0;z=(ba(c[(c[k+(n<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+z|0;n=n+1|0;}while((n|0)<(l|0));H=C>>14;I=z>>14}else{H=-65536;I=-65536}n=c[r>>2]|0;B=c[s>>2]|0;A=(ba(F-n|0,B)|0)+8192|0;E=(ba(G-n|0,B)|0)+8192|0;B=ba(c[t>>2]|0,I)|0;n=ba(c[u>>2]|0,I)|0;D=(ba(c[v>>2]|0,H)|0)+n|0;n=ba(c[w>>2]|0,H)|0;J=bFb(68)|0;if((J|0)==0){K=11;break}L=n+A|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[y]=x;x=x>>8;a[y+1|0]=x;J=bFb(68)|0;if((J|0)==0){K=17;break}L=D+A|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+2|0;x=O;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+2|0;x=de(O|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(68)|0;if((J|0)==0){K=24;break}L=B+A|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+4|0;x=P;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+4|0;x=de(P|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(68)|0;if((J|0)==0){K=31;break}L=n+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+6|0;x=Q;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+6|0;x=de(Q|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(68)|0;if((J|0)==0){K=38;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+8|0;x=R;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+8|0;x=de(R|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(68)|0;if((J|0)==0){K=45;break}L=B+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+10|0;x=S;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+10|0;x=de(S|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=d+1|0;if((J|0)<(m|0)){d=J;y=y+12|0}else{K=52;break}}if((K|0)==11){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==17){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==24){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==31){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==38){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==45){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==52){i=p;return}}function Gwb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;y=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ba((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ba((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ba(c[p>>2]|0,y)|0;z=ba(c[q>>2]|0,y)|0;y=(ba(c[r>>2]|0,w)|0)+z|0;z=ba(c[s>>2]|0,w)|0;w=bFb(67)|0;if((w|0)==0){D=5;break}v=z+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=de(E|0)|0}x=F;a[u]=x;x=x>>8;a[u+1|0]=x;w=bFb(67)|0;if((w|0)==0){D=11;break}v=y+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;x=G;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+2|0;x=de(G|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(67)|0;if((w|0)==0){D=18;break}v=A+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;x=H;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+4|0;x=de(H|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(67)|0;if((w|0)==0){D=25;break}v=z+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+6|0;x=I;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+6|0;x=de(I|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(67)|0;if((w|0)==0){D=32;break}v=y+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;x=J;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+8|0;x=de(J|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=bFb(67)|0;if((w|0)==0){D=39;break}v=A+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;x=K;a[w]=x;x=x>>8;a[w+1|0]=x}else{w=u+10|0;x=de(K|0)|0;a[w]=x;x=x>>8;a[w+1|0]=x}w=t+1|0;if((w|0)<(k|0)){t=w;u=u+12|0}else{D=90;break}}if((D|0)==5){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==11){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==18){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==25){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==32){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==39){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==90){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ba((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ba((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ba(c[k>>2]|0,F)|0;E=ba(c[K>>2]|0,F)|0;F=(ba(c[J>>2]|0,G)|0)+E|0;E=ba(c[I>>2]|0,G)|0;G=bFb(67)|0;if((G|0)==0){D=49;break}d=E+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[H]=x;x=x>>8;a[H+1|0]=x;G=bFb(67)|0;if((G|0)==0){D=55;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;x=O;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+2|0;x=de(O|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(67)|0;if((G|0)==0){D=62;break}d=s+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;x=P;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+4|0;x=de(P|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(67)|0;if((G|0)==0){D=69;break}d=E+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+6|0;x=Q;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+6|0;x=de(Q|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(67)|0;if((G|0)==0){D=76;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;x=R;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+8|0;x=de(R|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=bFb(67)|0;if((G|0)==0){D=83;break}d=s+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;x=S;a[G]=x;x=x>>8;a[G+1|0]=x}else{G=H+10|0;x=de(S|0)|0;a[G]=x;x=x>>8;a[G+1|0]=x}G=b+1|0;if((G|0)<(f|0)){b=G;H=H+12|0}else{D=90;break}}if((D|0)==49){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==55){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==62){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==69){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==76){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==83){yDb(0,0,2166496,(L=i,i=i+24|0,c[L>>2]=2097816,c[L+8>>2]=2042544,c[L+16>>2]=653,L)|0);i=L;Cd()}else if((D|0)==90){i=l;return}}}function Hwb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;y=h;while(1){h=b<<1;z=ba(c[g+(h<<2)>>2]|0,f)|0;A=(ba(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ba(c[g+(z<<2)>>2]|0,f)|0;B=(ba(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ba(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ba(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ba(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ba(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ba(A-h|0,D)|0)+8192|0;A=(ba(B-h|0,D)|0)+8192|0;D=ba(C,c[t>>2]|0)|0;h=ba(c[u>>2]|0,C)|0;C=(ba(c[v>>2]|0,z)|0)+h|0;h=ba(c[w>>2]|0,z)|0;z=bFb(67)|0;if((z|0)==0){F=4;break}B=h+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=de(G|0)|0}x=H;a[y]=x;x=x>>8;a[y+1|0]=x;z=bFb(67)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+2|0;x=I;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+2|0;x=de(I|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(67)|0;if((z|0)==0){F=17;break}B=D+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+4|0;x=J;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+4|0;x=de(J|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(67)|0;if((z|0)==0){F=24;break}B=h+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+6|0;x=K;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+6|0;x=de(K|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(67)|0;if((z|0)==0){F=31;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+8|0;x=L;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+8|0;x=de(L|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=bFb(67)|0;if((z|0)==0){F=38;break}B=D+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=y+10|0;x=M;a[z]=x;x=x>>8;a[z+1|0]=x}else{z=y+10|0;x=de(M|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x}z=b+1|0;if((z|0)<(r|0)){b=z;y=y+12|0}else{F=45;break}}if((F|0)==4){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==10){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==17){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==24){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==31){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==38){yDb(0,0,2166496,(N=i,i=i+24|0,c[N>>2]=2097816,c[N+8>>2]=2042544,c[N+16>>2]=653,N)|0);i=N;Cd()}else if((F|0)==45){i=m;return}}function Iwb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;y=n;while(1){if(o){n=d<<1;z=n|1;A=-1073741824;B=-1073741824;C=0;do{D=c[f+(C<<2)>>2]|0;E=b[e+(C<<1)>>1]|0;A=(ba(E,c[D+(n<<2)>>2]|0)|0)+A|0;B=(ba(c[D+(z<<2)>>2]|0,E)|0)+B|0;C=C+1|0;}while((C|0)<(g|0));F=(A>>14)+65536|0;G=(B>>14)+65536|0}else{F=0;G=0}if(q){C=-1073741824;z=-1073741824;n=0;do{E=b[h+(n<<1)>>1]|0;C=(ba(E,c[(c[j+(n<<2)>>2]|0)+(d<<2)>>2]|0)|0)+C|0;z=(ba(c[(c[k+(n<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+z|0;n=n+1|0;}while((n|0)<(l|0));H=C>>14;I=z>>14}else{H=-65536;I=-65536}n=c[r>>2]|0;B=c[s>>2]|0;A=(ba(F-n|0,B)|0)+8192|0;E=(ba(G-n|0,B)|0)+8192|0;B=ba(c[t>>2]|0,I)|0;n=ba(c[u>>2]|0,I)|0;D=(ba(c[v>>2]|0,H)|0)+n|0;n=ba(c[w>>2]|0,H)|0;J=bFb(67)|0;if((J|0)==0){K=11;break}L=n+A|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=de(M|0)|0}x=N;a[y]=x;x=x>>8;a[y+1|0]=x;J=bFb(67)|0;if((J|0)==0){K=17;break}L=D+A|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+2|0;x=O;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+2|0;x=de(O|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(67)|0;if((J|0)==0){K=24;break}L=B+A|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+4|0;x=P;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+4|0;x=de(P|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(67)|0;if((J|0)==0){K=31;break}L=n+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+6|0;x=Q;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+6|0;x=de(Q|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(67)|0;if((J|0)==0){K=38;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+8|0;x=R;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+8|0;x=de(R|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=bFb(67)|0;if((J|0)==0){K=45;break}L=B+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=y+10|0;x=S;a[J]=x;x=x>>8;a[J+1|0]=x}else{J=y+10|0;x=de(S|0)|0;a[J]=x;x=x>>8;a[J+1|0]=x}J=d+1|0;if((J|0)<(m|0)){d=J;y=y+12|0}else{K=52;break}}if((K|0)==11){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==17){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==24){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==31){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==38){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==45){yDb(0,0,2166496,(T=i,i=i+24|0,c[T>>2]=2097816,c[T+8>>2]=2042544,c[T+16>>2]=653,T)|0);i=T;Cd()}else if((K|0)==52){i=p;return}}function Jwb(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=c[e>>2]|0;l=c[f>>2]|0;if((j|0)<2048){j=i+1>>1;if((j|0)<=0){return}m=h;n=0;do{o=n<<1;p=(b[d+(o<<1)>>1]|0)+64>>7;q=o|1;r=(b[d+(q<<1)>>1]|0)+64>>7;s=((b[l+(n<<1)>>1]|0)+64>>7)+128|0;t=((b[k+(n<<1)>>1]|0)+64>>7)+128|0;u=((b[g+(o<<1)>>1]|0)*255|0)+16384>>15;v=((b[g+(q<<1)>>1]|0)*255|0)+16384>>15;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}if(v>>>0>255>>>0){x=-v>>31&255}else{x=v&255}v=c[a+4352+(s<<2)>>2]|0;u=(c[a+6400+(t<<2)>>2]|0)+(c[a+2304+(s<<2)>>2]|0)|0;s=c[a+8448+(t<<2)>>2]|0;c[m+(o<<2)>>2]=(c[v+(p<<2)>>2]|0)+((w&255)<<24)+(c[u+(p<<2)>>2]|0)+(c[s+(p<<2)>>2]|0);c[m+(q<<2)>>2]=(c[v+(r<<2)>>2]|0)+((x&255)<<24)+(c[u+(r<<2)>>2]|0)+(c[s+(r<<2)>>2]|0);n=n+1|0;}while((n|0)<(j|0));return}else{j=c[e+4>>2]|0;e=c[f+4>>2]|0;f=i+1>>1;if((f|0)<=0){return}i=h;h=0;do{n=h<<1;x=(b[d+(n<<1)>>1]|0)+64>>7;m=n|1;w=(b[d+(m<<1)>>1]|0)+64>>7;r=((b[l+(h<<1)>>1]|0)+128+(b[e+(h<<1)>>1]|0)>>8)+128|0;s=((b[k+(h<<1)>>1]|0)+128+(b[j+(h<<1)>>1]|0)>>8)+128|0;u=(b[g+(n<<1)>>1]|0)+64>>7;v=(b[g+(m<<1)>>1]|0)+64>>7;if(u>>>0>255>>>0){y=-u>>31&255}else{y=u&255}if(v>>>0>255>>>0){z=-v>>31&255}else{z=v&255}v=c[a+4352+(r<<2)>>2]|0;u=(c[a+6400+(s<<2)>>2]|0)+(c[a+2304+(r<<2)>>2]|0)|0;r=c[a+8448+(s<<2)>>2]|0;c[i+(n<<2)>>2]=(c[v+(x<<2)>>2]|0)+((y&255)<<24)+(c[u+(x<<2)>>2]|0)+(c[r+(x<<2)>>2]|0);c[i+(m<<2)>>2]=(c[v+(w<<2)>>2]|0)+((z&255)<<24)+(c[u+(w<<2)>>2]|0)+(c[r+(w<<2)>>2]|0);h=h+1|0;}while((h|0)<(f|0));return}}function Kwb(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;l=c[d>>2]|0;m=c[d+4>>2]|0;d=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-j|0;q=4096-k|0;r=i+1>>1;if((r|0)<=0){return}i=h;h=0;do{s=h<<1;t=ba(b[l+(s<<1)>>1]|0,g)|0;u=(ba(b[m+(s<<1)>>1]|0,j)|0)+t>>19;t=s|1;v=ba(b[l+(t<<1)>>1]|0,g)|0;w=(ba(b[m+(t<<1)>>1]|0,j)|0)+v>>19;v=ba(b[d+(h<<1)>>1]|0,q)|0;x=(ba(b[n+(h<<1)>>1]|0,k)|0)+v>>19;v=ba(b[e+(h<<1)>>1]|0,q)|0;y=((ba(b[o+(h<<1)>>1]|0,k)|0)+v>>19)+128|0;v=x+128|0;x=ba(b[f+(s<<1)>>1]|0,g)|0;z=(ba(b[p+(s<<1)>>1]|0,j)|0)+x>>19;x=ba(b[f+(t<<1)>>1]|0,g)|0;A=(ba(b[p+(t<<1)>>1]|0,j)|0)+x>>19;if(z>>>0>255>>>0){B=-z>>31&255}else{B=z&255}if(A>>>0>255>>>0){C=-A>>31&255}else{C=A&255}A=c[a+4352+(y<<2)>>2]|0;z=(c[a+6400+(v<<2)>>2]|0)+(c[a+2304+(y<<2)>>2]|0)|0;y=c[a+8448+(v<<2)>>2]|0;c[i+(s<<2)>>2]=(c[A+(u<<2)>>2]|0)+((B&255)<<24)+(c[z+(u<<2)>>2]|0)+(c[y+(u<<2)>>2]|0);c[i+(t<<2)>>2]=(c[A+(w<<2)>>2]|0)+((C&255)<<24)+(c[z+(w<<2)>>2]|0)+(c[y+(w<<2)>>2]|0);h=h+1|0;}while((h|0)<(r|0));return}function Lwb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;n=m+1>>1;if((n|0)<=0){return}m=(f|0)>0;o=(j|0)>0;p=l;l=0;do{if(m){q=l<<1;r=q|1;s=262144;t=262144;u=0;do{v=c[e+(u<<2)>>2]|0;w=b[d+(u<<1)>>1]|0;s=(ba(w,b[v+(q<<1)>>1]|0)|0)+s|0;t=(ba(b[v+(r<<1)>>1]|0,w)|0)+t|0;u=u+1|0;}while((u|0)<(f|0));x=s>>19;y=t>>19}else{x=0;y=0}if(o){u=262144;r=262144;q=0;do{w=b[g+(q<<1)>>1]|0;u=(ba(w,b[(c[h+(q<<2)>>2]|0)+(l<<1)>>1]|0)|0)+u|0;r=(ba(b[(c[i+(q<<2)>>2]|0)+(l<<1)>>1]|0,w)|0)+r|0;q=q+1|0;}while((q|0)<(j|0));z=(u>>19)+128|0;A=(r>>19)+128|0}else{z=128;A=128}if(m){q=l<<1;t=q|1;s=262144;w=262144;v=0;do{B=c[k+(v<<2)>>2]|0;C=b[d+(v<<1)>>1]|0;w=(ba(C,b[B+(q<<1)>>1]|0)|0)+w|0;s=(ba(b[B+(t<<1)>>1]|0,C)|0)+s|0;v=v+1|0;}while((v|0)<(f|0));D=s>>19;E=w>>19}else{D=0;E=0}if(((D|E)&256|0)==0){F=E;G=D}else{if(E>>>0>255>>>0){H=-E>>31&255}else{H=E&255}if(D>>>0>255>>>0){I=-D>>31&255}else{I=D&255}F=H&255;G=I&255}v=c[a+4352+(A<<2)>>2]|0;t=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;q=c[a+8448+(z<<2)>>2]|0;r=l<<1;c[p+(r<<2)>>2]=(c[v+(x<<2)>>2]|0)+(F<<24)+(c[t+(x<<2)>>2]|0)+(c[q+(x<<2)>>2]|0);c[p+((r|1)<<2)>>2]=(c[v+(y<<2)>>2]|0)+(G<<24)+(c[t+(y<<2)>>2]|0)+(c[q+(y<<2)>>2]|0);l=l+1|0;}while((l|0)<(n|0));return}function Mwb(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=c[e>>2]|0;g=c[f>>2]|0;if((j|0)<2048){j=i+1>>1;if((j|0)<=0){return}l=h;m=0;do{n=m<<1;o=(b[d+(n<<1)>>1]|0)+64>>7;p=n|1;q=(b[d+(p<<1)>>1]|0)+64>>7;r=((b[g+(m<<1)>>1]|0)+64>>7)+128|0;s=((b[k+(m<<1)>>1]|0)+64>>7)+128|0;t=c[a+4352+(r<<2)>>2]|0;u=(c[a+6400+(s<<2)>>2]|0)+(c[a+2304+(r<<2)>>2]|0)|0;r=c[a+8448+(s<<2)>>2]|0;c[l+(n<<2)>>2]=(c[u+(o<<2)>>2]|0)+(c[t+(o<<2)>>2]|0)+(c[r+(o<<2)>>2]|0);c[l+(p<<2)>>2]=(c[u+(q<<2)>>2]|0)+(c[t+(q<<2)>>2]|0)+(c[r+(q<<2)>>2]|0);m=m+1|0;}while((m|0)<(j|0));return}else{j=c[e+4>>2]|0;e=c[f+4>>2]|0;f=i+1>>1;if((f|0)<=0){return}i=h;h=0;do{m=h<<1;l=(b[d+(m<<1)>>1]|0)+64>>7;q=m|1;r=(b[d+(q<<1)>>1]|0)+64>>7;t=((b[g+(h<<1)>>1]|0)+128+(b[e+(h<<1)>>1]|0)>>8)+128|0;u=((b[k+(h<<1)>>1]|0)+128+(b[j+(h<<1)>>1]|0)>>8)+128|0;p=c[a+4352+(t<<2)>>2]|0;o=(c[a+6400+(u<<2)>>2]|0)+(c[a+2304+(t<<2)>>2]|0)|0;t=c[a+8448+(u<<2)>>2]|0;c[i+(m<<2)>>2]=(c[o+(l<<2)>>2]|0)+(c[p+(l<<2)>>2]|0)+(c[t+(l<<2)>>2]|0);c[i+(q<<2)>>2]=(c[o+(r<<2)>>2]|0)+(c[p+(r<<2)>>2]|0)+(c[t+(r<<2)>>2]|0);h=h+1|0;}while((h|0)<(f|0));return}}function Nwb(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=c[d>>2]|0;g=c[d+4>>2]|0;d=c[e>>2]|0;m=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=4096-j|0;o=4096-k|0;p=i+1>>1;if((p|0)<=0){return}i=h;h=0;do{q=h<<1;r=ba(b[l+(q<<1)>>1]|0,f)|0;s=(ba(b[g+(q<<1)>>1]|0,j)|0)+r>>19;r=q|1;t=ba(b[l+(r<<1)>>1]|0,f)|0;u=(ba(b[g+(r<<1)>>1]|0,j)|0)+t>>19;t=ba(b[d+(h<<1)>>1]|0,o)|0;v=(ba(b[m+(h<<1)>>1]|0,k)|0)+t>>19;t=ba(b[e+(h<<1)>>1]|0,o)|0;w=((ba(b[n+(h<<1)>>1]|0,k)|0)+t>>19)+128|0;t=v+128|0;v=c[a+4352+(w<<2)>>2]|0;x=(c[a+6400+(t<<2)>>2]|0)+(c[a+2304+(w<<2)>>2]|0)|0;w=c[a+8448+(t<<2)>>2]|0;c[i+(q<<2)>>2]=(c[x+(s<<2)>>2]|0)+(c[v+(s<<2)>>2]|0)+(c[w+(s<<2)>>2]|0);c[i+(r<<2)>>2]=(c[x+(u<<2)>>2]|0)+(c[v+(u<<2)>>2]|0)+(c[w+(u<<2)>>2]|0);h=h+1|0;}while((h|0)<(p|0));return}function Owb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;n=m+1>>1;if((n|0)<=0){return}m=(f|0)>0;k=(j|0)>0;o=l;l=0;do{if(m){p=l<<1;q=p|1;r=262144;s=262144;t=0;do{u=c[e+(t<<2)>>2]|0;v=b[d+(t<<1)>>1]|0;r=(ba(v,b[u+(p<<1)>>1]|0)|0)+r|0;s=(ba(b[u+(q<<1)>>1]|0,v)|0)+s|0;t=t+1|0;}while((t|0)<(f|0));w=r>>19;x=s>>19}else{w=0;x=0}if(k){t=262144;q=262144;p=0;do{v=b[g+(p<<1)>>1]|0;t=(ba(v,b[(c[h+(p<<2)>>2]|0)+(l<<1)>>1]|0)|0)+t|0;q=(ba(b[(c[i+(p<<2)>>2]|0)+(l<<1)>>1]|0,v)|0)+q|0;p=p+1|0;}while((p|0)<(j|0));y=(t>>19)+128|0;z=(q>>19)+128|0}else{y=128;z=128}p=c[a+4352+(z<<2)>>2]|0;s=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;r=c[a+8448+(y<<2)>>2]|0;v=l<<1;c[o+(v<<2)>>2]=(c[s+(w<<2)>>2]|0)+(c[p+(w<<2)>>2]|0)+(c[r+(w<<2)>>2]|0);c[o+((v|1)<<2)>>2]=(c[s+(x<<2)>>2]|0)+(c[p+(x<<2)>>2]|0)+(c[r+(x<<2)>>2]|0);l=l+1|0;}while((l|0)<(n|0));return}function Pwb(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=c[e>>2]|0;l=c[f>>2]|0;if((j|0)<2048){j=i+1>>1;if((j|0)<=0){return}m=h;n=0;do{o=n<<1;p=(b[d+(o<<1)>>1]|0)+64>>7;q=o|1;r=(b[d+(q<<1)>>1]|0)+64>>7;s=((b[l+(n<<1)>>1]|0)+64>>7)+128|0;t=((b[k+(n<<1)>>1]|0)+64>>7)+128|0;u=((b[g+(o<<1)>>1]|0)*255|0)+16384>>15;v=((b[g+(q<<1)>>1]|0)*255|0)+16384>>15;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}if(v>>>0>255>>>0){x=-v>>31&255}else{x=v&255}v=c[a+4352+(s<<2)>>2]|0;u=(c[a+6400+(t<<2)>>2]|0)+(c[a+2304+(s<<2)>>2]|0)|0;s=c[a+8448+(t<<2)>>2]|0;c[m+(o<<2)>>2]=(c[v+(p<<2)>>2]|0)+(w&255)+(c[u+(p<<2)>>2]|0)+(c[s+(p<<2)>>2]|0);c[m+(q<<2)>>2]=(c[v+(r<<2)>>2]|0)+(x&255)+(c[u+(r<<2)>>2]|0)+(c[s+(r<<2)>>2]|0);n=n+1|0;}while((n|0)<(j|0));return}else{j=c[e+4>>2]|0;e=c[f+4>>2]|0;f=i+1>>1;if((f|0)<=0){return}i=h;h=0;do{n=h<<1;x=(b[d+(n<<1)>>1]|0)+64>>7;m=n|1;w=(b[d+(m<<1)>>1]|0)+64>>7;r=((b[l+(h<<1)>>1]|0)+128+(b[e+(h<<1)>>1]|0)>>8)+128|0;s=((b[k+(h<<1)>>1]|0)+128+(b[j+(h<<1)>>1]|0)>>8)+128|0;u=(b[g+(n<<1)>>1]|0)+64>>7;v=(b[g+(m<<1)>>1]|0)+64>>7;if(u>>>0>255>>>0){y=-u>>31&255}else{y=u&255}if(v>>>0>255>>>0){z=-v>>31&255}else{z=v&255}v=c[a+4352+(r<<2)>>2]|0;u=(c[a+6400+(s<<2)>>2]|0)+(c[a+2304+(r<<2)>>2]|0)|0;r=c[a+8448+(s<<2)>>2]|0;c[i+(n<<2)>>2]=(c[v+(x<<2)>>2]|0)+(y&255)+(c[u+(x<<2)>>2]|0)+(c[r+(x<<2)>>2]|0);c[i+(m<<2)>>2]=(c[v+(w<<2)>>2]|0)+(z&255)+(c[u+(w<<2)>>2]|0)+(c[r+(w<<2)>>2]|0);h=h+1|0;}while((h|0)<(f|0));return}}function Qwb(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;l=c[d>>2]|0;m=c[d+4>>2]|0;d=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-j|0;q=4096-k|0;r=i+1>>1;if((r|0)<=0){return}i=h;h=0;do{s=h<<1;t=ba(b[l+(s<<1)>>1]|0,g)|0;u=(ba(b[m+(s<<1)>>1]|0,j)|0)+t>>19;t=s|1;v=ba(b[l+(t<<1)>>1]|0,g)|0;w=(ba(b[m+(t<<1)>>1]|0,j)|0)+v>>19;v=ba(b[d+(h<<1)>>1]|0,q)|0;x=(ba(b[n+(h<<1)>>1]|0,k)|0)+v>>19;v=ba(b[e+(h<<1)>>1]|0,q)|0;y=((ba(b[o+(h<<1)>>1]|0,k)|0)+v>>19)+128|0;v=x+128|0;x=ba(b[f+(s<<1)>>1]|0,g)|0;z=(ba(b[p+(s<<1)>>1]|0,j)|0)+x>>19;x=ba(b[f+(t<<1)>>1]|0,g)|0;A=(ba(b[p+(t<<1)>>1]|0,j)|0)+x>>19;if(z>>>0>255>>>0){B=-z>>31&255}else{B=z&255}if(A>>>0>255>>>0){C=-A>>31&255}else{C=A&255}A=c[a+4352+(y<<2)>>2]|0;z=(c[a+6400+(v<<2)>>2]|0)+(c[a+2304+(y<<2)>>2]|0)|0;y=c[a+8448+(v<<2)>>2]|0;c[i+(s<<2)>>2]=(c[A+(u<<2)>>2]|0)+(B&255)+(c[z+(u<<2)>>2]|0)+(c[y+(u<<2)>>2]|0);c[i+(t<<2)>>2]=(c[A+(w<<2)>>2]|0)+(C&255)+(c[z+(w<<2)>>2]|0)+(c[y+(w<<2)>>2]|0);h=h+1|0;}while((h|0)<(r|0));return}function Rwb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;n=m+1>>1;if((n|0)<=0){return}m=(f|0)>0;o=(j|0)>0;p=l;l=0;do{if(m){q=l<<1;r=q|1;s=262144;t=262144;u=0;do{v=c[e+(u<<2)>>2]|0;w=b[d+(u<<1)>>1]|0;s=(ba(w,b[v+(q<<1)>>1]|0)|0)+s|0;t=(ba(b[v+(r<<1)>>1]|0,w)|0)+t|0;u=u+1|0;}while((u|0)<(f|0));x=s>>19;y=t>>19}else{x=0;y=0}if(o){u=262144;r=262144;q=0;do{w=b[g+(q<<1)>>1]|0;u=(ba(w,b[(c[h+(q<<2)>>2]|0)+(l<<1)>>1]|0)|0)+u|0;r=(ba(b[(c[i+(q<<2)>>2]|0)+(l<<1)>>1]|0,w)|0)+r|0;q=q+1|0;}while((q|0)<(j|0));z=(u>>19)+128|0;A=(r>>19)+128|0}else{z=128;A=128}if(m){q=l<<1;t=q|1;s=262144;w=262144;v=0;do{B=c[k+(v<<2)>>2]|0;C=b[d+(v<<1)>>1]|0;w=(ba(C,b[B+(q<<1)>>1]|0)|0)+w|0;s=(ba(b[B+(t<<1)>>1]|0,C)|0)+s|0;v=v+1|0;}while((v|0)<(f|0));D=s>>19;E=w>>19}else{D=0;E=0}if(((D|E)&256|0)==0){F=E;G=D}else{if(E>>>0>255>>>0){H=-E>>31&255}else{H=E&255}if(D>>>0>255>>>0){I=-D>>31&255}else{I=D&255}F=H&255;G=I&255}v=c[a+4352+(A<<2)>>2]|0;t=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;q=c[a+8448+(z<<2)>>2]|0;r=l<<1;c[p+(r<<2)>>2]=(c[v+(x<<2)>>2]|0)+F+(c[t+(x<<2)>>2]|0)+(c[q+(x<<2)>>2]|0);c[p+((r|1)<<2)>>2]=(c[v+(y<<2)>>2]|0)+G+(c[t+(y<<2)>>2]|0)+(c[q+(y<<2)>>2]|0);l=l+1|0;}while((l|0)<(n|0));return}function Swb(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=c[e>>2]|0;g=c[f>>2]|0;if((j|0)<2048){j=i+1>>1;if((j|0)<=0){return}l=h;m=0;do{n=m<<1;o=(b[d+(n<<1)>>1]|0)+64>>7;p=n|1;q=(b[d+(p<<1)>>1]|0)+64>>7;r=((b[g+(m<<1)>>1]|0)+64>>7)+128|0;s=((b[k+(m<<1)>>1]|0)+64>>7)+128|0;t=c[a+4352+(r<<2)>>2]|0;u=(c[a+6400+(s<<2)>>2]|0)+(c[a+2304+(r<<2)>>2]|0)|0;r=c[a+8448+(s<<2)>>2]|0;c[l+(n<<2)>>2]=(c[u+(o<<2)>>2]|0)+(c[t+(o<<2)>>2]|0)+(c[r+(o<<2)>>2]|0);c[l+(p<<2)>>2]=(c[u+(q<<2)>>2]|0)+(c[t+(q<<2)>>2]|0)+(c[r+(q<<2)>>2]|0);m=m+1|0;}while((m|0)<(j|0));return}else{j=c[e+4>>2]|0;e=c[f+4>>2]|0;f=i+1>>1;if((f|0)<=0){return}i=h;h=0;do{m=h<<1;l=(b[d+(m<<1)>>1]|0)+64>>7;q=m|1;r=(b[d+(q<<1)>>1]|0)+64>>7;t=((b[g+(h<<1)>>1]|0)+128+(b[e+(h<<1)>>1]|0)>>8)+128|0;u=((b[k+(h<<1)>>1]|0)+128+(b[j+(h<<1)>>1]|0)>>8)+128|0;p=c[a+4352+(t<<2)>>2]|0;o=(c[a+6400+(u<<2)>>2]|0)+(c[a+2304+(t<<2)>>2]|0)|0;t=c[a+8448+(u<<2)>>2]|0;c[i+(m<<2)>>2]=(c[o+(l<<2)>>2]|0)+(c[p+(l<<2)>>2]|0)+(c[t+(l<<2)>>2]|0);c[i+(q<<2)>>2]=(c[o+(r<<2)>>2]|0)+(c[p+(r<<2)>>2]|0)+(c[t+(r<<2)>>2]|0);h=h+1|0;}while((h|0)<(f|0));return}}function Twb(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=c[d>>2]|0;g=c[d+4>>2]|0;d=c[e>>2]|0;m=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=4096-j|0;o=4096-k|0;p=i+1>>1;if((p|0)<=0){return}i=h;h=0;do{q=h<<1;r=ba(b[l+(q<<1)>>1]|0,f)|0;s=(ba(b[g+(q<<1)>>1]|0,j)|0)+r>>19;r=q|1;t=ba(b[l+(r<<1)>>1]|0,f)|0;u=(ba(b[g+(r<<1)>>1]|0,j)|0)+t>>19;t=ba(b[d+(h<<1)>>1]|0,o)|0;v=(ba(b[m+(h<<1)>>1]|0,k)|0)+t>>19;t=ba(b[e+(h<<1)>>1]|0,o)|0;w=((ba(b[n+(h<<1)>>1]|0,k)|0)+t>>19)+128|0;t=v+128|0;v=c[a+4352+(w<<2)>>2]|0;x=(c[a+6400+(t<<2)>>2]|0)+(c[a+2304+(w<<2)>>2]|0)|0;w=c[a+8448+(t<<2)>>2]|0;c[i+(q<<2)>>2]=(c[x+(s<<2)>>2]|0)+(c[v+(s<<2)>>2]|0)+(c[w+(s<<2)>>2]|0);c[i+(r<<2)>>2]=(c[x+(u<<2)>>2]|0)+(c[v+(u<<2)>>2]|0)+(c[w+(u<<2)>>2]|0);h=h+1|0;}while((h|0)<(p|0));return}function Uwb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;n=m+1>>1;if((n|0)<=0){return}m=(f|0)>0;k=(j|0)>0;o=l;l=0;do{if(m){p=l<<1;q=p|1;r=262144;s=262144;t=0;do{u=c[e+(t<<2)>>2]|0;v=b[d+(t<<1)>>1]|0;r=(ba(v,b[u+(p<<1)>>1]|0)|0)+r|0;s=(ba(b[u+(q<<1)>>1]|0,v)|0)+s|0;t=t+1|0;}while((t|0)<(f|0));w=r>>19;x=s>>19}else{w=0;x=0}if(k){t=262144;q=262144;p=0;do{v=b[g+(p<<1)>>1]|0;t=(ba(v,b[(c[h+(p<<2)>>2]|0)+(l<<1)>>1]|0)|0)+t|0;q=(ba(b[(c[i+(p<<2)>>2]|0)+(l<<1)>>1]|0,v)|0)+q|0;p=p+1|0;}while((p|0)<(j|0));y=(t>>19)+128|0;z=(q>>19)+128|0}else{y=128;z=128}p=c[a+4352+(z<<2)>>2]|0;s=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;r=c[a+8448+(y<<2)>>2]|0;v=l<<1;c[o+(v<<2)>>2]=(c[s+(w<<2)>>2]|0)+(c[p+(w<<2)>>2]|0)+(c[r+(w<<2)>>2]|0);c[o+((v|1)<<2)>>2]=(c[s+(x<<2)>>2]|0)+(c[p+(x<<2)>>2]|0)+(c[r+(x<<2)>>2]|0);l=l+1|0;}while((l|0)<(n|0));return}function Vwb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)>0){m=0}else{return}do{n=m<<1;o=(b[e+(n<<1)>>1]|0)+64>>7;p=(b[e+((n|1)<<1)>>1]|0)+64>>7;n=((b[h+(m<<1)>>1]|0)+64>>7)+128|0;q=c[d+4352+(n<<2)>>2]|0;r=((b[l+(m<<1)>>1]|0)+64>>7)+128|0;s=c[d+6400+(r<<2)>>2]|0;t=c[d+2304+(n<<2)>>2]|0;n=c[d+8448+(r<<2)>>2]|0;r=m*6|0;a[i+r|0]=a[q+o|0]|0;a[i+(r|1)|0]=a[s+(t+o)|0]|0;a[i+(r+2)|0]=a[n+o|0]|0;a[i+(r+3)|0]=a[q+p|0]|0;a[i+(r+4)|0]=a[s+(t+p)|0]|0;a[i+(r+5)|0]=a[n+p|0]|0;m=m+1|0;}while((m|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)>0){u=0}else{return}do{j=u<<1;m=(b[e+(j<<1)>>1]|0)+64>>7;p=(b[e+((j|1)<<1)>>1]|0)+64>>7;j=((b[h+(u<<1)>>1]|0)+128+(b[f+(u<<1)>>1]|0)>>8)+128|0;n=c[d+4352+(j<<2)>>2]|0;r=((b[l+(u<<1)>>1]|0)+128+(b[k+(u<<1)>>1]|0)>>8)+128|0;t=c[d+6400+(r<<2)>>2]|0;s=c[d+2304+(j<<2)>>2]|0;j=c[d+8448+(r<<2)>>2]|0;r=u*6|0;a[i+r|0]=a[n+m|0]|0;a[i+(r|1)|0]=a[t+(s+m)|0]|0;a[i+(r+2)|0]=a[j+m|0]|0;a[i+(r+3)|0]=a[n+p|0]|0;a[i+(r+4)|0]=a[t+(s+p)|0]|0;a[i+(r+5)|0]=a[j+p|0]|0;u=u+1|0;}while((u|0)<(g|0));return}}function Wwb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;q=j+1>>1;if((q|0)>0){r=0}else{return}do{j=r<<1;s=ba(b[m+(j<<1)>>1]|0,g)|0;t=(ba(b[h+(j<<1)>>1]|0,k)|0)+s>>19;s=j|1;j=ba(b[m+(s<<1)>>1]|0,g)|0;u=(ba(b[h+(s<<1)>>1]|0,k)|0)+j>>19;j=ba(b[e+(r<<1)>>1]|0,p)|0;s=(ba(b[n+(r<<1)>>1]|0,l)|0)+j>>19;j=ba(b[f+(r<<1)>>1]|0,p)|0;v=((ba(b[o+(r<<1)>>1]|0,l)|0)+j>>19)+128|0;j=c[d+4352+(v<<2)>>2]|0;w=s+128|0;s=c[d+6400+(w<<2)>>2]|0;x=c[d+2304+(v<<2)>>2]|0;v=c[d+8448+(w<<2)>>2]|0;w=r*6|0;a[i+w|0]=a[j+t|0]|0;a[i+(w|1)|0]=a[s+(x+t)|0]|0;a[i+(w+2)|0]=a[v+t|0]|0;a[i+(w+3)|0]=a[j+u|0]|0;a[i+(w+4)|0]=a[s+(x+u)|0]|0;a[i+(w+5)|0]=a[v+u|0]|0;r=r+1|0;}while((r|0)<(q|0));return}function Xwb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;o=n+1>>1;if((o|0)<=0){return}n=(g|0)>0;l=(k|0)>0;p=0;do{if(n){q=p<<1;r=q|1;s=262144;t=262144;u=0;do{v=c[f+(u<<2)>>2]|0;w=b[e+(u<<1)>>1]|0;s=(ba(w,b[v+(q<<1)>>1]|0)|0)+s|0;t=(ba(b[v+(r<<1)>>1]|0,w)|0)+t|0;u=u+1|0;}while((u|0)<(g|0));x=s>>19;y=t>>19}else{x=0;y=0}if(l){u=262144;r=262144;q=0;do{w=b[h+(q<<1)>>1]|0;u=(ba(w,b[(c[i+(q<<2)>>2]|0)+(p<<1)>>1]|0)|0)+u|0;r=(ba(b[(c[j+(q<<2)>>2]|0)+(p<<1)>>1]|0,w)|0)+r|0;q=q+1|0;}while((q|0)<(k|0));z=(u>>19)+128|0;A=(r>>19)+128|0}else{z=128;A=128}q=c[d+4352+(A<<2)>>2]|0;t=c[d+6400+(z<<2)>>2]|0;s=c[d+2304+(A<<2)>>2]|0;w=c[d+8448+(z<<2)>>2]|0;v=p*6|0;a[m+v|0]=a[q+x|0]|0;a[m+(v|1)|0]=a[t+(s+x)|0]|0;a[m+(v+2)|0]=a[w+x|0]|0;a[m+(v+3)|0]=a[q+y|0]|0;a[m+(v+4)|0]=a[t+(s+y)|0]|0;a[m+(v+5)|0]=a[w+y|0]|0;p=p+1|0;}while((p|0)<(o|0));return}function Ywb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)>0){m=0}else{return}do{n=m<<1;o=(b[e+(n<<1)>>1]|0)+64>>7;p=(b[e+((n|1)<<1)>>1]|0)+64>>7;n=((b[h+(m<<1)>>1]|0)+64>>7)+128|0;q=c[d+4352+(n<<2)>>2]|0;r=((b[l+(m<<1)>>1]|0)+64>>7)+128|0;s=c[d+6400+(r<<2)>>2]|0;t=c[d+2304+(n<<2)>>2]|0;n=c[d+8448+(r<<2)>>2]|0;r=m*6|0;a[i+r|0]=a[n+o|0]|0;a[i+(r|1)|0]=a[s+(t+o)|0]|0;a[i+(r+2)|0]=a[q+o|0]|0;a[i+(r+3)|0]=a[n+p|0]|0;a[i+(r+4)|0]=a[s+(t+p)|0]|0;a[i+(r+5)|0]=a[q+p|0]|0;m=m+1|0;}while((m|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)>0){u=0}else{return}do{j=u<<1;m=(b[e+(j<<1)>>1]|0)+64>>7;p=(b[e+((j|1)<<1)>>1]|0)+64>>7;j=((b[h+(u<<1)>>1]|0)+128+(b[f+(u<<1)>>1]|0)>>8)+128|0;q=c[d+4352+(j<<2)>>2]|0;r=((b[l+(u<<1)>>1]|0)+128+(b[k+(u<<1)>>1]|0)>>8)+128|0;t=c[d+6400+(r<<2)>>2]|0;s=c[d+2304+(j<<2)>>2]|0;j=c[d+8448+(r<<2)>>2]|0;r=u*6|0;a[i+r|0]=a[j+m|0]|0;a[i+(r|1)|0]=a[t+(s+m)|0]|0;a[i+(r+2)|0]=a[q+m|0]|0;a[i+(r+3)|0]=a[j+p|0]|0;a[i+(r+4)|0]=a[t+(s+p)|0]|0;a[i+(r+5)|0]=a[q+p|0]|0;u=u+1|0;}while((u|0)<(g|0));return}}function Zwb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;q=j+1>>1;if((q|0)>0){r=0}else{return}do{j=r<<1;s=ba(b[m+(j<<1)>>1]|0,g)|0;t=(ba(b[h+(j<<1)>>1]|0,k)|0)+s>>19;s=j|1;j=ba(b[m+(s<<1)>>1]|0,g)|0;u=(ba(b[h+(s<<1)>>1]|0,k)|0)+j>>19;j=ba(b[e+(r<<1)>>1]|0,p)|0;s=(ba(b[n+(r<<1)>>1]|0,l)|0)+j>>19;j=ba(b[f+(r<<1)>>1]|0,p)|0;v=((ba(b[o+(r<<1)>>1]|0,l)|0)+j>>19)+128|0;j=c[d+4352+(v<<2)>>2]|0;w=s+128|0;s=c[d+6400+(w<<2)>>2]|0;x=c[d+2304+(v<<2)>>2]|0;v=c[d+8448+(w<<2)>>2]|0;w=r*6|0;a[i+w|0]=a[v+t|0]|0;a[i+(w|1)|0]=a[s+(x+t)|0]|0;a[i+(w+2)|0]=a[j+t|0]|0;a[i+(w+3)|0]=a[v+u|0]|0;a[i+(w+4)|0]=a[s+(x+u)|0]|0;a[i+(w+5)|0]=a[j+u|0]|0;r=r+1|0;}while((r|0)<(q|0));return}function _wb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;o=n+1>>1;if((o|0)<=0){return}n=(g|0)>0;l=(k|0)>0;p=0;do{if(n){q=p<<1;r=q|1;s=262144;t=262144;u=0;do{v=c[f+(u<<2)>>2]|0;w=b[e+(u<<1)>>1]|0;s=(ba(w,b[v+(q<<1)>>1]|0)|0)+s|0;t=(ba(b[v+(r<<1)>>1]|0,w)|0)+t|0;u=u+1|0;}while((u|0)<(g|0));x=s>>19;y=t>>19}else{x=0;y=0}if(l){u=262144;r=262144;q=0;do{w=b[h+(q<<1)>>1]|0;u=(ba(w,b[(c[i+(q<<2)>>2]|0)+(p<<1)>>1]|0)|0)+u|0;r=(ba(b[(c[j+(q<<2)>>2]|0)+(p<<1)>>1]|0,w)|0)+r|0;q=q+1|0;}while((q|0)<(k|0));z=(u>>19)+128|0;A=(r>>19)+128|0}else{z=128;A=128}q=c[d+4352+(A<<2)>>2]|0;t=c[d+6400+(z<<2)>>2]|0;s=c[d+2304+(A<<2)>>2]|0;w=c[d+8448+(z<<2)>>2]|0;v=p*6|0;a[m+v|0]=a[w+x|0]|0;a[m+(v|1)|0]=a[t+(s+x)|0]|0;a[m+(v+2)|0]=a[q+x|0]|0;a[m+(v+3)|0]=a[w+y|0]|0;a[m+(v+4)|0]=a[t+(s+y)|0]|0;a[m+(v+5)|0]=a[q+y|0]|0;p=p+1|0;}while((p|0)<(o|0));return}function $wb(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){return}n=i;o=l&1;p=o^1;q=d[1233008+(o<<3)|0]|0;r=d[1233032+(o<<3)|0]|0;s=d[1233009+(o<<3)|0]|0;t=d[1233033+(o<<3)|0]|0;o=d[1233008+(p<<3)|0]|0;u=d[1233009+(p<<3)|0]|0;p=0;do{v=p<<1;w=(b[e+(v<<1)>>1]|0)+64>>7;x=v|1;y=(b[e+(x<<1)>>1]|0)+64>>7;z=((b[m+(p<<1)>>1]|0)+64>>7)+128|0;A=((b[h+(p<<1)>>1]|0)+64>>7)+128|0;B=c[a+4352+(z<<2)>>2]|0;C=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;z=c[a+8448+(A<<2)>>2]|0;b[n+(v<<1)>>1]=((b[C+(r+w<<1)>>1]|0)+(b[B+(q+w<<1)>>1]|0)&65535)+(b[z+(o+w<<1)>>1]|0);b[n+(x<<1)>>1]=((b[C+(t+y<<1)>>1]|0)+(b[B+(s+y<<1)>>1]|0)&65535)+(b[z+(u+y<<1)>>1]|0);p=p+1|0;}while((p|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)<=0){return}j=i;i=l&1;l=i^1;p=d[1233008+(i<<3)|0]|0;u=d[1233032+(i<<3)|0]|0;s=d[1233009+(i<<3)|0]|0;t=d[1233033+(i<<3)|0]|0;i=d[1233008+(l<<3)|0]|0;n=d[1233009+(l<<3)|0]|0;l=0;do{o=l<<1;q=(b[e+(o<<1)>>1]|0)+64>>7;r=o|1;y=(b[e+(r<<1)>>1]|0)+64>>7;z=((b[m+(l<<1)>>1]|0)+128+(b[f+(l<<1)>>1]|0)>>8)+128|0;B=((b[h+(l<<1)>>1]|0)+128+(b[k+(l<<1)>>1]|0)>>8)+128|0;C=c[a+4352+(z<<2)>>2]|0;x=(c[a+6400+(B<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;z=c[a+8448+(B<<2)>>2]|0;b[j+(o<<1)>>1]=((b[x+(u+q<<1)>>1]|0)+(b[C+(p+q<<1)>>1]|0)&65535)+(b[z+(i+q<<1)>>1]|0);b[j+(r<<1)>>1]=((b[x+(t+y<<1)>>1]|0)+(b[C+(s+y<<1)>>1]|0)&65535)+(b[z+(n+y<<1)>>1]|0);l=l+1|0;}while((l|0)<(g|0));return}}function axb(a,e,f,g,h,i,j,k,l,m){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){return}j=i;i=m&1;m=i^1;s=d[1233008+(i<<3)|0]|0;t=d[1233032+(i<<3)|0]|0;u=d[1233009+(i<<3)|0]|0;v=d[1233033+(i<<3)|0]|0;i=d[1233008+(m<<3)|0]|0;w=d[1233009+(m<<3)|0]|0;m=0;do{x=m<<1;y=ba(b[h+(x<<1)>>1]|0,g)|0;z=(ba(b[n+(x<<1)>>1]|0,k)|0)+y>>19;y=x|1;A=ba(b[h+(y<<1)>>1]|0,g)|0;B=(ba(b[n+(y<<1)>>1]|0,k)|0)+A>>19;A=ba(b[e+(m<<1)>>1]|0,q)|0;C=(ba(b[o+(m<<1)>>1]|0,l)|0)+A>>19;A=ba(b[f+(m<<1)>>1]|0,q)|0;D=((ba(b[p+(m<<1)>>1]|0,l)|0)+A>>19)+128|0;A=C+128|0;C=c[a+4352+(D<<2)>>2]|0;E=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(D<<2)>>2]|0)|0;D=c[a+8448+(A<<2)>>2]|0;b[j+(x<<1)>>1]=((b[E+(t+z<<1)>>1]|0)+(b[C+(s+z<<1)>>1]|0)&65535)+(b[D+(i+z<<1)>>1]|0);b[j+(y<<1)>>1]=((b[E+(v+B<<1)>>1]|0)+(b[C+(u+B<<1)>>1]|0)&65535)+(b[D+(w+B<<1)>>1]|0);m=m+1|0;}while((m|0)<(r|0));return}function bxb(a,e,f,g,h,i,j,k,l,m,n,o){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;l=n+1>>1;if((l|0)<=0){return}n=(g|0)>0;p=(k|0)>0;q=m;m=o&1;o=m^1;r=d[1233008+(m<<3)|0]|0;s=d[1233032+(m<<3)|0]|0;t=d[1233009+(m<<3)|0]|0;u=d[1233033+(m<<3)|0]|0;m=d[1233008+(o<<3)|0]|0;v=d[1233009+(o<<3)|0]|0;o=0;do{if(n){w=o<<1;x=w|1;y=262144;z=262144;A=0;do{B=c[f+(A<<2)>>2]|0;C=b[e+(A<<1)>>1]|0;y=(ba(C,b[B+(w<<1)>>1]|0)|0)+y|0;z=(ba(b[B+(x<<1)>>1]|0,C)|0)+z|0;A=A+1|0;}while((A|0)<(g|0));D=y>>19;E=z>>19}else{D=0;E=0}if(p){A=262144;x=262144;w=0;do{C=b[h+(w<<1)>>1]|0;A=(ba(C,b[(c[i+(w<<2)>>2]|0)+(o<<1)>>1]|0)|0)+A|0;x=(ba(b[(c[j+(w<<2)>>2]|0)+(o<<1)>>1]|0,C)|0)+x|0;w=w+1|0;}while((w|0)<(k|0));F=(A>>19)+128|0;G=(x>>19)+128|0}else{F=128;G=128}w=c[a+4352+(G<<2)>>2]|0;z=(c[a+6400+(F<<2)>>2]|0)+(c[a+2304+(G<<2)>>2]|0)|0;y=c[a+8448+(F<<2)>>2]|0;C=o<<1;b[q+(C<<1)>>1]=((b[z+(s+D<<1)>>1]|0)+(b[w+(r+D<<1)>>1]|0)&65535)+(b[y+(m+D<<1)>>1]|0);b[q+((C|1)<<1)>>1]=((b[z+(u+E<<1)>>1]|0)+(b[w+(t+E<<1)>>1]|0)&65535)+(b[y+(v+E<<1)>>1]|0);o=o+1|0;}while((o|0)<(l|0));return}function cxb(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){return}n=i;o=l&1;p=o^1;q=d[1233008+(o<<3)|0]|0;r=d[1233009+(o<<3)|0]|0;o=d[1233008+(p<<3)|0]|0;s=d[1233009+(p<<3)|0]|0;p=0;do{t=p<<1;u=(b[e+(t<<1)>>1]|0)+64>>7;v=t|1;w=(b[e+(v<<1)>>1]|0)+64>>7;x=((b[m+(p<<1)>>1]|0)+64>>7)+128|0;y=((b[h+(p<<1)>>1]|0)+64>>7)+128|0;z=c[a+4352+(x<<2)>>2]|0;A=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(y<<2)>>2]|0;b[n+(t<<1)>>1]=((b[A+(r+u<<1)>>1]|0)+(b[z+(q+u<<1)>>1]|0)&65535)+(b[x+(o+u<<1)>>1]|0);b[n+(v<<1)>>1]=((b[A+(q+w<<1)>>1]|0)+(b[z+(r+w<<1)>>1]|0)&65535)+(b[x+(s+w<<1)>>1]|0);p=p+1|0;}while((p|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)<=0){return}j=i;i=l&1;l=i^1;p=d[1233008+(i<<3)|0]|0;s=d[1233009+(i<<3)|0]|0;i=d[1233008+(l<<3)|0]|0;r=d[1233009+(l<<3)|0]|0;l=0;do{q=l<<1;n=(b[e+(q<<1)>>1]|0)+64>>7;o=q|1;w=(b[e+(o<<1)>>1]|0)+64>>7;x=((b[m+(l<<1)>>1]|0)+128+(b[f+(l<<1)>>1]|0)>>8)+128|0;z=((b[h+(l<<1)>>1]|0)+128+(b[k+(l<<1)>>1]|0)>>8)+128|0;A=c[a+4352+(x<<2)>>2]|0;v=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(z<<2)>>2]|0;b[j+(q<<1)>>1]=((b[v+(s+n<<1)>>1]|0)+(b[A+(p+n<<1)>>1]|0)&65535)+(b[x+(i+n<<1)>>1]|0);b[j+(o<<1)>>1]=((b[v+(p+w<<1)>>1]|0)+(b[A+(s+w<<1)>>1]|0)&65535)+(b[x+(r+w<<1)>>1]|0);l=l+1|0;}while((l|0)<(g|0));return}}function dxb(a,e,f,g,h,i,j,k,l,m){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){return}j=i;i=m&1;m=i^1;s=d[1233008+(i<<3)|0]|0;t=d[1233009+(i<<3)|0]|0;i=d[1233008+(m<<3)|0]|0;u=d[1233009+(m<<3)|0]|0;m=0;do{v=m<<1;w=ba(b[h+(v<<1)>>1]|0,g)|0;x=(ba(b[n+(v<<1)>>1]|0,k)|0)+w>>19;w=v|1;y=ba(b[h+(w<<1)>>1]|0,g)|0;z=(ba(b[n+(w<<1)>>1]|0,k)|0)+y>>19;y=ba(b[e+(m<<1)>>1]|0,q)|0;A=(ba(b[o+(m<<1)>>1]|0,l)|0)+y>>19;y=ba(b[f+(m<<1)>>1]|0,q)|0;B=((ba(b[p+(m<<1)>>1]|0,l)|0)+y>>19)+128|0;y=A+128|0;A=c[a+4352+(B<<2)>>2]|0;C=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(B<<2)>>2]|0)|0;B=c[a+8448+(y<<2)>>2]|0;b[j+(v<<1)>>1]=((b[C+(t+x<<1)>>1]|0)+(b[A+(s+x<<1)>>1]|0)&65535)+(b[B+(i+x<<1)>>1]|0);b[j+(w<<1)>>1]=((b[C+(s+z<<1)>>1]|0)+(b[A+(t+z<<1)>>1]|0)&65535)+(b[B+(u+z<<1)>>1]|0);m=m+1|0;}while((m|0)<(r|0));return}function exb(a,e,f,g,h,i,j,k,l,m,n,o){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;l=n+1>>1;if((l|0)<=0){return}n=(g|0)>0;p=(k|0)>0;q=m;m=o&1;o=m^1;r=d[1233008+(m<<3)|0]|0;s=d[1233009+(m<<3)|0]|0;m=d[1233008+(o<<3)|0]|0;t=d[1233009+(o<<3)|0]|0;o=0;do{if(n){u=o<<1;v=u|1;w=262144;x=262144;y=0;do{z=c[f+(y<<2)>>2]|0;A=b[e+(y<<1)>>1]|0;w=(ba(A,b[z+(u<<1)>>1]|0)|0)+w|0;x=(ba(b[z+(v<<1)>>1]|0,A)|0)+x|0;y=y+1|0;}while((y|0)<(g|0));B=w>>19;C=x>>19}else{B=0;C=0}if(p){y=262144;v=262144;u=0;do{A=b[h+(u<<1)>>1]|0;y=(ba(A,b[(c[i+(u<<2)>>2]|0)+(o<<1)>>1]|0)|0)+y|0;v=(ba(b[(c[j+(u<<2)>>2]|0)+(o<<1)>>1]|0,A)|0)+v|0;u=u+1|0;}while((u|0)<(k|0));D=(y>>19)+128|0;E=(v>>19)+128|0}else{D=128;E=128}u=c[a+4352+(E<<2)>>2]|0;x=(c[a+6400+(D<<2)>>2]|0)+(c[a+2304+(E<<2)>>2]|0)|0;w=c[a+8448+(D<<2)>>2]|0;A=o<<1;b[q+(A<<1)>>1]=((b[x+(s+B<<1)>>1]|0)+(b[u+(r+B<<1)>>1]|0)&65535)+(b[w+(m+B<<1)>>1]|0);b[q+((A|1)<<1)>>1]=((b[x+(r+C<<1)>>1]|0)+(b[u+(s+C<<1)>>1]|0)&65535)+(b[w+(t+C<<1)>>1]|0);o=o+1|0;}while((o|0)<(l|0));return}function fxb(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){return}n=i;o=l&3;p=o^3;q=d[1232968+(o<<3)|0]|0;r=d[1232969+(o<<3)|0]|0;o=d[1232968+(p<<3)|0]|0;s=d[1232969+(p<<3)|0]|0;p=0;do{t=p<<1;u=(b[e+(t<<1)>>1]|0)+64>>7;v=t|1;w=(b[e+(v<<1)>>1]|0)+64>>7;x=((b[m+(p<<1)>>1]|0)+64>>7)+128|0;y=((b[h+(p<<1)>>1]|0)+64>>7)+128|0;z=c[a+4352+(x<<2)>>2]|0;A=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(y<<2)>>2]|0;b[n+(t<<1)>>1]=((b[A+(r+u<<1)>>1]|0)+(b[z+(q+u<<1)>>1]|0)&65535)+(b[x+(o+u<<1)>>1]|0);b[n+(v<<1)>>1]=((b[A+(q+w<<1)>>1]|0)+(b[z+(r+w<<1)>>1]|0)&65535)+(b[x+(s+w<<1)>>1]|0);p=p+1|0;}while((p|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)<=0){return}j=i;i=l&3;l=i^3;p=d[1232968+(i<<3)|0]|0;s=d[1232969+(i<<3)|0]|0;i=d[1232968+(l<<3)|0]|0;r=d[1232969+(l<<3)|0]|0;l=0;do{q=l<<1;n=(b[e+(q<<1)>>1]|0)+64>>7;o=q|1;w=(b[e+(o<<1)>>1]|0)+64>>7;x=((b[m+(l<<1)>>1]|0)+128+(b[f+(l<<1)>>1]|0)>>8)+128|0;z=((b[h+(l<<1)>>1]|0)+128+(b[k+(l<<1)>>1]|0)>>8)+128|0;A=c[a+4352+(x<<2)>>2]|0;v=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(z<<2)>>2]|0;b[j+(q<<1)>>1]=((b[v+(s+n<<1)>>1]|0)+(b[A+(p+n<<1)>>1]|0)&65535)+(b[x+(i+n<<1)>>1]|0);b[j+(o<<1)>>1]=((b[v+(p+w<<1)>>1]|0)+(b[A+(s+w<<1)>>1]|0)&65535)+(b[x+(r+w<<1)>>1]|0);l=l+1|0;}while((l|0)<(g|0));return}}function gxb(a,e,f,g,h,i,j,k,l,m){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){return}j=i;i=m&3;m=i^3;s=d[1232968+(i<<3)|0]|0;t=d[1232969+(i<<3)|0]|0;i=d[1232968+(m<<3)|0]|0;u=d[1232969+(m<<3)|0]|0;m=0;do{v=m<<1;w=ba(b[h+(v<<1)>>1]|0,g)|0;x=(ba(b[n+(v<<1)>>1]|0,k)|0)+w>>19;w=v|1;y=ba(b[h+(w<<1)>>1]|0,g)|0;z=(ba(b[n+(w<<1)>>1]|0,k)|0)+y>>19;y=ba(b[e+(m<<1)>>1]|0,q)|0;A=(ba(b[o+(m<<1)>>1]|0,l)|0)+y>>19;y=ba(b[f+(m<<1)>>1]|0,q)|0;B=((ba(b[p+(m<<1)>>1]|0,l)|0)+y>>19)+128|0;y=A+128|0;A=c[a+4352+(B<<2)>>2]|0;C=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(B<<2)>>2]|0)|0;B=c[a+8448+(y<<2)>>2]|0;b[j+(v<<1)>>1]=((b[C+(t+x<<1)>>1]|0)+(b[A+(s+x<<1)>>1]|0)&65535)+(b[B+(i+x<<1)>>1]|0);b[j+(w<<1)>>1]=((b[C+(s+z<<1)>>1]|0)+(b[A+(t+z<<1)>>1]|0)&65535)+(b[B+(u+z<<1)>>1]|0);m=m+1|0;}while((m|0)<(r|0));return}function hxb(a,e,f,g,h,i,j,k,l,m,n,o){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;l=n+1>>1;if((l|0)<=0){return}n=(g|0)>0;p=(k|0)>0;q=m;m=o&3;o=m^3;r=d[1232968+(m<<3)|0]|0;s=d[1232969+(m<<3)|0]|0;m=d[1232968+(o<<3)|0]|0;t=d[1232969+(o<<3)|0]|0;o=0;do{if(n){u=o<<1;v=u|1;w=262144;x=262144;y=0;do{z=c[f+(y<<2)>>2]|0;A=b[e+(y<<1)>>1]|0;w=(ba(A,b[z+(u<<1)>>1]|0)|0)+w|0;x=(ba(b[z+(v<<1)>>1]|0,A)|0)+x|0;y=y+1|0;}while((y|0)<(g|0));B=w>>19;C=x>>19}else{B=0;C=0}if(p){y=262144;v=262144;u=0;do{A=b[h+(u<<1)>>1]|0;y=(ba(A,b[(c[i+(u<<2)>>2]|0)+(o<<1)>>1]|0)|0)+y|0;v=(ba(b[(c[j+(u<<2)>>2]|0)+(o<<1)>>1]|0,A)|0)+v|0;u=u+1|0;}while((u|0)<(k|0));D=(y>>19)+128|0;E=(v>>19)+128|0}else{D=128;E=128}u=c[a+4352+(E<<2)>>2]|0;x=(c[a+6400+(D<<2)>>2]|0)+(c[a+2304+(E<<2)>>2]|0)|0;w=c[a+8448+(D<<2)>>2]|0;A=o<<1;b[q+(A<<1)>>1]=((b[x+(s+B<<1)>>1]|0)+(b[u+(r+B<<1)>>1]|0)&65535)+(b[w+(m+B<<1)>>1]|0);b[q+((A|1)<<1)>>1]=((b[x+(r+C<<1)>>1]|0)+(b[u+(s+C<<1)>>1]|0)&65535)+(b[w+(t+C<<1)>>1]|0);o=o+1|0;}while((o|0)<(l|0));return}function ixb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;i=c[g>>2]|0;n=c[h>>2]|0;if((l|0)<2048){l=k+1>>1;if((l|0)<=0){return}o=m&7;p=0;do{q=p<<1;r=(b[f+(q<<1)>>1]|0)+64>>7;s=q|1;t=(b[f+(s<<1)>>1]|0)+64>>7;u=((b[n+(p<<1)>>1]|0)+64>>7)+128|0;v=c[e+4352+(u<<2)>>2]|0;w=((b[i+(p<<1)>>1]|0)+64>>7)+128|0;x=c[e+6400+(w<<2)>>2]|0;y=c[e+2304+(u<<2)>>2]|0;u=c[e+8448+(w<<2)>>2]|0;w=q&6;z=d[1232752+(o<<3)+w|0]|0;A=w|1;B=d[1232752+(o<<3)+A|0]|0;C=d[1232680+(o<<3)+A|0]|0;a[j+q|0]=((a[x+(y+r+z)|0]|0)+(a[v+(z+r)|0]|0)&255)+(a[u+((d[1232680+(o<<3)+w|0]|0)+r)|0]|0);a[j+s|0]=((a[x+(y+t+B)|0]|0)+(a[v+(B+t)|0]|0)&255)+(a[u+(C+t)|0]|0);p=p+1|0;}while((p|0)<(l|0));return}else{l=c[g+4>>2]|0;g=c[h+4>>2]|0;h=k+1>>1;if((h|0)<=0){return}k=m&7;m=0;do{p=m<<1;o=(b[f+(p<<1)>>1]|0)+64>>7;t=p|1;C=(b[f+(t<<1)>>1]|0)+64>>7;u=((b[n+(m<<1)>>1]|0)+128+(b[g+(m<<1)>>1]|0)>>8)+128|0;B=c[e+4352+(u<<2)>>2]|0;v=((b[i+(m<<1)>>1]|0)+128+(b[l+(m<<1)>>1]|0)>>8)+128|0;y=c[e+6400+(v<<2)>>2]|0;x=c[e+2304+(u<<2)>>2]|0;u=c[e+8448+(v<<2)>>2]|0;v=p&6;s=d[1232752+(k<<3)+v|0]|0;r=v|1;w=d[1232752+(k<<3)+r|0]|0;z=d[1232680+(k<<3)+r|0]|0;a[j+p|0]=((a[y+(x+o+s)|0]|0)+(a[B+(s+o)|0]|0)&255)+(a[u+((d[1232680+(k<<3)+v|0]|0)+o)|0]|0);a[j+t|0]=((a[y+(x+C+w)|0]|0)+(a[B+(w+C)|0]|0)&255)+(a[u+(z+C)|0]|0);m=m+1|0;}while((m|0)<(h|0));return}}function jxb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;i=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-l|0;r=4096-m|0;s=k+1>>1;if((s|0)<=0){return}k=n&7;n=0;do{t=n<<1;u=ba(b[i+(t<<1)>>1]|0,h)|0;v=(ba(b[o+(t<<1)>>1]|0,l)|0)+u>>19;u=t|1;w=ba(b[i+(u<<1)>>1]|0,h)|0;x=(ba(b[o+(u<<1)>>1]|0,l)|0)+w>>19;w=ba(b[f+(n<<1)>>1]|0,r)|0;y=(ba(b[p+(n<<1)>>1]|0,m)|0)+w>>19;w=ba(b[g+(n<<1)>>1]|0,r)|0;z=((ba(b[q+(n<<1)>>1]|0,m)|0)+w>>19)+128|0;w=c[e+4352+(z<<2)>>2]|0;A=y+128|0;y=c[e+6400+(A<<2)>>2]|0;B=c[e+2304+(z<<2)>>2]|0;z=c[e+8448+(A<<2)>>2]|0;A=t&6;C=d[1232752+(k<<3)+A|0]|0;D=A|1;E=d[1232752+(k<<3)+D|0]|0;F=d[1232680+(k<<3)+D|0]|0;a[j+t|0]=((a[y+(B+v+C)|0]|0)+(a[w+(C+v)|0]|0)&255)+(a[z+((d[1232680+(k<<3)+A|0]|0)+v)|0]|0);a[j+u|0]=((a[y+(B+x+E)|0]|0)+(a[w+(E+x)|0]|0)&255)+(a[z+(F+x)|0]|0);n=n+1|0;}while((n|0)<(s|0));return}function kxb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;m=o+1>>1;if((m|0)<=0){return}o=(h|0)>0;q=(l|0)>0;r=p&7;p=0;do{if(o){s=p<<1;t=s|1;u=262144;v=262144;w=0;do{x=c[g+(w<<2)>>2]|0;y=b[f+(w<<1)>>1]|0;u=(ba(y,b[x+(s<<1)>>1]|0)|0)+u|0;v=(ba(b[x+(t<<1)>>1]|0,y)|0)+v|0;w=w+1|0;}while((w|0)<(h|0));z=u>>19;A=v>>19}else{z=0;A=0}if(q){w=262144;t=262144;s=0;do{y=b[i+(s<<1)>>1]|0;w=(ba(y,b[(c[j+(s<<2)>>2]|0)+(p<<1)>>1]|0)|0)+w|0;t=(ba(b[(c[k+(s<<2)>>2]|0)+(p<<1)>>1]|0,y)|0)+t|0;s=s+1|0;}while((s|0)<(l|0));B=(w>>19)+128|0;C=(t>>19)+128|0}else{B=128;C=128}s=c[e+4352+(C<<2)>>2]|0;v=c[e+6400+(B<<2)>>2]|0;u=c[e+2304+(C<<2)>>2]|0;y=c[e+8448+(B<<2)>>2]|0;x=p<<1;D=x&6;E=d[1232752+(r<<3)+D|0]|0;F=D|1;G=d[1232752+(r<<3)+F|0]|0;H=d[1232680+(r<<3)+F|0]|0;a[n+x|0]=((a[v+(u+z+E)|0]|0)+(a[s+(E+z)|0]|0)&255)+(a[y+((d[1232680+(r<<3)+D|0]|0)+z)|0]|0);a[n+(x|1)|0]=((a[v+(u+A+G)|0]|0)+(a[s+(G+A)|0]|0)&255)+(a[y+(H+A)|0]|0);p=p+1|0;}while((p|0)<(m|0));return}function lxb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=c[g>>2]|0;n=c[h>>2]|0;if((l|0)<2048){l=k+1>>1;if((l|0)<=0){return}o=m&7;p=0;do{q=p<<1;r=(b[f+(q<<1)>>1]|0)+64>>7;s=(b[f+((q|1)<<1)>>1]|0)+64>>7;t=((b[n+(p<<1)>>1]|0)+64>>7)+128|0;u=c[e+4352+(t<<2)>>2]|0;v=((b[i+(p<<1)>>1]|0)+64>>7)+128|0;w=c[e+6400+(v<<2)>>2]|0;x=c[e+2304+(t<<2)>>2]|0;t=c[e+8448+(v<<2)>>2]|0;v=q&6;q=v|1;y=(d[1232824+(o<<3)+v|0]|0)+r|0;z=(d[1232824+(o<<3)+q|0]|0)+s|0;a[j+p|0]=(((a[w+(x+r+(d[1232680+(o<<3)+v|0]|0))|0]|0)+(a[u+y|0]|0)&255)+(a[t+y|0]|0)&255)+((((a[w+(x+s+(d[1232680+(o<<3)+q|0]|0))|0]|0)+(a[u+z|0]|0)&255)+(a[t+z|0]|0)&255)<<4);p=p+1|0;}while((p|0)<(l|0));return}else{l=c[g+4>>2]|0;g=c[h+4>>2]|0;h=k+1>>1;if((h|0)<=0){return}k=m&7;m=0;do{p=m<<1;o=(b[f+(p<<1)>>1]|0)+64>>7;z=(b[f+((p|1)<<1)>>1]|0)+64>>7;t=((b[n+(m<<1)>>1]|0)+128+(b[g+(m<<1)>>1]|0)>>8)+128|0;u=c[e+4352+(t<<2)>>2]|0;q=((b[i+(m<<1)>>1]|0)+128+(b[l+(m<<1)>>1]|0)>>8)+128|0;s=c[e+6400+(q<<2)>>2]|0;x=c[e+2304+(t<<2)>>2]|0;t=c[e+8448+(q<<2)>>2]|0;q=p&6;p=q|1;w=(d[1232824+(k<<3)+q|0]|0)+o|0;y=(d[1232824+(k<<3)+p|0]|0)+z|0;a[j+m|0]=(((a[s+(x+o+(d[1232680+(k<<3)+q|0]|0))|0]|0)+(a[u+w|0]|0)&255)+(a[t+w|0]|0)&255)+((((a[s+(x+z+(d[1232680+(k<<3)+p|0]|0))|0]|0)+(a[u+y|0]|0)&255)+(a[t+y|0]|0)&255)<<4);m=m+1|0;}while((m|0)<(h|0));return}}function mxb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;i=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-l|0;r=4096-m|0;s=k+1>>1;if((s|0)<=0){return}k=n&7;n=0;do{t=n<<1;u=ba(b[i+(t<<1)>>1]|0,h)|0;v=(ba(b[o+(t<<1)>>1]|0,l)|0)+u>>19;u=t|1;w=ba(b[i+(u<<1)>>1]|0,h)|0;x=(ba(b[o+(u<<1)>>1]|0,l)|0)+w>>19;w=ba(b[f+(n<<1)>>1]|0,r)|0;u=(ba(b[p+(n<<1)>>1]|0,m)|0)+w>>19;w=ba(b[g+(n<<1)>>1]|0,r)|0;y=((ba(b[q+(n<<1)>>1]|0,m)|0)+w>>19)+128|0;w=c[e+4352+(y<<2)>>2]|0;z=u+128|0;u=c[e+6400+(z<<2)>>2]|0;A=c[e+2304+(y<<2)>>2]|0;y=c[e+8448+(z<<2)>>2]|0;z=t&6;t=z|1;B=(d[1232824+(k<<3)+z|0]|0)+v|0;C=(d[1232824+(k<<3)+t|0]|0)+x|0;a[j+n|0]=(((a[u+(A+v+(d[1232680+(k<<3)+z|0]|0))|0]|0)+(a[w+B|0]|0)&255)+(a[y+B|0]|0)&255)+((((a[u+(A+x+(d[1232680+(k<<3)+t|0]|0))|0]|0)+(a[w+C|0]|0)&255)+(a[y+C|0]|0)&255)<<4);n=n+1|0;}while((n|0)<(s|0));return}function nxb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;m=o+1>>1;if((m|0)<=0){return}o=(h|0)>0;q=(l|0)>0;r=p&7;p=0;do{if(o){s=p<<1;t=s|1;u=262144;v=262144;w=0;do{x=c[g+(w<<2)>>2]|0;y=b[f+(w<<1)>>1]|0;u=(ba(y,b[x+(s<<1)>>1]|0)|0)+u|0;v=(ba(b[x+(t<<1)>>1]|0,y)|0)+v|0;w=w+1|0;}while((w|0)<(h|0));z=u>>19;A=v>>19}else{z=0;A=0}if(q){w=262144;t=262144;s=0;do{y=b[i+(s<<1)>>1]|0;w=(ba(y,b[(c[j+(s<<2)>>2]|0)+(p<<1)>>1]|0)|0)+w|0;t=(ba(b[(c[k+(s<<2)>>2]|0)+(p<<1)>>1]|0,y)|0)+t|0;s=s+1|0;}while((s|0)<(l|0));B=(w>>19)+128|0;C=(t>>19)+128|0}else{B=128;C=128}s=c[e+4352+(C<<2)>>2]|0;v=c[e+6400+(B<<2)>>2]|0;u=c[e+2304+(C<<2)>>2]|0;y=c[e+8448+(B<<2)>>2]|0;x=p<<1&6;D=x|1;E=(d[1232824+(r<<3)+x|0]|0)+z|0;F=(d[1232824+(r<<3)+D|0]|0)+A|0;a[n+p|0]=(((a[v+(u+z+(d[1232680+(r<<3)+x|0]|0))|0]|0)+(a[s+E|0]|0)&255)+(a[y+E|0]|0)&255)+((((a[v+(u+A+(d[1232680+(r<<3)+D|0]|0))|0]|0)+(a[s+F|0]|0)&255)+(a[y+F|0]|0)&255)<<4);p=p+1|0;}while((p|0)<(m|0));return}function oxb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c[g>>2]|0;n=c[h>>2]|0;if((l|0)<2048){l=k+1>>1;if((l|0)<=0){return}o=m&7;p=0;do{q=p<<1;r=(b[f+(q<<1)>>1]|0)+64>>7;s=q|1;t=(b[f+(s<<1)>>1]|0)+64>>7;u=((b[n+(p<<1)>>1]|0)+64>>7)+128|0;v=c[e+4352+(u<<2)>>2]|0;w=((b[i+(p<<1)>>1]|0)+64>>7)+128|0;x=c[e+6400+(w<<2)>>2]|0;y=c[e+2304+(u<<2)>>2]|0;u=c[e+8448+(w<<2)>>2]|0;w=q&6;z=w|1;A=d[1232824+(o<<3)+z|0]|0;B=d[1232680+(o<<3)+z|0]|0;z=(d[1232824+(o<<3)+w|0]|0)+r|0;a[j+q|0]=((a[x+(y+r+(d[1232680+(o<<3)+w|0]|0))|0]|0)+(a[v+z|0]|0)&255)+(a[u+z|0]|0);z=A+t|0;a[j+s|0]=((a[x+(y+t+B)|0]|0)+(a[v+z|0]|0)&255)+(a[u+z|0]|0);p=p+1|0;}while((p|0)<(l|0));return}else{l=c[g+4>>2]|0;g=c[h+4>>2]|0;h=k+1>>1;if((h|0)<=0){return}k=m&7;m=0;do{p=m<<1;o=(b[f+(p<<1)>>1]|0)+64>>7;z=p|1;u=(b[f+(z<<1)>>1]|0)+64>>7;v=((b[n+(m<<1)>>1]|0)+128+(b[g+(m<<1)>>1]|0)>>8)+128|0;B=c[e+4352+(v<<2)>>2]|0;t=((b[i+(m<<1)>>1]|0)+128+(b[l+(m<<1)>>1]|0)>>8)+128|0;y=c[e+6400+(t<<2)>>2]|0;x=c[e+2304+(v<<2)>>2]|0;v=c[e+8448+(t<<2)>>2]|0;t=p&6;s=t|1;A=d[1232824+(k<<3)+s|0]|0;w=d[1232680+(k<<3)+s|0]|0;s=(d[1232824+(k<<3)+t|0]|0)+o|0;a[j+p|0]=((a[y+(x+o+(d[1232680+(k<<3)+t|0]|0))|0]|0)+(a[B+s|0]|0)&255)+(a[v+s|0]|0);s=A+u|0;a[j+z|0]=((a[y+(x+u+w)|0]|0)+(a[B+s|0]|0)&255)+(a[v+s|0]|0);m=m+1|0;}while((m|0)<(h|0));return}}function pxb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;i=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-l|0;r=4096-m|0;s=k+1>>1;if((s|0)<=0){return}k=n&7;n=0;do{t=n<<1;u=ba(b[i+(t<<1)>>1]|0,h)|0;v=(ba(b[o+(t<<1)>>1]|0,l)|0)+u>>19;u=t|1;w=ba(b[i+(u<<1)>>1]|0,h)|0;x=(ba(b[o+(u<<1)>>1]|0,l)|0)+w>>19;w=ba(b[f+(n<<1)>>1]|0,r)|0;y=(ba(b[p+(n<<1)>>1]|0,m)|0)+w>>19;w=ba(b[g+(n<<1)>>1]|0,r)|0;z=((ba(b[q+(n<<1)>>1]|0,m)|0)+w>>19)+128|0;w=c[e+4352+(z<<2)>>2]|0;A=y+128|0;y=c[e+6400+(A<<2)>>2]|0;B=c[e+2304+(z<<2)>>2]|0;z=c[e+8448+(A<<2)>>2]|0;A=t&6;C=A|1;D=d[1232824+(k<<3)+C|0]|0;E=d[1232680+(k<<3)+C|0]|0;C=(d[1232824+(k<<3)+A|0]|0)+v|0;a[j+t|0]=((a[y+(B+v+(d[1232680+(k<<3)+A|0]|0))|0]|0)+(a[w+C|0]|0)&255)+(a[z+C|0]|0);C=D+x|0;a[j+u|0]=((a[y+(B+x+E)|0]|0)+(a[w+C|0]|0)&255)+(a[z+C|0]|0);n=n+1|0;}while((n|0)<(s|0));return}function qxb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;m=o+1>>1;if((m|0)<=0){return}o=(h|0)>0;q=(l|0)>0;r=p&7;p=0;do{if(o){s=p<<1;t=s|1;u=262144;v=262144;w=0;do{x=c[g+(w<<2)>>2]|0;y=b[f+(w<<1)>>1]|0;u=(ba(y,b[x+(s<<1)>>1]|0)|0)+u|0;v=(ba(b[x+(t<<1)>>1]|0,y)|0)+v|0;w=w+1|0;}while((w|0)<(h|0));z=u>>19;A=v>>19}else{z=0;A=0}if(q){w=262144;t=262144;s=0;do{y=b[i+(s<<1)>>1]|0;w=(ba(y,b[(c[j+(s<<2)>>2]|0)+(p<<1)>>1]|0)|0)+w|0;t=(ba(b[(c[k+(s<<2)>>2]|0)+(p<<1)>>1]|0,y)|0)+t|0;s=s+1|0;}while((s|0)<(l|0));B=(w>>19)+128|0;C=(t>>19)+128|0}else{B=128;C=128}s=c[e+4352+(C<<2)>>2]|0;v=c[e+6400+(B<<2)>>2]|0;u=c[e+2304+(C<<2)>>2]|0;y=c[e+8448+(B<<2)>>2]|0;x=p<<1;D=x&6;E=D|1;F=d[1232824+(r<<3)+E|0]|0;G=d[1232680+(r<<3)+E|0]|0;E=(d[1232824+(r<<3)+D|0]|0)+z|0;a[n+x|0]=((a[v+(u+z+(d[1232680+(r<<3)+D|0]|0))|0]|0)+(a[s+E|0]|0)&255)+(a[y+E|0]|0);E=F+A|0;a[n+(x|1)|0]=((a[v+(u+A+G)|0]|0)+(a[s+E|0]|0)&255)+(a[y+E|0]|0);p=p+1|0;}while((p|0)<(m|0));return}function rxb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=m&7;m=1232824+(l<<3)|0;i=(k|0)>0;if((c[e+23972>>2]|0)!=3){if(!i){return}h=d[m]|0;m=d[1232825+(l<<3)|0]|0;g=d[1232826+(l<<3)|0]|0;n=d[1232827+(l<<3)|0]|0;o=d[1232828+(l<<3)|0]|0;p=d[1232829+(l<<3)|0]|0;q=d[1232830+(l<<3)|0]|0;r=d[1232831+(l<<3)|0]|0;l=0;s=j;while(1){a[s]=~((((((((((b[f+((l|1)<<1)>>1]|0)+64>>7)+m|0)>237|((((b[f+(l<<1)>>1]|0)+64>>7)+h|0)>237)<<1)<<1|(((b[f+((l|2)<<1)>>1]|0)+64>>7)+g|0)>237)<<1|(((b[f+((l|3)<<1)>>1]|0)+64>>7)+n|0)>237)<<1|(((b[f+((l|4)<<1)>>1]|0)+64>>7)+o|0)>237)<<1|(((b[f+((l|5)<<1)>>1]|0)+64>>7)+p|0)>237)<<1|(((b[f+((l|6)<<1)>>1]|0)+64>>7)+q|0)>237)<<1|(((b[f+((l|7)<<1)>>1]|0)+64>>7)+r|0)>237);t=l+8|0;if((t|0)<(k|0)){l=t;s=s+1|0}else{break}}return}s=e+11200|0;a:do{if(i){e=0;l=0;r=0;q=j;while(1){p=c[s>>2]|0;o=p+(r<<2)|0;n=r|1;g=p+(n<<2)|0;h=c[g>>2]|0;m=r+2|0;t=c[p+(m<<2)>>2]|0;u=((e*7|0)-248+(c[o>>2]|0)+(h*5|0)+(t*3|0)>>4)+((b[f+(r<<1)>>1]|0)+64>>7)|0;c[o>>2]=e;o=(u|0)>127|0;v=u-(-o&220)|0;u=(h-248+(t*5|0)+((c[p+(r+3<<2)>>2]|0)*3|0)+(v*7|0)>>4)+((b[f+(n<<1)>>1]|0)+64>>7)|0;c[g>>2]=v;v=(u|0)>127|0;g=v|(o|l)<<1;o=u-(-v&220)|0;if((r&6|0)==6){a[q]=g^255;w=q+1|0}else{w=q}if((m|0)>=(k|0)){x=o;y=m;break a}e=o;l=g<<1;r=m;q=w}}else{x=0;y=0}}while(0);c[(c[s>>2]|0)+(y<<2)>>2]=x;return}function sxb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=c[f>>2]|0;i=c[f+4>>2]|0;f=n&7;n=1232824+(f<<3)|0;h=4096-l|0;g=(k|0)>0;if((c[e+23972>>2]|0)!=3){if(!g){return}o=d[n]|0;n=d[1232825+(f<<3)|0]|0;p=d[1232826+(f<<3)|0]|0;q=d[1232827+(f<<3)|0]|0;r=d[1232828+(f<<3)|0]|0;s=d[1232829+(f<<3)|0]|0;t=d[1232830+(f<<3)|0]|0;u=d[1232831+(f<<3)|0]|0;f=0;v=j;while(1){w=ba(b[m+(f<<1)>>1]|0,h)|0;x=(((ba(b[i+(f<<1)>>1]|0,l)|0)+w>>19)+o|0)>237|0;w=f|1;y=ba(b[m+(w<<1)>>1]|0,h)|0;z=(((ba(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+n|0)>237|x<<1;x=f|2;y=ba(b[m+(x<<1)>>1]|0,h)|0;w=(((ba(b[i+(x<<1)>>1]|0,l)|0)+y>>19)+p|0)>237|z<<1;z=f|3;y=ba(b[m+(z<<1)>>1]|0,h)|0;x=(((ba(b[i+(z<<1)>>1]|0,l)|0)+y>>19)+q|0)>237|w<<1;w=f|4;y=ba(b[m+(w<<1)>>1]|0,h)|0;z=(((ba(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+r|0)>237|x<<1;x=f|5;y=ba(b[m+(x<<1)>>1]|0,h)|0;w=(((ba(b[i+(x<<1)>>1]|0,l)|0)+y>>19)+s|0)>237|z<<1;z=f|6;y=ba(b[m+(z<<1)>>1]|0,h)|0;x=(((ba(b[i+(z<<1)>>1]|0,l)|0)+y>>19)+t|0)>237|w<<1;w=f|7;y=ba(b[m+(w<<1)>>1]|0,h)|0;a[v]=~((((ba(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+u|0)>237|x<<1);x=f+8|0;if((x|0)<(k|0)){f=x;v=v+1|0}else{break}}return}v=e+11200|0;a:do{if(g){e=0;f=0;u=0;t=j;while(1){s=ba(b[m+(u<<1)>>1]|0,h)|0;r=(ba(b[i+(u<<1)>>1]|0,l)|0)+s>>19;s=c[v>>2]|0;q=s+(u<<2)|0;p=u|1;n=s+(p<<2)|0;o=c[n>>2]|0;x=u+2|0;y=c[s+(x<<2)>>2]|0;w=((f*7|0)-248+(c[q>>2]|0)+(o*5|0)+(y*3|0)>>4)+r|0;c[q>>2]=f;q=(w|0)>127|0;r=w-(-q&220)|0;w=ba(b[m+(p<<1)>>1]|0,h)|0;z=(ba(b[i+(p<<1)>>1]|0,l)|0)+w>>19;w=(o-248+(y*5|0)+((c[s+(u+3<<2)>>2]|0)*3|0)+(r*7|0)>>4)+z|0;c[n>>2]=r;r=(w|0)>127|0;n=r|(q|e)<<1;q=w-(-r&220)|0;if((u&6|0)==6){a[t]=n^255;A=t+1|0}else{A=t}if((x|0)>=(k|0)){B=q;C=x;break a}e=n<<1;f=q;u=x;t=A}}else{B=0;C=0}}while(0);c[(c[v>>2]|0)+(C<<2)>>2]=B;return}function txb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;m=p&7;if((o|0)<=0){c[c[e+11200>>2]>>2]=0;return}p=(h|0)>0;l=e+23972|0;k=e+11200|0;e=n;n=0;j=0;i=0;while(1){if(p){q=n|1;r=0;s=262144;t=262144;do{u=c[g+(r<<2)>>2]|0;v=b[f+(r<<1)>>1]|0;s=(ba(v,b[u+(n<<1)>>1]|0)|0)+s|0;t=(ba(b[u+(q<<1)>>1]|0,v)|0)+t|0;r=r+1|0;}while((r|0)<(h|0));w=s>>19;x=t>>19}else{w=0;x=0}if(((w|x)&256|0)==0){y=x;z=w}else{if(w>>>0>255>>>0){A=-w>>31&255}else{A=w&255}if(x>>>0>255>>>0){B=-x>>31&255}else{B=x&255}y=B&255;z=A&255}if((c[l>>2]|0)==3){r=c[k>>2]|0;q=r+(n<<2)|0;v=r+((n|1)<<2)|0;u=c[v>>2]|0;C=c[r+(n+2<<2)>>2]|0;D=((i*7|0)-248+(c[q>>2]|0)+(u*5|0)+(C*3|0)>>4)+z|0;c[q>>2]=i;q=(D|0)>127|0;E=D-(-q&220)|0;D=(u-248+(C*5|0)+((c[r+(n+3<<2)>>2]|0)*3|0)+(E*7|0)>>4)+y|0;c[v>>2]=E;E=(D|0)>127|0;F=D-(-E&220)|0;G=E|(q|j<<1)<<1;H=n&6}else{q=n&6;F=i;G=(((d[1232824+(m<<3)+q|0]|0)+z|0)>237|j<<1)<<1|((d[(q|1)+(1232824+(m<<3))|0]|0)+y|0)>237;H=q}if((H|0)==6){a[e]=G^255;I=e+1|0}else{I=e}J=n+2|0;if((J|0)<(o|0)){e=I;n=J;j=G;i=F}else{break}}c[(c[k>>2]|0)+(J<<2)>>2]=F;if((J&6|0)==0){return}a[I]=G^255;return}function uxb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=m&7;m=1232824+(l<<3)|0;i=(k|0)>0;if((c[e+23972>>2]|0)!=3){if(!i){return}h=d[m]|0;m=d[1232825+(l<<3)|0]|0;g=d[1232826+(l<<3)|0]|0;n=d[1232827+(l<<3)|0]|0;o=d[1232828+(l<<3)|0]|0;p=d[1232829+(l<<3)|0]|0;q=d[1232830+(l<<3)|0]|0;r=d[1232831+(l<<3)|0]|0;l=0;s=j;while(1){a[s]=(((((((((b[f+((l|1)<<1)>>1]|0)+64>>7)+m|0)>237|((((b[f+(l<<1)>>1]|0)+64>>7)+h|0)>237)<<1)<<1|(((b[f+((l|2)<<1)>>1]|0)+64>>7)+g|0)>237)<<1|(((b[f+((l|3)<<1)>>1]|0)+64>>7)+n|0)>237)<<1|(((b[f+((l|4)<<1)>>1]|0)+64>>7)+o|0)>237)<<1|(((b[f+((l|5)<<1)>>1]|0)+64>>7)+p|0)>237)<<1|(((b[f+((l|6)<<1)>>1]|0)+64>>7)+q|0)>237)<<1|(((b[f+((l|7)<<1)>>1]|0)+64>>7)+r|0)>237;t=l+8|0;if((t|0)<(k|0)){l=t;s=s+1|0}else{break}}return}s=e+11200|0;a:do{if(i){e=0;l=0;r=0;q=j;while(1){p=c[s>>2]|0;o=p+(r<<2)|0;n=r|1;g=p+(n<<2)|0;h=c[g>>2]|0;m=r+2|0;t=c[p+(m<<2)>>2]|0;u=((e*7|0)-248+(c[o>>2]|0)+(h*5|0)+(t*3|0)>>4)+((b[f+(r<<1)>>1]|0)+64>>7)|0;c[o>>2]=e;o=(u|0)>127|0;v=u-(-o&220)|0;u=(h-248+(t*5|0)+((c[p+(r+3<<2)>>2]|0)*3|0)+(v*7|0)>>4)+((b[f+(n<<1)>>1]|0)+64>>7)|0;c[g>>2]=v;v=(u|0)>127|0;g=v|(o|l)<<1;o=u-(-v&220)|0;if((r&6|0)==6){a[q]=g;w=q+1|0}else{w=q}if((m|0)>=(k|0)){x=o;y=m;break a}e=o;l=g<<1;r=m;q=w}}else{x=0;y=0}}while(0);c[(c[s>>2]|0)+(y<<2)>>2]=x;return}function vxb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=c[f>>2]|0;i=c[f+4>>2]|0;f=n&7;n=1232824+(f<<3)|0;h=4096-l|0;g=(k|0)>0;if((c[e+23972>>2]|0)!=3){if(!g){return}o=d[n]|0;n=d[1232825+(f<<3)|0]|0;p=d[1232826+(f<<3)|0]|0;q=d[1232827+(f<<3)|0]|0;r=d[1232828+(f<<3)|0]|0;s=d[1232829+(f<<3)|0]|0;t=d[1232830+(f<<3)|0]|0;u=d[1232831+(f<<3)|0]|0;f=0;v=j;while(1){w=ba(b[m+(f<<1)>>1]|0,h)|0;x=(((ba(b[i+(f<<1)>>1]|0,l)|0)+w>>19)+o|0)>237|0;w=f|1;y=ba(b[m+(w<<1)>>1]|0,h)|0;z=(((ba(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+n|0)>237|x<<1;x=f|2;y=ba(b[m+(x<<1)>>1]|0,h)|0;w=(((ba(b[i+(x<<1)>>1]|0,l)|0)+y>>19)+p|0)>237|z<<1;z=f|3;y=ba(b[m+(z<<1)>>1]|0,h)|0;x=(((ba(b[i+(z<<1)>>1]|0,l)|0)+y>>19)+q|0)>237|w<<1;w=f|4;y=ba(b[m+(w<<1)>>1]|0,h)|0;z=(((ba(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+r|0)>237|x<<1;x=f|5;y=ba(b[m+(x<<1)>>1]|0,h)|0;w=(((ba(b[i+(x<<1)>>1]|0,l)|0)+y>>19)+s|0)>237|z<<1;z=f|6;y=ba(b[m+(z<<1)>>1]|0,h)|0;x=(((ba(b[i+(z<<1)>>1]|0,l)|0)+y>>19)+t|0)>237|w<<1;w=f|7;y=ba(b[m+(w<<1)>>1]|0,h)|0;a[v]=(((ba(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+u|0)>237|x<<1;x=f+8|0;if((x|0)<(k|0)){f=x;v=v+1|0}else{break}}return}v=e+11200|0;a:do{if(g){e=0;f=0;u=0;t=j;while(1){s=ba(b[m+(u<<1)>>1]|0,h)|0;r=(ba(b[i+(u<<1)>>1]|0,l)|0)+s>>19;s=c[v>>2]|0;q=s+(u<<2)|0;p=u|1;n=s+(p<<2)|0;o=c[n>>2]|0;x=u+2|0;y=c[s+(x<<2)>>2]|0;w=((f*7|0)-248+(c[q>>2]|0)+(o*5|0)+(y*3|0)>>4)+r|0;c[q>>2]=f;q=(w|0)>127|0;r=w-(-q&220)|0;w=ba(b[m+(p<<1)>>1]|0,h)|0;z=(ba(b[i+(p<<1)>>1]|0,l)|0)+w>>19;w=(o-248+(y*5|0)+((c[s+(u+3<<2)>>2]|0)*3|0)+(r*7|0)>>4)+z|0;c[n>>2]=r;r=(w|0)>127|0;n=r|(q|e)<<1;q=w-(-r&220)|0;if((u&6|0)==6){a[t]=n;A=t+1|0}else{A=t}if((x|0)>=(k|0)){B=q;C=x;break a}e=n<<1;f=q;u=x;t=A}}else{B=0;C=0}}while(0);c[(c[v>>2]|0)+(C<<2)>>2]=B;return}function wxb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;m=p&7;if((o|0)<=0){c[c[e+11200>>2]>>2]=0;return}p=(h|0)>0;l=e+23972|0;k=e+11200|0;e=n;n=0;j=0;i=0;while(1){if(p){q=n|1;r=0;s=262144;t=262144;do{u=c[g+(r<<2)>>2]|0;v=b[f+(r<<1)>>1]|0;s=(ba(v,b[u+(n<<1)>>1]|0)|0)+s|0;t=(ba(b[u+(q<<1)>>1]|0,v)|0)+t|0;r=r+1|0;}while((r|0)<(h|0));w=s>>19;x=t>>19}else{w=0;x=0}if(((w|x)&256|0)==0){y=x;z=w}else{if(w>>>0>255>>>0){A=-w>>31&255}else{A=w&255}if(x>>>0>255>>>0){B=-x>>31&255}else{B=x&255}y=B&255;z=A&255}if((c[l>>2]|0)==3){r=c[k>>2]|0;q=r+(n<<2)|0;v=r+((n|1)<<2)|0;u=c[v>>2]|0;C=c[r+(n+2<<2)>>2]|0;D=((i*7|0)-248+(c[q>>2]|0)+(u*5|0)+(C*3|0)>>4)+z|0;c[q>>2]=i;q=(D|0)>127|0;E=D-(-q&220)|0;D=(u-248+(C*5|0)+((c[r+(n+3<<2)>>2]|0)*3|0)+(E*7|0)>>4)+y|0;c[v>>2]=E;E=(D|0)>127|0;F=D-(-E&220)|0;G=E|(q|j<<1)<<1;H=n&6}else{q=n&6;F=i;G=(((d[1232824+(m<<3)+q|0]|0)+z|0)>237|j<<1)<<1|((d[(q|1)+(1232824+(m<<3))|0]|0)+y|0)>237;H=q}if((H|0)==6){a[e]=G;I=e+1|0}else{I=e}J=n+2|0;if((J|0)<(o|0)){e=I;n=J;j=G;i=F}else{break}}c[(c[k>>2]|0)+(J<<2)>>2]=F;if((J&6|0)==0){return}a[I]=G;return}function xxb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)>0){m=0}else{return}do{d=m<<1;n=(b[e+(d<<1)>>1]|0)+64>>7;o=(b[e+((d|1)<<1)>>1]|0)+64>>7;d=(b[l+(m<<1)>>1]|0)+64>>7;p=(b[h+(m<<1)>>1]|0)+64>>7;q=n>>>0>255>>>0;r=n&255;do{if(((o|n|d|p)&256|0)==0){if(q){s=-n>>31&255}else{s=r}if(o>>>0>255>>>0){t=-o>>31&255}else{t=o&255}if(d>>>0>255>>>0){u=-d>>31&255}else{u=d&255}if(!(p>>>0>255>>>0)){v=p&255;w=t;x=s;y=u;break}v=-p>>31&255;w=t;x=s;y=u}else{if(q){z=-n>>31&255}else{z=r}if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}if(d>>>0>255>>>0){B=-d>>31&255}else{B=d&255}if(!(p>>>0>255>>>0)){v=p&255;w=A;x=z;y=B;break}v=-p>>31&255;w=A;x=z;y=B}}while(0);p=m<<2;a[i+p|0]=x;a[i+(p|1)|0]=y;a[i+(p|2)|0]=w;a[i+(p|3)|0]=v;m=m+1|0;}while((m|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)>0){C=0}else{return}do{j=C<<1;m=(b[e+(j<<1)>>1]|0)+64>>7;v=(b[e+((j|1)<<1)>>1]|0)+64>>7;j=(b[l+(C<<1)>>1]|0)+128+(b[k+(C<<1)>>1]|0)>>8;w=(b[h+(C<<1)>>1]|0)+128+(b[f+(C<<1)>>1]|0)>>8;y=m>>>0>255>>>0;x=m&255;do{if(((v|m|j|w)&256|0)==0){if(y){D=-m>>31&255}else{D=x}if(v>>>0>255>>>0){E=-v>>31&255}else{E=v&255}if(j>>>0>255>>>0){F=-j>>31&255}else{F=j&255}if(!(w>>>0>255>>>0)){G=w&255;H=E;I=D;J=F;break}G=-w>>31&255;H=E;I=D;J=F}else{if(y){K=-m>>31&255}else{K=x}if(v>>>0>255>>>0){L=-v>>31&255}else{L=v&255}if(j>>>0>255>>>0){M=-j>>31&255}else{M=j&255}if(!(w>>>0>255>>>0)){G=w&255;H=L;I=K;J=M;break}G=-w>>31&255;H=L;I=K;J=M}}while(0);w=C<<2;a[i+w|0]=I;a[i+(w|1)|0]=J;a[i+(w|2)|0]=H;a[i+(w|3)|0]=G;C=C+1|0;}while((C|0)<(g|0));return}}function yxb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;d=c[f+4>>2]|0;f=c[g>>2]|0;n=c[g+4>>2]|0;g=4096-k|0;o=4096-l|0;p=j+1>>1;if((p|0)>0){q=0}else{return}do{j=q<<1;r=ba(b[m+(j<<1)>>1]|0,g)|0;s=(ba(b[h+(j<<1)>>1]|0,k)|0)+r>>19;r=j|1;j=ba(b[m+(r<<1)>>1]|0,g)|0;t=(ba(b[h+(r<<1)>>1]|0,k)|0)+j>>19;j=ba(b[e+(q<<1)>>1]|0,o)|0;r=(ba(b[d+(q<<1)>>1]|0,l)|0)+j>>19;j=ba(b[f+(q<<1)>>1]|0,o)|0;u=(ba(b[n+(q<<1)>>1]|0,l)|0)+j>>19;j=s&255;v=t&255;w=r&255;x=u&255;do{if(((t|s|r|u)&256|0)==0){y=x;z=w;A=v;B=j}else{if(s>>>0>255>>>0){C=-s>>31&255}else{C=j}if(t>>>0>255>>>0){D=-t>>31&255}else{D=v}if(r>>>0>255>>>0){E=-r>>31&255}else{E=w}if(!(u>>>0>255>>>0)){y=x;z=E;A=D;B=C;break}y=-u>>31&255;z=E;A=D;B=C}}while(0);u=q<<2;a[i+u|0]=B;a[i+(u|1)|0]=z;a[i+(u|2)|0]=A;a[i+(u|3)|0]=y;q=q+1|0;}while((q|0)<(p|0));return}function zxb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;o=n+1>>1;if((o|0)<=0){return}n=(g|0)>0;l=(k|0)>0;d=0;do{if(n){p=d<<1;q=p|1;r=0;s=262144;t=262144;do{u=c[f+(r<<2)>>2]|0;v=b[e+(r<<1)>>1]|0;s=(ba(v,b[u+(p<<1)>>1]|0)|0)+s|0;t=(ba(b[u+(q<<1)>>1]|0,v)|0)+t|0;r=r+1|0;}while((r|0)<(g|0));w=s>>19;x=t>>19}else{w=0;x=0}if(l){r=0;q=262144;p=262144;do{v=b[h+(r<<1)>>1]|0;q=(ba(v,b[(c[i+(r<<2)>>2]|0)+(d<<1)>>1]|0)|0)+q|0;p=(ba(b[(c[j+(r<<2)>>2]|0)+(d<<1)>>1]|0,v)|0)+p|0;r=r+1|0;}while((r|0)<(k|0));y=q>>19;z=p>>19}else{y=0;z=0}r=w&255;t=x&255;s=y&255;v=z&255;do{if(((w|x|z|y)&256|0)==0){A=v;B=s;C=t;D=r}else{if(w>>>0>255>>>0){E=-w>>31&255}else{E=r}if(x>>>0>255>>>0){F=-x>>31&255}else{F=t}if(y>>>0>255>>>0){G=-y>>31&255}else{G=s}if(!(z>>>0>255>>>0)){A=v;B=G;C=F;D=E;break}A=-z>>31&255;B=G;C=F;D=E}}while(0);v=d<<2;a[m+v|0]=D;a[m+(v|1)|0]=B;a[m+(v|2)|0]=C;a[m+(v|3)|0]=A;d=d+1|0;}while((d|0)<(o|0));return}function Axb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)>0){m=0}else{return}do{d=m<<1;n=(b[e+(d<<1)>>1]|0)+64>>7;o=(b[e+((d|1)<<1)>>1]|0)+64>>7;d=(b[l+(m<<1)>>1]|0)+64>>7;p=(b[h+(m<<1)>>1]|0)+64>>7;q=n>>>0>255>>>0;r=n&255;do{if(((o|n|d|p)&256|0)==0){if(q){s=-n>>31&255}else{s=r}if(o>>>0>255>>>0){t=-o>>31&255}else{t=o&255}if(d>>>0>255>>>0){u=-d>>31&255}else{u=d&255}if(!(p>>>0>255>>>0)){v=p&255;w=t;x=s;y=u;break}v=-p>>31&255;w=t;x=s;y=u}else{if(q){z=-n>>31&255}else{z=r}if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}if(d>>>0>255>>>0){B=-d>>31&255}else{B=d&255}if(!(p>>>0>255>>>0)){v=p&255;w=A;x=z;y=B;break}v=-p>>31&255;w=A;x=z;y=B}}while(0);p=m<<2;a[i+p|0]=y;a[i+(p|1)|0]=x;a[i+(p|2)|0]=v;a[i+(p|3)|0]=w;m=m+1|0;}while((m|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)>0){C=0}else{return}do{j=C<<1;m=(b[e+(j<<1)>>1]|0)+64>>7;w=(b[e+((j|1)<<1)>>1]|0)+64>>7;j=(b[l+(C<<1)>>1]|0)+128+(b[k+(C<<1)>>1]|0)>>8;v=(b[h+(C<<1)>>1]|0)+128+(b[f+(C<<1)>>1]|0)>>8;x=m>>>0>255>>>0;y=m&255;do{if(((w|m|j|v)&256|0)==0){if(x){D=-m>>31&255}else{D=y}if(w>>>0>255>>>0){E=-w>>31&255}else{E=w&255}if(j>>>0>255>>>0){F=-j>>31&255}else{F=j&255}if(!(v>>>0>255>>>0)){G=v&255;H=E;I=D;J=F;break}G=-v>>31&255;H=E;I=D;J=F}else{if(x){K=-m>>31&255}else{K=y}if(w>>>0>255>>>0){L=-w>>31&255}else{L=w&255}if(j>>>0>255>>>0){M=-j>>31&255}else{M=j&255}if(!(v>>>0>255>>>0)){G=v&255;H=L;I=K;J=M;break}G=-v>>31&255;H=L;I=K;J=M}}while(0);v=C<<2;a[i+v|0]=J;a[i+(v|1)|0]=I;a[i+(v|2)|0]=G;a[i+(v|3)|0]=H;C=C+1|0;}while((C|0)<(g|0));return}}function Bxb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;d=c[f+4>>2]|0;f=c[g>>2]|0;n=c[g+4>>2]|0;g=4096-k|0;o=4096-l|0;p=j+1>>1;if((p|0)>0){q=0}else{return}do{j=q<<1;r=ba(b[m+(j<<1)>>1]|0,g)|0;s=(ba(b[h+(j<<1)>>1]|0,k)|0)+r>>19;r=j|1;j=ba(b[m+(r<<1)>>1]|0,g)|0;t=(ba(b[h+(r<<1)>>1]|0,k)|0)+j>>19;j=ba(b[e+(q<<1)>>1]|0,o)|0;r=(ba(b[d+(q<<1)>>1]|0,l)|0)+j>>19;j=ba(b[f+(q<<1)>>1]|0,o)|0;u=(ba(b[n+(q<<1)>>1]|0,l)|0)+j>>19;j=s&255;v=t&255;w=r&255;x=u&255;do{if(((t|s|r|u)&256|0)==0){y=x;z=w;A=v;B=j}else{if(s>>>0>255>>>0){C=-s>>31&255}else{C=j}if(t>>>0>255>>>0){D=-t>>31&255}else{D=v}if(r>>>0>255>>>0){E=-r>>31&255}else{E=w}if(!(u>>>0>255>>>0)){y=x;z=E;A=D;B=C;break}y=-u>>31&255;z=E;A=D;B=C}}while(0);u=q<<2;a[i+u|0]=z;a[i+(u|1)|0]=B;a[i+(u|2)|0]=y;a[i+(u|3)|0]=A;q=q+1|0;}while((q|0)<(p|0));return}function Cxb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;o=n+1>>1;if((o|0)<=0){return}n=(g|0)>0;l=(k|0)>0;d=0;do{if(n){p=d<<1;q=p|1;r=0;s=262144;t=262144;do{u=c[f+(r<<2)>>2]|0;v=b[e+(r<<1)>>1]|0;s=(ba(v,b[u+(p<<1)>>1]|0)|0)+s|0;t=(ba(b[u+(q<<1)>>1]|0,v)|0)+t|0;r=r+1|0;}while((r|0)<(g|0));w=s>>19;x=t>>19}else{w=0;x=0}if(l){r=0;q=262144;p=262144;do{v=b[h+(r<<1)>>1]|0;q=(ba(v,b[(c[i+(r<<2)>>2]|0)+(d<<1)>>1]|0)|0)+q|0;p=(ba(b[(c[j+(r<<2)>>2]|0)+(d<<1)>>1]|0,v)|0)+p|0;r=r+1|0;}while((r|0)<(k|0));y=q>>19;z=p>>19}else{y=0;z=0}r=w&255;t=x&255;s=y&255;v=z&255;do{if(((w|x|z|y)&256|0)==0){A=v;B=s;C=t;D=r}else{if(w>>>0>255>>>0){E=-w>>31&255}else{E=r}if(x>>>0>255>>>0){F=-x>>31&255}else{F=t}if(y>>>0>255>>>0){G=-y>>31&255}else{G=s}if(!(z>>>0>255>>>0)){A=v;B=G;C=F;D=E;break}A=-z>>31&255;B=G;C=F;D=E}}while(0);v=d<<2;a[m+v|0]=B;a[m+(v|1)|0]=D;a[m+(v|2)|0]=A;a[m+(v|3)|0]=C;d=d+1|0;}while((d|0)<(o|0));return}function Dxb(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;n=c[m>>2]|0;o=c[m+4>>2]|0;p=c[m+8>>2]|0;q=c[m+12>>2]|0;r=c[m+16>>2]|0;s=c[m+20>>2]|0;t=c[m+24>>2]|0;u=c[m+28>>2]|0;v=c[m+32>>2]|0;m=h>>1;if((i|0)<=0){return}h=j<<1;w=l<<1;x=l+2|0;y=l+3|0;z=l+4|0;A=l+5|0;if((m|0)>0){B=0;C=g;D=f;E=e;F=b}else{b=0;while(1){if((b|1|0)==(i|0)){G=10;break}e=b+2|0;if((e|0)<(i|0)){b=e}else{G=10;break}}if((G|0)==10){return}}while(1){b=0;do{e=b*6|0;f=d[F+e|0]|0;g=d[F+(e|1)|0]|0;H=d[F+(e+2)|0]|0;I=(((ba(g,o)|0)+(ba(f,p)|0)+(ba(H,n)|0)|0)>>>15)+16|0;J=(((ba(g,u)|0)+(ba(f,v)|0)+(ba(H,t)|0)|0)>>>15)+128|0;a[D+b|0]=(((ba(g,r)|0)+(ba(f,s)|0)+(ba(H,q)|0)|0)>>>15)+128;a[C+b|0]=J;J=b<<1;a[E+J|0]=I;a[E+(J|1)|0]=(((ba(d[F+(e+4)|0]|0,o)|0)+(ba(d[F+(e+3)|0]|0,p)|0)+(ba(d[F+(e+5)|0]|0,n)|0)|0)>>>15)+16;b=b+1|0;}while((b|0)<(m|0));if((B|1|0)==(i|0)){G=10;break}else{K=0}do{b=K*6|0;e=K<<1;a[E+(e+j)|0]=(((ba(d[F+((b|1)+l)|0]|0,o)|0)+(ba(d[F+(b+l)|0]|0,p)|0)+(ba(d[F+(x+b)|0]|0,n)|0)|0)>>>15)+16;a[E+((e|1)+j)|0]=(((ba(d[F+(z+b)|0]|0,o)|0)+(ba(d[F+(y+b)|0]|0,p)|0)+(ba(d[F+(A+b)|0]|0,n)|0)|0)>>>15)+16;K=K+1|0;}while((K|0)<(m|0));b=B+2|0;if((b|0)<(i|0)){B=b;C=C+k|0;D=D+k|0;E=E+h|0;F=F+w|0}else{G=10;break}}if((G|0)==10){return}}function Exb(){c[1149362]=486;c[1149358]=140;c[1149360]=1532;c[1149352]=664;c[1149354]=1554;c[1149356]=1398;c[1149344]=1090;c[1149346]=458;c[1149340]=1832;c[1149336]=1578;c[1149338]=1234;c[1149330]=710;c[1149350]=620;c[1149348]=1414;c[1149342]=1748;c[1077824]=300;c[1149332]=1052;c[1149334]=2246;c[591446]=80;c[591448]=108;c[591456]=118;c[591458]=152;c[591454]=156;c[1162430]=2;c[1432194]=24;c[1271018]=48;c[2131022]=14;c[636772]=16;c[591444]=6;c[646580]=72;c[646578]=6;c[591452]=92;c[591450]=130;return}function Fxb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=d>>2;if((e|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;a[c+g|0]=a[b+(d|2)|0]|0;a[c+(g+1)|0]=a[b+(d|1)|0]|0;a[c+(g+2)|0]=a[b+d|0]|0;f=f+1|0;}while((f|0)<(e|0));return}function Gxb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;if((d|0)>0){e=0;f=0}else{return}do{g=e<<2;a[c+g|0]=a[b+(f+2)|0]|0;a[c+(g|1)|0]=a[b+(f+1)|0]|0;a[c+(g|2)|0]=a[b+f|0]|0;a[c+(g|3)|0]=-1;e=e+1|0;f=e*3|0;}while((f|0)<(d|0));return}function Hxb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>8&248|f>>>13;d=f&2016;a[h+1|0]=d>>>3|d>>>9;a[h+2|0]=f>>>2&7|f<<3;a[h+3|0]=-1;if(c>>>0<b>>>0){g=c;h=h+4|0}else{break}}return}function Ixb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=a;a=e+(((d|0)/2|0)<<1)|0;if(!(e>>>0<a>>>0)){return}d=e;e=c;while(1){c=d+2|0;f=b[d>>1]|0;g=f&15;b[e>>1]=f<<3&30720|(f&65535)>>>1&1024|(f&65535)>>>2&32|f<<2&960|(g&65535)>>>3|g<<1;if(c>>>0<a>>>0){d=c;e=e+2|0}else{break}}return}function Jxb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>8&248|f>>>13;d=f&2016;a[h+1|0]=d>>>3|d>>>9;a[h+2|0]=f>>>2&7|f<<3;if(c>>>0<b>>>0){g=c;h=h+3|0}else{break}}return}function Kxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=d>>1;if((e|0)<=0){return}d=a;a=c;c=0;do{f=b[d+(c<<1)>>1]|0;b[a+(c<<1)>>1]=(f&65535)>>>11|f&2016|f<<11;c=c+1|0;}while((c|0)<(e|0));return}function Lxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=d>>1;if((e|0)<=0){return}d=a;a=c;c=0;do{f=b[d+(c<<1)>>1]|0;b[a+(c<<1)>>1]=(f&65535)>>>1&992|(f&65535)>>>11|f<<10&31744;c=c+1|0;}while((c|0)<(e|0));return}function Mxb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;d=f&31744;a[h]=d>>>7|d>>>12;d=f&992;a[h+1|0]=d>>>2|d>>>7;a[h+2|0]=f>>>2&7|f<<3;a[h+3|0]=-1;if(c>>>0<b>>>0){g=c;h=h+4|0}else{break}}return}function Nxb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;d=f&31744;a[h]=d>>>7|d>>>12;d=f&992;a[h+1|0]=d>>>2|d>>>7;a[h+2|0]=f>>>2&7|f<<3;if(c>>>0<b>>>0){g=c;h=h+3|0}else{break}}return}function Oxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=d>>1;if((e|0)<=0){return}d=a;a=c;c=0;do{f=b[d+(c<<1)>>1]|0;b[a+(c<<1)>>1]=f<<1&1984|f<<11|(f&65535)>>>10&31;c=c+1|0;}while((c|0)<(e|0));return}function Pxb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=d>>1;if((f|0)<=0){return}d=a;a=c;c=0;do{g=e[d+(c<<1)>>1]|0;h=g&31775;b[a+(c<<1)>>1]=h>>>10|g&992|h<<10;c=c+1|0;}while((c|0)<(f|0));return}function Qxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=c;c=a;a=d>>1;if((a|0)>0){f=0}else{return}do{d=b[c+(f<<1)>>1]|0;b[e+(f<<1)>>1]=(d&65535)>>>8|d&240|d<<8&3840;f=f+1|0;}while((f|0)<(a|0));return}function Rxb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)>0){e=0}else{return}do{a[c+e|0]=a[b+e|0]|0;f=e|3;g=e|1;a[c+g|0]=a[b+f|0]|0;h=e|2;a[c+h|0]=a[b+h|0]|0;a[c+f|0]=a[b+g|0]|0;e=e+4|0;}while((e|0)<(d|0));return}function Sxb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;if((d|0)>0){e=0}else{return}do{f=e|1;a[c+e|0]=a[b+f|0]|0;g=e|2;a[c+f|0]=a[b+g|0]|0;f=e|3;a[c+g|0]=a[b+f|0]|0;a[c+f|0]=a[b+e|0]|0;e=e+4|0;}while((e|0)<(d|0));return}function Txb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)>0){e=0}else{return}do{f=e|3;a[c+e|0]=a[b+f|0]|0;g=e|1;a[c+g|0]=a[b+e|0]|0;h=e|2;a[c+h|0]=a[b+g|0]|0;a[c+f|0]=a[b+h|0]|0;e=e+4|0;}while((e|0)<(d|0));return}function Uxb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)>0){e=0}else{return}do{f=e|3;a[c+e|0]=a[b+f|0]|0;g=e|2;h=e|1;a[c+h|0]=a[b+g|0]|0;a[c+g|0]=a[b+h|0]|0;a[c+f|0]=a[b+e|0]|0;e=e+4|0;}while((e|0)<(d|0));return}function Vxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>1;if((a|0)>0){f=0}else{return}do{d=f+2|0;b[e+(f<<1)>>1]=b[c+(d<<1)>>1]|0;g=f+1|0;b[e+(g<<1)>>1]=b[c+(g<<1)>>1]|0;b[e+(d<<1)>>1]=b[c+(f<<1)>>1]|0;f=f+3|0;}while((f|0)<(a|0));return}function Wxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>1;if((a|0)>0){f=0}else{return}do{d=f+2|0;b[e+(f<<1)>>1]=de(b[c+(d<<1)>>1]|0)|0;g=f+1|0;b[e+(g<<1)>>1]=de(b[c+(g<<1)>>1]|0)|0;b[e+(d<<1)>>1]=de(b[c+(f<<1)>>1]|0)|0;f=f+3|0;}while((f|0)<(a|0));return}function Xxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>3;if((a|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;b[e+(g<<1)>>1]=b[c+((d|2)<<1)>>1]|0;b[e+(g+1<<1)>>1]=b[c+((d|1)<<1)>>1]|0;b[e+(g+2<<1)>>1]=b[c+(d<<1)>>1]|0;f=f+1|0;}while((f|0)<(a|0));return}function Yxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>3;if((a|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;b[e+(g<<1)>>1]=de(b[c+((d|2)<<1)>>1]|0)|0;b[e+(g+1<<1)>>1]=de(b[c+((d|1)<<1)>>1]|0)|0;b[e+(g+2<<1)>>1]=de(b[c+(d<<1)>>1]|0)|0;f=f+1|0;}while((f|0)<(a|0));return}function Zxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>3;if((a|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;b[e+(g<<1)>>1]=b[c+(d<<1)>>1]|0;b[e+(g+1<<1)>>1]=b[c+((d|1)<<1)>>1]|0;b[e+(g+2<<1)>>1]=b[c+((d|2)<<1)>>1]|0;f=f+1|0;}while((f|0)<(a|0));return}function _xb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>3;if((a|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;b[e+(g<<1)>>1]=de(b[c+(d<<1)>>1]|0)|0;b[e+(g+1<<1)>>1]=de(b[c+((d|1)<<1)>>1]|0)|0;b[e+(g+2<<1)>>1]=de(b[c+((d|2)<<1)>>1]|0)|0;f=f+1|0;}while((f|0)<(a|0));return}function $xb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+e|0;g=e-3|0;e=a+g|0;if((g|0)>0){g=a;h=d;while(1){i=c[g>>2]|0;c[h>>2]=(i&2147450879)+(i&2145419232);i=h+4|0;j=g+4|0;if(j>>>0<e>>>0){g=j;h=i}else{k=j;l=i;break}}}else{k=a;l=d}if(!(k>>>0<f>>>0)){return}f=b[k>>1]|0;b[l>>1]=(f&32767)+(f&32736);return}function ayb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>2&7|f<<3;d=f&992;a[h+1|0]=d>>>2|d>>>7;d=f&31744;a[h+2|0]=d>>>7|d>>>12;if(c>>>0<b>>>0){g=c;h=h+3|0}else{break}}return}function byb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>2&7|f<<3;d=f&992;a[h+1|0]=d>>>2|d>>>7;d=f&31744;a[h+2|0]=d>>>7|d>>>12;a[h+3|0]=-1;if(c>>>0<b>>>0){g=c;h=h+4|0}else{break}}return}function cyb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>2&7|f<<3;d=f&2016;a[h+1|0]=d>>>3|d>>>9;a[h+2|0]=f>>>8&248|f>>>13;if(c>>>0<b>>>0){g=c;h=h+3|0}else{break}}return}function dyb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>2&7|f<<3;d=f&2016;a[h+1|0]=d>>>3|d>>>9;a[h+2|0]=f>>>8&248|f>>>13;a[h+3|0]=-1;if(c>>>0<b>>>0){g=c;h=h+4|0}else{break}}return}function eyb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+e|0;g=e-3|0;e=a+g|0;if((g|0)>0){g=a;h=d;while(1){i=c[g>>2]|0;c[h>>2]=i>>>1&2145419232|i&2031647;i=g+4|0;j=h+4|0;if(i>>>0<e>>>0){g=i;h=j}else{k=i;l=j;break}}}else{k=a;l=d}if(!(k>>>0<f>>>0)){return}f=b[k>>1]|0;b[l>>1]=(f&65535)>>>1&32736|f&31;return}function fyb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;g=c+f|0;if((f|0)<=0){return}f=c;c=e;while(1){e=f+3|0;b[c>>1]=(d[f+1|0]|0)<<3&2016|(a[f]&255)>>>3|(d[f+2|0]|0)<<8&-2048;if(e>>>0<g>>>0){f=e;c=c+2|0}else{break}}return}function gyb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;g=c+f|0;if((f|0)<=0){return}f=c;c=e;while(1){e=f+3|0;b[c>>1]=(d[f+1|0]|0)<<2&992|(a[f]&255)>>>3|(d[f+2|0]|0)<<7&31744;if(e>>>0<g>>>0){f=e;c=c+2|0}else{break}}return}function hyb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=b+d|0;if((d|0)>0){f=b;g=c}else{return}while(1){a[g]=a[f]|0;a[g+1|0]=a[f+1|0]|0;c=f+3|0;a[g+2|0]=a[f+2|0]|0;a[g+3|0]=-1;if(c>>>0<e>>>0){f=c;g=g+4|0}else{break}}return}function iyb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0;f=a+e|0;if((e|0)<=0){return}e=a;a=d;while(1){d=c[e>>2]|0;g=e+4|0;b[a>>1]=d>>>3&31|d>>>5&2016|d>>>8&63488;if(g>>>0<f>>>0){e=g;a=a+2|0}else{break}}return}function jyb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0;f=a+e|0;if((e|0)<=0){return}e=a;a=d;while(1){d=c[e>>2]|0;g=e+4|0;b[a>>1]=d>>>3&31|d>>>6&992|d>>>9&31744;if(g>>>0<f>>>0){e=g;a=a+2|0}else{break}}return}function kyb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=b+d|0;if((d|0)>0){f=b;g=c}else{return}while(1){a[g]=a[f]|0;a[g+1|0]=a[f+1|0]|0;a[g+2|0]=a[f+2|0]|0;c=f+4|0;if(c>>>0<e>>>0){f=c;g=g+3|0}else{break}}return}function lyb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;g=c+f|0;if((f|0)<=0){return}f=c;c=e;while(1){e=f+3|0;b[c>>1]=(d[f+1|0]|0)<<2&992|(d[f]|0)<<7&31744|(a[f+2|0]&255)>>>3;if(e>>>0<g>>>0){f=e;c=c+2|0}else{break}}return}function myb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;g=c+f|0;if((f|0)<=0){return}f=c;c=e;while(1){e=f+3|0;b[c>>1]=(d[f+1|0]|0)<<3&2016|(d[f]|0)<<8&-2048|(a[f+2|0]&255)>>>3;if(e>>>0<g>>>0){f=e;c=c+2|0}else{break}}return}function nyb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)==0){return}else{e=0}do{f=e+2|0;g=a[b+f|0]|0;h=e+1|0;a[c+h|0]=a[b+h|0]|0;a[c+f|0]=a[b+e|0]|0;a[c+e|0]=g;e=e+3|0;}while(e>>>0<d>>>0);return}function oyb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=15-d|0;if((d|0)>0){f=e}else{return}do{d=f-e|0;g=c[a+d>>2]|0;h=g&16711935;c[b+d>>2]=h>>>16|g&-16711936|h<<16;f=f+4|0;}while((f|0)<15);return}function pyb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0;f=a+e|0;if((e|0)<=0){return}e=a;a=d;while(1){d=c[e>>2]|0;g=e+4|0;b[a>>1]=d<<8&63488|d>>>5&2016|d>>>19&31;if(g>>>0<f>>>0){e=g;a=a+2|0}else{break}}return}function qyb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0;f=a+e|0;if((e|0)<=0){return}e=a;a=d;while(1){d=c[e>>2]|0;g=e+4|0;b[a>>1]=d<<7&31744|d>>>6&992|d>>>19&31;if(g>>>0<f>>>0){e=g;a=a+2|0}else{break}}return}function ryb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=g>>1;if((h|0)<=0){return}g=(l|0)>0;m=f;f=e;e=b;b=0;n=a;while(1){if(g){a=0;o=m;p=n;q=e;r=f;while(1){c[o>>2]=(d[q]|0)<<8|(d[p]|0)|(d[p+1|0]|0)<<16|(d[r]|0)<<24;s=a+1|0;if((s|0)<(l|0)){a=s;o=o+4|0;p=p+2|0;q=q+1|0;r=r+1|0}else{break}}}if((b&1|0)==0){t=e;u=f}else{t=e+j|0;u=f+j|0}r=b+1|0;if((r|0)<(h|0)){m=m+k|0;f=u;e=t;b=r;n=n+i|0}else{break}}return}function syb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=g>>1;if((h|0)<=0){return}g=(l|0)>0;m=f;f=e;e=b;b=0;n=a;while(1){if(g){a=0;o=m;p=n;q=e;r=f;while(1){c[o>>2]=(d[p]|0)<<8|(d[q]|0)|(d[r]|0)<<16|(d[p+1|0]|0)<<24;s=a+1|0;if((s|0)<(l|0)){a=s;o=o+4|0;p=p+2|0;q=q+1|0;r=r+1|0}else{break}}}if((b&1|0)==0){t=e;u=f}else{t=e+j|0;u=f+j|0}r=b+1|0;if((r|0)<(h|0)){m=m+k|0;f=u;e=t;b=r;n=n+i|0}else{break}}return}function tyb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>1;if((h|0)<=0){return}g=(l|0)>0;m=f;f=e;e=b;b=0;n=a;while(1){if(g){a=0;o=m;p=n;q=e;r=f;while(1){c[o>>2]=(d[q]|0)<<8|(d[p]|0)|(d[p+1|0]|0)<<16|(d[r]|0)<<24;s=a+1|0;if((s|0)<(l|0)){a=s;o=o+4|0;p=p+2|0;q=q+1|0;r=r+1|0}else{break}}}r=b+1|0;if((r|0)<(h|0)){m=m+k|0;f=f+j|0;e=e+j|0;b=r;n=n+i|0}else{break}}return}function uyb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>1;if((h|0)<=0){return}g=(l|0)>0;m=f;f=e;e=b;b=0;n=a;while(1){if(g){a=0;o=m;p=n;q=e;r=f;while(1){c[o>>2]=(d[p]|0)<<8|(d[q]|0)|(d[r]|0)<<16|(d[p+1|0]|0)<<24;s=a+1|0;if((s|0)<(l|0)){a=s;o=o+4|0;p=p+2|0;q=q+1|0;r=r+1|0}else{break}}}r=b+1|0;if((r|0)<(h|0)){m=m+k|0;f=f+j|0;e=e+j|0;b=r;n=n+i|0}else{break}}return}function vyb(b,c,d,e,f,g,h,i,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=f>>1;if((g|0)<=0){return}f=(k|0)>0;l=h<<1;m=j<<1;n=e;e=d;d=c;c=0;o=b;while(1){do{if(f){b=0;do{p=b<<2;q=b<<1;a[d+q|0]=a[o+p|0]|0;a[e+b|0]=a[o+(p|1)|0]|0;a[d+(q|1)|0]=a[o+(p|2)|0]|0;a[n+b|0]=a[o+(p|3)|0]|0;b=b+1|0;}while((b|0)<(k|0));if(f){r=0}else{break}do{b=r<<2;p=r<<1;a[d+(p+h)|0]=a[o+(b+j)|0]|0;a[d+((p|1)+h)|0]=a[o+((b|2)+j)|0]|0;r=r+1|0;}while((r|0)<(k|0))}}while(0);b=c+2|0;if((b|0)<(g|0)){n=n+i|0;e=e+i|0;d=d+l|0;c=b;o=o+m|0}else{break}}return}function wyb(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;a[c]=a[b]|0;i=e-1|0;j=(i|0)>0;if(j){k=0;while(1){l=b+k|0;m=k+1|0;n=b+m|0;o=k<<1;a[c+(o|1)|0]=(((d[l]|0)*3|0)+(d[n]|0)|0)>>>2;a[c+(o+2)|0]=(((d[n]|0)*3|0)+(d[l]|0)|0)>>>2;if((m|0)<(i|0)){k=m}else{break}}}k=(e<<1)-1|0;a[c+k|0]=a[b+i|0]|0;e=c+h|0;m=a[b]|0;if((f|0)>1){l=i+g|0;n=k+h|0;o=h<<1;p=ba((f<<1)-1|0,h)|0;q=ba(f-1|0,g)|0;r=e;s=1;t=b;u=m;while(1){v=t+g|0;a[r]=((d[v]|0)+((u&255)*3|0)|0)>>>2;a[r+h|0]=(((d[v]|0)*3|0)+(d[t]|0)|0)>>>2;if(j){w=0;do{x=t+w|0;y=w+g|0;z=t+(y+1)|0;A=w<<1;a[r+(A|1)|0]=(((d[x]|0)*3|0)+(d[z]|0)|0)>>>2;B=A+h|0;a[r+(B+2)|0]=(((d[z]|0)*3|0)+(d[x]|0)|0)>>>2;w=w+1|0;x=t+w|0;z=t+y|0;a[r+(B+1)|0]=(((d[z]|0)*3|0)+(d[x]|0)|0)>>>2;a[r+(A+2)|0]=(((d[x]|0)*3|0)+(d[z]|0)|0)>>>2;}while((w|0)<(i|0))}w=t+i|0;z=t+l|0;a[r+k|0]=(((d[w]|0)*3|0)+(d[z]|0)|0)>>>2;a[r+n|0]=(((d[z]|0)*3|0)+(d[w]|0)|0)>>>2;w=s+1|0;C=a[v]|0;if((w|0)<(f|0)){r=r+o|0;s=w;t=v;u=C}else{break}}D=c+p|0;E=b+q|0;F=C}else{D=e;E=b;F=m}a[D]=F;if(j){G=0}else{H=E+i|0;I=a[H]|0;J=D+k|0;a[J]=I;return}while(1){j=E+G|0;F=G+1|0;m=E+F|0;b=G<<1;a[D+(b|1)|0]=(((d[j]|0)*3|0)+(d[m]|0)|0)>>>2;a[D+(b+2)|0]=(((d[m]|0)*3|0)+(d[j]|0)|0)>>>2;if((F|0)<(i|0)){G=F}else{break}}H=E+i|0;I=a[H]|0;J=D+k|0;a[J]=I;return}function xyb(b,c,d,e,f,g,h,i){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((f|0)<=0){return}j=(e|0)>0;k=d;d=c;c=b;b=0;while(1){if(j){l=0;do{m=l<<1;a[k+m|0]=a[c+l|0]|0;a[k+(m|1)|0]=a[d+l|0]|0;l=l+1|0;}while((l|0)<(e|0))}l=b+1|0;if((l|0)<(f|0)){k=k+i|0;d=d+h|0;c=c+g|0;b=l}else{break}}return}function yyb(b,c,d,e,f,g,h,i){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((f|0)<=0){return}j=(e|0)>0;k=d;d=c;c=b;b=0;while(1){if(j){l=0;do{m=l<<1;a[d+l|0]=a[c+m|0]|0;a[k+l|0]=a[c+(m|1)|0]|0;l=l+1|0;}while((l|0)<(e|0))}l=b+1|0;if((l|0)<(f|0)){k=k+i|0;d=d+h|0;c=c+g|0;b=l}else{break}}return}function zyb(b,c,d,e,f,g,h,i,j,k){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;l=(f|0)/2|0;m=(g|0)/2|0;n=(g|0)>1;if(!n){return}g=(f|0)>1;o=0;do{p=ba(o>>1,h)|0;q=ba(o,j)|0;if(g){r=0;do{s=a[b+(r+p)|0]|0;t=r<<1;a[d+((t|1)+q)|0]=s;a[d+(t+q)|0]=s;r=r+1|0;}while((r|0)<(l|0))}o=o+1|0;}while((o|0)<(m|0));if(!n){return}n=(f|0)>1;f=0;do{o=ba(f>>1,i)|0;d=ba(f,k)|0;if(n){b=0;do{g=a[c+(b+o)|0]|0;j=b<<1;a[e+((j|1)+d)|0]=g;a[e+(j+d)|0]=g;b=b+1|0;}while((b|0)<(l|0))}f=f+1|0;}while((f|0)<(m|0));return}function Ayb(b,c,d,e,f,g,h,i,j,k){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=(f|0)/2|0;if((g|0)<=0){return}m=(f|0)>1;f=0;do{n=ba(f,h)|0;o=f>>2;p=ba(o,i)|0;q=ba(o,j)|0;o=ba(f,k)|0;if(m){r=0;do{s=r<<2;t=r<<3;a[e+(t+o)|0]=a[b+(s+n)|0]|0;u=c+(r+p)|0;a[e+((t|1)+o)|0]=a[u]|0;a[e+((t|2)+o)|0]=a[b+((s|1)+n)|0]|0;v=d+(r+q)|0;a[e+((t|3)+o)|0]=a[v]|0;a[e+((t|4)+o)|0]=a[b+((s|2)+n)|0]|0;a[e+((t|5)+o)|0]=a[u]|0;a[e+((t|6)+o)|0]=a[b+((s|3)+n)|0]|0;a[e+((t|7)+o)|0]=a[v]|0;r=r+1|0;}while((r|0)<(l|0))}f=f+1|0;}while((f|0)<(g|0));return}function Byb(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=g+1>>1;if((h|0)<=0){return}m=(g|0)>0;n=-g|0;o=l<<2;p=(l|0)>0;q=-l|0;r=f;f=e;e=c;c=0;s=b;while(1){if(m){b=n;do{t=b+g|0;a[s+t|0]=a[r+(t<<1|1)|0]|0;b=b+1|0;}while((b|0)<0)}if((c&1|0)==0){u=e;v=f}else{if(p){b=q;do{t=b<<2;w=t+o|0;x=b+l|0;a[e+x|0]=((d[r+w|0]|0)+(d[r+(w-k)|0]|0)|0)>>>1;w=(t|2)+o|0;a[f+x|0]=((d[r+w|0]|0)+(d[r+(w-k)|0]|0)|0)>>>1;b=b+1|0;}while((b|0)<0)}u=e+j|0;v=f+j|0}b=c+1|0;if((b|0)<(h|0)){r=r+k|0;f=v;e=u;c=b;s=s+i|0}else{break}}return}function Cyb(b,c,d,e,f,g,h,i,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=f+1>>1;if((g|0)<=0){return}l=(f|0)>0;m=-f|0;n=k<<2;o=(k|0)>0;p=-k|0;q=e;e=d;d=c;c=0;r=b;while(1){if(l){b=m;do{s=b+f|0;a[r+s|0]=a[q+(s<<1|1)|0]|0;b=b+1|0;}while((b|0)<0)}if(o){b=p;do{s=b<<2;t=b+k|0;a[d+t|0]=a[q+(s+n)|0]|0;a[e+t|0]=a[q+((s|2)+n)|0]|0;b=b+1|0;}while((b|0)<0)}b=c+1|0;if((b|0)<(g|0)){q=q+j|0;e=e+i|0;d=d+i|0;c=b;r=r+h|0}else{break}}return}function Dyb(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=g+1>>1;if((h|0)<=0){return}m=(g|0)>0;n=-g|0;o=l<<2|1;p=(l|0)>0;q=-l|0;r=f;f=e;e=c;c=0;s=b;while(1){if(m){b=n;do{t=b+g|0;a[s+t|0]=a[r+(t<<1)|0]|0;b=b+1|0;}while((b|0)<0)}if((c&1|0)==0){u=e;v=f}else{if(p){b=q;do{t=b<<2;w=t+o|0;x=b+l|0;a[e+x|0]=((d[r+w|0]|0)+(d[r+(w-k)|0]|0)|0)>>>1;w=(t|2)+o|0;a[f+x|0]=((d[r+w|0]|0)+(d[r+(w-k)|0]|0)|0)>>>1;b=b+1|0;}while((b|0)<0)}u=e+j|0;v=f+j|0}b=c+1|0;if((b|0)<(h|0)){r=r+k|0;f=v;e=u;c=b;s=s+i|0}else{break}}return}function Eyb(b,c,d,e,f,g,h,i,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=f+1>>1;if((g|0)<=0){return}l=(f|0)>0;m=-f|0;n=k<<2|1;o=(k|0)>0;p=-k|0;q=e;e=d;d=c;c=0;r=b;while(1){if(l){b=m;do{s=b+f|0;a[r+s|0]=a[q+(s<<1)|0]|0;b=b+1|0;}while((b|0)<0)}if(o){b=p;do{s=b<<2;t=b+k|0;a[d+t|0]=a[q+(s+n)|0]|0;a[e+t|0]=a[q+((s|2)+n)|0]|0;b=b+1|0;}while((b|0)<0)}b=c+1|0;if((b|0)<(g|0)){q=q+j|0;e=e+i|0;d=d+i|0;c=b;r=r+h|0}else{break}}return}function Fyb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;f=i;g=e+56|0;h=c[g>>2]|0;j=c[e+52>>2]|0;k=e+2284|0;l=c[k>>2]|0;m=c[e+16>>2]|0;n=(j|0)==291;o=(j|0)==292;p=(j|0)==2;q=(j|0)==67;r=(j|0)==68;s=(j|0)==293;t=(j|0)==294;u=(j|0)==28;v=(j|0)==27;w=(j|0)==3;x=(j|0)==65;y=(j|0)==64;a:do{switch(j|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{z=5;break};default:{A=bFb(j)|0;if((A|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=674,B)|0);i=B;Cd()}else{if((a[A+7|0]&32)==0){C=0;break a}else{z=5;break a}}}}}while(0);b:do{if((z|0)==5){A=c[e+60>>2]|0;if((A|0)>=24){C=0;break}if((A|0)<(c[e+64>>2]|0)){C=1;break}switch(h|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{C=0;break b;break};default:{}}A=bFb(h)|0;if((A|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=674,B)|0);i=B;Cd()}else{C=(a[A+7|0]&32)==0;break}}}while(0);A=(h|0)==0;do{if((h|0)==35|(h|0)==0){if(!((j-25|0)>>>0<2>>>0)){z=14;break}c[e+4>>2]=6;D=0}else{z=14}}while(0);do{if((z|0)==14){if((j|0)!=0){D=0;break}if(!((h-25|0)>>>0<2>>>0)){D=1;break}c[e+4>>2]=4;D=1}}while(0);E=(h|0)==4;switch(h|0){case 3:{z=30;break};case 35:case 4:case 0:{c:do{switch(j|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{z=22;break};default:{F=bFb(j)|0;if((F|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=674,B)|0);i=B;Cd()}else{if((a[F+7|0]&32)==0){break c}else{z=22;break c}}}}}while(0);do{if((z|0)==22){if((l&262144|0)!=0){break}if(!(((c[e+23972>>2]|0)-1|0)>>>0<2>>>0)){break}if((m&1|0)!=0){break}c[e+4>>2]=Fsb(e)|0}}while(0);if((h|0)==3){z=30}else if((h|0)==6){z=27}else{z=33}break};case 6:{z=27;break};default:{z=33}}do{if((z|0)==27){if(!((j|0)==35|(j|0)==0)){G=0;H=0;I=0;J=0;K=0;L=0;z=34;break}if((l&524288|0)!=0){z=33;break}c[e+4>>2]=24;z=33}else if((z|0)==30){if(!((j|0)==35|(j|0)==0)){M=0;N=0;O=0;P=0;Q=0;R=0;z=37;break}if((l&262144|0)!=0){M=0;N=0;O=0;P=0;Q=0;R=0;z=37;break}c[e+4>>2]=88;M=0;N=0;O=0;P=0;Q=0;R=0;z=37}}while(0);if((z|0)==33){l=(h|0)==291;m=(h|0)==292;F=(h|0)==67;S=(h|0)==68;T=(h|0)==293;U=(h|0)==294;switch(h|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{M=l;N=m;O=F;P=S;Q=T;R=U;z=37;break};default:{G=l;H=m;I=F;J=S;K=T;L=U;z=34}}}do{if((z|0)==34){U=bFb(h)|0;if((U|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=674,B)|0);i=B;Cd()}else{if((a[U+7|0]&32)==0){V=G;W=H;X=I;Y=J;Z=K;_=L;break}else{M=G;N=H;O=I;P=J;Q=K;R=L;z=37;break}}}}while(0);d:do{if((z|0)==37){e:do{switch(j|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{break};default:{L=bFb(j)|0;if((L|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=674,B)|0);i=B;Cd()}else{if((a[L+7|0]&32)==0){V=M;W=N;X=O;Y=P;Z=Q;_=R;break d}else{break e}}}}}while(0);if((Kyb(e)|0)==0){V=M;W=N;X=O;Y=P;Z=Q;_=R;break}if(C){if((c[k>>2]&17|0)==0){V=M;W=N;X=O;Y=P;Z=Q;_=R;break}}c[e+4>>2]=28;V=M;W=N;X=O;Y=P;Z=Q;_=R}}while(0);R=(h|0)==82;if(R&(j|0)==317){z=47}else{if((h|0)==317&(j|0)==82){z=47}}if((z|0)==47){c[e+4>>2]=50}do{if(R){Q=bFb(82)|0;if((Q|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=806,B)|0);i=B;Cd()}if(!((d[Q+4|0]|0)>>>0>1>>>0)){break}if((a[Q+7|0]&16)==0){break}if(!((j-29|0)>>>0<2>>>0|p|u|v|w)){break}c[e+4>>2]=56}}while(0);do{if((h-41|0)>>>0<2>>>0|Y|X|W|V|_|Z){if(!((j-83|0)>>>0<2>>>0|(j|0)==86|(j|0)==85|(j|0)==314|(j|0)==313|(j|0)==316|(j|0)==315|(j|0)==88|(j|0)==87|(j|0)==319|(j|0)==318)){break}c[e+4>>2]=106}}while(0);R=(h|0)==84;Q=(h|0)==83;P=(h|0)==88;O=(h|0)==87;N=(h|0)==86;M=(h|0)==85;C=(h|0)==314;L=(h|0)==313;K=(h|0)==316;J=(h|0)==315;I=(h|0)==319;H=(h|0)==318;do{if((h-83|0)>>>0<2>>>0|P|O|N|M|C|L|K|J|I|H){if(!((j-41|0)>>>0<2>>>0|r|q|o|n|t|s)){break}c[e+4>>2]=102}}while(0);do{if((b[(bFb(h)|0)+8>>1]&30720)==14336){G=bFb(h)|0;if((G|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=813,B)|0);i=B;Cd()}if(!((a[G+7|0]&48)==32&(j|0)==82)){break}c[e+4>>2]=96}}while(0);f:do{switch(h|0){case 65:{if(y){z=132}else{z=83}break};case 64:{if(x|X&r|Y&q|Z&t|_&s){z=132}else{z=91}break};case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:{if(p){c[e+4>>2]=98}else{do{if(D){c[e+4>>2]=90}else{if((j-321|0)>>>0<12>>>0){break}yDb(e,16,2166464,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2172176,c[B+8>>2]=2097720,c[B+16>>2]=1655,B)|0);i=B;Cd()}}while(0);if(!((h|0)!=326|(j|0)!=325)){z=132;break f}if(!((h|0)!=325|(j|0)!=326)){z=132;break f}if(!((h|0)!=328|(j|0)!=327)){z=132;break f}if(!((h|0)!=327|(j|0)!=328)){z=132;break f}if(!((h|0)!=330|(j|0)!=329)){z=132;break f}if(!((h|0)!=329|(j|0)!=330)){z=132;break f}if(!((h|0)!=332|(j|0)!=331)){z=132;break f}if(!((h|0)!=331|(j|0)!=332)){z=132;break f}}if((h|0)!=65|y^1){z=83}else{z=132}break};default:{if(X&r|Y&q|Z&t|_&s){z=132}else{z=86}}}}while(0);if((z|0)==83){if(x&(h|0)==64|X&r|Y&q|Z&t|_&s){z=132}else{z=86}}do{if((z|0)==86){if(!((h|0)!=49|(j|0)!=50)){z=132;break}if(!((h|0)!=50|(j|0)!=49)){z=132;break}if(!((h|0)!=47|(j|0)!=48)){z=132;break}if(!((h|0)!=48|(j|0)!=47)){z=132;break}if((h|0)==31&(j|0)==32){z=132}else{z=91}}}while(0);do{if((z|0)==91){if((h|0)==32&(j|0)==31|Q&(j|0)==84|R&(j|0)==83|M&(j|0)==86|N&(j|0)==85|L&(j|0)==314|C&(j|0)==313|J&(j|0)==316|K&(j|0)==315|O&(j|0)==88|P&(j|0)==87|H&(j|0)==319|I&(j|0)==318){z=132;break}if(!((h|0)!=63|(j|0)!=62)){z=132;break}if(!((h|0)!=62|(j|0)!=63)){z=132;break}if(!((h|0)!=41|(j|0)!=42)){z=132;break}if((j|0)==41&(h|0)==42|V&o|W&n){z=132;break}if(!((h|0)!=45|(j|0)!=46)){z=132;break}if(!((h|0)!=46|(j|0)!=45)){z=132;break}if(!((h|0)!=43|(j|0)!=44)){z=132;break}if(!((h|0)!=44|(j|0)!=43)){z=132;break}if((h|0)==111&(j|0)==110){z=132;break}if((h|0)==110&(j|0)==111){z=132;break}if((h|0)==69&(j|0)==70){z=132;break}if((h|0)==70&(j|0)==69){z=132;break}if((h|0)==71&(j|0)==72){z=132;break}if((h|0)==72&(j|0)==71){z=132;break}if((h|0)==301&(j|0)==302){z=132;break}if((h|0)==302&(j|0)==301){z=132;break}if((h|0)==303&(j|0)==304){z=132;break}if((h|0)==304&(j|0)==303){z=132;break}if((h|0)==55&(j|0)==54){z=132;break}if((h|0)==54&(j|0)==55){z=132;break}if((h|0)==79&(j|0)==80){z=132;break}if((h|0)==80&(j|0)==79){z=132;break}if((h|0)==73&(j|0)==74){z=132;break}if((h|0)==74&(j|0)==73){z=132;break}if((h|0)==305&(j|0)==306){z=132;break}if((h|0)==306&(j|0)==305){z=132;break}if((h|0)==307&(j|0)==308){z=132;break}if((h|0)==308&(j|0)==307){z=132;break}if((h|0)==57&(j|0)==56){z=132;break}if((h|0)==56&(j|0)==57){z=132;break}if((h|0)==75&(j|0)==76){z=132;break}if((h|0)==76&(j|0)==75){z=132;break}if((h|0)==77&(j|0)==78){z=132;break}if((h|0)==78&(j|0)==77){z=132;break}if((h|0)==309&(j|0)==310){z=132;break}if((h|0)==310&(j|0)==309){z=132;break}if((h|0)==311&(j|0)==312){z=132;break}if((h|0)==312&(j|0)==311){z=132;break}if((h|0)==59&(j|0)==58){z=132;break}if((h|0)==58&(j|0)==59){z=132}}}while(0);if((z|0)==132){c[e+4>>2]=30}n=bFb(h)|0;if((n|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=828,B)|0);i=B;Cd()}do{if(!((a[n+7|0]&66)==0)){if(!((j-29|0)>>>0<2>>>0|p|u|v|w)){break}c[e+4>>2]=68}}while(0);do{if(E){if((j|0)==1){c[e+4>>2]=80;break}else if((j|0)==17){c[e+4>>2]=42;break}else{break}}}while(0);do{if((c[k>>2]&17|0)!=0){if(!((h|0)==35|(h|0)==0)){break}if((j|0)==1){c[e+4>>2]=14;break}else if((j|0)==17){c[e+4>>2]=108;break}else{break}}}while(0);k=(h|0)==1;do{if(k){if(!((j|0)==35|(j|0)==0)){$=0;z=153;break}c[e+4>>2]=48;$=0;z=153}else{if((h|0)!=17){break}if(!((j|0)==35|(j|0)==0)){$=1;z=153;break}c[e+4>>2]=64;$=1;z=153}}while(0);do{if((z|0)==153){E=(j|0)==4;if(k&E){c[e+4>>2]=20}if(!($&E)){break}c[e+4>>2]=12}}while(0);g:do{if((h|0)!=(j|0)){if(D&(h|0)==35|A&(j|0)==35){break}$=bFb(h)|0;if(($|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=667,B)|0);i=B;Cd()}do{if(!((a[$+7|0]&16)==0)){k=bFb(h)|0;if((k|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=660,B)|0);i=B;Cd()}if(!((a[k+7|0]&32)==0)){break}if(!((d[k+4|0]|0)>>>0>1>>>0)){break}if(((j|0)==8|(j|0)==66|(j|0)==31|(j|0)==32)&(j|0)!=66){break g}}}while(0);$=bFb(j)|0;if(($|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=667,B)|0);i=B;Cd()}do{if(!((a[$+7|0]&16)==0)){k=bFb(j)|0;if((k|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=660,B)|0);i=B;Cd()}if(!((a[k+7|0]&32)==0)){break}if(!((d[k+4|0]|0)>>>0>1>>>0)){break}if(((h|0)==8|(h|0)==66|(h|0)==31|(h|0)==32)&(h|0)!=66){break g}}}while(0);if(((j|0)==8|(j|0)==66|(j|0)==31|(j|0)==32)&(j|0)!=66){if(((h|0)==8|(h|0)==66|(h|0)==31|(h|0)==32)&(h|0)!=66){break}}$=bFb(h)|0;if(($|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=667,B)|0);i=B;Cd()}if((a[$+7|0]&16)==0){i=f;return}$=bFb(h)|0;if(($|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=660,B)|0);i=B;Cd()}if(!((a[$+7|0]&32)==0)){i=f;return}if(!((d[$+4|0]|0)>>>0>1>>>0)){i=f;return}$=bFb(j)|0;if(($|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=667,B)|0);i=B;Cd()}if((a[$+7|0]&16)==0){i=f;return}$=bFb(j)|0;if(($|0)==0){yDb(0,0,2301720,(B=i,i=i+24|0,c[B>>2]=2042536,c[B+8>>2]=1997616,c[B+16>>2]=660,B)|0);i=B;Cd()}if(!((a[$+7|0]&32)==0)){i=f;return}if(!((d[$+4|0]|0)>>>0>1>>>0)){i=f;return}if((c[e+84>>2]|0)!=(c[e+76>>2]|0)){i=f;return}if((c[e+88>>2]|0)!=(c[e+80>>2]|0)){i=f;return}if(!((j-25|0)>>>0>1>>>0)){i=f;return}if((h-25|0)>>>0>1>>>0){break}i=f;return}}while(0);h=c[g>>2]|0;h:do{switch(h|0){case 11:case 1:case 17:case 66:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:{break};default:{switch(h|0){case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 10:case 9:case 3:{break h;break};default:{}}c[e+4>>2]=54;i=f;return}}}while(0);c[e+4>>2]=94;i=f;return}function Gyb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=h+4|0;j=(c[g+4>>2]|0)+((ba(c[i>>2]|0,e)|0)/2|0)|0;k=c[b>>2]|0;l=c[d>>2]|0;m=a+8|0;n=c[m>>2]|0;o=c[h>>2]|0;h=(c[g>>2]|0)+(ba(o,e)|0)|0;do{if((o|0)==(l|0)&(l|0)>0){UGb(h|0,k|0,ba(l,f)|0)|0}else{if((f|0)>0){p=h;q=k;r=0}else{break}while(1){UGb(p|0,q|0,n)|0;e=r+1|0;if((e|0)<(f|0)){p=p+o|0;q=q+l|0;r=e}else{break}}}}while(0);r=c[1271018]|0;if((c[a+52>>2]|0)==25){Be[r&127](c[b+4>>2]|0,c[b+8>>2]|0,j,(c[m>>2]|0)/2|0,(f|0)/2|0,c[d+4>>2]|0,c[d+8>>2]|0,c[i>>2]|0);return f|0}else{Be[r&127](c[b+8>>2]|0,c[b+4>>2]|0,j,(c[m>>2]|0)/2|0,(f|0)/2|0,c[d+8>>2]|0,c[d+4>>2]|0,c[i>>2]|0);return f|0}return 0}function Hyb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=h+4|0;j=(c[g+4>>2]|0)+((ba(c[i>>2]|0,e)|0)/2|0)|0;k=h+8|0;l=(c[g+8>>2]|0)+((ba(c[k>>2]|0,e)|0)/2|0)|0;m=c[b>>2]|0;n=c[d>>2]|0;o=a+8|0;p=c[o>>2]|0;q=c[h>>2]|0;h=(c[g>>2]|0)+(ba(q,e)|0)|0;do{if((q|0)==(n|0)&(n|0)>0){UGb(h|0,m|0,ba(n,f)|0)|0}else{if((f|0)>0){r=h;s=m;t=0}else{break}while(1){UGb(r|0,s|0,p)|0;e=t+1|0;if((e|0)<(f|0)){r=r+q|0;s=s+n|0;t=e}else{break}}}}while(0);t=c[2131022]|0;n=c[b+4>>2]|0;b=(c[o>>2]|0)/2|0;o=(f|0)/2|0;s=c[d+4>>2]|0;if((c[a+56>>2]|0)==25){Be[t&127](n,j,l,b,o,s,c[i>>2]|0,c[k>>2]|0);return f|0}else{Be[t&127](n,l,j,b,o,s,c[k>>2]|0,c[i>>2]|0);return f|0}return 0}function Iyb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=c[b>>2]|0;j=c[d>>2]|0;k=a+8|0;l=c[k>>2]|0;m=c[h>>2]|0;n=(c[g>>2]|0)+(ba(m,e)|0)|0;do{if((m|0)==(j|0)&(j|0)>0){UGb(n|0,i|0,ba(j,f)|0)|0}else{if((f|0)>0){o=n;p=i;q=0}else{break}while(1){UGb(o|0,p|0,l)|0;r=q+1|0;if((r|0)<(f|0)){o=o+m|0;p=p+j|0;q=r}else{break}}}}while(0);q=c[h+4>>2]|0;j=e>>1;p=(c[g+4>>2]|0)+(ba(q,j)|0)|0;m=a+20|0;a=f>>2;Se[c[1162430]&511](c[b+4>>2]|0,p,c[m>>2]|0,a,c[d+4>>2]|0,q);q=c[h+8>>2]|0;p=(c[g+8>>2]|0)+(ba(q,j)|0)|0;Se[c[1162430]&511](c[b+8>>2]|0,p,c[m>>2]|0,a,c[d+8>>2]|0,q);q=c[g+12>>2]|0;if((q|0)==0){return f|0}g=c[h+12>>2]|0;h=c[k>>2]|0;if((f|0)<=0){return f|0}k=0;d=q+(ba(g,e)|0)|0;while(1){TGb(d|0,-1|0,h|0)|0;e=k+1|0;if((e|0)<(f|0)){k=e;d=d+g|0}else{break}}return f|0}function Jyb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ba(i,e)|0)|0;k=e>>1;l=c[h+4>>2]|0;m=(c[g+4>>2]|0)+(ba(l,k)|0)|0;n=(c[g+8>>2]|0)+(ba(c[h+8>>2]|0,k)|0)|0;k=a+8|0;Ne[c[1432194]&127](c[b>>2]|0,j,m,n,c[k>>2]|0,f,i,l,c[d>>2]|0,a+10496|0);a=c[g+12>>2]|0;if((a|0)==0){return f|0}g=c[h+12>>2]|0;h=c[k>>2]|0;if((f|0)<=0){return f|0}k=0;d=a+(ba(g,e)|0)|0;while(1){TGb(d|0,-1|0,h|0)|0;e=k+1|0;if((e|0)<(f|0)){k=e;d=d+g|0}else{break}}return f|0}function Kyb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[a+56>>2]|0;d=c[a+52>>2]|0;e=c[a+64>>2]|0;f=c[a+60>>2]|0;a=(b|0)==27;g=(b|0)==28;h=(b|0)==30;i=(b|0)==29;do{if((b-27|0)>>>0<2>>>0|h|i){j=(d|0)==30;k=(d|0)==29;if(!((d-27|0)>>>0<2>>>0|j|k)){break}l=i^1;m=(d|0)!=28;if(!(m|l)){n=1336;return n|0}o=a^1;p=j^1;if(!(o|p)){n=1336;return n|0}j=h^1;q=(d|0)!=27;if(!(q|j)){n=1336;return n|0}r=g^1;s=k^1;if(!(r|s)){n=1336;return n|0}if(!((q|l)&(o|s))){n=1208;return n|0}if(!((l|p)&(m|o))){n=2080;return n|0}if((m|j)&(r|p)){return((j|s)&(q|r)?0:270)|0}n=c[1077824]|0;return n|0}}while(0);r=(b-41|0)>>>0<2>>>0;q=(b|0)==68;s=(b|0)==67;do{if(r|q|s){j=(d|0)==68;p=(d|0)==67;if(!((d-41|0)>>>0<2>>>0|j|p)){break}m=(b|0)!=42;o=j^1;if(!(m|o)){n=16;return n|0}j=q^1;l=(d|0)!=42;if(!(l|j)){n=16;return n|0}k=(b|0)!=41;t=p^1;if(!(k|t)){n=16;return n|0}p=s^1;u=(d|0)!=41;if(!(u|p)){n=16;return n|0}n=(m|t)&(u|j)&(k|o)&(l|p)?0:1494;return n|0}}while(0);s=(b|0)==292;q=(b|0)==291;p=(b|0)==294;l=(b|0)==293;do{if((b-291|0)>>>0<2>>>0|p|l){o=(d|0)==68;k=(d|0)==67;if(!((d-41|0)>>>0<2>>>0|o|k)){break}j=s^1;u=o^1;if(!(j|u)){n=1828;return n|0}o=p^1;t=(d|0)!=42;if(!(t|o)){n=1828;return n|0}m=q^1;v=k^1;if(!(m|v)){n=1828;return n|0}k=l^1;w=(d|0)!=41;if(!(w|k)){n=1828;return n|0}if(!((j|v)&(w|o)&(m|u)&(t|k))){n=2112;return n|0}if(!((t|j)&(o|u)&(w|m)&(k|v))){n=2228;return n|0}n=(w|j)&(o|v)&(t|m)&(k|u)?0:1714;return n|0}}while(0);u=(b|0)==10;k=(b|0)==9;m=(b-67|0)>>>0<2>>>0|l|p|g|a|(b|0)==3|(b|0)==47|(b|0)==48|(b|0)==49|(b|0)==50|(b|0)==65|(b|0)==64|(b|0)==19|(b|0)==20|(b|0)==21|u|k;if(m){if(!((d-67|0)>>>0<2>>>0|(d|0)==293|(d|0)==294|(d|0)==28|(d|0)==27|(d|0)==3|(d|0)==47|(d|0)==48|(d|0)==49|(d|0)==50|(d|0)==65|(d|0)==64|(d|0)==19|(d|0)==20|(d|0)==21|(d|0)==10|(d|0)==9)){x=30}}else{x=30}do{if((x|0)==30){a=r|q|s|h|i|(b|0)==2|(b|0)==43|(b|0)==44|(b|0)==45|(b|0)==46|(b|0)==63|(b|0)==62|(b|0)==22|(b|0)==23|(b|0)==24|u|k;if(a){if((d-41|0)>>>0<2>>>0|(d|0)==291|(d|0)==292|(d|0)==30|(d|0)==29|(d|0)==2|(d|0)==43|(d|0)==44|(d|0)==45|(d|0)==46|(d|0)==63|(d|0)==62|(d|0)==22|(d|0)==23|(d|0)==24|(d|0)==10|(d|0)==9){break}}if(m){if(!((d-41|0)>>>0<2>>>0|(d|0)==291|(d|0)==292|(d|0)==30|(d|0)==29|(d|0)==2|(d|0)==43|(d|0)==44|(d|0)==45|(d|0)==46|(d|0)==63|(d|0)==62|(d|0)==22|(d|0)==23|(d|0)==24|(d|0)==10|(d|0)==9)){x=48}}else{x=48}do{if((x|0)==48){if(!a){n=0;return n|0}if((d-67|0)>>>0<2>>>0|(d|0)==293|(d|0)==294|(d|0)==28|(d|0)==27|(d|0)==3|(d|0)==47|(d|0)==48|(d|0)==49|(d|0)==50|(d|0)==65|(d|0)==64|(d|0)==19|(d|0)==20|(d|0)==21|(d|0)==10|(d|0)==9){break}else{n=0}return n|0}}while(0);a=f<<16|e;if((a|0)==1048592){n=1358;return n|0}else if((a|0)==1048600){n=c[1149344]|0;return n|0}else if((a|0)==1048608){n=c[1149332]|0;return n|0}else if((a|0)==2097176){n=c[1149340]|0;return n|0}else if((a|0)==786444){n=1126;return n|0}else if((a|0)==983055){n=2116;return n|0}else if((a|0)==983056){n=1356;return n|0}else if((a|0)==1572896){n=c[1149330]|0;return n|0}else if((a|0)==2097167){n=1618;return n|0}else if((a|0)==2097168){n=1426;return n|0}else if((a|0)==1572879){n=c[1149358]|0;return n|0}else if((a|0)==1572880){n=c[1149352]|0;return n|0}else if((a|0)==1572888){n=c[1149342]|0;return n|0}else if((a|0)==983064){n=c[1149346]|0;return n|0}else if((a|0)==983072){n=c[1149334]|0;return n|0}else if((a|0)==1048591){n=1952;return n|0}else{n=0;return n|0}}}while(0);d=f<<16|e;if((d|0)==983052){n=1212;return n|0}else if((d|0)==1572879){n=1992;return n|0}else if((d|0)==1572880){n=2062;return n|0}else if((d|0)==1572896){n=252;return n|0}else if((d|0)==2097167){n=c[1149360]|0;return n|0}else if((d|0)==2097168){n=c[1149354]|0;return n|0}else if((d|0)==1048600){n=c[1149348]|0;return n|0}else if((d|0)==1048608){n=c[1149336]|0;return n|0}else if((d|0)==2097176){n=1878;return n|0}else if((d|0)==983056){n=c[1149356]|0;return n|0}else if((d|0)==983064){n=c[1149350]|0;return n|0}else if((d|0)==983072){n=c[1149338]|0;return n|0}else if((d|0)==1048591){n=c[1149362]|0;return n|0}else{n=0;return n|0}return 0}function Lyb(d,e,f,g,h,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;l=i;m=c[d+56>>2]|0;n=d+52|0;o=c[n>>2]|0;p=bFb(m)|0;q=bFb(c[n>>2]|0)|0;n=(c[d+64>>2]|0)+7|0;r=n>>3;s=(c[d+60>>2]|0)+7|0;t=s>>3;u=Kyb(d)|0;if((u|0)==0){v=ZEb(m)|0;w=ZEb(o)|0;yDb(d,16,1961096,(x=i,i=i+16|0,c[x>>2]=v,c[x+8>>2]=w,x)|0);i=x;i=l;return h|0}x=c[e>>2]|0;e=c[j>>2]|0;if((n&-8|0)==16){y=(a[p+7|0]&1)!=0}else{y=0}if((s&-8|0)==16){z=(a[q+7|0]&1)!=0}else{z=0}if((m|0)==29|(m|0)==27){A=(o-27|0)>>>0<2>>>0|(o|0)==30|(o|0)==29?x:x+1|0}else{A=x}do{if((o|0)==29|(o|0)==27){if((m-27|0)>>>0<2>>>0|(m|0)==30|(m|0)==29){B=e;break}if((h|0)>0){x=0;do{a[e+(ba(c[k>>2]|0,x+g|0)|0)|0]=-1;x=x+1|0;}while((x|0)<(h|0))}B=e+1|0}else{B=e}}while(0);e=c[k>>2]|0;m=ba(e,r)|0;o=c[f>>2]|0;do{if((m|0)==(ba(o,t)|0)&(o|0)>0){if(((o|0)%(r|0)|0|0)!=0|z|y){break}x=B+(ba(e,g)|0)|0;q=ba(o,h)|0;Xe[u&4095](A,x,q);i=l;return h|0}}while(0);o=B+(ba(e,g)|0)|0;if((h|0)<=0){i=l;return h|0}g=d+8|0;e=d+2208|0;if(y){C=o;D=A;E=0}else{y=o;o=A;A=0;while(1){d=ba(c[g>>2]|0,r)|0;Xe[u&4095](o,y,d);do{if(z){d=c[g>>2]|0;if((d|0)<=0){break}B=y;t=0;do{m=B+(t<<1)|0;b[m>>1]=de(b[m>>1]|0)|0;t=t+1|0;}while((t|0)<(d|0))}}while(0);d=A+1|0;if((d|0)<(h|0)){y=y+(c[k>>2]|0)|0;o=o+(c[f>>2]|0)|0;A=d}else{break}}i=l;return h|0}while(1){A=c[g>>2]|0;if((A|0)>0){o=D;y=c[e>>2]|0;d=y;t=0;while(1){b[d+(t<<1)>>1]=de(b[o+(t<<1)>>1]|0)|0;B=t+1|0;if((B|0)<(A|0)){t=B}else{F=y;break}}}else{F=c[e>>2]|0}y=ba(A,r)|0;Xe[u&4095](F,C,y);do{if(z){y=c[g>>2]|0;if((y|0)<=0){break}t=C;o=0;do{d=t+(o<<1)|0;b[d>>1]=de(b[d>>1]|0)|0;o=o+1|0;}while((o|0)<(y|0))}}while(0);A=E+1|0;if((A|0)<(h|0)){C=C+(c[k>>2]|0)|0;D=D+(c[f>>2]|0)|0;E=A}else{break}}i=l;return h|0}function Myb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;i=c[b>>2]|0;j=c[d>>2]|0;k=a+8|0;a=c[k>>2]|0;l=c[h>>2]|0;m=(c[g>>2]|0)+(ba(l,e)|0)|0;do{if((l|0)==(j|0)&(j|0)>0){UGb(m|0,i|0,ba(j,f)|0)|0}else{if((f|0)>0){n=m;o=i;p=0}else{break}while(1){UGb(n|0,o|0,a)|0;q=p+1|0;if((q|0)<(f|0)){n=n+l|0;o=o+j|0;p=q}else{break}}}}while(0);p=c[b+4>>2]|0;j=c[d+4>>2]|0;o=c[k>>2]|0;l=c[h+4>>2]|0;n=(c[g+4>>2]|0)+(ba(l,e)|0)|0;do{if((l|0)==(j|0)&(j|0)>0){UGb(n|0,p|0,ba(j,f)|0)|0}else{if((f|0)>0){r=n;s=p;t=0}else{break}while(1){UGb(r|0,s|0,o)|0;a=t+1|0;if((a|0)<(f|0)){r=r+l|0;s=s+j|0;t=a}else{break}}}}while(0);t=c[b+8>>2]|0;b=c[d+8>>2]|0;d=c[k>>2]|0;j=c[h+8>>2]|0;s=(c[g+8>>2]|0)+(ba(j,e)|0)|0;do{if((j|0)==(b|0)&(b|0)>0){UGb(s|0,t|0,ba(b,f)|0)|0}else{if((f|0)>0){u=s;v=t;w=0}else{break}while(1){UGb(u|0,v|0,d)|0;l=w+1|0;if((l|0)<(f|0)){u=u+j|0;v=v+b|0;w=l}else{break}}}}while(0);w=c[g+12>>2]|0;if((w|0)==0){return f|0}g=c[h+12>>2]|0;h=c[k>>2]|0;if((f|0)<=0){return f|0}k=0;b=w+(ba(g,e)|0)|0;while(1){TGb(b|0,-1|0,h|0)|0;e=k+1|0;if((e|0)<(f|0)){k=e;b=b+g|0}else{break}}return f|0}function Nyb(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=i;l=c[d+4>>2]|0;m=c[d>>2]|0;n=c[d+8>>2]|0;d=c[e+4>>2]|0;o=c[e>>2]|0;p=c[e+8>>2]|0;e=c[b+56>>2]|0;if((e|0)!=82){q=ZEb(e)|0;e=ZEb(c[b+52>>2]|0)|0;yDb(b,16,1933232,(r=i,i=i+16|0,c[r>>2]=q,c[r+8>>2]=e,r)|0);i=r;i=k;return g|0}e=b+52|0;switch(c[e>>2]|0){case 3:{q=c[h>>2]|0;s=c[j>>2]|0;t=c[b+8>>2]|0;if((g|0)>0&(t|0)>0){u=0;v=l;w=m;x=n}else{i=k;return g|0}while(1){y=0;z=q+(ba(u+f|0,s)|0)|0;while(1){a[z]=a[v+y|0]|0;a[z+1|0]=a[w+y|0]|0;a[z+2|0]=a[x+y|0]|0;A=y+1|0;if((A|0)<(t|0)){y=A;z=z+3|0}else{break}}z=u+1|0;if((z|0)<(g|0)){u=z;v=v+d|0;w=w+o|0;x=x+p|0}else{break}}i=k;return g|0};case 30:{B=0;C=22;break};case 2:{x=c[h>>2]|0;w=c[j>>2]|0;v=c[b+8>>2]|0;if((g|0)>0&(v|0)>0){D=0;E=n;F=m;G=l}else{i=k;return g|0}while(1){u=0;t=x+(ba(D+f|0,w)|0)|0;while(1){a[t]=a[E+u|0]|0;a[t+1|0]=a[F+u|0]|0;a[t+2|0]=a[G+u|0]|0;s=u+1|0;if((s|0)<(v|0)){u=s;t=t+3|0}else{break}}t=D+1|0;if((t|0)<(g|0)){D=t;E=E+p|0;F=F+o|0;G=G+d|0}else{break}}i=k;return g|0};case 27:{H=1;C=13;break};case 28:{H=0;C=13;break};case 29:{B=1;C=22;break};default:{G=ZEb(82)|0;F=ZEb(c[e>>2]|0)|0;yDb(b,16,1933232,(r=i,i=i+16|0,c[r>>2]=G,c[r+8>>2]=F,r)|0);i=r;i=k;return g|0}}if((C|0)==13){r=c[h>>2]|0;F=c[j>>2]|0;G=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}e=(H|0)==0;H=(G|0)>0;E=0;D=n;v=m;w=l;while(1){x=r+(ba(E+f|0,F)|0)|0;do{if(e){if(H){I=0;J=x}else{break}while(1){a[J]=a[D+I|0]|0;a[J+1|0]=a[v+I|0]|0;a[J+2|0]=a[w+I|0]|0;a[J+3|0]=-1;t=I+1|0;if((t|0)<(G|0)){I=t;J=J+4|0}else{break}}}else{if(H){K=0;L=x}else{break}while(1){a[L]=-1;a[L+1|0]=a[D+K|0]|0;a[L+2|0]=a[v+K|0]|0;a[L+3|0]=a[w+K|0]|0;t=K+1|0;if((t|0)<(G|0)){K=t;L=L+4|0}else{break}}}}while(0);x=E+1|0;if((x|0)<(g|0)){E=x;D=D+p|0;v=v+o|0;w=w+d|0}else{break}}i=k;return g|0}else if((C|0)==22){C=c[h>>2]|0;h=c[j>>2]|0;j=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}b=(B|0)==0;B=(j|0)>0;w=0;v=l;l=m;m=n;while(1){n=C+(ba(w+f|0,h)|0)|0;do{if(b){if(B){M=0;N=n}else{break}while(1){a[N]=a[v+M|0]|0;a[N+1|0]=a[l+M|0]|0;a[N+2|0]=a[m+M|0]|0;a[N+3|0]=-1;D=M+1|0;if((D|0)<(j|0)){M=D;N=N+4|0}else{break}}}else{if(B){O=0;P=n}else{break}while(1){a[P]=-1;a[P+1|0]=a[v+O|0]|0;a[P+2|0]=a[l+O|0]|0;a[P+3|0]=a[m+O|0]|0;D=O+1|0;if((D|0)<(j|0)){O=D;P=P+4|0}else{break}}}}while(0);n=w+1|0;if((n|0)<(g|0)){w=n;v=v+d|0;l=l+o|0;m=m+p|0}else{break}}i=k;return g|0}return 0}function Oyb(b,f,g,h,j,k,l){b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;m=i;i=i+64|0;n=m|0;o=m+16|0;p=m+32|0;q=m+48|0;r=n|0;s=c[k+8>>2]|0;c[r>>2]=s;t=c[k>>2]|0;c[n+4>>2]=t;u=c[k+4>>2]|0;c[n+8>>2]=u;v=c[k+12>>2]|0;c[n+12>>2]=v;n=o|0;c[n>>2]=u;c[o+4>>2]=t;c[o+8>>2]=s;c[o+12>>2]=v;v=p|0;o=c[l+8>>2]|0;c[v>>2]=o;s=c[l>>2]|0;c[p+4>>2]=s;t=c[l+4>>2]|0;c[p+8>>2]=t;u=c[l+12>>2]|0;c[p+12>>2]=u;p=q|0;c[p>>2]=t;c[q+4>>2]=s;c[q+8>>2]=o;c[q+12>>2]=u;u=b+56|0;q=bFb(c[u>>2]|0)|0;o=bFb(c[b+52>>2]|0)|0;s=(e[o+8>>1]|0)>>>11&15;t=d[q+7|0]|0;l=t&128;k=t&1;t=a[o+7|0]|0;w=(t&1)==0?k:k|2;if((t&48)!=48|(s+1|0)>>>0<9>>>0){t=c[o>>2]|0;yDb(b,16,1910320,(x=i,i=i+16|0,c[x>>2]=c[q>>2],c[x+8>>2]=t,x)|0);i=x;i=m;return j|0}switch(c[u>>2]|0){case 68:case 67:case 294:case 293:{u=c[g>>2]|0;dAb((c[f>>2]|0)+(ba(u,h)|0)|0,u,n,p,j,l,w,s^15,c[b+8>>2]|0);i=m;return j|0};case 42:case 41:case 292:case 291:{p=c[g>>2]|0;dAb((c[f>>2]|0)+(ba(p,h)|0)|0,p,r,v,j,l,w,s^15,c[b+8>>2]|0);i=m;return j|0};default:{s=c[o>>2]|0;yDb(b,16,1910320,(x=i,i=i+16|0,c[x>>2]=c[q>>2],c[x+8>>2]=s,x)|0);i=x;i=m;return j|0}}return 0}function Pyb(b,d,f,g,h,j,k){b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=i;i=i+64|0;m=l|0;n=l+16|0;o=l+32|0;p=l+48|0;q=m|0;r=c[d+4>>2]|0;c[q>>2]=r;s=c[d>>2]|0;c[m+4>>2]=s;t=c[d+8>>2]|0;c[m+8>>2]=t;u=c[d+12>>2]|0;c[m+12>>2]=u;m=n|0;c[m>>2]=t;c[n+4>>2]=s;c[n+8>>2]=r;c[n+12>>2]=u;u=o|0;n=c[f+4>>2]|0;c[u>>2]=n;r=c[f>>2]|0;c[o+4>>2]=r;s=c[f+8>>2]|0;c[o+8>>2]=s;t=c[f+12>>2]|0;c[o+12>>2]=t;o=p|0;c[o>>2]=s;c[p+4>>2]=r;c[p+8>>2]=n;c[p+12>>2]=t;t=bFb(c[b+56>>2]|0)|0;p=b+52|0;n=bFb(c[p>>2]|0)|0;r=((e[t+8>>1]|0)>>>11&15)+1|0;s=a[t+7|0]|0;f=s&1;d=(a[n+7|0]&1)==0?f:f|2;if((s&48)!=48|r>>>0<9>>>0){s=c[n>>2]|0;yDb(b,16,1933232,(v=i,i=i+16|0,c[v>>2]=c[t>>2],c[v+8>>2]=s,v)|0);i=v;i=l;return h|0}switch(c[p>>2]|0){case 292:case 291:{p=c[k>>2]|0;cAb(m,o,(c[j>>2]|0)+(ba(p,g)|0)|0,p,h,1,d,r,c[b+8>>2]|0);i=l;return h|0};case 68:case 67:{p=c[k>>2]|0;cAb(q,u,(c[j>>2]|0)+(ba(p,g)|0)|0,p,h,0,d,r,c[b+8>>2]|0);i=l;return h|0};case 42:case 41:{p=c[k>>2]|0;cAb(m,o,(c[j>>2]|0)+(ba(p,g)|0)|0,p,h,0,d,r,c[b+8>>2]|0);i=l;return h|0};case 294:case 293:{p=c[k>>2]|0;cAb(q,u,(c[j>>2]|0)+(ba(p,g)|0)|0,p,h,1,d,r,c[b+8>>2]|0);i=l;return h|0};default:{r=c[n>>2]|0;yDb(b,16,1933232,(v=i,i=i+16|0,c[v>>2]=c[t>>2],c[v+8>>2]=r,v)|0);i=v;i=l;return h|0}}return 0}function Qyb(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;k=i;l=c[j+4>>2]|0;m=c[j>>2]|0;n=c[j+8>>2]|0;j=(c[h+4>>2]|0)+(ba(l,f)|0)|0;o=(c[h>>2]|0)+(ba(m,f)|0)|0;p=(c[h+8>>2]|0)+(ba(n,f)|0)|0;f=c[b+56>>2]|0;switch(f|0){case 28:{q=0;r=15;break};case 3:{h=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}s=(h|0)>0;t=h*3|0;u=(c[e>>2]|0)-t|0;v=c[d>>2]|0;w=p;x=o;y=j;z=0;while(1){if(s){A=v;B=0;while(1){a[y+B|0]=a[A]|0;a[x+B|0]=a[A+1|0]|0;a[w+B|0]=a[A+2|0]|0;C=B+1|0;if((C|0)<(h|0)){A=A+3|0;B=C}else{break}}D=v+t|0}else{D=v}B=z+1|0;if((B|0)<(g|0)){v=D+u|0;w=w+n|0;x=x+m|0;y=y+l|0;z=B}else{break}}i=k;return g|0};case 29:{E=1;r=22;break};case 30:{E=0;r=22;break};case 27:{q=1;r=15;break};case 2:{z=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}y=(z|0)>0;x=z*3|0;w=(c[e>>2]|0)-x|0;u=c[d>>2]|0;D=j;v=o;t=p;h=0;while(1){if(y){s=u;B=0;while(1){a[t+B|0]=a[s]|0;a[v+B|0]=a[s+1|0]|0;a[D+B|0]=a[s+2|0]|0;A=B+1|0;if((A|0)<(z|0)){s=s+3|0;B=A}else{break}}F=u+x|0}else{F=u}B=h+1|0;if((B|0)<(g|0)){u=F+w|0;D=D+l|0;v=v+m|0;t=t+n|0;h=B}else{break}}i=k;return g|0};default:{h=ZEb(f)|0;f=ZEb(c[b+52>>2]|0)|0;yDb(b,16,1933232,(t=i,i=i+16|0,c[t>>2]=h,c[t+8>>2]=f,t)|0);i=t;i=k;return g|0}}if((r|0)==15){t=c[d>>2]|0;f=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}h=(f|0)>0;v=f<<2;D=(c[e>>2]|0)-v|0;w=(q|0)==0?t:t+1|0;t=j;q=o;F=p;u=0;while(1){if(h){x=w;z=0;while(1){a[F+z|0]=a[x]|0;a[q+z|0]=a[x+1|0]|0;a[t+z|0]=a[x+2|0]|0;y=z+1|0;if((y|0)<(f|0)){x=x+4|0;z=y}else{break}}G=w+v|0}else{G=w}z=u+1|0;if((z|0)<(g|0)){w=G+D|0;t=t+l|0;q=q+m|0;F=F+n|0;u=z}else{break}}i=k;return g|0}else if((r|0)==22){r=c[d>>2]|0;d=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}b=(d|0)>0;u=d<<2;F=(c[e>>2]|0)-u|0;e=(E|0)==0?r:r+1|0;r=p;p=o;o=j;j=0;while(1){if(b){E=e;q=0;while(1){a[o+q|0]=a[E]|0;a[p+q|0]=a[E+1|0]|0;a[r+q|0]=a[E+2|0]|0;t=q+1|0;if((t|0)<(d|0)){E=E+4|0;q=t}else{break}}H=e+u|0}else{H=e}q=j+1|0;if((q|0)<(g|0)){e=H+F|0;r=r+n|0;p=p+m|0;o=o+l|0;j=q}else{break}}i=k;return g|0}return 0}function Ryb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=c[g>>2]|0;g=c[b>>2]|0;switch(c[a+56>>2]|0){case 330:{i=38;j=438;break};case 331:{i=508;j=322;break};case 328:{i=514;j=378;break};case 322:{i=318;j=310;break};case 326:{i=8;j=396;break};case 321:{i=478;j=182;break};case 327:{i=258;j=376;break};case 325:{i=272;j=256;break};case 323:{i=402;j=334;break};case 329:{i=178;j=78;break};case 332:{i=90;j=382;break};case 324:{i=534;j=470;break};default:{k=0;return k|0}}b=a+8|0;le[j&1023](g,c[d>>2]|0,e,c[h>>2]|0,c[b>>2]|0);a=c[d>>2]|0;l=g+(a<<1)|0;g=c[h>>2]|0;m=e+(g<<1)|0;e=f-2|0;n=c[b>>2]|0;if((e|0)>2){o=m;p=l;q=2;r=a;s=g;t=n;while(1){le[i&1023](p,r,o,s,t);u=c[d>>2]|0;v=p+(u<<1)|0;w=c[h>>2]|0;x=o+(w<<1)|0;y=q+2|0;z=c[b>>2]|0;if((y|0)<(e|0)){o=x;p=v;q=y;r=u;s=w;t=z}else{A=x;B=v;C=u;D=w;E=z;break}}}else{A=m;B=l;C=a;D=g;E=n}le[j&1023](B,C,A,D,E);k=f;return k|0}function Syb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;e=c[b>>2]|0;b=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;switch(c[a+56>>2]|0){case 326:{k=90;l=108;break};case 328:{k=84;l=102;break};case 329:{k=88;l=28;break};case 330:{k=44;l=118;break};case 321:{k=94;l=52;break};case 323:{k=46;l=38;break};case 324:{k=24;l=30;break};case 331:{k=42;l=40;break};case 327:{k=116;l=56;break};case 322:{k=12;l=60;break};case 332:{k=20;l=74;break};case 325:{k=22;l=50;break};default:{m=0;return m|0}}g=a+8|0;n=a+10496|0;Be[l&127](e,c[d>>2]|0,b,i,j,c[h>>2]|0,c[g>>2]|0,n);a=c[d>>2]|0;o=e+(a<<1)|0;e=c[h>>2]|0;p=b+(e<<1)|0;b=h+4|0;q=c[b>>2]|0;r=i+q|0;i=j+q|0;q=f-2|0;j=c[g>>2]|0;if((q|0)>2){s=o;t=p;u=r;v=i;w=2;x=a;y=e;z=j;while(1){Be[k&127](s,x,t,u,v,y,z,n);A=c[d>>2]|0;B=s+(A<<1)|0;C=c[h>>2]|0;D=t+(C<<1)|0;E=c[b>>2]|0;F=u+E|0;G=v+E|0;E=w+2|0;H=c[g>>2]|0;if((E|0)<(q|0)){s=B;t=D;u=F;v=G;w=E;x=A;y=C;z=H}else{I=B;J=D;K=F;L=G;M=A;N=C;O=H;break}}}else{I=o;J=p;K=r;L=i;M=a;N=e;O=j}Be[l&127](I,M,J,K,L,N,O,n);m=f;return m|0}function Tyb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a+88|0;a=0;do{j=c[e+(a<<2)>>2]|0;k=(j|0)/2|0;l=c[i+(a<<2)>>2]|0;m=(l|0)/2|0;n=c[h+(a<<2)>>2]|0;o=n;p=c[d+(a<<2)>>2]|0;q=p;r=(j|0)>-2?k:-k|0;j=(l|0)>-2?m:-m|0;l=(r|0)>(j|0)?j:r;do{if(!((n|0)==0|(p|0)==0)){r=g>>c[f>>2];if((r|0)<=0){break}j=(l|0)>0;s=o;t=q;u=0;while(1){if(j){v=0;do{b[s+(v<<1)>>1]=de(b[t+(v<<1)>>1]|0)|0;v=v+1|0;}while((v|0)<(l|0))}v=u+1|0;if((v|0)<(r|0)){s=s+(m<<1)|0;t=t+(k<<1)|0;u=v}else{break}}}}while(0);a=a+1|0;}while((a|0)<4);return g|0}function Uyb(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;l=c[b+56>>2]|0;m=c[b+52>>2]|0;n=(c[h>>2]|0)+(ba(c[j>>2]|0,f)|0)|0;f=c[d>>2]|0;a:do{if((l|0)==66){switch(m|0){case 2:{o=498;break a;break};case 30:case 28:{o=100;break a;break};case 3:{o=498;break a;break};case 29:{o=122;break a;break};case 27:{o=122;break a;break};default:{p=15;break a}}}else{d=bFb(l)|0;if((d|0)==0){yDb(0,0,2301720,(q=i,i=i+24|0,c[q>>2]=2042536,c[q+8>>2]=1997616,c[q+16>>2]=828,q)|0);i=q;Cd();return 0}if((a[d+7|0]&66)==0){p=15;break}switch(m|0){case 30:case 28:case 27:case 29:{o=178;break a;break};case 2:{o=578;break a;break};case 3:{o=578;break a;break};default:{p=15;break a}}}}while(0);if((p|0)==15){p=ZEb(l)|0;l=ZEb(m)|0;yDb(b,16,1961096,(q=i,i=i+16|0,c[q>>2]=p,c[q+8>>2]=l,q)|0);i=q;i=k;return g|0}if((g|0)<=0){i=k;return g|0}q=b+8|0;l=b+1144|0;b=0;p=n;n=f;while(1){cf[o&1023](n,p,c[q>>2]|0,l);f=b+1|0;if((f|0)<(g|0)){b=f;p=p+(c[j>>2]|0)|0;n=n+(c[e>>2]|0)|0}else{break}}i=k;return g|0}function Vyb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;i=c[h>>2]|0;h=(c[g>>2]|0)+(ba(i,e)|0)|0;Le[c[591456]&255](c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,h,c[a+8>>2]|0,f,c[d>>2]|0,c[d+4>>2]|0,i);return f|0}function Wyb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;i=c[h>>2]|0;h=(c[g>>2]|0)+(ba(i,e)|0)|0;Le[c[591458]&255](c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,h,c[a+8>>2]|0,f,c[d>>2]|0,c[d+4>>2]|0,i);return f|0}function Xyb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;i=c[h>>2]|0;h=(c[g>>2]|0)+(ba(i,e)|0)|0;Le[c[591446]&255](c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,h,c[a+8>>2]|0,f,c[d>>2]|0,c[d+4>>2]|0,i);return f|0}function Yyb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;i=c[h>>2]|0;h=(c[g>>2]|0)+(ba(i,e)|0)|0;Le[c[591448]&255](c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,h,c[a+8>>2]|0,f,c[d>>2]|0,c[d+4>>2]|0,i);return f|0}function Zyb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ba(i,e)|0)|0;k=c[h+4>>2]|0;l=(c[g+4>>2]|0)+((ba(k,e)|0)/2|0)|0;m=(c[g+8>>2]|0)+((ba(c[h+8>>2]|0,e)|0)/2|0)|0;n=a+8|0;Le[c[591452]&255](j,l,m,c[b>>2]|0,c[n>>2]|0,f,i,k,c[d>>2]|0);d=c[g+12>>2]|0;if((d|0)==0){return f|0}g=c[h+12>>2]|0;h=c[n>>2]|0;if((f|0)<=0){return f|0}n=0;k=d+(ba(g,e)|0)|0;while(1){TGb(k|0,-1|0,h|0)|0;e=n+1|0;if((e|0)<(f|0)){n=e;k=k+g|0}else{break}}return f|0}function _yb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ba(i,e)|0)|0;k=c[h+4>>2]|0;l=(c[g+4>>2]|0)+((ba(k,e)|0)/2|0)|0;m=(c[g+8>>2]|0)+((ba(c[h+8>>2]|0,e)|0)/2|0)|0;n=a+8|0;Le[c[646580]&255](j,l,m,c[b>>2]|0,c[n>>2]|0,f,i,k,c[d>>2]|0);d=c[g+12>>2]|0;if((d|0)==0){return f|0}g=c[h+12>>2]|0;h=c[n>>2]|0;if((f|0)<=0){return f|0}n=0;k=d+(ba(g,e)|0)|0;while(1){TGb(k|0,-1|0,h|0)|0;e=n+1|0;if((e|0)<(f|0)){n=e;k=k+g|0}else{break}}return f|0}function $yb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ba(i,e)|0)|0;k=c[h+4>>2]|0;l=(c[g+4>>2]|0)+(ba(k,e)|0)|0;m=(c[g+8>>2]|0)+(ba(c[h+8>>2]|0,e)|0)|0;Le[c[591450]&255](j,l,m,c[b>>2]|0,c[a+8>>2]|0,f,i,k,c[d>>2]|0);return f|0}function azb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ba(i,e)|0)|0;k=c[h+4>>2]|0;l=(c[g+4>>2]|0)+(ba(k,e)|0)|0;m=(c[g+8>>2]|0)+(ba(c[h+8>>2]|0,e)|0)|0;Le[c[646578]&255](j,l,m,c[b>>2]|0,c[a+8>>2]|0,f,i,k,c[d>>2]|0);return f|0}function bzb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[h>>2]|0;j=c[d>>2]|0;if((i|0)==(j|0)&(j|0)>0){k=(c[g>>2]|0)+(ba(i,e)|0)|0;UGb(k|0,c[b>>2]|0,ba(i,f)|0)|0;return f|0}k=c[b>>2]|0;b=(c[g>>2]|0)+(ba(i,e)|0)|0;e=c[a+8>>2]|0;a=(i|0)>-1?i:-i|0;i=0;while(1){g=e+i|0;if((g|0)>(a|0)){break}if((g|0)>(((j|0)>-1?j:-j|0)|0)){break}else{i=g}}if((f|0)>0){l=0;m=k;n=b}else{return f|0}while(1){UGb(n|0,m|0,i)|0;b=l+1|0;if((b|0)<(f|0)){l=b;m=m+(c[d>>2]|0)|0;n=n+(c[h>>2]|0)|0}else{break}}return f|0}function czb(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;n=i;o=f+56|0;p=bFb(c[o>>2]|0)|0;q=f+52|0;r=bFb(c[q>>2]|0)|0;s=f+8|0;t=f+84|0;u=-j|0;v=f+88|0;w=-k|0;y=l+8|0;z=g+8|0;A=p+8|0;B=f+11260|0;f=0;a:while(1){C=(f|0)==3;D=c[s>>2]|0;if((f|0)==3|(f|0)==0){E=D}else{E=-(-D>>c[t>>2])|0}if((f|0)==3|(f|0)==0){F=j}else{F=-(u>>c[v>>2])|0}if((f|0)==3|(f|0)==0){G=k}else{G=-(w>>c[v>>2])|0}D=g+(f<<2)|0;H=c[D>>2]|0;I=l+(f<<2)|0;J=c[I>>2]|0;K=m+(f<<2)|0;L=J+(ba(c[K>>2]|0,F)|0)|0;M=(f|0)==1;if((f-1|0)>>>0<2>>>0){N=1}else{N=(c[B>>2]|f|0)==0}b:do{if((J|0)!=0){do{if(M){if((c[y>>2]|0)!=0){break}f=f+1|0;continue a}}while(0);do{if((H|0)!=0){if(M){if((c[z>>2]|0)==0){break}}O=bFb(c[o>>2]|0)|0;if((O|0)==0){P=40;break a}do{if(!((((e[O+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0)){Q=bFb(c[q>>2]|0)|0;if((Q|0)==0){P=43;break a}if((((e[Q+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){break}Q=bFb(c[o>>2]|0)|0;if((Q|0)==0){P=46;break a}R=b[Q+8>>1]|0;Q=bFb(c[q>>2]|0)|0;if((Q|0)==0){P=48;break a}if((R&30720)==30720^(b[Q+8>>1]&30720)==30720){break}Q=bFb(c[o>>2]|0)|0;if((Q|0)==0){P=169;break a}do{if((b[Q+8>>1]&30720)==30720){R=bFb(c[q>>2]|0)|0;if((R|0)==0){P=172;break a}if(!((b[R+8>>1]&30720)==30720)){break}R=bFb(c[o>>2]|0)|0;if((R|0)==0){P=175;break a}S=a[R+7|0]|0;R=bFb(c[q>>2]|0)|0;if((R|0)==0){P=177;break a}if(((a[R+7|0]^S)&1)==0){break}if((G|0)<=0){break b}S=(E|0)>0;R=c[h+(f<<2)>>2]|0;T=c[K>>2]|0;U=L;V=H;W=0;while(1){if(S){X=V;Y=U;Z=0;do{b[Y+(Z<<1)>>1]=de(b[X+(Z<<1)>>1]|0)|0;Z=Z+1|0;}while((Z|0)<(E|0))}Z=W+1|0;if((Z|0)<(G|0)){U=U+T|0;V=V+R|0;W=Z}else{break b}}}}while(0);Q=c[K>>2]|0;W=h+(f<<2)|0;R=c[W>>2]|0;if((Q|0)==(R|0)&(R|0)>0&(R|0)==(E|0)){R=(c[I>>2]|0)+(ba(Q,F)|0)|0;UGb(R|0,c[D>>2]|0,ba(Q,G)|0)|0;break b}Q=bFb(c[o>>2]|0)|0;if((Q|0)==0){P=188;break a}do{if((b[Q+8>>1]&30720)==30720){R=bFb(c[q>>2]|0)|0;if((R|0)==0){P=191;break a}if(!((b[R+8>>1]&30720)==30720)){P=194;break}_=E<<1}else{P=194}}while(0);if((P|0)==194){P=0;_=(b[A>>1]&30720)==0?E>>3:E}if((G|0)>0){$=L;aa=H;ca=0}else{break b}while(1){UGb($|0,aa|0,_)|0;Q=ca+1|0;if((Q|0)<(G|0)){$=$+(c[K>>2]|0)|0;aa=aa+(c[W>>2]|0)|0;ca=Q}else{break b}}}}while(0);O=(e[p+8+(f<<1)>>1]|0)>>>11&15;W=O+1|0;Q=(e[r+8+(f<<1)>>1]|0)>>>11&15;R=Q+1|0;V=H;T=L;if((R|0)==8){U=bFb(c[o>>2]|0)|0;if((U|0)==0){P=52;break a}S=b[1361080+(Q<<5)+(O<<1)>>1]|0;Z=(e[1361080+(O-1<<5)+(Q<<1)>>1]|0)+(O-7)|0;X=(G|0)>0;if((a[U+7|0]&1)==0){if(!X){break b}U=O-8|0;Y=E-7|0;da=(Y|0)>0;ea=h+(f<<2)|0;fa=S&65535;ga=V;ha=L;ia=0;while(1){ja=ia&7;if(da){ka=d[1360528+(U<<6)+(ja<<3)|0]|0;la=d[1360528+(U<<6)+(ja<<3)+1|0]|0;ma=d[1360528+(U<<6)+(ja<<3)+2|0]|0;na=d[1360528+(U<<6)+(ja<<3)+3|0]|0;oa=d[1360528+(U<<6)+(ja<<3)+4|0]|0;pa=d[1360528+(U<<6)+(ja<<3)+5|0]|0;qa=d[1360528+(U<<6)+(ja<<3)+6|0]|0;ra=d[1360528+(U<<6)+(ja<<3)+7|0]|0;sa=0;while(1){a[ha+sa|0]=(ba(ka+(e[ga+(sa<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|1;a[ha+ta|0]=(ba(la+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|2;a[ha+ta|0]=(ba(ma+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|3;a[ha+ta|0]=(ba(na+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|4;a[ha+ta|0]=(ba(oa+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|5;a[ha+ta|0]=(ba(pa+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|6;a[ha+ta|0]=(ba(qa+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|7;a[ha+ta|0]=(ba(ra+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa+8|0;if((ta|0)<(Y|0)){sa=ta}else{ua=ta;break}}}else{ua=0}if((ua|0)<(E|0)){sa=ua;do{a[ha+sa|0]=(ba((d[(sa&7)+(1360528+(U<<6)+(ja<<3))|0]|0)+(e[ga+(sa<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);sa=sa+1|0;}while((sa|0)<(E|0))}sa=ia+1|0;if((sa|0)<(G|0)){ga=ga+(((c[ea>>2]|0)/2|0)<<1)|0;ha=ha+(c[K>>2]|0)|0;ia=sa}else{break b}}}else{if(!X){break b}ia=O-8|0;ha=E-7|0;ea=(ha|0)>0;ga=h+(f<<2)|0;fa=S&65535;U=V;Y=L;da=0;while(1){sa=da&7;if(ea){ja=d[1360528+(ia<<6)+(sa<<3)|0]|0;ra=d[1360528+(ia<<6)+(sa<<3)+1|0]|0;qa=d[1360528+(ia<<6)+(sa<<3)+2|0]|0;pa=d[1360528+(ia<<6)+(sa<<3)+3|0]|0;oa=d[1360528+(ia<<6)+(sa<<3)+4|0]|0;na=d[1360528+(ia<<6)+(sa<<3)+5|0]|0;ma=d[1360528+(ia<<6)+(sa<<3)+6|0]|0;la=d[1360528+(ia<<6)+(sa<<3)+7|0]|0;ka=0;while(1){a[Y+ka|0]=(ba(ja+((de(b[U+(ka<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|1;a[Y+ta|0]=(ba(ra+((de(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|2;a[Y+ta|0]=(ba(qa+((de(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|3;a[Y+ta|0]=(ba(pa+((de(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|4;a[Y+ta|0]=(ba(oa+((de(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|5;a[Y+ta|0]=(ba(na+((de(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|6;a[Y+ta|0]=(ba(ma+((de(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|7;a[Y+ta|0]=(ba(la+((de(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka+8|0;if((ta|0)<(ha|0)){ka=ta}else{va=ta;break}}}else{va=0}if((va|0)<(E|0)){ka=va;do{la=(de(b[U+(ka<<1)>>1]|0)|0)&65535;a[Y+ka|0]=(ba((d[(ka&7)+(1360528+(ia<<6)+(sa<<3))|0]|0)+la|0,fa)|0)>>>(Z>>>0);ka=ka+1|0;}while((ka|0)<(E|0))}ka=da+1|0;if((ka|0)<(G|0)){U=U+(((c[ga>>2]|0)/2|0)<<1)|0;Y=Y+(c[K>>2]|0)|0;da=ka}else{break b}}}}if((W|0)==8){if((G|0)<=0){break b}da=(E|0)>0;Y=Q-7|0;ga=Q^15;U=h+(f<<2)|0;Z=T;fa=H;ia=0;while(1){ha=bFb(c[q>>2]|0)|0;if((ha|0)==0){P=74;break a}do{if((a[ha+7|0]&1)==0){if(N){if(da){wa=0}else{break}do{ea=Z+(wa<<1)|0;x=(d[fa+wa|0]|0)<<Y&65535;a[ea]=x;x=x>>8;a[ea+1|0]=x;wa=wa+1|0;}while((wa|0)<(E|0))}else{if(da){xa=0}else{break}do{ea=d[fa+xa|0]|0;S=Z+(xa<<1)|0;x=(ea<<Y|ea>>>(ga>>>0))&65535;a[S]=x;x=x>>8;a[S+1|0]=x;xa=xa+1|0;}while((xa|0)<(E|0))}}else{if(N){if(da){ya=0}else{break}do{S=Z+(ya<<1)|0;x=de((d[fa+ya|0]|0)<<Y&65535|0)|0;a[S]=x;x=x>>8;a[S+1|0]=x;ya=ya+1|0;}while((ya|0)<(E|0))}else{if(da){za=0}else{break}do{S=d[fa+za|0]|0;ea=Z+(za<<1)|0;x=de((S<<Y|S>>>(ga>>>0))&65535|0)|0;a[ea]=x;x=x>>8;a[ea+1|0]=x;za=za+1|0;}while((za|0)<(E|0))}}}while(0);ha=ia+1|0;if((ha|0)<(G|0)){Z=Z+(((c[K>>2]|0)/2|0)<<1)|0;fa=fa+(c[U>>2]|0)|0;ia=ha}else{break b}}}if(W>>>0>R>>>0){ia=bFb(c[o>>2]|0)|0;if((ia|0)==0){P=130;break a}U=a[ia+7|0]|0;ia=bFb(c[q>>2]|0)|0;if((ia|0)==0){P=132;break a}fa=(a[ia+7|0]&1)==0;ia=b[1361080+(Q<<5)+(O<<1)>>1]|0;Z=(e[1361080+(O-1<<5)+(Q<<1)>>1]|0)+(W-R)|0;ga=(G|0)>0;if((U&1)==0){if(fa){if(!ga){break b}U=O-8|0;Y=E-7|0;da=(Y|0)>0;ha=h+(f<<2)|0;ea=ia&65535;S=T;X=V;ka=0;while(1){sa=ka&7;if(da){la=d[1360528+(U<<6)+(sa<<3)|0]|0;ma=d[1360528+(U<<6)+(sa<<3)+1|0]|0;na=d[1360528+(U<<6)+(sa<<3)+2|0]|0;oa=d[1360528+(U<<6)+(sa<<3)+3|0]|0;pa=d[1360528+(U<<6)+(sa<<3)+4|0]|0;qa=d[1360528+(U<<6)+(sa<<3)+5|0]|0;ra=d[1360528+(U<<6)+(sa<<3)+6|0]|0;ja=d[1360528+(U<<6)+(sa<<3)+7|0]|0;ta=0;while(1){b[S+(ta<<1)>>1]=(ba(la+(e[X+(ta<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|1;b[S+(Aa<<1)>>1]=(ba(ma+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|2;b[S+(Aa<<1)>>1]=(ba(na+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|3;b[S+(Aa<<1)>>1]=(ba(oa+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|4;b[S+(Aa<<1)>>1]=(ba(pa+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|5;b[S+(Aa<<1)>>1]=(ba(qa+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|6;b[S+(Aa<<1)>>1]=(ba(ra+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|7;b[S+(Aa<<1)>>1]=(ba(ja+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta+8|0;if((Aa|0)<(Y|0)){ta=Aa}else{Ba=Aa;break}}}else{Ba=0}if((Ba|0)<(E|0)){ta=Ba;do{b[S+(ta<<1)>>1]=(ba((d[(ta&7)+(1360528+(U<<6)+(sa<<3))|0]|0)+(e[X+(ta<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);ta=ta+1|0;}while((ta|0)<(E|0))}ta=ka+1|0;if((ta|0)<(G|0)){S=S+(((c[K>>2]|0)/2|0)<<1)|0;X=X+(((c[ha>>2]|0)/2|0)<<1)|0;ka=ta}else{break b}}}else{if(!ga){break b}ka=O-8|0;ha=E-7|0;X=(ha|0)>0;S=h+(f<<2)|0;ea=ia&65535;U=T;Y=V;da=0;while(1){Q=da&7;if(X){ta=d[1360528+(ka<<6)+(Q<<3)|0]|0;sa=d[1360528+(ka<<6)+(Q<<3)+1|0]|0;ja=d[1360528+(ka<<6)+(Q<<3)+2|0]|0;ra=d[1360528+(ka<<6)+(Q<<3)+3|0]|0;qa=d[1360528+(ka<<6)+(Q<<3)+4|0]|0;pa=d[1360528+(ka<<6)+(Q<<3)+5|0]|0;oa=d[1360528+(ka<<6)+(Q<<3)+6|0]|0;na=d[1360528+(ka<<6)+(Q<<3)+7|0]|0;ma=0;while(1){b[U+(ma<<1)>>1]=de((ba(ta+(e[Y+(ma<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|1;b[U+(la<<1)>>1]=de((ba(sa+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|2;b[U+(la<<1)>>1]=de((ba(ja+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|3;b[U+(la<<1)>>1]=de((ba(ra+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|4;b[U+(la<<1)>>1]=de((ba(qa+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|5;b[U+(la<<1)>>1]=de((ba(pa+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|6;b[U+(la<<1)>>1]=de((ba(oa+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|7;b[U+(la<<1)>>1]=de((ba(na+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma+8|0;if((la|0)<(ha|0)){ma=la}else{Ca=la;break}}}else{Ca=0}if((Ca|0)<(E|0)){ma=Ca;do{b[U+(ma<<1)>>1]=de((ba((d[(ma&7)+(1360528+(ka<<6)+(Q<<3))|0]|0)+(e[Y+(ma<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;ma=ma+1|0;}while((ma|0)<(E|0))}ma=da+1|0;if((ma|0)<(G|0)){U=U+(((c[K>>2]|0)/2|0)<<1)|0;Y=Y+(((c[S>>2]|0)/2|0)<<1)|0;da=ma}else{break b}}}}else{if(fa){if(!ga){break b}da=O-8|0;S=E-7|0;Y=(S|0)>0;U=h+(f<<2)|0;ea=ia&65535;ka=T;ha=V;X=0;while(1){ma=X&7;if(Y){Q=d[1360528+(da<<6)+(ma<<3)|0]|0;na=d[1360528+(da<<6)+(ma<<3)+1|0]|0;oa=d[1360528+(da<<6)+(ma<<3)+2|0]|0;pa=d[1360528+(da<<6)+(ma<<3)+3|0]|0;qa=d[1360528+(da<<6)+(ma<<3)+4|0]|0;ra=d[1360528+(da<<6)+(ma<<3)+5|0]|0;ja=d[1360528+(da<<6)+(ma<<3)+6|0]|0;sa=d[1360528+(da<<6)+(ma<<3)+7|0]|0;ta=0;while(1){b[ka+(ta<<1)>>1]=(ba(Q+((de(b[ha+(ta<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|1;b[ka+(la<<1)>>1]=(ba(na+((de(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|2;b[ka+(la<<1)>>1]=(ba(oa+((de(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|3;b[ka+(la<<1)>>1]=(ba(pa+((de(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|4;b[ka+(la<<1)>>1]=(ba(qa+((de(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|5;b[ka+(la<<1)>>1]=(ba(ra+((de(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|6;b[ka+(la<<1)>>1]=(ba(ja+((de(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|7;b[ka+(la<<1)>>1]=(ba(sa+((de(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta+8|0;if((la|0)<(S|0)){ta=la}else{Da=la;break}}}else{Da=0}if((Da|0)<(E|0)){ta=Da;do{sa=(de(b[ha+(ta<<1)>>1]|0)|0)&65535;b[ka+(ta<<1)>>1]=(ba((d[(ta&7)+(1360528+(da<<6)+(ma<<3))|0]|0)+sa|0,ea)|0)>>>(Z>>>0);ta=ta+1|0;}while((ta|0)<(E|0))}ta=X+1|0;if((ta|0)<(G|0)){ka=ka+(((c[K>>2]|0)/2|0)<<1)|0;ha=ha+(((c[U>>2]|0)/2|0)<<1)|0;X=ta}else{break b}}}else{if(!ga){break b}X=O-8|0;U=E-7|0;ha=(U|0)>0;ka=h+(f<<2)|0;ea=ia&65535;da=T;S=V;Y=0;while(1){fa=Y&7;if(ha){ta=d[1360528+(X<<6)+(fa<<3)|0]|0;ma=d[1360528+(X<<6)+(fa<<3)+1|0]|0;sa=d[1360528+(X<<6)+(fa<<3)+2|0]|0;ja=d[1360528+(X<<6)+(fa<<3)+3|0]|0;ra=d[1360528+(X<<6)+(fa<<3)+4|0]|0;qa=d[1360528+(X<<6)+(fa<<3)+5|0]|0;pa=d[1360528+(X<<6)+(fa<<3)+6|0]|0;oa=d[1360528+(X<<6)+(fa<<3)+7|0]|0;na=0;while(1){b[da+(na<<1)>>1]=de((ba(ta+((de(b[S+(na<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|1;b[da+(Q<<1)>>1]=de((ba(ma+((de(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|2;b[da+(Q<<1)>>1]=de((ba(sa+((de(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|3;b[da+(Q<<1)>>1]=de((ba(ja+((de(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|4;b[da+(Q<<1)>>1]=de((ba(ra+((de(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|5;b[da+(Q<<1)>>1]=de((ba(qa+((de(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|6;b[da+(Q<<1)>>1]=de((ba(pa+((de(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|7;b[da+(Q<<1)>>1]=de((ba(oa+((de(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na+8|0;if((Q|0)<(U|0)){na=Q}else{Ea=Q;break}}}else{Ea=0}if((Ea|0)<(E|0)){na=Ea;do{oa=(de(b[S+(na<<1)>>1]|0)|0)&65535;b[da+(na<<1)>>1]=de((ba((d[(na&7)+(1360528+(X<<6)+(fa<<3))|0]|0)+oa|0,ea)|0)>>>(Z>>>0)&65535|0)|0;na=na+1|0;}while((na|0)<(E|0))}na=Y+1|0;if((na|0)<(G|0)){da=da+(((c[K>>2]|0)/2|0)<<1)|0;S=S+(((c[ka>>2]|0)/2|0)<<1)|0;Y=na}else{break b}}}}}else{if((G|0)<=0){break b}Y=N^1;ka=R-W|0;S=E-1|0;da=(S|0)>0;Z=(W<<1)-R|0;ea=h+(f<<2)|0;X=T;U=V;ha=0;while(1){ia=bFb(c[o>>2]|0)|0;if((ia|0)==0){P=91;break a}do{if((a[ia+7|0]&1)==0){O=bFb(c[q>>2]|0)|0;if((O|0)==0){P=94;break a}if((a[O+7|0]&1)!=0|Y){Fa=0;break}if((ka|0)==6){if(da){Ga=0}else{Fa=0;break}while(1){c[X+(Ga<<1)>>2]=c[U+(Ga<<1)>>2]<<6;O=Ga+2|0;if((O|0)<(S|0)){Ga=O}else{Fa=O;break}}}else if((ka|0)==7){if(da){Ha=0}else{Fa=0;break}while(1){c[X+(Ha<<1)>>2]=c[U+(Ha<<1)>>2]<<7;O=Ha+2|0;if((O|0)<(S|0)){Ha=O}else{Fa=O;break}}}else{Fa=0;break}}else{Fa=0}}while(0);ia=bFb(c[o>>2]|0)|0;if((ia|0)==0){P=102;break a}O=a[ia+7|0]|0;ia=bFb(c[q>>2]|0)|0;if((ia|0)==0){P=104;break a}ga=(a[ia+7|0]&1)!=0;ia=(Fa|0)<(E|0);do{if((O&1)==0){if(ga){if(N){if(ia){Ia=Fa}else{break}do{na=U+(Ia<<1)|0;fa=X+(Ia<<1)|0;x=de(((d[na]|d[na+1|0]<<8)<<16>>16&65535)<<ka&65535|0)|0;a[fa]=x;x=x>>8;a[fa+1|0]=x;Ia=Ia+1|0;}while((Ia|0)<(E|0))}else{if(ia){Ja=Fa}else{break}do{fa=U+(Ja<<1)|0;na=(d[fa]|d[fa+1|0]<<8)<<16>>16&65535;fa=X+(Ja<<1)|0;x=de((na<<ka|na>>>(Z>>>0))&65535|0)|0;a[fa]=x;x=x>>8;a[fa+1|0]=x;Ja=Ja+1|0;}while((Ja|0)<(E|0))}}else{if(N){if(ia){Ka=Fa}else{break}do{fa=U+(Ka<<1)|0;na=X+(Ka<<1)|0;x=((d[fa]|d[fa+1|0]<<8)<<16>>16&65535)<<ka&65535;a[na]=x;x=x>>8;a[na+1|0]=x;Ka=Ka+1|0;}while((Ka|0)<(E|0))}else{if(ia){La=Fa}else{break}do{na=U+(La<<1)|0;fa=(d[na]|d[na+1|0]<<8)<<16>>16&65535;na=X+(La<<1)|0;x=(fa<<ka|fa>>>(Z>>>0))&65535;a[na]=x;x=x>>8;a[na+1|0]=x;La=La+1|0;}while((La|0)<(E|0))}}}else{if(ga){if(N){if(ia){Ma=Fa}else{break}do{na=U+(Ma<<1)|0;fa=X+(Ma<<1)|0;x=de(((de((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ka&65535|0)|0;a[fa]=x;x=x>>8;a[fa+1|0]=x;Ma=Ma+1|0;}while((Ma|0)<(E|0))}else{if(ia){Na=Fa}else{break}do{fa=U+(Na<<1)|0;na=(de((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535;fa=X+(Na<<1)|0;x=de((na<<ka|na>>>(Z>>>0))&65535|0)|0;a[fa]=x;x=x>>8;a[fa+1|0]=x;Na=Na+1|0;}while((Na|0)<(E|0))}}else{if(N){if(ia){Oa=Fa}else{break}do{fa=U+(Oa<<1)|0;na=X+(Oa<<1)|0;x=((de((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535)<<ka&65535;a[na]=x;x=x>>8;a[na+1|0]=x;Oa=Oa+1|0;}while((Oa|0)<(E|0))}else{if(ia){Pa=Fa}else{break}do{na=U+(Pa<<1)|0;fa=(de((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535;na=X+(Pa<<1)|0;x=(fa<<ka|fa>>>(Z>>>0))&65535;a[na]=x;x=x>>8;a[na+1|0]=x;Pa=Pa+1|0;}while((Pa|0)<(E|0))}}}}while(0);ia=ha+1|0;if((ia|0)<(G|0)){X=X+(((c[K>>2]|0)/2|0)<<1)|0;U=U+(((c[ea>>2]|0)/2|0)<<1)|0;ha=ia}else{break b}}}}}while(0);ha=bFb(c[q>>2]|0)|0;if((ha|0)==0){P=18;break a}do{if(!((b[ha+8>>1]&30720)==30720)){ea=bFb(c[q>>2]|0)|0;if((ea|0)==0){P=21;break a}if((((e[ea+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){break}ea=c[K>>2]|0;U=C?-1:-128;if((G|0)<=0){break b}X=0;Z=(c[I>>2]|0)+(ba(ea,F)|0)|0;while(1){TGb(Z|0,U|0,E|0)|0;ka=X+1|0;if((ka|0)<(G|0)){X=ka;Z=Z+ea|0}else{break b}}}}while(0);ha=c[I>>2]|0;ea=c[K>>2]|0;Z=(e[r+8+(f<<1)>>1]|0)>>>11&15;X=bFb(c[q>>2]|0)|0;if((X|0)==0){P=24;break a}U=ha+(ba(ea,F)|0)|0;if(C){Qa=65535>>>((Z^15)>>>0)&65535}else{Qa=1<<Z&65535}if((G|0)<=0){break}Z=(a[X+7|0]&1)==0;X=(E|0)>0;ha=de(Qa|0)|0;ka=U;U=0;while(1){do{if(Z){if(X){Ra=0}else{break}do{S=ka+(Ra<<1)|0;x=Qa;a[S]=x;x=x>>8;a[S+1|0]=x;Ra=Ra+1|0;}while((Ra|0)<(E|0))}else{if(X){Sa=0}else{break}do{S=ka+(Sa<<1)|0;x=ha;a[S]=x;x=x>>8;a[S+1|0]=x;Sa=Sa+1|0;}while((Sa|0)<(E|0))}}while(0);S=U+1|0;if((S|0)<(G|0)){ka=ka+ea|0;U=S}else{break}}}}while(0);C=f+1|0;if((C|0)<4){f=C}else{P=198;break}}if((P|0)==18){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=637,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==21){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=644,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==24){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==40){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=644,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==43){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=644,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==46){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=637,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==48){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=637,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==52){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==74){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==91){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==94){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==102){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==104){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==130){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==132){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==169){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=637,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==172){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=637,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==175){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==177){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=653,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==188){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=637,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==191){yDb(0,0,2301720,(Ta=i,i=i+24|0,c[Ta>>2]=2042536,c[Ta+8>>2]=1997616,c[Ta+16>>2]=637,Ta)|0);i=Ta;Cd();return 0}else if((P|0)==198){i=n;return k|0}return 0}function dzb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;if((e|0)<=0){return}g=f;f=b;b=0;do{c[f+(b<<2)>>2]=c[g+((d[a+b|0]|0)<<2)>>2];b=b+1|0;}while((b|0)<(e|0));return}function ezb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)>0){g=c;h=0}else{return}while(1){c=b+h|0;a[g]=a[f+((d[c]|0)<<2)|0]|0;a[g+1|0]=a[f+((d[c]|0)<<2|1)|0]|0;a[g+2|0]=a[f+((d[c]|0)<<2|2)|0]|0;c=h+1|0;if((c|0)<(e|0)){g=g+3|0;h=c}else{break}}return}function fzb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)<=0){return}g=f;f=b;b=0;do{h=b<<1;c[f+(b<<2)>>2]=(d[a+(h|1)|0]|0)<<24|c[g+((d[a+h|0]|0)<<2)>>2];b=b+1|0;}while((b|0)<(e|0));return}function gzb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)<=0){return}g=f;f=b;b=0;do{h=b<<1;c[f+(b<<2)>>2]=d[a+(h|1)|0]|0|c[g+((d[a+h|0]|0)<<2)>>2];b=b+1|0;}while((b|0)<(e|0));return}function hzb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)>0){g=c;h=0}else{return}while(1){c=b+(h<<1)|0;a[g]=a[f+((d[c]|0)<<2)|0]|0;a[g+1|0]=a[f+((d[c]|0)<<2|1)|0]|0;a[g+2|0]=a[f+((d[c]|0)<<2|2)|0]|0;c=h+1|0;if((c|0)<(e|0)){g=g+3|0;h=c}else{break}}return}function izb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+1|0;p=n+6|0;q=n+9|0;r=n+3|0;s=n|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=a[f+o|0]|0;a[p]=B;a[q]=B;a[r]=B;a[s]=B;B=f+1|0;a[t]=a[B]|0;C=f+e|0;D=((d[C]|0)+(d[B]|0)|0)>>>1&255;a[u]=D;a[v]=D;a[w]=a[C]|0;C=a[f]|0;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ne[c[1432194]&127](s,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+2|0;b=C}else{break}}i=m;return}function jzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;m=i;i=i+16|0;n=m|0;o=e+1|0;p=a[b+o|0]|0;q=n+6|0;a[q]=p;r=n+9|0;a[r]=p;s=n+3|0;a[s]=p;t=n|0;a[t]=p;p=a[b+1|0]|0;u=n+4|0;a[u]=p;v=a[b+e|0]|0;w=((v&255)+(p&255)|0)>>>1&255;p=n+10|0;a[p]=w;x=n+1|0;a[x]=w;w=n+7|0;a[w]=v;v=a[b]|0;y=n+8|0;a[y]=v;z=n+5|0;a[z]=v;A=n+2|0;a[A]=v;B=n+11|0;a[B]=v;Ne[c[1432194]&127](t,f,h,g,2,2,j,0,6,l);v=b+2|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=~e;D=1-e|0;E=e-1|0;F=e<<1;G=e+2|0;H=F|1;I=F+2|0;J=v;K=2;L=b;M=f;N=g;while(1){O=J+D|0;P=J+E|0;Q=J+o|0;a[t]=((d[O]|0)+(d[J+C|0]|0)+(d[P]|0)+(d[Q]|0)|0)>>>2;R=J+1|0;S=J+e|0;a[x]=((d[J-1|0]|0)+(d[J+n|0]|0)+(d[R]|0)+(d[S]|0)|0)>>>2;a[A]=a[J]|0;a[s]=((d[Q]|0)+(d[O]|0)|0)>>>1;a[u]=a[R]|0;O=J+2|0;a[z]=((d[O]|0)+(d[J]|0)|0)>>>1;a[q]=((d[Q]|0)+(d[P]|0)|0)>>>1;a[w]=a[S]|0;P=J+F|0;a[y]=((d[P]|0)+(d[J]|0)|0)>>>1;a[r]=a[Q]|0;a[p]=((d[S]|0)+(d[R]|0)+(d[J+G|0]|0)+(d[J+H|0]|0)|0)>>>2;a[B]=((d[O]|0)+(d[J]|0)+(d[P]|0)+(d[J+I|0]|0)|0)>>>2;Ne[c[1432194]&127](t,L,N,M,2,2,j,0,6,l);P=K+2|0;R=L+2|0;S=M+1|0;Q=N+1|0;if((P|0)<(h|0)){J=O;K=P;L=R;M=S;N=Q}else{T=O;U=R;V=S;W=Q;break}}}else{T=v;U=b;V=f;W=g}if((k|0)<=2){i=m;return}k=a[T+o|0]|0;a[q]=k;a[r]=k;a[s]=k;a[t]=k;k=T+1|0;a[u]=a[k]|0;u=T+e|0;e=((d[u]|0)+(d[k]|0)|0)>>>1&255;a[p]=e;a[x]=e;a[w]=a[u]|0;u=a[T]|0;a[y]=u;a[z]=u;a[A]=u;a[B]=u;Ne[c[1432194]&127](t,U,W,V,2,2,j,0,6,l);i=m;return}function kzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+2|0;p=n+6|0;q=n+9|0;r=n+3|0;s=n|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+o|0;C=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[p]=C;a[q]=C;a[r]=C;a[s]=C;C=f+2|0;a[t]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;B=f+e|0;D=(((d[B]|d[B+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[u]=D;a[v]=D;a[w]=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8;B=f;D=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ne[c[1432194]&127](s,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function lzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;m=i;i=i+16|0;n=m|0;o=e+2|0;p=b+o|0;q=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8&255;p=n+6|0;a[p]=q;r=n+9|0;a[r]=q;s=n+3|0;a[s]=q;t=n|0;a[t]=q;q=b+2|0;u=(d[q]|d[q+1|0]<<8)<<16>>16;q=n+4|0;a[q]=(u&65535)>>>8;v=b+e|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=((w&65535)+(u&65535)|0)>>>9&255;u=n+10|0;a[u]=v;x=n+1|0;a[x]=v;v=n+7|0;a[v]=(w&65535)>>>8;w=b;y=((d[w]|d[w+1|0]<<8)<<16>>16&65535)>>>8&255;w=n+8|0;a[w]=y;z=n+5|0;a[z]=y;A=n+2|0;a[A]=y;B=n+11|0;a[B]=y;Ne[c[1432194]&127](t,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=-2-e|0;D=2-e|0;E=e-2|0;F=e<<1;G=e+4|0;H=F+2|0;I=F+4|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+C|0;P=J+D|0;Q=J+E|0;R=J+o|0;a[t]=(((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+n|0;S=J-2|0;T=J+2|0;U=J+e|0;a[x]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[U]|d[U+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J;a[A]=((d[O]|d[O+1|0]<<8)<<16>>16&65535)>>>8;a[s]=(((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)|0)>>>9;a[q]=((d[T]|d[T+1|0]<<8)<<16>>16&65535)>>>8;P=J+4|0;S=P;a[z]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;a[p]=(((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)|0)>>>9;a[v]=((d[U]|d[U+1|0]<<8)<<16>>16&65535)>>>8;Q=J+F|0;a[w]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;a[r]=((d[R]|d[R+1|0]<<8)<<16>>16&65535)>>>8;R=J+G|0;V=J+H|0;a[u]=(((d[U]|d[U+1|0]<<8)<<16>>16&65535)+((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)|0)>>>10;V=J+I|0;a[B]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)|0)>>>10;Ne[c[1432194]&127](t,L,N,M,2,2,j,0,6,l);V=K+2|0;Q=L+2|0;O=M+1|0;S=N+1|0;if((V|0)<(h|0)){J=P;K=V;L=Q;M=O;N=S}else{W=P;X=Q;Y=O;Z=S;break}}}else{W=y;X=b;Y=f;Z=g}if((k|0)<=2){i=m;return}k=W+o|0;o=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[p]=o;a[r]=o;a[s]=o;a[t]=o;o=W+2|0;a[q]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;q=W+e|0;e=(((d[q]|d[q+1|0]<<8)<<16>>16&65535)+((d[o]|d[o+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[u]=e;a[x]=e;a[v]=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8;q=W;W=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8&255;a[w]=W;a[z]=W;a[A]=W;a[B]=W;Ne[c[1432194]&127](t,X,Z,Y,2,2,j,0,6,l);i=m;return}function mzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+2|0;p=n+6|0;q=n+9|0;r=n+3|0;s=n|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+o|0;C=(d[B]|d[B+1|0]<<8)<<16>>16&255;a[p]=C;a[q]=C;a[r]=C;a[s]=C;C=f+2|0;a[t]=(d[C]|d[C+1|0]<<8)<<16>>16;B=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=f+e|0;D=(((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+B|0)>>>9&255;a[u]=D;a[v]=D;a[w]=(d[C]|d[C+1|0]<<8)<<16>>16;C=f;D=(d[C]|d[C+1|0]<<8)<<16>>16&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ne[c[1432194]&127](s,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function nzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;m=i;i=i+16|0;n=m|0;o=e+2|0;p=b+o|0;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;p=n+6|0;a[p]=q;r=n+9|0;a[r]=q;s=n+3|0;a[s]=q;t=n|0;a[t]=q;q=b+2|0;u=(d[q]|d[q+1|0]<<8)<<16>>16;q=n+4|0;a[q]=u;v=(de(u|0)|0)&65535;u=b+e|0;w=(d[u]|d[u+1|0]<<8)<<16>>16;u=(((de(w|0)|0)&65535)+v|0)>>>9&255;v=n+10|0;a[v]=u;x=n+1|0;a[x]=u;u=n+7|0;a[u]=w;w=b;y=(d[w]|d[w+1|0]<<8)<<16>>16&255;w=n+8|0;a[w]=y;z=n+5|0;a[z]=y;A=n+2|0;a[A]=y;B=n+11|0;a[B]=y;Ne[c[1432194]&127](t,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=-2-e|0;D=2-e|0;E=e-2|0;F=e<<1;G=e+4|0;H=F+2|0;I=F+4|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+C|0;P=(de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=J+D|0;Q=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)+P|0;P=J+E|0;R=Q+((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0;Q=J+o|0;a[t]=(R+((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;R=J+n|0;S=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=J-2|0;T=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=J+2|0;R=T+((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0;T=J+e|0;a[x]=(R+((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;R=J;a[A]=(d[R]|d[R+1|0]<<8)<<16>>16;U=(de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;a[s]=(((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[q]=(d[S]|d[S+1|0]<<8)<<16>>16;U=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;O=J+4|0;V=O;a[z]=(((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;U=(de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535;a[p]=(((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[u]=(d[T]|d[T+1|0]<<8)<<16>>16;U=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;P=J+F|0;a[w]=(((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[r]=(d[Q]|d[Q+1|0]<<8)<<16>>16;Q=(de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+Q|0;Q=J+G|0;T=S+((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0;Q=J+H|0;a[v]=(T+((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;Q=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)+Q|0;Q=R+((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0;P=J+I|0;a[B]=(Q+((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;Ne[c[1432194]&127](t,L,N,M,2,2,j,0,6,l);P=K+2|0;Q=L+2|0;R=M+1|0;V=N+1|0;if((P|0)<(h|0)){J=O;K=P;L=Q;M=R;N=V}else{W=O;X=Q;Y=R;Z=V;break}}}else{W=y;X=b;Y=f;Z=g}if((k|0)<=2){i=m;return}k=W+o|0;o=(d[k]|d[k+1|0]<<8)<<16>>16&255;a[p]=o;a[r]=o;a[s]=o;a[t]=o;o=W+2|0;a[q]=(d[o]|d[o+1|0]<<8)<<16>>16;q=(de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;o=W+e|0;e=(((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)+q|0)>>>9&255;a[v]=e;a[x]=e;a[u]=(d[o]|d[o+1|0]<<8)<<16>>16;o=W;W=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[w]=W;a[z]=W;a[A]=W;a[B]=W;Ne[c[1432194]&127](t,X,Z,Y,2,2,j,0,6,l);i=m;return}function ozb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+1|0;p=n+8|0;q=n+11|0;r=n+5|0;s=n+2|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=a[f+o|0]|0;a[p]=B;a[q]=B;a[r]=B;a[s]=B;B=f+1|0;a[t]=a[B]|0;C=f+e|0;D=((d[C]|0)+(d[B]|0)|0)>>>1&255;a[u]=D;a[v]=D;a[w]=a[C]|0;C=a[f]|0;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ne[c[1432194]&127](z,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+2|0;b=C}else{break}}i=m;return}function pzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;m=i;i=i+16|0;n=m|0;o=e+1|0;p=a[b+o|0]|0;q=n+8|0;a[q]=p;r=n+11|0;a[r]=p;s=n+5|0;a[s]=p;t=n+2|0;a[t]=p;p=a[b+1|0]|0;u=n+4|0;a[u]=p;v=a[b+e|0]|0;w=((v&255)+(p&255)|0)>>>1&255;p=n+10|0;a[p]=w;x=n+1|0;a[x]=w;w=n+7|0;a[w]=v;v=a[b]|0;y=n+6|0;a[y]=v;z=n+3|0;a[z]=v;A=n|0;a[A]=v;B=n+9|0;a[B]=v;Ne[c[1432194]&127](A,f,h,g,2,2,j,0,6,l);v=b+2|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=~e;D=1-e|0;E=e-1|0;F=e<<1;G=e+2|0;H=F|1;I=F+2|0;J=v;K=2;L=b;M=f;N=g;while(1){O=J+D|0;P=J+E|0;Q=J+o|0;a[t]=((d[O]|0)+(d[J+C|0]|0)+(d[P]|0)+(d[Q]|0)|0)>>>2;R=J+1|0;S=J+e|0;a[x]=((d[J-1|0]|0)+(d[J+n|0]|0)+(d[R]|0)+(d[S]|0)|0)>>>2;a[A]=a[J]|0;a[s]=((d[Q]|0)+(d[O]|0)|0)>>>1;a[u]=a[R]|0;O=J+2|0;a[z]=((d[O]|0)+(d[J]|0)|0)>>>1;a[q]=((d[Q]|0)+(d[P]|0)|0)>>>1;a[w]=a[S]|0;P=J+F|0;a[y]=((d[P]|0)+(d[J]|0)|0)>>>1;a[r]=a[Q]|0;a[p]=((d[S]|0)+(d[R]|0)+(d[J+G|0]|0)+(d[J+H|0]|0)|0)>>>2;a[B]=((d[O]|0)+(d[J]|0)+(d[P]|0)+(d[J+I|0]|0)|0)>>>2;Ne[c[1432194]&127](A,L,N,M,2,2,j,0,6,l);P=K+2|0;R=L+2|0;S=M+1|0;Q=N+1|0;if((P|0)<(h|0)){J=O;K=P;L=R;M=S;N=Q}else{T=O;U=R;V=S;W=Q;break}}}else{T=v;U=b;V=f;W=g}if((k|0)<=2){i=m;return}k=a[T+o|0]|0;a[q]=k;a[r]=k;a[s]=k;a[t]=k;k=T+1|0;a[u]=a[k]|0;u=T+e|0;e=((d[u]|0)+(d[k]|0)|0)>>>1&255;a[p]=e;a[x]=e;a[w]=a[u]|0;u=a[T]|0;a[y]=u;a[z]=u;a[A]=u;a[B]=u;Ne[c[1432194]&127](A,U,W,V,2,2,j,0,6,l);i=m;return}function qzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+2|0;p=n+8|0;q=n+11|0;r=n+5|0;s=n+2|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+o|0;C=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[p]=C;a[q]=C;a[r]=C;a[s]=C;C=f+2|0;a[t]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;B=f+e|0;D=(((d[B]|d[B+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[u]=D;a[v]=D;a[w]=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8;B=f;D=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ne[c[1432194]&127](z,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function rzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;m=i;i=i+16|0;n=m|0;o=e+2|0;p=b+o|0;q=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8&255;p=n+8|0;a[p]=q;r=n+11|0;a[r]=q;s=n+5|0;a[s]=q;t=n+2|0;a[t]=q;q=b+2|0;u=(d[q]|d[q+1|0]<<8)<<16>>16;q=n+4|0;a[q]=(u&65535)>>>8;v=b+e|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=((w&65535)+(u&65535)|0)>>>9&255;u=n+10|0;a[u]=v;x=n+1|0;a[x]=v;v=n+7|0;a[v]=(w&65535)>>>8;w=b;y=((d[w]|d[w+1|0]<<8)<<16>>16&65535)>>>8&255;w=n+6|0;a[w]=y;z=n+3|0;a[z]=y;A=n|0;a[A]=y;B=n+9|0;a[B]=y;Ne[c[1432194]&127](A,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=-2-e|0;D=2-e|0;E=e-2|0;F=e<<1;G=e+4|0;H=F+2|0;I=F+4|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+C|0;P=J+D|0;Q=J+E|0;R=J+o|0;a[t]=(((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+n|0;S=J-2|0;T=J+2|0;U=J+e|0;a[x]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[U]|d[U+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J;a[A]=((d[O]|d[O+1|0]<<8)<<16>>16&65535)>>>8;a[s]=(((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)|0)>>>9;a[q]=((d[T]|d[T+1|0]<<8)<<16>>16&65535)>>>8;P=J+4|0;S=P;a[z]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;a[p]=(((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)|0)>>>9;a[v]=((d[U]|d[U+1|0]<<8)<<16>>16&65535)>>>8;Q=J+F|0;a[w]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;a[r]=((d[R]|d[R+1|0]<<8)<<16>>16&65535)>>>8;R=J+G|0;V=J+H|0;a[u]=(((d[U]|d[U+1|0]<<8)<<16>>16&65535)+((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)|0)>>>10;V=J+I|0;a[B]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)|0)>>>10;Ne[c[1432194]&127](A,L,N,M,2,2,j,0,6,l);V=K+2|0;Q=L+2|0;O=M+1|0;S=N+1|0;if((V|0)<(h|0)){J=P;K=V;L=Q;M=O;N=S}else{W=P;X=Q;Y=O;Z=S;break}}}else{W=y;X=b;Y=f;Z=g}if((k|0)<=2){i=m;return}k=W+o|0;o=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[p]=o;a[r]=o;a[s]=o;a[t]=o;o=W+2|0;a[q]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;q=W+e|0;e=(((d[q]|d[q+1|0]<<8)<<16>>16&65535)+((d[o]|d[o+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[u]=e;a[x]=e;a[v]=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8;q=W;W=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8&255;a[w]=W;a[z]=W;a[A]=W;a[B]=W;Ne[c[1432194]&127](A,X,Z,Y,2,2,j,0,6,l);i=m;return}function szb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+2|0;p=n+8|0;q=n+11|0;r=n+5|0;s=n+2|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+o|0;C=(d[B]|d[B+1|0]<<8)<<16>>16&255;a[p]=C;a[q]=C;a[r]=C;a[s]=C;C=f+2|0;a[t]=(d[C]|d[C+1|0]<<8)<<16>>16;B=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=f+e|0;D=(((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+B|0)>>>9&255;a[u]=D;a[v]=D;a[w]=(d[C]|d[C+1|0]<<8)<<16>>16;C=f;D=(d[C]|d[C+1|0]<<8)<<16>>16&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ne[c[1432194]&127](z,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function tzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;m=i;i=i+16|0;n=m|0;o=e+2|0;p=b+o|0;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;p=n+8|0;a[p]=q;r=n+11|0;a[r]=q;s=n+5|0;a[s]=q;t=n+2|0;a[t]=q;q=b+2|0;u=(d[q]|d[q+1|0]<<8)<<16>>16;q=n+4|0;a[q]=u;v=(de(u|0)|0)&65535;u=b+e|0;w=(d[u]|d[u+1|0]<<8)<<16>>16;u=(((de(w|0)|0)&65535)+v|0)>>>9&255;v=n+10|0;a[v]=u;x=n+1|0;a[x]=u;u=n+7|0;a[u]=w;w=b;y=(d[w]|d[w+1|0]<<8)<<16>>16&255;w=n+6|0;a[w]=y;z=n+3|0;a[z]=y;A=n|0;a[A]=y;B=n+9|0;a[B]=y;Ne[c[1432194]&127](A,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=-2-e|0;D=2-e|0;E=e-2|0;F=e<<1;G=e+4|0;H=F+2|0;I=F+4|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+C|0;P=(de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=J+D|0;Q=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)+P|0;P=J+E|0;R=Q+((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0;Q=J+o|0;a[t]=(R+((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;R=J+n|0;S=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=J-2|0;T=((de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=J+2|0;R=T+((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0;T=J+e|0;a[x]=(R+((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;R=J;a[A]=(d[R]|d[R+1|0]<<8)<<16>>16;U=(de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;a[s]=(((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[q]=(d[S]|d[S+1|0]<<8)<<16>>16;U=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;O=J+4|0;V=O;a[z]=(((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;U=(de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535;a[p]=(((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[u]=(d[T]|d[T+1|0]<<8)<<16>>16;U=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;P=J+F|0;a[w]=(((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[r]=(d[Q]|d[Q+1|0]<<8)<<16>>16;Q=(de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+Q|0;Q=J+G|0;T=S+((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0;Q=J+H|0;a[v]=(T+((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;Q=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)+Q|0;Q=R+((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0;P=J+I|0;a[B]=(Q+((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;Ne[c[1432194]&127](A,L,N,M,2,2,j,0,6,l);P=K+2|0;Q=L+2|0;R=M+1|0;V=N+1|0;if((P|0)<(h|0)){J=O;K=P;L=Q;M=R;N=V}else{W=O;X=Q;Y=R;Z=V;break}}}else{W=y;X=b;Y=f;Z=g}if((k|0)<=2){i=m;return}k=W+o|0;o=(d[k]|d[k+1|0]<<8)<<16>>16&255;a[p]=o;a[r]=o;a[s]=o;a[t]=o;o=W+2|0;a[q]=(d[o]|d[o+1|0]<<8)<<16>>16;q=(de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;o=W+e|0;e=(((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)+q|0)>>>9&255;a[v]=e;a[x]=e;a[u]=(d[o]|d[o+1|0]<<8)<<16>>16;o=W;W=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[w]=W;a[z]=W;a[A]=W;a[B]=W;Ne[c[1432194]&127](A,X,Z,Y,2,2,j,0,6,l);i=m;return}function uzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+6|0;p=n+9|0;q=n+3|0;r=n|0;s=n+1|0;t=e+1|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=a[f+e|0]|0;a[o]=B;a[p]=B;a[q]=B;a[r]=B;a[s]=a[f]|0;B=f+t|0;a[u]=a[B]|0;C=((d[B]|0)+(d[f]|0)|0)>>>1&255;a[v]=C;a[w]=C;C=a[f+1|0]|0;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ne[c[1432194]&127](r,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+2|0;b=C}else{break}}i=m;return}function vzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;m=i;i=i+16|0;n=m|0;o=a[b+e|0]|0;p=n+6|0;a[p]=o;q=n+9|0;a[q]=o;r=n+3|0;a[r]=o;s=n|0;a[s]=o;o=a[b]|0;t=n+1|0;a[t]=o;u=e+1|0;v=a[b+u|0]|0;w=n+10|0;a[w]=v;x=((v&255)+(o&255)|0)>>>1&255;o=n+7|0;a[o]=x;v=n+4|0;a[v]=x;x=a[b+1|0]|0;y=n+8|0;a[y]=x;z=n+5|0;a[z]=x;A=n+2|0;a[A]=x;B=n+11|0;a[B]=x;Ne[c[1432194]&127](s,f,h,g,2,2,j,0,6,l);x=b+2|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=2-e|0;D=e+2|0;E=1-e|0;F=e-1|0;G=e<<1;H=G-1|0;I=G|1;J=x;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=J+e|0;a[s]=((d[P]|0)+(d[O]|0)|0)>>>1;a[t]=a[J]|0;Q=J-1|0;R=J+1|0;a[A]=((d[R]|0)+(d[Q]|0)|0)>>>1;S=J+D|0;a[r]=((d[J+C|0]|0)+(d[O]|0)+(d[P]|0)+(d[S]|0)|0)>>>2;O=J+2|0;T=J+u|0;a[v]=((d[J]|0)+(d[J+E|0]|0)+(d[O]|0)+(d[T]|0)|0)>>>2;a[z]=a[R]|0;a[p]=a[P]|0;a[o]=((d[J+F|0]|0)+(d[J]|0)+(d[T]|0)+(d[J+G|0]|0)|0)>>>2;U=J+I|0;a[y]=((d[R]|0)+(d[Q]|0)+(d[J+H|0]|0)+(d[U]|0)|0)>>>2;a[q]=((d[S]|0)+(d[P]|0)|0)>>>1;a[w]=a[T]|0;a[B]=((d[U]|0)+(d[R]|0)|0)>>>1;Ne[c[1432194]&127](s,L,N,M,2,2,j,0,6,l);R=K+2|0;U=L+2|0;T=M+1|0;P=N+1|0;if((R|0)<(h|0)){J=O;K=R;L=U;M=T;N=P}else{V=O;W=U;X=T;Y=P;break}}}else{V=x;W=b;X=f;Y=g}if((k|0)<=2){i=m;return}k=a[V+e|0]|0;a[p]=k;a[q]=k;a[r]=k;a[s]=k;a[t]=a[V]|0;t=V+u|0;a[w]=a[t]|0;w=((d[t]|0)+(d[V]|0)|0)>>>1&255;a[o]=w;a[v]=w;w=a[V+1|0]|0;a[y]=w;a[z]=w;a[A]=w;a[B]=w;Ne[c[1432194]&127](s,W,Y,X,2,2,j,0,6,l);i=m;return}function wzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+6|0;p=n+9|0;q=n+3|0;r=n|0;s=n+1|0;t=e+2|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+e|0;C=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[o]=C;a[p]=C;a[q]=C;a[r]=C;C=f;a[s]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;B=f+t|0;a[u]=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8;D=(((d[B]|d[B+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[v]=D;a[w]=D;D=f+2|0;C=((d[D]|d[D+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ne[c[1432194]&127](r,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=C}else{break}}i=m;return}function xzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;m=i;i=i+16|0;n=m|0;o=b+e|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;o=n+6|0;a[o]=p;q=n+9|0;a[q]=p;r=n+3|0;a[r]=p;s=n|0;a[s]=p;p=b;t=(d[p]|d[p+1|0]<<8)<<16>>16;p=n+1|0;a[p]=(t&65535)>>>8;u=e+2|0;v=b+u|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=n+10|0;a[v]=(w&65535)>>>8;x=((w&65535)+(t&65535)|0)>>>9&255;t=n+7|0;a[t]=x;w=n+4|0;a[w]=x;x=b+2|0;y=((d[x]|d[x+1|0]<<8)<<16>>16&65535)>>>8&255;x=n+8|0;a[x]=y;z=n+5|0;a[z]=y;A=n+2|0;a[A]=y;B=n+11|0;a[B]=y;Ne[c[1432194]&127](s,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=4-e|0;D=e+4|0;E=2-e|0;F=e-2|0;G=e<<1;H=G-2|0;I=G+2|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=J+e|0;a[s]=(((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;Q=J;a[p]=((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)>>>8;R=J-2|0;S=J+2|0;a[A]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)|0)>>>9;T=J+C|0;U=J+D|0;a[r]=(((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[U]|d[U+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+E|0;T=J+4|0;V=T;W=J+u|0;a[w]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)+((d[W]|d[W+1|0]<<8)<<16>>16&65535)|0)>>>10;a[z]=((d[S]|d[S+1|0]<<8)<<16>>16&65535)>>>8;a[o]=((d[P]|d[P+1|0]<<8)<<16>>16&65535)>>>8;V=J+F|0;O=J+G|0;a[t]=(((d[V]|d[V+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[W]|d[W+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+H|0;Q=J+I|0;a[x]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)|0)>>>10;a[q]=(((d[U]|d[U+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)|0)>>>9;a[v]=((d[W]|d[W+1|0]<<8)<<16>>16&65535)>>>8;a[B]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[S]|d[S+1|0]<<8)<<16>>16&65535)|0)>>>9;Ne[c[1432194]&127](s,L,N,M,2,2,j,0,6,l);S=K+2|0;Q=L+2|0;W=M+1|0;P=N+1|0;if((S|0)<(h|0)){J=T;K=S;L=Q;M=W;N=P}else{X=T;Y=Q;Z=W;_=P;break}}}else{X=y;Y=b;Z=f;_=g}if((k|0)<=2){i=m;return}k=X+e|0;e=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[o]=e;a[q]=e;a[r]=e;a[s]=e;e=X;a[p]=((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>8;p=X+u|0;a[v]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;v=(((d[p]|d[p+1|0]<<8)<<16>>16&65535)+((d[e]|d[e+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[t]=v;a[w]=v;v=X+2|0;X=((d[v]|d[v+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=X;a[z]=X;a[A]=X;a[B]=X;Ne[c[1432194]&127](s,Y,_,Z,2,2,j,0,6,l);i=m;return}function yzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+6|0;p=n+9|0;q=n+3|0;r=n|0;s=n+1|0;t=e+2|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+e|0;C=(d[B]|d[B+1|0]<<8)<<16>>16&255;a[o]=C;a[p]=C;a[q]=C;a[r]=C;C=f;a[s]=(d[C]|d[C+1|0]<<8)<<16>>16;B=f+t|0;a[u]=(d[B]|d[B+1|0]<<8)<<16>>16;D=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=(((de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)+D|0)>>>9&255;a[v]=C;a[w]=C;C=f+2|0;D=(d[C]|d[C+1|0]<<8)<<16>>16&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ne[c[1432194]&127](r,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function zzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;m=i;i=i+16|0;n=m|0;o=b+e|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;o=n+6|0;a[o]=p;q=n+9|0;a[q]=p;r=n+3|0;a[r]=p;s=n|0;a[s]=p;p=b;t=(d[p]|d[p+1|0]<<8)<<16>>16;p=n+1|0;a[p]=t;u=e+2|0;v=b+u|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=n+10|0;a[v]=w;x=(de(t|0)|0)&65535;t=(((de(w|0)|0)&65535)+x|0)>>>9&255;x=n+7|0;a[x]=t;w=n+4|0;a[w]=t;t=b+2|0;y=(d[t]|d[t+1|0]<<8)<<16>>16&255;t=n+8|0;a[t]=y;z=n+5|0;a[z]=y;A=n+2|0;a[A]=y;B=n+11|0;a[B]=y;Ne[c[1432194]&127](s,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=4-e|0;D=e+4|0;E=2-e|0;F=e-2|0;G=e<<1;H=G-2|0;I=G+2|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=(de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;Q=J+e|0;a[s]=(((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+P|0)>>>9;P=J;a[p]=(d[P]|d[P+1|0]<<8)<<16>>16;R=J-2|0;S=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;T=J+2|0;a[A]=(((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+S|0)>>>9;S=(de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=J+C|0;U=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=U+((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0;U=J+D|0;a[r]=(S+((de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;S=J+E|0;O=(de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+O|0;O=J+4|0;V=O;W=S+((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0;V=J+u|0;a[w]=(W+((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;a[z]=(d[T]|d[T+1|0]<<8)<<16>>16;a[o]=(d[Q]|d[Q+1|0]<<8)<<16>>16;W=(de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535;P=J+F|0;S=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+W|0;W=S+((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0;S=J+G|0;a[x]=(W+((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;S=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=J+H|0;W=R+((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0;S=J+I|0;a[t]=(W+((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;W=(de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535;a[q]=(((de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)+W|0)>>>9;a[v]=(d[V]|d[V+1|0]<<8)<<16>>16;V=(de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535;a[B]=(((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)+V|0)>>>9;Ne[c[1432194]&127](s,L,N,M,2,2,j,0,6,l);V=K+2|0;S=L+2|0;T=M+1|0;W=N+1|0;if((V|0)<(h|0)){J=O;K=V;L=S;M=T;N=W}else{X=O;Y=S;Z=T;_=W;break}}}else{X=y;Y=b;Z=f;_=g}if((k|0)<=2){i=m;return}k=X+e|0;e=(d[k]|d[k+1|0]<<8)<<16>>16&255;a[o]=e;a[q]=e;a[r]=e;a[s]=e;e=X;a[p]=(d[e]|d[e+1|0]<<8)<<16>>16;p=X+u|0;a[v]=(d[p]|d[p+1|0]<<8)<<16>>16;v=(de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535;e=(((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)+v|0)>>>9&255;a[x]=e;a[w]=e;e=X+2|0;X=(d[e]|d[e+1|0]<<8)<<16>>16&255;a[t]=X;a[z]=X;a[A]=X;a[B]=X;Ne[c[1432194]&127](s,Y,_,Z,2,2,j,0,6,l);i=m;return}function Azb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+8|0;p=n+11|0;q=n+5|0;r=n+2|0;s=n+1|0;t=e+1|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=a[f+e|0]|0;a[o]=B;a[p]=B;a[q]=B;a[r]=B;a[s]=a[f]|0;B=f+t|0;a[u]=a[B]|0;C=((d[B]|0)+(d[f]|0)|0)>>>1&255;a[v]=C;a[w]=C;C=a[f+1|0]|0;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ne[c[1432194]&127](z,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+2|0;b=C}else{break}}i=m;return}function Bzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;m=i;i=i+16|0;n=m|0;o=a[b+e|0]|0;p=n+8|0;a[p]=o;q=n+11|0;a[q]=o;r=n+5|0;a[r]=o;s=n+2|0;a[s]=o;o=a[b]|0;t=n+1|0;a[t]=o;u=e+1|0;v=a[b+u|0]|0;w=n+10|0;a[w]=v;x=((v&255)+(o&255)|0)>>>1&255;o=n+7|0;a[o]=x;v=n+4|0;a[v]=x;x=a[b+1|0]|0;y=n+6|0;a[y]=x;z=n+3|0;a[z]=x;A=n|0;a[A]=x;B=n+9|0;a[B]=x;Ne[c[1432194]&127](A,f,h,g,2,2,j,0,6,l);x=b+2|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=2-e|0;D=e+2|0;E=1-e|0;F=e-1|0;G=e<<1;H=G-1|0;I=G|1;J=x;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=J+e|0;a[s]=((d[P]|0)+(d[O]|0)|0)>>>1;a[t]=a[J]|0;Q=J-1|0;R=J+1|0;a[A]=((d[R]|0)+(d[Q]|0)|0)>>>1;S=J+D|0;a[r]=((d[J+C|0]|0)+(d[O]|0)+(d[P]|0)+(d[S]|0)|0)>>>2;O=J+2|0;T=J+u|0;a[v]=((d[J]|0)+(d[J+E|0]|0)+(d[O]|0)+(d[T]|0)|0)>>>2;a[z]=a[R]|0;a[p]=a[P]|0;a[o]=((d[J+F|0]|0)+(d[J]|0)+(d[T]|0)+(d[J+G|0]|0)|0)>>>2;U=J+I|0;a[y]=((d[R]|0)+(d[Q]|0)+(d[J+H|0]|0)+(d[U]|0)|0)>>>2;a[q]=((d[S]|0)+(d[P]|0)|0)>>>1;a[w]=a[T]|0;a[B]=((d[U]|0)+(d[R]|0)|0)>>>1;Ne[c[1432194]&127](A,L,N,M,2,2,j,0,6,l);R=K+2|0;U=L+2|0;T=M+1|0;P=N+1|0;if((R|0)<(h|0)){J=O;K=R;L=U;M=T;N=P}else{V=O;W=U;X=T;Y=P;break}}}else{V=x;W=b;X=f;Y=g}if((k|0)<=2){i=m;return}k=a[V+e|0]|0;a[p]=k;a[q]=k;a[r]=k;a[s]=k;a[t]=a[V]|0;t=V+u|0;a[w]=a[t]|0;w=((d[t]|0)+(d[V]|0)|0)>>>1&255;a[o]=w;a[v]=w;w=a[V+1|0]|0;a[y]=w;a[z]=w;a[A]=w;a[B]=w;Ne[c[1432194]&127](A,W,Y,X,2,2,j,0,6,l);i=m;return}function Czb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+8|0;p=n+11|0;q=n+5|0;r=n+2|0;s=n+1|0;t=e+2|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+e|0;C=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[o]=C;a[p]=C;a[q]=C;a[r]=C;C=f;a[s]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;B=f+t|0;a[u]=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8;D=(((d[B]|d[B+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[v]=D;a[w]=D;D=f+2|0;C=((d[D]|d[D+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ne[c[1432194]&127](z,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=C}else{break}}i=m;return}function Dzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;m=i;i=i+16|0;n=m|0;o=b+e|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;o=n+8|0;a[o]=p;q=n+11|0;a[q]=p;r=n+5|0;a[r]=p;s=n+2|0;a[s]=p;p=b;t=(d[p]|d[p+1|0]<<8)<<16>>16;p=n+1|0;a[p]=(t&65535)>>>8;u=e+2|0;v=b+u|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=n+10|0;a[v]=(w&65535)>>>8;x=((w&65535)+(t&65535)|0)>>>9&255;t=n+7|0;a[t]=x;w=n+4|0;a[w]=x;x=b+2|0;y=((d[x]|d[x+1|0]<<8)<<16>>16&65535)>>>8&255;x=n+6|0;a[x]=y;z=n+3|0;a[z]=y;A=n|0;a[A]=y;B=n+9|0;a[B]=y;Ne[c[1432194]&127](A,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=4-e|0;D=e+4|0;E=2-e|0;F=e-2|0;G=e<<1;H=G-2|0;I=G+2|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=J+e|0;a[s]=(((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;Q=J;a[p]=((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)>>>8;R=J-2|0;S=J+2|0;a[A]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)|0)>>>9;T=J+C|0;U=J+D|0;a[r]=(((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[U]|d[U+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+E|0;T=J+4|0;V=T;W=J+u|0;a[w]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)+((d[W]|d[W+1|0]<<8)<<16>>16&65535)|0)>>>10;a[z]=((d[S]|d[S+1|0]<<8)<<16>>16&65535)>>>8;a[o]=((d[P]|d[P+1|0]<<8)<<16>>16&65535)>>>8;V=J+F|0;O=J+G|0;a[t]=(((d[V]|d[V+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[W]|d[W+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+H|0;Q=J+I|0;a[x]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)|0)>>>10;a[q]=(((d[U]|d[U+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)|0)>>>9;a[v]=((d[W]|d[W+1|0]<<8)<<16>>16&65535)>>>8;a[B]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[S]|d[S+1|0]<<8)<<16>>16&65535)|0)>>>9;Ne[c[1432194]&127](A,L,N,M,2,2,j,0,6,l);S=K+2|0;Q=L+2|0;W=M+1|0;P=N+1|0;if((S|0)<(h|0)){J=T;K=S;L=Q;M=W;N=P}else{X=T;Y=Q;Z=W;_=P;break}}}else{X=y;Y=b;Z=f;_=g}if((k|0)<=2){i=m;return}k=X+e|0;e=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[o]=e;a[q]=e;a[r]=e;a[s]=e;e=X;a[p]=((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>8;p=X+u|0;a[v]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;v=(((d[p]|d[p+1|0]<<8)<<16>>16&65535)+((d[e]|d[e+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[t]=v;a[w]=v;v=X+2|0;X=((d[v]|d[v+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=X;a[z]=X;a[A]=X;a[B]=X;Ne[c[1432194]&127](A,Y,_,Z,2,2,j,0,6,l);i=m;return}function Ezb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+8|0;p=n+11|0;q=n+5|0;r=n+2|0;s=n+1|0;t=e+2|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+e|0;C=(d[B]|d[B+1|0]<<8)<<16>>16&255;a[o]=C;a[p]=C;a[q]=C;a[r]=C;C=f;a[s]=(d[C]|d[C+1|0]<<8)<<16>>16;B=f+t|0;a[u]=(d[B]|d[B+1|0]<<8)<<16>>16;D=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=(((de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)+D|0)>>>9&255;a[v]=C;a[w]=C;C=f+2|0;D=(d[C]|d[C+1|0]<<8)<<16>>16&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ne[c[1432194]&127](z,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function Fzb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;m=i;i=i+16|0;n=m|0;o=b+e|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;o=n+8|0;a[o]=p;q=n+11|0;a[q]=p;r=n+5|0;a[r]=p;s=n+2|0;a[s]=p;p=b;t=(d[p]|d[p+1|0]<<8)<<16>>16;p=n+1|0;a[p]=t;u=e+2|0;v=b+u|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=n+10|0;a[v]=w;x=(de(t|0)|0)&65535;t=(((de(w|0)|0)&65535)+x|0)>>>9&255;x=n+7|0;a[x]=t;w=n+4|0;a[w]=t;t=b+2|0;y=(d[t]|d[t+1|0]<<8)<<16>>16&255;t=n+6|0;a[t]=y;z=n+3|0;a[z]=y;A=n|0;a[A]=y;B=n+9|0;a[B]=y;Ne[c[1432194]&127](A,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=4-e|0;D=e+4|0;E=2-e|0;F=e-2|0;G=e<<1;H=G-2|0;I=G+2|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=(de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;Q=J+e|0;a[s]=(((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+P|0)>>>9;P=J;a[p]=(d[P]|d[P+1|0]<<8)<<16>>16;R=J-2|0;S=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;T=J+2|0;a[A]=(((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+S|0)>>>9;S=(de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=J+C|0;U=((de((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=U+((de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0;U=J+D|0;a[r]=(S+((de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;S=J+E|0;O=(de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+O|0;O=J+4|0;V=O;W=S+((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0;V=J+u|0;a[w]=(W+((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;a[z]=(d[T]|d[T+1|0]<<8)<<16>>16;a[o]=(d[Q]|d[Q+1|0]<<8)<<16>>16;W=(de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535;P=J+F|0;S=((de((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+W|0;W=S+((de((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0;S=J+G|0;a[x]=(W+((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;S=(de((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=((de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=J+H|0;W=R+((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0;S=J+I|0;a[t]=(W+((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;W=(de((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535;a[q]=(((de((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)+W|0)>>>9;a[v]=(d[V]|d[V+1|0]<<8)<<16>>16;V=(de((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535;a[B]=(((de((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)+V|0)>>>9;Ne[c[1432194]&127](A,L,N,M,2,2,j,0,6,l);V=K+2|0;S=L+2|0;T=M+1|0;W=N+1|0;if((V|0)<(h|0)){J=O;K=V;L=S;M=T;N=W}else{X=O;Y=S;Z=T;_=W;break}}}else{X=y;Y=b;Z=f;_=g}if((k|0)<=2){i=m;return}k=X+e|0;e=(d[k]|d[k+1|0]<<8)<<16>>16&255;a[o]=e;a[q]=e;a[r]=e;a[s]=e;e=X;a[p]=(d[e]|d[e+1|0]<<8)<<16>>16;p=X+u|0;a[v]=(d[p]|d[p+1|0]<<8)<<16>>16;v=(de((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535;e=(((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)+v|0)>>>9&255;a[x]=e;a[w]=e;e=X+2|0;X=(d[e]|d[e+1|0]<<8)<<16>>16&255;a[t]=X;a[z]=X;a[A]=X;a[B]=X;Ne[c[1432194]&127](A,Y,_,Z,2,2,j,0,6,l);i=m;return}function Gzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+1|0;i=f+3|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=a[e+h|0]|0;a[n+f|0]=o;a[n+i|0]=o;a[n+3|0]=o;a[n]=o;o=e+1|0;a[n+4|0]=a[o]|0;p=e+c|0;q=((d[p]|0)+(d[o]|0)|0)>>>1&255;a[n+j|0]=q;a[n+1|0]=q;a[n+k|0]=a[p]|0;p=a[e]|0;a[n+l|0]=p;a[n+5|0]=p;a[n+2|0]=p;a[n+m|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+2|0;b=p}else{break}}return}function Hzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=c+1|0;i=a[b+h|0]|0;a[e+f|0]=i;a[e+(f+3)|0]=i;a[e+3|0]=i;a[e]=i;i=b+1|0;a[e+4|0]=a[i]|0;j=b+c|0;k=((d[j]|0)+(d[i]|0)|0)>>>1&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=a[j]|0;j=a[b]|0;a[e+(f+2)|0]=j;a[e+5|0]=j;a[e+2|0]=j;a[e+(f+5)|0]=j;j=b+2|0;b=e+6|0;k=g-2|0;if((k|0)>2){i=-c|0;l=~c;m=1-c|0;n=c-1|0;o=f+6|0;p=f+7|0;q=c<<1;r=f+8|0;s=f+9|0;t=c+2|0;u=q|1;v=f+10|0;w=q+2|0;x=f+11|0;y=e;z=j;A=2;B=b;while(1){C=z+m|0;D=z+n|0;E=z+h|0;a[B]=((d[C]|0)+(d[z+l|0]|0)+(d[D]|0)+(d[E]|0)|0)>>>2;F=z+1|0;G=z+c|0;a[y+7|0]=((d[z-1|0]|0)+(d[z+i|0]|0)+(d[F]|0)+(d[G]|0)|0)>>>2;a[y+8|0]=a[z]|0;a[y+9|0]=((d[E]|0)+(d[C]|0)|0)>>>1;a[y+10|0]=a[F]|0;C=z+2|0;a[y+11|0]=((d[C]|0)+(d[z]|0)|0)>>>1;a[y+o|0]=((d[E]|0)+(d[D]|0)|0)>>>1;a[y+p|0]=a[G]|0;D=z+q|0;a[y+r|0]=((d[D]|0)+(d[z]|0)|0)>>>1;a[y+s|0]=a[E]|0;a[y+v|0]=((d[G]|0)+(d[F]|0)+(d[z+t|0]|0)+(d[z+u|0]|0)|0)>>>2;a[y+x|0]=((d[C]|0)+(d[z]|0)+(d[D]|0)+(d[z+w|0]|0)|0)>>>2;D=A+2|0;F=B+6|0;if((D|0)<(k|0)){y=B;z=C;A=D;B=F}else{H=B;I=C;J=F;break}}}else{H=e;I=j;J=b}if((g|0)<=2){return}g=a[I+h|0]|0;a[H+(f+6)|0]=g;a[H+(f+9)|0]=g;a[H+9|0]=g;a[J]=g;g=I+1|0;a[H+10|0]=a[g]|0;J=I+c|0;c=((d[J]|0)+(d[g]|0)|0)>>>1&255;a[H+(f+10)|0]=c;a[H+7|0]=c;a[H+(f+7)|0]=a[J]|0;J=a[I]|0;a[H+(f+8)|0]=J;a[H+11|0]=J;a[H+8|0]=J;a[H+(f+11)|0]=J;return}function Izb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+2|0;i=f+3|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=e+h|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+f|0]=p;a[n+i|0]=p;a[n+3|0]=p;a[n]=p;p=e+2|0;a[n+4|0]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;o=e+c|0;q=(((d[o]|d[o+1|0]<<8)<<16>>16&65535)+((d[p]|d[p+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[n+j|0]=q;a[n+1|0]=q;a[n+k|0]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;o=e;q=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+l|0]=q;a[n+5|0]=q;a[n+2|0]=q;a[n+m|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function Jzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=c+2|0;i=b+h|0;j=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+f|0]=j;a[e+(f+3)|0]=j;a[e+3|0]=j;a[e]=j;j=b+2|0;a[e+4|0]=((d[j]|d[j+1|0]<<8)<<16>>16&65535)>>>8;i=b+c|0;k=(((d[i]|d[i+1|0]<<8)<<16>>16&65535)+((d[j]|d[j+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8;i=b;k=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+(f+2)|0]=k;a[e+5|0]=k;a[e+2|0]=k;a[e+(f+5)|0]=k;k=b+4|0;b=e+6|0;i=g-2|0;if((i|0)>2){j=-c|0;l=-2-c|0;m=2-c|0;n=c-2|0;o=f+6|0;p=f+7|0;q=c<<1;r=f+8|0;s=f+9|0;t=c+4|0;u=q+2|0;v=f+10|0;w=q+4|0;x=f+11|0;y=e;z=k;A=2;B=b;while(1){C=z+l|0;D=z+m|0;E=z+n|0;F=z+h|0;a[B]=(((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+j|0;G=z-2|0;H=z+2|0;I=z+c|0;a[y+7|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[I]|d[I+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z;a[y+8|0]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;a[y+9|0]=(((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+10|0]=((d[H]|d[H+1|0]<<8)<<16>>16&65535)>>>8;D=z+4|0;G=D;a[y+11|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+o|0]=(((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+p|0]=((d[I]|d[I+1|0]<<8)<<16>>16&65535)>>>8;E=z+q|0;a[y+r|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+s|0]=((d[F]|d[F+1|0]<<8)<<16>>16&65535)>>>8;F=z+t|0;J=z+u|0;a[y+v|0]=(((d[I]|d[I+1|0]<<8)<<16>>16&65535)+((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)|0)>>>10;J=z+w|0;a[y+x|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)|0)>>>10;J=A+2|0;E=B+6|0;if((J|0)<(i|0)){y=B;z=D;A=J;B=E}else{K=B;L=D;M=E;break}}}else{K=e;L=k;M=b}if((g|0)<=2){return}g=L+h|0;h=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[K+(f+6)|0]=h;a[K+(f+9)|0]=h;a[K+9|0]=h;a[M]=h;h=L+2|0;a[K+10|0]=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8;M=L+c|0;c=(((d[M]|d[M+1|0]<<8)<<16>>16&65535)+((d[h]|d[h+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[K+(f+10)|0]=c;a[K+7|0]=c;a[K+(f+7)|0]=((d[M]|d[M+1|0]<<8)<<16>>16&65535)>>>8;M=L;L=((d[M]|d[M+1|0]<<8)<<16>>16&65535)>>>8&255;a[K+(f+8)|0]=L;a[K+11|0]=L;a[K+8|0]=L;a[K+(f+11)|0]=L;return}function Kzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+2|0;i=f+3|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=e+h|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[n+f|0]=p;a[n+i|0]=p;a[n+3|0]=p;a[n]=p;p=e+2|0;a[n+4|0]=(d[p]|d[p+1|0]<<8)<<16>>16;o=(de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=e+c|0;q=(((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)+o|0)>>>9&255;a[n+j|0]=q;a[n+1|0]=q;a[n+k|0]=(d[p]|d[p+1|0]<<8)<<16>>16;p=e;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;a[n+l|0]=q;a[n+5|0]=q;a[n+2|0]=q;a[n+m|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function Lzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=c+2|0;i=b+h|0;j=(d[i]|d[i+1|0]<<8)<<16>>16&255;a[e+f|0]=j;a[e+(f+3)|0]=j;a[e+3|0]=j;a[e]=j;j=b+2|0;a[e+4|0]=(d[j]|d[j+1|0]<<8)<<16>>16;i=(de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535;j=b+c|0;k=(((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)+i|0)>>>9&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=(d[j]|d[j+1|0]<<8)<<16>>16;j=b;k=(d[j]|d[j+1|0]<<8)<<16>>16&255;a[e+(f+2)|0]=k;a[e+5|0]=k;a[e+2|0]=k;a[e+(f+5)|0]=k;k=b+4|0;b=e+6|0;j=g-2|0;if((j|0)>2){i=-c|0;l=-2-c|0;m=2-c|0;n=c-2|0;o=f+6|0;p=f+7|0;q=c<<1;r=f+8|0;s=f+9|0;t=c+4|0;u=q+2|0;v=f+10|0;w=q+4|0;x=f+11|0;y=e;z=k;A=2;B=b;while(1){C=z+l|0;D=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=z+m|0;E=((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+D|0;D=z+n|0;F=E+((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0;E=z+h|0;a[B]=(F+((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;F=z+i|0;G=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=z-2|0;H=((de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=z+2|0;F=H+((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0;H=z+c|0;a[y+7|0]=(F+((de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;F=z;a[y+8|0]=(d[F]|d[F+1|0]<<8)<<16>>16;I=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;a[y+9|0]=(((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+10|0]=(d[G]|d[G+1|0]<<8)<<16>>16;I=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;C=z+4|0;J=C;a[y+11|0]=(((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;I=(de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;a[y+o|0]=(((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+p|0]=(d[H]|d[H+1|0]<<8)<<16>>16;I=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;D=z+q|0;a[y+r|0]=(((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+s|0]=(d[E]|d[E+1|0]<<8)<<16>>16;E=(de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=((de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+E|0;E=z+t|0;H=G+((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0;E=z+u|0;a[y+v|0]=(H+((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;E=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)+E|0;E=F+((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0;D=z+w|0;a[y+x|0]=(E+((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;D=A+2|0;E=B+6|0;if((D|0)<(j|0)){y=B;z=C;A=D;B=E}else{K=B;L=C;M=E;break}}}else{K=e;L=k;M=b}if((g|0)<=2){return}g=L+h|0;h=(d[g]|d[g+1|0]<<8)<<16>>16&255;a[K+(f+6)|0]=h;a[K+(f+9)|0]=h;a[K+9|0]=h;a[M]=h;h=L+2|0;a[K+10|0]=(d[h]|d[h+1|0]<<8)<<16>>16;M=(de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;h=L+c|0;c=(((de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535)+M|0)>>>9&255;a[K+(f+10)|0]=c;a[K+7|0]=c;a[K+(f+7)|0]=(d[h]|d[h+1|0]<<8)<<16>>16;h=L;L=(d[h]|d[h+1|0]<<8)<<16>>16&255;a[K+(f+8)|0]=L;a[K+11|0]=L;a[K+8|0]=L;a[K+(f+11)|0]=L;return}function Mzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+1|0;i=f+2|0;j=f+3|0;k=f+5|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=a[e+h|0]|0;a[n+i|0]=o;a[n+k|0]=o;a[n+5|0]=o;a[n+2|0]=o;o=e+1|0;a[n+4|0]=a[o]|0;p=e+c|0;q=((d[p]|0)+(d[o]|0)|0)>>>1&255;a[n+l|0]=q;a[n+1|0]=q;a[n+m|0]=a[p]|0;p=a[e]|0;a[n+f|0]=p;a[n+3|0]=p;a[n]=p;a[n+j|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+2|0;b=p}else{break}}return}function Nzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=c+1|0;i=a[b+h|0]|0;a[e+(f+2)|0]=i;a[e+(f+5)|0]=i;a[e+5|0]=i;a[e+2|0]=i;i=b+1|0;a[e+4|0]=a[i]|0;j=b+c|0;k=((d[j]|0)+(d[i]|0)|0)>>>1&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=a[j]|0;j=a[b]|0;a[e+f|0]=j;a[e+3|0]=j;a[e]=j;a[e+(f+3)|0]=j;j=b+2|0;b=e+6|0;k=g-2|0;if((k|0)>2){i=-c|0;l=~c;m=1-c|0;n=c-1|0;o=f+8|0;p=f+7|0;q=c<<1;r=f+6|0;s=f+11|0;t=c+2|0;u=q|1;v=f+10|0;w=q+2|0;x=f+9|0;y=e;z=j;A=2;B=b;while(1){C=z+m|0;D=z+n|0;E=z+h|0;a[y+8|0]=((d[C]|0)+(d[z+l|0]|0)+(d[D]|0)+(d[E]|0)|0)>>>2;F=z+1|0;G=z+c|0;a[y+7|0]=((d[z-1|0]|0)+(d[z+i|0]|0)+(d[F]|0)+(d[G]|0)|0)>>>2;a[B]=a[z]|0;a[y+11|0]=((d[E]|0)+(d[C]|0)|0)>>>1;a[y+10|0]=a[F]|0;C=z+2|0;a[y+9|0]=((d[C]|0)+(d[z]|0)|0)>>>1;a[y+o|0]=((d[E]|0)+(d[D]|0)|0)>>>1;a[y+p|0]=a[G]|0;D=z+q|0;a[y+r|0]=((d[D]|0)+(d[z]|0)|0)>>>1;a[y+s|0]=a[E]|0;a[y+v|0]=((d[G]|0)+(d[F]|0)+(d[z+t|0]|0)+(d[z+u|0]|0)|0)>>>2;a[y+x|0]=((d[C]|0)+(d[z]|0)+(d[D]|0)+(d[z+w|0]|0)|0)>>>2;D=A+2|0;F=B+6|0;if((D|0)<(k|0)){y=B;z=C;A=D;B=F}else{H=B;I=C;J=F;break}}}else{H=e;I=j;J=b}if((g|0)<=2){return}g=a[I+h|0]|0;a[H+(f+8)|0]=g;a[H+(f+11)|0]=g;a[H+11|0]=g;a[H+8|0]=g;g=I+1|0;a[H+10|0]=a[g]|0;h=I+c|0;c=((d[h]|0)+(d[g]|0)|0)>>>1&255;a[H+(f+10)|0]=c;a[H+7|0]=c;a[H+(f+7)|0]=a[h]|0;h=a[I]|0;a[H+(f+6)|0]=h;a[H+9|0]=h;a[J]=h;a[H+(f+9)|0]=h;return}function Ozb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+2|0;i=f+2|0;j=f+3|0;k=f+5|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=e+h|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+i|0]=p;a[n+k|0]=p;a[n+5|0]=p;a[n+2|0]=p;p=e+2|0;a[n+4|0]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;o=e+c|0;q=(((d[o]|d[o+1|0]<<8)<<16>>16&65535)+((d[p]|d[p+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[n+l|0]=q;a[n+1|0]=q;a[n+m|0]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;o=e;q=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+f|0]=q;a[n+3|0]=q;a[n]=q;a[n+j|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function Pzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=c+2|0;i=b+h|0;j=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+(f+2)|0]=j;a[e+(f+5)|0]=j;a[e+5|0]=j;a[e+2|0]=j;j=b+2|0;a[e+4|0]=((d[j]|d[j+1|0]<<8)<<16>>16&65535)>>>8;i=b+c|0;k=(((d[i]|d[i+1|0]<<8)<<16>>16&65535)+((d[j]|d[j+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8;i=b;k=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+f|0]=k;a[e+3|0]=k;a[e]=k;a[e+(f+3)|0]=k;k=b+4|0;b=e+6|0;i=g-2|0;if((i|0)>2){j=-c|0;l=-2-c|0;m=2-c|0;n=c-2|0;o=f+8|0;p=f+7|0;q=c<<1;r=f+6|0;s=f+11|0;t=c+4|0;u=q+2|0;v=f+10|0;w=q+4|0;x=f+9|0;y=e;z=k;A=2;B=b;while(1){C=z+l|0;D=z+m|0;E=z+n|0;F=z+h|0;a[y+8|0]=(((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+j|0;G=z-2|0;H=z+2|0;I=z+c|0;a[y+7|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[I]|d[I+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z;a[B]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;a[y+11|0]=(((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+10|0]=((d[H]|d[H+1|0]<<8)<<16>>16&65535)>>>8;D=z+4|0;G=D;a[y+9|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+o|0]=(((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+p|0]=((d[I]|d[I+1|0]<<8)<<16>>16&65535)>>>8;E=z+q|0;a[y+r|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+s|0]=((d[F]|d[F+1|0]<<8)<<16>>16&65535)>>>8;F=z+t|0;J=z+u|0;a[y+v|0]=(((d[I]|d[I+1|0]<<8)<<16>>16&65535)+((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)|0)>>>10;J=z+w|0;a[y+x|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)|0)>>>10;J=A+2|0;E=B+6|0;if((J|0)<(i|0)){y=B;z=D;A=J;B=E}else{K=B;L=D;M=E;break}}}else{K=e;L=k;M=b}if((g|0)<=2){return}g=L+h|0;h=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[K+(f+8)|0]=h;a[K+(f+11)|0]=h;a[K+11|0]=h;a[K+8|0]=h;h=L+2|0;a[K+10|0]=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8;g=L+c|0;c=(((d[g]|d[g+1|0]<<8)<<16>>16&65535)+((d[h]|d[h+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[K+(f+10)|0]=c;a[K+7|0]=c;a[K+(f+7)|0]=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8;g=L;L=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[K+(f+6)|0]=L;a[K+9|0]=L;a[M]=L;a[K+(f+9)|0]=L;return}function Qzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+2|0;i=f+2|0;j=f+3|0;k=f+5|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=e+h|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[n+i|0]=p;a[n+k|0]=p;a[n+5|0]=p;a[n+2|0]=p;p=e+2|0;a[n+4|0]=(d[p]|d[p+1|0]<<8)<<16>>16;o=(de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=e+c|0;q=(((de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)+o|0)>>>9&255;a[n+l|0]=q;a[n+1|0]=q;a[n+m|0]=(d[p]|d[p+1|0]<<8)<<16>>16;p=e;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;a[n+f|0]=q;a[n+3|0]=q;a[n]=q;a[n+j|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function Rzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=c+2|0;i=b+h|0;j=(d[i]|d[i+1|0]<<8)<<16>>16&255;a[e+(f+2)|0]=j;a[e+(f+5)|0]=j;a[e+5|0]=j;a[e+2|0]=j;j=b+2|0;a[e+4|0]=(d[j]|d[j+1|0]<<8)<<16>>16;i=(de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535;j=b+c|0;k=(((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)+i|0)>>>9&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=(d[j]|d[j+1|0]<<8)<<16>>16;j=b;k=(d[j]|d[j+1|0]<<8)<<16>>16&255;a[e+f|0]=k;a[e+3|0]=k;a[e]=k;a[e+(f+3)|0]=k;k=b+4|0;b=e+6|0;j=g-2|0;if((j|0)>2){i=-c|0;l=-2-c|0;m=2-c|0;n=c-2|0;o=f+8|0;p=f+7|0;q=c<<1;r=f+6|0;s=f+11|0;t=c+4|0;u=q+2|0;v=f+10|0;w=q+4|0;x=f+9|0;y=e;z=k;A=2;B=b;while(1){C=z+l|0;D=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=z+m|0;E=((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+D|0;D=z+n|0;F=E+((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0;E=z+h|0;a[y+8|0]=(F+((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;F=z+i|0;G=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=z-2|0;H=((de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=z+2|0;F=H+((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0;H=z+c|0;a[y+7|0]=(F+((de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;F=z;a[B]=(d[F]|d[F+1|0]<<8)<<16>>16;I=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;a[y+11|0]=(((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+10|0]=(d[G]|d[G+1|0]<<8)<<16>>16;I=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;C=z+4|0;J=C;a[y+9|0]=(((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;I=(de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;a[y+o|0]=(((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+p|0]=(d[H]|d[H+1|0]<<8)<<16>>16;I=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;D=z+q|0;a[y+r|0]=(((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+s|0]=(d[E]|d[E+1|0]<<8)<<16>>16;E=(de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=((de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+E|0;E=z+t|0;H=G+((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0;E=z+u|0;a[y+v|0]=(H+((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;E=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)+E|0;E=F+((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0;D=z+w|0;a[y+x|0]=(E+((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;D=A+2|0;E=B+6|0;if((D|0)<(j|0)){y=B;z=C;A=D;B=E}else{K=B;L=C;M=E;break}}}else{K=e;L=k;M=b}if((g|0)<=2){return}g=L+h|0;h=(d[g]|d[g+1|0]<<8)<<16>>16&255;a[K+(f+8)|0]=h;a[K+(f+11)|0]=h;a[K+11|0]=h;a[K+8|0]=h;h=L+2|0;a[K+10|0]=(d[h]|d[h+1|0]<<8)<<16>>16;g=(de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;h=L+c|0;c=(((de((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535)+g|0)>>>9&255;a[K+(f+10)|0]=c;a[K+7|0]=c;a[K+(f+7)|0]=(d[h]|d[h+1|0]<<8)<<16>>16;h=L;L=(d[h]|d[h+1|0]<<8)<<16>>16&255;a[K+(f+6)|0]=L;a[K+9|0]=L;a[M]=L;a[K+(f+9)|0]=L;return}function Szb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)<=0){return}h=f+3|0;i=c+1|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=a[e+c|0]|0;a[n+f|0]=o;a[n+h|0]=o;a[n+3|0]=o;a[n]=o;a[n+1|0]=a[e]|0;o=e+i|0;a[n+j|0]=a[o]|0;p=((d[o]|0)+(d[e]|0)|0)>>>1&255;a[n+k|0]=p;a[n+4|0]=p;p=a[e+1|0]|0;a[n+l|0]=p;a[n+5|0]=p;a[n+2|0]=p;a[n+m|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+2|0;b=p}else{break}}return}function Tzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=a[b+c|0]|0;a[e+f|0]=h;a[e+(f+3)|0]=h;a[e+3|0]=h;a[e]=h;a[e+1|0]=a[b]|0;h=c+1|0;i=b+h|0;a[e+(f+4)|0]=a[i]|0;j=((d[i]|0)+(d[b]|0)|0)>>>1&255;a[e+(f+1)|0]=j;a[e+4|0]=j;j=a[b+1|0]|0;a[e+(f+2)|0]=j;a[e+5|0]=j;a[e+2|0]=j;a[e+(f+5)|0]=j;j=b+2|0;b=e+6|0;i=g-2|0;if((i|0)>2){k=-c|0;l=2-c|0;m=c+2|0;n=1-c|0;o=f+6|0;p=c-1|0;q=c<<1;r=f+7|0;s=q-1|0;t=q|1;u=f+8|0;v=f+9|0;w=f+10|0;x=f+11|0;y=e;z=j;A=2;B=b;while(1){C=z+k|0;D=z+c|0;a[B]=((d[D]|0)+(d[C]|0)|0)>>>1;a[y+7|0]=a[z]|0;E=z-1|0;F=z+1|0;a[y+8|0]=((d[F]|0)+(d[E]|0)|0)>>>1;G=z+m|0;a[y+9|0]=((d[z+l|0]|0)+(d[C]|0)+(d[D]|0)+(d[G]|0)|0)>>>2;C=z+2|0;H=z+h|0;a[y+10|0]=((d[z]|0)+(d[z+n|0]|0)+(d[C]|0)+(d[H]|0)|0)>>>2;a[y+11|0]=a[F]|0;a[y+o|0]=a[D]|0;a[y+r|0]=((d[z+p|0]|0)+(d[z]|0)+(d[H]|0)+(d[z+q|0]|0)|0)>>>2;I=z+t|0;a[y+u|0]=((d[F]|0)+(d[E]|0)+(d[z+s|0]|0)+(d[I]|0)|0)>>>2;a[y+v|0]=((d[G]|0)+(d[D]|0)|0)>>>1;a[y+w|0]=a[H]|0;a[y+x|0]=((d[I]|0)+(d[F]|0)|0)>>>1;F=A+2|0;I=B+6|0;if((F|0)<(i|0)){y=B;z=C;A=F;B=I}else{J=B;K=C;L=I;break}}}else{J=e;K=j;L=b}if((g|0)<=2){return}g=a[K+c|0]|0;a[J+(f+6)|0]=g;a[J+(f+9)|0]=g;a[J+9|0]=g;a[L]=g;a[J+7|0]=a[K]|0;g=K+h|0;a[J+(f+10)|0]=a[g]|0;h=((d[g]|0)+(d[K]|0)|0)>>>1&255;a[J+(f+7)|0]=h;a[J+10|0]=h;h=a[K+1|0]|0;a[J+(f+8)|0]=h;a[J+11|0]=h;a[J+8|0]=h;a[J+(f+11)|0]=h;return}function Uzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=f+3|0;i=c+2|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=e+c|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+f|0]=p;a[n+h|0]=p;a[n+3|0]=p;a[n]=p;p=e;a[n+1|0]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;o=e+i|0;a[n+j|0]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;q=(((d[o]|d[o+1|0]<<8)<<16>>16&65535)+((d[p]|d[p+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[n+k|0]=q;a[n+4|0]=q;q=e+2|0;p=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+l|0]=p;a[n+5|0]=p;a[n+2|0]=p;a[n+m|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+4|0;b=p}else{break}}return}function Vzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=b+c|0;i=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+f|0]=i;a[e+(f+3)|0]=i;a[e+3|0]=i;a[e]=i;i=b;a[e+1|0]=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8;h=c+2|0;j=b+h|0;a[e+(f+4)|0]=((d[j]|d[j+1|0]<<8)<<16>>16&65535)>>>8;k=(((d[j]|d[j+1|0]<<8)<<16>>16&65535)+((d[i]|d[i+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[e+(f+1)|0]=k;a[e+4|0]=k;k=b+2|0;i=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+(f+2)|0]=i;a[e+5|0]=i;a[e+2|0]=i;a[e+(f+5)|0]=i;i=b+4|0;b=e+6|0;k=g-2|0;if((k|0)>2){j=-c|0;l=4-c|0;m=c+4|0;n=2-c|0;o=f+6|0;p=c-2|0;q=c<<1;r=f+7|0;s=q-2|0;t=q+2|0;u=f+8|0;v=f+9|0;w=f+10|0;x=f+11|0;y=e;z=i;A=2;B=b;while(1){C=z+j|0;D=z+c|0;a[B]=(((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;E=z;a[y+7|0]=((d[E]|d[E+1|0]<<8)<<16>>16&65535)>>>8;F=z-2|0;G=z+2|0;a[y+8|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)|0)>>>9;H=z+l|0;I=z+m|0;a[y+9|0]=(((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[I]|d[I+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+n|0;H=z+4|0;J=H;K=z+h|0;a[y+10|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)+((d[K]|d[K+1|0]<<8)<<16>>16&65535)|0)>>>10;a[y+11|0]=((d[G]|d[G+1|0]<<8)<<16>>16&65535)>>>8;a[y+o|0]=((d[D]|d[D+1|0]<<8)<<16>>16&65535)>>>8;J=z+p|0;C=z+q|0;a[y+r|0]=(((d[J]|d[J+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[K]|d[K+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+s|0;E=z+t|0;a[y+u|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)|0)>>>10;a[y+v|0]=(((d[I]|d[I+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+w|0]=((d[K]|d[K+1|0]<<8)<<16>>16&65535)>>>8;a[y+x|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[G]|d[G+1|0]<<8)<<16>>16&65535)|0)>>>9;G=A+2|0;E=B+6|0;if((G|0)<(k|0)){y=B;z=H;A=G;B=E}else{L=B;M=H;N=E;break}}}else{L=e;M=i;N=b}if((g|0)<=2){return}g=M+c|0;c=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[L+(f+6)|0]=c;a[L+(f+9)|0]=c;a[L+9|0]=c;a[N]=c;c=M;a[L+7|0]=((d[c]|d[c+1|0]<<8)<<16>>16&65535)>>>8;N=M+h|0;a[L+(f+10)|0]=((d[N]|d[N+1|0]<<8)<<16>>16&65535)>>>8;h=(((d[N]|d[N+1|0]<<8)<<16>>16&65535)+((d[c]|d[c+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[L+(f+7)|0]=h;a[L+10|0]=h;h=M+2|0;M=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8&255;a[L+(f+8)|0]=M;a[L+11|0]=M;a[L+8|0]=M;a[L+(f+11)|0]=M;return}function Wzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=f+3|0;i=c+2|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=e+c|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[n+f|0]=p;a[n+h|0]=p;a[n+3|0]=p;a[n]=p;p=e;a[n+1|0]=(d[p]|d[p+1|0]<<8)<<16>>16;o=e+i|0;a[n+j|0]=(d[o]|d[o+1|0]<<8)<<16>>16;q=(de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=(((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)+q|0)>>>9&255;a[n+k|0]=p;a[n+4|0]=p;p=e+2|0;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;a[n+l|0]=q;a[n+5|0]=q;a[n+2|0]=q;a[n+m|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function Xzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=b+c|0;i=(d[h]|d[h+1|0]<<8)<<16>>16&255;a[e+f|0]=i;a[e+(f+3)|0]=i;a[e+3|0]=i;a[e]=i;i=b;a[e+1|0]=(d[i]|d[i+1|0]<<8)<<16>>16;h=c+2|0;j=b+h|0;a[e+(f+4)|0]=(d[j]|d[j+1|0]<<8)<<16>>16;k=(de((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535;i=(((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)+k|0)>>>9&255;a[e+(f+1)|0]=i;a[e+4|0]=i;i=b+2|0;k=(d[i]|d[i+1|0]<<8)<<16>>16&255;a[e+(f+2)|0]=k;a[e+5|0]=k;a[e+2|0]=k;a[e+(f+5)|0]=k;k=b+4|0;b=e+6|0;i=g-2|0;if((i|0)>2){j=-c|0;l=4-c|0;m=c+4|0;n=2-c|0;o=f+6|0;p=c-2|0;q=c<<1;r=f+7|0;s=q-2|0;t=q+2|0;u=f+8|0;v=f+9|0;w=f+10|0;x=f+11|0;y=e;z=k;A=2;B=b;while(1){C=z+j|0;D=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;E=z+c|0;a[B]=(((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+D|0)>>>9;D=z;a[y+7|0]=(d[D]|d[D+1|0]<<8)<<16>>16;F=z-2|0;G=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;H=z+2|0;a[y+8|0]=(((de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+G|0)>>>9;G=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=z+l|0;I=((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=I+((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0;I=z+m|0;a[y+9|0]=(G+((de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;G=z+n|0;C=(de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+C|0;C=z+4|0;J=C;K=G+((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0;J=z+h|0;a[y+10|0]=(K+((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;a[y+11|0]=(d[H]|d[H+1|0]<<8)<<16>>16;a[y+o|0]=(d[E]|d[E+1|0]<<8)<<16>>16;K=(de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;D=z+p|0;G=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+K|0;K=G+((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0;G=z+q|0;a[y+r|0]=(K+((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;G=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=((de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=z+s|0;K=F+((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0;G=z+t|0;a[y+u|0]=(K+((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;K=(de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;a[y+v|0]=(((de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)+K|0)>>>9;a[y+w|0]=(d[J]|d[J+1|0]<<8)<<16>>16;J=(de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;a[y+x|0]=(((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)+J|0)>>>9;J=A+2|0;G=B+6|0;if((J|0)<(i|0)){y=B;z=C;A=J;B=G}else{L=B;M=C;N=G;break}}}else{L=e;M=k;N=b}if((g|0)<=2){return}g=M+c|0;c=(d[g]|d[g+1|0]<<8)<<16>>16&255;a[L+(f+6)|0]=c;a[L+(f+9)|0]=c;a[L+9|0]=c;a[N]=c;c=M;a[L+7|0]=(d[c]|d[c+1|0]<<8)<<16>>16;N=M+h|0;a[L+(f+10)|0]=(d[N]|d[N+1|0]<<8)<<16>>16;h=(de((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&65535;c=(((de((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)+h|0)>>>9&255;a[L+(f+7)|0]=c;a[L+10|0]=c;c=M+2|0;M=(d[c]|d[c+1|0]<<8)<<16>>16&255;a[L+(f+8)|0]=M;a[L+11|0]=M;a[L+8|0]=M;a[L+(f+11)|0]=M;return}function Yzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)<=0){return}h=f+2|0;i=f+3|0;j=f+5|0;k=c+1|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=a[e+c|0]|0;a[n+h|0]=o;a[n+j|0]=o;a[n+5|0]=o;a[n+2|0]=o;a[n+1|0]=a[e]|0;o=e+k|0;a[n+l|0]=a[o]|0;p=((d[o]|0)+(d[e]|0)|0)>>>1&255;a[n+m|0]=p;a[n+4|0]=p;p=a[e+1|0]|0;a[n+f|0]=p;a[n+3|0]=p;a[n]=p;a[n+i|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+2|0;b=p}else{break}}return}function Zzb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=a[b+c|0]|0;a[e+(f+2)|0]=h;a[e+(f+5)|0]=h;a[e+5|0]=h;a[e+2|0]=h;a[e+1|0]=a[b]|0;h=c+1|0;i=b+h|0;a[e+(f+4)|0]=a[i]|0;j=((d[i]|0)+(d[b]|0)|0)>>>1&255;a[e+(f+1)|0]=j;a[e+4|0]=j;j=a[b+1|0]|0;a[e+f|0]=j;a[e+3|0]=j;a[e]=j;a[e+(f+3)|0]=j;j=b+2|0;b=e+6|0;i=g-2|0;if((i|0)>2){k=-c|0;l=2-c|0;m=c+2|0;n=1-c|0;o=f+8|0;p=c-1|0;q=c<<1;r=f+7|0;s=q-1|0;t=q|1;u=f+6|0;v=f+11|0;w=f+10|0;x=f+9|0;y=e;z=j;A=2;B=b;while(1){C=z+k|0;D=z+c|0;a[y+8|0]=((d[D]|0)+(d[C]|0)|0)>>>1;a[y+7|0]=a[z]|0;E=z-1|0;F=z+1|0;a[B]=((d[F]|0)+(d[E]|0)|0)>>>1;G=z+m|0;a[y+11|0]=((d[z+l|0]|0)+(d[C]|0)+(d[D]|0)+(d[G]|0)|0)>>>2;C=z+2|0;H=z+h|0;a[y+10|0]=((d[z]|0)+(d[z+n|0]|0)+(d[C]|0)+(d[H]|0)|0)>>>2;a[y+9|0]=a[F]|0;a[y+o|0]=a[D]|0;a[y+r|0]=((d[z+p|0]|0)+(d[z]|0)+(d[H]|0)+(d[z+q|0]|0)|0)>>>2;I=z+t|0;a[y+u|0]=((d[F]|0)+(d[E]|0)+(d[z+s|0]|0)+(d[I]|0)|0)>>>2;a[y+v|0]=((d[G]|0)+(d[D]|0)|0)>>>1;a[y+w|0]=a[H]|0;a[y+x|0]=((d[I]|0)+(d[F]|0)|0)>>>1;F=A+2|0;I=B+6|0;if((F|0)<(i|0)){y=B;z=C;A=F;B=I}else{J=B;K=C;L=I;break}}}else{J=e;K=j;L=b}if((g|0)<=2){return}g=a[K+c|0]|0;a[J+(f+8)|0]=g;a[J+(f+11)|0]=g;a[J+11|0]=g;a[J+8|0]=g;a[J+7|0]=a[K]|0;g=K+h|0;a[J+(f+10)|0]=a[g]|0;h=((d[g]|0)+(d[K]|0)|0)>>>1&255;a[J+(f+7)|0]=h;a[J+10|0]=h;h=a[K+1|0]|0;a[J+(f+6)|0]=h;a[J+9|0]=h;a[L]=h;a[J+(f+9)|0]=h;return}function _zb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=f+2|0;i=f+3|0;j=f+5|0;k=c+2|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=e+c|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+h|0]=p;a[n+j|0]=p;a[n+5|0]=p;a[n+2|0]=p;p=e;a[n+1|0]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;o=e+k|0;a[n+l|0]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;q=(((d[o]|d[o+1|0]<<8)<<16>>16&65535)+((d[p]|d[p+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[n+m|0]=q;a[n+4|0]=q;q=e+2|0;p=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+f|0]=p;a[n+3|0]=p;a[n]=p;a[n+i|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+4|0;b=p}else{break}}return}function $zb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=b+c|0;i=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+(f+2)|0]=i;a[e+(f+5)|0]=i;a[e+5|0]=i;a[e+2|0]=i;i=b;a[e+1|0]=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8;h=c+2|0;j=b+h|0;a[e+(f+4)|0]=((d[j]|d[j+1|0]<<8)<<16>>16&65535)>>>8;k=(((d[j]|d[j+1|0]<<8)<<16>>16&65535)+((d[i]|d[i+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[e+(f+1)|0]=k;a[e+4|0]=k;k=b+2|0;i=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+f|0]=i;a[e+3|0]=i;a[e]=i;a[e+(f+3)|0]=i;i=b+4|0;b=e+6|0;k=g-2|0;if((k|0)>2){j=-c|0;l=4-c|0;m=c+4|0;n=2-c|0;o=f+8|0;p=c-2|0;q=c<<1;r=f+7|0;s=q-2|0;t=q+2|0;u=f+6|0;v=f+11|0;w=f+10|0;x=f+9|0;y=e;z=i;A=2;B=b;while(1){C=z+j|0;D=z+c|0;a[y+8|0]=(((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;E=z;a[y+7|0]=((d[E]|d[E+1|0]<<8)<<16>>16&65535)>>>8;F=z-2|0;G=z+2|0;a[B]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)|0)>>>9;H=z+l|0;I=z+m|0;a[y+11|0]=(((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[I]|d[I+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+n|0;H=z+4|0;J=H;K=z+h|0;a[y+10|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)+((d[K]|d[K+1|0]<<8)<<16>>16&65535)|0)>>>10;a[y+9|0]=((d[G]|d[G+1|0]<<8)<<16>>16&65535)>>>8;a[y+o|0]=((d[D]|d[D+1|0]<<8)<<16>>16&65535)>>>8;J=z+p|0;C=z+q|0;a[y+r|0]=(((d[J]|d[J+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[K]|d[K+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+s|0;E=z+t|0;a[y+u|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)|0)>>>10;a[y+v|0]=(((d[I]|d[I+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+w|0]=((d[K]|d[K+1|0]<<8)<<16>>16&65535)>>>8;a[y+x|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[G]|d[G+1|0]<<8)<<16>>16&65535)|0)>>>9;G=A+2|0;E=B+6|0;if((G|0)<(k|0)){y=B;z=H;A=G;B=E}else{L=B;M=H;N=E;break}}}else{L=e;M=i;N=b}if((g|0)<=2){return}g=M+c|0;c=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[L+(f+8)|0]=c;a[L+(f+11)|0]=c;a[L+11|0]=c;a[L+8|0]=c;c=M;a[L+7|0]=((d[c]|d[c+1|0]<<8)<<16>>16&65535)>>>8;g=M+h|0;a[L+(f+10)|0]=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8;h=(((d[g]|d[g+1|0]<<8)<<16>>16&65535)+((d[c]|d[c+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[L+(f+7)|0]=h;a[L+10|0]=h;h=M+2|0;M=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8&255;a[L+(f+6)|0]=M;a[L+9|0]=M;a[N]=M;a[L+(f+9)|0]=M;return}function aAb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=f+2|0;i=f+3|0;j=f+5|0;k=c+2|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=e+c|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[n+h|0]=p;a[n+j|0]=p;a[n+5|0]=p;a[n+2|0]=p;p=e;a[n+1|0]=(d[p]|d[p+1|0]<<8)<<16>>16;o=e+k|0;a[n+l|0]=(d[o]|d[o+1|0]<<8)<<16>>16;q=(de((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=(((de((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)+q|0)>>>9&255;a[n+m|0]=p;a[n+4|0]=p;p=e+2|0;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;a[n+f|0]=q;a[n+3|0]=q;a[n]=q;a[n+i|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function bAb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=b+c|0;i=(d[h]|d[h+1|0]<<8)<<16>>16&255;a[e+(f+2)|0]=i;a[e+(f+5)|0]=i;a[e+5|0]=i;a[e+2|0]=i;i=b;a[e+1|0]=(d[i]|d[i+1|0]<<8)<<16>>16;h=c+2|0;j=b+h|0;a[e+(f+4)|0]=(d[j]|d[j+1|0]<<8)<<16>>16;k=(de((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535;i=(((de((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)+k|0)>>>9&255;a[e+(f+1)|0]=i;a[e+4|0]=i;i=b+2|0;k=(d[i]|d[i+1|0]<<8)<<16>>16&255;a[e+f|0]=k;a[e+3|0]=k;a[e]=k;a[e+(f+3)|0]=k;k=b+4|0;b=e+6|0;i=g-2|0;if((i|0)>2){j=-c|0;l=4-c|0;m=c+4|0;n=2-c|0;o=f+8|0;p=c-2|0;q=c<<1;r=f+7|0;s=q-2|0;t=q+2|0;u=f+6|0;v=f+11|0;w=f+10|0;x=f+9|0;y=e;z=k;A=2;B=b;while(1){C=z+j|0;D=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;E=z+c|0;a[y+8|0]=(((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+D|0)>>>9;D=z;a[y+7|0]=(d[D]|d[D+1|0]<<8)<<16>>16;F=z-2|0;G=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;H=z+2|0;a[B]=(((de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+G|0)>>>9;G=(de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=z+l|0;I=((de((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=I+((de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0;I=z+m|0;a[y+11|0]=(G+((de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;G=z+n|0;C=(de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+C|0;C=z+4|0;J=C;K=G+((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0;J=z+h|0;a[y+10|0]=(K+((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;a[y+9|0]=(d[H]|d[H+1|0]<<8)<<16>>16;a[y+o|0]=(d[E]|d[E+1|0]<<8)<<16>>16;K=(de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;D=z+p|0;G=((de((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+K|0;K=G+((de((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0;G=z+q|0;a[y+r|0]=(K+((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;G=(de((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=((de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=z+s|0;K=F+((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0;G=z+t|0;a[y+u|0]=(K+((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;K=(de((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;a[y+v|0]=(((de((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)+K|0)>>>9;a[y+w|0]=(d[J]|d[J+1|0]<<8)<<16>>16;J=(de((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;a[y+x|0]=(((de((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)+J|0)>>>9;J=A+2|0;G=B+6|0;if((J|0)<(i|0)){y=B;z=C;A=J;B=G}else{L=B;M=C;N=G;break}}}else{L=e;M=k;N=b}if((g|0)<=2){return}g=M+c|0;c=(d[g]|d[g+1|0]<<8)<<16>>16&255;a[L+(f+8)|0]=c;a[L+(f+11)|0]=c;a[L+11|0]=c;a[L+8|0]=c;c=M;a[L+7|0]=(d[c]|d[c+1|0]<<8)<<16>>16;g=M+h|0;a[L+(f+10)|0]=(d[g]|d[g+1|0]<<8)<<16>>16;h=(de((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&65535;c=(((de((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535)+h|0)>>>9&255;a[L+(f+7)|0]=c;a[L+10|0]=c;c=M+2|0;M=(d[c]|d[c+1|0]<<8)<<16>>16&255;a[L+(f+6)|0]=M;a[L+9|0]=M;a[N]=M;a[L+(f+9)|0]=M;return}function cAb(a,d,f,g,h,i,j,k,l){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=a+12|0;n=(c[m>>2]|0)!=0;o=16-k|0;p=(k<<1)-16|0;if((h|0)<=0){return}k=(i|0)==0;i=k|n;q=k|n^1;k=(l|0)>0;r=a+4|0;s=a+8|0;t=n?4:3;n=0;do{u=f+(ba(n,g)|0)|0;a:do{if((j|0)==1){if(!i){if(!k){v=0;break}w=c[a>>2]|0;x=c[r>>2]|0;y=c[s>>2]|0;z=0;A=u;while(1){B=(de(b[w+(z<<1)>>1]|0)|0)&65535;b[A>>1]=B<<o|B>>>(p>>>0);B=(de(b[x+(z<<1)>>1]|0)|0)&65535;b[A+2>>1]=B<<o|B>>>(p>>>0);B=(de(b[y+(z<<1)>>1]|0)|0)&65535;b[A+4>>1]=B<<o|B>>>(p>>>0);b[A+6>>1]=-1;B=z+1|0;if((B|0)<(l|0)){z=B;A=A+8|0}else{v=0;break a}}}if(q){if(!k){v=0;break}A=c[a>>2]|0;z=c[r>>2]|0;y=c[s>>2]|0;x=0;w=u;while(1){B=(de(b[A+(x<<1)>>1]|0)|0)&65535;b[w>>1]=B<<o|B>>>(p>>>0);B=(de(b[z+(x<<1)>>1]|0)|0)&65535;b[w+2>>1]=B<<o|B>>>(p>>>0);B=(de(b[y+(x<<1)>>1]|0)|0)&65535;b[w+4>>1]=B<<o|B>>>(p>>>0);B=x+1|0;if((B|0)<(l|0)){x=B;w=w+6|0}else{v=0;break}}}else{if(!k){v=0;break}w=c[a>>2]|0;x=c[r>>2]|0;y=c[s>>2]|0;z=c[m>>2]|0;A=0;B=u;while(1){C=(de(b[w+(A<<1)>>1]|0)|0)&65535;b[B>>1]=C<<o|C>>>(p>>>0);C=(de(b[x+(A<<1)>>1]|0)|0)&65535;b[B+2>>1]=C<<o|C>>>(p>>>0);C=(de(b[y+(A<<1)>>1]|0)|0)&65535;b[B+4>>1]=C<<o|C>>>(p>>>0);C=(de(b[z+(A<<1)>>1]|0)|0)&65535;b[B+6>>1]=C<<o|C>>>(p>>>0);C=A+1|0;if((C|0)<(l|0)){A=C;B=B+8|0}else{v=0;break}}}}else if((j|0)==2){if(!i){if(!k){v=0;break}B=c[a>>2]|0;A=c[r>>2]|0;z=c[s>>2]|0;y=0;x=u;while(1){w=e[B+(y<<1)>>1]|0;b[x>>1]=de((w<<o|w>>>(p>>>0))&65535|0)|0;w=e[A+(y<<1)>>1]|0;b[x+2>>1]=de((w<<o|w>>>(p>>>0))&65535|0)|0;w=e[z+(y<<1)>>1]|0;b[x+4>>1]=de((w<<o|w>>>(p>>>0))&65535|0)|0;b[x+6>>1]=-1;w=y+1|0;if((w|0)<(l|0)){y=w;x=x+8|0}else{v=0;break a}}}if(q){if(!k){v=0;break}x=c[a>>2]|0;y=c[r>>2]|0;z=c[s>>2]|0;A=0;B=u;while(1){w=e[x+(A<<1)>>1]|0;b[B>>1]=de((w<<o|w>>>(p>>>0))&65535|0)|0;w=e[y+(A<<1)>>1]|0;b[B+2>>1]=de((w<<o|w>>>(p>>>0))&65535|0)|0;w=e[z+(A<<1)>>1]|0;b[B+4>>1]=de((w<<o|w>>>(p>>>0))&65535|0)|0;w=A+1|0;if((w|0)<(l|0)){A=w;B=B+6|0}else{v=0;break}}}else{if(!k){v=0;break}B=c[a>>2]|0;A=c[r>>2]|0;z=c[s>>2]|0;y=c[m>>2]|0;x=0;w=u;while(1){C=e[B+(x<<1)>>1]|0;b[w>>1]=de((C<<o|C>>>(p>>>0))&65535|0)|0;C=e[A+(x<<1)>>1]|0;b[w+2>>1]=de((C<<o|C>>>(p>>>0))&65535|0)|0;C=e[z+(x<<1)>>1]|0;b[w+4>>1]=de((C<<o|C>>>(p>>>0))&65535|0)|0;C=e[y+(x<<1)>>1]|0;b[w+6>>1]=de((C<<o|C>>>(p>>>0))&65535|0)|0;C=x+1|0;if((C|0)<(l|0)){x=C;w=w+8|0}else{v=0;break}}}}else if((j|0)==3){if(!i){if(!k){v=0;break}w=c[a>>2]|0;x=c[r>>2]|0;y=c[s>>2]|0;z=0;A=u;while(1){B=(de(b[w+(z<<1)>>1]|0)|0)&65535;b[A>>1]=de((B<<o|B>>>(p>>>0))&65535|0)|0;B=(de(b[x+(z<<1)>>1]|0)|0)&65535;b[A+2>>1]=de((B<<o|B>>>(p>>>0))&65535|0)|0;B=(de(b[y+(z<<1)>>1]|0)|0)&65535;b[A+4>>1]=de((B<<o|B>>>(p>>>0))&65535|0)|0;b[A+6>>1]=-1;B=z+1|0;if((B|0)<(l|0)){z=B;A=A+8|0}else{v=0;break a}}}if(q){if(!k){v=0;break}A=c[a>>2]|0;z=c[r>>2]|0;y=c[s>>2]|0;x=0;w=u;while(1){B=(de(b[A+(x<<1)>>1]|0)|0)&65535;b[w>>1]=de((B<<o|B>>>(p>>>0))&65535|0)|0;B=(de(b[z+(x<<1)>>1]|0)|0)&65535;b[w+2>>1]=de((B<<o|B>>>(p>>>0))&65535|0)|0;B=(de(b[y+(x<<1)>>1]|0)|0)&65535;b[w+4>>1]=de((B<<o|B>>>(p>>>0))&65535|0)|0;B=x+1|0;if((B|0)<(l|0)){x=B;w=w+6|0}else{v=0;break}}}else{if(!k){v=0;break}w=c[a>>2]|0;x=c[r>>2]|0;y=c[s>>2]|0;z=c[m>>2]|0;A=0;B=u;while(1){C=(de(b[w+(A<<1)>>1]|0)|0)&65535;b[B>>1]=de((C<<o|C>>>(p>>>0))&65535|0)|0;C=(de(b[x+(A<<1)>>1]|0)|0)&65535;b[B+2>>1]=de((C<<o|C>>>(p>>>0))&65535|0)|0;C=(de(b[y+(A<<1)>>1]|0)|0)&65535;b[B+4>>1]=de((C<<o|C>>>(p>>>0))&65535|0)|0;C=(de(b[z+(A<<1)>>1]|0)|0)&65535;b[B+6>>1]=de((C<<o|C>>>(p>>>0))&65535|0)|0;C=A+1|0;if((C|0)<(l|0)){A=C;B=B+8|0}else{v=0;break}}}}else{if(!i){if(!k){v=0;break}B=c[a>>2]|0;A=c[r>>2]|0;z=c[s>>2]|0;y=0;x=u;while(1){w=e[B+(y<<1)>>1]|0;b[x>>1]=w<<o|w>>>(p>>>0);w=e[A+(y<<1)>>1]|0;b[x+2>>1]=w<<o|w>>>(p>>>0);w=e[z+(y<<1)>>1]|0;b[x+4>>1]=w<<o|w>>>(p>>>0);b[x+6>>1]=-1;w=y+1|0;if((w|0)<(l|0)){y=w;x=x+8|0}else{v=0;break a}}}if(q){if(!k){v=0;break}x=c[a>>2]|0;y=c[r>>2]|0;z=c[s>>2]|0;A=0;B=u;while(1){w=e[x+(A<<1)>>1]|0;b[B>>1]=w<<o|w>>>(p>>>0);w=e[y+(A<<1)>>1]|0;b[B+2>>1]=w<<o|w>>>(p>>>0);w=e[z+(A<<1)>>1]|0;b[B+4>>1]=w<<o|w>>>(p>>>0);w=A+1|0;if((w|0)<(l|0)){A=w;B=B+6|0}else{v=0;break}}}else{if(!k){v=0;break}B=c[a>>2]|0;A=c[r>>2]|0;z=c[s>>2]|0;y=c[m>>2]|0;x=0;w=u;while(1){C=e[B+(x<<1)>>1]|0;b[w>>1]=C<<o|C>>>(p>>>0);C=e[A+(x<<1)>>1]|0;b[w+2>>1]=C<<o|C>>>(p>>>0);C=e[z+(x<<1)>>1]|0;b[w+4>>1]=C<<o|C>>>(p>>>0);C=e[y+(x<<1)>>1]|0;b[w+6>>1]=C<<o|C>>>(p>>>0);C=x+1|0;if((C|0)<(l|0)){x=C;w=w+8|0}else{v=0;break}}}}}while(0);do{u=a+(v<<2)|0;c[u>>2]=(c[u>>2]|0)+(c[d+(v<<2)>>2]>>1<<1);v=v+1|0;}while((v|0)<(t|0));n=n+1|0;}while((n|0)<(h|0));return}function dAb(a,d,f,g,h,i,j,k,l){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=f+12|0;n=c[m>>2]|0;o=(n|0)!=0;if((h|0)<=0){return}p=(i|0)!=0;i=p&o;q=(l|0)>0;r=f+4|0;s=f+8|0;t=0;u=n;do{n=a+(ba(t,d)|0)|0;a:do{if((j|0)==1){if(i){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=((de(b[z>>1]|0)|0)&65535)>>>(k>>>0);b[w+(y<<1)>>1]=((de(b[z+2>>1]|0)|0)&65535)>>>(k>>>0);b[x+(y<<1)>>1]=((de(b[z+4>>1]|0)|0)&65535)>>>(k>>>0);b[u+(y<<1)>>1]=((de(b[z+6>>1]|0)|0)&65535)>>>(k>>>0);A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break a}}}if(o){if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=((de(b[v>>1]|0)|0)&65535)>>>(k>>>0);b[y+(w<<1)>>1]=((de(b[v+2>>1]|0)|0)&65535)>>>(k>>>0);b[x+(w<<1)>>1]=((de(b[v+4>>1]|0)|0)&65535)>>>(k>>>0);b[u+(w<<1)>>1]=-1;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break a}}}if(p){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=((de(b[z>>1]|0)|0)&65535)>>>(k>>>0);b[w+(y<<1)>>1]=((de(b[z+2>>1]|0)|0)&65535)>>>(k>>>0);b[x+(y<<1)>>1]=((de(b[z+4>>1]|0)|0)&65535)>>>(k>>>0);A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break}}}else{if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=((de(b[v>>1]|0)|0)&65535)>>>(k>>>0);b[y+(w<<1)>>1]=((de(b[v+2>>1]|0)|0)&65535)>>>(k>>>0);b[x+(w<<1)>>1]=((de(b[v+4>>1]|0)|0)&65535)>>>(k>>>0);A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break}}}}else if((j|0)==2){if(i){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=de((e[z>>1]|0)>>>(k>>>0)&65535|0)|0;b[w+(y<<1)>>1]=de((e[z+2>>1]|0)>>>(k>>>0)&65535|0)|0;b[x+(y<<1)>>1]=de((e[z+4>>1]|0)>>>(k>>>0)&65535|0)|0;b[u+(y<<1)>>1]=de((e[z+6>>1]|0)>>>(k>>>0)&65535|0)|0;A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break a}}}if(o){if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=de((e[v>>1]|0)>>>(k>>>0)&65535|0)|0;b[y+(w<<1)>>1]=de((e[v+2>>1]|0)>>>(k>>>0)&65535|0)|0;b[x+(w<<1)>>1]=de((e[v+4>>1]|0)>>>(k>>>0)&65535|0)|0;b[u+(w<<1)>>1]=-1;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break a}}}if(p){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=de((e[z>>1]|0)>>>(k>>>0)&65535|0)|0;b[w+(y<<1)>>1]=de((e[z+2>>1]|0)>>>(k>>>0)&65535|0)|0;b[x+(y<<1)>>1]=de((e[z+4>>1]|0)>>>(k>>>0)&65535|0)|0;A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break}}}else{if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=de((e[v>>1]|0)>>>(k>>>0)&65535|0)|0;b[y+(w<<1)>>1]=de((e[v+2>>1]|0)>>>(k>>>0)&65535|0)|0;b[x+(w<<1)>>1]=de((e[v+4>>1]|0)>>>(k>>>0)&65535|0)|0;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break}}}}else if((j|0)==3){if(i){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=de(((de(b[z>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[w+(y<<1)>>1]=de(((de(b[z+2>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[x+(y<<1)>>1]=de(((de(b[z+4>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[u+(y<<1)>>1]=de(((de(b[z+6>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break a}}}if(o){if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=de(((de(b[v>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[y+(w<<1)>>1]=de(((de(b[v+2>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[x+(w<<1)>>1]=de(((de(b[v+4>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[u+(w<<1)>>1]=-1;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break a}}}if(p){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=de(((de(b[z>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[w+(y<<1)>>1]=de(((de(b[z+2>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[x+(y<<1)>>1]=de(((de(b[z+4>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break}}}else{if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=de(((de(b[v>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[y+(w<<1)>>1]=de(((de(b[v+2>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[x+(w<<1)>>1]=de(((de(b[v+4>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break}}}}else{if(i){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=(e[z>>1]|0)>>>(k>>>0);b[w+(y<<1)>>1]=(e[z+2>>1]|0)>>>(k>>>0);b[x+(y<<1)>>1]=(e[z+4>>1]|0)>>>(k>>>0);b[u+(y<<1)>>1]=(e[z+6>>1]|0)>>>(k>>>0);A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break a}}}if(o){if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=(e[v>>1]|0)>>>(k>>>0);b[y+(w<<1)>>1]=(e[v+2>>1]|0)>>>(k>>>0);b[x+(w<<1)>>1]=(e[v+4>>1]|0)>>>(k>>>0);b[u+(w<<1)>>1]=-1;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break a}}}if(p){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=(e[z>>1]|0)>>>(k>>>0);b[w+(y<<1)>>1]=(e[z+2>>1]|0)>>>(k>>>0);b[x+(y<<1)>>1]=(e[z+4>>1]|0)>>>(k>>>0);A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break}}}else{if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=(e[v>>1]|0)>>>(k>>>0);b[y+(w<<1)>>1]=(e[v+2>>1]|0)>>>(k>>>0);b[x+(w<<1)>>1]=(e[v+4>>1]|0)>>>(k>>>0);A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break}}}}}while(0);c[f>>2]=(c[f>>2]|0)+(c[g>>2]>>1<<1);c[r>>2]=(c[r>>2]|0)+(c[g+4>>2]>>1<<1);c[s>>2]=(c[s>>2]|0)+(c[g+8>>2]>>1<<1);u=u+(c[g+12>>2]>>1<<1)|0;c[m>>2]=u;t=t+1|0;}while((t|0)<(h|0));return}function eAb(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=a&65535;f=a>>>16;if((c|0)==0){g=e;h=f;i=h<<16;j=i|g;return j|0}else{k=b;l=c;m=e;n=f}while(1){f=k+1|0;e=(d[k]|0)+m|0;c=e+n|0;if(l>>>0>4>>>0){b=k;a=l;o=f;p=e;q=c;while(1){r=(d[o]|0)+p|0;s=r+(d[b+2|0]|0)|0;t=b+4|0;u=s+(d[b+3|0]|0)|0;v=r+q+s+u|0;s=a-4|0;r=b+5|0;w=(d[t]|0)+u|0;u=w+v|0;if(s>>>0>4>>>0&(v|0)>-1){b=t;a=s;o=r;p=w;q=u}else{x=s;y=r;z=w;A=u;break}}}else{x=l;y=f;z=e;A=c}q=x-1|0;p=(z>>>0)%65521|0;o=(A>>>0)%65521|0;if((q|0)==0){g=p;h=o;break}else{k=y;l=q;m=p;n=o}}i=h<<16;j=i|g;return j|0}function fAb(){return cEb(280)|0}function gAb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0;j=g-1|0;if((g|0)==0){return}g=b+272|0;k=b+256|0;l=b+264|0;m=(h|0)==0;n=b+240|0;o=n|0;p=b+248|0;q=n;r=n;s=q+4|0;t=p;u=q+12|0;q=n;v=n;n=q+4|0;w=p;y=q+12|0;z=v+1|0;A=v+5|0;B=v+9|0;C=v+13|0;D=q+2|0;E=q+10|0;F=q+6|0;G=q+14|0;q=v+3|0;H=v+15|0;I=v+11|0;J=v+7|0;K=b+240|0;L=b|0;M=b+8|0;N=h;O=h+8|0;if((i|0)==0){P=f;Q=e;R=j}else{i=f;f=e;e=j;while(1){j=c[g>>2]|0;S=i;T=S|0;U=S+4|0;S=b+(j<<4)|0;V=c[S>>2]^(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24);T=c[S+4>>2]^(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24);c[k>>2]=V;c[k+4>>2]=T;U=i+8|0;S=U|0;W=U+4|0;U=b+(j<<4)+8|0;X=c[U>>2]^(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24);S=c[U+4>>2]^(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24);c[l>>2]=X;c[l+4>>2]=S;W=V&255;U=(S>>>8|0<<24)&255;Y=(X>>>16|S<<16)&255;Z=(T>>>24|0<<8)&255;_=T&255;$=(V>>>8|T<<24)&255;aa=(S>>>16|0<<16)&255;ba=(X>>>24|S<<8)&255;ca=X&255;da=(T>>>8|0<<24)&255;ea=(V>>>16|T<<16)&255;fa=(S>>>24|0<<8)&255;ga=S&255;ha=(X>>>8|S<<24)&255;S=(T>>>16|0<<16)&255;X=(V>>>24|T<<8)&255;T=j-1|0;if((T|0)>0){j=T;T=W;V=U;ia=Y;ja=Z;ka=_;la=$;ma=aa;na=ba;oa=ca;pa=da;qa=ea;ra=fa;sa=ga;ta=ha;ua=S;va=X;while(1){c[r>>2]=c[8649320+((V&255)<<2)>>2]^c[8648296+((T&255)<<2)>>2]^c[8650344+((ia&255)<<2)>>2]^c[8651368+((ja&255)<<2)>>2];c[s>>2]=c[8649320+((la&255)<<2)>>2]^c[8648296+((ka&255)<<2)>>2]^c[8650344+((ma&255)<<2)>>2]^c[8651368+((na&255)<<2)>>2];c[t>>2]=c[8649320+((pa&255)<<2)>>2]^c[8648296+((oa&255)<<2)>>2]^c[8650344+((qa&255)<<2)>>2]^c[8651368+((ra&255)<<2)>>2];c[u>>2]=c[8649320+((ta&255)<<2)>>2]^c[8648296+((sa&255)<<2)>>2]^c[8650344+((ua&255)<<2)>>2]^c[8651368+((va&255)<<2)>>2];wa=b+(j<<4)|0;xa=c[wa>>2]^c[o>>2];ya=c[wa+4>>2]^c[o+4>>2];c[k>>2]=xa;c[k+4>>2]=ya;wa=b+(j<<4)+8|0;za=c[wa>>2]^c[p>>2];Aa=c[wa+4>>2]^c[p+4>>2];c[l>>2]=za;c[l+4>>2]=Aa;wa=j-1|0;Ba=xa&255;Ca=(Aa>>>8|0<<24)&255;Da=(za>>>16|Aa<<16)&255;Ea=(ya>>>24|0<<8)&255;Fa=ya&255;Ga=(xa>>>8|ya<<24)&255;Ha=(Aa>>>16|0<<16)&255;Ia=(za>>>24|Aa<<8)&255;Ja=za&255;Ka=(ya>>>8|0<<24)&255;La=(xa>>>16|ya<<16)&255;Ma=(Aa>>>24|0<<8)&255;Na=Aa&255;Oa=(za>>>8|Aa<<24)&255;Aa=(ya>>>16|0<<16)&255;za=(xa>>>24|ya<<8)&255;if((wa|0)>0){j=wa;T=Ba;V=Ca;ia=Da;ja=Ea;ka=Fa;la=Ga;ma=Ha;na=Ia;oa=Ja;pa=Ka;qa=La;ra=Ma;sa=Na;ta=Oa;ua=Aa;va=za}else{Pa=Ba;Qa=Fa;Ra=Ja;Sa=Na;Ta=Ea;Ua=Ia;Va=Ma;Wa=za;Xa=Da;Ya=La;Za=Ha;_a=Aa;$a=Ca;ab=Oa;bb=Ka;cb=Ga;break}}}else{Pa=W;Qa=_;Ra=ca;Sa=ga;Ta=Z;Ua=ba;Va=fa;Wa=X;Xa=Y;Ya=ea;Za=aa;_a=S;$a=U;ab=ha;bb=da;cb=$}a[v]=a[5081904+(Pa&255)|0]|0;a[n]=a[5081904+(Qa&255)|0]|0;a[w]=a[5081904+(Ra&255)|0]|0;a[y]=a[5081904+(Sa&255)|0]|0;a[q]=a[5081904+(Ta&255)|0]|0;a[J]=a[5081904+(Ua&255)|0]|0;a[I]=a[5081904+(Va&255)|0]|0;a[H]=a[5081904+(Wa&255)|0]|0;a[D]=a[5081904+(Xa&255)|0]|0;a[E]=a[5081904+(Ya&255)|0]|0;a[F]=a[5081904+(Za&255)|0]|0;a[G]=a[5081904+(_a&255)|0]|0;a[z]=a[5081904+($a&255)|0]|0;a[C]=a[5081904+(ab&255)|0]|0;a[B]=a[5081904+(bb&255)|0]|0;a[A]=a[5081904+(cb&255)|0]|0;if(!m){va=N|0;ua=N+4|0;ta=c[K+4>>2]^(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24);c[K>>2]=c[K>>2]^(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24);c[K+4>>2]=ta;ta=O|0;va=O+4|0;ua=c[p+4>>2]^(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24);c[p>>2]=c[p>>2]^(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24);c[p+4>>2]=ua;UGb(h|0,i|0,16)|0}ua=c[L+4>>2]^c[K+4>>2];ta=f;va=ta|0;x=c[L>>2]^c[K>>2];a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;va=ta+4|0;x=ua;a[va]=x;x=x>>8;a[va+1|0]=x;x=x>>8;a[va+2|0]=x;x=x>>8;a[va+3|0]=x;va=c[M+4>>2]^c[p+4>>2];ua=f+8|0;ta=ua|0;x=c[M>>2]^c[p>>2];a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;ta=ua+4|0;x=va;a[ta]=x;x=x>>8;a[ta+1|0]=x;x=x>>8;a[ta+2|0]=x;x=x>>8;a[ta+3|0]=x;if((e|0)==0){break}i=i+16|0;f=f+16|0;e=e-1|0}return}while(1){e=c[g>>2]|0;f=P;i=f|0;cb=f+4|0;f=b+(e<<4)|0;bb=c[f>>2]^(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24);i=c[f+4>>2]^(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24);c[k>>2]=bb;c[k+4>>2]=i;cb=P+8|0;f=cb|0;ab=cb+4|0;cb=b+(e<<4)+8|0;$a=c[cb>>2]^(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24);f=c[cb+4>>2]^(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24);c[l>>2]=$a;c[l+4>>2]=f;ab=bb&255;cb=(i>>>8|0<<24)&255;_a=($a>>>16|f<<16)&255;Za=(f>>>24|0<<8)&255;Ya=i&255;Xa=($a>>>8|f<<24)&255;Wa=(f>>>16|0<<16)&255;Va=(bb>>>24|i<<8)&255;Ua=$a&255;Ta=(f>>>8|0<<24)&255;Sa=(bb>>>16|i<<16)&255;Ra=(i>>>24|0<<8)&255;Qa=f&255;Pa=(bb>>>8|i<<24)&255;ta=(i>>>16|0<<16)&255;va=($a>>>24|f<<8)&255;if(m){ua=e-1|0;if((ua|0)>0){sa=ua;ua=ab;ra=cb;qa=_a;pa=Za;oa=Ya;na=Xa;ma=Wa;la=Va;ka=Ua;ja=Ta;ia=Sa;V=Ra;T=Qa;j=Pa;Ga=ta;Ka=va;while(1){c[r>>2]=c[8157128+((ra&255)<<2)>>2]^c[8156104+((ua&255)<<2)>>2]^c[8158152+((qa&255)<<2)>>2]^c[8159176+((pa&255)<<2)>>2];c[s>>2]=c[8157128+((na&255)<<2)>>2]^c[8156104+((oa&255)<<2)>>2]^c[8158152+((ma&255)<<2)>>2]^c[8159176+((la&255)<<2)>>2];c[t>>2]=c[8157128+((ja&255)<<2)>>2]^c[8156104+((ka&255)<<2)>>2]^c[8158152+((ia&255)<<2)>>2]^c[8159176+((V&255)<<2)>>2];c[u>>2]=c[8157128+((j&255)<<2)>>2]^c[8156104+((T&255)<<2)>>2]^c[8158152+((Ga&255)<<2)>>2]^c[8159176+((Ka&255)<<2)>>2];Oa=b+(sa<<4)|0;Ca=c[Oa>>2]^c[o>>2];Aa=c[Oa+4>>2]^c[o+4>>2];c[k>>2]=Ca;c[k+4>>2]=Aa;Oa=b+(sa<<4)+8|0;Ha=c[Oa>>2]^c[p>>2];La=c[Oa+4>>2]^c[p+4>>2];c[l>>2]=Ha;c[l+4>>2]=La;Oa=sa-1|0;Da=Ca&255;za=(Aa>>>8|0<<24)&255;Ma=(Ha>>>16|La<<16)&255;Ia=(La>>>24|0<<8)&255;Ea=Aa&255;Na=(Ha>>>8|La<<24)&255;Ja=(La>>>16|0<<16)&255;Fa=(Ca>>>24|Aa<<8)&255;Ba=Ha&255;wa=(La>>>8|0<<24)&255;ya=(Ca>>>16|Aa<<16)&255;xa=(Aa>>>24|0<<8)&255;db=La&255;eb=(Ca>>>8|Aa<<24)&255;Ca=(Aa>>>16|0<<16)&255;Aa=(Ha>>>24|La<<8)&255;if((Oa|0)>0){sa=Oa;ua=Da;ra=za;qa=Ma;pa=Ia;oa=Ea;na=Na;ma=Ja;la=Fa;ka=Ba;ja=wa;ia=ya;V=xa;T=db;j=eb;Ga=Ca;Ka=Aa}else{fb=Da;gb=Ea;hb=Ba;ib=db;jb=za;kb=Na;lb=wa;mb=eb;nb=Ma;ob=ya;pb=Ja;qb=Ca;rb=Ia;sb=Aa;tb=xa;ub=Fa;break}}}else{fb=ab;gb=Ya;hb=Ua;ib=Qa;jb=cb;kb=Xa;lb=Ta;mb=Pa;nb=_a;ob=Sa;pb=Wa;qb=ta;rb=Za;sb=va;tb=Ra;ub=Va}a[v]=a[4314512+(fb&255)|0]|0;a[n]=a[4314512+(gb&255)|0]|0;a[w]=a[4314512+(hb&255)|0]|0;a[y]=a[4314512+(ib&255)|0]|0;a[z]=a[4314512+(jb&255)|0]|0;a[A]=a[4314512+(kb&255)|0]|0;a[B]=a[4314512+(lb&255)|0]|0;a[C]=a[4314512+(mb&255)|0]|0;a[D]=a[4314512+(nb&255)|0]|0;a[E]=a[4314512+(ob&255)|0]|0;a[F]=a[4314512+(pb&255)|0]|0;a[G]=a[4314512+(qb&255)|0]|0;a[q]=a[4314512+(rb&255)|0]|0;a[H]=a[4314512+(sb&255)|0]|0;a[I]=a[4314512+(tb&255)|0]|0;a[J]=a[4314512+(ub&255)|0]|0;Ka=c[L+4>>2]^c[K+4>>2];Ga=Q;j=Ga|0;x=c[L>>2]^c[K>>2];a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=Ga+4|0;x=Ka;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=c[M+4>>2]^c[p+4>>2];Ka=Q+8|0;Ga=Ka|0;x=c[M>>2]^c[p>>2];a[Ga]=x;x=x>>8;a[Ga+1|0]=x;x=x>>8;a[Ga+2|0]=x;x=x>>8;a[Ga+3|0]=x;Ga=Ka+4|0;x=j;a[Ga]=x;x=x>>8;a[Ga+1|0]=x;x=x>>8;a[Ga+2|0]=x;x=x>>8;a[Ga+3|0]=x}else{Ga=N|0;j=N+4|0;Ka=bb^(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24);Ga=i^(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24);c[k>>2]=Ka;c[k+4>>2]=Ga;j=O|0;T=O+4|0;V=$a^(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24);j=f^(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24);c[l>>2]=V;c[l+4>>2]=j;T=e-1|0;ia=Ka&255;ja=(Ga>>>8|0<<24)&255;ka=(V>>>16|j<<16)&255;la=(j>>>24|0<<8)&255;ma=Ga&255;na=(V>>>8|j<<24)&255;oa=(j>>>16|0<<16)&255;pa=(Ka>>>24|Ga<<8)&255;qa=V&255;ra=(j>>>8|0<<24)&255;ua=(Ka>>>16|Ga<<16)&255;sa=(Ga>>>24|0<<8)&255;$=j&255;da=(Ka>>>8|Ga<<24)&255;Ka=(Ga>>>16|0<<16)&255;Ga=(V>>>24|j<<8)&255;if((T|0)>0){j=T;T=ia;V=ja;ha=ka;U=la;S=ma;aa=na;ea=oa;Y=pa;X=qa;fa=ra;ba=ua;Z=sa;ga=$;ca=da;_=Ka;W=Ga;while(1){c[r>>2]=c[8157128+((V&255)<<2)>>2]^c[8156104+((T&255)<<2)>>2]^c[8158152+((ha&255)<<2)>>2]^c[8159176+((U&255)<<2)>>2];c[s>>2]=c[8157128+((aa&255)<<2)>>2]^c[8156104+((S&255)<<2)>>2]^c[8158152+((ea&255)<<2)>>2]^c[8159176+((Y&255)<<2)>>2];c[t>>2]=c[8157128+((fa&255)<<2)>>2]^c[8156104+((X&255)<<2)>>2]^c[8158152+((ba&255)<<2)>>2]^c[8159176+((Z&255)<<2)>>2];c[u>>2]=c[8157128+((ca&255)<<2)>>2]^c[8156104+((ga&255)<<2)>>2]^c[8158152+((_&255)<<2)>>2]^c[8159176+((W&255)<<2)>>2];Fa=b+(j<<4)|0;xa=c[Fa>>2]^c[o>>2];Aa=c[Fa+4>>2]^c[o+4>>2];c[k>>2]=xa;c[k+4>>2]=Aa;Fa=b+(j<<4)+8|0;Ia=c[Fa>>2]^c[p>>2];Ca=c[Fa+4>>2]^c[p+4>>2];c[l>>2]=Ia;c[l+4>>2]=Ca;Fa=j-1|0;Ja=xa&255;ya=(Aa>>>8|0<<24)&255;Ma=(Ia>>>16|Ca<<16)&255;eb=(Ca>>>24|0<<8)&255;wa=Aa&255;Na=(Ia>>>8|Ca<<24)&255;za=(Ca>>>16|0<<16)&255;db=(xa>>>24|Aa<<8)&255;Ba=Ia&255;Ea=(Ca>>>8|0<<24)&255;Da=(xa>>>16|Aa<<16)&255;Oa=(Aa>>>24|0<<8)&255;La=Ca&255;Ha=(xa>>>8|Aa<<24)&255;xa=(Aa>>>16|0<<16)&255;Aa=(Ia>>>24|Ca<<8)&255;if((Fa|0)>0){j=Fa;T=Ja;V=ya;ha=Ma;U=eb;S=wa;aa=Na;ea=za;Y=db;X=Ba;fa=Ea;ba=Da;Z=Oa;ga=La;ca=Ha;_=xa;W=Aa}else{vb=Ja;wb=wa;xb=Ba;yb=La;zb=ya;Ab=Na;Bb=Ea;Cb=Ha;Db=Ma;Eb=Da;Fb=za;Gb=xa;Hb=eb;Ib=Aa;Jb=Oa;Kb=db;break}}}else{vb=ia;wb=ma;xb=qa;yb=$;zb=ja;Ab=na;Bb=ra;Cb=da;Db=ka;Eb=ua;Fb=oa;Gb=Ka;Hb=la;Ib=Ga;Jb=sa;Kb=pa}a[v]=a[4314512+(vb&255)|0]|0;a[n]=a[4314512+(wb&255)|0]|0;a[w]=a[4314512+(xb&255)|0]|0;a[y]=a[4314512+(yb&255)|0]|0;a[z]=a[4314512+(zb&255)|0]|0;a[A]=a[4314512+(Ab&255)|0]|0;a[B]=a[4314512+(Bb&255)|0]|0;a[C]=a[4314512+(Cb&255)|0]|0;a[D]=a[4314512+(Db&255)|0]|0;a[E]=a[4314512+(Eb&255)|0]|0;a[F]=a[4314512+(Fb&255)|0]|0;a[G]=a[4314512+(Gb&255)|0]|0;a[q]=a[4314512+(Hb&255)|0]|0;a[H]=a[4314512+(Ib&255)|0]|0;a[I]=a[4314512+(Jb&255)|0]|0;a[J]=a[4314512+(Kb&255)|0]|0;W=c[L+4>>2]^c[K+4>>2];_=Q;ca=_|0;x=c[L>>2]^c[K>>2];a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;ca=_+4|0;x=W;a[ca]=x;x=x>>8;a[ca+1|0]=x;x=x>>8;a[ca+2|0]=x;x=x>>8;a[ca+3|0]=x;ca=c[M+4>>2]^c[p+4>>2];W=Q+8|0;_=W|0;x=c[M>>2]^c[p>>2];a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;_=W+4|0;x=ca;a[_]=x;x=x>>8;a[_+1|0]=x;x=x>>8;a[_+2|0]=x;x=x>>8;a[_+3|0]=x;UGb(h|0,Q|0,16)|0}if((R|0)==0){break}P=P+16|0;Q=Q+16|0;R=R-1|0}return}function hAb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+848|0;j=h|0;k=h+32|0;l=h+288|0;m=h+800|0;n=h+816|0;o=h+832|0;p=f>>5;q=p+6|0;if((c[2040049]|0)==0){r=1;s=0;while(1){t=r&255;a[l+(s+255)|0]=t;a[l+s|0]=t;a[k+r|0]=s;t=r<<1^r;u=s+1|0;if((u|0)<255){r=(t|0)>255?t^283:t;s=u}else{v=0;break}}do{if((v|0)==0){w=0}else{w=d[l+((d[k+v|0]|0)^255)|0]|0}s=w<<2^w^w<<1^w<<3^w<<4;r=(s>>>8^s)&255^99;a[5081904+r|0]=v;a[4314512+v|0]=r;v=v+1|0;}while((v|0)<256);v=m|0;c[v>>2]=14;c[m+4>>2]=9;c[m+8>>2]=13;c[m+12>>2]=11;m=k|0;k=l|0;iAb(8648296,v,m,k,5081904);v=n|0;c[v>>2]=2;c[n+4>>2]=1;c[n+8>>2]=1;c[n+12>>2]=3;iAb(8156104,v,m,k,4314512)}if(!((f|0)==256|(f|0)==192|(f|0)==128)){x=-1;i=h;return x|0}c[b+272>>2]=q;k=j|0;m=p<<2;UGb(k|0,e|0,m)|0;v=b;UGb(v|0,e|0,m)|0;e=p+7|0;n=e<<4;if((m|0)<(n|0)){l=p-1|0;w=(p|0)>1;r=(p|0)==8;s=f>>6;f=m;u=0;while(1){t=a[k]^a[4314512+(d[j+(l<<2)+1|0]|0)|0];a[k]=t;y=j+1|0;a[y]=a[y]^a[4314512+(d[j+(l<<2)+2|0]|0)|0];y=j+2|0;a[y]=a[y]^a[4314512+(d[j+(l<<2)+3|0]|0)|0];y=j+3|0;a[y]=a[y]^a[4314512+(d[j+(l<<2)|0]|0)|0];y=u+1|0;a[k]=t^a[549280+u|0];if(w){t=1;do{if(r&(t|0)==(s|0)){z=s-1|0;A=j+(s<<2)|0;a[A]=a[A]^a[4314512+(d[j+(z<<2)|0]|0)|0];A=j+(s<<2)+1|0;a[A]=a[A]^a[4314512+(d[j+(z<<2)+1|0]|0)|0];A=j+(s<<2)+2|0;a[A]=a[A]^a[4314512+(d[j+(z<<2)+2|0]|0)|0];A=j+(s<<2)+3|0;a[A]=a[A]^a[4314512+(d[j+(z<<2)+3|0]|0)|0]}else{z=t-1|0;A=j+(t<<2)|0;a[A]=a[A]^a[j+(z<<2)|0];A=j+(t<<2)+1|0;a[A]=a[A]^a[j+(z<<2)+1|0];A=j+(t<<2)+2|0;a[A]=a[A]^a[j+(z<<2)+2|0];A=j+(t<<2)+3|0;a[A]=a[A]^a[j+(z<<2)+3|0]}t=t+1|0;}while((t|0)<(p|0))}UGb(v+f|0,k|0,m)|0;t=f+m|0;if((t|0)<(n|0)){f=t;u=y}else{break}}}if((g|0)!=0){if((q|0)>1){B=1}else{x=0;i=h;return x|0}while(1){g=b+(B<<4)|0;u=g;f=u+4|0;n=b+(B<<4)+8|0;m=u+12|0;k=c[8649320+((d[4314512+(d[u+5|0]|0)|0]|0)<<2)>>2]^c[8648296+((d[4314512+(d[f]|0)|0]|0)<<2)>>2]^c[8650344+((d[4314512+(d[u+6|0]|0)|0]|0)<<2)>>2]^c[8651368+((d[4314512+(d[u+7|0]|0)|0]|0)<<2)>>2];v=c[8649320+((d[4314512+(d[u+9|0]|0)|0]|0)<<2)>>2]^c[8648296+((d[4314512+(d[n]|0)|0]|0)<<2)>>2]^c[8650344+((d[4314512+(d[u+10|0]|0)|0]|0)<<2)>>2]^c[8651368+((d[4314512+(d[u+11|0]|0)|0]|0)<<2)>>2];p=c[8649320+((d[4314512+(d[u+13|0]|0)|0]|0)<<2)>>2]^c[8648296+((d[4314512+(d[m]|0)|0]|0)<<2)>>2]^c[8650344+((d[4314512+(d[u+14|0]|0)|0]|0)<<2)>>2]^c[8651368+((d[4314512+(d[u+15|0]|0)|0]|0)<<2)>>2];c[g>>2]=c[8649320+((d[4314512+(d[u+1|0]|0)|0]|0)<<2)>>2]^c[8648296+((d[4314512+(d[u]|0)|0]|0)<<2)>>2]^c[8650344+((d[4314512+(d[u+2|0]|0)|0]|0)<<2)>>2]^c[8651368+((d[4314512+(d[u+3|0]|0)|0]|0)<<2)>>2];c[f>>2]=k;c[n>>2]=v;c[m>>2]=p;p=B+1|0;if((p|0)<(q|0)){B=p}else{x=0;break}}i=h;return x|0}B=e>>1;if((B|0)<=0){x=0;i=h;return x|0}e=o;o=0;while(1){p=b+(q-o<<4)|0;c[e>>2]=c[p>>2];c[e+4>>2]=c[p+4>>2];c[e+8>>2]=c[p+8>>2];c[e+12>>2]=c[p+12>>2];m=b+(o<<4)|0;c[p>>2]=c[m>>2];c[p+4>>2]=c[m+4>>2];c[p+8>>2]=c[m+8>>2];c[p+12>>2]=c[m+12>>2];c[m>>2]=c[e>>2];c[m+4>>2]=c[e+4>>2];c[m+8>>2]=c[e+8>>2];c[m+12>>2]=c[e+12>>2];m=o+1|0;if((m|0)<(B|0)){o=m}else{x=0;break}}i=h;return x|0}function iAb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=e+4|0;j=e+8|0;k=e+12|0;l=0;do{m=a[h+l|0]|0;if(!(m<<24>>24==0)){n=d[f+(m&255)|0]|0;m=d[g+((d[f+(c[e>>2]|0)|0]|0)+n)|0]|0;o=d[g+((d[f+(c[k>>2]|0)|0]|0)+n)|0]|0;p=(d[g+((d[f+(c[i>>2]|0)|0]|0)+n)|0]|0)<<8|m;q=p|(d[g+((d[f+(c[j>>2]|0)|0]|0)+n)|0]|0)<<16;n=o<<24|q;c[b+(l<<2)>>2]=n;c[b+1024+(l<<2)>>2]=q<<8|o;c[b+2048+(l<<2)>>2]=p<<16|n>>>16;c[b+3072+(l<<2)>>2]=m<<24|n>>>8}l=l+1|0;}while((l|0)<256);return}function jAb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)==0){return}b=a|0;d=c[b>>2]|0;if((d|0)!=0){e=a+4|0;f=c[e>>2]|0;if((f|0)>0){g=0;h=d;i=f;while(1){f=c[h+(g<<2)>>2]|0;if((f|0)==0){j=i;k=h}else{VBb(f);j=c[e>>2]|0;k=c[b>>2]|0}f=g+1|0;if((f|0)<(j|0)){g=f;h=k;i=j}else{l=k;break}}}else{l=d}ZDb(l)}ZDb(a);return}function kAb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+8|0;f=e|0;if((DFb(f,b,d,a,1)|0)<0){g=0;i=e;return g|0}h=cEb(28)|0;j=h;if((h|0)==0){g=0;i=e;return g|0}c[h+16>>2]=b;c[h+20>>2]=a;c[h+24>>2]=(c[f>>2]|0)/(d|0)|0;k=(CFb(a)|0)!=0;a=k?b:1;b=h+4|0;c[b>>2]=a;k=cEb(a<<2)|0;a=k;l=h;c[l>>2]=a;a:do{if((k|0)==0){m=a}else{n=0;while(1){if((n|0)>=(c[b>>2]|0)){break}o=UBb(c[f>>2]|0)|0;c[(c[l>>2]|0)+(n<<2)>>2]=o;o=c[l>>2]|0;if((c[o+(n<<2)>>2]|0)==0){m=o;break a}else{n=n+1|0}}c[h+12>>2]=d;g=j;i=e;return g|0}}while(0);if((m|0)!=0){j=c[b>>2]|0;if((j|0)>0){d=0;f=m;a=j;while(1){j=c[f+(d<<2)>>2]|0;if((j|0)==0){p=a;q=f}else{VBb(j);p=c[b>>2]|0;q=c[l>>2]|0}j=d+1|0;if((j|0)<(p|0)){d=j;f=q;a=p}else{r=q;break}}}else{r=m}ZDb(r)}ZDb(h);g=0;i=e;return g|0}function lAb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=DFb(e,c[a+16>>2]|0,b,c[a+20>>2]|0,1)|0;if((f|0)<0){g=f;i=d;return g|0}f=a+4|0;h=a|0;j=0;while(1){if((j|0)>=(c[f>>2]|0)){break}k=YBb(c[(c[h>>2]|0)+(j<<2)>>2]|0,c[e>>2]|0)|0;if((k|0)<0){g=k;l=6;break}else{j=j+1|0}}if((l|0)==6){i=d;return g|0}c[a+12>>2]=b;g=0;i=d;return g|0}function mAb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=a+12|0;h=a+8|0;j=c[h>>2]|0;do{if(((c[g>>2]|0)-j|0)<(d|0)){if((1073741823-j|0)<(d|0)){k=-22;i=e;return k|0}l=j+d<<1;m=DFb(f,c[a+16>>2]|0,l,c[a+20>>2]|0,1)|0;if((m|0)<0){k=m;i=e;return k|0}m=a+4|0;n=a|0;o=0;while(1){if((o|0)>=(c[m>>2]|0)){p=8;break}q=YBb(c[(c[n>>2]|0)+(o<<2)>>2]|0,c[f>>2]|0)|0;if((q|0)<0){k=q;p=14;break}else{o=o+1|0}}if((p|0)==8){c[g>>2]=l;r=m;s=n;break}else if((p|0)==14){i=e;return k|0}}else{r=a+4|0;s=a|0}}while(0);g=ba(c[a+24>>2]|0,d)|0;a=0;while(1){if((a|0)>=(c[r>>2]|0)){break}if((_Bb(c[(c[s>>2]|0)+(a<<2)>>2]|0,c[b+(a<<2)>>2]|0,g,0)|0)!=(g|0)){k=-558323010;p=14;break}a=a+1|0}if((p|0)==14){i=e;return k|0}c[h>>2]=(c[h>>2]|0)+d;k=d;i=e;return k|0}function nAb(a){a=a|0;return(c[a+12>>2]|0)-(c[a+8>>2]|0)|0}function oAb(a){a=a|0;return c[a+8>>2]|0}function pAb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((d|0)<0){e=-22;return e|0}f=a+8|0;g=c[f>>2]|0;h=(g|0)<(d|0)?g:d;if((h|0)==0){e=0;return e|0}d=ba(c[a+24>>2]|0,h)|0;g=a+4|0;i=a|0;a=0;while(1){if((a|0)>=(c[g>>2]|0)){break}if((ZBb(c[(c[i>>2]|0)+(a<<2)>>2]|0,c[b+(a<<2)>>2]|0,d,0)|0)<0){e=-558323010;j=7;break}else{a=a+1|0}}if((j|0)==7){return e|0}c[f>>2]=(c[f>>2]|0)-h;e=h;return e|0}function qAb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=a[d]|0;a:do{if(f<<24>>24==0){g=d;h=b;i=4}else{j=d;k=b;l=f;while(1){if(!(l<<24>>24==(a[k]|0))){m=l;break a}n=j+1|0;o=k+1|0;p=a[n]|0;if(p<<24>>24==0){g=n;h=o;i=4;break}else{j=n;k=o;l=p}}}}while(0);do{if((i|0)==4){if((e|0)==0){m=0;break}c[e>>2]=h;m=a[g]|0}}while(0);return m<<24>>24==0|0}function rAb(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=a[c]|0;if(d<<24>>24==0){e=b;return e|0}else{f=b}a:while(1){b=c;g=f;h=d;while(1){i=h<<24>>24;j=a[g]|0;if((((i-97|0)>>>0<26>>>0?i^32:i)|0)!=(((j-97|0)>>>0<26>>>0?j^32:j)|0)){break}j=b+1|0;i=a[j]|0;if(i<<24>>24==0){e=f;k=8;break a}else{b=j;g=g+1|0;h=i}}if(h<<24>>24==0){e=f;k=8;break}if((a[f]|0)==0){e=0;k=8;break}f=f+1|0}if((k|0)==8){return e|0}return 0}function sAb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:do{if(d>>>0>1>>>0){e=c;f=b;g=1;while(1){h=a[e]|0;if(h<<24>>24==0){i=e;j=f;k=g;break a}l=e+1|0;m=f+1|0;a[f]=h;h=g+1|0;if(h>>>0<d>>>0){e=l;f=m;g=h}else{i=l;j=m;k=h;break}}}else{i=c;j=b;k=1}}while(0);if(!(k>>>0>d>>>0)){a[j]=0}return k-1+(SGb(i|0)|0)|0}function tAb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=SGb(b|0)|0;if(!((e+1|0)>>>0<d>>>0)){f=SGb(c|0)|0;g=f+e|0;return g|0}h=b+e|0;b=d-e|0;a:do{if(b>>>0>1>>>0){d=c;i=h;j=1;while(1){k=a[d]|0;if(k<<24>>24==0){l=d;m=i;n=j;break a}o=d+1|0;p=i+1|0;a[i]=k;k=j+1|0;if(k>>>0<b>>>0){d=o;i=p;j=k}else{l=o;m=p;n=k;break}}}else{l=c;m=h;n=1}}while(0);if(!(n>>>0>b>>>0)){a[m]=0}f=n-1+(SGb(l|0)|0)|0;g=f+e|0;return g|0}function uAb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f|0;h=SGb(a|0)|0;j=g;c[j>>2]=e;c[j+4>>2]=0;j=(wd(a+h|0,(h>>>0<b>>>0?b-h|0:0)|0,d|0,g|0)|0)+h|0;i=f;return j|0}function vAb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+24|0;e=d|0;f=d+8|0;c[e>>2]=0;g=f|0;h=f;c[h>>2]=b;c[h+4>>2]=0;f=wd(0,0,a|0,g|0)|0;do{if((f|0)>=0){j=f+1|0;k=WDb(j)|0;c[e>>2]=k;if((k|0)==0){break}c[h>>2]=b;c[h+4>>2]=0;if((wd(k|0,j|0,a|0,g|0)|0)>=0){break}$Db(e)}}while(0);i=d;return c[e>>2]|0}function wAb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=WDb((SGb(c[b>>2]|0)|0)+1|0)|0;f=c[b>>2]|0;if((e|0)==0){g=0;return g|0}h=f+(qd(f|0,2301712)|0)|0;f=a[h]|0;a:do{if(f<<24>>24==0){i=e;j=h;k=e}else{l=e;m=e;n=h;o=f;while(1){p=l;q=n;r=o;while(1){if((qd(q|0,d|0)|0)!=0){i=p;j=q;k=m;break a}s=q+1|0;if((r<<24>>24|0)==39){t=7;break}else if((r<<24>>24|0)==92){u=a[s]|0;if(!(u<<24>>24==0)){t=9;break}}v=p+1|0;a[p]=r;w=a[s]|0;if(w<<24>>24==0){i=v;j=s;k=m;break a}else{p=v;q=s;r=w}}if((t|0)==7){t=0;r=a[s]|0;w=r<<24>>24==0;v=q+2|0;if(r<<24>>24!=39&(w^1)){x=p;y=r;r=v;while(1){z=x+1|0;a[x]=y;A=a[r]|0;B=A<<24>>24==0;C=r+1|0;if(A<<24>>24!=39&(B^1)){x=z;y=A;r=C}else{D=z;E=r;F=B;G=C;break}}}else{D=p;E=s;F=w;G=v}H=F?E:G;I=F?m:D;J=D}else if((t|0)==9){t=0;r=p+1|0;a[p]=u;H=q+2|0;I=r;J=r}r=a[H]|0;if(r<<24>>24==0){i=J;j=H;k=I;break}else{l=J;m=I;n=H;o=r}}}}while(0);H=i;while(1){i=H-1|0;a[H]=0;if(i>>>0<k>>>0){break}if((qd(i|0,2301712)|0)==0){break}else{H=i}}c[b>>2]=j;g=e;return g|0}function xAb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;do{if((b|0)==0){f=c[e>>2]|0;if((f|0)==0){g=0}else{h=f;break}return g|0}else{h=b}}while(0);b=qd(h|0,d|0)|0;f=h+b|0;if((a[f]|0)==0){c[e>>2]=0;g=0;return g|0}i=b+1|0;b=(hc(h+i|0,d|0)|0)+i|0;i=h+b|0;if((a[i]|0)==0){j=0}else{a[i]=0;j=h+(b+1)|0}c[e>>2]=j;g=f;return g|0}function yAb(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b;b=c;while(1){c=a[d]|0;e=a[b]|0;f=(e-65|0)>>>0<26>>>0?e^32:e;e=((c-65|0)>>>0<26>>>0?c^32:c)&255;if((e|0)==0){break}c=f&255;if((e|0)==(c|0)){d=d+1|0;b=b+1|0}else{g=e;h=c;i=5;break}}if((i|0)==5){j=g-h|0;return j|0}g=0;h=f&255;j=g-h|0;return j|0}function zAb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+d|0;d=b;b=c;while(1){c=d+1|0;f=a[d]|0;g=a[b]|0;h=(g-65|0)>>>0<26>>>0?g^32:g;g=((f-65|0)>>>0<26>>>0?f^32:f)&255;if(!(c>>>0<e>>>0)){i=g;break}if((g|0)==0){i=0;break}if((g|0)==(h&255|0)){d=c;b=b+1|0}else{i=g;break}}return i-(h&255)|0}function AAb(a){a=a|0;var b=0;b=cc(a|0,47)|0;return((b|0)==0?a:b+1|0)|0}function BAb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+1024|0;h=g|0;IAb(h,1,-1);RAb(h,b,d,e,f);f=h+4|0;if((c[f>>2]|0)>>>0<(c[h+8>>2]|0)>>>0){QAb(h,a)|0;j=c[f>>2]|0;i=g;return j|0}else{QAb(h,0)|0;j=-12;i=g;return j|0}return 0}function CAb(a){a=a|0;var b=0;if((a|0)>47){b=(a|0)<58|0}else{b=0}return b|0}function DAb(a){a=a|0;var b=0;if((a|0)>32){b=(a|0)<127|0}else{b=0}return b|0}function EAb(a){a=a|0;var b=0;switch(a|0){case 32:case 13:case 12:case 10:case 9:{b=1;break};default:{b=(a|0)==11|0}}return b|0}function FAb(a){a=a|0;var b=0,c=0;b=(a-65|0)>>>0<26>>>0?a^32:a;do{if((b|0)>47){if((b|0)<58){c=1;break}if((b|0)<=96){c=0;break}c=(b|0)<103|0}else{c=0}}while(0);return c|0}function GAb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=b+e|0;g=f;a:do{if((e|0)>3){h=b;i=c;while(1){j=d[684912+(d[i]|0)|0]|0;if((j&128|0)!=0){k=j;l=h;break a}m=d[684912+(d[i+1|0]|0)|0]|0;if((m&128|0)!=0){k=m;l=h;break a}n=m+(j<<6)|0;o=d[684912+(d[i+2|0]|0)|0]|0;if((o&128|0)!=0){p=24;break}q=o+(n<<6)|0;r=d[684912+(d[i+3|0]|0)|0]|0;if((r&128|0)!=0){p=22;break}j=h;x=fe(r+(q<<6)<<8|0)|0;a[j]=x;x=x>>8;a[j+1|0]=x;x=x>>8;a[j+2|0]=x;x=x>>8;a[j+3|0]=x;j=h+3|0;m=i+4|0;if((g-j|0)>3){h=j;i=m}else{s=j;t=m;p=7;break a}}if((p|0)==22){u=q>>>10&255;v=q>>>2&255;w=r;y=h;p=23;break}else if((p|0)==24){z=n>>>4&255;A=o;B=h;p=25;break}}else{s=b;t=c;p=7}}while(0);b:do{if((p|0)==7){if((f|0)==(s|0)){C=t;D=f}else{c=d[684912+(d[t]|0)|0]|0;if((c&128|0)!=0){k=c;l=s;break}o=d[684912+(d[t+1|0]|0)|0]|0;if((o&128|0)!=0){k=o;l=s;break}n=o+(c<<6)|0;c=d[684912+(d[t+2|0]|0)|0]|0;if((c&128|0)!=0){z=n>>>4&255;A=c;B=s;p=25;break}o=c+(n<<6)|0;n=d[684912+(d[t+3|0]|0)|0]|0;if((n&128|0)!=0){u=o>>>10&255;v=o>>>2&255;w=n;y=s;p=23;break}c=n+(o<<6)|0;o=s+1|0;a[s]=c>>>16;if((f|0)==(o|0)){E=f}else{a[o]=c>>>8;E=s+2|0}if((f|0)==(E|0)){F=f}else{a[E]=c;F=E+1|0}C=t+4|0;D=F}c=C;while(1){o=d[684912+(d[c]|0)|0]|0;if((o&128|0)!=0){k=o;l=D;break b}o=d[684912+(d[c+1|0]|0)|0]|0;if((o&128|0)!=0){k=o;l=D;break b}o=d[684912+(d[c+2|0]|0)|0]|0;if((o&128|0)!=0){k=o;l=D;break b}o=d[684912+(d[c+3|0]|0)|0]|0;if((o&128|0)==0){c=c+4|0}else{k=o;l=D;break}}}}while(0);if((p|0)==23){a[y]=u;z=v;A=w;B=y+1|0;p=25}if((p|0)==25){a[B]=z;k=A;l=B+1|0}if((k&1|0)!=0){G=-1094995529;return G|0}G=l-b|0;return G|0}function HAb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if(f>>>0>1073741822>>>0){g=0;return g|0}if((((f+2|0)/3|0)<<2|1|0)>(c|0)){g=0;return g|0}if((f|0)>3){c=((f-4|0)>>>0)/3|0;h=b+((c<<2)+4)|0;i=c*3|0;c=i+3|0;j=e;k=b;l=f;while(1){m=j;n=fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;m=l-3|0;a[k]=a[1781544+(n>>>26)|0]|0;a[k+1|0]=a[1781544+(n>>>20&63)|0]|0;a[k+2|0]=a[1781544+(n>>>14&63)|0]|0;a[k+3|0]=a[1781544+(n>>>8&63)|0]|0;if((m|0)>3){j=j+3|0;k=k+4|0;l=m}else{break}}o=e+c|0;p=h;q=f-3-i|0}else{o=e;p=b;q=f}do{if((q|0)==0){r=p}else{f=o;e=0;i=q;while(1){s=d[f]|0|e<<8;h=i-1|0;if((h|0)==0){break}else{f=f+1|0;e=s;i=h}}i=q<<3;e=s<<6;if((i|0)<=0){r=p;break}f=(((i-1|0)>>>0)/6|0)+1|0;h=p;c=i;while(1){a[h]=a[1781544+(e>>>(c>>>0)&63)|0]|0;i=c-6|0;if((i|0)>0){h=h+1|0;c=i}else{break}}r=p+f|0}}while(0);p=b;if((r-p&3|0)==0){t=r}else{s=r;while(1){r=s+1|0;a[s]=61;if((r-p&3|0)==0){t=r;break}else{s=r}}}a[t]=0;g=b;return g|0}function IAb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b+16|0;g=(e|0)==1?1008:e;e=b|0;c[e>>2]=f;h=b+4|0;c[h>>2]=0;i=g>>>0<1008>>>0?g:1008;j=b+8|0;c[j>>2]=i;c[b+12>>2]=g;a[f]=0;if(!(i>>>0<d>>>0)){return}if((i|0)==(g|0)|(i|0)==0){return}f=(d-1|0)>>>0<4294967294>>>0?d:-1;d=i>>>0>g>>>1>>>0?g:i<<1;if(d>>>0<f>>>0){k=g>>>0>f>>>0?f:g}else{k=d}d=XDb(0,k)|0;if((d|0)==0){return}UGb(d|0,c[e>>2]|0,(c[h>>2]|0)+1|0)|0;c[e>>2]=d;c[j>>2]=k;return}function JAb(b,d,e){b=b|0;d=d|0;e=e|0;c[b>>2]=d;c[b+4>>2]=0;c[b+8>>2]=e;c[b+12>>2]=e;a[d]=0;return}function KAb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+16|0;g=f|0;h=b+8|0;j=b+4|0;k=g|0;l=g;g=b+12|0;m=b|0;n=b+16|0;b=c[h>>2]|0;while(1){o=c[j>>2]|0;p=o>>>0>b>>>0?b:o;q=b-p|0;if((b|0)==(p|0)){r=0}else{r=(c[m>>2]|0)+o|0}c[l>>2]=e;c[l+4>>2]=0;s=wd(r|0,q|0,d|0,k|0)|0;if((s|0)<1){t=16;break}if(s>>>0<q>>>0){break}q=c[h>>2]|0;o=c[g>>2]|0;if((q|0)==(o|0)){break}p=c[j>>2]|0;if(!(p>>>0<q>>>0)){break}u=-2-p|0;v=p+1+(u>>>0>s>>>0?s:u)|0;u=q>>>0>o>>>1>>>0?o:q<<1;if(u>>>0<v>>>0){w=o>>>0>v>>>0?v:o}else{w=u}u=c[m>>2]|0;o=(u|0)==(n|0)?0:u;u=XDb(o,w)|0;if((u|0)==0){break}if((o|0)==0){UGb(u|0,c[m>>2]|0,(c[j>>2]|0)+1|0)|0}c[m>>2]=u;c[h>>2]=w;b=w}if((t|0)==16){i=f;return}t=c[j>>2]|0;w=-6-t|0;b=(w>>>0<s>>>0?w:s)+t|0;c[j>>2]=b;j=c[h>>2]|0;if((j|0)==0){i=f;return}h=j-1|0;a[(c[m>>2]|0)+(b>>>0>h>>>0?h:b)|0]=0;i=f;return}function LAb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+16|0;g=f|0;h=b+8|0;j=b+4|0;k=g|0;l=g;g=e;e=b+12|0;m=b|0;n=b+16|0;b=c[h>>2]|0;while(1){o=c[j>>2]|0;p=o>>>0>b>>>0?b:o;q=b-p|0;if((b|0)==(p|0)){r=0}else{r=(c[m>>2]|0)+o|0}Fc(l|0,g|0);s=wd(r|0,q|0,d|0,k|0)|0;if((s|0)<1){t=16;break}if(s>>>0<q>>>0){break}q=c[h>>2]|0;o=c[e>>2]|0;if((q|0)==(o|0)){break}p=c[j>>2]|0;if(!(p>>>0<q>>>0)){break}u=-2-p|0;v=p+1+(u>>>0>s>>>0?s:u)|0;u=q>>>0>o>>>1>>>0?o:q<<1;if(u>>>0<v>>>0){w=o>>>0>v>>>0?v:o}else{w=u}u=c[m>>2]|0;o=(u|0)==(n|0)?0:u;u=XDb(o,w)|0;if((u|0)==0){break}if((o|0)==0){UGb(u|0,c[m>>2]|0,(c[j>>2]|0)+1|0)|0}c[m>>2]=u;c[h>>2]=w;b=w}if((t|0)==16){i=f;return}t=c[j>>2]|0;w=-6-t|0;b=(w>>>0<s>>>0?w:s)+t|0;c[j>>2]=b;j=c[h>>2]|0;if((j|0)==0){i=f;return}h=j-1|0;a[(c[m>>2]|0)+(b>>>0>h>>>0?h:b)|0]=0;i=f;return}function MAb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=b+12|0;g=b+4|0;h=b+8|0;i=c[h>>2]|0;j=c[g>>2]|0;k=j>>>0>i>>>0?i:j;l=i-k|0;a:do{if(l>>>0>e>>>0){m=i;n=k;o=l}else{p=b|0;q=b+16|0;r=i;s=k;t=l;u=j;while(1){v=c[f>>2]|0;if(!((r|0)!=(v|0)&u>>>0<r>>>0)){m=r;n=s;o=t;break a}w=-2-u|0;x=u+1+(w>>>0>e>>>0?e:w)|0;w=r>>>0>v>>>1>>>0?v:r<<1;if(w>>>0<x>>>0){y=v>>>0>x>>>0?x:v}else{y=w}w=c[p>>2]|0;v=(w|0)==(q|0)?0:w;w=XDb(v,y)|0;if((w|0)==0){m=r;n=s;o=t;break a}if((v|0)==0){UGb(w|0,c[p>>2]|0,(c[g>>2]|0)+1|0)|0}c[p>>2]=w;c[h>>2]=y;w=c[g>>2]|0;v=w>>>0>y>>>0?y:w;x=y-v|0;if(x>>>0>e>>>0){m=y;n=v;o=x;break}else{r=y;s=v;t=x;u=w}}}}while(0);if((m|0)!=(n|0)){n=o-1|0;TGb((c[b>>2]|0)+(c[g>>2]|0)|0,d|0,(n>>>0<e>>>0?n:e)|0)|0}n=c[g>>2]|0;d=-6-n|0;o=(d>>>0<e>>>0?d:e)+n|0;c[g>>2]=o;g=c[h>>2]|0;if((g|0)==0){return}h=g-1|0;a[(c[b>>2]|0)+(o>>>0>h>>>0?h:o)|0]=0;return}function NAb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=b+12|0;g=b+4|0;h=b+8|0;i=c[h>>2]|0;j=c[g>>2]|0;k=j>>>0>i>>>0?i:j;l=i-k|0;a:do{if(l>>>0>e>>>0){m=i;n=k;o=l}else{p=b|0;q=b+16|0;r=i;s=k;t=l;u=j;while(1){v=c[f>>2]|0;if(!((r|0)!=(v|0)&u>>>0<r>>>0)){m=r;n=s;o=t;break a}w=-2-u|0;x=u+1+(w>>>0>e>>>0?e:w)|0;w=r>>>0>v>>>1>>>0?v:r<<1;if(w>>>0<x>>>0){y=v>>>0>x>>>0?x:v}else{y=w}w=c[p>>2]|0;v=(w|0)==(q|0)?0:w;w=XDb(v,y)|0;if((w|0)==0){m=r;n=s;o=t;break a}if((v|0)==0){UGb(w|0,c[p>>2]|0,(c[g>>2]|0)+1|0)|0}c[p>>2]=w;c[h>>2]=y;w=c[g>>2]|0;v=w>>>0>y>>>0?y:w;x=y-v|0;if(x>>>0>e>>>0){m=y;n=v;o=x;break}else{r=y;s=v;t=x;u=w}}}}while(0);if((m|0)!=(n|0)){n=o-1|0;UGb((c[b>>2]|0)+(c[g>>2]|0)|0,d|0,n>>>0<e>>>0?n:e)|0}n=c[g>>2]|0;d=-6-n|0;o=(d>>>0<e>>>0?d:e)+n|0;c[g>>2]=o;g=c[h>>2]|0;if((g|0)==0){return}h=g-1|0;a[(c[b>>2]|0)+(o>>>0>h>>>0?h:o)|0]=0;return}function OAb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=a+8|0;g=c[f>>2]|0;h=a+4|0;i=c[h>>2]|0;do{if((g-(i>>>0>g>>>0?g:i)|0)>>>0<b>>>0){j=c[a+12>>2]|0;if(!((g|0)!=(j|0)&i>>>0<g>>>0)){k=g;break}l=-2-i|0;m=i+1+(l>>>0>b>>>0?b:l)|0;l=g>>>0>j>>>1>>>0?j:g<<1;if(l>>>0<m>>>0){n=j>>>0>m>>>0?m:j}else{n=l}l=a|0;j=c[l>>2]|0;m=(j|0)==(a+16|0)?0:j;j=XDb(m,n)|0;if((j|0)==0){k=c[f>>2]|0;break}if((m|0)==0){UGb(j|0,c[l>>2]|0,(c[h>>2]|0)+1|0)|0}c[l>>2]=j;c[f>>2]=n;k=n}else{k=g}}while(0);g=c[h>>2]|0;n=g>>>0>k>>>0?k:g;c[e>>2]=k-n;if((k|0)==(n|0)){o=0;c[d>>2]=o;return}o=(c[a>>2]|0)+(c[h>>2]|0)|0;c[d>>2]=o;return}function PAb(b){b=b|0;var d=0;d=b+4|0;if((c[d>>2]|0)==0){return}a[c[b>>2]|0]=0;c[d>>2]=0;return}function QAb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(c[a+4>>2]|0)+1|0;e=a+8|0;f=c[e>>2]|0;g=d>>>0>f>>>0?f:d;d=a|0;f=c[d>>2]|0;h=(f|0)!=(a+16|0);if((b|0)==0){if(!h){i=0;c[e>>2]=g;return i|0}$Db(a);i=0;c[e>>2]=g;return i|0}do{if(h){a=XDb(f,g)|0;if((a|0)==0){j=c[d>>2]|0}else{j=a}c[d>>2]=0;k=0;l=j}else{a=WDb(g)|0;if((a|0)==0){k=-12;l=0;break}UGb(a|0,c[d>>2]|0,g)|0;k=0;l=a}}while(0);c[b>>2]=l;i=k;c[e>>2]=g;return i|0}function RAb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;if((f|0)==2){MAb(b,39,1);f=d;while(1){j=a[f]|0;if((j<<24>>24|0)==39){KAb(b,2301672,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k}else if((j<<24>>24|0)==0){break}else{MAb(b,j,1)}f=f+1|0}MAb(b,39,1);i=h;return}f=a[d]|0;if(f<<24>>24==0){i=h;return}j=(g&2|0)==0;k=(g&1|0)!=0;if((e|0)==0){g=d;l=f;do{if((g|0)==(d|0)){m=0}else{m=(a[g+1|0]|0)!=0}n=l<<24>>24;o=Ib(2172080,n|0,4)|0;p=(Ib(2097704,n|0,3)|0)!=0;n=(o|0)==0;do{if(j){if((m|n)&((p|n?p:k)^1)){q=l;break}MAb(b,92,1);q=a[g]|0}else{q=l}}while(0);MAb(b,q,1);g=g+1|0;l=a[g]|0;}while(!(l<<24>>24==0));i=h;return}if(j){r=d;s=f}else{j=d;l=f;do{if((Vb(e|0,l<<24>>24|0)|0)==0){t=l}else{MAb(b,92,1);t=a[j]|0}MAb(b,t,1);j=j+1|0;l=a[j]|0;}while(!(l<<24>>24==0));i=h;return}do{if((r|0)==(d|0)){u=0}else{u=(a[r+1|0]|0)!=0}l=s<<24>>24;do{if((Vb(e|0,l|0)|0)==0){j=Ib(2172080,l|0,4)|0;t=(Ib(2097704,l|0,3)|0)!=0;f=(j|0)==0;if(t|f){if((u|f)&(t^1)){v=s;break}else{w=17;break}}else{if((u|f)&(k^1)){v=s;break}else{w=17;break}}}else{w=17}}while(0);if((w|0)==17){w=0;MAb(b,92,1);v=a[r]|0}MAb(b,v,1);r=r+1|0;s=a[r]|0;}while(!(s<<24>>24==0));i=h;return}function SAb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+8|0;h=g|0;j=cEb(24)|0;c[h>>2]=j;if((j|0)==0){k=0;i=g;return k|0}c[j>>2]=a;c[j+4>>2]=b;c[j+12>>2]=(d|0)!=0?d:98;c[j+16>>2]=e;c[j+8>>2]=1;if((f&1|0)!=0){f=(c[h>>2]|0)+20|0;c[f>>2]=c[f>>2]|1}f=cEb(12)|0;if((f|0)==0){$Db(h);k=0;i=g;return k|0}else{c[f>>2]=c[h>>2];c[f+4>>2]=a;c[f+8>>2]=b;k=f;i=g;return k|0}return 0}function TAb(a,b){a=a|0;b=b|0;ZDb(b);return}function UAb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=WDb(a)|0;c[e>>2]=f;if((f|0)==0){g=0;i=b;return g|0}h=d;j=cEb(24)|0;c[d>>2]=j;do{if((j|0)!=0){c[j>>2]=f;c[j+4>>2]=a;c[j+12>>2]=98;c[j+16>>2]=0;c[j+8>>2]=1;k=cEb(12)|0;if((k|0)==0){$Db(h);break}c[k>>2]=c[d>>2];c[k+4>>2]=f;c[k+8>>2]=a;g=k;i=b;return g|0}}while(0);$Db(e);g=0;i=b;return g|0}function VAb(a){a=a|0;var b=0,d=0;b=UAb(a)|0;if((b|0)==0){d=0;return d|0}TGb(c[b+4>>2]|0,0,a|0)|0;d=b;return d|0}function WAb(a){a=a|0;var b=0,d=0,e=0;b=cEb(12)|0;if((b|0)==0){d=0;return d|0}e=a;c[b>>2]=c[e>>2];c[b+4>>2]=c[e+4>>2];c[b+8>>2]=c[e+8>>2];e=(c[a>>2]|0)+8|0;D=c[e>>2]|0,c[e>>2]=D+1,D;d=b;return d|0}function XAb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;if((a|0)==0){i=b;return}e=c[a>>2]|0;if((e|0)==0){i=b;return}f=c[e>>2]|0;c[d>>2]=f;$Db(a);a=f+8|0;if(((D=c[a>>2]|0,c[a>>2]=D+ -1,D)|0)!=1){i=b;return}a=c[d>>2]|0;ne[c[a+12>>2]&1023](c[a+16>>2]|0,c[a>>2]|0);$Db(d);i=b;return}function YAb(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;if((c[b+20>>2]&1|0)!=0){d=0;return d|0}d=(c[b+8>>2]|0)==1|0;return d|0}function ZAb(a){a=a|0;return c[(c[a>>2]|0)+8>>2]|0}function _Ab(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e>>2]|0;do{if((c[f+20>>2]&1|0)==0){if((c[f+8>>2]|0)==1){g=0}else{break}i=b;return g|0}}while(0);f=e+8|0;h=UAb(c[f>>2]|0)|0;if((h|0)==0){g=-12;i=b;return g|0}UGb(c[h+4>>2]|0,c[e+4>>2]|0,c[f>>2]|0)|0;f=d;do{if((a|0)!=0){e=c[a>>2]|0;if((e|0)==0){break}j=c[e>>2]|0;c[d>>2]=j;$Db(a);e=j+8|0;if(((D=c[e>>2]|0,c[e>>2]=D+ -1,D)|0)!=1){break}e=c[d>>2]|0;ne[c[e+12>>2]&1023](c[e+16>>2]|0,c[e>>2]|0);$Db(f)}}while(0);c[a>>2]=h;g=0;i=b;return g|0}function $Ab(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=c[a>>2]|0;if((j|0)==0){k=XDb(0,b)|0;c[g>>2]=k;if((k|0)==0){l=-12;i=d;return l|0}m=f;n=cEb(24)|0;c[f>>2]=n;do{if((n|0)!=0){c[n>>2]=k;c[n+4>>2]=b;c[n+12>>2]=98;c[n+16>>2]=0;c[n+8>>2]=1;o=cEb(12)|0;if((o|0)==0){$Db(m);break}p=c[f>>2]|0;c[o>>2]=p;c[o+4>>2]=k;c[o+8>>2]=b;q=p+20|0;c[q>>2]=c[q>>2]|2;c[a>>2]=o;l=0;i=d;return l|0}}while(0);$Db(g);l=-12;i=d;return l|0}g=j+8|0;if((c[g>>2]|0)==(b|0)){l=0;i=d;return l|0}k=j|0;f=c[k>>2]|0;do{if((c[f+20>>2]&3|0)==2){if((c[f+8>>2]|0)!=1){break}m=XDb(c[c[k>>2]>>2]|0,b)|0;if((m|0)==0){l=-12;i=d;return l|0}c[j+4>>2]=m;c[c[k>>2]>>2]=m;c[g>>2]=b;c[(c[k>>2]|0)+4>>2]=b;l=0;i=d;return l|0}}while(0);c[h>>2]=0;$Ab(h,b)|0;k=c[h>>2]|0;if((k|0)==0){l=-12;i=d;return l|0}f=c[g>>2]|0;UGb(c[k+4>>2]|0,c[j+4>>2]|0,(f|0)<(b|0)?f:b)|0;b=e;do{if((a|0)!=0){f=c[a>>2]|0;if((f|0)==0){break}j=c[f>>2]|0;c[e>>2]=j;$Db(a);f=j+8|0;if(((D=c[f>>2]|0,c[f>>2]=D+ -1,D)|0)!=1){break}f=c[e>>2]|0;ne[c[f+12>>2]&1023](c[f+16>>2]|0,c[f>>2]|0);$Db(b)}}while(0);c[a>>2]=c[h>>2];l=0;i=d;return l|0}function aBb(a,b){a=a|0;b=b|0;var d=0,e=0;d=cEb(20)|0;if((d|0)==0){e=0;return e|0}c[d+12>>2]=a;c[d+16>>2]=(b|0)!=0?b:1636;c[d+4>>2]=1;e=d;return e|0}function bBb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;e=b+8|0;if((a|0)==0){i=b;return}f=c[a>>2]|0;if((f|0)==0){i=b;return}c[a>>2]=0;a=f+4|0;if(((D=c[a>>2]|0,c[a>>2]=D+ -1,D)|0)!=1){i=b;return}a=d;g=e;c[d>>2]=f;h=f|0;if((c[h>>2]|0)!=0){f=h;do{h=c[f>>2]|0;c[e>>2]=h;c[c[d>>2]>>2]=c[h+16>>2];h=c[e>>2]|0;ne[c[h+8>>2]&1023](c[h+4>>2]|0,c[h>>2]|0);$Db(g);f=c[d>>2]|0;}while((c[f>>2]|0)!=0)}$Db(a);i=b;return}function cBb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=a;h=a;j=0;k=c[g>>2]|0;while(1){l=k;if((l|0)==(j|0)){m=4;break}n=(D=c[h>>2]|0,(c[h>>2]|0)==(k|0)?(c[h>>2]=0)|0:0,D);if((n|0)==0){m=5;break}else{j=l;k=n}}if((m|0)==4){if((j|0)==0){m=5}else{o=j}}a:do{if((m|0)==5){j=a+4|0;k=a+8|0;b:do{if((c[j>>2]|0)<=(c[k>>2]|0)){yDb(0,48,2166e3,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;c:while(1){if((c[j>>2]|0)>(c[k>>2]|0)){break b}n=0;l=c[g>>2]|0;while(1){p=l;if((p|0)==(n|0)){break}q=(D=c[h>>2]|0,(c[h>>2]|0)==(l|0)?(c[h>>2]=0)|0:0,D);if((q|0)==0){continue c}else{n=p;l=q}}if((n|0)!=0){o=n;break a}}}}while(0);l=re[c[a+16>>2]&4095](c[a+12>>2]|0)|0;c[e>>2]=l;if((l|0)==0){r=0;i=b;return r|0}q=cEb(20)|0;if((q|0)!=0){p=l|0;c[q>>2]=c[c[p>>2]>>2];c[q+4>>2]=c[(c[p>>2]|0)+16>>2];c[q+8>>2]=c[(c[p>>2]|0)+12>>2];c[q+12>>2]=a;c[(c[p>>2]|0)+16>>2]=q;c[(c[c[e>>2]>>2]|0)+12>>2]=78;D=c[j>>2]|0,c[j>>2]=D+1,D;D=c[k>>2]|0,c[k>>2]=D+1,D;r=c[e>>2]|0;i=b;return r|0}q=c[l>>2]|0;c[d>>2]=q;$Db(e);l=q+8|0;if(((D=c[l>>2]|0,c[l>>2]=D+ -1,D)|0)!=1){r=0;i=b;return r|0}l=c[d>>2]|0;ne[c[l+12>>2]&1023](c[l+16>>2]|0,c[l>>2]|0);$Db(d);r=0;i=b;return r|0}}while(0);d=(o|0)==0;e=o+16|0;h=c[e>>2]|0;do{if((h|0)!=0){g=c[h+12>>2]|0;m=h+16|0;if((c[m>>2]|0)==0){s=h}else{l=m;while(1){m=c[l>>2]|0;q=m+16|0;if((c[q>>2]|0)==0){s=m;break}else{l=q}}}l=g;k=h;if(((D=c[l>>2]|0,(c[l>>2]|0)==0?(c[l>>2]=k)|0:0,D)|0)==0){break}j=g;q=s;while(1){m=0;p=c[j>>2]|0;while(1){t=p;if((t|0)==(m|0)){u=m;break}v=(D=c[l>>2]|0,(c[l>>2]|0)==(p|0)?(c[l>>2]=0)|0:0,D);if((v|0)==0){u=0;break}else{m=t;p=v}}p=q+16|0;c[p>>2]=u;if((c[p>>2]|0)==0){w=q}else{m=p;while(1){p=c[m>>2]|0;v=p+16|0;if((c[v>>2]|0)==0){w=p;break}else{m=v}}}if(((D=c[l>>2]|0,(c[l>>2]|0)==0?(c[l>>2]=k)|0:0,D)|0)==0){break}else{q=w}}}}while(0);c[e>>2]=0;w=c[o>>2]|0;u=c[a+12>>2]|0;s=f;h=cEb(24)|0;c[f>>2]=h;do{if((h|0)!=0){c[h>>2]=w;c[h+4>>2]=u;c[h+12>>2]=78;c[h+16>>2]=o;c[h+8>>2]=1;q=cEb(12)|0;if((q|0)==0){$Db(s);break}c[q>>2]=c[f>>2];c[q+4>>2]=w;c[q+8>>2]=u;k=q;q=a+4|0;D=c[q>>2]|0,c[q>>2]=D+1,D;r=k;i=b;return r|0}}while(0);if(d){r=0;i=b;return r|0}d=c[o+12>>2]|0;if((c[e>>2]|0)==0){x=o}else{a=e;while(1){e=c[a>>2]|0;u=e+16|0;if((c[u>>2]|0)==0){x=e;break}else{a=u}}}a=d;u=o;if(((D=c[a>>2]|0,(c[a>>2]|0)==0?(c[a>>2]=u)|0:0,D)|0)==0){r=0;i=b;return r|0}o=d;d=x;while(1){x=0;e=c[o>>2]|0;while(1){w=e;if((w|0)==(x|0)){y=x;break}f=(D=c[a>>2]|0,(c[a>>2]|0)==(e|0)?(c[a>>2]=0)|0:0,D);if((f|0)==0){y=0;break}else{x=w;e=f}}e=d+16|0;c[e>>2]=y;if((c[e>>2]|0)==0){z=d}else{x=e;while(1){e=c[x>>2]|0;f=e+16|0;if((c[f>>2]|0)==0){z=e;break}else{x=f}}}if(((D=c[a>>2]|0,(c[a>>2]|0)==0?(c[a>>2]=u)|0:0,D)|0)==0){r=0;break}else{d=z}}i=b;return r|0}function dBb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+12>>2]|0;do{if((a|0)!=0){g=a+16|0;if((c[g>>2]|0)==0){h=a}else{j=g;while(1){g=c[j>>2]|0;k=g+16|0;if((c[k>>2]|0)==0){h=g;break}else{j=k}}}j=f;k=a;if(((D=c[j>>2]|0,(c[j>>2]|0)==0?(c[j>>2]=k)|0:0,D)|0)==0){break}g=f;l=h;while(1){m=0;n=c[g>>2]|0;while(1){o=n;if((o|0)==(m|0)){p=m;break}q=(D=c[j>>2]|0,(c[j>>2]|0)==(n|0)?(c[j>>2]=0)|0:0,D);if((q|0)==0){p=0;break}else{m=o;n=q}}n=l+16|0;c[n>>2]=p;if((c[n>>2]|0)==0){r=l}else{m=n;while(1){n=c[m>>2]|0;q=n+16|0;if((c[q>>2]|0)==0){r=n;break}else{m=q}}}if(((D=c[j>>2]|0,(c[j>>2]|0)==0?(c[j>>2]=k)|0:0,D)|0)==0){break}else{l=r}}}}while(0);r=f+4|0;if(((D=c[r>>2]|0,c[r>>2]=D+ -1,D)|0)!=1){i=b;return}r=d;p=e;c[d>>2]=f;h=f|0;if((c[h>>2]|0)!=0){f=h;do{h=c[f>>2]|0;c[e>>2]=h;c[c[d>>2]>>2]=c[h+16>>2];h=c[e>>2]|0;ne[c[h+8>>2]&1023](c[h+4>>2]|0,c[h>>2]|0);$Db(p);f=c[d>>2]|0;}while((c[f>>2]|0)!=0)}$Db(r);i=b;return}function eBb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+8|0;f=e|0;g=SGb(b|0)|0;h=b+g|0;if((g|0)<=0){j=0;k=0;i=e;return(F=j,k)|0}g=(d|0)==0;d=b;b=0;l=0;a:while(1){b:do{if(d>>>0<h>>>0){m=d;while(1){n=a[m]|0;if((n<<24>>24|0)==43|(n<<24>>24|0)==124){o=m;break b}n=m+1|0;if(n>>>0<h>>>0){m=n}else{o=n;break}}}else{o=d}}while(0);m=d;n=o-m|0;p=0;while(1){q=c[1492880+(p<<4)>>2]|0;if((SGb(q|0)|0)==(n|0)){if((PGb(q,d,n)|0)==0){r=9;break}}q=p+1|0;if(q>>>0<27>>>0){p=q}else{s=0;r=11;break}}c:do{if((r|0)==9){r=0;q=1492888+(p<<4)|0;t=c[q+4>>2]|0;u=c[q>>2]|0;r=32}else if((r|0)==11){d:while(1){r=0;do{if((s-18|0)>>>0>10>>>0){q=c[1492592+(s<<3)>>2]|0;if((SGb(q|0)|0)!=(n|0)){break}if((PGb(q,d,n)|0)==0){r=14;break d}}}while(0);q=s+1|0;if(q>>>0<36>>>0){s=q;r=11}else{break}}if((r|0)==14){r=0;q=_Gb(1,0,s|0)|0;v=F;w=q;break}q=kb(d|0,f|0,10)|0;x=c[f>>2]|0;do{if(g){if((x+1-m|0)!=(n|0)){break}if((a[x]|0)==99){y=0}else{break}while(1){if(!(y>>>0<27>>>0)){j=0;k=0;r=34;break a}if((c[1492884+(y<<4)>>2]|0)==(q|0)){break}else{y=y+1|0}}z=1492888+(y<<4)|0;t=c[z+4>>2]|0;u=c[z>>2]|0;r=32;break c}else{z=(x-m|0)==(n|0);if(z){A=0}else{if((x+1-m|0)!=(n|0)){break}if((a[x]|0)==99){A=0}else{break}}while(1){if(!(A>>>0<27>>>0)){B=0;C=0;break}if((c[1492884+(A<<4)>>2]|0)==(q|0)){r=22;break}else{A=A+1|0}}if((r|0)==22){r=0;D=1492888+(A<<4)|0;B=c[D+4>>2]|0;C=c[D>>2]|0}if(!z){break}yDb(0,24,1917168,(D=i,i=i+32|0,c[D>>2]=n,c[D+8>>2]=d,c[D+16>>2]=n,c[D+24>>2]=d,D)|0);i=D;t=B;u=C;r=32;break c}}while(0);q=Ed(d|0,f|0,0)|0;x=F;if(((c[f>>2]|0)-m|0)!=(n|0)){j=0;k=0;r=34;break a}D=0;E=(x|0)>(D|0)|(x|0)==(D|0)&q>>>0>0>>>0;t=E?x:0;u=E?q:0;r=32}}while(0);if((r|0)==32){r=0;if((u|0)==0&(t|0)==0){j=0;k=0;r=34;break}else{v=t;w=u}}n=w|l;m=v|b;p=o+1|0;if(p>>>0<h>>>0){d=p;b=m;l=n}else{j=m;k=n;r=34;break}}if((r|0)==34){i=e;return(F=j,k)|0}return 0}function fBb(a){a=a|0;var b=0;b=eBb(a,1)|0;return(F=F,b)|0}function gBb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;if((b|0)<1){g=d;h=g-(g>>>1&1431655765)|0;g=(h>>>2&858993459)+(h&858993459)|0;h=(g>>>4)+g&252645135;g=(h>>>8)+h|0;h=e-((e>>>1|0<<31)&1431655765)|0;j=(h>>>2&858993459)+(h&858993459)|0;h=(j>>>4)+j&252645135;j=(h>>>8)+h|0;k=((g>>>16)+g&63)+((j>>>16)+j&63)|0}else{k=b}b=0;while(1){if((k|0)==(c[1492884+(b<<4)>>2]|0)){j=1492888+(b<<4)|0;if((c[j>>2]|0)==(d|0)&(c[j+4>>2]|0)==(e|0)){l=6;break}}j=b+1|0;if(j>>>0<27>>>0){b=j}else{break}}if((l|0)==6){KAb(a,2165328,(m=i,i=i+8|0,c[m>>2]=c[1492880+(b<<4)>>2],m)|0);i=m;i=f;return}KAb(a,2301592,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;if((d|0)==0&(e|0)==0){i=f;return}KAb(a,2172032,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;k=0;b=0;while(1){l=_Gb(1,0,k|0)|0;if((l&d|0)==0&(F&e|0)==0){n=b}else{do{if(!(k>>>0>35>>>0)){l=c[1492592+(k<<3)>>2]|0;if((k-18|0)>>>0<11>>>0){break}if((b|0)>0){KAb(a,2097680,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}KAb(a,2165328,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m}}while(0);n=b+1|0}l=k+1|0;if((l|0)<64){k=l;b=n}else{break}}KAb(a,2042488,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;i=f;return}function hBb(a,b){a=a|0;b=b|0;var c=0;c=a;a=c-(c>>>1&1431655765)|0;c=(a>>>2&858993459)+(a&858993459)|0;a=(c>>>4)+c&252645135;c=(a>>>8)+a|0;a=b-((b>>>1|0<<31)&1431655765)|0;b=(a>>>2&858993459)+(a&858993459)|0;a=(b>>>4)+b&252645135;b=(a>>>8)+a|0;return((c>>>16)+c&63)+((b>>>16)+b&63)|0}function iBb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+1024|0;g=f|0;JAb(g,a,b);gBb(g,c,d,e);i=f;return}function jBb(a){a=a|0;var b=0,d=0,e=0,f=0;b=0;while(1){if(!(b>>>0<27>>>0)){d=0;e=0;f=5;break}if((c[1492884+(b<<4)>>2]|0)==(a|0)){break}else{b=b+1|0}}if((f|0)==5){return(F=d,e)|0}f=1492888+(b<<4)|0;d=c[f+4>>2]|0;e=c[f>>2]|0;return(F=d,e)|0}function kBb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((c&a|0)==0&(d&b|0)==0){e=-22;return e|0}f=c;g=f-(f>>>1&1431655765)|0;f=(g>>>2&858993459)+(g&858993459)|0;g=(f>>>4)+f&252645135;f=(g>>>8)+g|0;g=d-((d>>>1|0<<31)&1431655765)|0;h=(g>>>2&858993459)+(g&858993459)|0;g=(h>>>4)+h&252645135;h=(g>>>8)+g|0;if((((f>>>16)+f&63)+((h>>>16)+h&63)|0)!=1){e=-22;return e|0}h=YGb(c,d,-1,-1)|0;d=F&b;b=h&a;a=b-(b>>>1&1431655765)|0;b=(a>>>2&858993459)+(a&858993459)|0;a=(b>>>4)+b&252645135;b=(a>>>8)+a|0;a=d-((d>>>1|0<<31)&1431655765)|0;d=(a>>>2&858993459)+(a&858993459)|0;a=(d>>>4)+d&252645135;d=(a>>>8)+a|0;e=((b>>>16)+b&63)+((d>>>16)+d&63)|0;return e|0}function lBb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=d-(d>>>1&1431655765)|0;d=(e>>>2&858993459)+(e&858993459)|0;e=(d>>>4)+d&252645135;d=(e>>>8)+e|0;e=b-((b>>>1|0<<31)&1431655765)|0;f=(e>>>2&858993459)+(e&858993459)|0;e=(f>>>4)+f&252645135;f=(e>>>8)+e|0;if((((d>>>16)+d&63)+((f>>>16)+f&63)|0)==1){g=0}else{h=0;return h|0}while(1){if((g|0)>=64){h=0;i=6;break}f=_Gb(1,0,g|0)|0;if((f&a|0)==0&(F&b|0)==0){g=g+1|0}else{break}}if((i|0)==6){return h|0}if((g|0)<0|g>>>0>35>>>0){h=0;return h|0}h=c[1492592+(g<<3)>>2]|0;return h|0}function mBb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=d-(d>>>1&1431655765)|0;d=(e>>>2&858993459)+(e&858993459)|0;e=(d>>>4)+d&252645135;d=(e>>>8)+e|0;e=b-((b>>>1|0<<31)&1431655765)|0;f=(e>>>2&858993459)+(e&858993459)|0;e=(f>>>4)+f&252645135;f=(e>>>8)+e|0;if((((d>>>16)+d&63)+((f>>>16)+f&63)|0)==1){g=0}else{h=0;return h|0}while(1){if(!(g>>>0<36>>>0)){h=0;i=5;break}f=_Gb(1,0,g|0)|0;if((f&a|0)==0&(F&b|0)==0){g=g+1|0}else{break}}if((i|0)==5){return h|0}h=c[1492596+(g<<3)>>2]|0;return h|0}function nBb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=d-(d>>>1&1431655765)|0;d=(e>>>2&858993459)+(e&858993459)|0;e=(d>>>4)+d&252645135;d=(e>>>8)+e|0;e=b-((b>>>1|0<<31)&1431655765)|0;f=(e>>>2&858993459)+(e&858993459)|0;e=(f>>>4)+f&252645135;f=(e>>>8)+e|0;if((((d>>>16)+d&63)+((f>>>16)+f&63)|0)>(c|0)){g=c;h=0}else{i=0;j=0;return(F=i,j)|0}while(1){c=_Gb(1,0,h|0)|0;f=F;if((c&a|0)==0&(f&b|0)==0){k=g}else{if((g|0)==0){i=f;j=c;l=5;break}else{k=g-1|0}}c=h+1|0;if((c|0)<64){g=k;h=c}else{i=0;j=0;l=5;break}}if((l|0)==5){return(F=i,j)|0}return 0}function oBb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;if(a>>>0>26>>>0){e=-541478725;return e|0}if((b|0)!=0){f=1492888+(a<<4)|0;g=c[f+4>>2]|0;c[b>>2]=c[f>>2];c[b+4>>2]=g}if((d|0)==0){e=0;return e|0}c[d>>2]=c[1492880+(a<<4)>>2];e=0;return e|0}function pBb(a){a=a|0;c[1305364]=a;c[2202840]=(a|0)!=-1;return}function qBb(){if((c[2202840]|0)==0){c[2202840]=1}return c[1305364]|0}function rBb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+8|0;e=d|0;c[e>>2]=1781136;f=uEb(e,1781040,b,a)|0;i=d;return f|0}function sBb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((d-8|0)>>>0>24>>>0){g=-1;return g|0}h=0;i=_Gb(1,0,d|0)|0;j=F;if(!((h|0)<(j|0)|(h|0)==(j|0)&e>>>0<i>>>0)){g=-1;return g|0}if(!((f|0)==4096|(f|0)==1028)){g=-1;return g|0}i=e<<32-d;if((b|0)==0){b=0;do{d=b<<24>>31&i^b<<25;j=d>>31&i^d<<1;d=j>>31&i^j<<1;j=d>>31&i^d<<1;d=j>>31&i^j<<1;j=d>>31&i^d<<1;d=j>>31&i^j<<1;c[a+(b<<2)>>2]=fe(d>>31&i^d<<1|0)|0;b=b+1|0;}while(b>>>0<256>>>0)}else{b=0;do{i=-(b&1)&e^b>>>1;d=-(i&1)&e^i>>>1;i=-(d&1)&e^d>>>1;d=-(i&1)&e^i>>>1;i=-(d&1)&e^d>>>1;d=-(i&1)&e^i>>>1;i=-(d&1)&e^d>>>1;c[a+(b<<2)>>2]=-(i&1)&e^i>>>1;b=b+1|0;}while(b>>>0<256>>>0)}c[a+1024>>2]=1;if(f>>>0>4095>>>0){k=0}else{g=0;return g|0}while(1){f=c[a+(k<<2)>>2]|0;b=f>>>8^c[a+((f&255)<<2)>>2];c[a+(k+256<<2)>>2]=b;f=b>>>8^c[a+((b&255)<<2)>>2];c[a+(k+512<<2)>>2]=f;c[a+(k+768<<2)>>2]=f>>>8^c[a+((f&255)<<2)>>2];f=k+1|0;if(f>>>0<256>>>0){k=f}else{g=0;break}}return g|0}function tBb(a){a=a|0;var b=0,e=0;b=8883192+(a<<12)|0;do{if((c[8887284+(a<<12)>>2]|0)==0){if((sBb(b,d[1781344+(a<<3)|0]|0,d[1781345+(a<<3)|0]|0,c[1781348+(a<<3)>>2]|0,4096)|0)<0){e=0}else{break}return e|0}}while(0);e=b;return e|0}function uBb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=e+f|0;do{if((c[a+1024>>2]|0)==0){if((e&3|0)!=0&(f|0)>0){h=e;i=b;while(1){j=h+1|0;k=c[a+(((d[h]|0)^i&255)<<2)>>2]^i>>>8;if((j&3|0)!=0&j>>>0<g>>>0){h=j;i=k}else{l=j;m=k;break}}}else{l=e;m=b}i=e+(f-3)|0;if(l>>>0<i>>>0){n=l;o=m}else{p=m;q=l;break}while(1){h=c[n>>2]^o;k=n+4|0;j=c[a+((h>>>8&255|512)<<2)>>2]^c[a+((h&255|768)<<2)>>2]^c[a+((h>>>16&255|256)<<2)>>2]^c[a+(h>>>24<<2)>>2];if(k>>>0<i>>>0){n=k;o=j}else{p=j;q=k;break}}}else{p=b;q=e}}while(0);if(q>>>0<g>>>0){r=q;s=p}else{t=p;return t|0}while(1){p=r+1|0;q=c[a+(((d[r]|0)^s&255)<<2)>>2]^s>>>8;if(p>>>0<g>>>0){r=p;s=q}else{t=q;break}}return t|0}function vBb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0;if(!((e|0)==192|(e|0)==64)){g=-1;return g|0}f=a+384|0;c[f>>2]=(e|0)>64;e=b;h=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;h=fe(e|0)|0;e=i|0;i=2363128;j=0;k=0;l=0;while(1){m=$Gb(h|0,e|0,d[i]|0|0)|0;n=m&1|(l<<1|0>>>31);m=F&0|(k<<1|l>>>31);o=j+1|0;if((o|0)<56){i=i+1|0;j=o;k=m;l=n}else{p=0;q=m;r=n;break}}while(1){l=(r<<1|0>>>31)&-268435458|(r>>>27|q<<5)&268435457;k=q<<1|r>>>31|0|(q>>>27|0<<5)&0;do{if((p|0)>1){if((p|0)==15|(p|0)==8){s=k;t=l;break}s=k<<1|l>>>31|0|(q>>>26|0<<6)&0;t=(l<<1|0>>>31)&-268435458|(r>>>26|q<<6)&268435457}else{s=k;t=l}}while(0);l=2363080;k=0;j=0;i=0;while(1){e=$Gb(t|0,s|0,d[l]|0|0)|0;u=e&1|(i<<1|0>>>31);v=F&0|(j<<1|i>>>31);e=k+1|0;if((e|0)<48){l=l+1|0;k=e;j=v;i=u}else{break}}i=a+(p<<3)|0;c[i>>2]=u;c[i+4>>2]=v;i=p+1|0;if((i|0)<16){p=i;q=s;r=t}else{break}}if((c[f>>2]|0)==0){g=0;return g|0}f=b+8|0;t=f|0;r=f+4|0;f=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=fe(f|0)|0;f=r|0;r=2363128;s=0;q=0;p=0;while(1){v=$Gb(t|0,f|0,d[r]|0|0)|0;u=v&1|(p<<1|0>>>31);v=F&0|(q<<1|p>>>31);i=s+1|0;if((i|0)<56){r=r+1|0;s=i;q=v;p=u}else{w=0;x=v;y=u;break}}while(1){p=(y<<1|0>>>31)&-268435458|(y>>>27|x<<5)&268435457;q=x<<1|y>>>31|0|(x>>>27|0<<5)&0;do{if((w|0)>1){if((w|0)==15|(w|0)==8){z=q;A=p;break}z=q<<1|p>>>31|0|(x>>>26|0<<6)&0;A=(p<<1|0>>>31)&-268435458|(y>>>26|x<<6)&268435457}else{z=q;A=p}}while(0);p=2363080;q=0;s=0;r=0;while(1){f=$Gb(A|0,z|0,d[p]|0|0)|0;B=f&1|(r<<1|0>>>31);C=F&0|(s<<1|r>>>31);f=q+1|0;if((f|0)<48){p=p+1|0;q=f;s=C;r=B}else{break}}r=a+128+(w<<3)|0;c[r>>2]=B;c[r+4>>2]=C;r=w+1|0;if((r|0)<16){w=r;x=z;y=A}else{break}}A=b+16|0;b=A|0;y=A+4|0;A=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;b=fe(A|0)|0;A=y|0;y=2363128;z=0;x=0;w=0;while(1){C=$Gb(b|0,A|0,d[y]|0|0)|0;B=C&1|(w<<1|0>>>31);C=F&0|(x<<1|w>>>31);r=z+1|0;if((r|0)<56){y=y+1|0;z=r;x=C;w=B}else{D=0;E=C;G=B;break}}while(1){w=(G<<1|0>>>31)&-268435458|(G>>>27|E<<5)&268435457;x=E<<1|G>>>31|0|(E>>>27|0<<5)&0;do{if((D|0)>1){if((D|0)==15|(D|0)==8){H=x;I=w;break}H=x<<1|w>>>31|0|(E>>>26|0<<6)&0;I=(w<<1|0>>>31)&-268435458|(G>>>26|E<<6)&268435457}else{H=x;I=w}}while(0);w=2363080;x=0;z=0;y=0;while(1){A=$Gb(I|0,H|0,d[w]|0|0)|0;J=A&1|(y<<1|0>>>31);K=F&0|(z<<1|y>>>31);A=x+1|0;if((A|0)<48){w=w+1|0;x=A;z=K;y=J}else{break}}y=a+256+(D<<3)|0;c[y>>2]=J;c[y+4>>2]=K;y=D+1|0;if((y|0)<16){D=y;E=H;G=I}else{g=0;break}}return g|0}function wBb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;xBb(a,b,c,d,e,f,0);return}function xBb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;k=(h|0)!=0;if(k){l=h;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=fe(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;o=n|0;p=fe(l|0)|0}else{o=0;p=0}l=g-1|0;n=p;m=o;a:do{if((g|0)>0){q=b|0;r=b+384|0;s=b+128|0;t=b+256|0;u=(j|0)==0;if((i|0)==0){v=f;w=o;y=p;z=e;A=l;while(1){if((v|0)==0){B=0;C=0}else{D=v;E=D|0;G=D+4|0;D=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;G=fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0;B=G|0;C=fe(D|0)|0}D=zBb(C^y,B^w,q,0)|0;G=F;if((c[r>>2]|0)==0){H=G;I=D;J=G;K=D}else{E=zBb(D,G,s,1)|0;G=zBb(E,F,t,0)|0;E=F;H=E;I=G;J=E;K=G}L=k?K:0;M=k?J:0;G=fe(I|0)|0;E=z;D=E|0;x=fe(H|0)|0;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;D=E+4|0;x=G|0;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;if((A|0)>0){v=v+8|0;w=M;y=L;z=u?z+8|0:z;A=A-1|0}else{break}}N=M;O=L;break}if(k){P=f;Q=o;R=p;S=e;T=l}else{A=f;z=o;y=p;w=e;v=l;while(1){if((A|0)==0){U=0;V=0}else{D=A;G=D|0;E=D+4|0;D=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=fe(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0;U=E|0;V=fe(D|0)|0}if((c[r>>2]|0)==0){W=U;X=V}else{D=zBb(V,U,t,1)|0;E=zBb(D,F,s,0)|0;W=F;X=E}E=zBb(X,W,q,1)|0;D=F^z;G=fe(E^y|0)|0;E=w;Y=E|0;x=fe(D|0)|0;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;Y=E+4|0;x=G|0;a[Y]=x;x=x>>8;a[Y+1|0]=x;x=x>>8;a[Y+2|0]=x;x=x>>8;a[Y+3|0]=x;if((v|0)>0){A=A+8|0;z=0;y=0;w=u?w+8|0:w;v=v-1|0}else{N=0;O=0;break a}}}while(1){if((P|0)==0){Z=0;_=0}else{v=P;w=v|0;y=v+4|0;v=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=fe(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;Z=y|0;_=fe(v|0)|0}if((c[r>>2]|0)==0){$=Z;aa=_}else{v=zBb(_,Z,t,1)|0;y=zBb(v,F,s,0)|0;$=F;aa=y}y=zBb(aa,$,q,1)|0;v=F^Q;w=fe(y^R|0)|0;y=S;z=y|0;x=fe(v|0)|0;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;z=y+4|0;x=w|0;a[z]=x;x=x>>8;a[z+1|0]=x;x=x>>8;a[z+2|0]=x;x=x>>8;a[z+3|0]=x;if((T|0)>0){P=P+8|0;Q=Z;R=_;S=u?S+8|0:S;T=T-1|0}else{break}}N=Z;O=_}else{N=m;O=n}}while(0);if(!k){return}k=fe(O|0)|0;O=h;h=O|0;x=fe(N|0)|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;h=O+4|0;x=k|0;a[h]=x;x=x>>8;a[h+1|0]=x;x=x>>8;a[h+2|0]=x;x=x>>8;a[h+3|0]=x;return}function yBb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;c[g>>2]=0;c[g+4>>2]=0;xBb(a,b,d,e,g,0,1);i=f;return}function zBb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=(f|0)!=0;f=2365192;h=0;i=0;j=0;while(1){k=$Gb(a|0,b|0,d[f]|0|0)|0;l=k&1|(j<<1|0>>>31);m=F&0|(i<<1|j>>>31);k=h+1|0;if((k|0)<64){f=f+1|0;h=k;i=m;j=l}else{break}}j=g?15:0;g=0;i=m;m=l;while(1){l=m;h=e+((g^j)<<3)|0;f=c[h>>2]|0;b=c[h+4>>2]|0;h=l<<1|l>>>31;a=l>>>3;k=a&268435440;n=(c[2361928+((((f>>>6|b<<26)^a)&255&63)<<2)>>2]|c[2362184+(((f^h)&255&63)<<2)>>2]|c[2361672+((((f>>>12|b<<20)^k>>>4)&255&63)<<2)>>2]|c[2361416+((((f>>>18|b<<14)^l>>>11)&255&63)<<2)>>2]|c[2361160+((((f>>>24|b<<8)^l>>>15)&255&63)<<2)>>2]|c[2360904+((((f>>>30|b<<2)^l>>>19)&255&63)<<2)>>2]|c[2360648+((((b>>>4|0<<28)^l>>>23)&255&63)<<2)>>2]|c[2360392+((((b>>>10|0<<22)^(h<<28|k)>>>24)&255&63)<<2)>>2])^i;o=0^m;k=g+1|0;if((k|0)<16){g=k;i=o;m=n}else{break}}m=2365255;i=n|0;n=o|0;o=0;g=0;j=0;while(1){e=_Gb(n&1|0,i&0|0,d[m]|0|0)|0;p=e|j;q=F|g;e=n>>>1|i<<31;k=o+1|0;if((k|0)<64){m=m-1|0;i=i>>>1|0<<31;n=e;o=k;g=q;j=p}else{break}}return(F=q,p)|0}function ABb(a){a=a|0;var b=0;if((a|0)==0){b=0}else{b=c[a>>2]|0}return b|0}function BBb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((b|0)==0){g=0;return g|0}if((e|0)==0){h=0}else{h=(e-(c[b+4>>2]|0)>>3)+1|0}e=c[b>>2]|0;if(!(h>>>0<e>>>0)){g=0;return g|0}i=c[b+4>>2]|0;b=(f&2|0)==0;a:do{if((f&1|0)==0){j=h;while(1){k=c[i+(j<<3)>>2]|0;l=0;while(1){m=a[k+l|0]|0;n=a[d+l|0]|0;o=n<<24>>24;if((((m-97|0)>>>0<26>>>0?m^32:m)|0)!=(((o-97|0)>>>0<26>>>0?o^32:o)|0)|n<<24>>24==0){break}else{l=l+1|0}}if(n<<24>>24==0){if((a[k+l|0]|0)==0|b^1){p=j;break a}}o=j+1|0;if(o>>>0<e>>>0){j=o}else{g=0;break}}return g|0}else{if(b){q=h}else{j=h;while(1){o=c[i+(j<<3)>>2]|0;m=0;while(1){r=a[d+m|0]|0;if((a[o+m|0]|0)!=r<<24>>24|r<<24>>24==0){break}else{m=m+1|0}}if(r<<24>>24==0){p=j;break a}m=j+1|0;if(m>>>0<e>>>0){j=m}else{g=0;break}}return g|0}while(1){j=c[i+(q<<3)>>2]|0;m=0;while(1){s=a[d+m|0]|0;if((a[j+m|0]|0)!=s<<24>>24|s<<24>>24==0){break}else{m=m+1|0}}if(s<<24>>24==0){if((a[j+m|0]|0)==0){p=q;break a}}o=q+1|0;if(o>>>0<e>>>0){q=o}else{g=0;break}}return g|0}}while(0);g=i+(p<<3)|0;return g|0}function CBb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+8|0;g=f|0;h=c[a>>2]|0;j=BBb(h,b,0,e)|0;c[g>>2]=0;if((h|0)==0){k=cEb(8)|0;c[a>>2]=k;l=k}else{l=h}do{if((j|0)==0){h=l+4|0;k=XDb(c[h>>2]|0,(c[l>>2]<<3)+8|0)|0;if((k|0)==0){m=-12;i=f;return m|0}else{c[h>>2]=k;break}}else{if((e&16|0)!=0){m=0;i=f;return m|0}k=c[j+4>>2]|0;if((e&32|0)==0){ZDb(k)}else{c[g>>2]=k}ZDb(c[j>>2]|0);k=l|0;h=(c[k>>2]|0)-1|0;c[k>>2]=h;k=(c[l+4>>2]|0)+(h<<3)|0;h=j;n=c[k+4>>2]|0;c[h>>2]=c[k>>2];c[h+4>>2]=n}}while(0);if((d|0)==0){o=c[l>>2]|0}else{if((e&4|0)==0){j=eEb(b)|0;n=c[l>>2]|0;c[(c[l+4>>2]|0)+(n<<3)>>2]=j;p=n}else{n=c[l>>2]|0;c[(c[l+4>>2]|0)+(n<<3)>>2]=b;p=n}a:do{if((e&8|0)==0){n=c[g>>2]|0;do{if((n|0)!=0){if((e&32|0)==0){break}b=SGb(n|0)|0;j=b+1+(SGb(d|0)|0)|0;b=cEb(j)|0;if((b|0)==0){m=-12;i=f;return m|0}else{tAb(b,n,j)|0;$Db(g);tAb(b,d,j)|0;j=c[l>>2]|0;c[(c[l+4>>2]|0)+(j<<3)+4>>2]=b;q=j;break a}}}while(0);n=eEb(d)|0;j=c[l>>2]|0;c[(c[l+4>>2]|0)+(j<<3)+4>>2]=n;q=j}else{c[(c[l+4>>2]|0)+(p<<3)+4>>2]=d;q=p}}while(0);p=q+1|0;c[l>>2]=p;o=p}if((o|0)!=0){m=0;i=f;return m|0}ZDb(c[l+4>>2]|0);$Db(a);m=0;i=f;return m|0}function DBb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a>>2]|0;if((b|0)==0){d=a;$Db(d);return}e=b|0;f=c[e>>2]|0;g=f-1|0;c[e>>2]=g;h=b+4|0;b=c[h>>2]|0;if((f|0)==0){i=b}else{f=g;g=b;while(1){ZDb(c[g+(f<<3)>>2]|0);ZDb(c[(c[h>>2]|0)+(c[e>>2]<<3)+4>>2]|0);b=c[e>>2]|0;j=b-1|0;c[e>>2]=j;k=c[h>>2]|0;if((b|0)==0){i=k;break}else{f=j;g=k}}}ZDb(i);d=a;$Db(d);return}function EBb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((b|0)==0){return}e=b|0;f=b+4|0;b=0;while(1){if((b|0)==0){g=0}else{g=(b-(c[f>>2]|0)>>3)+1|0}if(!(g>>>0<(c[e>>2]|0)>>>0)){h=8;break}i=c[f>>2]|0;j=i+(g<<3)|0;if((j|0)==0){h=8;break}CBb(a,c[i+(g<<3)>>2]|0,c[i+(g<<3)+4>>2]|0,d)|0;b=j}if((h|0)==8){return}}function FBb(a){a=a|0;var b=0,d=0,e=0,f=0;b=VCb(a,4)|0;do{if((b|0)==0){d=TCb(a,4,48)|0;if((d|0)==0){e=0}else{f=d;break}return e|0}else{f=b}}while(0);e=c[f+4>>2]|0;return e|0}function GBb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=0;while(1){if(!(f>>>0<19>>>0)){break}if((c[1340824+(f*12|0)>>2]|0)==(a|0)){g=4;break}else{f=f+1|0}}if((g|0)==4){sAb(b,c[1340832+(f*12|0)>>2]|0,d)|0;h=0;i=e;return h|0}f=ae(-a|0,b|0,d|0)|0;g=-f|0;if((f|0)<=0){h=g;i=e;return h|0}Lb(b|0,d|0,2163192,(d=i,i=i+8|0,c[d>>2]=a,d)|0)|0;i=d;h=g;i=e;return h|0}function HBb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0.0,j=0,k=0.0,l=0,m=0,n=0.0,o=0,p=0.0,q=0,r=0,s=0.0;e=i;i=i+8|0;f=e|0;do{if((a[b]|0)==48){if((a[b+1|0]|32|0)!=120){g=4;break}h=+((hb(b|0,f|0,16)|0)>>>0>>>0)}else{g=4}}while(0);if((g|0)==4){h=+OGb(b,f)}j=c[f>>2]|0;do{if((j|0)==(b|0)){k=h;l=b}else{m=a[j]|0;do{if(m<<24>>24==100){if((a[j+1|0]|0)!=66){g=10;break}n=+S(+10.0,+(h/20.0));o=j+2|0;c[f>>2]=o;p=n;q=o}else{if((m-69&255)>>>0<54>>>0){g=10}else{p=h;q=j}}}while(0);do{if((g|0)==10){o=a[437848+((m<<24>>24)-69)|0]|0;if(o<<24>>24==0){p=h;q=j;break}r=j+1|0;n=+(o<<24>>24|0);if((a[r]|0)==105){s=h*+Wc(+(n/.3));o=j+2|0;c[f>>2]=o;p=s;q=o;break}else{s=h*+S(+10.0,+n);c[f>>2]=r;p=s;q=r;break}}}while(0);if((a[q]|0)!=66){k=p;l=q;break}m=q+1|0;c[f>>2]=m;k=p*8.0;l=m}}while(0);if((d|0)==0){i=e;return+k}c[d>>2]=l;i=e;return+k}function IBb(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;if((a|0)==0){i=b;return}IBb(c[a+20>>2]|0);IBb(c[a+24>>2]|0);IBb(c[a+28>>2]|0);$Db(a+32|0);$Db(d);i=b;return}function JBb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;m=i;i=i+64|0;n=m|0;o=m+56|0;p=n;TGb(p|0,0,52)|0;c[o>>2]=0;q=WDb((SGb(d|0)|0)+1|0)|0;if((q|0)==0){r=-12;i=m;return r|0}else{s=q;t=d}a:while(1){u=t;while(1){v=a[u]|0;if(v<<24>>24==0){break a}w=u+1|0;if((EAb(v<<24>>24)|0)==0){break}else{u=w}}a[s]=a[u]|0;s=s+1|0;t=w}a[s]=0;c[n>>2]=1340752;c[n+4>>2]=100;s=n+8|0;c[s>>2]=q;c[n+16>>2]=e;c[n+20>>2]=g;c[n+24>>2]=f;c[n+28>>2]=j;c[n+32>>2]=h;c[n+40>>2]=k;c[n+44>>2]=l;l=KBb(o,n)|0;do{if((l|0)<0){x=l}else{n=c[o>>2]|0;if((a[c[s>>2]|0]|0)!=0){IBb(n);yDb(p,16,2162904,(k=i,i=i+16|0,c[k>>2]=c[s>>2],c[k+8>>2]=d,k)|0);i=k;x=-22;break}if((LBb(n)|0)==0){IBb(n);x=-22;break}else{c[n+32>>2]=cEb(80)|0;c[b>>2]=n;x=l;break}}}while(0);ZDb(q);r=x;i=m;return r|0}function KBb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+16|0;f=e|0;g=e+8|0;j=d+4|0;k=c[j>>2]|0;if((k|0)<1){l=-22;i=e;return l|0}c[j>>2]=k-1;k=PBb(f,d)|0;if((k|0)<0){l=k;i=e;return l|0}k=d+8|0;m=c[k>>2]|0;n=c[f>>2]|0;a:do{if((a[m]|0)==59){o=m;p=n;while(1){c[k>>2]=o+1;q=PBb(g,d)|0;if((q|0)<0){r=5;break}s=c[g>>2]|0;t=cEb(40)|0;if((t|0)==0){r=7;break}u=t;c[t>>2]=22;h[t+8>>3]=1.0;c[t+20>>2]=p;c[t+24>>2]=s;c[f>>2]=u;t=c[k>>2]|0;if((a[t]|0)==59){o=t;p=u}else{v=u;break a}}if((r|0)==5){IBb(p);l=q;i=e;return l|0}else if((r|0)==7){c[f>>2]=0;IBb(p);IBb(s);l=-12;i=e;return l|0}}else{v=n}}while(0);c[j>>2]=(c[j>>2]|0)+1;c[b>>2]=v;l=0;i=e;return l|0}function LBb(a){a=a|0;var b=0,d=0;if((a|0)==0){b=0;return b|0}switch(c[a>>2]|0){case 2:case 3:case 5:case 7:case 6:case 8:case 9:case 27:case 28:case 29:case 30:case 31:case 32:{if((LBb(c[a+20>>2]|0)|0)==0){b=0;return b|0}b=(c[a+24>>2]|0)==0|0;return b|0};case 40:{if((LBb(c[a+20>>2]|0)|0)==0){b=0;return b|0}if((LBb(c[a+24>>2]|0)|0)==0){b=0;return b|0}else{return(LBb(c[a+28>>2]|0)|0)!=0|0}break};case 37:{if((LBb(c[a+20>>2]|0)|0)==0){b=0;return b|0}d=c[a+24>>2]|0;if((d|0)==0){b=1;return b|0}else{return(LBb(d)|0)!=0|0}break};case 35:case 36:case 25:{if((LBb(c[a+20>>2]|0)|0)==0){b=0;return b|0}if((LBb(c[a+24>>2]|0)|0)==0){b=0;return b|0}d=c[a+28>>2]|0;if((d|0)==0){b=1;return b|0}else{return(LBb(d)|0)!=0|0}break};case 0:case 1:{b=1;return b|0};default:{if((LBb(c[a+20>>2]|0)|0)==0){b=0;return b|0}if((LBb(c[a+24>>2]|0)|0)==0){b=0;return b|0}b=(c[a+28>>2]|0)==0|0;return b|0}}return 0}function MBb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0.0;e=i;i=i+56|0;f=e|0;TGb(f|0,0,48)|0;c[f+48>>2]=c[a+32>>2];c[f+12>>2]=b;c[f+36>>2]=d;g=+NBb(f,a);i=e;return+g}function NBb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0.0,j=0.0,l=0.0,m=0.0,n=0,o=0,p=0.0,r=0,s=0.0,t=0.0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0,M=0,N=0.0,O=0.0,T=0,U=0.0,V=0;e=i;f=b|0;switch(c[f>>2]|0){case 31:{g=+h[b+8>>3]*+(+NBb(a,c[b+20>>2]|0)==0.0|0);i=e;return+g};case 1:{j=+h[b+8>>3]*+h[(c[a+12>>2]|0)+(c[b+16>>2]<<3)>>3];i=e;return+j};case 40:{g=+NBb(a,c[b+20>>2]|0);l=+h[b+8>>3];if(g<+NBb(a,c[b+24>>2]|0)){m=0.0}else{m=+(g<=+NBb(a,c[b+28>>2]|0)|0)}j=l*m;i=e;return+j};case 7:{m=+h[b+8>>3];n=~~+NBb(a,c[b+20>>2]|0);if((n|0)<0){o=0}else{o=(n|0)>9?9:n}j=m*+h[(c[a+48>>2]|0)+(o<<3)>>3];i=e;return+j};case 6:{m=+NBb(a,c[b+20>>2]|0);l=+_(m*(-0.0-m)*.5)/2.5066282746310002;i=e;return+l};case 4:{l=+h[b+8>>3];o=c[b+16>>2]|0;n=c[a+36>>2]|0;m=+NBb(a,c[b+20>>2]|0);g=+NBb(a,c[b+24>>2]|0);p=l*+Re[o&1](n,m,g);i=e;return+p};case 28:{p=+h[b+8>>3]*+aa(+NBb(a,c[b+20>>2]|0));i=e;return+p};case 8:{p=+h[b+8>>3];g=+NBb(a,c[b+20>>2]|0);h[k>>3]=g;n=c[k+4>>2]&2147483647;o=2146435072;g=p*+((n>>>0>o>>>0|n>>>0==o>>>0&(c[k>>2]|0)>>>0>0>>>0)&1|0);i=e;return+g};case 29:{g=+h[b+8>>3]*+sc(+(+NBb(a,c[b+20>>2]|0)));i=e;return+g};case 9:{g=+h[b+8>>3];p=+NBb(a,c[b+20>>2]|0);h[k>>3]=p;p=g*+((c[k>>2]|0|0)==0&(c[k+4>>2]&2147483647|0)==2146435072&1|0);i=e;return+p};case 2:{p=+h[b+8>>3];o=c[b+16>>2]|0;g=+NBb(a,c[b+20>>2]|0);m=p*+He[o&31](g);i=e;return+m};case 37:{m=+NBb(a,c[b+20>>2]|0);o=c[b+24>>2]|0;if((o|0)==0){r=32}else{r=~~+NBb(a,o)}yDb(a,r,2301320,(r=i,i=i+8|0,h[r>>3]=m,r)|0);i=r;j=m;i=e;return+j};case 27:{m=+h[b+8>>3]*+P(+NBb(a,c[b+20>>2]|0));i=e;return+m};case 24:{r=b+20|0;if(!(+NBb(a,c[r>>2]|0)!=0.0)){j=+q;i=e;return+j}o=b+24|0;while(1){m=+NBb(a,c[o>>2]|0);if(!(+NBb(a,c[r>>2]|0)!=0.0)){j=m;break}}i=e;return+j};case 35:{m=+h[b+8>>3];do{if(+NBb(a,c[b+20>>2]|0)!=0.0){s=+NBb(a,c[b+24>>2]|0)}else{r=c[b+28>>2]|0;if((r|0)==0){s=0.0;break}s=+NBb(a,r)}}while(0);j=m*s;i=e;return+j};case 3:{s=+h[b+8>>3];r=c[b+16>>2]|0;o=c[a+36>>2]|0;m=+NBb(a,c[b+20>>2]|0);g=s*+Te[r&15](o,m);i=e;return+g};case 0:{j=+h[b+8>>3];i=e;return+j};case 36:{g=+h[b+8>>3];do{if(+NBb(a,c[b+20>>2]|0)!=0.0){o=c[b+28>>2]|0;if((o|0)==0){t=0.0;break}t=+NBb(a,o)}else{t=+NBb(a,c[b+24>>2]|0)}}while(0);j=g*t;i=e;return+j};case 25:{t=+NBb(a,c[b+24>>2]|0);o=c[b+28>>2]|0;do{if((o|0)==0){u=0}else{r=~~+NBb(a,o);if((r|0)<0){u=0;break}u=(r|0)>9?9:r}}while(0);o=a+48|0;r=c[o>>2]|0;g=+h[r+(u<<3)>>3];n=b+20|0;v=0;m=0.0;s=1.0;w=r;while(1){h[w+(u<<3)>>3]=+(v|0);p=+NBb(a,c[n>>2]|0);x=m+s*p;if(m==x&p!=0.0){break}r=v+1|0;if((r|0)>=1e3){break}v=r;m=x;s=s*(t/+(r|0));w=c[o>>2]|0}h[(c[o>>2]|0)+(u<<3)>>3]=g;j=x;i=e;return+j};case 5:{x=1.0/(+_(+NBb(a,c[b+20>>2]|0)*4.0)+1.0);i=e;return+x};case 26:{u=a+48|0;x=+h[c[u>>2]>>3];g=+NBb(a,c[b+24>>2]|0);o=b+20|0;t=1.7976931348623157e+308;s=-1.7976931348623157e+308;m=-1.0;p=-1.0;w=-1;while(1){if((w|0)>=1024){y=t;z=s;A=m;B=p;break}do{if((w|0)<255){h[c[u>>2]>>3]=g*+(d[1775432+(w&255)|0]|0|0)/255.0}else{l=g*+S(+.9,+(+(w-255|0)));v=c[u>>2]|0;if((w&1|0)==0){C=l}else{C=l*-1.0}h[v>>3]=C;if((w&2|0)==0){h[v>>3]=m+C;break}else{h[v>>3]=p+C;break}}}while(0);l=+NBb(a,c[o>>2]|0);if(l<=0.0&l>s){D=l;G=+h[c[u>>2]>>3]}else{D=s;G=p}if(l>=0.0&l<t){H=l;I=+h[c[u>>2]>>3]}else{H=t;I=m}if(G<0.0|I<0.0){t=H;s=D;m=I;p=G;w=w+1|0}else{J=I;K=G;L=0;M=65;break}}a:do{if((M|0)==65){while(1){M=0;if((L|0)>=1e3){y=H;z=D;A=J;B=K;break a}G=(K+J)*.5;h[c[u>>2]>>3]=G;if(K==G|J==G){y=H;z=D;A=J;B=K;break a}G=+NBb(a,c[o>>2]|0);if(G>0.0){N=K}else{N=+h[c[u>>2]>>3]}if(G<0.0){O=J}else{O=+h[c[u>>2]>>3]}h[k>>3]=G;w=c[k+4>>2]&2147483647;v=2146435072;if(w>>>0>v>>>0|w>>>0==v>>>0&(c[k>>2]|0)>>>0>0>>>0){y=H;z=D;A=G;B=G;break}else{J=O;K=N;L=L+1|0;M=65}}}}while(0);h[c[u>>2]>>3]=x;j=y>-0.0-z?B:A;i=e;return+j};case 30:{A=+h[b+8>>3];B=A*+R(+NBb(a,c[b+20>>2]|0));i=e;return+B};case 32:{u=~~+NBb(a,c[b+20>>2]|0);if((u|0)<0){T=0}else{T=(u|0)>9?9:u}u=(c[a+48>>2]|0)+(T<<3)|0;B=+h[u>>3];T=c[u+4>>2]&2147483647;M=2146435072;if(T>>>0>M>>>0|T>>>0==M>>>0&(c[u>>2]|0)>>>0>0>>>0){U=1013904223.0}else{M=gHb(~~+B>>>0,(E=+B,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0),1664525,0)|0;T=YGb(M,F,1013904223,0)|0;U=+(T>>>0)+ +(F>>>0)*4294967296.0}h[u>>3]=U;j=U*5.421010862427522e-20*+h[b+8>>3];i=e;return+j};default:{U=+NBb(a,c[b+20>>2]|0);B=+NBb(a,c[b+24>>2]|0);switch(c[f>>2]|0){case 33:{j=+h[b+8>>3]*+R(U*U+B*B);i=e;return+j};case 38:{h[k>>3]=U;f=c[k+4>>2]&2147483647;u=2146435072;if(f>>>0>u>>>0|f>>>0==u>>>0&(c[k>>2]|0)>>>0>0>>>0){j=+q;i=e;return+j}h[k>>3]=B;u=c[k+4>>2]&2147483647;f=2146435072;if(u>>>0>f>>>0|u>>>0==f>>>0&(c[k>>2]|0)>>>0>0>>>0){j=+q;i=e;return+j}j=+(~~B&~~U|0)*+h[b+8>>3];i=e;return+j};case 39:{h[k>>3]=U;f=c[k+4>>2]&2147483647;u=2146435072;if(f>>>0>u>>>0|f>>>0==u>>>0&(c[k>>2]|0)>>>0>0>>>0){j=+q;i=e;return+j}h[k>>3]=B;u=c[k+4>>2]&2147483647;f=2146435072;if(u>>>0>f>>>0|u>>>0==f>>>0&(c[k>>2]|0)>>>0>0>>>0){j=+q;i=e;return+j}j=+(~~B|~~U|0)*+h[b+8>>3];i=e;return+j};case 12:{j=(U<B?U:B)*+h[b+8>>3];i=e;return+j};case 13:{j=(U==B?1.0:0.0)*+h[b+8>>3];i=e;return+j};case 14:{j=(U>B?1.0:0.0)*+h[b+8>>3];i=e;return+j};case 15:{j=(U>=B?1.0:0.0)*+h[b+8>>3];i=e;return+j};case 21:{j=(U+B)*+h[b+8>>3];i=e;return+j};case 22:{j=B*+h[b+8>>3];i=e;return+j};case 23:{A=+h[b+8>>3];f=~~U;if((f|0)<0){V=0}else{V=(f|0)>9?9:f}h[(c[a+48>>2]|0)+(V<<3)>>3]=B;j=B*A;i=e;return+j};case 17:{j=(U<B?1.0:0.0)*+h[b+8>>3];i=e;return+j};case 16:{j=(U<=B?1.0:0.0)*+h[b+8>>3];i=e;return+j};case 18:{j=+h[b+8>>3]*+S(+U,+B);i=e;return+j};case 19:{j=U*B*+h[b+8>>3];i=e;return+j};case 20:{j=+h[b+8>>3]*(U/B);i=e;return+j};case 10:{j=+h[b+8>>3]*(U-B*+P(U/B));i=e;return+j};case 34:{A=+h[b+8>>3];j=A*(+((GDb(~~+U>>>0,(E=+U,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0),~~+B>>>0,(E=+B,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0))|0)>>>0)+ +(F|0)*4294967296.0);i=e;return+j};case 11:{j=(U>B?U:B)*+h[b+8>>3];i=e;return+j};default:{j=+q;i=e;return+j}}}}return 0.0}function OBb(a,b,d,e,f,g,j,k,l,m,n){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,r=0,s=0,t=0;o=i;i=i+64|0;p=o|0;r=o+56|0;c[r>>2]=0;s=JBb(r,b,d,f,g,j,k,m,n)|0;if((s|0)<0){h[a>>3]=+q;t=s;i=o;return t|0}else{s=c[r>>2]|0;TGb(p|0,0,48)|0;c[p+48>>2]=c[s+32>>2];c[p+12>>2]=e;c[p+36>>2]=l;h[a>>3]=+NBb(p,s);IBb(s);s=c[a+4>>2]&2147483647;p=2146435072;t=s>>>0>p>>>0|s>>>0==p>>>0&(c[a>>2]|0)>>>0>0>>>0?-22:0;i=o;return t|0}return 0}function PBb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+16|0;f=e|0;g=e+8|0;j=QBb(f,d)|0;if((j|0)<0){k=j;i=e;return k|0}j=d+8|0;l=c[f>>2]|0;while(1){m=a[c[j>>2]|0]|0;if(!((m<<24>>24|0)==45|(m<<24>>24|0)==43)){n=9;break}o=QBb(g,d)|0;if((o|0)<0){n=5;break}p=c[g>>2]|0;m=cEb(40)|0;if((m|0)==0){n=7;break}q=m;c[m>>2]=21;h[m+8>>3]=1.0;c[m+20>>2]=l;c[m+24>>2]=p;c[f>>2]=q;l=q}if((n|0)==5){IBb(l);k=o;i=e;return k|0}else if((n|0)==7){c[f>>2]=0;IBb(l);IBb(p);k=-12;i=e;return k|0}else if((n|0)==9){c[b>>2]=l;k=0;i=e;return k|0}return 0}function QBb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+16|0;f=e|0;g=e+8|0;j=RBb(f,d)|0;if((j|0)<0){k=j;i=e;return k|0}j=d+8|0;while(1){l=c[j>>2]|0;m=a[l]|0;if(!((m<<24>>24|0)==42|(m<<24>>24|0)==47)){n=9;break}c[j>>2]=l+1;m=a[l]|0;o=c[f>>2]|0;p=RBb(g,d)|0;if((p|0)<0){n=5;break}q=c[g>>2]|0;l=cEb(40)|0;if((l|0)==0){n=7;break}c[l>>2]=m<<24>>24==42?19:20;h[l+8>>3]=1.0;c[l+20>>2]=o;c[l+24>>2]=q;c[f>>2]=l}if((n|0)==5){IBb(o);k=p;i=e;return k|0}else if((n|0)==7){c[f>>2]=0;IBb(o);IBb(q);k=-12;i=e;return k|0}else if((n|0)==9){c[b>>2]=c[f>>2];k=0;i=e;return k|0}return 0}function RBb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0;e=i;i=i+32|0;f=e|0;g=e+8|0;j=e+16|0;k=e+24|0;l=d+8|0;m=c[l>>2]|0;do{if((a[m]|0)==45){+OGb(m,f);n=c[f>>2]|0;o=c[l>>2]|0;if((n|0)==(o|0)){p=n;q=6;break}if((a[n]|0)!=100){p=o;q=6;break}if((a[n+1|0]|0)!=66){p=o;q=6;break}r=SBb(j,d)|0;s=1.0}else{p=m;q=6}}while(0);if((q|0)==6){m=a[p]|0;f=(m<<24>>24==43)-(m<<24>>24==45)|0;c[l>>2]=p+(f&1);r=SBb(j,d)|0;s=+(f|1|0)}if((r|0)<0){t=r;i=e;return t|0}r=c[l>>2]|0;f=c[j>>2]|0;a:do{if((a[r]|0)==94){p=r;m=f;while(1){o=p+1|0;c[l>>2]=o;do{if((a[o]|0)==45){+OGb(o,g);n=c[g>>2]|0;u=c[l>>2]|0;if((n|0)==(u|0)){v=n;q=15;break}if((a[n]|0)!=100){v=u;q=15;break}if((a[n+1|0]|0)!=66){v=u;q=15;break}w=SBb(k,d)|0;x=1.0}else{v=o;q=15}}while(0);if((q|0)==15){q=0;o=a[v]|0;u=(o<<24>>24==43)-(o<<24>>24==45)|0;c[l>>2]=v+(u&1);w=SBb(k,d)|0;x=+(u|1|0)}if((w|0)<0){q=17;break}y=c[k>>2]|0;u=cEb(40)|0;if((u|0)==0){q=19;break}o=u;c[u>>2]=18;h[u+8>>3]=1.0;c[u+20>>2]=m;c[u+24>>2]=y;c[j>>2]=o;if((y|0)!=0){u=y+8|0;h[u>>3]=x*+h[u>>3]}u=c[l>>2]|0;if((a[u]|0)==94){p=u;m=o}else{z=o;break a}}if((q|0)==17){IBb(m);t=w;i=e;return t|0}else if((q|0)==19){c[j>>2]=0;IBb(m);IBb(y);t=-12;i=e;return t|0}}else{z=f}}while(0);if((z|0)!=0){f=z+8|0;h[f>>3]=s*+h[f>>3]}c[b>>2]=z;t=0;i=e;return t|0}function SBb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0;e=i;i=i+16|0;f=e|0;g=e+8|0;j=cEb(40)|0;c[f>>2]=j;k=d+8|0;l=c[k>>2]|0;c[g>>2]=l;if((j|0)==0){m=-12;i=e;return m|0}n=+HBb(l,g);j=c[f>>2]|0;o=j+8|0;h[o>>3]=n;p=c[g>>2]|0;if((p|0)!=(c[k>>2]|0)){c[j>>2]=0;c[k>>2]=p;c[b>>2]=j;m=0;i=e;return m|0}h[o>>3]=1.0;q=c[d+16>>2]|0;a:do{if((q|0)==0){r=0}else{s=0;while(1){t=c[q+(s<<2)>>2]|0;if((t|0)==0){r=0;break a}else{u=0}while(1){v=a[t+u|0]|0;w=a[p+u|0]|0;if(v<<24>>24==0){x=8;break}if(v<<24>>24==w<<24>>24){u=u+1|0}else{break}}if((x|0)==8){x=0;v=w<<24>>24;if(!((v-48|0)>>>0<10>>>0|(v-97|0)>>>0<26>>>0|(v-65|0)>>>0<26>>>0|w<<24>>24==95)){break}}s=s+1|0}c[k>>2]=p+(SGb(t|0)|0);c[j>>2]=1;c[j+16>>2]=s;c[b>>2]=j;m=0;i=e;return m|0}}while(0);while(1){y=a[p+r|0]|0;if((r|0)==1){x=13;break}if((a[2008136+r|0]|0)==y<<24>>24){r=r+1|0}else{z=0;x=226;break}}if((x|0)==13){r=y<<24>>24;if((r-48|0)>>>0<10>>>0|(r-97|0)>>>0<26>>>0|(r-65|0)>>>0<26>>>0|y<<24>>24==95){z=0;x=226}else{A=0;B=1420408}}do{if((x|0)==226){while(1){x=0;C=a[p+z|0]|0;if((z|0)==2){x=228;break}if((a[1998128+z|0]|0)==C<<24>>24){z=z+1|0;x=226}else{D=0;break}}if((x|0)==228){s=C<<24>>24;if((s-48|0)>>>0<10>>>0|(s-97|0)>>>0<26>>>0|(s-65|0)>>>0<26>>>0|C<<24>>24==95){D=0}else{A=1;B=1420424;break}}while(1){E=a[p+D|0]|0;if((D|0)==3){x=231;break}if((a[1994296+D|0]|0)==E<<24>>24){D=D+1|0}else{break}}if((x|0)==231){s=E<<24>>24;if(!((s-48|0)>>>0<10>>>0|(s-97|0)>>>0<26>>>0|(s-65|0)>>>0<26>>>0|E<<24>>24==95)){A=2;B=1420440;break}}s=Vb(p|0,40)|0;c[k>>2]=s;if((s|0)==0){yDb(d,16,2171864,(F=i,i=i+8|0,c[F>>2]=l,F)|0);i=F;c[k>>2]=c[g>>2];IBb(c[f>>2]|0);m=-22;i=e;return m|0}c[k>>2]=s+1;if((a[p]|0)==40){$Db(f);s=KBb(f,d)|0;if((s|0)<0){m=s;i=e;return m|0}s=c[k>>2]|0;if((a[s]|0)==41){c[k>>2]=s+1;c[b>>2]=c[f>>2];m=0;i=e;return m|0}else{yDb(d,16,2097544,(F=i,i=i+8|0,c[F>>2]=l,F)|0);i=F;IBb(c[f>>2]|0);m=-22;i=e;return m|0}}s=KBb(j+20|0,d)|0;if((s|0)<0){IBb(c[f>>2]|0);m=s;i=e;return m|0}s=c[k>>2]|0;y=a[s]|0;do{if(y<<24>>24==44){c[k>>2]=s+1;KBb((c[f>>2]|0)+24|0,d)|0;r=c[k>>2]|0;t=a[r]|0;if(!(t<<24>>24==44)){G=r;H=t;break}c[k>>2]=r+1;KBb((c[f>>2]|0)+28|0,d)|0;r=c[k>>2]|0;G=r;H=a[r]|0}else{G=s;H=y}}while(0);if(!(H<<24>>24==41)){yDb(d,16,2042272,(F=i,i=i+8|0,c[F>>2]=l,F)|0);i=F;IBb(c[f>>2]|0);m=-22;i=e;return m|0}c[k>>2]=G+1;y=c[f>>2]|0;s=y|0;c[s>>2]=2;r=c[g>>2]|0;t=0;while(1){I=a[r+t|0]|0;if((t|0)==4){x=31;break}if((a[1997488+t|0]|0)==I<<24>>24){t=t+1|0}else{J=0;x=33;break}}do{if((x|0)==31){t=I<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|I<<24>>24==95){J=0;x=33;break}c[y+16>>2]=24}}while(0);b:do{if((x|0)==33){while(1){x=0;K=a[r+J|0]|0;if((J|0)==4){x=35;break}if((a[1960992+J|0]|0)==K<<24>>24){J=J+1|0;x=33}else{L=0;break}}do{if((x|0)==35){t=K<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|K<<24>>24==95){L=0;break}c[y+16>>2]=18;break b}}while(0);while(1){M=a[r+L|0]|0;if((L|0)==4){x=39;break}if((a[1933152+L|0]|0)==M<<24>>24){L=L+1|0}else{N=0;break}}do{if((x|0)==39){t=M<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|M<<24>>24==95){N=0;break}c[y+16>>2]=2;break b}}while(0);while(1){O=a[r+N|0]|0;if((N|0)==3){x=43;break}if((a[1910240+N|0]|0)==O<<24>>24){N=N+1|0}else{P=0;break}}do{if((x|0)==43){t=O<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|O<<24>>24==95){P=0;break}c[y+16>>2]=22;break b}}while(0);while(1){Q=a[r+P|0]|0;if((P|0)==3){x=47;break}if((a[1889936+P|0]|0)==Q<<24>>24){P=P+1|0}else{R=0;break}}do{if((x|0)==47){t=Q<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Q<<24>>24==95){R=0;break}c[y+16>>2]=14;break b}}while(0);while(1){S=a[r+R|0]|0;if((R|0)==3){x=51;break}if((a[2347248+R|0]|0)==S<<24>>24){R=R+1|0}else{T=0;break}}do{if((x|0)==51){t=S<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|S<<24>>24==95){T=0;break}c[y+16>>2]=26;break b}}while(0);while(1){U=a[r+T|0]|0;if((T|0)==4){x=55;break}if((a[2326856+T|0]|0)==U<<24>>24){T=T+1|0}else{V=0;break}}do{if((x|0)==55){t=U<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|U<<24>>24==95){V=0;break}c[y+16>>2]=6;break b}}while(0);while(1){W=a[r+V|0]|0;if((V|0)==4){x=59;break}if((a[2302960+V|0]|0)==W<<24>>24){V=V+1|0}else{X=0;break}}do{if((x|0)==59){t=W<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|W<<24>>24==95){X=0;break}c[y+16>>2]=4;break b}}while(0);while(1){Y=a[r+X|0]|0;if((X|0)==4){x=63;break}if((a[2284992+X|0]|0)==Y<<24>>24){X=X+1|0}else{Z=0;break}}do{if((x|0)==63){t=Y<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Y<<24>>24==95){Z=0;break}c[y+16>>2]=12;break b}}while(0);while(1){_=a[r+Z|0]|0;if((Z|0)==3){x=67;break}if((a[2269544+Z|0]|0)==_<<24>>24){Z=Z+1|0}else{$=0;break}}do{if((x|0)==67){t=_<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|_<<24>>24==95){$=0;break}c[y+16>>2]=20;break b}}while(0);while(1){aa=a[r+$|0]|0;if(($|0)==3){x=71;break}if((a[2254072+$|0]|0)==aa<<24>>24){$=$+1|0}else{ba=0;break}}do{if((x|0)==71){t=aa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|aa<<24>>24==95){ba=0;break}c[y+16>>2]=10;break b}}while(0);while(1){ca=a[r+ba|0]|0;if((ba|0)==3){x=75;break}if((a[2239928+ba|0]|0)==ca<<24>>24){ba=ba+1|0}else{da=0;break}}do{if((x|0)==75){t=ca<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ca<<24>>24==95){da=0;break}c[y+16>>2]=16;break b}}while(0);while(1){ea=a[r+da|0]|0;if((da|0)==4){x=79;break}if((a[2227864+da|0]|0)==ea<<24>>24){da=da+1|0}else{fa=0;break}}do{if((x|0)==79){t=ea<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ea<<24>>24==95){fa=0;break}c[y+16>>2]=8;break b}}while(0);while(1){ga=a[r+fa|0]|0;if((fa|0)==6){x=83;break}if((a[2216296+fa|0]|0)==ga<<24>>24){fa=fa+1|0}else{ha=0;break}}do{if((x|0)==83){t=ga<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ga<<24>>24==95){ha=0;break}c[s>>2]=5;break b}}while(0);while(1){ia=a[r+ha|0]|0;if((ha|0)==5){x=87;break}if((a[2206536+ha|0]|0)==ia<<24>>24){ha=ha+1|0}else{ja=0;break}}do{if((x|0)==87){t=ia<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ia<<24>>24==95){ja=0;break}c[s>>2]=6;break b}}while(0);while(1){ka=a[r+ja|0]|0;if((ja|0)==3){x=91;break}if((a[2198672+ja|0]|0)==ka<<24>>24){ja=ja+1|0}else{la=0;break}}do{if((x|0)==91){t=ka<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ka<<24>>24==95){la=0;break}c[s>>2]=10;break b}}while(0);while(1){ma=a[r+la|0]|0;if((la|0)==3){x=95;break}if((a[2189728+la|0]|0)==ma<<24>>24){la=la+1|0}else{na=0;break}}do{if((x|0)==95){t=ma<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ma<<24>>24==95){na=0;break}c[s>>2]=11;break b}}while(0);while(1){oa=a[r+na|0]|0;if((na|0)==3){x=99;break}if((a[2172968+na|0]|0)==oa<<24>>24){na=na+1|0}else{pa=0;break}}do{if((x|0)==99){t=oa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|oa<<24>>24==95){pa=0;break}c[s>>2]=12;break b}}while(0);while(1){qa=a[r+pa|0]|0;if((pa|0)==2){x=103;break}if((a[2163464+pa|0]|0)==qa<<24>>24){pa=pa+1|0}else{ra=0;break}}do{if((x|0)==103){t=qa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|qa<<24>>24==95){ra=0;break}c[s>>2]=13;break b}}while(0);while(1){sa=a[r+ra|0]|0;if((ra|0)==3){x=107;break}if((a[2156624+ra|0]|0)==sa<<24>>24){ra=ra+1|0}else{ta=0;break}}do{if((x|0)==107){t=sa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|sa<<24>>24==95){ta=0;break}c[s>>2]=15;break b}}while(0);while(1){ua=a[r+ta|0]|0;if((ta|0)==2){x=111;break}if((a[2149768+ta|0]|0)==ua<<24>>24){ta=ta+1|0}else{va=0;break}}do{if((x|0)==111){t=ua<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ua<<24>>24==95){va=0;break}c[s>>2]=14;break b}}while(0);while(1){wa=a[r+va|0]|0;if((va|0)==3){x=115;break}if((a[2142904+va|0]|0)==wa<<24>>24){va=va+1|0}else{xa=0;break}}do{if((x|0)==115){t=wa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|wa<<24>>24==95){xa=0;break}c[s>>2]=16;break b}}while(0);while(1){ya=a[r+xa|0]|0;if((xa|0)==2){x=119;break}if((a[2137488+xa|0]|0)==ya<<24>>24){xa=xa+1|0}else{za=0;break}}do{if((x|0)==119){t=ya<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ya<<24>>24==95){za=0;break}c[s>>2]=17;break b}}while(0);while(1){Aa=a[r+za|0]|0;if((za|0)==2){x=123;break}if((a[2130816+za|0]|0)==Aa<<24>>24){za=za+1|0}else{Ba=0;break}}do{if((x|0)==123){t=Aa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Aa<<24>>24==95){Ba=0;break}c[s>>2]=7;break b}}while(0);while(1){Ca=a[r+Ba|0]|0;if((Ba|0)==5){x=127;break}if((a[2124440+Ba|0]|0)==Ca<<24>>24){Ba=Ba+1|0}else{Da=0;break}}do{if((x|0)==127){t=Ca<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ca<<24>>24==95){Da=0;break}c[s>>2]=8;break b}}while(0);while(1){Ea=a[r+Da|0]|0;if((Da|0)==5){x=131;break}if((a[2118968+Da|0]|0)==Ea<<24>>24){Da=Da+1|0}else{Fa=0;break}}do{if((x|0)==131){t=Ea<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ea<<24>>24==95){Fa=0;break}c[s>>2]=9;break b}}while(0);while(1){Ga=a[r+Fa|0]|0;if((Fa|0)==2){x=135;break}if((a[2112480+Fa|0]|0)==Ga<<24>>24){Fa=Fa+1|0}else{Ha=0;break}}do{if((x|0)==135){t=Ga<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ga<<24>>24==95){Ha=0;break}c[s>>2]=23;break b}}while(0);while(1){Ia=a[r+Ha|0]|0;if((Ha|0)==5){x=139;break}if((a[2098456+Ha|0]|0)==Ia<<24>>24){Ha=Ha+1|0}else{Ja=0;break}}do{if((x|0)==139){t=Ia<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ia<<24>>24==95){Ja=0;break}c[s>>2]=24;break b}}while(0);while(1){Ka=a[r+Ja|0]|0;if((Ja|0)==6){x=143;break}if((a[2092304+Ja|0]|0)==Ka<<24>>24){Ja=Ja+1|0}else{La=0;break}}do{if((x|0)==143){t=Ka<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ka<<24>>24==95){La=0;break}c[s>>2]=25;break b}}while(0);while(1){Ma=a[r+La|0]|0;if((La|0)==4){x=147;break}if((a[2086992+La|0]|0)==Ma<<24>>24){La=La+1|0}else{Na=0;break}}do{if((x|0)==147){t=Ma<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ma<<24>>24==95){Na=0;break}c[s>>2]=26;break b}}while(0);while(1){Oa=a[r+Na|0]|0;if((Na|0)==5){x=151;break}if((a[2082416+Na|0]|0)==Oa<<24>>24){Na=Na+1|0}else{Pa=0;break}}do{if((x|0)==151){t=Oa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Oa<<24>>24==95){Pa=0;break}c[s>>2]=27;break b}}while(0);while(1){Qa=a[r+Pa|0]|0;if((Pa|0)==4){x=155;break}if((a[2076624+Pa|0]|0)==Qa<<24>>24){Pa=Pa+1|0}else{Ra=0;break}}do{if((x|0)==155){t=Qa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Qa<<24>>24==95){Ra=0;break}c[s>>2]=28;break b}}while(0);while(1){Sa=a[r+Ra|0]|0;if((Ra|0)==5){x=159;break}if((a[2071960+Ra|0]|0)==Sa<<24>>24){Ra=Ra+1|0}else{Ta=0;break}}do{if((x|0)==159){t=Sa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Sa<<24>>24==95){Ta=0;break}c[s>>2]=29;break b}}while(0);while(1){Ua=a[r+Ta|0]|0;if((Ta|0)==4){x=163;break}if((a[2067256+Ta|0]|0)==Ua<<24>>24){Ta=Ta+1|0}else{Va=0;break}}do{if((x|0)==163){t=Ua<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ua<<24>>24==95){Va=0;break}c[s>>2]=30;break b}}while(0);while(1){Wa=a[r+Va|0]|0;if((Va|0)==3){x=167;break}if((a[2063008+Va|0]|0)==Wa<<24>>24){Va=Va+1|0}else{Xa=0;break}}do{if((x|0)==167){t=Wa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Wa<<24>>24==95){Xa=0;break}c[s>>2]=31;break b}}while(0);while(1){Ya=a[r+Xa|0]|0;if((Xa|0)==3){x=171;break}if((a[2059272+Xa|0]|0)==Ya<<24>>24){Xa=Xa+1|0}else{Za=0;break}}do{if((x|0)==171){t=Ya<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ya<<24>>24==95){Za=0;break}c[s>>2]=18;break b}}while(0);while(1){_a=a[r+Za|0]|0;if((Za|0)==5){x=175;break}if((a[2053872+Za|0]|0)==_a<<24>>24){Za=Za+1|0}else{$a=0;break}}do{if((x|0)==175){t=_a<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|_a<<24>>24==95){$a=0;break}c[s>>2]=37;break b}}while(0);while(1){ab=a[r+$a|0]|0;if(($a|0)==6){x=179;break}if((a[2043296+$a|0]|0)==ab<<24>>24){$a=$a+1|0}else{bb=0;break}}do{if((x|0)==179){t=ab<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ab<<24>>24==95){bb=0;break}c[s>>2]=32;break b}}while(0);while(1){cb=a[r+bb|0]|0;if((bb|0)==5){x=183;break}if((a[2038768+bb|0]|0)==cb<<24>>24){bb=bb+1|0}else{db=0;break}}do{if((x|0)==183){t=cb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|cb<<24>>24==95){db=0;break}c[s>>2]=33;break b}}while(0);while(1){eb=a[r+db|0]|0;if((db|0)==3){x=187;break}if((a[2035584+db|0]|0)==eb<<24>>24){db=db+1|0}else{fb=0;break}}do{if((x|0)==187){t=eb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|eb<<24>>24==95){fb=0;break}c[s>>2]=34;break b}}while(0);while(1){gb=a[r+fb|0]|0;if((fb|0)==2){x=191;break}if((a[2031768+fb|0]|0)==gb<<24>>24){fb=fb+1|0}else{hb=0;break}}do{if((x|0)==191){t=gb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|gb<<24>>24==95){hb=0;break}c[s>>2]=35;break b}}while(0);while(1){ib=a[r+hb|0]|0;if((hb|0)==5){x=195;break}if((a[2027536+hb|0]|0)==ib<<24>>24){hb=hb+1|0}else{jb=0;break}}do{if((x|0)==195){t=ib<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ib<<24>>24==95){jb=0;break}c[s>>2]=36;break b}}while(0);while(1){kb=a[r+jb|0]|0;if((jb|0)==6){x=199;break}if((a[2024072+jb|0]|0)==kb<<24>>24){jb=jb+1|0}else{lb=0;break}}do{if((x|0)==199){t=kb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|kb<<24>>24==95){lb=0;break}c[s>>2]=38;break b}}while(0);while(1){mb=a[r+lb|0]|0;if((lb|0)==5){x=203;break}if((a[2020664+lb|0]|0)==mb<<24>>24){lb=lb+1|0}else{nb=0;break}}do{if((x|0)==203){t=mb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|mb<<24>>24==95){nb=0;break}c[s>>2]=39;break b}}while(0);while(1){ob=a[r+nb|0]|0;if((nb|0)==7){x=208;break}if((a[2016856+nb|0]|0)==ob<<24>>24){nb=nb+1|0}else{break}}do{if((x|0)==208){t=ob<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ob<<24>>24==95){break}c[s>>2]=40;break b}}while(0);t=c[d+24>>2]|0;c:do{if((t|0)!=0){w=0;while(1){u=c[t+(w<<2)>>2]|0;if((u|0)==0){break c}else{pb=0}while(1){q=a[u+pb|0]|0;qb=a[r+pb|0]|0;if(q<<24>>24==0){x=214;break}if(q<<24>>24==qb<<24>>24){pb=pb+1|0}else{break}}if((x|0)==214){x=0;u=qb<<24>>24;if(!((u-48|0)>>>0<10>>>0|(u-97|0)>>>0<26>>>0|(u-65|0)>>>0<26>>>0|qb<<24>>24==95)){break}}w=w+1|0}c[y+16>>2]=c[(c[d+20>>2]|0)+(w<<2)>>2];u=c[f>>2]|0;c[u>>2]=3;c[b>>2]=u;m=0;i=e;return m|0}}while(0);t=c[d+32>>2]|0;d:do{if((t|0)!=0){u=0;while(1){q=c[t+(u<<2)>>2]|0;if((q|0)==0){break d}else{rb=0}while(1){v=a[q+rb|0]|0;sb=a[r+rb|0]|0;if(v<<24>>24==0){x=220;break}if(v<<24>>24==sb<<24>>24){rb=rb+1|0}else{break}}if((x|0)==220){x=0;q=sb<<24>>24;if(!((q-48|0)>>>0<10>>>0|(q-97|0)>>>0<26>>>0|(q-65|0)>>>0<26>>>0|sb<<24>>24==95)){break}}u=u+1|0}c[y+16>>2]=c[(c[d+28>>2]|0)+(u<<2)>>2];w=c[f>>2]|0;c[w>>2]=4;c[b>>2]=w;m=0;i=e;return m|0}}while(0);yDb(d,16,2012888,(F=i,i=i+8|0,c[F>>2]=l,F)|0);i=F;IBb(c[f>>2]|0);m=-22;i=e;return m|0}}while(0);c[b>>2]=c[f>>2];m=0;i=e;return m|0}}while(0);c[k>>2]=p+(SGb(c[B>>2]|0)|0);c[j>>2]=0;h[o>>3]=+h[1420416+(A<<4)>>3];c[b>>2]=j;m=0;i=e;return m|0}function TBb(a){a=+a;var b=0;b=WFb()|0;return+((+(b>>>0)+ +(F|0)*4294967296.0)*1.0e-6)}function UBb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;e=cEb(24)|0;f=e;c[d>>2]=f;if((e|0)==0){g=0;i=b;return g|0}h=WDb(a)|0;c[e>>2]=h;c[e+12>>2]=h+a;c[e+4>>2]=h;c[e+8>>2]=h;c[e+16>>2]=0;c[e+20>>2]=0;if((h|0)!=0){g=f;i=b;return g|0}$Db(d);g=c[d>>2]|0;i=b;return g|0}function VBb(a){a=a|0;var b=0;if((a|0)==0){return}b=a;$Db(b);ZDb(b);return}function WBb(a){a=a|0;return(c[a+20>>2]|0)-(c[a+16>>2]|0)|0}function XBb(a){a=a|0;return(c[a+12>>2]|0)-(c[a>>2]|0)-(c[a+20>>2]|0)+(c[a+16>>2]|0)|0}function YBb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+8|0;e=d|0;f=a+12|0;g=a|0;if(!(((c[f>>2]|0)-(c[g>>2]|0)|0)>>>0<b>>>0)){h=0;i=d;return h|0}j=a+16|0;k=(c[a+20>>2]|0)-(c[j>>2]|0)|0;l=cEb(24)|0;m=l;c[e>>2]=m;if((l|0)==0){h=-12;i=d;return h|0}n=WDb(b)|0;c[l>>2]=n;c[l+12>>2]=n+b;c[l+4>>2]=n;c[l+8>>2]=n;c[l+16>>2]=0;c[l+20>>2]=0;if((n|0)==0){$Db(e);o=c[e>>2]|0}else{o=m}if((o|0)==0){h=-12;i=d;return h|0}m=a+4|0;e=c[o>>2]|0;n=k;l=c[f>>2]|0;b=c[m>>2]|0;while(1){p=l-b|0;q=(p|0)>(n|0)?n:p;UGb(e|0,b|0,q)|0;p=c[m>>2]|0;r=c[f>>2]|0;s=p+q|0;c[m>>2]=s;if(s>>>0<r>>>0){t=s}else{s=p+(q-r+(c[g>>2]|0))|0;c[m>>2]=s;t=s}c[j>>2]=(c[j>>2]|0)+q;s=n-q|0;if((s|0)>0){e=e+q|0;n=s;l=r;b=t}else{break}}t=o+8|0;c[t>>2]=(c[t>>2]|0)+k;t=o+20|0;c[t>>2]=(c[t>>2]|0)+k;ZDb(c[g>>2]|0);g=a;a=o;c[g>>2]=c[a>>2];c[g+4>>2]=c[a+4>>2];c[g+8>>2]=c[a+8>>2];c[g+12>>2]=c[a+12>>2];c[g+16>>2]=c[a+16>>2];c[g+20>>2]=c[a+20>>2];ZDb(a);h=0;i=d;return h|0}function ZBb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=a+12|0;g=a+4|0;h=a+16|0;i=a|0;a=c[f>>2]|0;j=c[g>>2]|0;if((e|0)==0){k=b;l=d;m=a;n=j;while(1){o=m-n|0;p=(o|0)>(l|0)?l:o;UGb(k|0,n|0,p)|0;o=c[g>>2]|0;q=c[f>>2]|0;r=o+p|0;c[g>>2]=r;if(r>>>0<q>>>0){s=r}else{r=o+(p-q+(c[i>>2]|0))|0;c[g>>2]=r;s=r}c[h>>2]=(c[h>>2]|0)+p;r=l-p|0;if((r|0)>0){k=k+p|0;l=r;m=q;n=s}else{break}}return 0}else{s=d;d=a;a=j;while(1){j=d-a|0;n=(j|0)>(s|0)?s:j;Xe[e&4095](b,a,n);j=c[g>>2]|0;m=c[f>>2]|0;l=j+n|0;c[g>>2]=l;if(l>>>0<m>>>0){t=l}else{l=j+(n-m+(c[i>>2]|0))|0;c[g>>2]=l;t=l}c[h>>2]=(c[h>>2]|0)+n;l=s-n|0;if((l|0)>0){s=l;d=m;a=t}else{break}}return 0}return 0}function _Bb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=a+20|0;g=c[f>>2]|0;h=a+8|0;i=c[h>>2]|0;j=a+12|0;k=a|0;a=c[j>>2]|0;if((e|0)==0){l=b;m=i;n=g;o=d;p=a;while(1){q=p-m|0;r=(q|0)>(o|0)?o:q;UGb(m|0,l|0,r)|0;q=c[j>>2]|0;s=m+r|0;if(s>>>0<q>>>0){t=s}else{t=c[k>>2]|0}s=r+n|0;u=o-r|0;if((u|0)>0){l=l+r|0;m=t;n=s;o=u;p=q}else{v=t;w=s;x=u;break}}c[f>>2]=w;c[h>>2]=v;y=d-x|0;return y|0}else{z=i;A=g;B=d;C=a}while(1){a=C-z|0;g=(a|0)>(B|0)?B:a;if((ze[e&511](b,z,g)|0)<1){v=z;w=A;x=B;D=9;break}a=c[j>>2]|0;i=z+g|0;if(i>>>0<a>>>0){E=i}else{E=c[k>>2]|0}i=g+A|0;t=B-g|0;if((t|0)>0){z=E;A=i;B=t;C=a}else{v=E;w=i;x=t;D=9;break}}if((D|0)==9){c[f>>2]=w;c[h>>2]=v;y=d-x|0;return y|0}return 0}function $Bb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+4|0;e=c[d>>2]|0;f=e+b|0;c[d>>2]=f;g=c[a+12>>2]|0;if(!(f>>>0<g>>>0)){c[d>>2]=e+(b-g+(c[a>>2]|0))}g=a+16|0;c[g>>2]=(c[g>>2]|0)+b;return}function aCb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+224|0;h=g|0;j=g+16|0;k=g+96|0;c[h>>2]=1068952;c[h+4>>2]=e;c[h+8>>2]=f;f=cCb(a,0,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0)|0;i=e;c[b>>2]=0;if((f|0)<0){l=-(c[(ld()|0)>>2]|0)|0;m=k|0;GBb(l,m,128)|0;yDb(h,16,2162384,(e=i,i=i+16|0,c[e>>2]=a,c[e+8>>2]=m,e)|0);i=e;n=l;i=g;return n|0}if((od(f|0,j|0)|0)<0){l=-(c[(ld()|0)>>2]|0)|0;m=k|0;GBb(l,m,128)|0;yDb(h,16,2301160,(e=i,i=i+8|0,c[e>>2]=m,e)|0);i=e;Ub(f|0)|0;n=l;i=g;return n|0}l=c[j+36>>2]|0;c[d>>2]=l;d=vb(0,l|0,3,2,f|0,0)|0;if((d|0)==-1){l=-(c[(ld()|0)>>2]|0)|0;j=k|0;GBb(l,j,128)|0;yDb(h,16,2097504,(e=i,i=i+8|0,c[e>>2]=j,e)|0);i=e;Ub(f|0)|0;n=l;i=g;return n|0}else{c[b>>2]=d;Ub(f|0)|0;n=0;i=g;return n|0}return 0}function bCb(a,b){a=a|0;b=b|0;Cb(a|0,b|0)|0;return}function cCb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;if((b&64|0)==0){h=0}else{g=f|0;h=(w=c[g+4>>2]|0,c[g+4>>2]=w+8,c[(c[g>>2]|0)+w>>2]|0)}g=Lc(a|0,b|524288|0,(b=i,i=i+8|0,c[b>>2]=h,b)|0)|0;i=b;if((g|0)==-1){i=e;return g|0}h=fc(g|0,2,(b=i,i=i+8|0,c[b>>2]=1,b)|0)|0;i=b;if(!((h|0)==-1)){i=e;return g|0}yDb(0,48,2162280,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;i=e;return g|0}function dCb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=a[d]|0;if((f|0)==114){g=d;h=0}else if((f|0)==97){g=d;h=1089}else if((f|0)==119){g=d;h=577}else{c[(ld()|0)>>2]=22;j=0;i=e;return j|0}while(1){f=g+1|0;k=a[f]|0;if((k<<24>>24|0)==98){g=f;h=h;continue}else if((k<<24>>24|0)==0){break}else if((k<<24>>24|0)!=43){l=7;break}g=f;h=h&-4|2}if((l|0)==7){c[(ld()|0)>>2]=22;j=0;i=e;return j|0}l=cCb(b,h,(h=i,i=i+8|0,c[h>>2]=438,h)|0)|0;i=h;if((l|0)==-1){j=0;i=e;return j|0}j=Vc(l|0,d|0)|0;i=e;return j|0}function eCb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0.0,e=0,f=0.0,h=0.0,i=0;if((c|0)>0){d=0.0;e=0}else{f=0.0;return+f}while(1){h=d+ +g[a+(e<<2)>>2]*+g[b+(e<<2)>>2];i=e+1|0;if((i|0)<(c|0)){d=h;e=i}else{f=h;break}}return+f}function fCb(a,b){a=a|0;b=b|0;c[a>>2]=310;c[a+4>>2]=4;c[a+8>>2]=6;c[a+12>>2]=2;c[a+16>>2]=400;c[a+20>>2]=286;c[a+24>>2]=760;c[a+28>>2]=2252;c[a+32>>2]=4;return}function gCb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((d|0)>0){e=0}else{return}do{g[a+(e<<2)>>2]=+g[b+(e<<2)>>2]*+g[c+(e<<2)>>2];e=e+1|0;}while((e|0)<(d|0));return}function hCb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0;if((d|0)>0){e=0}else{return}do{f=a+(e<<2)|0;g[f>>2]=+g[f>>2]+ +g[b+(e<<2)>>2]*c;e=e+1|0;}while((e|0)<(d|0));return}function iCb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0;if((d|0)>0){e=0}else{return}do{g[a+(e<<2)>>2]=+g[b+(e<<2)>>2]*c;e=e+1|0;}while((e|0)<(d|0));return}function jCb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0;if((d|0)>0){e=0}else{return}do{h[a+(e<<3)>>3]=+h[b+(e<<3)>>3]*c;e=e+1|0;}while((e|0)<(d|0));return}function kCb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0,n=0.0;if((e|0)<=0){return}f=-e|0;h=e;do{h=h-1|0;i=f+e|0;j=+g[b+(i<<2)>>2];k=+g[c+(h<<2)>>2];l=+g[d+(i<<2)>>2];m=h+e|0;n=+g[d+(m<<2)>>2];g[a+(i<<2)>>2]=j*n-k*l;g[a+(m<<2)>>2]=j*l+k*n;f=f+1|0;}while((f|0)<0);return}function lCb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;if((e|0)>0){f=0}else{return}do{g[a+(f<<2)>>2]=+g[b+(f<<2)>>2]*+g[c+(f<<2)>>2]+ +g[d+(f<<2)>>2];f=f+1|0;}while((f|0)<(e|0));return}function mCb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=d-1|0;if((d|0)>0){f=0}else{return}do{g[a+(f<<2)>>2]=+g[b+(f<<2)>>2]*+g[c+(e-f<<2)>>2];f=f+1|0;}while((f|0)<(d|0));return}function nCb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0,i=0.0;if((c|0)>0){d=0}else{return}do{e=a+(d<<2)|0;f=+g[e>>2];h=b+(d<<2)|0;i=+g[h>>2];g[e>>2]=f+i;g[h>>2]=f-i;d=d+1|0;}while((d|0)<(c|0));return}function oCb(a){a=a|0;var b=0;b=a+416|0;return(F=c[b+4>>2]|0,c[b>>2]|0)|0}function pCb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+416|0;c[e>>2]=b;c[e+4>>2]=d;return}function qCb(a){a=a|0;var b=0;b=a+432|0;return(F=c[b+4>>2]|0,c[b>>2]|0)|0}function rCb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+432|0;c[e>>2]=b;c[e+4>>2]=d;return}function sCb(a){a=a|0;var b=0;b=a+424|0;return(F=c[b+4>>2]|0,c[b>>2]|0)|0}function tCb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+424|0;c[e>>2]=b;c[e+4>>2]=d;return}function uCb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+352|0;c[e>>2]=b;c[e+4>>2]=d;return}function vCb(a){a=a|0;return c[a+448>>2]|0}function wCb(a,b){a=a|0;b=b|0;c[a+448>>2]=b;return}function xCb(a,b){a=a|0;b=b|0;c[a+344>>2]=b;return}function yCb(a,b){a=a|0;b=b|0;c[a+440>>2]=b;return}function zCb(a,b){a=a|0;b=b|0;c[a+444>>2]=b;return}function ACb(a,b){a=a|0;b=b|0;c[a+452>>2]=b;return}function BCb(a){a=a|0;return c[a+456>>2]|0}function CCb(a,b){a=a|0;b=b|0;c[a+456>>2]=b;return}function DCb(a){a=a|0;return c[a+460>>2]|0}function ECb(a,b){a=a|0;b=b|0;c[a+460>>2]=b;return}function FCb(a){a=a|0;return a+440|0}function GCb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=a+464|0;XAb(f);c[f>>2]=b;c[a+176>>2]=c[b+4>>2];c[a+180>>2]=d;c[a+184>>2]=e;return 0}function HCb(a){a=a|0;var b=0;if(a>>>0>8>>>0){b=0;return b|0}b=c[1781208+(a<<2)>>2]|0;return b|0}function ICb(){var a=0,b=0,d=0,e=0;a=cEb(472)|0;if((a|0)==0){b=0;return b|0}d=a+64|0;e=d;c[e>>2]=0;$Db(d);TGb(a|0,0,472)|0;d=a+144|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+152|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+136|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+416|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+432|0;c[d>>2]=0;c[d+4>>2]=0;d=a+424|0;c[d>>2]=-1;c[d+4>>2]=-1;c[a+452>>2]=-1;c[a+84>>2]=1;c[a+124>>2]=0;c[a+128>>2]=1;c[a+80>>2]=-1;c[a+456>>2]=2;c[e>>2]=a;b=a;return b|0}function JCb(a){a=a|0;var b=0;if((a|0)==0){return}b=c[a>>2]|0;if((b|0)==0){return}KCb(b);$Db(a);return}function KCb(a){a=a|0;var b=0,d=0,e=0;b=a+404|0;d=a+400|0;if((c[b>>2]|0)>0){e=0;do{$Db((c[(c[d>>2]|0)+(e<<2)>>2]|0)+4|0);DBb((c[(c[d>>2]|0)+(e<<2)>>2]|0)+12|0);$Db((c[d>>2]|0)+(e<<2)|0);e=e+1|0;}while((e|0)<(c[b>>2]|0))}$Db(d);XAb(a+360|0);XAb(a+364|0);XAb(a+368|0);XAb(a+372|0);XAb(a+376|0);XAb(a+380|0);XAb(a+384|0);XAb(a+388|0);d=a+396|0;b=a+392|0;if((c[d>>2]|0)>0){e=0;do{XAb((c[b>>2]|0)+(e<<2)|0);e=e+1|0;}while((e|0)<(c[d>>2]|0))}$Db(b);DBb(a+440|0);XAb(a+464|0);b=a+64|0;d=a|0;if((c[b>>2]|0)!=(d|0)){$Db(b)}TGb(a|0,0,472)|0;e=a+144|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=a+152|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=a+136|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=a+416|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=a+432|0;c[e>>2]=0;c[e+4>>2]=0;e=a+424|0;c[e>>2]=-1;c[e+4>>2]=-1;c[a+452>>2]=-1;c[a+84>>2]=1;c[a+124>>2]=0;c[a+128>>2]=1;c[a+80>>2]=-1;c[a+456>>2]=2;c[b>>2]=d;return}function LCb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b+80|0;g=c[f>>2]|0;if((g|0)<0){h=-22;return h|0}i=b+68|0;do{if((c[i>>2]|0)>0){j=b+72|0;if((c[j>>2]|0)<=0){break}k=bFb(g)|0;if((k|0)==0){h=-22;return h|0}l=hDb(c[i>>2]|0,c[j>>2]|0,0,0)|0;if((l|0)<0){h=l;return h|0}l=b+32|0;m=c[l>>2]|0;do{if((m|0)==0){n=e-1|0;o=1;p=0;while(1){if((o|0)>(e|0)){q=p;break}r=dDb(l,c[f>>2]|0,o-1+(c[i>>2]|0)&-o)|0;if((r|0)<0){h=r;s=52;break}r=c[l>>2]|0;if((r&n|0)==0){q=r;break}else{o=o<<1;p=r}}if((s|0)==52){return h|0}p=-e|0;if((q|0)==0){s=16;break}o=q+n&p;c[l>>2]=o;r=b+36|0;t=c[r>>2]|0;do{if((t|0)!=0){c[r>>2]=t+n&p;u=b+40|0;v=c[u>>2]|0;if((v|0)==0){break}c[u>>2]=v+n&p;v=b+44|0;u=c[v>>2]|0;if((u|0)==0){break}c[v>>2]=u+n&p}}while(0);if((o|0)==0){s=16}else{w=o;s=14}}else{w=m;s=14}}while(0);do{if((s|0)==14){m=k+6|0;l=UAb(ba((c[j>>2]|0)+31&-32,w)|0|31)|0;c[b+360>>2]=l;if((l|0)==0){break}c[b>>2]=c[l+4>>2];l=c[b+36>>2]|0;if((l|0)==0){s=16;break}p=UAb(31-(ba(-((c[j>>2]|0)+31&-32)>>(d[m]|0),l)|0)|0)|0;c[b+364>>2]=p;if((p|0)==0){break}c[b+4>>2]=c[p+4>>2];p=c[b+40>>2]|0;if((p|0)==0){s=16;break}l=UAb(31-(ba(-((c[j>>2]|0)+31&-32)>>(d[m]|0),p)|0)|0)|0;c[b+368>>2]=l;if((l|0)==0){break}c[b+8>>2]=c[l+4>>2];l=c[b+44>>2]|0;if((l|0)==0){s=16;break}p=UAb(ba((c[j>>2]|0)+31&-32,l)|0|31)|0;c[b+372>>2]=p;if((p|0)==0){break}c[b+12>>2]=c[p+4>>2];s=16}}while(0);do{if((s|0)==16){if(!((a[k+7|0]&66)==0)){j=b+364|0;XAb(j);p=UAb(1024)|0;c[j>>2]=p;if((p|0)==0){break}c[b+4>>2]=c[p+4>>2]}c[b+64>>2]=b;h=0;return h|0}}while(0);KCb(b);h=-12;return h|0}}while(0);w=b+76|0;if((c[w>>2]|0)<=0){h=-22;return h|0}q=b+352|0;i=b+448|0;do{if((c[q>>2]|0)==0&(c[q+4>>2]|0)==0){if((c[i>>2]|0)>0){break}else{h=-22}return h|0}}while(0);k=CFb(g)|0;g=c[i>>2]|0;if((g|0)==0){p=hBb(c[q>>2]|0,c[q+4>>2]|0)|0;c[i>>2]=p;x=p}else{x=g}g=(k|0)!=0?x:1;k=b+32|0;do{if((c[k>>2]|0)==0){p=DFb(k,x,c[w>>2]|0,c[f>>2]|0,e)|0;if((p|0)<0){h=p}else{break}return h|0}}while(0);e=(g|0)>8;do{if(e){f=b+64|0;c[f>>2]=cEb(g<<2)|0;w=g-8|0;x=cEb(w<<2)|0;p=b+392|0;c[p>>2]=x;if(!((c[f>>2]|0)==0|(x|0)==0)){c[b+396>>2]=w;break}$Db(f);$Db(p);h=-12;return h|0}else{c[b+64>>2]=b}}while(0);p=e?8:g;a:do{if((p|0)>0){e=b+64|0;f=0;while(1){w=UAb(c[k>>2]|0)|0;c[b+360+(f<<2)>>2]=w;if((w|0)==0){break}x=c[w+4>>2]|0;c[b+(f<<2)>>2]=x;c[(c[e>>2]|0)+(f<<2)>>2]=x;f=f+1|0;if((f|0)>=(p|0)){break a}}KCb(b);h=-12;return h|0}}while(0);p=g-8|0;if((p|0)<=0){h=0;return h|0}g=b+392|0;f=b+64|0;e=0;while(1){x=UAb(c[k>>2]|0)|0;c[(c[g>>2]|0)+(e<<2)>>2]=x;x=c[(c[g>>2]|0)+(e<<2)>>2]|0;if((x|0)==0){break}c[(c[f>>2]|0)+(e+8<<2)>>2]=c[x+4>>2];x=e+1|0;if((x|0)<(p|0)){e=x}else{h=0;s=52;break}}if((s|0)==52){return h|0}KCb(b);h=-12;return h|0}function MCb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[a+80>>2]=c[b+80>>2];c[a+68>>2]=c[b+68>>2];c[a+72>>2]=c[b+72>>2];d=b+448|0;c[a+448>>2]=c[d>>2];e=b+352|0;f=c[e+4>>2]|0;g=a+352|0;c[g>>2]=c[e>>2];c[g+4>>2]=f;c[a+76>>2]=c[b+76>>2];f=NCb(a,b)|0;if((f|0)<0){h=f;return h|0}f=c[b+360>>2]|0;if((f|0)==0){g=LCb(a,32)|0;if((g|0)<0){h=g;return h|0}g=OCb(a,b)|0;if((g|0)>=0){h=g;return h|0}KCb(a);h=g;return h|0}g=WAb(f)|0;c[a+360>>2]=g;a:do{if((g|0)==0){i=-12}else{f=c[b+364>>2]|0;if((f|0)!=0){e=WAb(f)|0;c[a+364>>2]=e;if((e|0)==0){i=-12;break}}e=c[b+368>>2]|0;if((e|0)!=0){f=WAb(e)|0;c[a+368>>2]=f;if((f|0)==0){i=-12;break}}f=c[b+372>>2]|0;if((f|0)!=0){e=WAb(f)|0;c[a+372>>2]=e;if((e|0)==0){i=-12;break}}e=c[b+376>>2]|0;if((e|0)!=0){f=WAb(e)|0;c[a+376>>2]=f;if((f|0)==0){i=-12;break}}f=c[b+380>>2]|0;if((f|0)!=0){e=WAb(f)|0;c[a+380>>2]=e;if((e|0)==0){i=-12;break}}e=c[b+384>>2]|0;if((e|0)!=0){f=WAb(e)|0;c[a+384>>2]=f;if((f|0)==0){i=-12;break}}f=c[b+388>>2]|0;if((f|0)!=0){e=WAb(f)|0;c[a+388>>2]=e;if((e|0)==0){i=-12;break}}e=b+392|0;b:do{if((c[e>>2]|0)!=0){f=b+396|0;j=cEb(c[f>>2]<<2)|0;k=a+392|0;c[k>>2]=j;if((j|0)==0){i=-12;break a}c[a+396>>2]=c[f>>2];j=0;while(1){if((j|0)>=(c[f>>2]|0)){break b}l=WAb(c[(c[e>>2]|0)+(j<<2)>>2]|0)|0;c[(c[k>>2]|0)+(j<<2)>>2]=l;if((c[(c[k>>2]|0)+(j<<2)>>2]|0)==0){i=-12;break a}else{j=j+1|0}}}}while(0);e=b+64|0;if((c[e>>2]|0)==(b|0)){c[a+64>>2]=a}else{j=c[d>>2]|0;if((j|0)==0){i=-22;break}k=j<<2;j=WDb(k)|0;c[a+64>>2]=j;if((j|0)==0){i=-12;break}UGb(j|0,c[e>>2]|0,k)|0}UGb(a|0,b|0,32)|0;UGb(a+32|0,b+32|0,32)|0;h=0;return h|0}}while(0);KCb(a);h=i;return h|0}function NCb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+8|0;e=d|0;c[a+84>>2]=c[b+84>>2];c[a+88>>2]=c[b+88>>2];f=b+124|0;g=a+124|0;h=c[f+4>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;h=b+136|0;g=c[h+4>>2]|0;f=a+136|0;c[f>>2]=c[h>>2];c[f+4>>2]=g;c[a+292>>2]=c[b+292>>2];c[a+296>>2]=c[b+296>>2];c[a+300>>2]=c[b+300>>2];c[a+304>>2]=c[b+304>>2];c[a+344>>2]=c[b+344>>2];c[a+216>>2]=c[b+216>>2];c[a+288>>2]=c[b+288>>2];g=b+144|0;f=c[g+4>>2]|0;h=a+144|0;c[h>>2]=c[g>>2];c[h+4>>2]=f;f=b+152|0;h=c[f+4>>2]|0;g=a+152|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;h=b+424|0;g=c[h+4>>2]|0;f=a+424|0;c[f>>2]=c[h>>2];c[f+4>>2]=g;c[a+452>>2]=c[b+452>>2];g=b+432|0;f=c[g+4>>2]|0;h=a+432|0;c[h>>2]=c[g>>2];c[h+4>>2]=f;f=b+320|0;h=c[f+4>>2]|0;g=a+320|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;c[a+168>>2]=c[b+168>>2];h=b+416|0;g=c[h+4>>2]|0;f=a+416|0;c[f>>2]=c[h>>2];c[f+4>>2]=g;c[a+160>>2]=c[b+160>>2];c[a+164>>2]=c[b+164>>2];c[a+408>>2]=c[b+408>>2];c[a+444>>2]=c[b+444>>2];c[a+456>>2]=c[b+456>>2];c[a+460>>2]=c[b+460>>2];EBb(a+440|0,c[b+440>>2]|0,0);UGb(a+224|0,b+224|0,64)|0;g=b+404|0;a:do{if((c[g>>2]|0)>0){f=b+400|0;h=e;j=a+404|0;k=a+400|0;l=0;while(1){m=c[(c[f>>2]|0)+(l<<2)>>2]|0;n=c[m>>2]|0;o=m+8|0;p=c[o>>2]|0;q=c[j>>2]|0;if(q>>>0>536870910>>>0){r=q;break}s=XDb(c[k>>2]|0,(q<<2)+4|0)|0;if((s|0)==0){t=9;break}c[k>>2]=s;s=cEb(16)|0;q=s;c[e>>2]=q;if((s|0)==0){t=9;break}u=WDb(p)|0;c[s+4>>2]=u;if((u|0)==0){t=7;break}c[s+8>>2]=p;c[s>>2]=n;n=c[j>>2]|0;c[j>>2]=n+1;c[(c[k>>2]|0)+(n<<2)>>2]=q;q=c[e>>2]|0;if((q|0)==0){t=9;break}UGb(c[q+4>>2]|0,c[m+4>>2]|0,c[o>>2]|0)|0;EBb(q+12|0,c[m+12>>2]|0,0);l=l+1|0;if((l|0)>=(c[g>>2]|0)){break a}}if((t|0)==7){$Db(h);t=9}if((t|0)==9){r=c[j>>2]|0}if((r|0)>0){l=0;do{$Db((c[(c[k>>2]|0)+(l<<2)>>2]|0)+4|0);$Db((c[k>>2]|0)+(l<<2)|0);DBb((c[(c[k>>2]|0)+(l<<2)>>2]|0)+12|0);l=l+1|0;}while((l|0)<(c[j>>2]|0))}$Db(k);v=-12;i=d;return v|0}}while(0);r=a+176|0;c[r>>2]=0;t=a+180|0;c[t>>2]=0;g=a+184|0;c[g>>2]=0;e=c[b+464>>2]|0;if((e|0)==0){v=0;i=d;return v|0}j=WAb(e)|0;c[a+464>>2]=j;if((j|0)==0){v=0;i=d;return v|0}c[r>>2]=c[j+4>>2];c[t>>2]=c[b+180>>2];c[g>>2]=c[b+184>>2];v=0;i=d;return v|0}function OCb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+16|0;e=d|0;f=a+80|0;g=c[f>>2]|0;if((g|0)!=(c[b+80>>2]|0)|(g|0)<0){h=-22;i=d;return h|0}j=a+68|0;k=c[j>>2]|0;do{if((k|0)>0){l=a+72|0;m=c[l>>2]|0;if((m|0)<=0){break}n=e;if((k|0)!=(c[b+68>>2]|0)){h=-22;i=d;return h|0}if((m|0)!=(c[b+72>>2]|0)){h=-22;i=d;return h|0}m=fFb(g)|0;o=0;while(1){if((o|0)>=(m|0)){p=10;break}if((c[a+(o<<2)>>2]|0)==0){h=-22;p=21;break}if((c[b+(o<<2)>>2]|0)==0){h=-22;p=21;break}else{o=o+1|0}}if((p|0)==10){o=b;c[n>>2]=c[o>>2];c[n+4>>2]=c[o+4>>2];c[n+8>>2]=c[o+8>>2];c[n+12>>2]=c[o+12>>2];jDb(a|0,a+32|0,e|0,b+32|0,c[f>>2]|0,c[j>>2]|0,c[l>>2]|0);h=0;i=d;return h|0}else if((p|0)==21){i=d;return h|0}}}while(0);j=a+76|0;if((c[j>>2]|0)<=0){h=-22;i=d;return h|0}e=a+352|0;if((c[e>>2]|0)==0&(c[e+4>>2]|0)==0){h=-22;i=d;return h|0}k=CFb(g)|0;g=c[a+448>>2]|0;o=(k|0)!=0?g:1;k=c[j>>2]|0;if((k|0)!=(c[b+76>>2]|0)){h=-22;i=d;return h|0}if((g|0)!=(c[b+448>>2]|0)){h=-22;i=d;return h|0}j=b+352|0;if(!((c[e>>2]|0)==(c[j>>2]|0)&(c[e+4>>2]|0)==(c[j+4>>2]|0))){h=-22;i=d;return h|0}j=c[a+64>>2]|0;a=b+64|0;b=0;while(1){if((b|0)>=(o|0)){p=20;break}if((c[j+(b<<2)>>2]|0)==0){h=-22;p=21;break}if((c[(c[a>>2]|0)+(b<<2)>>2]|0)==0){h=-22;p=21;break}else{b=b+1|0}}if((p|0)==20){IFb(j,c[a>>2]|0,0,0,k,g,c[f>>2]|0)|0;h=0;i=d;return h|0}else if((p|0)==21){i=d;return h|0}return 0}function PCb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=cEb(472)|0;if((e|0)==0){c[d>>2]=0;f=0;i=b;return f|0}g=e;h=e+64|0;j=h;c[j>>2]=0;$Db(h);TGb(e|0,0,472)|0;h=e+144|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=e+152|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=e+136|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=e+416|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=e+432|0;c[h>>2]=0;c[h+4>>2]=0;h=e+424|0;c[h>>2]=-1;c[h+4>>2]=-1;c[e+452>>2]=-1;c[e+84>>2]=1;c[e+124>>2]=0;c[e+128>>2]=1;c[e+80>>2]=-1;c[e+456>>2]=2;c[j>>2]=e;c[d>>2]=g;if((MCb(g,a)|0)>=0){f=g;i=b;return f|0}KCb(g);$Db(d);f=c[d>>2]|0;i=b;return f|0}function QCb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=b;UGb(a|0,d|0,472)|0;e=b+64|0;f=b|0;if((c[e>>2]|0)==(f|0)){c[a+64>>2]=a;TGb(d|0,0,472)|0}else{TGb(d|0,0,472)|0}$Db(e);TGb(d|0,0,472)|0;d=b+144|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=b+152|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=b+136|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=b+416|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=b+432|0;c[d>>2]=0;c[d+4>>2]=0;d=b+424|0;c[d>>2]=-1;c[d+4>>2]=-1;c[b+452>>2]=-1;c[b+84>>2]=1;c[b+124>>2]=0;c[b+128>>2]=1;c[b+80>>2]=-1;c[b+456>>2]=2;c[e>>2]=f;return}function RCb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+360>>2]|0;if((b|0)==0){d=0;return d|0}e=(YAb(b)|0)!=0;b=c[a+364>>2]|0;if((b|0)==0){f=e}else{f=(YAb(b)|0)!=0&e}e=c[a+368>>2]|0;if((e|0)==0){g=f}else{g=(YAb(e)|0)!=0&f}f=c[a+372>>2]|0;if((f|0)==0){h=g}else{h=(YAb(f)|0)!=0&g}g=c[a+376>>2]|0;if((g|0)==0){i=h}else{i=(YAb(g)|0)!=0&h}h=c[a+380>>2]|0;if((h|0)==0){j=i}else{j=(YAb(h)|0)!=0&i}i=c[a+384>>2]|0;if((i|0)==0){k=j}else{k=(YAb(i)|0)!=0&j}j=c[a+388>>2]|0;if((j|0)==0){l=k}else{l=(YAb(j)|0)!=0&k}k=l&1;l=a+396|0;if((c[l>>2]|0)<=0){d=k;return d|0}j=a+392|0;a=0;i=k;while(1){k=(YAb(c[(c[j>>2]|0)+(a<<2)>>2]|0)|0)!=0&i;h=a+1|0;if((h|0)<(c[l>>2]|0)){a=h;i=k}else{d=k;break}}return d|0}function SCb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+472|0;d=b|0;if((c[a+360>>2]|0)==0){e=-22;i=b;return e|0}if((RCb(a)|0)!=0){e=0;i=b;return e|0}f=d;TGb(f|0,0,472)|0;c[d+80>>2]=c[a+80>>2];c[d+68>>2]=c[a+68>>2];c[d+72>>2]=c[a+72>>2];c[d+448>>2]=c[a+448>>2];g=a+352|0;h=c[g+4>>2]|0;j=d+352|0;c[j>>2]=c[g>>2];c[j+4>>2]=h;c[d+76>>2]=c[a+76>>2];h=LCb(d,32)|0;if((h|0)<0){e=h;i=b;return e|0}h=OCb(d,a)|0;if((h|0)<0){KCb(d);e=h;i=b;return e|0}h=NCb(d,a)|0;if((h|0)<0){KCb(d);e=h;i=b;return e|0}KCb(a);UGb(a|0,f|0,472)|0;if((d|0)!=(c[d+64>>2]|0)){e=0;i=b;return e|0}c[a+64>>2]=a;e=0;i=b;return e|0}function TCb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=a+404|0;h=c[g>>2]|0;if(h>>>0>536870910>>>0){j=0;i=e;return j|0}k=a+400|0;a=XDb(c[k>>2]|0,(h<<2)+4|0)|0;if((a|0)==0){j=0;i=e;return j|0}c[k>>2]=a;a=cEb(16)|0;h=a;c[f>>2]=h;if((a|0)==0){j=0;i=e;return j|0}l=WDb(d)|0;c[a+4>>2]=l;if((l|0)==0){$Db(f);j=0;i=e;return j|0}else{c[a+8>>2]=d;c[a>>2]=b;b=c[g>>2]|0;c[g>>2]=b+1;c[(c[k>>2]|0)+(b<<2)>>2]=h;j=c[f>>2]|0;i=e;return j|0}return 0}function UCb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;do{if((c[a+76>>2]|0)==0){d=4}else{e=c[a+448>>2]|0;if((e|0)==0){f=0;return f|0}else{g=(CFb(c[a+80>>2]|0)|0)!=0;d=g?e:1;break}}}while(0);if(!((b|0)>-1&(d|0)>(b|0))){f=0;return f|0}d=c[(c[a+64>>2]|0)+(b<<2)>>2]|0;if((d|0)==0){f=0;return f|0}b=c[a+360>>2]|0;do{if((b|0)!=0){e=c[b+4>>2]|0;do{if(!(d>>>0<e>>>0)){if(d>>>0<(e+(c[b+8>>2]|0)|0)>>>0){f=b}else{break}return f|0}}while(0);e=c[a+364>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+368>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+372>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+376>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+380>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+384>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+388>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;if(d>>>0<g>>>0){break}if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);b=c[a+396>>2]|0;if((b|0)<=0){f=0;return f|0}e=c[a+392>>2]|0;a=0;while(1){g=c[e+(a<<2)>>2]|0;h=c[g+4>>2]|0;if(!(d>>>0<h>>>0)){if(d>>>0<(h+(c[g+8>>2]|0)|0)>>>0){f=g;i=15;break}}g=a+1|0;if((g|0)<(b|0)){a=g}else{f=0;i=15;break}}if((i|0)==15){return f|0}return 0}function VCb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+400|0;e=c[a+404>>2]|0;a=0;while(1){if((a|0)>=(e|0)){f=0;g=4;break}h=c[(c[d>>2]|0)+(a<<2)>>2]|0;if((c[h>>2]|0)==(b|0)){f=h;g=4;break}else{a=a+1|0}}if((g|0)==4){return f|0}return 0}function WCb(a){a=a|0;return c[981552+(c[a+4>>2]<<3)>>2]|0}function XCb(a){a=a|0;return c[981556+(c[a+4>>2]<<3)>>2]|0}function YCb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;c[a>>2]=0;d=0;while(1){if((d|0)>=15){e=-22;f=18;break}if((yAb(b,c[981552+(d<<3)>>2]|0)|0)==0){break}else{d=d+1|0}}if((f|0)==18){return e|0}if((d|0)>14){e=-22;return e|0}b=cEb(16)|0;g=b;if((b|0)==0){e=-12;return e|0}c[b+4>>2]=d;switch(d|0){case 6:case 7:case 8:{c[b>>2]=JFb()|0;f=13;break};case 0:{h=PDb()|0;c[b>>2]=h;i=h;f=15;break};case 9:case 10:case 11:case 12:{c[b>>2]=PFb()|0;f=13;break};case 2:case 3:case 4:case 5:{c[b>>2]=qFb()|0;f=13;break};case 13:{c[b+8>>2]=tBb(4)|0;break};case 1:{h=lEb()|0;c[b>>2]=h;i=h;f=15;break};default:{f=13}}do{if((f|0)==13){if(!((d-13|0)>>>0>1>>>0)){break}i=c[b>>2]|0;f=15}}while(0);do{if((f|0)==15){if((i|0)!=0){break}ZDb(b);e=-12;return e|0}}while(0);c[a>>2]=g;e=0;return e|0}function ZCb(a){a=a|0;switch(c[a+4>>2]|0){case 4:{rFb(c[a>>2]|0,256)|0;return};case 7:{KFb(c[a>>2]|0,224)|0;return};case 3:{rFb(c[a>>2]|0,160)|0;return};case 2:{rFb(c[a>>2]|0,128)|0;return};case 14:{c[a+12>>2]=1;return};case 0:{QDb(c[a>>2]|0);return};case 10:{QFb(c[a>>2]|0,256)|0;return};case 1:{mEb(c[a>>2]|0);return};case 12:{QFb(c[a>>2]|0,512)|0;return};case 6:{KFb(c[a>>2]|0,160)|0;return};case 8:{KFb(c[a>>2]|0,256)|0;return};case 5:{rFb(c[a>>2]|0,320)|0;return};case 13:{c[a+12>>2]=-1;return};case 9:{QFb(c[a>>2]|0,224)|0;return};case 11:{QFb(c[a>>2]|0,384)|0;return};default:{return}}}function _Cb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;switch(c[a+4>>2]|0){case 0:{RDb(c[a>>2]|0,b,d);return};case 9:case 10:case 11:case 12:{RFb(c[a>>2]|0,b,d);return};case 2:case 3:case 4:case 5:{uFb(c[a>>2]|0,b,d);return};case 14:{e=a+12|0;c[e>>2]=eAb(c[e>>2]|0,b,d)|0;return};case 1:{nEb(c[a>>2]|0,b,d);return};case 13:{e=a+12|0;c[e>>2]=uBb(c[a+8>>2]|0,c[e>>2]|0,b,d)|0;return};case 6:case 7:case 8:{NFb(c[a>>2]|0,b,d);return};default:{return}}}function $Cb(b,d){b=b|0;d=d|0;var e=0;switch(c[b+4>>2]|0){case 9:case 10:case 11:case 12:{TFb(c[b>>2]|0,d);return};case 13:{e=d;x=fe(~c[b+12>>2]|0)|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;return};case 2:case 3:case 4:case 5:{vFb(c[b>>2]|0,d);return};case 6:case 7:case 8:{OFb(c[b>>2]|0,d);return};case 0:{TDb(c[b>>2]|0,d);return};case 1:{oEb(c[b>>2]|0,d);return};case 14:{e=d;x=fe(c[b+12>>2]|0)|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;return};default:{return}}}function aDb(a){a=a|0;var b=0;b=c[a>>2]|0;if((b|0)!=0){$Db(b)}$Db(a);return}function bDb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;TGb(a|0,0,16)|0;if((d|0)==0){f=b[e+8>>1]|0;g=((f&65535)>>>2&7)+1|0;h=a+((f&3)<<2)|0;if((g|0)>(c[h>>2]|0)){c[h>>2]=g}g=b[e+10>>1]|0;h=((g&65535)>>>2&7)+1|0;f=a+((g&3)<<2)|0;if((h|0)>(c[f>>2]|0)){c[f>>2]=h}h=b[e+12>>1]|0;f=((h&65535)>>>2&7)+1|0;g=a+((h&3)<<2)|0;if((f|0)>(c[g>>2]|0)){c[g>>2]=f}f=b[e+14>>1]|0;g=((f&65535)>>>2&7)+1|0;h=a+((f&3)<<2)|0;if((g|0)<=(c[h>>2]|0)){return}c[h>>2]=g;return}else{TGb(d|0,0,16)|0;g=e+8|0;h=b[g>>1]|0;f=((h&65535)>>>2&7)+1|0;i=a+((h&3)<<2)|0;if((f|0)>(c[i>>2]|0)){c[i>>2]=f;c[d+((b[g>>1]&3)<<2)>>2]=0}g=e+10|0;f=b[g>>1]|0;i=((f&65535)>>>2&7)+1|0;h=a+((f&3)<<2)|0;if((i|0)>(c[h>>2]|0)){c[h>>2]=i;c[d+((b[g>>1]&3)<<2)>>2]=1}g=e+12|0;i=b[g>>1]|0;h=((i&65535)>>>2&7)+1|0;f=a+((i&3)<<2)|0;if((h|0)>(c[f>>2]|0)){c[f>>2]=h;c[d+((b[g>>1]&3)<<2)>>2]=2}g=e+14|0;e=b[g>>1]|0;h=((e&65535)>>>2&7)+1|0;f=a+((e&3)<<2)|0;if((h|0)<=(c[f>>2]|0)){return}c[f>>2]=h;c[d+((b[g>>1]&3)<<2)>>2]=3;return}}function cDb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=bFb(b)|0;if(b>>>0>332>>>0){l=-22;i=g;return l|0}b=k+7|0;if(!((a[b]&8)==0)){l=-22;i=g;return l|0}bDb(h|0,j|0,k);m=c[h+(f<<2)>>2]|0;if((k|0)==0|(e|0)<0){l=-22;i=g;return l|0}if(((c[j+(f<<2)>>2]|0)-1|0)>>>0<2>>>0){n=d[k+5|0]|0}else{n=0}k=e-1+(1<<n)>>n;do{if((k|0)!=0){if((2147483647/(k|0)|0|0)<(m|0)){l=-22}else{break}i=g;return l|0}}while(0);n=ba(k,m)|0;if((a[b]&4)==0){l=n;i=g;return l|0}l=n+7>>3;i=g;return l|0}function dDb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=bFb(e)|0;TGb(b|0,0,16)|0;if((k|0)==0){l=-22;i=g;return l|0}e=k+7|0;if(!((a[e]&8)==0)){l=-22;i=g;return l|0}m=h|0;n=j|0;bDb(m,n,k);o=k+5|0;k=f-1|0;if((f|0)<0){l=-22;i=g;return l|0}f=c[m>>2]|0;if(((c[n>>2]|0)-1|0)>>>0<2>>>0){p=d[o]|0}else{p=0}n=k+(1<<p)>>p;do{if((n|0)!=0){if((2147483647/(n|0)|0|0)<(f|0)){l=-22}else{break}i=g;return l|0}}while(0);p=ba(n,f)|0;if((a[e]&4)==0){q=p}else{q=p+7>>3}if((q|0)<0){l=q;i=g;return l|0}c[b>>2]=q;q=c[h+4>>2]|0;if(((c[j+4>>2]|0)-1|0)>>>0<2>>>0){r=d[o]|0}else{r=0}p=k+(1<<r)>>r;do{if((p|0)!=0){if((2147483647/(p|0)|0|0)<(q|0)){l=-22}else{break}i=g;return l|0}}while(0);r=ba(p,q)|0;if((a[e]&4)==0){s=r}else{s=r+7>>3}if((s|0)<0){l=s;i=g;return l|0}c[b+4>>2]=s;s=c[h+8>>2]|0;if(((c[j+8>>2]|0)-1|0)>>>0<2>>>0){t=d[o]|0}else{t=0}r=k+(1<<t)>>t;do{if((r|0)!=0){if((2147483647/(r|0)|0|0)<(s|0)){l=-22}else{break}i=g;return l|0}}while(0);t=ba(r,s)|0;if((a[e]&4)==0){u=t}else{u=t+7>>3}if((u|0)<0){l=u;i=g;return l|0}c[b+8>>2]=u;u=c[h+12>>2]|0;if(((c[j+12>>2]|0)-1|0)>>>0<2>>>0){v=d[o]|0}else{v=0}o=k+(1<<v)>>v;do{if((o|0)!=0){if((2147483647/(o|0)|0|0)<(u|0)){l=-22}else{break}i=g;return l|0}}while(0);v=ba(o,u)|0;if((a[e]&4)==0){w=v}else{w=v+7>>3}if((w|0)<0){l=w;i=g;return l|0}c[b+12>>2]=w;l=0;i=g;return l|0}function eDb(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=i;i=i+16|0;l=k|0;TGb(l|0,0,16)|0;m=bFb(f)|0;TGb(e|0,0,16)|0;if((m|0)==0){n=-22;i=k;return n|0}f=m+7|0;if(!((a[f]&8)==0)){n=-22;i=k;return n|0}c[e>>2]=h;o=c[j>>2]|0;if((o|0)>(2147482623/(g|0)|0|0)){n=-22;i=k;return n|0}p=ba(o,g)|0;if(!((a[f]&66)==0)){f=p+3&-4;c[e+4>>2]=h+f;n=f+1024|0;i=k;return n|0}c[l+((b[m+8>>1]&3)<<2)>>2]=1;c[l+((b[m+10>>1]&3)<<2)>>2]=1;c[l+((b[m+12>>1]&3)<<2)>>2]=1;c[l+((b[m+14>>1]&3)<<2)>>2]=1;f=g-1|0;o=m+6|0;if((c[l+4>>2]|0)==0){n=p;i=k;return n|0}m=d[o]|0;c[e+4>>2]=h+p;q=f+(1<<m)>>m;m=c[j+4>>2]|0;if((m|0)>(2147483647/(q|0)|0|0)){n=-22;i=k;return n|0}r=ba(q,m)|0;if((p|0)>(2147483647-r|0)){n=-22;i=k;return n|0}m=r+p|0;if((c[l+8>>2]|0)==0){n=m;i=k;return n|0}q=d[o]|0;o=p+r|0;c[e+8>>2]=h+o;r=f+(1<<q)>>q;q=c[j+8>>2]|0;if((q|0)>(2147483647/(r|0)|0|0)){n=-22;i=k;return n|0}f=ba(r,q)|0;if((m|0)>(2147483647-f|0)){n=-22;i=k;return n|0}q=f+m|0;if((c[l+12>>2]|0)==0){n=q;i=k;return n|0}c[e+12>>2]=h+(o+f);f=c[j+12>>2]|0;if((f|0)>(2147483647/(g|0)|0|0)){n=-22;i=k;return n|0}else{n=ba(f,g)|0;i=k;return((q|0)>(2147483647-n|0)?-22:n+q|0)|0}return 0}function fDb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==22){d=0;while(1){c[a+(d<<2)>>2]=(ba(d>>5,2359296)|0)-16777216|((d>>>2&7)*9216|0)|((d&3)*85|0);e=d+1|0;if((e|0)<256){d=e}else{f=0;break}}return f|0}else{g=0}while(1){if((b|0)==24){h=-(g&1)&255;i=(g>>>1&3)*85|0;j=(g>>3)*255|0}else if((b|0)==8){h=g;i=g;j=g}else if((b|0)==21){h=(g>>3)*255|0;i=(g>>>1&3)*85|0;j=-(g&1)&255}else if((b|0)==19){h=(g>>6)*85|0;i=(g>>>3&7)*36|0;j=(g&7)*36|0}else{f=-22;k=8;break}c[a+(g<<2)>>2]=(j<<16)-16777216+(i<<8)+h;d=g+1|0;if((d|0)<256){g=d}else{f=0;k=8;break}}if((k|0)==8){return f|0}return 0}function gDb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;i=i+16|0;k=j|0;l=bFb(g)|0;if((l|0)==0){m=-22;i=j;return m|0}n=k;c[k>>2]=913648;c[k+4>>2]=0;c[k+8>>2]=0;do{if((e|0)>0&(f|0)>0){k=gHb(f+128|0,0,e+128|0,0)|0;o=F;p=0;if(!(o>>>0<p>>>0|o>>>0==p>>>0&k>>>0<268435455>>>0)){break}if((h|0)>7){q=e+7&-8}else{q=e}k=dDb(d,g,q)|0;if((k|0)<0){m=k;i=j;return m|0}k=h-1|0;p=-h|0;c[d>>2]=k+(c[d>>2]|0)&p;o=d+4|0;c[o>>2]=k+(c[o>>2]|0)&p;o=d+8|0;c[o>>2]=k+(c[o>>2]|0)&p;o=d+12|0;c[o>>2]=k+(c[o>>2]|0)&p;p=eDb(b,g,f,0,d)|0;if((p|0)<0){m=p;i=j;return m|0}o=WDb(p+h|0)|0;if((o|0)==0){m=-12;i=j;return m|0}p=eDb(b,g,f,o,d)|0;if((p|0)<0){ZDb(o);m=p;i=j;return m|0}if((a[l+7|0]&66)==0){m=p;i=j;return m|0}o=c[b+4>>2]|0;if((g|0)==22){k=0;while(1){c[o+(k<<2)>>2]=(k>>>2&7)*9216|0|((k&3)*85|0)|(ba(k>>5,2359296)|0)-16777216;r=k+1|0;if((r|0)<256){k=r}else{m=p;break}}i=j;return m|0}else{s=0}while(1){if((g|0)==21){t=(s>>3)*255|0;u=(s>>>1&3)*85|0;v=-(s&1)&255}else if((g|0)==19){t=(s>>6)*85|0;u=(s>>>3&7)*36|0;v=(s&7)*36|0}else if((g|0)==8){t=s;u=s;v=s}else if((g|0)==24){t=-(s&1)&255;u=(s>>>1&3)*85|0;v=(s>>3)*255|0}else{m=p;w=20;break}c[o+(s<<2)>>2]=(v<<16)-16777216+(u<<8)+t;k=s+1|0;if((k|0)<256){s=k}else{m=p;w=20;break}}if((w|0)==20){i=j;return m|0}}}while(0);yDb(n,16,2161784,(n=i,i=i+16|0,c[n>>2]=e,c[n+8>>2]=f,n)|0);i=n;m=-22;i=j;return m|0}function hDb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f|0;c[g>>2]=913648;c[g+4>>2]=d;c[g+8>>2]=e;do{if((a|0)>0&(b|0)>0){e=gHb(b+128|0,0,a+128|0,0)|0;d=F;h=0;if(d>>>0<h>>>0|d>>>0==h>>>0&e>>>0<268435455>>>0){j=0}else{break}i=f;return j|0}}while(0);yDb(g,16,2161784,(g=i,i=i+16|0,c[g>>2]=a,c[g+8>>2]=b,g)|0);i=g;j=-22;i=f;return j|0}function iDb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;if((a|0)==0|(d|0)==0){i=h;return}if((((e|0)>-1?e:-e|0)|0)<(f|0)){yDb(0,0,2301032,(j=i,i=i+24|0,c[j>>2]=2171656,c[j+8>>2]=2097448,c[j+16>>2]=248,j)|0);i=j;Cd()}if((((b|0)>-1?b:-b|0)|0)<(f|0)){yDb(0,0,2301032,(j=i,i=i+24|0,c[j>>2]=2042184,c[j+8>>2]=2097448,c[j+16>>2]=249,j)|0);i=j;Cd()}if((g|0)>0){k=d;l=a;m=g}else{i=h;return}while(1){UGb(l|0,k|0,f)|0;g=m-1|0;if((g|0)>0){k=k+e|0;l=l+b|0;m=g}else{break}}i=h;return}function jDb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;m=i;i=i+32|0;n=m|0;o=m+16|0;p=bFb(j)|0;if((p|0)==0){i=m;return}q=d[p+7|0]|0;if((q&8|0)!=0){i=m;return}if((q&66|0)!=0){q=c[e>>2]|0;r=c[f>>2]|0;s=c[g>>2]|0;t=c[h>>2]|0;do{if(!((q|0)==0|(s|0)==0)){if((((t|0)>-1?t:-t|0)|0)<(k|0)){yDb(0,0,2301032,(u=i,i=i+24|0,c[u>>2]=2171656,c[u+8>>2]=2097448,c[u+16>>2]=248,u)|0);i=u;Cd()}if((((r|0)>-1?r:-r|0)|0)<(k|0)){yDb(0,0,2301032,(u=i,i=i+24|0,c[u>>2]=2042184,c[u+8>>2]=2097448,c[u+16>>2]=249,u)|0);i=u;Cd()}if((l|0)>0){v=s;w=q;x=l}else{break}while(1){UGb(w|0,v|0,k)|0;y=x-1|0;if((y|0)>0){v=v+t|0;w=w+r|0;x=y}else{break}}}}while(0);UGb(c[e+4>>2]|0,c[g+4>>2]|0,1024)|0;i=m;return}x=a[p+4|0]|0;if(x<<24>>24==0){i=m;return}r=x&255;x=0;w=0;do{t=(b[p+8+(w<<1)>>1]&3)+1|0;x=(x|0)>(t|0)?x:t;w=w+1|0;}while((w|0)<(r|0));if((x|0)<=0){i=m;return}r=j>>>0>332>>>0;w=n|0;t=o|0;v=(k|0)<0;q=k-1|0;k=-l|0;s=p+6|0;p=0;a:while(1){y=bFb(j)|0;if(r){z=27;break}A=y+7|0;if(!((a[A]&8)==0)){z=27;break}bDb(w,t,y);B=c[n+(p<<2)>>2]|0;if((y|0)==0|v){z=27;break}if(((c[o+(p<<2)>>2]|0)-1|0)>>>0<2>>>0){C=d[y+5|0]|0}else{C=0}y=q+(1<<C)>>C;if((y|0)!=0){if((2147483647/(y|0)|0|0)<(B|0)){z=27;break}}D=ba(y,B)|0;if((a[A]&4)==0){E=D}else{E=D+7>>3}if((E|0)<0){z=27;break}if((p-1|0)>>>0<2>>>0){F=-(k>>(d[s]|0))|0}else{F=l}D=c[e+(p<<2)>>2]|0;A=c[f+(p<<2)>>2]|0;B=c[g+(p<<2)>>2]|0;y=c[h+(p<<2)>>2]|0;do{if(!((D|0)==0|(B|0)==0)){if((((y|0)>-1?y:-y|0)|0)<(E|0)){z=32;break a}if((((A|0)>-1?A:-A|0)|0)<(E|0)){z=35;break a}if((F|0)>0){G=B;H=D;I=F}else{break}while(1){UGb(H|0,G|0,E)|0;J=I-1|0;if((J|0)>0){G=G+y|0;H=H+A|0;I=J}else{break}}}}while(0);A=p+1|0;if((A|0)<(x|0)){p=A}else{z=38;break}}if((z|0)==27){yDb(0,16,1997368,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;i=m;return}else if((z|0)==32){yDb(0,0,2301032,(u=i,i=i+24|0,c[u>>2]=2171656,c[u+8>>2]=2097448,c[u+16>>2]=248,u)|0);i=u;Cd()}else if((z|0)==35){yDb(0,0,2301032,(u=i,i=i+24|0,c[u>>2]=2042184,c[u+8>>2]=2097448,c[u+16>>2]=249,u)|0);i=u;Cd()}else if((z|0)==38){i=m;return}}function kDb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=i;i=i+16|0;k=j|0;l=k;c[k>>2]=913648;c[k+4>>2]=0;c[k+8>>2]=0;do{if((f|0)>0&(g|0)>0){k=gHb(g+128|0,0,f+128|0,0)|0;m=F;n=0;if(!(m>>>0<n>>>0|m>>>0==n>>>0&k>>>0<268435455>>>0)){break}k=dDb(b,e,f)|0;if((k|0)<0){o=k;i=j;return o|0}k=h-1|0;n=-h|0;c[b>>2]=k+(c[b>>2]|0)&n;m=b+4|0;c[m>>2]=k+(c[m>>2]|0)&n;m=b+8|0;c[m>>2]=k+(c[m>>2]|0)&n;m=b+12|0;c[m>>2]=k+(c[m>>2]|0)&n;n=eDb(a,e,f,0,b)|0;if((n|0)<0){o=n;i=j;return o|0}o=eDb(a,e,g,d,b)|0;i=j;return o|0}}while(0);yDb(l,16,2161784,(l=i,i=i+16|0,c[l>>2]=f,c[l+8>>2]=g,l)|0);i=l;o=-22;i=j;return o|0}function lDb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+48|0;h=g|0;j=g+16|0;k=g+32|0;l=bFb(b)|0;if((l|0)==0){m=-22;i=g;return m|0}n=h;c[h>>2]=913648;c[h+4>>2]=0;c[h+8>>2]=0;do{if((d|0)>0&(e|0)>0){h=gHb(e+128|0,0,d+128|0,0)|0;o=F;p=0;if(!(o>>>0<p>>>0|o>>>0==p>>>0&h>>>0<268435455>>>0)){break}if((a[l+7|0]&64)==0){m=kDb(j|0,k|0,0,b,d,e,f)|0;i=g;return m|0}else{m=ba(e,d)|0;i=g;return m|0}}}while(0);yDb(n,16,2161784,(n=i,i=i+16|0,c[n>>2]=d,c[n+8>>2]=e,n)|0);i=n;m=-22;i=g;return m|0}function mDb(e,f,g,h,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;n=i;i=i+64|0;o=n|0;p=n+16|0;q=n+32|0;r=n+48|0;s=bFb(j)|0;t=bFb(j)|0;a:do{if((t|0)==0){u=-22}else{v=o;c[o>>2]=913648;c[o+4>>2]=0;c[o+8>>2]=0;do{if((k|0)>0&(l|0)>0){w=gHb(l+128|0,0,k+128|0,0)|0;x=F;y=0;if(!(x>>>0<y>>>0|x>>>0==y>>>0&w>>>0<268435455>>>0)){break}if((a[t+7|0]&64)==0){u=kDb(p|0,q|0,0,j,k,l,m)|0;break a}else{u=ba(l,k)|0;break a}}}while(0);yDb(v,16,2161784,(w=i,i=i+16|0,c[w>>2]=k,c[w+8>>2]=l,w)|0);i=w;u=-22}}while(0);if((u|0)>(f|0)|(u|0)<0){z=-22;i=n;return z|0}f=a[s+4|0]|0;if(f<<24>>24==0){dDb(r|0,j,k)|0;A=1;B=14}else{q=f&255;f=0;p=0;do{t=b[s+8+(p<<1)>>1]&3;f=(t|0)>(f|0)?t:f;p=p+1|0;}while((p|0)<(q|0));q=f+1|0;dDb(r|0,j,k)|0;if((q|0)>0){A=q;B=14}else{C=e}}if((B|0)==14){B=s+6|0;q=l-1|0;l=m-1|0;k=-m|0;m=0;j=e;while(1){if((m-1|0)>>>0<2>>>0){D=d[B]|0}else{D=0}e=q+(1<<D)>>D;if((e|0)>0){f=r+(m<<2)|0;p=h+(m<<2)|0;t=0;o=j;w=c[g+(m<<2)>>2]|0;y=c[f>>2]|0;while(1){UGb(o|0,w|0,y)|0;x=c[f>>2]|0;E=o+(l+x&k)|0;G=t+1|0;if((G|0)<(e|0)){t=G;o=E;w=w+(c[p>>2]|0)|0;y=x}else{H=E;break}}}else{H=j}y=m+1|0;if((y|0)<(A|0)){m=y;j=H}else{C=H;break}}}if((a[s+7|0]&2)==0){z=u;i=n;return z|0}s=C+3&-4;C=g+4|0;g=0;while(1){H=(c[C>>2]|0)+(g<<2)|0;c[s+(g<<2)>>2]=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24;H=g+1|0;if((H|0)<256){g=H}else{z=u;break}}i=n;return z|0}function nDb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a&1|0)!=0){b=0;return b|0}c=(a&65535|0)==0;d=c?a>>16:a;a=c?17:1;if((d&255|0)==0){e=a|8;f=d>>8}else{e=a;f=d}if((f&15|0)==0){g=e+4|0;h=f>>4}else{g=e;h=f}if((h&3|0)==0){i=g+2|0;j=h>>2}else{i=g;j=h}b=i-(j&1)|0;return b|0}function oDb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;f=e|0;g=f|0;h=f;TGb(h|0,0,16)|0;j=f+4|0;k=j;l=f+8|0;m=f+12|0;f=8;do{c[g>>2]=d;a[k]=f;UDb(h,h,16);c[b+(f<<2)>>2]=c[g>>2];c[b+((f|1)<<2)>>2]=c[j>>2];c[b+((f|2)<<2)>>2]=c[l>>2];c[b+((f|3)<<2)>>2]=c[m>>2];f=f+4|0;}while((f|0)<64);c[b+256>>2]=0;i=e;return}function pDb(a,b,d){a=a|0;b=+b;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0.0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0.0;e=a+296|0;f=a|0;g=c[a+18816>>2]|0;i=(g|0)>0;do{if(i){j=0;while(1){k=j+1|0;l=a+(k*288|0)+(j<<3)|0;if((j|0)>0){m=j;while(1){n=m+1|0;o=+h[e+(j*288|0)+(m<<3)>>3];p=j;do{p=p-1|0;o=o- +h[a+(k*288|0)+(p<<3)>>3]*+h[a+(n*288|0)+(p<<3)>>3];}while((p|0)>0);if((j|0)==(m|0)){h[l>>3]=+R(o<b?1.0:o);q=m+1|0}else{p=m+1|0;h[a+(p*288|0)+(j<<3)>>3]=o/+h[l>>3];q=p}if((q|0)<(g|0)){m=q}else{break}}}else{m=j;while(1){r=+h[e+(j*288|0)+(m<<3)>>3];if((j|0)==(m|0)){h[l>>3]=+R(r<b?1.0:r);s=m+1|0}else{p=m+1|0;h[a+(p*288|0)+(j<<3)>>3]=r/+h[l>>3];s=p}if((s|0)<(g|0)){m=s}else{break}}}if((k|0)<(g|0)){j=k}else{break}}if(i){t=0}else{break}while(1){j=t+1|0;r=+h[a+(j<<3)>>3];if((t|0)>0){u=r;m=t;while(1){l=m-1|0;v=u- +h[a+(j*288|0)+(l<<3)>>3]*+h[a+10368+(l<<3)>>3];if((l|0)>0){u=v;m=l}else{w=v;break}}}else{w=r}h[a+10368+(t<<3)>>3]=w/+h[a+(j*288|0)+(t<<3)>>3];if((j|0)<(g|0)){t=j}else{break}}}}while(0);t=g-1|0;g=d&65535;if((t|0)<(g|0)){return}else{x=t}do{t=x;while(1){w=+h[a+10368+(t<<3)>>3];d=t+1|0;if((d|0)>(x|0)){y=w}else{i=t;b=w;s=d;while(1){w=b- +h[a+((i+2|0)*288|0)+(t<<3)>>3]*+h[a+10368+(x<<8)+(s<<3)>>3];q=s+1|0;if((q|0)>(x|0)){y=w;break}else{i=s;b=w;s=q}}}h[a+10368+(x<<8)+(t<<3)>>3]=y/+h[a+(d*288|0)+(t<<3)>>3];if((t|0)>0){t=t-1|0}else{break}}b=+h[f>>3];t=a+18560+(x<<3)|0;h[t>>3]=b;s=0;r=b;while(1){b=+h[a+10368+(x<<8)+(s<<3)>>3];i=s+1|0;w=b*+h[e+(s*288|0)+(s<<3)>>3]- +h[a+(i<<3)>>3]*2.0;if((s|0)>0){j=0;u=w;while(1){v=u+ +h[a+10368+(x<<8)+(j<<3)>>3]*2.0*+h[e+(j*288|0)+(s<<3)>>3];q=j+1|0;if((q|0)<(s|0)){j=q;u=v}else{z=v;break}}}else{z=w}u=r+z*b;h[t>>3]=u;if((i|0)>(x|0)){break}else{s=i;r=u}}x=x-1|0;}while((x|0)>=(g|0));return}function qDb(a,b){a=a|0;b=b|0;TGb(a|0,0,18848)|0;c[a+18816>>2]=b;c[a+18820>>2]=428;c[a+18824>>2]=2;return}function rDb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;d=a+18816|0;e=c[d>>2]|0;if((e|0)<0){return}else{f=0;g=e}while(1){if((f|0)>(g|0)){i=g}else{e=b+(f<<3)|0;j=f;while(1){k=a+(f*288|0)+(j<<3)|0;h[k>>3]=+h[k>>3]+ +h[e>>3]*+h[b+(j<<3)>>3];k=j+1|0;l=c[d>>2]|0;if((k|0)>(l|0)){i=l;break}else{j=k}}}j=f+1|0;if((j|0)>(i|0)){break}else{f=j;g=i}}return}function sDb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0.0,e=0,f=0.0,g=0.0,i=0;if((c|0)<0){d=0.0;return+d}else{e=0;f=0.0}while(1){g=f+ +h[b+(e<<3)>>3]*+h[a+10368+(c<<8)+(e<<3)>>3];i=e+1|0;if((i|0)>(c|0)){d=g;break}else{e=i;f=g}}return+d}function tDb(a){a=a|0;return c[c[a>>2]>>2]|0}function uDb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0;b=i;i=i+3072|0;j=b|0;vDb(a,d,e,j|0,h,0);h=c[j+1024>>2]|0;e=c[j+2048>>2]|0;Lb(f|0,g|0,2161688,(g=i,i=i+24|0,c[g>>2]=c[j>>2],c[g+8>>2]=h,c[g+16>>2]=e,g)|0)|0;i=g;QAb(j+2048|0,0)|0;i=b;return}function vDb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;if((b|0)==0){k=0}else{k=c[b>>2]|0}IAb(f,0,1);l=f+1024|0;IAb(l,0,1);m=f+2048|0;IAb(m,0,65536);n=(h|0)!=0;if(n){c[h+4>>2]=16;c[h>>2]=16}a:do{if(!((c[g>>2]|0)==0|(k|0)==0)){o=c[k+20>>2]|0;do{if((o|0)!=0){p=c[b+o>>2]|0;if((p|0)==0){break}q=c[p>>2]|0;if((q|0)==0){break}r=p;s=re[c[q+4>>2]&4095](r)|0;KAb(f,2302912,(t=i,i=i+16|0,c[t>>2]=s,c[t+8>>2]=p,t)|0);i=t;if(!n){s=re[c[k+4>>2]&4095](b)|0;KAb(l,2302912,(t=i,i=i+16|0,c[t>>2]=s,c[t+8>>2]=b,t)|0);i=t;break a}s=c[p>>2]|0;do{if((s|0)==0){u=16}else{p=c[s+12>>2]|0;if((p&252)>>>0<100>>>0|(p|0)<3357440){u=16;break}p=c[s+32>>2]|0;if(p>>>0>10>>>0){u=16;break}q=c[s+36>>2]|0;if((q|0)==0){u=p+16|0;break}else{u=(re[q&4095](r)|0)+16|0;break}}}while(0);c[h>>2]=u}}while(0);o=re[c[k+4>>2]&4095](b)|0;KAb(l,2302912,(t=i,i=i+16|0,c[t>>2]=o,c[t+8>>2]=b,t)|0);i=t;if(!n){break}o=c[b>>2]|0;do{if((o|0)==0){v=16}else{r=c[o+12>>2]|0;if((r&252)>>>0<100>>>0|(r|0)<3357440){v=16;break}r=c[o+32>>2]|0;if(r>>>0>10>>>0){v=16;break}s=c[o+36>>2]|0;if((s|0)==0){v=r+16|0;break}else{v=(re[s&4095](b)|0)+16|0;break}}}while(0);c[h+4>>2]=v}}while(0);LAb(m,d,e);do{if((a[c[f>>2]|0]|0)==0){if((a[c[l>>2]|0]|0)!=0){break}if((a[c[m>>2]|0]|0)!=0){break}i=j;return}}while(0);l=c[f+2052>>2]|0;do{if((l|0)==0){w=0;x=32}else{if(l>>>0>(c[f+2056>>2]|0)>>>0){w=0;x=32;break}e=a[(c[m>>2]|0)+(l-1)|0]|0;if(e<<24>>24==10){y=1}else{w=e<<24>>24;x=32}}}while(0);if((x|0)==32){y=(w|0)==13|0}c[g>>2]=y;i=j;return}function wDb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+4104|0;h=g|0;j=g+3072|0;k=g+4096|0;if((c[445296]|0)<(d|0)){i=g;return}l=k|0;vDb(b,e,f,h|0,1781192,l);f=j|0;e=h|0;b=h+1024|0;m=c[b>>2]|0;n=h+2048|0;o=c[n>>2]|0;Lb(f|0,1024,2161688,(q=i,i=i+24|0,c[q>>2]=c[e>>2],c[q+8>>2]=m,c[q+16>>2]=o,q)|0)|0;i=q;o=c[2220792]|0;if((o|0)==0){m=(cd(2)|0)!=0;r=m?1:-1;c[2220792]=r;s=r}else{s=o}do{if((c[445298]|0)==0){t=10}else{if((c[1305362]&1|0)==0){t=10;break}o=(QGb(f,8882144)|0)!=0;if(o|(a[f]|0)==0){t=10;break}if((a[j+((SGb(f|0)|0)-1)|0]|0)==13){t=10;break}o=(c[2220794]|0)+1|0;c[2220794]=o;if((s|0)!=1){break}Dd(c[p>>2]|0,2300992,(q=i,i=i+8|0,c[q>>2]=o,q)|0)|0;i=q}}while(0);if((t|0)==10){t=c[2220794]|0;if((t|0)>0){Dd(c[p>>2]|0,2171608,(q=i,i=i+8|0,c[q>>2]=t,q)|0)|0;i=q;c[2220794]=0}WGb(8882144,f|0)|0;f=c[e>>2]|0;q=a[f]|0;if(q<<24>>24==0){u=f}else{t=f;f=q;do{if((f&255)>>>0<8>>>0|(f-14&255)>>>0<18>>>0){a[t]=63}t=t+1|0;f=a[t]|0;}while(!(f<<24>>24==0));u=c[e>>2]|0}xDb(c[l>>2]|0,u);u=c[b>>2]|0;l=a[u]|0;if(l<<24>>24==0){v=u}else{e=u;u=l;do{if((u&255)>>>0<8>>>0|(u-14&255)>>>0<18>>>0){a[e]=63}e=e+1|0;u=a[e]|0;}while(!(u<<24>>24==0));v=c[b>>2]|0}xDb(c[k+4>>2]|0,v);v=c[n>>2]|0;k=a[v]|0;if(!(k<<24>>24==0)){b=v;v=k;do{if((v&255)>>>0<8>>>0|(v-14&255)>>>0<18>>>0){a[b]=63}b=b+1|0;v=a[b]|0;}while(!(v<<24>>24==0))}v=d>>3;if((v|0)<0){w=0}else{w=(v|0)>6?6:v}xDb(w,c[n>>2]|0)}QAb(h+2048|0,0)|0;i=g;return}function xDb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;if((a[d]|0)==0){i=e;return}f=c[40246]|0;do{if((f|0)<0){do{if((ed(1997352)|0)==0){if((ed(1960928)|0)!=0){g=0;break}if((ed(1933120)|0)!=0){if((cd(2)|0)!=0){g=1;break}}g=(ed(1910168)|0)!=0|0}else{g=0}}while(0);c[40246]=g;if((ed(1889888)|0)==0){h=g;break}j=g<<8;c[40246]=j;h=j}else{h=f}}while(0);f=(b|0)==4;if(!((h|0)!=1|f)){g=c[1426168+(b<<2)>>2]|0;Dd(c[p>>2]|0,2347208,(k=i,i=i+24|0,c[k>>2]=g>>>4&15,c[k+8>>2]=g&15,c[k+16>>2]=d,k)|0)|0;i=k;i=e;return}g=c[p>>2]|0;if((h|0)!=256|f){rb(d|0,g|0)|0;i=e;return}else{f=c[1426168+(b<<2)>>2]|0;Dd(g|0,2326768,(k=i,i=i+24|0,c[k>>2]=f>>>16&255,c[k+8>>2]=f>>>8&255,c[k+16>>2]=d,k)|0)|0;i=k;i=e;return}}function yDb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;do{if((a|0)==0){h=g;c[h>>2]=e;c[h+4>>2]=0;j=b;k=g|0;l=h}else{h=c[a>>2]|0;m=g|0;n=g;c[n>>2]=e;c[n+4>>2]=0;if((h|0)==0){j=b;k=m;l=n;break}if((c[h+12>>2]|0)<=3280641){j=b;k=m;l=n;break}o=c[h+16>>2]|0;if(!((o|0)!=0&(b|0)>7)){j=b;k=m;l=n;break}j=(c[a+o>>2]|0)+b|0;k=m;l=n}}while(0);l=c[445300]|0;if((l|0)==0){i=f;return}cf[l&1023](a,j,d,k);i=f;return}function zDb(){return c[445296]|0}function ADb(a){a=a|0;c[445296]=a;return}function BDb(a){a=a|0;c[1305362]=a;return}function CDb(a){a=a|0;c[445300]=a;return}function DDb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=c[445300]|0;if((g|0)!=0){cf[g&1023](a,24,b,f|0)}yDb(a,24,2097240,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;yDb(a,24,2042040,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=e;return}function EDb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=c[445300]|0;if((g|0)!=0){cf[g&1023](a,24,b,f|0)}yDb(a,24,2097240,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=e;return}function FDb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;h=c[e>>2]|0;i=(h|0)<1;j=c[g>>2]|0;if(i|(j|0)<1){k=(j|0)<1|(i?2:0);return k|0}i=f+j|0;j=b+h|0;l=f+1|0;m=a[f]|0;n=m&255;if((m&255)>>>0>17>>>0){m=n-17|0;o=i-l|0;if((o|0)<(m|0)){p=(o|0)>0?o:0;q=1}else{p=m;q=0}if((p|0)>(h|0)){r=(h|0)>0?h:0;s=q|2}else{r=p;s=q}q=l;p=b;x=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=x;x=x>>8;a[p+1|0]=x;x=x>>8;a[p+2|0]=x;x=x>>8;a[p+3|0]=x;p=r-4|0;if((p|0)>0){UGb(b+4|0,f+5|0,p)|0}p=a[f+(r+1)|0]|0;t=p&255;u=f+(r+2)|0;v=b+r|0;w=(p&255)>>>0<16>>>0?s|8:s}else{t=n;u=l;v=b;w=0}l=i;n=j;j=b;b=t;t=1;s=u;p=v;v=w|u>>>0>i>>>0;a:while(1){b:do{if(t){u=b;w=s;r=p;f=v;while(1){if((f|0)!=0){y=w;z=f;A=r;break a}if((u|0)>15){B=r;C=w;D=u;E=29;break b}q=u&15;if((q|0)==0){h=0;m=w;while(1){if(!(m>>>0<i>>>0)){F=1;G=m;H=1;break}I=m+1|0;J=a[m]|0;if(J<<24>>24==0){h=h+255|0;m=I}else{E=19;break}}if((E|0)==19){E=0;F=J&255;G=I;H=0}K=h+15+F|0;L=G;M=H}else{K=q;L=w;M=0}m=K+3|0;o=l-L|0;if((o|0)<(m|0)){N=(o|0)>0?o:0;O=1}else{N=m;O=M}m=n-r|0;if((N|0)>(m|0)){P=(m|0)>0?m:0;Q=O|2}else{P=N;Q=O}m=L;o=r;x=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=P-4|0;if((o|0)>0){UGb(r+4|0,L+4|0,o)|0}R=r+P|0;S=L+(P+1)|0;o=a[L+P|0]|0;T=o&255;if((o&255)>>>0>15>>>0){u=T;w=S;r=R;f=Q}else{break}}U=(T>>>2)+1+((d[S]|0)<<2|2048)|0;V=1;W=T;X=L+(P+2)|0;Y=R;Z=Q}else{if((v|0)!=0){y=s;z=v;A=p;break a}if((b|0)>15){B=p;C=s;D=b;E=29;break}U=(b>>2)+1+((d[s]|0)<<2)|0;V=0;W=b;X=s+1|0;Y=p;Z=v}}while(0);do{if((E|0)==29){E=0;if((D|0)>63){U=((d[C]|0)<<3|D>>>2&7)+1|0;V=(D>>5)-1|0;W=D;X=C+1|0;Y=B;Z=0;break}if((D|0)>31){f=D&31;if((f|0)==0){r=0;w=C;while(1){if(!(w>>>0<i>>>0)){_=1;$=w;aa=1;break}ba=w+1|0;ca=a[w]|0;if(ca<<24>>24==0){r=r+255|0;w=ba}else{E=35;break}}if((E|0)==35){E=0;_=ca&255;$=ba;aa=0}da=r+31+_|0;ea=$;fa=aa}else{da=f;ea=C;fa=0}w=d[ea]|0;U=((d[ea+1|0]|0)<<6|w>>>2)+1|0;V=da;W=w;X=ea+2|0;Y=B;Z=fa;break}else{w=D&7;if((w|0)==0){u=0;o=C;while(1){if(!(o>>>0<i>>>0)){ga=1;ha=o;ia=1;break}ja=o+1|0;ka=a[o]|0;if(ka<<24>>24==0){u=u+255|0;o=ja}else{E=41;break}}if((E|0)==41){E=0;ga=ka&255;ha=ja;ia=0}la=u+7+ga|0;ma=ha;na=ia}else{la=w;ma=C;na=0}o=d[ma]|0;oa=ma+2|0;f=o>>>2|(D<<11&16384)+16384|(d[ma+1|0]|0)<<6;if((f|0)==16384){E=44;break a}else{U=f;V=la;W=o;X=oa;Y=B;Z=na;break}}}}while(0);o=V+2|0;f=Y;if((f-j|0)<(U|0)){pa=Y;qa=Z|4}else{r=n-f|0;if((r|0)<(o|0)){ra=(r|0)>0?r:0;sa=Z|2}else{ra=o;sa=Z}iEb(Y,U,ra);pa=Y+ra|0;qa=sa}o=W&3;r=l-X|0;if((r|0)<(o|0)){ta=(r|0)>0?r:0;ua=qa|1}else{ta=o;ua=qa}r=n-pa|0;if((ta|0)>(r|0)){va=(r|0)>0?r:0;wa=ua|2}else{va=ta;wa=ua}r=X;f=pa;x=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;f=va-4|0;if((f|0)>0){UGb(pa+4|0,X+4|0,f)|0}b=d[X+va|0]|0;t=(o|0)==0;s=X+(va+1)|0;p=pa+va|0;v=wa}if((E|0)==44){y=oa;z=(la|0)==1?na:na|8;A=B}c[g>>2]=y>>>0>i>>>0?0:l-y|0;c[e>>2]=n-A;k=z;return k|0}function GDb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((c|0)==0&(d|0)==0){e=b;f=a;return(F=e,f)|0}else{g=b;h=a;i=d;j=c}while(1){c=fHb(h,g,j,i)|0;d=F;if((c|0)==0&(d|0)==0){e=i;f=j;break}else{g=i;h=j;i=d;j=c}}return(F=e,f)|0}function HDb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=0;i=0;if((f|0)<(h|0)|(f|0)==(h|0)&e>>>0<1>>>0|((d|0)<(i|0)|(d|0)==(i|0)&c>>>0<0>>>0)){j=-2147483648;k=0;return(F=j,k)|0}i=g&-8193;if(i>>>0>5>>>0|(i|0)==4){j=-2147483648;k=0;return(F=j,k)|0}do{if((g&8192|0)==0){l=g}else{i=YGb(a,b,1,-2147483648)|0;h=F;m=0;if(h>>>0<m>>>0|h>>>0==m>>>0&i>>>0<2>>>0){j=b;k=a;return(F=j,k)|0}else{l=g-8192|0;break}}}while(0);g=0;if(((b|0)<(g|0)|(b|0)==(g|0)&a>>>0<0>>>0)&((a|0)!=0|(b|0)!=(-2147483648|0))){g=ZGb(0,0,a,b)|0;i=HDb(g,F,c,d,e,f,l>>>1&1^l)|0;g=ZGb(0,0,i,F)|0;return(F=F,g)|0}if((l|0)==5){g=eHb(e,f,2,0)|0;n=F;o=g}else{g=(l&1|0)==0;l=YGb(e,f,-1,-1)|0;n=g?0:F;o=g?0:l}l=0;g=0;if(((d|0)<(l|0)|(d|0)==(l|0)&c>>>0<-2147483648>>>0)&((f|0)<(g|0)|(f|0)==(g|0)&e>>>0<-2147483648>>>0)){g=0;if((b|0)<(g|0)|(b|0)==(g|0)&a>>>0<-2147483648>>>0){g=gHb(c,d,a,b)|0;l=YGb(o,n,g,F)|0;g=eHb(l,F,e,f)|0;j=F;k=g;return(F=j,k)|0}else{g=eHb(a,b,e,f)|0;l=gHb(g,F,c,d)|0;g=F;i=fHb(a,b,e,f)|0;m=gHb(i,F,c,d)|0;i=YGb(m,F,o,n)|0;m=eHb(i,F,e,f)|0;i=YGb(m,F,l,g)|0;j=F;k=i;return(F=j,k)|0}}else{i=a|0;a=b&0;g=b;l=(b|0)<0|0?-1:0;b=c|0;c=d&0;m=d;h=(d|0)<0|0?-1:0;d=gHb(m,h,i,a)|0;p=F;q=gHb(b,c,g,l)|0;r=YGb(d,p,q,F)|0;q=F;p=gHb(b,c,i,a)|0;a=XGb(p|0,F|0,0,r|0)|0;p=G;i=F;c=gHb(m,h,g,l)|0;l=YGb(q,0,c,F)|0;c=YGb(l,F,p&1,0)|0;p=F;l=XGb(a|0,i|0,o|0,n|0)|0;n=l;l=F;o=YGb(c,p,G&1,0)|0;p=F;c=o;o=q;q=r;r=63;while(1){i=$Gb(n|0,l|0,r|0)|0;a=c<<1|0>>>31|i&1;i=p<<1|c>>>31|F&0;g=q<<1|0>>>31;h=o<<1|q>>>31;if(i>>>0<f>>>0|i>>>0==f>>>0&a>>>0<e>>>0){s=h;t=g;u=i;v=a}else{m=ZGb(a,i,e,f)|0;s=h|0;t=g|1;u=F;v=m}if((r|0)>0){p=u;c=v;o=s;q=t;r=r-1|0}else{j=s;k=t;break}}return(F=j,k)|0}return 0}function IDb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=HDb(a,b,c,d,e,f,5)|0;return(F=F,g)|0}function JDb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=d;d=i;i=i+8|0;c[d>>2]=c[h>>2];c[d+4>>2]=c[h+4>>2];h=e;e=i;i=i+8|0;c[e>>2]=c[h>>2];c[e+4>>2]=c[h+4>>2];h=c[d>>2]|0;j=c[e+4>>2]|0;k=gHb(j,(j|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=F;j=c[e>>2]|0;e=c[d+4>>2]|0;d=gHb(e,(e|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=HDb(a,b,k,h,d,F,f)|0;f=F;i=g;return(F=f,j)|0}function KDb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=d;d=i;i=i+8|0;c[d>>2]=c[g>>2];c[d+4>>2]=c[g+4>>2];g=e;e=i;i=i+8|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];g=c[d>>2]|0;h=c[e+4>>2]|0;j=gHb(h,(h|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;g=F;h=c[e>>2]|0;e=c[d+4>>2]|0;d=gHb(e,(e|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=HDb(a,b,j,g,d,F,5)|0;d=F;i=f;return(F=d,h)|0}function LDb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=d;d=i;i=i+8|0;c[d>>2]=c[j>>2];c[d+4>>2]=c[j+4>>2];j=g;g=i;i=i+8|0;c[g>>2]=c[j>>2];c[g+4>>2]=c[j+4>>2];j=c[d>>2]|0;k=c[g+4>>2]|0;l=gHb(k,(k|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=F;k=c[g>>2]|0;g=c[d+4>>2]|0;d=gHb(g,(g|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=F;g=-1;m=(b|0)>(g|0)|(b|0)==(g|0)&a>>>0>-1>>>0;g=ZGb(0,0,a,b)|0;n=m?b:F;o=-1;p=(f|0)>(o|0)|(f|0)==(o|0)&e>>>0>-1>>>0;o=ZGb(0,0,e,f)|0;q=(p?f:F)|n|j|k;n=0;if((q|0)<(n|0)|(q|0)==(n|0)&((p?e:o)|(m?a:g)|l|d)>>>0<-2147483648>>>0){g=gHb(l,j,a,b)|0;m=F;o=gHb(d,k,e,f)|0;p=F;r=(((m|0)>(p|0)|(m|0)==(p|0)&g>>>0>o>>>0)&1)-(((m|0)<(p|0)|(m|0)==(p|0)&g>>>0<o>>>0)&1)|0;i=h;return r|0}o=HDb(a,b,l,j,d,k,2)|0;g=F;if((g|0)<(f|0)|(g|0)==(f|0)&o>>>0<e>>>0){r=-1;i=h;return r|0}o=HDb(e,f,d,k,l,j,2)|0;j=F;r=((j|0)<(b|0)|(j|0)==(b|0)&o>>>0<a>>>0)&1;i=h;return r|0}function MDb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ZGb(a,b,c,d)|0;d=F;c=YGb(e,f,-1,-1)|0;b=c&g;g=F&d;d=f>>>1|0<<31;c=g>>>0>d>>>0|g>>>0==d>>>0&b>>>0>(e>>>1|f<<31)>>>0;d=ZGb(b,g,c?e:0,c?f:0)|0;return(F=F,d)|0}function NDb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=i;k=a;a=i;i=i+8|0;c[a>>2]=c[k>>2];c[a+4>>2]=c[k+4>>2];k=e;e=i;i=i+8|0;c[e>>2]=c[k>>2];c[e+4>>2]=c[k+4>>2];k=h;h=i;i=i+8|0;c[h>>2]=c[k>>2];c[h+4>>2]=c[k+4>>2];if((b|0)==0&(d|0)==(-2147483648|0)){yDb(0,0,2161464,(l=i,i=i+24|0,c[l>>2]=2300904,c[l+8>>2]=2171568,c[l+16>>2]=158,l)|0);i=l;Cd();return 0}if(!((f|0)>-1)){yDb(0,0,2161464,(l=i,i=i+24|0,c[l>>2]=2097192,c[l+8>>2]=2171568,c[l+16>>2]=159,l)|0);i=l;Cd();return 0}l=c[g>>2]|0;k=c[g+4>>2]|0;m=c[a>>2]|0;do{if((l|0)==0&(k|0)==(-2147483648|0)|(f|0)==0){n=c[a+4>>2]|0;o=c[h+4>>2]|0;p=c[h>>2]|0}else{q=m;r=(m|0)<0|0?-1:0;s=c[h+4>>2]|0;t=s;u=(s|0)<0|0?-1:0;v=gHb(t,u,q,r)|0;w=F;x=c[h>>2]|0;y=x;z=(x|0)<0|0?-1:0;A=c[a+4>>2]|0;B=A;C=(A|0)<0|0?-1:0;D=gHb(B,C,y,z)|0;E=F;if(!((w|0)>(E|0)|(w|0)==(E|0)&v>>>0>D>>>0)){n=A;o=s;p=x;break}D=b<<1|0>>>31;v=d<<1|b>>>31;E=YGb(D,v,-1,-1)|0;w=F;G=c[e+4>>2]|0;H=G;I=(G|0)<0|0?-1:0;G=gHb(H,I,q,r)|0;r=F;q=c[e>>2]|0;J=q;K=(q|0)<0|0?-1:0;q=gHb(J,K,B,C)|0;C=F;B=HDb(E,w,G,r,q,C,2)|0;w=F;E=B>>>1|w<<31;B=w>>1|((w|0)<0|0?-1:0)<<31;w=HDb(D|1,v|0,G,r,q,C,3)|0;C=YGb(w,F,1,0)|0;w=F;q=C>>>1|w<<31;C=w>>1|((w|0)<0|0?-1:0)<<31;w=ZGb(E<<1|0>>>31,B<<1|E>>>31,q,C)|0;r=F;if((k|0)<(r|0)|(k|0)==(r|0)&l>>>0<w>>>0){n=A;o=s;p=x;break}w=ZGb(q<<1|0>>>31,C<<1|q>>>31,E,B)|0;r=F;if((k|0)>(r|0)|(k|0)==(r|0)&l>>>0>w>>>0){n=A;o=s;p=x;break}if((k|0)<(B|0)|(k|0)==(B|0)&l>>>0<E>>>0){L=B;M=E}else{E=(k|0)>(C|0)|(k|0)==(C|0)&l>>>0>q>>>0;L=E?C:k;M=E?q:l}q=YGb(M,L,f,(f|0)<0|0?-1:0)|0;c[g>>2]=q;c[g+4>>2]=F;q=gHb(t,u,J,K)|0;K=F;J=gHb(H,I,y,z)|0;z=HDb(M,L,q,K,J,F,5)|0;N=F;O=z;i=j;return(F=N,O)|0}}while(0);L=m;M=(m|0)<0|0?-1:0;m=c[e+4>>2]|0;l=gHb(m,(m|0)<0|0?-1:0,L,M)|0;m=F;k=c[e>>2]|0;e=n;a=(n|0)<0|0?-1:0;n=gHb(e,a,k,(k|0)<0|0?-1:0)|0;k=HDb(b,d,l,m,n,F,5)|0;n=YGb(k,F,f,(f|0)<0|0?-1:0)|0;c[g>>2]=n;c[g+4>>2]=F;g=gHb(o,(o|0)<0|0?-1:0,L,M)|0;M=F;L=gHb(e,a,p,(p|0)<0|0?-1:0)|0;p=HDb(b,d,g,M,L,F,5)|0;N=F;O=p;i=j;return(F=N,O)|0}function ODb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+16|0;h=a;a=i;i=i+8|0;c[a>>2]=c[h>>2];c[a+4>>2]=c[h+4>>2];h=e;e=i;i=i+8|0;c[e>>2]=c[h>>2];c[e+4>>2]=c[h+4>>2];h=g|0;j=g+8|0;c[j>>2]=f;c[j+4>>2]=1;jFb(h,e,j);j=c[h>>2]|0;e=c[h+4>>2]|0;h=c[a>>2]|0;f=c[a+4>>2]|0;a=gHb(f,(f|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;k=F;l=gHb(h,(h|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;m=F;do{if((a|0)==(l|0)&(k|0)==(m|0)){if(!((f|0)==0|(e|0)==0)){break}if((j|0)==0|(h|0)==0){n=d;o=b;i=g;return(F=n,o)|0}else{p=(j>>31)-(h>>31)|0;q=6;break}}else{ZGb(a,k,l,m)|0;r=F^((f^e|0)<0|0?-1:0);((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;p=r>>31|((r|0)<0|0?-1:0)<<1|1;q=6}}while(0);do{if((q|0)==6){if((p|0)<0){n=d;o=b}else{break}i=g;return(F=n,o)|0}}while(0);p=HDb(b,d,l,m,a,k,5)|0;q=F;e=HDb(p,q,a,k,l,m,5)|0;f=F;h=YGb(p,q,1,0)|0;q=HDb(h,F,a,k,l,m,5)|0;m=F;l=ZGb(b,d,e,f)|0;f=YGb(l,F,q,m)|0;n=F;o=f;i=g;return(F=n,o)|0}function PDb(){return cEb(88)|0}function QDb(a){a=a|0;var b=0;b=a|0;c[b>>2]=0;c[b+4>>2]=0;c[a+72>>2]=271733878;c[a+76>>2]=-1732584194;c[a+80>>2]=-271733879;c[a+84>>2]=1732584193;return}function RDb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a|0;f=c[e>>2]|0;g=f&63;h=YGb(f,c[e+4>>2]|0,d,(d|0)<0|0?-1:0)|0;c[e>>2]=h;c[e+4>>2]=F;do{if((g|0)==0){i=b;j=d}else{e=64-g|0;h=(e|0)<(d|0)?e:d;UGb(a+8+g|0,b|0,h)|0;if((h+g|0)<64){return}else{SDb(a+72|0,a+8|0,1);i=b+h|0;j=d-h|0;break}}}while(0);d=j&-64;b=i+d|0;do{if((i&3|0)==0){SDb(a+72|0,i,(j|0)/64|0);k=b}else{if((d|0)<=0){k=i;break}g=a+8|0;h=g|0;e=a+72|0;f=g;g=i;while(1){UGb(h|0,g|0,64)|0;SDb(e,f,1);l=g+64|0;if(l>>>0<b>>>0){g=l}else{k=l;break}}}}while(0);b=j&63;if((b|0)==0){return}UGb(a+8|0,k|0,b)|0;return}function SDb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((d|0)<=0){return}e=a+12|0;f=a+8|0;g=a+4|0;h=0;i=c[e>>2]|0;j=c[f>>2]|0;k=c[g>>2]|0;l=c[a>>2]|0;do{m=h<<4;n=c[b+(m<<2)>>2]|0;o=i-680876936+n+((l^k)&j^l)|0;p=(o<<7|o>>>25)+j|0;o=c[b+((m|1)<<2)>>2]|0;q=l-389564586+o+(p&(k^j)^k)|0;r=(q<<12|q>>>20)+p|0;q=c[b+((m|2)<<2)>>2]|0;s=k+606105819+q+(r&(p^j)^j)|0;t=(s<<17|s>>>15)+r|0;s=c[b+((m|3)<<2)>>2]|0;u=j-1044525330+s+(t&(r^p)^p)|0;v=(u<<22|u>>>10)+t|0;u=c[b+((m|4)<<2)>>2]|0;w=u-176418897+p+(v&(t^r)^r)|0;p=(w<<7|w>>>25)+v|0;w=c[b+((m|5)<<2)>>2]|0;x=w+1200080426+r+(p&(v^t)^t)|0;r=(x<<12|x>>>20)+p|0;x=c[b+((m|6)<<2)>>2]|0;y=x-1473231341+t+(r&(p^v)^v)|0;t=(y<<17|y>>>15)+r|0;y=c[b+((m|7)<<2)>>2]|0;z=y-45705983+v+(t&(r^p)^p)|0;v=(z<<22|z>>>10)+t|0;z=c[b+((m|8)<<2)>>2]|0;A=z+1770035416+p+(v&(t^r)^r)|0;p=(A<<7|A>>>25)+v|0;A=c[b+((m|9)<<2)>>2]|0;B=A-1958414417+r+(p&(v^t)^t)|0;r=(B<<12|B>>>20)+p|0;B=c[b+((m|10)<<2)>>2]|0;C=B-42063+t+(r&(p^v)^v)|0;t=(C<<17|C>>>15)+r|0;C=c[b+((m|11)<<2)>>2]|0;D=C-1990404162+v+(t&(r^p)^p)|0;v=(D<<22|D>>>10)+t|0;D=c[b+((m|12)<<2)>>2]|0;E=D+1804603682+p+(v&(t^r)^r)|0;p=(E<<7|E>>>25)+v|0;E=c[b+((m|13)<<2)>>2]|0;F=E-40341101+r+(p&(v^t)^t)|0;r=(F<<12|F>>>20)+p|0;F=c[b+((m|14)<<2)>>2]|0;G=F-1502002290+t+(r&(p^v)^v)|0;t=(G<<17|G>>>15)+r|0;G=c[b+((m|15)<<2)>>2]|0;m=G+1236535329+v+(t&(r^p)^p)|0;v=(m<<22|m>>>10)+t|0;m=o-165796510+p+(v&r|t&~r)|0;p=(m<<5|m>>>27)+v|0;m=x-1069501632+r+(p&t|v&~t)|0;r=(m<<9|m>>>23)+p|0;m=C+643717713+t+(r&v|p&~v)|0;t=(m<<14|m>>>18)+r|0;m=n-373897302+v+(t&p|r&~p)|0;v=(m<<20|m>>>12)+t|0;m=w-701558691+p+(v&r|t&~r)|0;p=(m<<5|m>>>27)+v|0;m=B+38016083+r+(p&t|v&~t)|0;r=(m<<9|m>>>23)+p|0;m=G-660478335+t+(r&v|p&~v)|0;t=(m<<14|m>>>18)+r|0;m=u-405537848+v+(t&p|r&~p)|0;v=(m<<20|m>>>12)+t|0;m=A+568446438+p+(v&r|t&~r)|0;p=(m<<5|m>>>27)+v|0;m=F-1019803690+r+(p&t|v&~t)|0;r=(m<<9|m>>>23)+p|0;m=s-187363961+t+(r&v|p&~v)|0;t=(m<<14|m>>>18)+r|0;m=z+1163531501+v+(t&p|r&~p)|0;v=(m<<20|m>>>12)+t|0;m=E-1444681467+p+(v&r|t&~r)|0;p=(m<<5|m>>>27)+v|0;m=q-51403784+r+(p&t|v&~t)|0;r=(m<<9|m>>>23)+p|0;m=y+1735328473+t+(r&v|p&~v)|0;t=(m<<14|m>>>18)+r|0;m=D-1926607734+v+(t&p|r&~p)|0;v=(m<<20|m>>>12)+t|0;m=w-378558+p+(t^r^v)|0;p=(m<<4|m>>>28)+v|0;m=z-2022574463+r+(v^t^p)|0;r=(m<<11|m>>>21)+p|0;m=C+1839030562+t+(p^v^r)|0;t=(m<<16|m>>>16)+r|0;m=F-35309556+v+(r^p^t)|0;v=(m<<23|m>>>9)+t|0;m=o-1530992060+p+(t^r^v)|0;p=(m<<4|m>>>28)+v|0;m=u+1272893353+r+(v^t^p)|0;r=(m<<11|m>>>21)+p|0;m=y-155497632+t+(p^v^r)|0;t=(m<<16|m>>>16)+r|0;m=B-1094730640+v+(r^p^t)|0;v=(m<<23|m>>>9)+t|0;m=E+681279174+p+(t^r^v)|0;p=(m<<4|m>>>28)+v|0;m=n-358537222+r+(v^t^p)|0;r=(m<<11|m>>>21)+p|0;m=s-722521979+t+(p^v^r)|0;t=(m<<16|m>>>16)+r|0;m=x+76029189+v+(r^p^t)|0;v=(m<<23|m>>>9)+t|0;m=A-640364487+p+(t^r^v)|0;p=(m<<4|m>>>28)+v|0;m=D-421815835+r+(v^t^p)|0;r=(m<<11|m>>>21)+p|0;m=G+530742520+t+(p^v^r)|0;t=(m<<16|m>>>16)+r|0;m=q-995338651+v+(r^p^t)|0;v=(m<<23|m>>>9)+t|0;m=n-198630844+p+((v|~r)^t)|0;p=(m<<6|m>>>26)+v|0;m=y+1126891415+r+((p|~t)^v)|0;r=(m<<10|m>>>22)+p|0;m=F-1416354905+t+((r|~v)^p)|0;t=(m<<15|m>>>17)+r|0;m=w-57434055+v+((t|~p)^r)|0;v=(m<<21|m>>>11)+t|0;m=D+1700485571+p+((v|~r)^t)|0;p=(m<<6|m>>>26)+v|0;m=s-1894986606+r+((p|~t)^v)|0;r=(m<<10|m>>>22)+p|0;m=B-1051523+t+((r|~v)^p)|0;t=(m<<15|m>>>17)+r|0;m=o-2054922799+v+((t|~p)^r)|0;v=(m<<21|m>>>11)+t|0;m=z+1873313359+p+((v|~r)^t)|0;p=(m<<6|m>>>26)+v|0;m=G-30611744+r+((p|~t)^v)|0;r=(m<<10|m>>>22)+p|0;m=x-1560198380+t+((r|~v)^p)|0;t=(m<<15|m>>>17)+r|0;m=E+1309151649+v+((t|~p)^r)|0;v=(m<<21|m>>>11)+t|0;m=u-145523070+p+((v|~r)^t)|0;p=(m<<6|m>>>26)+v|0;m=C-1120210379+r+((p|~t)^v)|0;r=(m<<10|m>>>22)+p|0;m=q+718787259+t+((r|~v)^p)|0;t=(m<<15|m>>>17)+r|0;m=A-343485551+v+((t|~p)^r)|0;l=r+l|0;c[a>>2]=l;k=t+(c[g>>2]|0)|0;c[g>>2]=k;j=t+(c[f>>2]|0)+(m<<21|m>>>11)|0;c[f>>2]=j;i=p+(c[e>>2]|0)|0;c[e>>2]=i;h=h+1|0;}while((h|0)<(d|0));return}function TDb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=b|0;h=c[g>>2]|0;j=c[g+4>>2]<<3|h>>>29;c[f>>2]=h<<3|0>>>29;c[f+4>>2]=j;RDb(b,2161360,1);if(!((c[g>>2]&63|0)==56&(c[g+4>>2]&0|0)==0)){do{RDb(b,9203608,1);}while(!((c[g>>2]&63|0)==56&(c[g+4>>2]&0|0)==0))}RDb(b,f,8);f=d;x=c[b+84>>2]|0;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;f=d+4|0;x=c[b+80>>2]|0;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;f=d+8|0;x=c[b+76>>2]|0;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;f=d+12|0;x=c[b+72>>2]|0;a[f]=x;x=x>>8;a[f+1|0]=x;x=x>>8;a[f+2|0]=x;x=x>>8;a[f+3|0]=x;i=e;return}function UDb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+96|0;g=f|0;h=f+8|0;j=h|0;c[j>>2]=0;c[j+4>>2]=0;k=h+72|0;c[k>>2]=271733878;l=h+76|0;c[l>>2]=-1732584194;m=h+80|0;c[m>>2]=-271733879;n=h+84|0;c[n>>2]=1732584193;RDb(h,d,e);e=g;d=c[j>>2]|0;o=c[j+4>>2]<<3|d>>>29;c[g>>2]=d<<3|0>>>29;c[g+4>>2]=o;RDb(h,2161360,1);if(!((c[j>>2]&63|0)==56&(c[j+4>>2]&0|0)==0)){do{RDb(h,9203608,1);}while(!((c[j>>2]&63|0)==56&(c[j+4>>2]&0|0)==0))}RDb(h,e,8);e=b;x=c[n>>2]|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=b+4|0;x=c[m>>2]|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=b+8|0;x=c[l>>2]|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=b+12|0;x=c[k>>2]|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;i=f;return}function VDb(a){a=a|0;c[169910]=a;return}function WDb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[e>>2]=0;f=c[169910]|0;if((f-32|0)>>>0<a>>>0){g=0;i=b;return g|0}if((a|0)!=0){if((DGb(e,16,a)|0)==0){g=c[e>>2]|0;i=b;return g|0}else{c[e>>2]=0;g=0;i=b;return g|0}}c[d>>2]=0;do{if((f|0)==32){h=0}else{if((DGb(d,16,1)|0)==0){h=c[d>>2]|0;break}else{c[d>>2]=0;h=0;break}}}while(0);c[e>>2]=h;g=h;i=b;return g|0}function XDb(a,b){a=a|0;b=b|0;var d=0;if(((c[169910]|0)-32|0)>>>0<b>>>0){d=0;return d|0}d=AGb(a,((b|0)==0)+b|0)|0;return d|0}function YDb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=ba(d,b)|0;do{if((d|b)>>>0>65535>>>0&(d|0)!=0){if(((e>>>0)/(d>>>0)|0|0)==(b|0)){break}zGb(a);f=0;return f|0}}while(0);if(((c[169910]|0)-32|0)>>>0<e>>>0){g=0}else{g=AGb(a,((e|0)==0)+e|0)|0}if((g|0)!=0|(e|0)==0){f=g;return f|0}zGb(a);f=0;return f|0}function ZDb(a){a=a|0;zGb(a);return}function _Db(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a;a=c[d>>2]|0;if((b|0)==0){zGb(a);c[d>>2]=0;e=0;return e|0}do{if(((c[169910]|0)-32|0)>>>0<b>>>0){f=a}else{g=AGb(a,b)|0;if((g|0)==0){f=c[d>>2]|0;break}c[d>>2]=g;e=0;return e|0}}while(0);zGb(f);c[d>>2]=0;e=-12;return e|0}function $Db(a){a=a|0;var b=0;b=a;zGb(c[b>>2]|0);c[b>>2]=0;return}function aEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;if((d|0)==0){e=0;return e|0}if(!((2147483647/(d>>>0)|0)>>>0>b>>>0)){e=0;return e|0}f=ba(d,b)|0;if(((c[169910]|0)-32|0)>>>0<f>>>0){e=0;return e|0}e=AGb(a,((f|0)==0)+f|0)|0;return e|0}function bEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a;a=c[e>>2]|0;f=ba(d,b)|0;do{if((d|b)>>>0>65535>>>0&(d|0)!=0){if(((f>>>0)/(d>>>0)|0|0)==(b|0)){g=4;break}zGb(a);h=0}else{g=4}}while(0);do{if((g|0)==4){if(((c[169910]|0)-32|0)>>>0<f>>>0){i=0}else{i=AGb(a,((f|0)==0)+f|0)|0}if((i|0)!=0|(f|0)==0){h=i;break}zGb(a);h=0}}while(0);c[e>>2]=h;return((h|0)!=0|(b|0)==0|(d|0)==0?0:-12)|0}function cEb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[e>>2]=0;f=c[169910]|0;if((f-32|0)>>>0<a>>>0){g=0;i=b;return g|0}do{if((a|0)==0){c[d>>2]=0;do{if((f|0)==32){h=0}else{if((DGb(d,16,1)|0)==0){h=c[d>>2]|0;break}else{c[d>>2]=0;h=0;break}}}while(0);c[e>>2]=h;j=h}else{if((DGb(e,16,a)|0)==0){j=c[e>>2]|0;break}c[e>>2]=0;g=0;i=b;return g|0}}while(0);if((j|0)==0){g=0;i=b;return g|0}TGb(j|0,0,a|0)|0;g=j;i=b;return g|0}function dEb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+16|0;e=d|0;f=d+8|0;a:do{if((b|0)==0){g=0}else{if(!((2147483647/(b>>>0)|0)>>>0>a>>>0)){g=0;break}h=ba(b,a)|0;c[f>>2]=0;j=c[169910]|0;if((j-32|0)>>>0<h>>>0){g=0;break}do{if((h|0)==0){c[e>>2]=0;do{if((j|0)==32){k=0}else{if((DGb(e,16,1)|0)==0){k=c[e>>2]|0;break}else{c[e>>2]=0;k=0;break}}}while(0);c[f>>2]=k;l=k}else{if((DGb(f,16,h)|0)==0){l=c[f>>2]|0;break}else{c[f>>2]=0;g=0;break a}}}while(0);if((l|0)==0){g=0;break}TGb(l|0,0,h|0)|0;g=l}}while(0);i=d;return g|0}function eEb(a){a=a|0;var b=0,d=0,e=0;do{if((a|0)==0){b=0}else{d=(SGb(a|0)|0)+1|0;if(((c[169910]|0)-32|0)>>>0<d>>>0){b=0;break}e=AGb(0,((d|0)==0)+d|0)|0;if((e|0)==0){b=0;break}UGb(e|0,a|0,d)|0;b=e}}while(0);return b|0}function fEb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;e=d|0;f=d+8|0;a:do{if((a|0)==0){g=0}else{c[f>>2]=0;h=c[169910]|0;if((h-32|0)>>>0<b>>>0){g=0;break}do{if((b|0)==0){c[e>>2]=0;do{if((h|0)==32){j=0}else{if((DGb(e,16,1)|0)==0){j=c[e>>2]|0;break}else{c[e>>2]=0;j=0;break}}}while(0);c[f>>2]=j;k=j}else{if((DGb(f,16,b)|0)==0){k=c[f>>2]|0;break}else{c[f>>2]=0;g=0;break a}}}while(0);if((k|0)==0){g=0;break}UGb(k|0,a|0,b)|0;g=k}}while(0);i=d;return g|0}function gEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[b>>2]|0;f=a;g=c[f>>2]|0;h=g;a:do{if((e-1&e|0)==0){do{if((e|0)==0){i=4;j=5}else{if(e>>>0>268435455>>>0){k=h;break}i=e<<3;j=5}}while(0);do{if((j|0)==5){if(((c[169910]|0)-32|0)>>>0<i>>>0){k=h;break}l=AGb(g,(i|0)==0|i)|0;m=l;if((l|0)==0){k=c[a>>2]|0;break}else{c[f>>2]=m;n=m;break a}}}while(0);zGb(k);c[a>>2]=0;o=0;c[b>>2]=o;return}else{n=g}}while(0);c[n+(e<<2)>>2]=d;o=e+1|0;c[b>>2]=o;return}function hEb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[b>>2]|0;g=c[a>>2]|0;a:do{if((f-1&f|0)==0){do{if((f|0)==0){h=1;i=5}else{if(f>>>0>(2147483647/(d<<1>>>0)|0)>>>0){j=g;break}h=f<<1;i=5}}while(0);do{if((i|0)==5){k=ba(h,d)|0;if(((c[169910]|0)-32|0)>>>0<k>>>0){j=g;break}l=AGb(g,((k|0)==0)+k|0)|0;if((l|0)==0){j=c[a>>2]|0;break}else{c[a>>2]=l;m=l;break a}}}while(0);zGb(j);c[a>>2]=0;c[b>>2]=0;n=0;return n|0}else{m=g}}while(0);c[b>>2]=f+1;b=m+(ba(f,d)|0)|0;if((e|0)==0){n=b;return n|0}UGb(b|0,e|0,d)|0;n=b;return n|0}function iEb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=b+(-c|0)|0;switch(c|0){case 0:{return};case 3:{g=d[b-1|0]|0;h=(d[b-2|0]|0)<<8|g<<16;i=d[b-3|0]|0;j=h|i;k=j|i<<24;i=j<<16|h>>>8;h=j<<8|g;if((e|0)>11){g=((e-12|0)>>>0)%12|0;j=e;l=b;while(1){m=l;x=k;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+4|0;x=i;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=l+8|0;x=h;a[m]=x;x=x>>8;a[m+1|0]=x;x=x>>8;a[m+2|0]=x;x=x>>8;a[m+3|0]=x;m=j-12|0;if((m|0)>11){j=m;l=l+12|0}else{break}}n=g;o=b+(e-g)|0}else{n=e;o=b}do{if((n|0)>3){g=o;x=k;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;g=o+4|0;l=n-4|0;if((l|0)<=3){p=g;q=l;break}l=g;x=i;a[l]=x;x=x>>8;a[l+1|0]=x;x=x>>8;a[l+2|0]=x;x=x>>8;a[l+3|0]=x;p=o+8|0;q=n-8|0}else{p=o;q=n}}while(0);if((q|0)==0){return}else{r=q;s=p}while(1){p=r-1|0;a[s]=a[s-3|0]|0;if((p|0)==0){break}else{r=p;s=s+1|0}}return};case 2:{s=b-2|0;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;s=r<<16|r;if((e|0)>3){r=e-4|0;p=r&-4;q=b;n=e;while(1){o=q;x=s;a[o]=x;x=x>>8;a[o+1|0]=x;x=x>>8;a[o+2|0]=x;x=x>>8;a[o+3|0]=x;o=n-4|0;if((o|0)>3){q=q+4|0;n=o}else{break}}t=b+(p+4)|0;u=r-p|0}else{t=b;u=e}if((u|0)==0){return}else{v=t;w=u}while(1){u=w-1|0;a[v]=a[v-2|0]|0;if((u|0)==0){break}else{v=v+1|0;w=u}}return};case 1:{TGb(b|0,a[f]|0,e|0)|0;return};case 4:{w=b-4|0;v=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;if((e|0)>3){w=e-4|0;u=w&-4;t=e;p=b;while(1){r=p;x=v;a[r]=x;x=x>>8;a[r+1|0]=x;x=x>>8;a[r+2|0]=x;x=x>>8;a[r+3|0]=x;r=t-4|0;if((r|0)>3){t=r;p=p+4|0}else{break}}y=w-u|0;z=b+(u+4)|0}else{y=e;z=b}if((y|0)==0){return}else{A=y;B=z}while(1){z=A-1|0;a[B]=a[B-4|0]|0;if((z|0)==0){break}else{A=z;B=B+1|0}}return};default:{if((e|0)>15){if((e|0)>(c|0)){B=b;A=e;z=c;while(1){UGb(B|0,f|0,z)|0;y=B+z|0;u=A-z|0;w=z<<1;if((u|0)>(w|0)){B=y;A=u;z=w}else{C=y;D=u;break}}}else{C=b;D=e}UGb(C|0,f|0,D)|0;return}if((e|0)>7){D=f;C=b;x=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;a[C]=x;x=x>>8;a[C+1|0]=x;x=x>>8;a[C+2|0]=x;x=x>>8;a[C+3|0]=x;C=b+(4-c)|0;D=b+4|0;x=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;a[D]=x;x=x>>8;a[D+1|0]=x;x=x>>8;a[D+2|0]=x;x=x>>8;a[D+3|0]=x;E=b+(8-c)|0;F=e-8|0;G=b+8|0}else{E=f;F=e;G=b}if((F|0)>3){b=E;e=G;x=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;H=E+4|0;I=F-4|0;J=G+4|0}else{H=E;I=F;J=G}if((I|0)>1){G=H;F=J;x=(d[G]|d[G+1|0]<<8)<<16>>16;a[F]=x;x=x>>8;a[F+1|0]=x;K=H+2|0;L=I-2|0;M=J+2|0}else{K=H;L=I;M=J}if((L|0)==0){return}a[M]=a[K]|0;return}}}function jEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((c[b>>2]|0)>>>0>d>>>0){e=a;return e|0}f=((d*17|0)>>>4)+32|0;g=f>>>0>d>>>0?f:d;if(((c[169910]|0)-32|0)>>>0<g>>>0){h=0}else{h=AGb(a,((g|0)==0)+g|0)|0}c[b>>2]=(h|0)==0?0:g;e=h;return e|0}function kEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a;if((c[b>>2]|0)>>>0>d>>>0){i=e;return}a=((d*17|0)>>>4)+32|0;j=a>>>0>d>>>0?a:d;zGb(c[h>>2]|0);c[g>>2]=0;d=c[169910]|0;do{if((d-32|0)>>>0<j>>>0){k=0}else{if((j|0)!=0){if((DGb(g,16,j)|0)==0){k=c[g>>2]|0;break}else{c[g>>2]=0;k=0;break}}c[f>>2]=0;do{if((d|0)==32){l=0}else{if((DGb(f,16,1)|0)==0){l=c[f>>2]|0;break}else{c[f>>2]=0;l=0;break}}}while(0);c[g>>2]=l;k=l}}while(0);c[h>>2]=k;c[b>>2]=(k|0)==0?0:j;i=e;return}function lEb(){return cEb(48)|0}function mEb(a){a=a|0;var b=0;TGb(a|0,0,48)|0;b=a+8|0;c[b>>2]=-622998955;c[b+4>>2]=1918553173;b=a|0;c[b>>2]=-622998955;c[b+4>>2]=1918553173;return}function nEb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0;g=b|0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=b+8|0;k=c[j>>2]|0;l=c[j+4>>2]|0;if((f|0)<1){return}m=b+40|0;n=YGb(c[m>>2]|0,c[m+4>>2]|0,f,(f|0)<0|0?-1:0)|0;c[m>>2]=n;c[m+4>>2]=F;m=b+32|0;n=c[m>>2]|0;if((n|0)>0){a:do{if((n|0)<16){o=n;p=f;q=e;while(1){r=a[q]|0;c[m>>2]=o+1;a[b+16+o|0]=r;r=p-1|0;if((r|0)<1){break}s=q+1|0;t=c[m>>2]|0;if((t|0)<16){o=t;p=r;q=s}else{u=r;v=s;break a}}return}else{u=f;v=e}}while(0);c[m>>2]=0;n=b+16|0;q=n|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;gHb(p,n,289559509,-2017231983)|0;q=F;o=gHb(p,n,-2147483648,-2002703894)|0;n=gHb(q>>>1|0<<31|o,0>>>1|0<<31|F,658871167,1291169091)|0;o=F;q=b+24|0;p=q|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=gHb(s,q,658871167,1291169091)|0;r=F;t=gHb(s,q,0,1317742334)|0;q=gHb(p>>>31|r<<1|t,r>>>31|0<<1|F,289559509,-2017231983)|0;r=F;t=n^h;n=o^i;o=YGb(t<<27|0>>>5|(n>>>5|0<<27),n<<27|t>>>5|(0>>>5|0<<27),k,l)|0;t=gHb(o,F,5,0)|0;o=YGb(t,F,1390208809,0)|0;t=F;n=q^k;q=r^l;r=YGb(o,t,n<<31|0>>>1|(q>>>1|0<<31),q<<31|n>>>1|(0>>>1|0<<31))|0;n=gHb(r,F,5,0)|0;r=YGb(n,F,944331445,0)|0;w=F;x=r;y=t;z=o;A=v;B=u}else{w=l;x=k;y=i;z=h;A=e;B=f}f=B&-16;e=A+f|0;if((f|0)>0){f=A;h=y;i=z;k=w;l=x;while(1){u=f;v=u|0;o=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=u+4|0;u=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;gHb(o,u,289559509,-2017231983)|0;v=F;t=gHb(o,u,-2147483648,-2002703894)|0;u=gHb(v>>>1|0<<31|t,0>>>1|0<<31|F,658871167,1291169091)|0;t=F;v=f+8|0;o=v|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=v+4|0;v=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=gHb(r,v,658871167,1291169091)|0;n=F;q=gHb(r,v,0,1317742334)|0;v=gHb(o>>>31|n<<1|q,n>>>31|0<<1|F,289559509,-2017231983)|0;n=F;q=u^i;u=t^h;t=YGb(q<<27|0>>>5|(u>>>5|0<<27),u<<27|q>>>5|(0>>>5|0<<27),l,k)|0;q=gHb(t,F,5,0)|0;t=YGb(q,F,1390208809,0)|0;q=F;u=v^l;v=n^k;n=YGb(t,q,u<<31|0>>>1|(v>>>1|0<<31),v<<31|u>>>1|(0>>>1|0<<31))|0;u=gHb(n,F,5,0)|0;n=YGb(u,F,944331445,0)|0;u=F;v=f+16|0;if(v>>>0<e>>>0){f=v;h=q;i=t;k=u;l=n}else{C=v;D=q;E=t;G=u;H=n;break}}}else{C=A;D=y;E=z;G=w;H=x}c[g>>2]=E;c[g+4>>2]=D;c[j>>2]=H;c[j+4>>2]=G;G=B&15;if((G|0)==0){return}UGb(b+16|0,C|0,G)|0;c[m>>2]=G;return}function oEb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b|0;g=c[f>>2]|0;h=c[f+4>>2]|0;f=b+8|0;i=c[f>>2]|0;j=c[f+4>>2]|0;f=c[b+32>>2]|0;TGb(b+16+f|0,0,16-f|0)|0;f=b+16|0;k=f|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=f+4|0;f=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;gHb(l,f,289559509,-2017231983)|0;k=F;m=gHb(l,f,-2147483648,-2002703894)|0;f=gHb(k>>>1|0<<31|m,0>>>1|0<<31|F,658871167,1291169091)|0;m=b+40|0;k=c[m>>2]|0;l=c[m+4>>2]|0;m=l^h^F;h=b+24|0;b=h|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+4|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=gHb(n,h,658871167,1291169091)|0;o=F;p=gHb(n,h,0,1317742334)|0;h=gHb(b>>>31|o<<1|p,o>>>31|0<<1|F,289559509,-2017231983)|0;o=k^i^h;h=l^j^F;j=YGb(o,h,k^g^f,m)|0;m=F;f=YGb(j,m,o,h)|0;h=F;o=gHb((m>>>1|0<<31)^j,(0>>>1|0<<31)^m,-313160499,-11423785)|0;m=F;j=gHb((m>>>1|0<<31)^o,(0>>>1|0<<31)^m,444984403,-993084930)|0;m=F;o=gHb((h>>>1|0<<31)^f,(0>>>1|0<<31)^h,-313160499,-11423785)|0;h=F;f=gHb((h>>>1|0<<31)^o,(0>>>1|0<<31)^h,444984403,-993084930)|0;h=F;o=(h>>>1|0<<31)^f;f=(0>>>1|0<<31)^h;h=YGb(o,f,(m>>>1|0<<31)^j,(0>>>1|0<<31)^m)|0;m=F;j=YGb(h,m,o,f)|0;f=F;o=e;g=o|0;x=h;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;g=o+4|0;x=m;a[g]=x;x=x>>8;a[g+1|0]=x;x=x>>8;a[g+2|0]=x;x=x>>8;a[g+3|0]=x;g=e+8|0;e=g|0;x=j;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;e=g+4|0;x=f;a[e]=x;x=x>>8;a[e+1|0]=x;x=x>>8;a[e+2|0]=x;x=x>>8;a[e+3|0]=x;return}function pEb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a>>2]|0;a=(b|0)!=0;do{if(!(a|(d|0)==0)){e=c[d+8>>2]|0;if((e|0)==0){break}if((c[e>>2]|0)==0){break}else{f=e}return f|0}}while(0);do{if(a){d=b+48|0;if((c[d>>2]|0)==0){break}else{f=d}return f|0}}while(0);f=0;return f|0}function qEb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return sEb(a,b,c,d,e,0)|0}function rEb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0.0,H=0,I=0,J=0;g=i;i=i+24|0;j=g|0;k=g+8|0;l=g+16|0;m=sEb(b,d,0,0,f,l)|0;f=c[l>>2]|0;if((m|0)==0|(f|0)==0){n=-1414549496;i=g;return n|0}l=(e|0)!=0;do{if(!l){d=c[m+12>>2]|0;if((d|0)==5|(d|0)==1346784596|(d|0)==1397116244|(d|0)==1397316165|(d|0)==1448231252|(d|0)==1146442272|(d|0)==1129270354|(d|0)==1128811585){break}else{n=-22}i=g;return n|0}}while(0);if((c[m+40>>2]&128|0)!=0){n=-22;i=g;return n|0}d=c[m+8>>2]|0;o=f+d|0;p=c[m+12>>2]|0;if((p|0)==0|(p|0)==1|(p|0)==2|(p|0)==4|(p|0)==3|(p|0)==6){n=tEb(b,f,m,e,o)|0;i=g;return n|0}else if((p|0)==1129270354){if((e|0)==0){n=0;i=g;return n|0}q=QEb(o,e,-1,b)|0;if((q|0)>=0){n=q;i=g;return n|0}yDb(b,16,1910648,(r=i,i=i+8|0,c[r>>2]=e,r)|0);i=r;n=q;i=g;return n|0}else if((p|0)==1146442272){q=o;if(!l){c[q>>2]=0;c[q+4>>2]=0;n=0;i=g;return n|0}s=VEb(q,e,1)|0;if((s|0)>=0){n=s;i=g;return n|0}yDb(b,16,2161256,(r=i,i=i+8|0,c[r>>2]=e,r)|0);i=r;n=s;i=g;return n|0}else if((p|0)==1448231252){do{if((e|0)==0){t=-22}else{s=PEb(o,e)|0;if((s|0)<0){t=s;break}else{n=s}i=g;return n|0}}while(0);yDb(b,16,1904064,(r=i,i=i+8|0,c[r>>2]=e,r)|0);i=r;n=t;i=g;return n|0}else if((p|0)==5){$Db(o);c[o>>2]=eEb(e)|0;n=0;i=g;return n|0}else if((p|0)==1128811585){do{if(l){if((QGb(e,2300832)|0)==0){break}t=eBb(e,0)|0;s=F;if((t|0)==0&(s|0)==0){yDb(b,16,2171496,(r=i,i=i+8|0,c[r>>2]=e,r)|0);i=r;u=-22}else{u=0}q=o;c[q>>2]=t;c[q+4>>2]=s;n=u;i=g;return n|0}}while(0);u=o;c[u>>2]=0;c[u+4>>2]=0}else if((p|0)==7){u=o;l=f+(d+4)|0;s=SGb(e|0)|0;$Db(o);c[l>>2]=0;if((s&1|0)!=0){n=-22;i=g;return n|0}q=(s|0)/2|0;s=WDb(q)|0;t=a[e]|0;a:do{if(!(t<<24>>24==0)){v=s;w=e;x=t;while(1){y=w+1|0;z=x<<24>>24;do{if((x-48&255)>>>0<10>>>0){A=z-48|0}else{if((x-97&255)>>>0<6>>>0){A=z-87|0;break}else{A=(x-65&255)>>>0<6>>>0?z-55|0:-1;break}}}while(0);z=w+2|0;B=a[y]|0;C=B<<24>>24;do{if((B-48&255)>>>0<10>>>0){D=C-48|0}else{if((B-97&255)>>>0<6>>>0){D=C-87|0;break}else{D=(B-65&255)>>>0<6>>>0?C-55|0:-1;break}}}while(0);if((D|A|0)<0){break}a[v]=D|A<<4;C=a[z]|0;if(C<<24>>24==0){break a}else{v=v+1|0;w=z;x=C}}ZDb(s);n=-22;i=g;return n|0}}while(0);c[u>>2]=s;c[l>>2]=q;n=0;i=g;return n|0}else if((p|0)==1397116244){do{if((e|0)==0){E=-1}else{if((QGb(e,2300832)|0)==0){E=-1;break}q=xFb(e)|0;if(!((q|0)==-1)){E=q;break}q=kb(e|0,j|0,0)|0;if((a[c[j>>2]|0]|0)==0&q>>>0<10>>>0){E=q;break}yDb(b,16,1907336,(r=i,i=i+16|0,c[r>>2]=e,c[r+8>>2]=1908864,r)|0);i=r;n=-22;i=g;return n|0}}while(0);G=+h[m+24>>3];if(G>-1.0){H=~~G}else{H=-1}G=+h[m+32>>3];j=G>9.0?9:~~G;q=(j|H|0)==0;l=q?-1:H;H=q?9:j;if((E|0)<(l|0)|(E|0)>(H|0)){j=c[m>>2]|0;yDb(b,16,1917032,(r=i,i=i+40|0,c[r>>2]=E,c[r+8>>2]=j,c[r+16>>2]=1908864,c[r+24>>2]=l,c[r+32>>2]=H,r)|0);i=r;n=-34;i=g;return n|0}else{c[o>>2]=E;n=0;i=g;return n|0}}else if((p|0)==1346784596){do{if((e|0)==0){I=-1}else{if((QGb(e,2300832)|0)==0){I=-1;break}E=_Eb(e)|0;if(!((E|0)==-1)){I=E;break}E=kb(e|0,k|0,0)|0;if((a[c[k>>2]|0]|0)==0&E>>>0<333>>>0){I=E;break}yDb(b,16,1907336,(r=i,i=i+16|0,c[r>>2]=e,c[r+8>>2]=1905760,r)|0);i=r;n=-22;i=g;return n|0}}while(0);G=+h[m+24>>3];if(G>-1.0){J=~~G}else{J=-1}G=+h[m+32>>3];k=G>332.0?332:~~G;E=(k|J|0)==0;H=E?-1:J;J=E?332:k;if((I|0)<(H|0)|(I|0)>(J|0)){k=c[m>>2]|0;yDb(b,16,1917032,(r=i,i=i+40|0,c[r>>2]=I,c[r+8>>2]=k,c[r+16>>2]=1905760,c[r+24>>2]=H,c[r+32>>2]=J,r)|0);i=r;n=-34;i=g;return n|0}else{c[o>>2]=I;n=0;i=g;return n|0}}else if((p|0)==1397316165){p=o;do{if((e|0)!=0){if((QGb(e,2300832)|0)==0){break}o=OEb(p,f+(d+4)|0,e)|0;if((o|0)>=0){n=o;i=g;return n|0}yDb(b,16,1902504,(r=i,i=i+8|0,c[r>>2]=e,r)|0);i=r;n=o;i=g;return n|0}}while(0);c[f+(d+4)>>2]=0;c[p>>2]=0;n=0;i=g;return n|0}yDb(b,16,2097128,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;n=-22;i=g;return n|0}function sEb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+8|0;j=h|0;if((a|0)==0){k=0;i=h;return k|0}l=a;m=c[l>>2]|0;if((m|0)==0){k=0;i=h;return k|0}a:do{if((f&1|0)!=0){if((f&2|0)==0){n=0;o=m;while(1){p=c[o+24>>2]|0;if((p|0)==0){break a}q=Oe[p&1023](a,n)|0;if((q|0)==0){break a}p=sEb(q,b,d,e,f,g)|0;if((p|0)!=0){k=p;break}n=q;o=c[l>>2]|0}i=h;return k|0}c[j>>2]=0;o=m+28|0;n=j;while(1){q=c[o>>2]|0;if((q|0)==0){r=7;break}p=re[q&4095](c[j>>2]|0)|0;c[j>>2]=p;if((p|0)==0){break a}p=sEb(n,b,d,e,f,0)|0;if((p|0)!=0){k=p;r=31;break}}if((r|0)==7){c[j>>2]=0;break}else if((r|0)==31){i=h;return k|0}}}while(0);j=c[l>>2]|0;l=(j|0)==0;m=(d|0)==0;n=j+8|0;j=0;while(1){o=(j|0)!=0;do{if(o|l){r=18}else{p=c[n>>2]|0;if((p|0)==0){r=18;break}q=c[p>>2]|0;if((q|0)==0){r=18}else{s=p;t=q}}}while(0);if((r|0)==18){r=0;if(!o){k=0;r=31;break}q=j+48|0;p=c[q>>2]|0;if((p|0)==0|(q|0)==0){k=0;r=31;break}else{s=q;t=p}}if((QGb(t,b)|0)!=0){j=s;continue}if((c[s+40>>2]&e|0)!=(e|0)){j=s;continue}p=(c[s+12>>2]|0)==128;if(m){if(p){j=s;continue}else{r=27;break}}if(!p){j=s;continue}p=c[s+44>>2]|0;if((p|0)==0){j=s;continue}if((QGb(p,d)|0)==0){r=27;break}else{j=s}}if((r|0)==27){if((g|0)==0){k=s;i=h;return k|0}if((f&2|0)==0){c[g>>2]=a;k=s;i=h;return k|0}else{c[g>>2]=0;k=s;i=h;return k|0}}else if((r|0)==31){i=h;return k|0}return 0}function tEb(b,d,e,f,j){b=b|0;d=d|0;e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0,Z=0,_=0.0,$=0.0,ba=0.0;k=i;i=i+288|0;l=k|0;m=k+8|0;n=k+24|0;o=k+280|0;p=xd(f|0,1901432,(q=i,i=i+24|0,c[q>>2]=l,c[q+8>>2]=m,c[q+16>>2]=k+16,q)|0)|0;i=q;do{if((p|0)==2){r=c[l>>2]|0;s=FEb(b,e,j,1.0,c[m>>2]|0,r,(r|0)<0|0?-1:0)|0;if((s|0)>-1){t=s}else{break}i=k;return t|0}}while(0);m=e+12|0;l=n|0;p=e+44|0;s=(d|0)==0;r=e+16|0;u=e+16|0;v=e+32|0;w=e+24|0;x=j;y=j;z=j;A=j;B=j+4|0;C=d;d=f;D=0;F=a[f]|0;a:while(1){do{if((F<<24>>24|0)==43|(F<<24>>24|0)==45){if((c[m>>2]|0)==0){G=d+1|0;H=F<<24>>24;I=0;break}if((D|0)!=0){G=d;H=0;I=0;break}a[l]=F;G=d;H=0;I=1}else{G=d;H=0;I=0}}while(0);f=I;while(1){J=a[G+f|0]|0;if((J<<24>>24|0)==0|(J<<24>>24|0)==43|(J<<24>>24|0)==45){K=f;break}a[n+f|0]=J;J=f+1|0;if(J>>>0<255>>>0){f=J}else{K=J;break}}a[n+K|0]=0;f=c[p>>2]|0;b:do{if(s){L=28}else{J=c[C>>2]|0;if((J|0)==0){L=28;break}M=(f|0)==0;N=J+8|0;J=0;while(1){O=(J|0)!=0;do{if(O){L=19}else{R=c[N>>2]|0;if((R|0)==0){L=28;break b}S=c[R>>2]|0;if((S|0)!=0){T=R;U=S;break}if(O){L=19}else{L=28;break b}}}while(0);if((L|0)==19){L=0;O=J+48|0;S=c[O>>2]|0;if((S|0)==0|(O|0)==0){L=28;break b}else{T=O;U=S}}if((QGb(U,l)|0)!=0){J=T;continue}V=(c[T+12>>2]|0)==128;if(M){if(V){J=T;continue}else{break}}if(!V){J=T;continue}S=c[T+44>>2]|0;if((S|0)==0){J=T;continue}if((QGb(S,f)|0)==0){break}else{J=T}}if((T|0)==0|V^1){L=28;break}J=T+16|0;h[o>>3]=+((c[J>>2]|0)>>>0)+ +(c[J+4>>2]|0)*4294967296.0}}while(0);do{if((L|0)==28){L=0;if((QGb(l,1899960)|0)==0){f=c[m>>2]|0;if((f|0)==2|(f|0)==128|(f|0)==0|(f|0)==1){W=+((c[u>>2]|0)>>>0)+ +(c[u+4>>2]|0)*4294967296.0}else{W=+h[r>>3]}h[o>>3]=W;break}if((QGb(l,1898536)|0)==0){h[o>>3]=+h[v>>3];break}if((QGb(l,1896408)|0)==0){h[o>>3]=+h[w>>3];break}if((QGb(l,2300832)|0)==0){h[o>>3]=0.0;break}if((QGb(l,1890264)|0)==0){h[o>>3]=-1.0;break}else{X=OBb(o,l,1420488,1420456,0,0,0,0,0,0,b)|0;if((X|0)<0){L=42;break a}else{break}}}}while(0);f=c[m>>2]|0;do{if((f|0)==1346784596|(f|0)==1397116244|(f|0)==1){J=c[x>>2]|0;Y=(J|0)<0|0?-1:0;Z=J;_=1.0;$=1.0;L=53}else if((f|0)==128){Y=0;Z=1;_=+h[r>>3];$=1.0;L=53}else if((f|0)==1128811585|(f|0)==1146442272|(f|0)==2){Y=c[y+4>>2]|0;Z=c[y>>2]|0;_=1.0;$=1.0;L=53}else if((f|0)==4){Y=0;Z=1;_=+g[z>>2];$=1.0;L=53}else if((f|0)==3){Y=0;Z=1;_=+h[A>>3];$=1.0;L=53}else if((f|0)==6){J=c[x>>2]|0;Y=(J|0)<0|0?-1:0;Z=J;_=1.0;$=+(c[B>>2]|0);L=53}else if((f|0)==0){J=c[x>>2]|0;M=0;if((H|0)==43){ba=+h[o>>3];h[o>>3]=+((~~+ba>>>0|J)>>>0)+ +((E=+ba,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0)|M|0)*4294967296.0;break}else if((H|0)==45){ba=+h[o>>3];h[o>>3]=+((J&~(~~+ba>>>0))>>>0)+ +(M&~(E=+ba,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0)|0)*4294967296.0;break}else{break}}else{Y=0;Z=1;_=1.0;$=1.0;L=53}}while(0);do{if((L|0)==53){L=0;if((H|0)==43){h[o>>3]=+(D|0)*_*(+(Z>>>0)+ +(Y|0)*4294967296.0)/$+ +h[o>>3];break}else if((H|0)==45){h[o>>3]=+(D|0)*_*(+(Z>>>0)+ +(Y|0)*4294967296.0)/$- +h[o>>3];break}else{break}}}while(0);f=FEb(b,e,j,+h[o>>3],1,1,0)|0;if((f|0)<0){t=f;L=58;break}f=G+K|0;M=a[f]|0;if(M<<24>>24==0){t=0;L=58;break}else{d=f;D=1;F=M}}if((L|0)==42){yDb(b,16,1888520,(q=i,i=i+8|0,c[q>>2]=G,q)|0);i=q;t=X;i=k;return t|0}else if((L|0)==58){i=k;return t|0}return 0}function uEb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;do{if((b|0)==0){f=-22}else{if((c[b+12>>2]|0)!=0){f=-22;break}if((c[b+40>>2]&128|0)!=0){f=-22;break}f=tEb(a,a,b,d,e)|0}}while(0);return f|0}function vEb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+8|0;h=g|0;j=sEb(a,b,0,0,f,h)|0;do{if((j|0)==0){k=-1414549496}else{f=c[h>>2]|0;if((f|0)==0){k=-1414549496;break}if((c[j+40>>2]&128|0)!=0){k=-22;break}k=FEb(a,j,f+(c[j+8>>2]|0)|0,1.0,1,d,e)|0}}while(0);i=g;return k|0}function wEb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+8|0;h=g|0;j=sEb(a,b,0,0,f,h)|0;f=c[h>>2]|0;do{if((j|0)==0|(f|0)==0){k=-1414549496}else{if((c[j+12>>2]|0)!=7){k=-22;break}if((c[j+40>>2]&128|0)!=0){k=-22;break}b=(e|0)!=0;if(b){a=WDb(e)|0;if((a|0)==0){k=-12;break}l=a;m=c[h>>2]|0}else{l=0;m=f}a=c[j+8>>2]|0;n=m+a|0;ZDb(c[n>>2]|0);c[n>>2]=l;c[m+(a+4)>>2]=e;if(!b){k=0;break}UGb(l|0,d|0,e)|0;k=0}}while(0);i=g;return k|0}function xEb(b,e,f,j){b=b|0;e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+136|0;l=k|0;m=k+8|0;n=sEb(b,e,0,0,f,l)|0;f=c[l>>2]|0;if((n|0)==0|(f|0)==0){o=-1414549496;i=k;return o|0}l=c[n+8>>2]|0;e=n+12|0;do{if((l|0)<1){if((c[e>>2]|0)==128){break}else{o=-1414549496}i=k;return o|0}}while(0);b=f+l|0;p=m|0;a[p]=0;m=c[e>>2]|0;if((m|0)==2){e=b;q=c[e+4>>2]|0;r=Lb(p|0,128,2302904,(s=i,i=i+16|0,c[s>>2]=c[e>>2],c[s+8>>2]=q,s)|0)|0;i=s;t=r}else if((m|0)==4){r=Lb(p|0,128,2284920,(s=i,i=i+8|0,h[s>>3]=+g[b>>2],s)|0)|0;i=s;t=r}else if((m|0)==5){r=c[b>>2]|0;if((r|0)==0){u=eEb(9203528)|0}else{u=eEb(r)|0}c[j>>2]=u;o=0;i=k;return o|0}else if((m|0)==3){u=Lb(p|0,128,2284920,(s=i,i=i+8|0,h[s>>3]=+h[b>>3],s)|0)|0;i=s;t=u}else if((m|0)==1){u=Lb(p|0,128,2326760,(s=i,i=i+8|0,c[s>>2]=c[b>>2],s)|0)|0;i=s;t=u}else if((m|0)==128){u=Lb(p|0,128,2284920,(s=i,i=i+8|0,h[s>>3]=+h[n+16>>3],s)|0)|0;i=s;t=u}else if((m|0)==1129270354){u=c[f+(l+4)>>2]|0;n=c[f+(l+8)>>2]|0;r=c[f+(l+12)>>2]|0;q=Lb(p|0,128,2198632,(s=i,i=i+32|0,c[s>>2]=c[b>>2],c[s+8>>2]=u,c[s+16>>2]=n,c[s+24>>2]=r,s)|0)|0;i=s;t=q}else if((m|0)==1448231252|(m|0)==6){q=c[f+(l+4)>>2]|0;r=Lb(p|0,128,2269464,(s=i,i=i+16|0,c[s>>2]=c[b>>2],c[s+8>>2]=q,s)|0)|0;i=s;t=r}else if((m|0)==1397116244){r=wFb(c[b>>2]|0)|0;q=Lb(p|0,128,2216280,(s=i,i=i+8|0,c[s>>2]=(r|0)!=0?r:2300832,s)|0)|0;i=s;t=q}else if((m|0)==1346784596){q=ZEb(c[b>>2]|0)|0;r=Lb(p|0,128,2216280,(s=i,i=i+8|0,c[s>>2]=(q|0)!=0?q:2300832,s)|0)|0;i=s;t=r}else if((m|0)==1146442272){r=b;q=c[r>>2]|0;n=c[r+4>>2]|0;r=eHb(q,n,-694967296,0)|0;u=F;e=eHb(q,n,6e7,0)|0;v=fHb(e,F,60,0)|0;e=eHb(q,n,1e6,0)|0;w=fHb(e,F,60,0)|0;e=fHb(q,n,1e6,0)|0;n=Lb(p|0,128,2206464,(s=i,i=i+40|0,c[s>>2]=r,c[s+8>>2]=u,c[s+16>>2]=v,c[s+24>>2]=w,c[s+32>>2]=e,s)|0)|0;i=s;t=n}else if((m|0)==1128811585){n=b;e=c[n+4>>2]|0;w=Lb(p|0,128,2189608,(s=i,i=i+16|0,c[s>>2]=c[n>>2],c[s+8>>2]=e,s)|0)|0;i=s;t=w}else if((m|0)==0){w=Lb(p|0,128,2347200,(s=i,i=i+8|0,c[s>>2]=c[b>>2],s)|0)|0;i=s;t=w}else if((m|0)==7){w=c[f+(l+4)>>2]|0;e=w;n=((w|0)<0|0?-1:0)<<1|e>>>31;v=0;if(n>>>0>v>>>0|n>>>0==v>>>0&(e<<1|0>>>31)>>>0>2147483647>>>0){o=-22;i=k;return o|0}e=WDb(w<<1|1)|0;c[j>>2]=e;if((e|0)==0){o=-12;i=k;return o|0}v=c[b>>2]|0;if((w|0)>0){x=0;y=e}else{o=0;i=k;return o|0}while(1){Lb(y+(x<<1)|0,3,2254032,(s=i,i=i+8|0,c[s>>2]=d[v+x|0]|0,s)|0)|0;i=s;e=x+1|0;if((e|0)>=(w|0)){o=0;break}x=e;y=c[j>>2]|0}i=k;return o|0}else if((m|0)==1397316165){m=c[f+(l+4)>>2]|0;l=Lb(p|0,128,2227848,(s=i,i=i+16|0,c[s>>2]=c[b>>2],c[s+8>>2]=m,s)|0)|0;i=s;t=l}else{o=-22;i=k;return o|0}if(t>>>0>127>>>0){o=-22;i=k;return o|0}c[j>>2]=eEb(p)|0;o=0;i=k;return o|0}function yEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0,v=0.0;if((a|0)==0){e=-1;f=-1;return(F=e,f)|0}i=c[a>>2]|0;if((i|0)==0){e=-1;f=-1;return(F=e,f)|0}j=i+8|0;i=0;a:while(1){k=(i|0)!=0;do{if(k){l=8}else{m=c[j>>2]|0;if((m|0)==0){e=-1;f=-1;l=23;break a}n=c[m>>2]|0;if((n|0)!=0){o=m;p=n;break}if(k){l=8}else{e=-1;f=-1;l=23;break a}}}while(0);if((l|0)==8){l=0;k=i+48|0;n=c[k>>2]|0;if((n|0)==0|(k|0)==0){e=-1;f=-1;l=23;break}else{o=k;p=n}}if((QGb(p,b)|0)!=0){i=o;continue}q=c[o+12>>2]|0;if((q|0)==128){i=o}else{l=11;break}}if((l|0)==11){if((o|0)==0){e=-1;f=-1;return(F=e,f)|0}i=c[o+8>>2]|0;b=a+i|0;if((d|0)!=0){c[d>>2]=o}if((q|0)==128){r=1.0;s=+h[o+16>>3];t=0;u=1}else if((q|0)==1128811585|(q|0)==1146442272|(q|0)==2){o=b;r=1.0;s=1.0;t=c[o+4>>2]|0;u=c[o>>2]|0}else if((q|0)==4){r=1.0;s=+g[b>>2];t=0;u=1}else if((q|0)==0){r=1.0;s=1.0;t=0;u=c[b>>2]|0}else if((q|0)==3){r=1.0;s=+h[b>>3];t=0;u=1}else if((q|0)==1346784596|(q|0)==1397116244|(q|0)==1){o=c[b>>2]|0;r=1.0;s=1.0;t=(o|0)<0|0?-1:0;u=o}else if((q|0)==6){q=c[b>>2]|0;r=+(c[a+(i+4)>>2]|0);s=1.0;t=(q|0)<0|0?-1:0;u=q}else{e=-1;f=-1;return(F=e,f)|0}v=s*(+(u>>>0)+ +(t|0)*4294967296.0)/r;e=(E=+v,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);f=~~+v>>>0;return(F=e,f)|0}else if((l|0)==23){return(F=e,f)|0}return 0}function zEb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0,q=0,r=0.0;f=i;i=i+8|0;j=f|0;k=sEb(a,b,0,0,d,j)|0;if((k|0)==0){l=-1;i=f;return l|0}d=c[j>>2]|0;if((d|0)==0){l=-1;i=f;return l|0}j=c[k+8>>2]|0;b=d+j|0;a=c[k+12>>2]|0;if((a|0)==3){m=1.0;n=+h[b>>3];o=0;p=1}else if((a|0)==6){q=c[b>>2]|0;m=+(c[d+(j+4)>>2]|0);n=1.0;o=(q|0)<0|0?-1:0;p=q}else if((a|0)==1346784596|(a|0)==1397116244|(a|0)==1){q=c[b>>2]|0;m=1.0;n=1.0;o=(q|0)<0|0?-1:0;p=q}else if((a|0)==0){m=1.0;n=1.0;o=0;p=c[b>>2]|0}else if((a|0)==128){m=1.0;n=+h[k+16>>3];o=0;p=1}else if((a|0)==4){m=1.0;n=+g[b>>2];o=0;p=1}else if((a|0)==1128811585|(a|0)==1146442272|(a|0)==2){a=b;m=1.0;n=1.0;o=c[a+4>>2]|0;p=c[a>>2]|0}else{l=-22;i=f;return l|0}r=n*(+(p>>>0)+ +(o|0)*4294967296.0)/m;o=(E=+r,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);c[e>>2]=~~+r>>>0;c[e+4>>2]=o;l=0;i=f;return l|0}function AEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0,D=0,F=0.0;if((a|0)==0){e=0;return e|0}f=c[a>>2]|0;i=(f|0)==0;if(i){e=0;return e|0}j=f+8|0;k=0;a:while(1){l=(k|0)!=0;do{if(l){m=8}else{n=c[j>>2]|0;if((n|0)==0){o=1;p=0;break a}q=c[n>>2]|0;if((q|0)!=0){r=n;s=q;break}if(l){m=8}else{o=1;p=0;break a}}}while(0);if((m|0)==8){m=0;l=k+48|0;q=c[l>>2]|0;if((q|0)==0|(l|0)==0){o=1;p=0;break}else{r=l;s=q}}if((QGb(s,b)|0)!=0){k=r;continue}if((c[r+12>>2]|0)==128){k=r}else{m=11;break}}do{if((m|0)==11){if((r|0)==0){o=1;p=0;break}o=0;p=c[r+44>>2]|0}}while(0);if(i){e=0;return e|0}i=(p|0)==0;r=f+8|0;f=0;b:while(1){k=(f|0)!=0;do{if(k){m=19}else{s=c[r>>2]|0;if((s|0)==0){e=0;m=43;break b}j=c[s>>2]|0;if((j|0)!=0){t=s;u=j;break}if(k){m=19}else{e=0;m=43;break b}}}while(0);if((m|0)==19){m=0;k=f+48|0;j=c[k>>2]|0;if((j|0)==0|(k|0)==0){e=0;m=43;break}else{t=k;u=j}}if((QGb(u,d)|0)!=0){f=t;continue}v=c[t+12>>2]|0;j=(v|0)==128;if(i){if(j){f=t;continue}else{m=26;break}}if(!j){f=t;continue}j=c[t+44>>2]|0;if((j|0)==0){f=t;continue}if((QGb(j,p)|0)==0){m=26;break}else{f=t}}if((m|0)==26){if((v|0)==128&(((t|0)==0|o)^1)){w=0}else{e=0;return e|0}c:while(1){o=(w|0)!=0;do{if(o){m=31}else{v=c[r>>2]|0;if((v|0)==0){e=0;m=43;break c}f=c[v>>2]|0;if((f|0)!=0){x=v;y=f;break}if(o){m=31}else{e=0;m=43;break c}}}while(0);if((m|0)==31){m=0;o=w+48|0;f=c[o>>2]|0;if((f|0)==0|(o|0)==0){e=0;m=43;break}else{x=o;y=f}}if((QGb(y,b)|0)!=0){w=x;continue}z=c[x+12>>2]|0;if((z|0)==128){w=x}else{m=34;break}}if((m|0)==34){if((x|0)==0){e=0;return e|0}w=c[x+8>>2]|0;x=a+w|0;if((z|0)==1346784596|(z|0)==1397116244|(z|0)==1){b=c[x>>2]|0;A=1.0;B=1.0;C=(b|0)<0|0?-1:0;D=b}else if((z|0)==3){A=1.0;B=+h[x>>3];C=0;D=1}else if((z|0)==6){b=c[x>>2]|0;A=+(c[a+(w+4)>>2]|0);B=1.0;C=(b|0)<0|0?-1:0;D=b}else if((z|0)==1128811585|(z|0)==1146442272|(z|0)==2){b=x;A=1.0;B=1.0;C=c[b+4>>2]|0;D=c[b>>2]|0}else if((z|0)==0){A=1.0;B=1.0;C=0;D=c[x>>2]|0}else if((z|0)==4){A=1.0;B=+g[x>>2];C=0;D=1}else{e=0;return e|0}F=B*(+(D>>>0)+ +(C|0)*4294967296.0)/A;C=~~+F>>>0;E=+F,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0;e=C&c[t+16>>2];return e|0}else if((m|0)==43){return e|0}}else if((m|0)==43){return e|0}return 0}function BEb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;if((a|0)==0){g=-1;i=f;return g|0}yDb(b,32,2156568,(h=i,i=i+8|0,c[h>>2]=c[c[a>>2]>>2],h)|0);i=h;CEb(a,b,0,d,e);g=0;i=f;return g|0}function CEb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+16|0;j=g|0;k=g+8|0;l=a;m=(d|0)==0;n=j;o=k|0;p=k+4|0;q=0;while(1){r=c[l>>2]|0;s=(q|0)!=0;do{if(s|(r|0)==0){t=5}else{u=c[r+8>>2]|0;if((u|0)==0){t=5;break}v=c[u>>2]|0;if((v|0)==0){t=5}else{w=u;x=v}}}while(0);if((t|0)==5){t=0;if(!s){t=62;break}r=q+48|0;v=c[r>>2]|0;if((v|0)==0|(r|0)==0){t=62;break}else{w=r;x=v}}v=w+40|0;r=c[v>>2]|0;if((r&e|0)==0){q=w;continue}if((r&f|0)!=0){q=w;continue}u=w+12|0;y=(c[u>>2]|0)==128;if(m){if(y){q=w;continue}yDb(b,32,2067232,(z=i,i=i+16|0,c[z>>2]=(r&65536|0)!=0?9203528:2063e3,c[z+8>>2]=x,z)|0);i=z}else{if(!y){q=w;continue}if((QGb(d,c[w+44>>2]|0)|0)!=0){q=w;continue}yDb(b,32,2071944,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z}y=c[u>>2]|0;if((y|0)==1){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2043272,z)|0);i=z}else if((y|0)==1448231252){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2012872,z)|0);i=z}else if((y|0)==1146442272){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=1994280,z)|0);i=z}else if((y|0)==1128811585){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=1987456,z)|0);i=z}else if((y|0)==1397116244){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=1998096,z)|0);i=z}else if((y|0)==3){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2035568,z)|0);i=z}else if((y|0)==1129270354){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=1990984,z)|0);i=z}else if((y|0)==1397316165){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2016840,z)|0);i=z}else if((y|0)==1346784596){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2008104,z)|0);i=z}else if((y|0)==0){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2053816,z)|0);i=z}else if((y|0)==2){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2038760,z)|0);i=z}else if((y|0)==6){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2024056,z)|0);i=z}else if((y|0)==5){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2027512,z)|0);i=z}else if((y|0)==4){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2031760,z)|0);i=z}else if((y|0)==7){yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=2020648,z)|0);i=z}else{yDb(b,32,2059264,(z=i,i=i+8|0,c[z>>2]=9203528,z)|0);i=z}yDb(b,32,1983232,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&1|0)!=0?69:46,z)|0);i=z;yDb(b,32,1983232,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&2|0)!=0?68:46,z)|0);i=z;yDb(b,32,1983232,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&65536|0)!=0?70:46,z)|0);i=z;yDb(b,32,1983232,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&16|0)!=0?86:46,z)|0);i=z;yDb(b,32,1983232,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&8|0)!=0?65:46,z)|0);i=z;yDb(b,32,1983232,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&32|0)!=0?83:46,z)|0);i=z;yDb(b,32,1983232,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&64|0)!=0?88:46,z)|0);i=z;yDb(b,32,1983232,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&128|0)!=0?82:46,z)|0);i=z;v=c[w+4>>2]|0;if((v|0)!=0){yDb(b,32,1980384,(z=i,i=i+8|0,c[z>>2]=v,z)|0);i=z}v=c[l>>2]|0;if((c[v+12>>2]|0)>3410688){A=c[v+40>>2]|0}else{A=0}if((_e[((A|0)==0?446:A)&1023](j,a,c[w>>2]|0,2)|0)>-1){a:do{switch(c[u>>2]|0){case 1:case 2:case 3:case 4:case 6:{v=c[j>>2]|0;if((c[v+4>>2]|0)>0){B=0}else{C=v;break a}while(1){yDb(b,32,1977600,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;MEb(b,+h[(c[(c[c[j>>2]>>2]|0)+(B<<2)>>2]|0)+8>>3]);yDb(b,32,1975048,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;MEb(b,+h[(c[(c[c[j>>2]>>2]|0)+(B<<2)>>2]|0)+16>>3]);yDb(b,32,1973184,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;v=B+1|0;y=c[j>>2]|0;if((v|0)<(c[y+4>>2]|0)){B=v}else{C=y;break}}break};default:{C=c[j>>2]|0}}}while(0);s=C+4|0;y=c[s>>2]|0;if((y|0)>0){v=C|0;r=0;D=y;while(1){y=c[(c[v>>2]|0)+(r<<2)>>2]|0;if((y|0)==0){E=D}else{$Db(y);$Db((c[v>>2]|0)+(r<<2)|0);E=c[s>>2]|0}y=r+1|0;if((y|0)<(E|0)){r=y;D=E}else{break}}}$Db(C);$Db(n)}D=c[u>>2]|0;if((D|0)==1129270354|(D|0)==1397316165|(D|0)==5|(D|0)==1448231252){if((c[w+16>>2]|0)!=0){t=49}}else if(!((D|0)==128|(D|0)==7)){t=49}if((t|0)==49){t=0;yDb(b,32,1970032,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=c[u>>2]|0;if((D|0)==1346784596){r=ZEb(c[w+16>>2]|0)|0;yDb(b,32,2216280,(z=i,i=i+8|0,c[z>>2]=(r|0)!=0?r:2300832,z)|0);i=z}else if((D|0)==3|(D|0)==4){MEb(b,+h[w+16>>3])}else if((D|0)==6){lFb(k,+h[w+16>>3],2147483647);r=c[p>>2]|0;yDb(b,32,2269464,(z=i,i=i+16|0,c[z>>2]=c[o>>2],c[z+8>>2]=r,z)|0);i=z}else if((D|0)==0){r=w+16|0;s=c[r+4>>2]|0;yDb(b,32,1961408,(z=i,i=i+16|0,c[z>>2]=c[r>>2],c[z+8>>2]=s,z)|0);i=z}else if((D|0)==1129270354|(D|0)==1397316165|(D|0)==5|(D|0)==1448231252){yDb(b,32,1959040,(z=i,i=i+8|0,c[z>>2]=c[w+16>>2],z)|0);i=z}else if((D|0)==1397116244){s=wFb(c[w+16>>2]|0)|0;yDb(b,32,2216280,(z=i,i=i+8|0,c[z>>2]=(s|0)!=0?s:2300832,z)|0);i=z}else if((D|0)==1128811585){s=w+16|0;r=c[s+4>>2]|0;yDb(b,32,2189608,(z=i,i=i+16|0,c[z>>2]=c[s>>2],c[z+8>>2]=r,z)|0);i=z}else if((D|0)==1146442272|(D|0)==1|(D|0)==2){D=w+16|0;MEb(b,+((c[D>>2]|0)>>>0)+ +(c[D+4>>2]|0)*4294967296.0)}yDb(b,32,1973184,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}yDb(b,32,1956944,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=c[w+44>>2]|0;if((D|0)==0){q=w;continue}if((c[u>>2]|0)==128){q=w;continue}CEb(a,b,D,e,f);q=w}if((t|0)==62){i=g;return}}function DEb(a){a=a|0;EEb(a,0,0);return}function EEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+8|0;f=e|0;g=a;j=c[g>>2]|0;k=f|0;l=f+4|0;m=j+12|0;n=0;o=j;while(1){j=(n|0)!=0;do{if(j|(o|0)==0){p=5}else{q=c[o+8>>2]|0;if((q|0)==0){p=5;break}r=c[q>>2]|0;if((r|0)==0){p=5}else{s=q;t=r}}}while(0);if((p|0)==5){p=0;if(!j){p=32;break}r=n+48|0;q=c[r>>2]|0;if((q|0)==0|(r|0)==0){p=32;break}else{s=r;t=q}}q=c[s+8>>2]|0;r=a+q|0;u=c[s+40>>2]|0;a:do{if((u&b|0)==(d|0)&(u&128|0)==0){v=c[s+12>>2]|0;if((v|0)==0|(v|0)==1|(v|0)==2|(v|0)==1146442272|(v|0)==1128811585){w=s+16|0;FEb(a,s,r,1.0,1,c[w>>2]|0,c[w+4>>2]|0)|0;break}else if((v|0)==5){w=c[s+16>>2]|0;$Db(r);c[r>>2]=eEb(w)|0;break}else if((v|0)==1129270354){w=c[s+16>>2]|0;if((w|0)==0){break}if((QEb(r,w,-1,a)|0)>=0){break}yDb(a,16,1910648,(x=i,i=i+8|0,c[x>>2]=w,x)|0);i=x;break}else if((v|0)==3|(v|0)==4){FEb(a,s,r,+h[s+16>>3],1,1,0)|0;break}else if((v|0)==1448231252){w=c[s+16>>2]|0;if((w|0)!=0){if((PEb(r,w)|0)>=0){break}}yDb(a,16,1904064,(x=i,i=i+8|0,c[x>>2]=w,x)|0);i=x;break}else if((v|0)==6){lFb(f,+h[s+16>>3],2147483647);w=c[k>>2]|0;FEb(a,s,r,1.0,c[l>>2]|0,w,(w|0)<0|0?-1:0)|0;break}else if((v|0)==1397316165){w=c[s+16>>2]|0;y=r;do{if((w|0)!=0){if((QGb(w,2300832)|0)==0){break}if((OEb(y,a+(q+4)|0,w)|0)>=0){break a}yDb(a,16,1902504,(x=i,i=i+8|0,c[x>>2]=w,x)|0);i=x;break a}}while(0);c[a+(q+4)>>2]=0;c[y>>2]=0;break}else if((v|0)==1346784596){w=c[m>>2]|0;if((w|0)!=0&(w|0)<3410532){rEb(a,t,c[s+16>>2]|0,0)|0;break}else{w=s+16|0;FEb(a,s,r,1.0,1,c[w>>2]|0,c[w+4>>2]|0)|0;break}}else if((v|0)==1397116244){w=c[m>>2]|0;if((w|0)!=0&(w|0)<3410532){rEb(a,t,c[s+16>>2]|0,0)|0;break}else{w=s+16|0;FEb(a,s,r,1.0,1,c[w>>2]|0,c[w+4>>2]|0)|0;break}}else if((v|0)==128|(v|0)==7){break}else{yDb(a,48,2149688,(x=i,i=i+16|0,c[x>>2]=v,c[x+8>>2]=t,x)|0);i=x;break}}}while(0);n=s;o=c[g>>2]|0}if((p|0)==32){i=e;return}}function FEb(a,b,d,e,f,j,k){a=a|0;b=b|0;d=d|0;e=+e;f=f|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0.0,y=0.0;l=i;i=i+8|0;m=l|0;n=m;o=b+12|0;p=c[o>>2]|0;a:do{if((p|0)==0){q=(+(j>>>0)+ +(k|0)*4294967296.0)*e/+(f|0);do{if(!(q<-1.5|q>4294967295.5)){r=ce(+(q*256.0))|0;if(!((r&255|0)==0&(F&0|0)==0)){break}s=c[o>>2]|0;break a}}while(0);r=c[b>>2]|0;yDb(a,16,2076552,(t=i,i=i+16|0,h[t>>3]=q,c[t+8>>2]=r,t)|0);i=t;u=-34;i=l;return u|0}else{v=+h[b+32>>3];w=+(f|0);x=(+(j>>>0)+ +(k|0)*4294967296.0)*e;y=+h[b+24>>3];if(!(w*v<x)){if(!(w*y>x)){s=p;break}}r=c[b>>2]|0;yDb(a,16,2082360,(t=i,i=i+32|0,h[t>>3]=x/w,c[t+8>>2]=r,h[t+16>>3]=y,h[t+24>>3]=v,t)|0);i=t;u=-34;i=l;return u|0}}while(0);if((s|0)==4){g[d>>2]=(+(j>>>0)+ +(k|0)*4294967296.0)*e/+(f|0);u=0;i=l;return u|0}else if((s|0)==6){v=(+(j>>>0)+ +(k|0)*4294967296.0)*e;if(+(~~e|0)==e){c[d>>2]=~~v;c[d+4>>2]=f;u=0;i=l;return u|0}else{lFb(n,v/+(f|0),16777216);n=d;t=c[m+4>>2]|0;c[n>>2]=c[m>>2];c[n+4>>2]=t;u=0;i=l;return u|0}}else if((s|0)==1146442272|(s|0)==1128811585|(s|0)==2){t=ce(+(e/+(f|0)))|0;n=gHb(t,F,j,k)|0;t=d;c[t>>2]=n;c[t+4>>2]=F;u=0;i=l;return u|0}else if((s|0)==3){h[d>>3]=(+(j>>>0)+ +(k|0)*4294967296.0)*e/+(f|0);u=0;i=l;return u|0}else if((s|0)==0|(s|0)==1346784596|(s|0)==1397116244|(s|0)==1){s=ce(+(e/+(f|0)))|0;f=gHb(s,F,j,k)|0;c[d>>2]=f;u=0;i=l;return u|0}else{u=-22;i=l;return u|0}return 0}function GEb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+8|0;k=j|0;l=c[b>>2]|0;c[k>>2]=l;m=l+(qd(l|0,2112360)|0)|0;l=m;while(1){n=a[l]|0;o=n<<24>>24;if(!(((o|32)-97|0)>>>0<26>>>0|(o-48|0)>>>0<10>>>0)){if(!((n<<24>>24|0)==95|(n<<24>>24|0)==47|(n<<24>>24|0)==45|(n<<24>>24|0)==46)){break}}l=l+1|0}n=qd(l|0,2112360)|0;o=a[l+n|0]|0;do{if(o<<24>>24==0){p=9}else{if((Vb(d|0,o<<24>>24|0)|0)==0){p=9;break}q=l-m|0;r=WDb(q+1|0)|0;if((r|0)==0){p=9;break}UGb(r|0,m|0,q)|0;a[r+q|0]=0;c[k>>2]=l+(n+1);s=r}}while(0);do{if((p|0)==9){if((f&1|0)==0){t=-22}else{s=0;break}i=j;return t|0}}while(0);f=wAb(k,e)|0;if((f|0)==0){ZDb(s);t=-12;i=j;return t|0}else{c[b>>2]=c[k>>2];c[g>>2]=s;c[h>>2]=f;t=0;i=j;return t|0}return 0}function HEb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a;d=0;while(1){e=c[b>>2]|0;f=(d|0)!=0;do{if(f|(e|0)==0){g=5}else{h=c[e+8>>2]|0;if((h|0)==0){g=5;break}if((c[h>>2]|0)==0){g=5}else{i=h}}}while(0);if((g|0)==5){g=0;if(!f){g=9;break}e=d+48|0;if((c[e>>2]|0)==0|(e|0)==0){g=9;break}else{i=e}}e=c[i+12>>2]|0;if(!((e|0)==5|(e|0)==7)){d=i;continue}$Db(a+(c[i+8>>2]|0)|0);d=i}if((g|0)==9){return}}function IEb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=BBb(c[b>>2]|0,9203528,0,2)|0;a:do{if((f|0)==0){g=0}else{h=f;while(1){j=h|0;k=h+4|0;l=rEb(a,c[j>>2]|0,c[k>>2]|0,0)|0;if((l|0)==-1414549496){CBb(e,c[j>>2]|0,c[k>>2]|0,0)|0}else{if((l|0)<0){break}}m=BBb(c[b>>2]|0,9203528,h,2)|0;if((m|0)==0){g=0;break a}else{h=m}}h=c[k>>2]|0;yDb(a,16,2118920,(m=i,i=i+16|0,c[m>>2]=c[j>>2],c[m+8>>2]=h,m)|0);i=m;g=l}}while(0);DBb(b);c[b>>2]=c[e>>2];i=d;return g|0}function JEb(a,b){a=a|0;b=b|0;var d=0,e=0;d=c[a+28>>2]|0;if((d|0)==0){e=0;return e|0}e=re[d&4095](b)|0;return e|0}function KEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)==0){e=0;return e|0}f=a+8|0;a=0;a:while(1){g=(a|0)!=0;do{if(g){h=7}else{i=c[f>>2]|0;if((i|0)==0){e=0;h=12;break a}j=c[i>>2]|0;if((j|0)!=0){k=i;l=j;break}if(g){h=7}else{e=0;h=12;break a}}}while(0);if((h|0)==7){h=0;g=a+48|0;j=c[g>>2]|0;if((j|0)==0|(g|0)==0){e=0;h=12;break}else{k=g;l=j}}if((QGb(l,d)|0)!=0){a=k;continue}if((c[k+12>>2]|0)==128){a=k}else{h=10;break}}if((h|0)==10){if((k|0)==0){e=0;return e|0}e=b+(c[k+8>>2]|0)|0;return e|0}else if((h|0)==12){return e|0}return 0}function LEb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;f=cEb(8)|0;g=f;i=cEb(4)|0;j=i;k=cEb(48)|0;l=sEb(b,d,0,0,e,0)|0;c[a>>2]=0;do{if((f|0)==0|(k|0)==0|(i|0)==0|(l|0)==0){m=-12}else{c[f>>2]=j;c[j>>2]=k;c[f+4>>2]=1;c[k+40>>2]=1;e=k+8|0;h[e>>3]=+h[l+24>>3];d=k+16|0;h[d>>3]=+h[l+32>>3];b=c[l+12>>2]|0;if((b|0)==5){h[k+24>>3]=0.0;h[k+32>>3]=1114111.0;h[e>>3]=-1.0;h[d>>3]=2147483647.0}else if((b|0)==1448231252){h[k+24>>3]=1.0;h[k+32>>3]=2147483647.0;h[e>>3]=1.0;h[d>>3]=2147483647.0}else if((b|0)==6){h[k+24>>3]=-2147483648.0;h[k+32>>3]=2147483647.0}else if((b|0)==1397316165){h[k+24>>3]=0.0;h[k+32>>3]=2097151.0;h[e>>3]=0.0;h[d>>3]=268435455.0}else if(!((b|0)==1|(b|0)==2|(b|0)==1346784596|(b|0)==1397116244|(b|0)==4|(b|0)==3|(b|0)==1146442272|(b|0)==1129270354|(b|0)==1128811585)){m=-38;break}c[a>>2]=g;n=0;return n|0}}while(0);ZDb(f);ZDb(k);ZDb(i);n=m;return n|0}function MEb(a,b){a=a|0;b=+b;var d=0,e=0;d=i;if(b==2147483647.0){yDb(a,32,1954672,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-2147483648.0){yDb(a,32,1952408,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==4294967295.0){yDb(a,32,1950240,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==9223372036854776000.0){yDb(a,32,1948280,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-9223372036854776000.0){yDb(a,32,1946376,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==3.4028234663852886e+38){yDb(a,32,1944392,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==1.1754943508222875e-38){yDb(a,32,1941368,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-3.4028234663852886e+38){yDb(a,32,1933536,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-1.1754943508222875e-38){yDb(a,32,1931400,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==1.7976931348623157e+308){yDb(a,32,1929536,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==2.2250738585072014e-308){yDb(a,32,1927760,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-1.7976931348623157e+308){yDb(a,32,1926040,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-2.2250738585072014e-308){yDb(a,32,1924608,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}else{yDb(a,32,1922960,(e=i,i=i+8|0,h[e>>3]=b,e)|0);i=e;i=d;return}}function NEb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+24|0;j=g+8|0;k=g+16|0;l=a|0;m=a+4|0;n=xd(b|0,2160728,(o=i,i=i+24|0,c[o>>2]=l,c[o+8>>2]=m,c[o+16>>2]=g,o)|0)|0;i=o;if((n|0)==2){n=c[l>>2]|0;o=c[m>>2]|0;iFb(l,m,n,(n|0)<0|0?-1:0,o,(o|0)<0|0?-1:0,d,(d|0)<0|0?-1:0)|0;p=0;i=g;return p|0}o=OBb(j,b,0,0,0,0,0,0,0,e,f)|0;if((o|0)<0){p=o;i=g;return p|0}lFb(k,+h[j>>3],d);d=a;a=c[k+4>>2]|0;c[d>>2]=c[k>>2];c[d+4>>2]=a;p=0;i=g;return p|0}function OEb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+8|0;g=f|0;h=0;while(1){if((h|0)>=49){j=5;break}if((QGb(c[136128+(h*12|0)>>2]|0,e)|0)==0){j=4;break}else{h=h+1|0}}do{if((j|0)==4){k=c[136136+(h*12|0)>>2]|0;l=c[136132+(h*12|0)>>2]|0}else if((j|0)==5){if((h|0)!=49){m=-22;i=f;return m|0}n=kb(e|0,g|0,10)|0;o=c[g>>2]|0;if((a[o]|0)==0){p=o}else{q=o+1|0;c[g>>2]=q;p=q}q=kb(p|0,g|0,10)|0;if((a[c[g>>2]|0]|0)==0){k=q;l=n;break}else{m=-22}i=f;return m|0}}while(0);if((l|0)<1|(k|0)<1){m=-22;i=f;return m|0}c[b>>2]=l;c[d>>2]=k;m=0;i=f;return m|0}function PEb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=0;while(1){if((d|0)>=8){break}if((QGb(c[136720+(d*12|0)>>2]|0,b)|0)==0){e=4;break}else{d=d+1|0}}if((e|0)==4){e=136724+(d*12|0)|0;d=a;f=c[e+4>>2]|0;c[d>>2]=c[e>>2];c[d+4>>2]=f;g=0;return g|0}f=NEb(a,b,1001e3,56,0)|0;if((f|0)<0){g=f;return g|0}if((c[a>>2]|0)<1){g=-22;return g|0}else{return((c[a+4>>2]|0)<1?-22:0)|0}return 0}function QEb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0;g=i;i=i+144|0;h=g|0;j=g+136|0;if((a[d]|0)==35){k=1}else{l=(RGb(d,2300488,2)|0)==0;k=l?2:0}if((e|0)<0){m=SGb(d|0)|0}else{m=e}e=g+8|0;l=m-k+1|0;sAb(e,d+k|0,l>>>0>128>>>0?128:l)|0;l=Vb(e|0,64)|0;c[h>>2]=l;if((l|0)==0){n=0}else{m=l+1|0;c[h>>2]=m;a[l]=0;n=m}m=SGb(e|0)|0;l=b+3|0;a[l]=-1;a:do{if((yAb(e,2171456)|0)==0){o=9}else{if((yAb(e,2097056)|0)==0){o=9;break}do{if((k|0)==0){if((qd(e|0,2041976)|0)==(m|0)){break}p=wc(e|0,1424384,140,8,180)|0;if((p|0)!=0){q=p+4|0;a[b]=a[q]|0;a[b+1|0]=a[q+1|0]|0;a[b+2|0]=a[q+2|0]|0;break a}yDb(f,16,1960880,(r=i,i=i+8|0,c[r>>2]=e,r)|0);i=r;s=-22;i=g;return s|0}}while(0);q=hb(e|0,j|0,16)|0;do{if((a[c[j>>2]|0]|0)==0){if(!((m|0)==8|(m|0)==6)){break}p=q&255;t=q>>>8&255;u=q>>>16&255;if((m|0)==8){a[l]=p;v=q>>>24&255;w=u;x=t}else{v=u;w=t;x=p}a[b]=v;a[b+1|0]=w;a[b+2|0]=x;break a}}while(0);yDb(f,16,1997296,(r=i,i=i+8|0,c[r>>2]=e,r)|0);i=r;s=-22;i=g;return s|0}}while(0);if((o|0)==9){o=hFb()|0;a[b]=o>>>24;a[b+1|0]=o>>>16;a[b+2|0]=o>>>8;a[l]=o}if((n|0)==0){s=0;i=g;return s|0}do{if((RGb(n,2300488,2)|0)==0){y=+((hb(n|0,h|0,16)|0)>>>0>>>0)}else{z=+OGb(n,h);if(z<0.0|z>1.0){y=256.0;break}y=z*255.0}}while(0);o=c[h>>2]|0;do{if((o|0)!=(n|0)){if((a[o]|0)!=0){break}if(y>255.0|y<0.0){break}a[l]=~~y;s=0;i=g;return s|0}}while(0);yDb(f,16,1933048,(r=i,i=i+16|0,c[r>>2]=n,c[r+8>>2]=d,r)|0);i=r;s=-22;i=g;return s|0}function REb(a,b){a=a|0;b=b|0;return yAb(a,c[b>>2]|0)|0}function SEb(a,b){a=a|0;b=b|0;var d=0;if(a>>>0>139>>>0){d=0;return d|0}if((b|0)!=0){c[b>>2]=1424388+(a<<3)}d=c[1424384+(a<<3)>>2]|0;return d|0}function TEb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=e+8|0;g=e+12|0;h=e+16|0;i=e+20|0;j=e|0;k=e+4|0;e=d;d=b;a:while(1){if((EAb(a[e]|0)|0)!=0){b=d;while(1){if((EAb(a[b]|0)|0)==0){break}else{b=b+1|0}}e=e+1|0;d=b;continue}l=e+1|0;m=a[e]|0;if(m<<24>>24==0){n=d;o=34;break}p=m<<24>>24;b:do{if(m<<24>>24==37){q=e+2|0;r=a[l]|0;switch(r<<24>>24|0){case 109:{s=a[d]|0;if((CAb(s)|0)==0){n=0;o=34;break a}t=s-48|0;s=d+1|0;u=a[s]|0;if((CAb(u)|0)==0){v=t;w=s}else{v=(t*10|0)-48+u|0;w=d+2|0}u=v-1|0;if(u>>>0>11>>>0|(v|0)==-1){n=0;o=34;break a}c[h>>2]=u;e=q;d=w;continue a;break};case 100:{u=a[d]|0;if((CAb(u)|0)==0){n=0;o=34;break a}t=u-48|0;u=d+1|0;s=a[u]|0;if((CAb(s)|0)==0){x=t;y=u}else{x=(t*10|0)-48+s|0;y=d+2|0}if((x-1|0)>>>0>30>>>0|(x|0)==-1){n=0;o=34;break a}c[g>>2]=x;e=q;d=y;continue a;break};case 77:{s=a[d]|0;if((CAb(s)|0)==0){n=0;o=34;break a}t=s-48|0;s=d+1|0;u=a[s]|0;if((CAb(u)|0)==0){z=t;A=s}else{z=(t*10|0)-48+u|0;A=d+2|0}if((A|0)==(d|0)|z>>>0>59>>>0){n=0;o=34;break a}c[k>>2]=z;e=q;d=A;continue a;break};case 72:case 74:{u=a[d]|0;if((CAb(u)|0)==0){n=0;o=34;break a}t=u-48|0;u=d+1|0;s=a[u]|0;if((CAb(s)|0)==0){B=t;C=u}else{B=(t*10|0)-48+s|0;C=d+2|0}if((B|0)<0|(B|0)>((r<<24>>24==72?23:2147483647)|0)|(B|0)==-1){n=0;o=34;break a}c[f>>2]=B;e=q;d=C;continue a;break};case 37:{D=37;E=q;break b;break};case 83:{r=a[d]|0;if((CAb(r)|0)==0){n=0;o=34;break a}s=r-48|0;r=d+1|0;t=a[r]|0;if((CAb(t)|0)==0){F=s;G=r}else{F=(s*10|0)-48+t|0;G=d+2|0}if((G|0)==(d|0)|F>>>0>59>>>0){n=0;o=34;break a}c[j>>2]=F;e=q;d=G;continue a;break};case 89:{t=a[d]|0;if((CAb(t)|0)==0){n=0;o=34;break a}s=t-48|0;t=d+1|0;r=a[t]|0;do{if((CAb(r)|0)==0){H=s;I=t}else{u=(s*10|0)-48+r|0;J=d+2|0;K=a[J]|0;if((CAb(K)|0)==0){H=u;I=J;break}J=(u*10|0)-48+K|0;K=d+3|0;u=a[K]|0;if((CAb(u)|0)==0){H=J;I=K;break}H=(J*10|0)-48+u|0;I=d+4|0}}while(0);if((I|0)==(d|0)|H>>>0>9999>>>0){n=0;o=34;break a}c[i>>2]=H-1900;e=q;d=I;continue a;break};default:{n=0;o=34;break a}}}else{D=p;E=l}}while(0);if((D|0)!=(a[d]|0)){n=0;o=34;break}e=E;d=d+1|0}if((o|0)==34){return n|0}return 0}function UEb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+20>>2]|0;d=c[a+16>>2]|0;e=d+1|0;if((e|0)<3){f=b+1899|0;g=d+13|0}else{f=b+1900|0;g=e}return((c[a+8>>2]|0)*3600|0)-2032579456+(((((g*153|0)-457|0)/5|0)+(c[a+12>>2]|0)+(f*365|0)+((f|0)/4|0)+((f|0)/-100|0)+((f|0)/400|0)|0)*86400|0)+((c[a+4>>2]|0)*60|0)+(c[a>>2]|0)|0}function VEb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0;f=i;i=i+96|0;g=f|0;h=f+8|0;j=f+56|0;k=f+64|0;TGb(h|0,0,44)|0;c[b>>2]=0;c[b+4>>2]=-2147483648;l=(e|0)!=0;a:do{if(l){e=(a[d]|0)==45;m=e?d+1|0:d;n=e&1;e=TEb(m,2284904,h)|0;if((e|0)!=0){o=e;p=0;q=n;break}e=TEb(m,2269456,h)|0;r=h+8|0;c[r>>2]=0;if((e|0)!=0){o=e;p=0;q=n;break}c[h>>2]=kb(m|0,j|0,10)|0;e=c[j>>2]|0;if((e|0)==(m|0)){s=-22;i=f;return s|0}else{c[h+4>>2]=0;c[r>>2]=0;t=n;u=0;v=e;w=15;break}}else{c[g>>2]=ee(0)|0;if((yAb(d,2302896)|0)==0){e=c[g>>2]|0;n=gHb(e,(e|0)<0|0?-1:0,1e6,0)|0;c[b>>2]=n;c[b+4>>2]=F;s=0;i=f;return s|0}else{x=0}while(1){if(!(x>>>0<2>>>0)){y=0;break}n=TEb(d,c[1781032+(x<<2)>>2]|0,h)|0;if((n|0)==0){x=x+1|0}else{y=n;break}}n=(y|0)==0;e=n?d:y;r=n&1;n=a[e]|0;if((n<<24>>24|0)==84|(n<<24>>24|0)==116|(n<<24>>24|0)==32){z=e+1|0}else{z=e}n=0;m=e;while(1){if(!(n>>>0<2>>>0)){t=0;u=r;v=m;w=15;break a}e=TEb(z,c[1781024+(n<<2)>>2]|0,h)|0;if((e|0)==0){n=n+1|0;m=0}else{o=e;p=r;q=0;break}}}}while(0);do{if((w|0)==15){if((v|0)==0){s=-22}else{o=v;p=u;q=t;break}i=f;return s|0}}while(0);if((a[o]|0)==46){t=o+1|0;do{if((CAb(a[t]|0)|0)==0){A=0;B=t}else{u=((a[t]|0)*1e5|0)-48e5|0;v=o+2|0;if((CAb(a[v]|0)|0)==0){A=u;B=v;break}w=((a[v]|0)*1e4|0)-48e4+u|0;u=o+3|0;if((CAb(a[u]|0)|0)==0){A=w;B=u;break}v=((a[u]|0)*1e3|0)-48e3+w|0;w=o+4|0;if((CAb(a[w]|0)|0)==0){A=v;B=w;break}u=((a[w]|0)*100|0)-4800+v|0;v=o+5|0;if((CAb(a[v]|0)|0)==0){A=u;B=v;break}w=((a[v]|0)*10|0)-480+u|0;u=o+6|0;if((CAb(a[u]|0)|0)==0){A=w;B=u;break}A=(a[u]|0)-48+w|0;B=o+7|0}}while(0);t=B;while(1){if((CAb(a[t]|0)|0)==0){C=A;D=t;break}else{t=t+1|0}}}else{C=0;D=o}do{if(l){E=((c[h+4>>2]|0)*60|0)+((c[h+8>>2]|0)*3600|0)+(c[h>>2]|0)|0;G=D}else{o=a[D]|0;t=D+((o<<24>>24==90|o<<24>>24==122)&1)|0;if((p|0)!=0){if((o<<24>>24|0)==122|(o<<24>>24|0)==90){UGb(k|0,(mc(g|0)|0)+12|0,32)|0}else{UGb(k|0,(ub(g|0)|0)+12|0,32)|0}UGb(h+12|0,k|0,32)|0}if(!((o<<24>>24|0)==122|(o<<24>>24|0)==90)){E=Uc(h|0)|0;G=t;break}o=c[h+20>>2]|0;A=c[h+16>>2]|0;B=A+1|0;if((B|0)<3){H=o+1899|0;I=A+13|0}else{H=o+1900|0;I=B}E=((c[h+8>>2]|0)*3600|0)-2032579456+(((((I*153|0)-457|0)/5|0)+(c[h+12>>2]|0)+(H*365|0)+((H|0)/4|0)+((H|0)/-100|0)+((H|0)/400|0)|0)*86400|0)+((c[h+4>>2]|0)*60|0)+(c[h>>2]|0)|0;G=t}}while(0);if((a[G]|0)!=0){s=-22;i=f;return s|0}G=gHb(E,(E|0)<0|0?-1:0,1e6,0)|0;E=YGb(G,F,C,(C|0)<0|0?-1:0)|0;C=F;G=(q|0)!=0;q=ZGb(0,0,E,C)|0;c[b>>2]=G?q:E;c[b+4>>2]=G?F:C;s=0;i=f;return s|0}function WEb(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+128|0;g=f|0;h=g|0;j=g;g=b;k=c-1|0;c=h;l=(a[e]|0)==63?e+1|0:e;while(1){e=a[l]|0;if(!((e<<24>>24|0)==0|(e<<24>>24|0)==61|(e<<24>>24|0)==38)){if((c-j|0)>>>0<127>>>0){a[c]=e;m=c+1|0}else{m=c}c=m;l=l+1|0;continue}a[c]=0;a:do{if((a[l]|0)==61){e=b;n=l;while(1){if((e-g|0)>=(k|0)){o=n;break}p=n+1|0;q=a[p]|0;if((q<<24>>24|0)==38|(q<<24>>24|0)==0){r=e;s=p;break a}a[e]=q<<24>>24==43?32:q;e=e+1|0;n=p}while(1){n=o+1|0;p=a[n]|0;if((p<<24>>24|0)==38|(p<<24>>24|0)==0){r=e;s=n;break}else{o=n}}}else{r=b;s=l}}while(0);a[r]=0;if((QGb(h,d)|0)==0){t=1;u=13;break}if((a[s]|0)==38){c=h;l=s+1|0}else{t=0;u=13;break}}if((u|0)==13){i=f;return t|0}return 0}function XEb(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;m=b[g+8+(j<<1)>>1]|0;n=m&3;o=(m&65535)>>>11&15;p=o+1|0;q=(1<<p)-1|0;r=(m&65535)>>>8&7;s=((m&65535)>>>2&7)+1|0;t=d[g+7|0]|0;if((t&4|0)!=0){g=((m&65535)>>>5&7)-1+(ba(s,h)|0)|0;u=(c[e+(n<<2)>>2]|0)+((ba(c[f+(n<<2)>>2]|0,i)|0)+(g>>3))|0;v=7-o-(g&7)|0;g=k-1|0;if((k|0)==0){return}o=e+4|0;if((l|0)==0){w=u;x=v;y=a;z=g;while(1){A=x-s|0;b[y>>1]=(d[w]|0)>>>(x>>>0)&q;if((z|0)==0){break}else{w=w+(-(A>>3)|0)|0;x=A&7;y=y+2|0;z=z-1|0}}return}else{z=u;u=v;v=a;y=g;while(1){g=u-s|0;b[v>>1]=d[(c[o>>2]|0)+((((d[z]|0)>>>(u>>>0)&q)<<2)+j)|0]|0;if((y|0)==0){break}else{z=z+(-(g>>3)|0)|0;u=g&7;v=v+2|0;y=y-1|0}}return}}y=((m&65535)>>>5&7)-1+(ba(s,h)|0)+(ba(c[f+(n<<2)>>2]|0,i)|0)|0;i=(p+r|0)<9;if(i){B=y+(t&1)|0}else{B=y}y=(c[e+(n<<2)>>2]|0)+B|0;B=k-1|0;if((k|0)==0){return}k=(l|0)==0;l=e+4|0;e=(t&1|0)==0;if(i){if(e){i=y;t=a;n=B;while(1){p=(d[i]|0)>>>(r>>>0)&q;if(k){C=p&65535}else{C=d[(c[l>>2]|0)+((p<<2)+j)|0]|0}b[t>>1]=C;if((n|0)==0){break}else{i=i+s|0;t=t+2|0;n=n-1|0}}return}else{n=y;t=a;i=B;while(1){C=(d[n]|0)>>>(r>>>0)&q;if(k){D=C&65535}else{D=d[(c[l>>2]|0)+((C<<2)+j)|0]|0}b[t>>1]=D;if((i|0)==0){break}else{n=n+s|0;t=t+2|0;i=i-1|0}}return}}else{if(e){e=y;i=a;t=B;while(1){n=e;D=((d[n]|d[n+1|0]<<8)<<16>>16&65535)>>>(r>>>0)&q;if(k){E=D&65535}else{E=d[(c[l>>2]|0)+((D<<2)+j)|0]|0}b[i>>1]=E;if((t|0)==0){break}else{e=e+s|0;i=i+2|0;t=t-1|0}}return}else{t=y;y=a;a=B;while(1){B=t;i=((de((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)>>>(r>>>0)&q;if(k){F=i&65535}else{F=d[(c[l>>2]|0)+((i<<2)+j)|0]|0}b[y>>1]=F;if((a|0)==0){break}else{t=t+s|0;y=y+2|0;a=a-1|0}}return}}}function YEb(f,g,h,i,j,k,l,m){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=b[i+8+(l<<1)>>1]|0;l=n&3;o=(n&65535)>>>11&15;p=((n&65535)>>>2&7)+1|0;q=d[i+7|0]|0;if((q&4|0)!=0){i=((n&65535)>>>5&7)-1+(ba(p,j)|0)|0;if((m|0)==0){return}r=(ba(c[h+(l<<2)>>2]|0,k)|0)+(i>>3)|0;s=7-o-(i&7)|0;i=(c[g+(l<<2)>>2]|0)+r|0;r=m;t=f;while(1){u=r-1|0;a[i]=d[i]|0|(e[t>>1]|0)<<s;v=s-p|0;if((u|0)==0){break}else{s=v&7;i=i+(-(v>>3)|0)|0;r=u;t=t+2|0}}return}t=(n&65535)>>>8&7;r=c[g+(l<<2)>>2]|0;g=((n&65535)>>>5&7)-1+(ba(p,j)|0)+(ba(c[h+(l<<2)>>2]|0,k)|0)|0;k=r+g|0;l=(m|0)==0;if((o+1+t|0)<9){if(l){return}o=r+(g+(q&1))|0;g=m;r=f;while(1){h=g-1|0;a[o]=d[o]|0|(e[r>>1]|0)<<t;if((h|0)==0){break}else{o=o+p|0;g=h;r=r+2|0}}return}if(l){return}l=(q&1|0)==0;q=k;k=f;f=m;while(1){m=f-1|0;r=q;g=(d[r]|d[r+1|0]<<8)<<16>>16;if(l){w=((e[k>>1]|0)<<t|g&65535)&65535}else{o=(de(g|0)|0)&65535;w=de(((e[k>>1]|0)<<t|o)&65535|0)|0}x=w;a[r]=x;x=x>>8;a[r+1|0]=x;if((m|0)==0){break}else{q=q+p|0;k=k+2|0;f=m}}return}function ZEb(a){a=a|0;var b=0;if(!(a>>>0<333>>>0)){b=0;return b|0}b=c[1775696+(a<<4)>>2]|0;return b|0}function _Eb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+32|0;d=b|0;if((QGb(a,2250880)|0)==0){e=2118896}else{f=(QGb(a,2249736)|0)==0;e=f?2130776:a}a=0;while(1){f=c[1775696+(a<<4)>>2]|0;if((f|0)!=0){if((QGb(f,e)|0)==0){g=7;break}}f=a+1|0;if((f|0)<333){a=f}else{break}}do{if((g|0)==7){if((a|0)==-1){break}else{h=a}i=b;return h|0}}while(0);a=d|0;Lb(a|0,32,2248640,(d=i,i=i+16|0,c[d>>2]=e,c[d+8>>2]=2247704,d)|0)|0;i=d;d=0;while(1){e=c[1775696+(d<<4)>>2]|0;if((e|0)!=0){if((QGb(e,a)|0)==0){h=d;g=12;break}}e=d+1|0;if((e|0)<333){d=e}else{h=-1;g=12;break}}if((g|0)==12){i=b;return h|0}return 0}function $Eb(b){b=b|0;var c=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=(d[b+6|0]|0)+(d[b+5|0]|0)|0;f=a[b+4|0]|0;if(f<<24>>24==0){g=0;h=g>>c;return h|0}i=f&255;f=0;j=0;while(1){k=(((e[b+8+(j<<1)>>1]|0)>>>11&15)+1<<((j-1|0)>>>0<2>>>0?0:c))+f|0;l=j+1|0;if((l|0)<(i|0)){f=k;j=l}else{g=k;break}}h=g>>c;return h|0}function aFb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+16|0;g=f|0;h=(d[e+6|0]|0)+(d[e+5|0]|0)|0;TGb(g|0,0,16)|0;j=a[e+4|0]|0;if(j<<24>>24==0){k=0;l=0;m=0;n=0;o=l+k|0;p=m+o|0;q=n+p|0;r=e+7|0;s=a[r]|0;t=s&4;u=t<<24>>24==0;v=q<<3;w=u?v:q;x=w>>h;i=f;return x|0}y=j&255;j=0;do{z=b[e+8+(j<<1)>>1]|0;c[g+((z&3)<<2)>>2]=((z&65535)>>>2&7)+1<<((j-1|0)>>>0<2>>>0?0:h);j=j+1|0;}while((j|0)<(y|0));k=c[g>>2]|0;l=c[g+4>>2]|0;m=c[g+8>>2]|0;n=c[g+12>>2]|0;o=l+k|0;p=m+o|0;q=n+p|0;r=e+7|0;s=a[r]|0;t=s&4;u=t<<24>>24==0;v=q<<3;w=u?v:q;x=w>>h;i=f;return x|0}function bFb(a){a=a|0;var b=0;if(a>>>0>332>>>0){b=0}else{b=1775696+(a<<4)|0}return b|0}function cFb(a){a=a|0;var b=0,d=0,e=0;a:do{if((a|0)==0){b=1775696}else{d=a;while(1){if(!(d-1775696>>4>>>0<332>>>0)){b=0;break a}e=d+16|0;if((c[e>>2]|0)==0){d=e}else{b=e;break}}}}while(0);return b|0}function dFb(a){a=a|0;var b=0;if(a>>>0<1775696>>>0|a>>>0>=1781024>>>0){b=-1;return b|0}b=a-1775696>>4;return b|0}function eFb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;if(a>>>0>332>>>0){f=-38;return f|0}c[b>>2]=d[1775701+(a<<4)|0]|0;c[e>>2]=d[1775702+(a<<4)|0]|0;f=0;return f|0}function fFb(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e|0;TGb(f|0,0,16)|0;if(d>>>0>332>>>0){g=-22;i=e;return g|0}h=a[1775700+(d<<4)|0]|0;if(h<<24>>24==0){j=0;k=0;l=0;m=0}else{n=h&255;h=0;do{c[f+((b[1775704+(d<<4)+(h<<1)>>1]&3)<<2)>>2]=1;h=h+1|0;}while((h|0)<(n|0));j=c[f>>2]|0;k=c[f+4>>2]|0;l=c[f+8>>2]|0;m=c[f+12>>2]|0}g=m+(l+(k+j))|0;i=e;return g|0}function gFb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+16|0;e=d|0;if(b>>>0>332>>>0){f=-1;i=d;return f|0}g=c[1775696+(b<<4)>>2]|0;if((SGb(g|0)|0)>>>0<2>>>0){f=-1;i=d;return f|0}b=e|0;sAb(b,g,16)|0;g=e+((SGb(b|0)|0)-2)|0;do{if((QGb(g,2226440)|0)!=0){if((QGb(g,2247704)|0)==0){break}else{f=-1}i=d;return f|0}}while(0);a[g]=a[g]^14;g=0;while(1){e=c[1775696+(g<<4)>>2]|0;if((e|0)!=0){if((QGb(e,b)|0)==0){f=g;h=9;break}}e=g+1|0;if((e|0)<333){g=e}else{f=-1;h=9;break}}if((h|0)==9){i=d;return f|0}return 0}function hFb(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;a=i;i=i+152|0;b=a|0;d=a+120|0;e=a+144|0;f=cCb(2156488,0,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0)|0;i=g;do{if(!((f|0)==-1)){h=wb(f|0,e|0,4)|0;Ub(f|0)|0;if((h|0)!=4){break}j=c[e>>2]|0;i=a;return j|0}}while(0);f=cCb(2299832,0,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0)|0;i=g;do{if(!((f|0)==-1)){h=wb(f|0,e|0,4)|0;Ub(f|0)|0;if((h|0)!=4){break}j=c[e>>2]|0;i=a;return j|0}}while(0);e=d;f=d|0;h=b;b=c[1302732]|0;k=c[1302733]|0;if(!((c[443856]|0)>>>0<121>>>0)){yDb(0,0,2171080,(g=i,i=i+24|0,c[g>>2]=2096912,c[g+8>>2]=2041816,c[g+16>>2]=72,g)|0);i=g;Cd();return 0}if((b|0)==0&(k|0)==0){g=0;while(1){l=Xb()|0;if((g|0)==(l|0)){m=5210936+((c[1302732]&511)<<2)|0;c[m>>2]=(c[m>>2]|0)+1;g=l;continue}else{m=YGb(c[1302732]|0,c[1302733]|0,1,0)|0;n=F;c[1302732]=m;c[1302733]=n;o=5210936+((m&511)<<2)|0;c[o>>2]=(c[o>>2]|0)+(((l-g|0)>>>0)%3294638521|0);o=0;if(n>>>0>o>>>0|n>>>0==o>>>0&m>>>0>64>>>0){break}else{g=l;continue}}}}else{g=0;while(1){l=Xb()|0;if((g|0)==(l|0)){m=5210936+((c[1302732]&511)<<2)|0;c[m>>2]=(c[m>>2]|0)+1;g=l;continue}else{m=YGb(c[1302732]|0,c[1302733]|0,1,0)|0;o=F;c[1302732]=m;c[1302733]=o;n=5210936+((m&511)<<2)|0;c[n>>2]=(c[n>>2]|0)+(((l-g|0)>>>0)%3294638521|0);n=ZGb(m,o,b,k)|0;o=F;m=0;if(o>>>0>m>>>0|o>>>0==m>>>0&n>>>0>4>>>0){break}else{g=l;continue}}}}KFb(h,160)|0;NFb(h,5210936,2048);OFb(h,e);e=fe(c[f>>2]|0)|0;j=(fe(c[d+16>>2]|0)|0)+e|0;i=a;return j|0}function iFb(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;j=f^d;k=g^e;l=-1;m=(e|0)>(l|0)|(e|0)==(l|0)&d>>>0>-1>>>0;l=ZGb(0,0,d,e)|0;n=m?d:l;l=m?e:F;m=-1;o=(g|0)>(m|0)|(g|0)==(m|0)&f>>>0>-1>>>0;m=ZGb(0,0,f,g)|0;p=o?f:m;m=o?g:F;o=GDb(n,l,p,m)|0;q=F;if((o|0)==0&(q|0)==0){r=e;s=d;t=g;u=f}else{f=eHb(n,l,o,q)|0;l=F;n=eHb(p,m,o,q)|0;r=l;s=f;t=F;u=n}a:do{if((r|0)>(i|0)|(r|0)==(i|0)&s>>>0>h>>>0|((t|0)>(i|0)|(t|0)==(i|0)&u>>>0>h>>>0)){if((u|0)==0&(t|0)==0){v=0;w=1;x=1;break}else{y=1;z=0;A=0;B=1;C=t;D=u;E=r;G=s}while(1){H=eHb(G,E,D,C)|0;I=F;J=y;K=(y|0)<0|0?-1:0;n=gHb(H,I,J,K)|0;L=A;M=(A|0)<0|0?-1:0;f=YGb(n,F,L,M)|0;n=F;N=z;O=(z|0)<0|0?-1:0;l=gHb(H,I,N,O)|0;P=B;Q=(B|0)<0|0?-1:0;q=YGb(l,F,P,Q)|0;l=F;if((n|0)>(i|0)|(n|0)==(i|0)&f>>>0>h>>>0|((l|0)>(i|0)|(l|0)==(i|0)&q>>>0>h>>>0)){break}l=gHb(H,I,D,C)|0;n=F;o=ZGb(G,E,l,n)|0;m=f;f=q;if((G|0)==(l|0)&(E|0)==(n|0)){v=f;w=m;x=1;break a}else{A=y;y=m;B=z;z=f;E=C;C=F;G=D;D=o}}if((y|0)==0){R=I;S=H}else{o=ZGb(h,i,L,M)|0;f=eHb(o,F,J,K)|0;R=F;S=f}if((z|0)==0){T=R;U=S}else{f=ZGb(h,i,P,Q)|0;o=eHb(f,F,N,O)|0;f=F;m=R>>>0>f>>>0|R>>>0==f>>>0&S>>>0>o>>>0;T=m?f:R;U=m?o:S}o=gHb(N<<1|0>>>31,O<<1|N>>>31,U,T)|0;m=YGb(o,F,P,Q)|0;o=gHb(m,F,D,C)|0;m=F;f=gHb(G,E,N,O)|0;n=F;if(!(m>>>0>n>>>0|m>>>0==n>>>0&o>>>0>f>>>0)){v=z;w=y;x=0;break}f=gHb(U,T,J,K)|0;o=YGb(f,F,L,M)|0;f=gHb(U,T,N,O)|0;n=YGb(f,F,P,Q)|0;v=n;w=o;x=0}else{v=u;w=s;x=1}}while(0);s=0;c[a>>2]=(k|0)<(s|0)|(k|0)==(s|0)&j>>>0<0>>>0?-w|0:w;c[b>>2]=v;return x|0}function jFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b;b=i;i=i+8|0;c[b>>2]=c[f>>2];c[b+4>>2]=c[f+4>>2];f=d;d=i;i=i+8|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];f=b|0;g=b+4|0;h=c[f>>2]|0;j=c[d>>2]|0;k=gHb(j,(j|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=F;j=c[g>>2]|0;l=c[d+4>>2]|0;d=gHb(l,(l|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;iFb(f,g,k,h,d,F,2147483647,0)|0;d=b;b=a;a=c[d+4>>2]|0;c[b>>2]=c[d>>2];c[b+4>>2]=a;i=e;return}function kFb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+8|0;g=b;b=i;i=i+8|0;c[b>>2]=c[g>>2];c[b+4>>2]=c[g+4>>2];g=e;e=i;i=i+8|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];g=f|0;h=c[e+4>>2]|0;j=c[e>>2]|0;e=b;b=e|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[g>>2]=k;c[g+4>>2]=e;b=k;k=gHb(b,(b|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=F;b=gHb(e,(e|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;iFb(g,g+4|0,k,h,b,F,2147483647,0)|0;b=a;a=c[g+4>>2]|0;c[b>>2]=c[g>>2];c[b+4>>2]=a;i=f;return}function lFb(a,b,d){a=a|0;b=+b;d=d|0;var e=0,f=0,g=0,j=0,l=0.0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+8|0;f=e|0;h[k>>3]=b;g=c[k+4>>2]&2147483647;j=2146435072;if(g>>>0>j>>>0|g>>>0==j>>>0&(c[k>>2]|0)>>>0>0>>>0){c[a>>2]=0;c[a+4>>2]=0;i=e;return}l=+Q(+b);if(l>2147483650.0){c[a>>2]=b<0.0?-1:1;c[a+4>>2]=0;i=e;return}j=~~(+$(l+1.0e-20)/.6931471805599453);g=(j|0)>0;m=_Gb(1,0,61-j|0)|0;j=g?m:0;m=g?F:536870912;g=f;n=f+4|0;l=+P((+(j>>>0)+ +(m|0)*4294967296.0)*b+.5);o=~~+l>>>0;p=(E=+l,+Q(E)>=1.0?E>0.0?(ga(+P(E/4294967296.0),4294967295.0)|0)>>>0:~~+aa((E- +(~~E>>>0))/4294967296.0)>>>0:0);iFb(g,n,o,p,j,m,d,(d|0)<0|0?-1:0)|0;if((c[g>>2]|0)==0){if(b!=0.0){q=8}}else{if((c[n>>2]|0)==0&b!=0.0){q=8}}do{if((q|0)==8){if(!((d|0)>0&(d|0)!=2147483647)){break}iFb(g,n,o,p,j,m,2147483647,0)|0}}while(0);m=a;a=c[f+4>>2]|0;c[m>>2]=c[f>>2];c[m+4>>2]=a;i=e;return}function mFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;f=a;a=i;i=i+8|0;c[a>>2]=c[f>>2];c[a+4>>2]=c[f+4>>2];f=b;b=i;i=i+8|0;c[b>>2]=c[f>>2];c[b+4>>2]=c[f+4>>2];f=d;d=i;i=i+8|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];f=c[b>>2]|0;g=c[d+4>>2]|0;h=g;j=(g|0)<0|0?-1:0;k=gHb(h,j,f,(f|0)<0|0?-1:0)|0;l=F;m=c[d>>2]|0;d=c[b+4>>2]|0;b=d;n=(d|0)<0|0?-1:0;o=gHb(b,n,m,(m|0)<0|0?-1:0)|0;p=F;q=YGb(o,p,k,l)|0;r=F;s=gHb(b<<1|0>>>31,n<<1|b>>>31,h,j)|0;j=F;h=c[a+4>>2]|0;b=h;n=(h|0)<0|0?-1:0;h=HDb(q,r,b,n,s,j,3)|0;t=F;u=HDb(q,r,b,n,s,j,2)|0;j=F;s=c[a>>2]|0;a=s;n=(s|0)<0|0?-1:0;s=(((t|0)>(n|0)|(t|0)==(n|0)&h>>>0>a>>>0)&1)-(((j|0)<(n|0)|(j|0)==(n|0)&u>>>0<a>>>0)&1)|0;if(!((o|0)==(k|0)&(p|0)==(l|0))){ZGb(o,p,k,l)|0;l=F^((d^g|0)<0|0?-1:0);((l|0)<0|0?-1:0)>>31|((l|0)<0|0?-1:0)<<1;v=l>>31|((l|0)<0|0?-1:0)<<1|1;w=ba(v,s)|0;i=e;return w|0}if(!((d|0)==0|(g|0)==0)){v=0;w=ba(v,s)|0;i=e;return w|0}if((m|0)==0|(f|0)==0){v=-2147483648;w=ba(v,s)|0;i=e;return w|0}v=(m>>31)-(f>>31)|0;w=ba(v,s)|0;i=e;return w|0}function nFb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;e=a;a=i;i=i+8|0;c[a>>2]=c[e>>2];c[a+4>>2]=c[e+4>>2];e=c[b+4>>2]|0;if((e|0)==0){f=0;i=d;return f|0}g=c[a+4>>2]|0;h=g;j=(g|0)<0|0?-1:0;g=c[a>>2]|0;a=g;k=(g|0)<0|0?-1:0;g=0;l=0;m=e;n=e;while(1){e=c[b+(g<<3)>>2]|0;o=n;p=(n|0)<0|0?-1:0;q=gHb(o,p,e,(e|0)<0|0?-1:0)|0;r=F;s=c[b+(l<<3)>>2]|0;t=m;u=(m|0)<0|0?-1:0;v=gHb(t,u,s,(s|0)<0|0?-1:0)|0;w=F;x=YGb(v,w,q,r)|0;y=F;z=gHb(t<<1|0>>>31,u<<1|t>>>31,o,p)|0;p=F;o=HDb(x,y,h,j,z,p,3)|0;t=F;u=HDb(x,y,h,j,z,p,2)|0;p=F;z=(((t|0)>(k|0)|(t|0)==(k|0)&o>>>0>a>>>0)&1)-(((p|0)<(k|0)|(p|0)==(k|0)&u>>>0<a>>>0)&1)|0;do{if((v|0)==(q|0)&(w|0)==(r|0)){if(!((m|0)==0|(n|0)==0)){A=0;break}if((s|0)==0|(e|0)==0){A=-2147483648;break}A=(s>>31)-(e>>31)|0}else{ZGb(v,w,q,r)|0;u=F^((m^n|0)<0|0?-1:0);((u|0)<0|0?-1:0)>>31|((u|0)<0|0?-1:0)<<1;A=u>>31|((u|0)<0|0?-1:0)<<1|1}}while(0);r=(ba(A,z)|0)>0;q=r?g:l;r=g+1|0;w=c[b+(r<<3)+4>>2]|0;if((w|0)==0){f=q;break}g=r;l=q;m=w;n=c[b+(q<<3)+4>>2]|0}i=d;return f|0}function oFb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=f>>3;if((f&7|0)==0){h=0}else{i=-1;return i|0}while(1){a[b+h|0]=h;f=h+1|0;if((f|0)<256){h=f}else{j=0;k=0;l=0;break}}while(1){h=(k|0)==(g|0)?0:k;f=b+l|0;m=a[f]|0;n=(m+j&255)+(a[e+h|0]|0)&255;o=b+(n&255)|0;p=a[o]|0;a[o]=m;a[f]=p;p=l+1|0;if((p|0)<256){j=n;k=h+1|0;l=p}else{break}}c[b+256>>2]=1;c[b+260>>2]=d[b+1|0]|0;i=0;return i|0}function pFb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=b+256|0;g=c[h>>2]|0;i=b+260|0;j=c[i>>2]&255;k=g&255;if((f|0)<=0){l=j;m=k;c[h>>2]=m;n=l&255;c[i>>2]=n;return}o=g&255;g=(o+(f+255&255)&255)+1&255;p=o;o=j;j=e;e=d;d=f;f=k;q=a[b+k|0]|0;while(1){k=d-1|0;r=b+(o&255)|0;s=a[r]|0;t=s+q&255;a[r]=q;a[b+f|0]=s;if((j|0)==0){u=a[b+(t&255)|0]|0;v=0}else{u=a[b+(t&255)|0]^a[j];v=j+1|0}a[e]=u;t=p+1&255;s=t&255;r=a[b+s|0]|0;w=r+o&255;if((k|0)>0){p=t;o=w;j=v;e=e+1|0;d=k;f=s;q=r}else{break}}l=w;m=g&255;c[h>>2]=m;n=l&255;c[i>>2]=n;return}function qFb(){return cEb(128)|0}function rFb(b,d){b=b|0;d=d|0;var e=0;a[b|0]=d>>>5;if((d|0)==256){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+96>>2]=1985229328;c[b+100>>2]=-19088744;c[b+104>>2]=-1985229329;c[b+108>>2]=19088743;c[b+124>>2]=2012;a[b+120|0]=1}else if((d|0)==160){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+96>>2]=-1009589776;c[b+124>>2]=2256;a[b+120|0]=0}else if((d|0)==320){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+96>>2]=-1009589776;c[b+100>>2]=1985229328;c[b+104>>2]=-19088744;c[b+108>>2]=-1985229329;c[b+112>>2]=19088743;c[b+116>>2]=1009589775;c[b+124>>2]=2256;a[b+120|0]=1}else if((d|0)==128){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+124>>2]=2012;a[b+120|0]=0}else{e=-1;return e|0}d=b+8|0;c[d>>2]=0;c[d+4>>2]=0;e=0;return e|0}function sFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=i;i=i+64|0;f=e|0;g=(d|0)!=0;d=c[a>>2]|0;h=a+4|0;j=c[h>>2]|0;k=a+8|0;l=c[k>>2]|0;m=a+12|0;n=c[m>>2]|0;if(g){o=c[a+28>>2]|0;p=c[a+24>>2]|0;q=c[a+20>>2]|0;r=c[a+16>>2]|0}else{o=n;p=l;q=j;r=d}UGb(f|0,b|0,64)|0;b=l^j;s=c[f>>2]|0;t=(b^n)+d+s|0;d=t<<11|t>>>21;t=c[f+20>>2]|0;u=r+1352829926+((p^q)&o^p)+t|0;r=u<<8|u>>>24;u=c[f+4>>2]|0;v=u+n+(b^d)|0;b=v<<14|v>>>18;v=c[f+56>>2]|0;n=o+1352829926+v+((r^q)&p^q)|0;o=n<<9|n>>>23;n=c[f+8>>2]|0;w=n+l+(d^j^b)|0;l=w<<15|w>>>17;w=c[f+28>>2]|0;x=p+1352829926+w+((o^r)&q^r)|0;p=x<<9|x>>>23;x=c[f+12>>2]|0;y=x+j+(b^d^l)|0;j=y<<12|y>>>20;y=q+1352829926+s+((p^o)&r^o)|0;q=y<<11|y>>>21;y=c[f+16>>2]|0;z=y+d+(l^b^j)|0;d=z<<5|z>>>27;z=c[f+36>>2]|0;A=r+1352829926+z+((q^p)&o^p)|0;r=A<<13|A>>>19;A=b+t+(j^l^d)|0;b=A<<8|A>>>24;A=n+1352829926+o+((r^q)&p^q)|0;o=A<<15|A>>>17;A=c[f+24>>2]|0;B=l+A+(d^j^b)|0;l=B<<7|B>>>25;B=c[f+44>>2]|0;C=B+1352829926+p+((o^r)&q^r)|0;p=C<<15|C>>>17;C=j+w+(b^d^l)|0;j=C<<9|C>>>23;C=y+1352829926+q+((p^o)&r^o)|0;q=C<<5|C>>>27;C=c[f+32>>2]|0;D=d+C+(l^b^j)|0;d=D<<11|D>>>21;D=c[f+52>>2]|0;E=D+1352829926+r+((q^p)&o^p)|0;r=E<<7|E>>>25;E=b+z+(j^l^d)|0;b=E<<13|E>>>19;E=A+1352829926+o+((r^q)&p^q)|0;o=E<<7|E>>>25;E=c[f+40>>2]|0;F=l+E+(d^j^b)|0;l=F<<14|F>>>18;F=c[f+60>>2]|0;G=F+1352829926+p+((o^r)&q^r)|0;p=G<<8|G>>>24;G=j+B+(b^d^l)|0;j=G<<15|G>>>17;G=C+1352829926+q+((p^o)&r^o)|0;q=G<<11|G>>>21;G=c[f+48>>2]|0;f=d+G+(l^b^j)|0;d=f<<6|f>>>26;f=u+1352829926+r+((q^p)&o^p)|0;r=f<<14|f>>>18;f=b+D+(j^l^d)|0;b=f<<7|f>>>25;f=E+1352829926+o+((r^q)&p^q)|0;o=f<<14|f>>>18;f=l+v+(d^j^b)|0;l=f<<9|f>>>23;f=x+1352829926+p+((o^r)&q^r)|0;p=f<<12|f>>>20;f=l^b;H=j+F+(f^d)|0;j=H<<8|H>>>24;H=G+1352829926+q+((p^o)&r^o)|0;q=H<<6|H>>>26;H=w+1518500249+(j&f^b)+(g?r:d)|0;f=H<<7|H>>>25;H=A+1548603684+(g?d:r)+((q|~p)^o)|0;r=H<<9|H>>>23;H=y+1518500249+b+(f&(j^l)^l)|0;b=H<<6|H>>>26;H=B+1548603684+o+((r|~q)^p)|0;o=H<<13|H>>>19;H=D+1518500249+l+(b&(f^j)^j)|0;l=H<<8|H>>>24;H=x+1548603684+p+((o|~r)^q)|0;p=H<<15|H>>>17;H=u+1518500249+j+(l&(b^f)^f)|0;j=H<<13|H>>>19;H=w+1548603684+q+((p|~o)^r)|0;q=H<<7|H>>>25;H=E+1518500249+f+(j&(l^b)^b)|0;f=H<<11|H>>>21;H=s+1548603684+r+((q|~p)^o)|0;r=H<<12|H>>>20;H=A+1518500249+b+(f&(j^l)^l)|0;b=H<<9|H>>>23;H=D+1548603684+o+((r|~q)^p)|0;o=H<<8|H>>>24;H=F+1518500249+l+(b&(f^j)^j)|0;l=H<<7|H>>>25;H=t+1548603684+p+((o|~r)^q)|0;p=H<<9|H>>>23;H=x+1518500249+j+(l&(b^f)^f)|0;j=H<<15|H>>>17;H=E+1548603684+q+((p|~o)^r)|0;q=H<<11|H>>>21;H=G+1518500249+f+(j&(l^b)^b)|0;f=H<<7|H>>>25;H=v+1548603684+r+((q|~p)^o)|0;r=H<<7|H>>>25;H=s+1518500249+b+(f&(j^l)^l)|0;b=H<<12|H>>>20;H=F+1548603684+o+((r|~q)^p)|0;o=H<<7|H>>>25;H=z+1518500249+l+(b&(f^j)^j)|0;l=H<<15|H>>>17;H=C+1548603684+p+((o|~r)^q)|0;p=H<<12|H>>>20;H=t+1518500249+j+(l&(b^f)^f)|0;j=H<<9|H>>>23;H=G+1548603684+q+((p|~o)^r)|0;q=H<<7|H>>>25;H=n+1518500249+f+(j&(l^b)^b)|0;f=H<<11|H>>>21;H=y+1548603684+r+((q|~p)^o)|0;r=H<<6|H>>>26;H=v+1518500249+b+(f&(j^l)^l)|0;b=H<<7|H>>>25;H=z+1548603684+o+((r|~q)^p)|0;o=H<<15|H>>>17;H=B+1518500249+l+(b&(f^j)^j)|0;l=H<<13|H>>>19;H=u+1548603684+p+((o|~r)^q)|0;p=H<<13|H>>>19;H=C+1518500249+j+(l&(b^f)^f)|0;j=H<<12|H>>>20;H=n+1548603684+q+((p|~o)^r)|0;q=H<<11|H>>>21;H=g?q:j;d=g?j:q;q=x+1859775393+f+((H|~l)^b)|0;f=q<<11|q>>>21;q=F+1836072691+r+(d&(p^o)^o)|0;r=q<<9|q>>>23;q=E+1859775393+b+((f|~H)^l)|0;b=q<<13|q>>>19;q=t+1836072691+o+(r&(d^p)^p)|0;o=q<<7|q>>>25;q=v+1859775393+l+((b|~f)^H)|0;l=q<<6|q>>>26;q=u+1836072691+p+(o&(r^d)^d)|0;p=q<<15|q>>>17;q=y+1859775393+H+((l|~b)^f)|0;H=q<<7|q>>>25;q=x+1836072691+d+(p&(o^r)^r)|0;d=q<<11|q>>>21;q=z+1859775393+f+((H|~l)^b)|0;f=q<<14|q>>>18;q=w+1836072691+r+(d&(p^o)^o)|0;r=q<<8|q>>>24;q=F+1859775393+b+((f|~H)^l)|0;b=q<<9|q>>>23;q=v+1836072691+o+(r&(d^p)^p)|0;o=q<<6|q>>>26;q=C+1859775393+l+((b|~f)^H)|0;l=q<<13|q>>>19;q=A+1836072691+p+(o&(r^d)^d)|0;p=q<<6|q>>>26;q=u+1859775393+H+((l|~b)^f)|0;H=q<<15|q>>>17;q=z+1836072691+d+(p&(o^r)^r)|0;d=q<<14|q>>>18;q=n+1859775393+f+((H|~l)^b)|0;f=q<<14|q>>>18;q=B+1836072691+r+(d&(p^o)^o)|0;r=q<<12|q>>>20;q=w+1859775393+b+((f|~H)^l)|0;b=q<<8|q>>>24;q=C+1836072691+o+(r&(d^p)^p)|0;o=q<<13|q>>>19;q=s+1859775393+l+((b|~f)^H)|0;l=q<<13|q>>>19;q=G+1836072691+p+(o&(r^d)^d)|0;p=q<<5|q>>>27;q=A+1859775393+H+((l|~b)^f)|0;H=q<<6|q>>>26;q=n+1836072691+d+(p&(o^r)^r)|0;d=q<<14|q>>>18;q=D+1859775393+f+((H|~l)^b)|0;f=q<<5|q>>>27;q=E+1836072691+r+(d&(p^o)^o)|0;r=q<<13|q>>>19;q=B+1859775393+b+((f|~H)^l)|0;b=q<<12|q>>>20;q=s+1836072691+o+(r&(d^p)^p)|0;o=q<<13|q>>>19;q=t+1859775393+l+((b|~f)^H)|0;l=q<<7|q>>>25;q=y+1836072691+p+(o&(r^d)^d)|0;p=q<<7|q>>>25;q=G+1859775393+H+((l|~b)^f)|0;H=q<<5|q>>>27;q=D+1836072691+d+(p&(o^r)^r)|0;d=q<<5|q>>>27;q=g?p:l;j=g?l:p;p=u-1894007588+f+((H^q)&b^q)|0;f=p<<11|p>>>21;p=r+C+(j^o^d)|0;r=p<<15|p>>>17;p=z-1894007588+b+((f^H)&q^H)|0;b=p<<12|p>>>20;p=o+A+(d^j^r)|0;o=p<<5|p>>>27;p=B-1894007588+q+((b^f)&H^f)|0;q=p<<14|p>>>18;p=j+y+(r^d^o)|0;j=p<<8|p>>>24;p=E-1894007588+H+((q^b)&f^b)|0;H=p<<15|p>>>17;p=d+u+(o^r^j)|0;u=p<<11|p>>>21;p=s-1894007588+f+((H^q)&b^q)|0;f=p<<14|p>>>18;p=r+x+(j^o^u)|0;r=p<<14|p>>>18;p=C-1894007588+b+((f^H)&q^H)|0;b=p<<15|p>>>17;p=o+B+(u^j^r)|0;B=p<<14|p>>>18;p=G-1894007588+q+((b^f)&H^f)|0;q=p<<9|p>>>23;p=j+F+(r^u^B)|0;j=p<<6|p>>>26;p=y-1894007588+H+((q^b)&f^b)|0;H=p<<8|p>>>24;p=u+s+(B^r^j)|0;s=p<<14|p>>>18;p=D-1894007588+f+((H^q)&b^q)|0;f=p<<9|p>>>23;p=r+t+(j^B^s)|0;r=p<<6|p>>>26;p=x-1894007588+b+((f^H)&q^H)|0;b=p<<14|p>>>18;p=B+G+(s^j^r)|0;G=p<<9|p>>>23;p=w-1894007588+q+((b^f)&H^f)|0;q=p<<5|p>>>27;p=j+n+(r^s^G)|0;j=p<<12|p>>>20;p=F-1894007588+H+((q^b)&f^b)|0;H=p<<6|p>>>26;p=s+D+(G^r^j)|0;D=p<<9|p>>>23;p=v-1894007588+f+((H^q)&b^q)|0;f=p<<8|p>>>24;p=r+z+(j^G^D)|0;z=p<<12|p>>>20;p=t-1894007588+b+((f^H)&q^H)|0;b=p<<6|p>>>26;p=G+w+(D^j^z)|0;w=p<<5|p>>>27;p=A-1894007588+q+((b^f)&H^f)|0;q=p<<5|p>>>27;p=j+E+(z^D^w)|0;E=p<<15|p>>>17;p=n-1894007588+H+((q^b)&f^b)|0;H=p<<12|p>>>20;p=D+v+(w^z^E)|0;v=p<<8|p>>>24;p=g?w:b;D=g?b:w;if(g){c[a>>2]=(c[a>>2]|0)+f;c[h>>2]=(c[h>>2]|0)+H;c[k>>2]=(c[k>>2]|0)+q;c[m>>2]=(c[m>>2]|0)+p;g=a+16|0;c[g>>2]=(c[g>>2]|0)+z;g=a+20|0;c[g>>2]=(c[g>>2]|0)+v;g=a+24|0;c[g>>2]=(c[g>>2]|0)+E;g=a+28|0;c[g>>2]=(c[g>>2]|0)+D;i=e;return}else{g=q+D+(c[h>>2]|0)|0;c[h>>2]=p+z+(c[k>>2]|0);c[k>>2]=f+v+(c[m>>2]|0);c[m>>2]=H+E+(c[a>>2]|0);c[a>>2]=g;i=e;return}}function tFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;i=i+64|0;f=e|0;g=(d|0)!=0;d=c[a>>2]|0;h=a+4|0;j=c[h>>2]|0;k=a+8|0;l=c[k>>2]|0;m=a+12|0;n=c[m>>2]|0;o=a+16|0;p=c[o>>2]|0;if(g){q=c[a+36>>2]|0;r=c[a+32>>2]|0;s=c[a+28>>2]|0;t=c[a+24>>2]|0;u=c[a+20>>2]|0}else{q=p;r=n;s=l;t=j;u=d}UGb(f|0,b|0,64)|0;b=c[f>>2]|0;v=(l^j^n)+d+b|0;d=(v<<11|v>>>21)+p|0;v=c[f+20>>2]|0;w=u+1352829926+((s|~r)^t)+v|0;u=(w<<8|w>>>24)+q|0;w=l<<10|l>>>22;l=s<<10|s>>>22;s=c[f+4>>2]|0;x=s+p+(w^j^d)|0;p=(x<<14|x>>>18)+n|0;x=c[f+56>>2]|0;y=q+1352829926+x+(u^(t|~l))|0;q=(y<<9|y>>>23)+r|0;y=j<<10|j>>>22;j=t<<10|t>>>22;t=c[f+8>>2]|0;z=t+n+(d^y^p)|0;n=(z<<15|z>>>17)+w|0;z=c[f+28>>2]|0;A=r+1352829926+z+(q^(u|~j))|0;r=(A<<9|A>>>23)+l|0;A=d<<10|d>>>22;d=u<<10|u>>>22;u=c[f+12>>2]|0;B=u+w+(p^A^n)|0;w=(B<<12|B>>>20)+y|0;B=l+1352829926+b+(r^(q|~d))|0;l=(B<<11|B>>>21)+j|0;B=p<<10|p>>>22;p=q<<10|q>>>22;q=c[f+16>>2]|0;C=q+y+(n^B^w)|0;y=(C<<5|C>>>27)+A|0;C=c[f+36>>2]|0;D=j+1352829926+C+(l^(r|~p))|0;j=(D<<13|D>>>19)+d|0;D=n<<10|n>>>22;n=r<<10|r>>>22;r=A+v+(w^D^y)|0;A=(r<<8|r>>>24)+B|0;r=t+1352829926+d+(j^(l|~n))|0;d=(r<<15|r>>>17)+p|0;r=w<<10|w>>>22;w=l<<10|l>>>22;l=c[f+24>>2]|0;E=B+l+(y^r^A)|0;B=(E<<7|E>>>25)+D|0;E=c[f+44>>2]|0;F=E+1352829926+p+(d^(j|~w))|0;p=(F<<15|F>>>17)+n|0;F=y<<10|y>>>22;y=j<<10|j>>>22;j=D+z+(A^F^B)|0;D=(j<<9|j>>>23)+r|0;j=q+1352829926+n+(p^(d|~y))|0;n=(j<<5|j>>>27)+w|0;j=A<<10|A>>>22;A=d<<10|d>>>22;d=c[f+32>>2]|0;G=r+d+(B^j^D)|0;r=(G<<11|G>>>21)+F|0;G=c[f+52>>2]|0;H=G+1352829926+w+(n^(p|~A))|0;w=(H<<7|H>>>25)+y|0;H=B<<10|B>>>22;B=p<<10|p>>>22;p=F+C+(D^H^r)|0;F=(p<<13|p>>>19)+j|0;p=l+1352829926+y+(w^(n|~B))|0;y=(p<<7|p>>>25)+A|0;p=D<<10|D>>>22;D=n<<10|n>>>22;n=c[f+40>>2]|0;I=j+n+(r^p^F)|0;j=(I<<14|I>>>18)+H|0;I=c[f+60>>2]|0;J=I+1352829926+A+(y^(w|~D))|0;A=(J<<8|J>>>24)+B|0;J=r<<10|r>>>22;r=w<<10|w>>>22;w=H+E+(F^J^j)|0;H=(w<<15|w>>>17)+p|0;w=d+1352829926+B+(A^(y|~r))|0;B=(w<<11|w>>>21)+D|0;w=F<<10|F>>>22;F=y<<10|y>>>22;y=c[f+48>>2]|0;f=p+y+(j^w^H)|0;p=(f<<6|f>>>26)+J|0;f=s+1352829926+D+(B^(A|~F))|0;D=(f<<14|f>>>18)+r|0;f=j<<10|j>>>22;j=A<<10|A>>>22;A=J+G+(H^f^p)|0;J=(A<<7|A>>>25)+w|0;A=n+1352829926+r+(D^(B|~j))|0;r=(A<<14|A>>>18)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=w+x+(p^A^J)|0;w=(B<<9|B>>>23)+f|0;B=u+1352829926+F+(r^(D|~H))|0;F=(B<<12|B>>>20)+j|0;B=p<<10|p>>>22;p=D<<10|D>>>22;D=f+I+(J^B^w)|0;f=(D<<8|D>>>24)+A|0;D=y+1352829926+j+(F^(r|~p))|0;j=(D<<6|D>>>26)+H|0;D=J<<10|J>>>22;J=r<<10|r>>>22;r=g?j:f;K=g?f:j;j=z+1518500249+A+(r&(w^D)^D)|0;A=(j<<7|j>>>25)+B|0;j=l+1548603684+H+((K^F)&J^F)|0;H=(j<<9|j>>>23)+p|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=q+1518500249+B+(A&(r^j)^j)|0;B=(F<<6|F>>>26)+D|0;F=E+1548603684+p+((H^K)&w^K)|0;p=(F<<13|F>>>19)+J|0;F=r<<10|r>>>22;r=K<<10|K>>>22;K=G+1518500249+D+(B&(A^F)^F)|0;D=(K<<8|K>>>24)+j|0;K=u+1548603684+J+((p^H)&r^H)|0;J=(K<<15|K>>>17)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=s+1518500249+j+(D&(B^K)^K)|0;j=(H<<13|H>>>19)+F|0;H=z+1548603684+w+((J^p)&A^p)|0;w=(H<<7|H>>>25)+r|0;H=B<<10|B>>>22;B=p<<10|p>>>22;p=n+1518500249+F+(j&(D^H)^H)|0;F=(p<<11|p>>>21)+K|0;p=b+1548603684+r+((w^J)&B^J)|0;r=(p<<12|p>>>20)+A|0;p=D<<10|D>>>22;D=J<<10|J>>>22;J=l+1518500249+K+(F&(j^p)^p)|0;K=(J<<9|J>>>23)+H|0;J=G+1548603684+A+((r^w)&D^w)|0;A=(J<<8|J>>>24)+B|0;J=j<<10|j>>>22;j=w<<10|w>>>22;w=I+1518500249+H+(K&(F^J)^J)|0;H=(w<<7|w>>>25)+p|0;w=v+1548603684+B+((A^r)&j^r)|0;B=(w<<9|w>>>23)+D|0;w=F<<10|F>>>22;F=r<<10|r>>>22;r=u+1518500249+p+(H&(K^w)^w)|0;p=(r<<15|r>>>17)+J|0;r=n+1548603684+D+((B^A)&F^A)|0;D=(r<<11|r>>>21)+j|0;r=K<<10|K>>>22;K=A<<10|A>>>22;A=y+1518500249+J+(p&(H^r)^r)|0;J=(A<<7|A>>>25)+w|0;A=x+1548603684+j+((D^B)&K^B)|0;j=(A<<7|A>>>25)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=b+1518500249+w+(J&(p^A)^A)|0;w=(B<<12|B>>>20)+r|0;B=I+1548603684+F+((j^D)&H^D)|0;F=(B<<7|B>>>25)+K|0;B=p<<10|p>>>22;p=D<<10|D>>>22;D=C+1518500249+r+(w&(J^B)^B)|0;r=(D<<15|D>>>17)+A|0;D=d+1548603684+K+((F^j)&p^j)|0;K=(D<<12|D>>>20)+H|0;D=J<<10|J>>>22;J=j<<10|j>>>22;j=v+1518500249+A+(r&(w^D)^D)|0;A=(j<<9|j>>>23)+B|0;j=y+1548603684+H+((K^F)&J^F)|0;H=(j<<7|j>>>25)+p|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=t+1518500249+B+(A&(r^j)^j)|0;B=(F<<11|F>>>21)+D|0;F=q+1548603684+p+((H^K)&w^K)|0;p=(F<<6|F>>>26)+J|0;F=r<<10|r>>>22;r=K<<10|K>>>22;K=x+1518500249+D+(B&(A^F)^F)|0;D=(K<<7|K>>>25)+j|0;K=C+1548603684+J+((p^H)&r^H)|0;J=(K<<15|K>>>17)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=E+1518500249+j+(D&(B^K)^K)|0;j=(H<<13|H>>>19)+F|0;H=s+1548603684+w+((J^p)&A^p)|0;w=(H<<13|H>>>19)+r|0;H=B<<10|B>>>22;B=p<<10|p>>>22;p=d+1518500249+F+(j&(D^H)^H)|0;F=(p<<12|p>>>20)+K|0;p=t+1548603684+r+((w^J)&B^J)|0;r=(p<<11|p>>>21)+A|0;p=D<<10|D>>>22;D=J<<10|J>>>22;J=g?D:p;f=g?p:D;D=u+1859775393+K+(J^(F|~j))|0;K=(D<<11|D>>>21)+H|0;D=I+1836072691+A+((r|~w)^f)|0;A=(D<<9|D>>>23)+B|0;D=j<<10|j>>>22;j=w<<10|w>>>22;w=n+1859775393+H+((K|~F)^D)|0;H=(w<<13|w>>>19)+J|0;w=v+1836072691+B+((A|~r)^j)|0;B=(w<<7|w>>>25)+f|0;w=F<<10|F>>>22;F=r<<10|r>>>22;r=x+1859775393+J+((H|~K)^w)|0;J=(r<<6|r>>>26)+D|0;r=s+1836072691+f+((B|~A)^F)|0;f=(r<<15|r>>>17)+j|0;r=K<<10|K>>>22;K=A<<10|A>>>22;A=q+1859775393+D+((J|~H)^r)|0;D=(A<<7|A>>>25)+w|0;A=u+1836072691+j+((f|~B)^K)|0;j=(A<<11|A>>>21)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=C+1859775393+w+((D|~J)^A)|0;w=(B<<14|B>>>18)+r|0;B=z+1836072691+F+((j|~f)^H)|0;F=(B<<8|B>>>24)+K|0;B=J<<10|J>>>22;J=f<<10|f>>>22;f=I+1859775393+r+((w|~D)^B)|0;r=(f<<9|f>>>23)+A|0;f=x+1836072691+K+((F|~j)^J)|0;K=(f<<6|f>>>26)+H|0;f=D<<10|D>>>22;D=j<<10|j>>>22;j=d+1859775393+A+((r|~w)^f)|0;A=(j<<13|j>>>19)+B|0;j=l+1836072691+H+((K|~F)^D)|0;H=(j<<6|j>>>26)+J|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=s+1859775393+B+((A|~r)^j)|0;B=(F<<15|F>>>17)+f|0;F=C+1836072691+J+((H|~K)^w)|0;J=(F<<14|F>>>18)+D|0;F=r<<10|r>>>22;r=K<<10|K>>>22;K=t+1859775393+f+((B|~A)^F)|0;f=(K<<14|K>>>18)+j|0;K=E+1836072691+D+((J|~H)^r)|0;D=(K<<12|K>>>20)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=z+1859775393+j+((f|~B)^K)|0;j=(H<<8|H>>>24)+F|0;H=d+1836072691+w+((D|~J)^A)|0;w=(H<<13|H>>>19)+r|0;H=B<<10|B>>>22;B=J<<10|J>>>22;J=b+1859775393+F+((j|~f)^H)|0;F=(J<<13|J>>>19)+K|0;J=y+1836072691+r+((w|~D)^B)|0;r=(J<<5|J>>>27)+A|0;J=f<<10|f>>>22;f=D<<10|D>>>22;D=l+1859775393+K+((F|~j)^J)|0;K=(D<<6|D>>>26)+H|0;D=t+1836072691+A+((r|~w)^f)|0;A=(D<<14|D>>>18)+B|0;D=j<<10|j>>>22;j=w<<10|w>>>22;w=G+1859775393+H+((K|~F)^D)|0;H=(w<<5|w>>>27)+J|0;w=n+1836072691+B+((A|~r)^j)|0;B=(w<<13|w>>>19)+f|0;w=F<<10|F>>>22;F=r<<10|r>>>22;r=E+1859775393+J+((H|~K)^w)|0;J=(r<<12|r>>>20)+D|0;r=b+1836072691+f+((B|~A)^F)|0;f=(r<<13|r>>>19)+j|0;r=K<<10|K>>>22;K=A<<10|A>>>22;A=v+1859775393+D+((J|~H)^r)|0;D=(A<<7|A>>>25)+w|0;A=q+1836072691+j+((f|~B)^K)|0;j=(A<<7|A>>>25)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=y+1859775393+w+((D|~J)^A)|0;w=(B<<5|B>>>27)+r|0;B=G+1836072691+F+((j|~f)^H)|0;F=(B<<5|B>>>27)+K|0;B=J<<10|J>>>22;J=f<<10|f>>>22;f=s-1894007588+(g?K:r)+((w^D)&B^D)|0;p=(f<<11|f>>>21)+A|0;f=d+2053994217+(g?r:K)+(F&(j^J)^J)|0;K=(f<<15|f>>>17)+H|0;f=D<<10|D>>>22;D=j<<10|j>>>22;j=C-1894007588+A+((p^w)&f^w)|0;A=(j<<12|j>>>20)+B|0;j=l+2053994217+H+(K&(F^D)^D)|0;H=(j<<5|j>>>27)+J|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=E-1894007588+B+((A^p)&j^p)|0;B=(F<<14|F>>>18)+f|0;F=q+2053994217+J+(H&(K^w)^w)|0;J=(F<<8|F>>>24)+D|0;F=p<<10|p>>>22;p=K<<10|K>>>22;K=n-1894007588+f+((B^A)&F^A)|0;f=(K<<15|K>>>17)+j|0;K=s+2053994217+D+(J&(H^p)^p)|0;D=(K<<11|K>>>21)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=b-1894007588+j+((f^B)&K^B)|0;j=(H<<14|H>>>18)+F|0;H=u+2053994217+w+(D&(J^A)^A)|0;w=(H<<14|H>>>18)+p|0;H=B<<10|B>>>22;B=J<<10|J>>>22;J=d-1894007588+F+((j^f)&H^f)|0;F=(J<<15|J>>>17)+K|0;J=E+2053994217+p+(w&(D^B)^B)|0;p=(J<<14|J>>>18)+A|0;J=f<<10|f>>>22;f=D<<10|D>>>22;D=y-1894007588+K+((F^j)&J^j)|0;K=(D<<9|D>>>23)+H|0;D=I+2053994217+A+(p&(w^f)^f)|0;A=(D<<6|D>>>26)+B|0;D=j<<10|j>>>22;j=w<<10|w>>>22;w=q-1894007588+H+((K^F)&D^F)|0;H=(w<<8|w>>>24)+J|0;w=b+2053994217+B+(A&(p^j)^j)|0;B=(w<<14|w>>>18)+f|0;w=F<<10|F>>>22;F=p<<10|p>>>22;p=G-1894007588+J+((H^K)&w^K)|0;J=(p<<9|p>>>23)+D|0;p=v+2053994217+f+(B&(A^F)^F)|0;f=(p<<6|p>>>26)+j|0;p=K<<10|K>>>22;K=A<<10|A>>>22;A=u-1894007588+D+((J^H)&p^H)|0;D=(A<<14|A>>>18)+w|0;A=y+2053994217+j+(f&(B^K)^K)|0;j=(A<<9|A>>>23)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=z-1894007588+w+((D^J)&A^J)|0;w=(B<<5|B>>>27)+p|0;B=t+2053994217+F+(j&(f^H)^H)|0;F=(B<<12|B>>>20)+K|0;B=J<<10|J>>>22;J=f<<10|f>>>22;f=I-1894007588+p+((w^D)&B^D)|0;p=(f<<6|f>>>26)+A|0;f=G+2053994217+K+(F&(j^J)^J)|0;K=(f<<9|f>>>23)+H|0;f=D<<10|D>>>22;D=j<<10|j>>>22;j=x-1894007588+A+((p^w)&f^w)|0;A=(j<<8|j>>>24)+B|0;j=C+2053994217+H+(K&(F^D)^D)|0;H=(j<<12|j>>>20)+J|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=v-1894007588+B+((A^p)&j^p)|0;B=(F<<6|F>>>26)+f|0;F=z+2053994217+J+(H&(K^w)^w)|0;J=(F<<5|F>>>27)+D|0;F=p<<10|p>>>22;p=K<<10|K>>>22;K=l-1894007588+f+((B^A)&F^A)|0;f=(K<<5|K>>>27)+j|0;K=n+2053994217+D+(J&(H^p)^p)|0;D=(K<<15|K>>>17)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=t-1894007588+j+((f^B)&K^B)|0;j=(H<<12|H>>>20)+F|0;H=x+2053994217+w+(D&(J^A)^A)|0;w=(H<<8|H>>>24)+p|0;H=B<<10|B>>>22;B=J<<10|J>>>22;J=g?D:f;r=g?f:D;D=q-1454113458+F+(j^(J|~H))|0;F=(D<<9|D>>>23)+K|0;D=p+y+(r^B^w)|0;p=(D<<8|D>>>24)+A|0;D=J<<10|J>>>22;J=r<<10|r>>>22;r=b-1454113458+K+(F^(j|~D))|0;K=(r<<15|r>>>17)+H|0;r=A+I+(J^w^p)|0;A=(r<<5|r>>>27)+B|0;r=j<<10|j>>>22;j=w<<10|w>>>22;w=v-1454113458+H+(K^(F|~r))|0;H=(w<<5|w>>>27)+D|0;w=B+n+(p^j^A)|0;B=(w<<12|w>>>20)+J|0;w=F<<10|F>>>22;F=p<<10|p>>>22;p=C-1454113458+D+(H^(K|~w))|0;D=(p<<11|p>>>21)+r|0;p=J+q+(A^F^B)|0;q=(p<<9|p>>>23)+j|0;p=K<<10|K>>>22;K=A<<10|A>>>22;A=z-1454113458+r+(D^(H|~p))|0;r=(A<<6|A>>>26)+w|0;A=j+s+(B^K^q)|0;j=(A<<12|A>>>20)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=y-1454113458+w+(r^(D|~A))|0;w=(B<<8|B>>>24)+p|0;B=F+v+(q^H^j)|0;v=(B<<5|B>>>27)+K|0;B=D<<10|D>>>22;D=q<<10|q>>>22;q=t-1454113458+p+(w^(r|~B))|0;p=(q<<13|q>>>19)+A|0;q=K+d+(j^D^v)|0;K=(q<<14|q>>>18)+H|0;q=r<<10|r>>>22;r=j<<10|j>>>22;j=n-1454113458+A+(p^(w|~q))|0;A=(j<<12|j>>>20)+B|0;j=H+z+(v^r^K)|0;z=(j<<6|j>>>26)+D|0;j=w<<10|w>>>22;w=v<<10|v>>>22;v=x-1454113458+B+(A^(p|~j))|0;B=(v<<5|v>>>27)+q|0;v=D+l+(K^w^z)|0;D=(v<<8|v>>>24)+r|0;v=p<<10|p>>>22;p=K<<10|K>>>22;K=s-1454113458+q+(B^(A|~v))|0;q=(K<<12|K>>>20)+j|0;K=r+t+(z^p^D)|0;t=(K<<13|K>>>19)+w|0;K=A<<10|A>>>22;A=z<<10|z>>>22;z=u-1454113458+j+(q^(B|~K))|0;j=(z<<13|z>>>19)+v|0;z=w+G+(D^A^t)|0;w=(z<<6|z>>>26)+p|0;z=B<<10|B>>>22;B=D<<10|D>>>22;D=d-1454113458+v+(j^(q|~z))|0;v=(D<<14|D>>>18)+K|0;D=p+x+(t^B^w)|0;x=(D<<5|D>>>27)+A|0;D=q<<10|q>>>22;q=t<<10|t>>>22;t=E-1454113458+K+(v^(j|~D))|0;K=(t<<11|t>>>21)+z|0;t=A+b+(w^q^x)|0;b=(t<<15|t>>>17)+B|0;t=j<<10|j>>>22;j=w<<10|w>>>22;w=l-1454113458+z+(K^(v|~t))|0;z=(w<<8|w>>>24)+D|0;w=B+u+(x^j^b)|0;u=(w<<13|w>>>19)+q|0;w=v<<10|v>>>22;v=x<<10|x>>>22;x=I-1454113458+D+(z^(K|~w))|0;D=(x<<5|x>>>27)+t|0;x=q+C+(b^v^u)|0;C=(x<<11|x>>>21)+j|0;x=K<<10|K>>>22;K=b<<10|b>>>22;b=G-1454113458+t+(D^(z|~x))|0;t=(b<<6|b>>>26)+w|0;b=j+E+(u^K^C)|0;E=(b<<11|b>>>21)+v|0;b=z<<10|z>>>22;z=u<<10|u>>>22;u=g?K:x;j=g?x:K;if(g){c[a>>2]=(c[a>>2]|0)+w;c[h>>2]=(c[h>>2]|0)+t;c[k>>2]=(c[k>>2]|0)+D;c[m>>2]=(c[m>>2]|0)+b;c[o>>2]=(c[o>>2]|0)+u;g=a+20|0;c[g>>2]=(c[g>>2]|0)+v;g=a+24|0;c[g>>2]=(c[g>>2]|0)+E;g=a+28|0;c[g>>2]=(c[g>>2]|0)+C;g=a+32|0;c[g>>2]=(c[g>>2]|0)+z;g=a+36|0;c[g>>2]=(c[g>>2]|0)+j;i=e;return}else{g=D+z+(c[h>>2]|0)|0;c[h>>2]=b+j+(c[k>>2]|0);c[k>>2]=u+v+(c[m>>2]|0);c[m>>2]=E+w+(c[o>>2]|0);c[o>>2]=t+C+(c[a>>2]|0);c[a>>2]=g;i=e;return}}function uFb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a+8|0;g=c[f>>2]|0;h=g&63;i=YGb(g,c[f+4>>2]|0,e,0)|0;c[f>>2]=i;c[f+4>>2]=F;do{if((h+e|0)>>>0>63>>>0){f=64-h|0;UGb(a+16+h|0,b|0,f)|0;i=a+124|0;g=a+80|0;j=a+120|0;Xe[c[i>>2]&4095](g,a+16|0,d[j]|0);if((f+63|0)>>>0<e>>>0){k=f}else{l=0;m=f;break}while(1){Xe[c[i>>2]&4095](g,b+k|0,d[j]|0);f=k+64|0;if((k+127|0)>>>0<e>>>0){k=f}else{l=0;m=f;break}}}else{l=h;m=0}}while(0);UGb(a+16+l|0,b+m|0,e-m|0)|0;return}function vFb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;f=i;i=i+8|0;g=f|0;h=b+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;c[g>>2]=j<<3|0>>>29;c[g+4>>2]=k<<3|j>>>29;l=j&63;m=YGb(j,k,1,0)|0;c[h>>2]=m;c[h+4>>2]=F;if((l+1|0)>>>0>63>>>0){m=64-l|0;UGb(b+16+l|0,2156440,m)|0;Xe[c[b+124>>2]&4095](b+80|0,b+16|0,d[b+120|0]|0);n=0;o=m}else{n=l;o=0}UGb(b+16+n|0,2156440+o|0,1-o|0)|0;o=c[h>>2]|0;n=c[h+4>>2]|0;if((o&63|0)==56&(n&0|0)==0){p=n;q=o}else{l=b+124|0;m=b+80|0;k=b+16|0;j=b+120|0;r=n;n=o;while(1){o=n&63;s=YGb(n,r,1,0)|0;c[h>>2]=s;c[h+4>>2]=F;if((o+1|0)>>>0>63>>>0){s=64-o|0;UGb(b+16+o|0,9203600,s)|0;Xe[c[l>>2]&4095](m,k,d[j]|0);t=0;u=s}else{t=o;u=0}UGb(b+16+t|0,9203600+u|0,1-u|0)|0;o=c[h>>2]|0;s=c[h+4>>2]|0;if((o&63|0)==56&(s&0|0)==0){p=s;q=o;break}else{r=s;n=o}}}n=g;g=q&63;r=YGb(q,p,8,0)|0;c[h>>2]=r;c[h+4>>2]=F;do{if((g+8|0)>>>0>63>>>0){h=64-g|0;UGb(b+16+g|0,n|0,h)|0;r=b+124|0;p=b+80|0;q=b+120|0;Xe[c[r>>2]&4095](p,b+16|0,d[q]|0);if((h+63|0)>>>0<8>>>0){v=h}else{w=0;y=h;break}while(1){Xe[c[r>>2]&4095](p,n+v|0,d[q]|0);h=v+64|0;if((v+127|0)>>>0<8>>>0){v=h}else{w=0;y=h;break}}}else{w=g;y=0}}while(0);UGb(b+16+w|0,n+y|0,8-y|0)|0;y=b|0;if((a[y]|0)==0){i=f;return}else{z=0}do{n=e+(z<<2)|0;x=c[b+80+(z<<2)>>2]|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;z=z+1|0;}while((z|0)<(d[y]|0));i=f;return}function wFb(a){a=a|0;var b=0;if(a>>>0>9>>>0){b=0}else{b=483264+(a*20|0)|0}return b|0}function xFb(a){a=a|0;var b=0,c=0,d=0;b=0;while(1){if((b|0)>=10){c=-1;d=4;break}if((QGb(483264+(b*20|0)|0,a)|0)==0){c=b;d=4;break}else{b=b+1|0}}if((d|0)==4){return c|0}return 0}function yFb(a){a=a|0;var b=0;do{if(a>>>0>9>>>0){b=-1}else{if(!((a-5|0)>>>0<5>>>0)){b=a;break}b=c[483280+(a*20|0)>>2]|0}}while(0);return b|0}function zFb(a){a=a|0;var b=0;do{if(a>>>0>9>>>0){b=-1}else{if((a-5|0)>>>0<5>>>0){b=a;break}b=c[483280+(a*20|0)>>2]|0}}while(0);return b|0}function AFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+24|0;f=e|0;if((d|0)<0){Lb(a|0,b|0,2156400,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0)|0;i=g;i=e;return a|0}if((d|0)>=10){i=e;return a|0}h=f|0;j=483264+(d*20|0)|0;c[h>>2]=c[j>>2];c[h+4>>2]=c[j+4>>2];c[h+8>>2]=c[j+8>>2];c[h+12>>2]=c[j+12>>2];c[h+16>>2]=c[j+16>>2];j=c[f+8>>2]|0;Lb(a|0,b|0,2299800,(g=i,i=i+16|0,c[g>>2]=h,c[g+8>>2]=j,g)|0)|0;i=g;i=e;return a|0}function BFb(a){a=a|0;var b=0;if(a>>>0>9>>>0){b=0;return b|0}b=c[483272+(a*20|0)>>2]>>3;return b|0}function CFb(a){a=a|0;var b=0;if(a>>>0>9>>>0){b=0;return b|0}b=c[483276+(a*20|0)>>2]|0;return b|0}function DFb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(e>>>0>9>>>0){g=-22;return g|0}h=c[483272+(e*20|0)>>2]>>3;if((h|0)==0|(d|0)<1|(b|0)<1){g=-22;return g|0}do{if((f|0)==0){if((d|0)>2147483616){g=-22;return g|0}else{i=d+31&-32;j=1;break}}else{i=d;j=f}}while(0);if((2147483647/(j|0)|0|0)<(b|0)){g=-22;return g|0}f=gHb(i,(i|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;d=F;k=(2147483647-(ba(j,b)|0)|0)/(h|0)|0;l=(k|0)<0|0?-1:0;if((d|0)>(l|0)|(d|0)==(l|0)&f>>>0>k>>>0){g=-22;return g|0}k=(e-5|0)>>>0<5>>>0;e=ba(i,h)|0;if(k){m=j-1+e&-j}else{m=j-1+(ba(e,b)|0)&-j}if((a|0)!=0){c[a>>2]=m}if(!k){g=m;return g|0}g=ba(m,b)|0;return g|0}function EFb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if(g>>>0>9>>>0){i=-22;return i|0}j=c[483272+(g*20|0)>>2]>>3;if((j|0)==0|(f|0)<1|(e|0)<1){i=-22;return i|0}do{if((h|0)==0){if((f|0)>2147483616){i=-22;return i|0}else{k=f+31&-32;l=1;break}}else{k=f;l=h}}while(0);if((2147483647/(l|0)|0|0)<(e|0)){i=-22;return i|0}h=gHb(k,(k|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;f=F;m=(2147483647-(ba(l,e)|0)|0)/(j|0)|0;n=(m|0)<0|0?-1:0;if((f|0)>(n|0)|(f|0)==(n|0)&h>>>0>m>>>0){i=-22;return i|0}m=(g-5|0)>>>0<5>>>0;g=ba(k,j)|0;if(m){j=l-1+g&-l;o=ba(j,e)|0;p=j}else{j=l-1+(ba(g,e)|0)&-l;o=j;p=j}if((o|0)<0){i=o;return i|0}c[a>>2]=d;if(m&(e|0)>1){m=1;o=d;do{o=o+p|0;c[a+(m<<2)>>2]=o;m=m+1|0;}while((m|0)<(e|0))}if((b|0)==0){i=0;return i|0}c[b>>2]=p;i=0;return i|0}function FFb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if(f>>>0>9>>>0){h=-22;return h|0}i=c[483272+(f*20|0)>>2]>>3;if((i|0)==0|(e|0)<1|(d|0)<1){h=-22;return h|0}do{if((g|0)==0){if((e|0)>2147483616){h=-22;return h|0}else{j=e+31&-32;k=1;break}}else{j=e;k=g}}while(0);if((2147483647/(k|0)|0|0)<(d|0)){h=-22;return h|0}l=gHb(j,(j|0)<0|0?-1:0,d,(d|0)<0|0?-1:0)|0;m=F;n=(2147483647-(ba(k,d)|0)|0)/(i|0)|0;o=(n|0)<0|0?-1:0;if((m|0)>(o|0)|(m|0)==(o|0)&l>>>0>n>>>0){h=-22;return h|0}n=(f-5|0)>>>0<5>>>0;l=ba(j,i)|0;if(n){p=ba(k-1+l&-k,d)|0}else{p=k-1+(ba(l,d)|0)&-k}if((p|0)<0){h=p;return h|0}k=WDb(p)|0;if((k|0)==0){h=-12;return h|0}p=EFb(a,b,k,d,e,f,g)|0;if((p|0)<0){ZDb(k);h=p;return h|0}p=n?d:1;k=ba(ba(n?1:d,e)|0,i)|0;if((f|0)==0){q=-128}else{q=(f|0)==5?-128:0}if((p|0)>0){r=0}else{h=0;return h|0}while(1){TGb(c[a+(r<<2)>>2]|0,q|0,k|0)|0;f=r+1|0;if((f|0)<(p|0)){r=f}else{h=0;break}}return h|0}function GFb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if(f>>>0>9>>>0){g=1;h=0;i=0;j=3}else{k=(f-5|0)>>>0<5>>>0;l=k?e:1;m=ba(c[483272+(f*20|0)>>2]>>3,k?1:e)|0;e=ba(m,d)|0;if((f|0)==0){n=-128;o=l;p=m;q=e}else{g=l;h=m;i=e;j=3}}if((j|0)==3){n=(f|0)==5?-128:0;o=g;p=h;q=i}i=ba(p,b)|0;if((o|0)>0){r=0}else{return 0}do{TGb((c[a+(r<<2)>>2]|0)+i|0,n|0,q|0)|0;r=r+1|0;}while((r|0)<(o|0));return 0}function HFb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if(f>>>0>9>>>0){h=1}else{h=(f-5|0)>>>0<5>>>0?d:1}i=dEb(h,4)|0;h=i;c[a>>2]=h;if((i|0)==0){j=-12;return j|0}i=FFb(h,b,d,e,f,g)|0;if((i|0)>=0){j=i;return j|0}$Db(a);j=i;return j|0}function IFb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if(h>>>0>9>>>0){i=0;j=g;k=1}else{l=(h-5|0)>>>0<5>>>0;i=c[483272+(h*20|0)>>2]>>3;j=l?1:g;k=l?g:1}g=ba(i,j)|0;j=ba(g,f)|0;f=ba(g,d)|0;d=ba(g,e)|0;e=c[a>>2]|0;g=c[b>>2]|0;if(e>>>0<g>>>0){m=g-e|0}else{m=e-g|0}i=(k|0)>0;if((m|0)<(j|0)){if(i){n=1;o=e;p=g}else{return 0}while(1){VGb(o+f|0,p+d|0,j|0)|0;if((n|0)>=(k|0)){break}m=c[a+(n<<2)>>2]|0;l=c[b+(n<<2)>>2]|0;n=n+1|0;o=m;p=l}return 0}else{if(i){q=1;r=e;s=g}else{return 0}while(1){UGb(r+f|0,s+d|0,j)|0;if((q|0)>=(k|0)){break}g=c[a+(q<<2)>>2]|0;e=c[b+(q<<2)>>2]|0;q=q+1|0;r=g;s=e}return 0}return 0}function JFb(){return cEb(120)|0}function KFb(b,d){b=b|0;d=d|0;var e=0;a[b|0]=d>>>5;if((d|0)==256){c[b+80>>2]=1779033703;c[b+84>>2]=-1150833019;c[b+88>>2]=1013904242;c[b+92>>2]=-1521486534;c[b+96>>2]=1359893119;c[b+100>>2]=-1694144372;c[b+104>>2]=528734635;c[b+108>>2]=1541459225;c[b+112>>2]=186}else if((d|0)==160){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+96>>2]=-1009589776;c[b+112>>2]=426}else if((d|0)==224){c[b+80>>2]=-1056596264;c[b+84>>2]=914150663;c[b+88>>2]=812702999;c[b+92>>2]=-150054599;c[b+96>>2]=-4191439;c[b+100>>2]=1750603025;c[b+104>>2]=1694076839;c[b+108>>2]=-1090891868;c[b+112>>2]=186}else{e=-1;return e|0}d=b+8|0;c[d>>2]=0;c[d+4>>2]=0;e=0;return e|0}function LFb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=c[a>>2]|0;f=a+4|0;g=c[f>>2]|0;h=a+8|0;i=c[h>>2]|0;j=a+12|0;k=c[j>>2]|0;l=a+16|0;m=c[l>>2]|0;n=b;o=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=(e<<5|e>>>27)+1518500249+m+o+((k^i)&g^k)|0;m=g<<30|g>>>2;g=b+4|0;p=fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=k+1518500249+((m^i)&e^i)+p+(n<<5|n>>>27)|0;k=e<<30|e>>>2;q=b+8|0;r=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=i+1518500249+r+(n&(m^k)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+12|0;s=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=m+1518500249+s+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b+16|0;t=fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=k+1518500249+t+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b+20|0;u=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=i+1518500249+u+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+24|0;v=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=m+1518500249+v+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b+28|0;w=fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=k+1518500249+w+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b+32|0;x=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=i+1518500249+x+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+36|0;y=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=m+1518500249+y+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b+40|0;z=fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=k+1518500249+z+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b+44|0;A=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=A+1518500249+i+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+48|0;B=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=B+1518500249+m+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b+52|0;C=fe(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=C+1518500249+k+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b+56|0;D=fe(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=D+1518500249+i+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+60|0;b=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=b+1518500249+m+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=r^o^x^C;o=g<<1|g>>>31;g=o+1518500249+k+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=s^p^y^D;p=q<<1|q>>>31;q=p+1518500249+i+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=t^r^z^b;r=n<<1|n>>>31;n=r+1518500249+m+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=u^s^A^o;s=g<<1|g>>>31;g=s+1518500249+k+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=v^t^B^p;t=q<<1|q>>>31;q=t+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=w^u^C^r;u=n<<1|n>>>31;n=u+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=x^v^D^s;v=g<<1|g>>>31;g=v+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=y^w^b^t;w=q<<1|q>>>31;q=w+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=z^x^o^u;x=n<<1|n>>>31;n=x+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=A^y^p^v;y=g<<1|g>>>31;g=y+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=B^z^r^w;z=q<<1|q>>>31;q=z+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=C^A^s^x;A=n<<1|n>>>31;n=A+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=D^B^t^y;B=g<<1|g>>>31;g=B+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b^C^u^z;C=q<<1|q>>>31;q=C+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=o^D^v^A;D=n<<1|n>>>31;n=D+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=p^b^w^B;b=g<<1|g>>>31;g=b+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=r^o^x^C;o=q<<1|q>>>31;q=o+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=s^p^y^D;p=n<<1|n>>>31;n=p+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=t^r^z^b;r=g<<1|g>>>31;g=r+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=u^s^A^o;s=q<<1|q>>>31;q=s+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=v^t^B^p;t=n<<1|n>>>31;n=t+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=w^u^C^r;u=g<<1|g>>>31;g=u+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=x^v^D^s;v=q<<1|q>>>31;q=v+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=y^w^b^t;w=n<<1|n>>>31;n=w+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=z^x^o^u;x=g<<1|g>>>31;g=x-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=A^y^p^v;y=q<<1|q>>>31;q=y-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=B^z^r^w;z=n<<1|n>>>31;n=z-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=C^A^s^x;A=g<<1|g>>>31;g=A-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=D^B^t^y;B=q<<1|q>>>31;q=B-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b^C^u^z;C=n<<1|n>>>31;n=C-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=o^D^v^A;D=g<<1|g>>>31;g=D-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=p^b^w^B;b=q<<1|q>>>31;q=b-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=r^o^x^C;o=n<<1|n>>>31;n=o-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=s^p^y^D;p=g<<1|g>>>31;g=p-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=t^r^z^b;r=q<<1|q>>>31;q=r-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=u^s^A^o;s=n<<1|n>>>31;n=s-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=v^t^B^p;t=g<<1|g>>>31;g=t-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=w^u^C^r;u=q<<1|q>>>31;q=u-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=x^v^D^s;v=n<<1|n>>>31;n=v-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=y^w^b^t;w=g<<1|g>>>31;g=w-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=z^x^o^u;x=q<<1|q>>>31;q=x-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=A^y^p^v;y=n<<1|n>>>31;n=y-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=B^z^r^w;z=g<<1|g>>>31;g=z-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=C^A^s^x;A=q<<1|q>>>31;q=A-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=D^B^t^y;B=n<<1|n>>>31;n=B-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b^C^u^z;C=g<<1|g>>>31;g=C-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=o^D^v^A;D=q<<1|q>>>31;q=D-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=p^b^w^B;b=n<<1|n>>>31;n=b-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=r^o^x^C;o=g<<1|g>>>31;g=o-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=s^p^y^D;p=q<<1|q>>>31;q=p-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=t^r^z^b;r=n<<1|n>>>31;n=r-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=u^s^A^o;s=g<<1|g>>>31;g=s-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=v^t^B^p;t=q<<1|q>>>31;q=t-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=w^u^C^r;u=n<<1|n>>>31;n=u-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=x^v^D^s;v=g<<1|g>>>31;g=v-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=y^w^b^t;w=q<<1|q>>>31;q=w-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=z^x^o^u;x=n<<1|n>>>31;n=x-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=A^y^p^v;y=g<<1|g>>>31;g=y-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=B^z^r^w;r=q<<1|q>>>31;q=r-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=C^A^s^x;x=n<<1|n>>>31;n=x-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=D^B^t^y;y=g<<1|g>>>31;g=y-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b^C^u^r;r=(q<<1|q>>>31)-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=o^D^v^x;x=(n<<1|n>>>31)-899497514+m+(i^k^g)+(r<<5|r>>>27)|0;m=g<<30|g>>>2;g=p^b^w^y;c[a>>2]=e-899497514+(g<<1|g>>>31)+k+(m^i^r)+(x<<5|x>>>27);c[f>>2]=x+(c[f>>2]|0);c[h>>2]=(r<<30|r>>>2)+(c[h>>2]|0);c[j>>2]=m+(c[j>>2]|0);c[l>>2]=i+(c[l>>2]|0);return}function MFb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=c[a>>2]|0;f=a+4|0;g=c[f>>2]|0;h=a+8|0;i=c[h>>2]|0;j=a+12|0;k=c[j>>2]|0;l=a+16|0;m=c[l>>2]|0;n=a+20|0;o=c[n>>2]|0;p=a+24|0;q=c[p>>2]|0;r=a+28|0;s=c[r>>2]|0;t=b;u=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=s+1116352408+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))+((q^o)&m^q)+u|0;s=t+k|0;k=((i|g)&e|i&g)+((e<<30|e>>>2)^(e<<19|e>>>13)^(e<<10|e>>>22))+t|0;t=b+4|0;v=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=q+1899447441+v+(s&(o^m)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(g|e)|g&e)+t|0;t=b+8|0;w=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=o-1245643825+w+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=t+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|e)|k&e)+t|0;t=b+12|0;x=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=m-373957723+x+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=t+e|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+t|0;t=b+16|0;z=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=s+961987163+z+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=b+20|0;A=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=q+1508970993+A+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=b+24|0;B=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=B-1841331548+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=t+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+t|0;t=b+28|0;C=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=C-1424204075+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=t+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+t|0;t=b+32|0;D=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=D-670586216+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=b+36|0;E=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=E+310598401+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=b+40|0;F=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=F+607225278+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=t+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+t|0;t=b+44|0;G=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=G+1426881987+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=t+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+t|0;t=b+48|0;H=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=H+1925078388+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=b+52|0;I=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=I-2132889090+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=b+56|0;J=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=J-1680079193+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=t+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+t|0;t=b+60|0;b=fe(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=b-1046744716+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=t+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+t|0;t=((v<<14|v>>>18)^v>>>3^(v<<25|v>>>7))+u+E+((J<<13|J>>>19)^J>>>10^(J<<15|J>>>17))|0;u=t-459576895+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=u+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+u|0;u=((w<<14|w>>>18)^w>>>3^(w<<25|w>>>7))+v+F+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))|0;v=u-272742522+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=v+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+v|0;v=((x<<14|x>>>18)^x>>>3^(x<<25|x>>>7))+w+G+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))|0;w=v+264347078+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=w+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+w|0;w=((z<<14|z>>>18)^z>>>3^(z<<25|z>>>7))+x+H+((u<<13|u>>>19)^u>>>10^(u<<15|u>>>17))|0;x=w+604807628+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=x+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+x|0;x=((A<<14|A>>>18)^A>>>3^(A<<25|A>>>7))+z+I+((v<<13|v>>>19)^v>>>10^(v<<15|v>>>17))|0;z=x+770255983+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=z+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+z|0;z=((B<<14|B>>>18)^B>>>3^(B<<25|B>>>7))+A+J+((w<<13|w>>>19)^w>>>10^(w<<15|w>>>17))|0;A=z+1249150122+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=A+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+A|0;A=((C<<14|C>>>18)^C>>>3^(C<<25|C>>>7))+B+b+((x<<13|x>>>19)^x>>>10^(x<<15|x>>>17))|0;B=A+1555081692+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=B+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+B|0;B=((D<<14|D>>>18)^D>>>3^(D<<25|D>>>7))+C+t+((z<<13|z>>>19)^z>>>10^(z<<15|z>>>17))|0;C=B+1996064986+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=C+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+C|0;C=((E<<14|E>>>18)^E>>>3^(E<<25|E>>>7))+D+u+((A<<13|A>>>19)^A>>>10^(A<<15|A>>>17))|0;D=C-1740746414+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=D+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+D|0;D=((F<<14|F>>>18)^F>>>3^(F<<25|F>>>7))+E+v+((B<<13|B>>>19)^B>>>10^(B<<15|B>>>17))|0;E=D-1473132947+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=E+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+E|0;E=((G<<14|G>>>18)^G>>>3^(G<<25|G>>>7))+F+w+((C<<13|C>>>19)^C>>>10^(C<<15|C>>>17))|0;F=E-1341970488+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=F+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+F|0;F=((H<<14|H>>>18)^H>>>3^(H<<25|H>>>7))+G+x+((D<<13|D>>>19)^D>>>10^(D<<15|D>>>17))|0;G=F-1084653625+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=G+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+G|0;G=((I<<14|I>>>18)^I>>>3^(I<<25|I>>>7))+H+z+((E<<13|E>>>19)^E>>>10^(E<<15|E>>>17))|0;H=G-958395405+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=H+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+H|0;H=((J<<14|J>>>18)^J>>>3^(J<<25|J>>>7))+I+A+((F<<13|F>>>19)^F>>>10^(F<<15|F>>>17))|0;I=H-710438585+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=I+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+I|0;I=((b<<14|b>>>18)^b>>>3^(b<<25|b>>>7))+J+B+((G<<13|G>>>19)^G>>>10^(G<<15|G>>>17))|0;J=I+113926993+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=J+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+J|0;J=((t<<14|t>>>18)^t>>>3^(t<<25|t>>>7))+b+C+((H<<13|H>>>19)^H>>>10^(H<<15|H>>>17))|0;b=J+338241895+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=b+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+b|0;b=((u<<14|u>>>18)^u>>>3^(u<<25|u>>>7))+t+D+((I<<13|I>>>19)^I>>>10^(I<<15|I>>>17))|0;t=b+666307205+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=((v<<14|v>>>18)^v>>>3^(v<<25|v>>>7))+u+E+((J<<13|J>>>19)^J>>>10^(J<<15|J>>>17))|0;u=t+773529912+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=u+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+u|0;u=((w<<14|w>>>18)^w>>>3^(w<<25|w>>>7))+v+F+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))|0;v=u+1294757372+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=v+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+v|0;v=((x<<14|x>>>18)^x>>>3^(x<<25|x>>>7))+w+G+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))|0;w=v+1396182291+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=w+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+w|0;w=((z<<14|z>>>18)^z>>>3^(z<<25|z>>>7))+x+H+((u<<13|u>>>19)^u>>>10^(u<<15|u>>>17))|0;x=w+1695183700+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=x+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+x|0;x=((A<<14|A>>>18)^A>>>3^(A<<25|A>>>7))+z+I+((v<<13|v>>>19)^v>>>10^(v<<15|v>>>17))|0;z=x+1986661051+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=z+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+z|0;z=((B<<14|B>>>18)^B>>>3^(B<<25|B>>>7))+A+J+((w<<13|w>>>19)^w>>>10^(w<<15|w>>>17))|0;A=z-2117940946+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=A+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+A|0;A=((C<<14|C>>>18)^C>>>3^(C<<25|C>>>7))+B+b+((x<<13|x>>>19)^x>>>10^(x<<15|x>>>17))|0;B=A-1838011259+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=B+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+B|0;B=((D<<14|D>>>18)^D>>>3^(D<<25|D>>>7))+C+t+((z<<13|z>>>19)^z>>>10^(z<<15|z>>>17))|0;C=B-1564481375+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=C+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+C|0;C=((E<<14|E>>>18)^E>>>3^(E<<25|E>>>7))+D+u+((A<<13|A>>>19)^A>>>10^(A<<15|A>>>17))|0;D=C-1474664885+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=D+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+D|0;D=((F<<14|F>>>18)^F>>>3^(F<<25|F>>>7))+E+v+((B<<13|B>>>19)^B>>>10^(B<<15|B>>>17))|0;E=D-1035236496+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=E+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+E|0;E=((G<<14|G>>>18)^G>>>3^(G<<25|G>>>7))+F+w+((C<<13|C>>>19)^C>>>10^(C<<15|C>>>17))|0;F=E-949202525+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=F+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+F|0;F=((H<<14|H>>>18)^H>>>3^(H<<25|H>>>7))+G+x+((D<<13|D>>>19)^D>>>10^(D<<15|D>>>17))|0;G=F-778901479+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=G+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+G|0;G=((I<<14|I>>>18)^I>>>3^(I<<25|I>>>7))+H+z+((E<<13|E>>>19)^E>>>10^(E<<15|E>>>17))|0;H=G-694614492+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=H+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+H|0;H=((J<<14|J>>>18)^J>>>3^(J<<25|J>>>7))+I+A+((F<<13|F>>>19)^F>>>10^(F<<15|F>>>17))|0;I=H-200395387+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=I+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+I|0;I=((b<<14|b>>>18)^b>>>3^(b<<25|b>>>7))+J+B+((G<<13|G>>>19)^G>>>10^(G<<15|G>>>17))|0;J=I+275423344+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=J+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+J|0;J=((t<<14|t>>>18)^t>>>3^(t<<25|t>>>7))+b+C+((H<<13|H>>>19)^H>>>10^(H<<15|H>>>17))|0;b=J+430227734+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=b+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+b|0;b=((u<<14|u>>>18)^u>>>3^(u<<25|u>>>7))+t+D+((I<<13|I>>>19)^I>>>10^(I<<15|I>>>17))|0;t=b+506948616+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=((v<<14|v>>>18)^v>>>3^(v<<25|v>>>7))+u+E+((J<<13|J>>>19)^J>>>10^(J<<15|J>>>17))|0;u=t+659060556+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=u+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+u|0;u=((w<<14|w>>>18)^w>>>3^(w<<25|w>>>7))+v+F+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))|0;v=u+883997877+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=v+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+v|0;v=((x<<14|x>>>18)^x>>>3^(x<<25|x>>>7))+w+G+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))|0;w=v+958139571+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=w+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+w|0;w=((z<<14|z>>>18)^z>>>3^(z<<25|z>>>7))+x+H+((u<<13|u>>>19)^u>>>10^(u<<15|u>>>17))|0;x=w+1322822218+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=x+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+x|0;x=((A<<14|A>>>18)^A>>>3^(A<<25|A>>>7))+z+I+((v<<13|v>>>19)^v>>>10^(v<<15|v>>>17))|0;z=x+1537002063+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=z+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+z|0;z=((B<<14|B>>>18)^B>>>3^(B<<25|B>>>7))+A+J+((w<<13|w>>>19)^w>>>10^(w<<15|w>>>17))|0;A=z+1747873779+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=A+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+A|0;A=((C<<14|C>>>18)^C>>>3^(C<<25|C>>>7))+B+b+((x<<13|x>>>19)^x>>>10^(x<<15|x>>>17))|0;b=A+1955562222+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=b+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+b|0;b=((D<<14|D>>>18)^D>>>3^(D<<25|D>>>7))+C+t+((z<<13|z>>>19)^z>>>10^(z<<15|z>>>17))|0;t=b+2024104815+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=((E<<14|E>>>18)^E>>>3^(E<<25|E>>>7))+D+u+((A<<13|A>>>19)^A>>>10^(A<<15|A>>>17))|0;u=t-2067236844+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=u+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+u|0;u=((F<<14|F>>>18)^F>>>3^(F<<25|F>>>7))+E+v+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))|0;b=u-1933114872+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=b+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+b|0;b=((G<<14|G>>>18)^G>>>3^(G<<25|G>>>7))+F+w+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))|0;t=b-1866530822+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=((H<<14|H>>>18)^H>>>3^(H<<25|H>>>7))+G+x+((u<<13|u>>>19)^u>>>10^(u<<15|u>>>17))|0;u=t-1538233109+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=u+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+u|0;u=H-1090935817+((I<<14|I>>>18)^I>>>3^(I<<25|I>>>7))+z+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=u+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+u|0;u=I-965641998+((J<<14|J>>>18)^J>>>3^(J<<25|J>>>7))+A+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;c[a>>2]=(g&(i|k)|i&k)+e+((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+u;c[f>>2]=g+(c[f>>2]|0);c[h>>2]=i+(c[h>>2]|0);c[j>>2]=k+(c[j>>2]|0);c[l>>2]=y+(c[l>>2]|0)+u;c[n>>2]=o+(c[n>>2]|0);c[p>>2]=q+(c[p>>2]|0);c[r>>2]=s+(c[r>>2]|0);return}function NFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a+8|0;f=c[e>>2]|0;g=f&63;h=YGb(f,c[e+4>>2]|0,d,0)|0;c[e>>2]=h;c[e+4>>2]=F;do{if((g+d|0)>>>0>63>>>0){e=64-g|0;UGb(a+16+g|0,b|0,e)|0;h=a+112|0;f=a+80|0;ne[c[h>>2]&1023](f,a+16|0);if((e+63|0)>>>0<d>>>0){i=e}else{j=0;k=e;break}while(1){ne[c[h>>2]&1023](f,b+i|0);e=i+64|0;if((i+127|0)>>>0<d>>>0){i=e}else{j=0;k=e;break}}}else{j=g;k=0}}while(0);UGb(a+16+j|0,b+k|0,d-k|0)|0;return}function OFb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;f=i;i=i+8|0;g=f|0;h=b+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;l=fe(j<<3|0>>>29|0)|0;c[g>>2]=fe(j>>>29|k<<3|0)|0;c[g+4>>2]=l;l=j&63;m=YGb(j,k,1,0)|0;c[h>>2]=m;c[h+4>>2]=F;if((l+1|0)>>>0>63>>>0){m=64-l|0;UGb(b+16+l|0,2156288,m)|0;ne[c[b+112>>2]&1023](b+80|0,b+16|0);n=0;o=m}else{n=l;o=0}UGb(b+16+n|0,2156288+o|0,1-o|0)|0;o=c[h>>2]|0;n=c[h+4>>2]|0;if((o&63|0)==56&(n&0|0)==0){p=n;q=o}else{l=b+112|0;m=b+80|0;k=b+16|0;j=n;n=o;while(1){o=n&63;r=YGb(n,j,1,0)|0;c[h>>2]=r;c[h+4>>2]=F;if((o+1|0)>>>0>63>>>0){r=64-o|0;UGb(b+16+o|0,9203592,r)|0;ne[c[l>>2]&1023](m,k);s=0;t=r}else{s=o;t=0}UGb(b+16+s|0,9203592+t|0,1-t|0)|0;o=c[h>>2]|0;r=c[h+4>>2]|0;if((o&63|0)==56&(r&0|0)==0){p=r;q=o;break}else{j=r;n=o}}}n=g;g=q&63;j=YGb(q,p,8,0)|0;c[h>>2]=j;c[h+4>>2]=F;do{if((g+8|0)>>>0>63>>>0){h=64-g|0;UGb(b+16+g|0,n|0,h)|0;j=b+112|0;p=b+80|0;ne[c[j>>2]&1023](p,b+16|0);if((h+63|0)>>>0<8>>>0){u=h}else{v=0;w=h;break}while(1){ne[c[j>>2]&1023](p,n+u|0);h=u+64|0;if((u+127|0)>>>0<8>>>0){u=h}else{v=0;w=h;break}}}else{v=g;w=0}}while(0);UGb(b+16+v|0,n+w|0,8-w|0)|0;w=b|0;if((a[w]|0)==0){i=f;return}else{y=0}do{n=e+(y<<2)|0;x=fe(c[b+80+(y<<2)>>2]|0)|0;a[n]=x;x=x>>8;a[n+1|0]=x;x=x>>8;a[n+2|0]=x;x=x>>8;a[n+3|0]=x;y=y+1|0;}while((y|0)<(d[w]|0));i=f;return}function PFb(){return cEb(208)|0}function QFb(b,d){b=b|0;d=d|0;var e=0,f=0;a[b|0]=d>>>6;if((d|0)==512){e=b+144|0;c[e>>2]=-205731576;c[e+4>>2]=1779033703;e=b+152|0;c[e>>2]=-2067093701;c[e+4>>2]=-1150833019;e=b+160|0;c[e>>2]=-23791573;c[e+4>>2]=1013904242;e=b+168|0;c[e>>2]=1595750129;c[e+4>>2]=-1521486534;e=b+176|0;c[e>>2]=-1377402159;c[e+4>>2]=1359893119;e=b+184|0;c[e>>2]=725511199;c[e+4>>2]=-1694144372;e=b+192|0;c[e>>2]=-79577749;c[e+4>>2]=528734635;e=b+200|0;c[e>>2]=327033209;c[e+4>>2]=1541459225}else if((d|0)==224){e=b+144|0;c[e>>2]=424955298;c[e+4>>2]=-1942145080;e=b+152|0;c[e>>2]=-1982016298;c[e+4>>2]=1944164710;e=b+160|0;c[e>>2]=855612546;c[e+4>>2]=502970286;e=b+168|0;c[e>>2]=1479516111;c[e+4>>2]=1738396948;e=b+176|0;c[e>>2]=2077511080;c[e+4>>2]=258812777;e=b+184|0;c[e>>2]=79989058;c[e+4>>2]=2011393907;e=b+192|0;c[e>>2]=1780299464;c[e+4>>2]=1067287976;e=b+200|0;c[e>>2]=-1848208735;c[e+4>>2]=286451373}else if((d|0)==256){e=b+144|0;c[e>>2]=-64227540;c[e+4>>2]=573645204;e=b+152|0;c[e>>2]=-934517566;c[e+4>>2]=-1621794909;e=b+160|0;c[e>>2]=1867755857;c[e+4>>2]=596883563;e=b+168|0;c[e>>2]=1497426621;c[e+4>>2]=-1774684391;e=b+176|0;c[e>>2]=-1467023389;c[e+4>>2]=-1775747358;e=b+184|0;c[e>>2]=1401305490;c[e+4>>2]=-1101128155;e=b+192|0;c[e>>2]=746961066;c[e+4>>2]=721525244;e=b+200|0;c[e>>2]=-2117784414;c[e+4>>2]=246885852}else if((d|0)==384){d=b+144|0;c[d>>2]=-1056596264;c[d+4>>2]=-876896931;d=b+152|0;c[d>>2]=914150663;c[d+4>>2]=1654270250;d=b+160|0;c[d>>2]=812702999;c[d+4>>2]=-1856437926;d=b+168|0;c[d>>2]=-150054599;c[d+4>>2]=355462360;d=b+176|0;c[d>>2]=-4191439;c[d+4>>2]=1731405415;d=b+184|0;c[d>>2]=1750603025;c[d+4>>2]=-1900787065;d=b+192|0;c[d>>2]=1694076839;c[d+4>>2]=-619958771;d=b+200|0;c[d>>2]=-1090891868;c[d+4>>2]=1203062813}else{f=-1;return f|0}d=b+8|0;c[d>>2]=0;c[d+4>>2]=0;f=0;return f|0}function RFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a+8|0;f=c[e>>2]|0;g=f&127;h=YGb(f,c[e+4>>2]|0,d,0)|0;c[e>>2]=h;c[e+4>>2]=F;do{if((g+d|0)>>>0>127>>>0){e=128-g|0;UGb(a+16+g|0,b|0,e)|0;h=a+144|0;SFb(h,a+16|0);if((e+127|0)>>>0<d>>>0){i=e}else{j=0;k=e;break}while(1){SFb(h,b+i|0);e=i+128|0;if((i+255|0)>>>0<d>>>0){i=e}else{j=0;k=e;break}}}else{j=g;k=0}}while(0);UGb(a+16+j|0,b+k|0,d-k|0)|0;return}function SFb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;e=c[a>>2]|0;f=c[a+4>>2]|0;g=a+8|0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=a+16|0;k=c[j>>2]|0;l=c[j+4>>2]|0;m=a+24|0;n=c[m>>2]|0;o=c[m+4>>2]|0;p=a+32|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=a+40|0;t=c[s>>2]|0;u=c[s+4>>2]|0;v=a+48|0;w=c[v>>2]|0;x=c[v+4>>2]|0;y=a+56|0;z=c[y>>2]|0;A=c[y+4>>2]|0;B=b;C=B|0;D=B+4|0;B=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=fe(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=fe(B|0)|0;B=D|0;D=YGb(z,A,-685199838,1116352408)|0;A=YGb(D,F,(q>>>14|r<<18|(0<<18|0>>>14))^(q>>>18|r<<14|(0<<14|0>>>18))^(r>>>9|0<<23|(q<<23|0>>>9)),(r>>>14|0<<18|(q<<18|0>>>14))^(r>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(r<<23|q>>>9)))|0;D=YGb(A,F,(w^t)&q^w,(x^u)&r^x)|0;A=YGb(D,F,C,B)|0;D=F;z=YGb(A,D,n,o)|0;o=F;n=YGb((k|h)&e|k&h,(l|i)&f|l&i,(e>>>28|f<<4|(0<<4|0>>>28))^(f>>>2|0<<30|(e<<30|0>>>2))^(f>>>7|0<<25|(e<<25|0>>>7)),(f>>>28|0<<4|(e<<4|0>>>28))^(0>>>2|0<<30|(f<<30|e>>>2))^(0>>>7|0<<25|(f<<25|e>>>7)))|0;E=YGb(n,F,A,D)|0;D=F;A=b+8|0;n=A|0;G=A+4|0;A=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;G=fe(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=fe(A|0)|0;A=n|0;H=G|0;G=YGb(w,x,602891725,1899447441)|0;x=YGb(G,F,A,H)|0;G=YGb(x,F,z&(t^q)^t,o&(u^r)^u)|0;x=YGb(G,F,(z>>>14|o<<18|(0<<18|0>>>14))^(z>>>18|o<<14|(0<<14|0>>>18))^(o>>>9|0<<23|(z<<23|0>>>9)),(o>>>14|0<<18|(z<<18|0>>>14))^(o>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(o<<23|z>>>9)))|0;G=F;w=YGb(x,G,k,l)|0;l=F;k=YGb((E>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(E<<30|0>>>2))^(D>>>7|0<<25|(E<<25|0>>>7)),(D>>>28|0<<4|(E<<4|0>>>28))^(0>>>2|0<<30|(D<<30|E>>>2))^(0>>>7|0<<25|(D<<25|E>>>7)),E&(h|e)|h&e,D&(i|f)|i&f)|0;I=YGb(k,F,x,G)|0;G=F;x=b+16|0;k=x|0;J=x+4|0;x=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;J=fe(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0;k=fe(x|0)|0;x=k|0;K=J|0;J=YGb(t,u,-330482897,-1245643825)|0;u=YGb(J,F,x,K)|0;J=YGb(u,F,w&(z^q)^q,l&(o^r)^r)|0;u=YGb(J,F,(w>>>14|l<<18|(0<<18|0>>>14))^(w>>>18|l<<14|(0<<14|0>>>18))^(l>>>9|0<<23|(w<<23|0>>>9)),(l>>>14|0<<18|(w<<18|0>>>14))^(l>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(l<<23|w>>>9)))|0;J=F;t=YGb(u,J,h,i)|0;i=F;h=YGb((I>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(I<<30|0>>>2))^(G>>>7|0<<25|(I<<25|0>>>7)),(G>>>28|0<<4|(I<<4|0>>>28))^(0>>>2|0<<30|(G<<30|I>>>2))^(0>>>7|0<<25|(G<<25|I>>>7)),I&(E|e)|E&e,G&(D|f)|D&f)|0;L=YGb(h,F,u,J)|0;J=F;u=b+24|0;h=u|0;M=u+4|0;u=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;M=fe(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;h=fe(u|0)|0;u=h|0;N=M|0;M=YGb(q,r,-2121671748,-373957723)|0;r=YGb(M,F,u,N)|0;M=YGb(r,F,t&(w^z)^z,i&(l^o)^o)|0;r=YGb(M,F,(t>>>14|i<<18|(0<<18|0>>>14))^(t>>>18|i<<14|(0<<14|0>>>18))^(i>>>9|0<<23|(t<<23|0>>>9)),(i>>>14|0<<18|(t<<18|0>>>14))^(i>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(i<<23|t>>>9)))|0;M=F;q=YGb(r,M,e,f)|0;O=F;P=YGb((L>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(L<<30|0>>>2))^(J>>>7|0<<25|(L<<25|0>>>7)),(J>>>28|0<<4|(L<<4|0>>>28))^(0>>>2|0<<30|(J<<30|L>>>2))^(0>>>7|0<<25|(J<<25|L>>>7)),L&(I|E)|I&E,J&(G|D)|G&D)|0;Q=YGb(P,F,r,M)|0;M=F;r=b+32|0;P=r|0;R=r+4|0;r=d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0;R=fe(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=fe(r|0)|0;r=P|0;S=R|0;R=YGb(z,o,-213338824,961987163)|0;o=YGb(R,F,r,S)|0;R=YGb(o,F,q&(t^w)^w,O&(i^l)^l)|0;o=YGb(R,F,(q>>>14|O<<18|(0<<18|0>>>14))^(q>>>18|O<<14|(0<<14|0>>>18))^(O>>>9|0<<23|(q<<23|0>>>9)),(O>>>14|0<<18|(q<<18|0>>>14))^(O>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(O<<23|q>>>9)))|0;R=F;z=YGb(o,R,E,D)|0;D=F;E=YGb((Q>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(Q<<30|0>>>2))^(M>>>7|0<<25|(Q<<25|0>>>7)),(M>>>28|0<<4|(Q<<4|0>>>28))^(0>>>2|0<<30|(M<<30|Q>>>2))^(0>>>7|0<<25|(M<<25|Q>>>7)),Q&(L|I)|L&I,M&(J|G)|J&G)|0;T=YGb(E,F,o,R)|0;R=F;o=b+40|0;E=o|0;U=o+4|0;o=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;U=fe(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0;E=fe(o|0)|0;o=E|0;V=U|0;U=YGb(w,l,-1241133031,1508970993)|0;l=YGb(U,F,o,V)|0;U=YGb(l,F,z&(q^t)^t,D&(O^i)^i)|0;l=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(l,U,I,G)|0;G=F;I=YGb((T>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(T<<30|0>>>2))^(R>>>7|0<<25|(T<<25|0>>>7)),(R>>>28|0<<4|(T<<4|0>>>28))^(0>>>2|0<<30|(R<<30|T>>>2))^(0>>>7|0<<25|(R<<25|T>>>7)),T&(Q|L)|Q&L,R&(M|J)|M&J)|0;W=YGb(I,F,l,U)|0;U=F;l=b+48|0;I=l|0;X=l+4|0;l=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;X=fe(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0;I=fe(l|0)|0;l=I|0;Y=X|0;X=YGb(t,i,-1357295717,-1841331548)|0;i=YGb(X,F,l,Y)|0;X=YGb(i,F,w&(z^q)^q,G&(D^O)^O)|0;i=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(i,X,L,J)|0;J=F;L=YGb((W>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(W<<30|0>>>2))^(U>>>7|0<<25|(W<<25|0>>>7)),(U>>>28|0<<4|(W<<4|0>>>28))^(0>>>2|0<<30|(U<<30|W>>>2))^(0>>>7|0<<25|(U<<25|W>>>7)),W&(T|Q)|T&Q,U&(R|M)|R&M)|0;Z=YGb(L,F,i,X)|0;X=F;i=b+56|0;L=i|0;_=i+4|0;i=d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0;_=fe(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0;L=fe(i|0)|0;i=L|0;$=_|0;_=YGb(q,O,-630357736,-1424204075)|0;O=YGb(_,F,i,$)|0;_=YGb(O,F,t&(w^z)^z,J&(G^D)^D)|0;O=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb(O,_,Q,M)|0;M=F;Q=YGb((Z>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(Z<<30|0>>>2))^(X>>>7|0<<25|(Z<<25|0>>>7)),(X>>>28|0<<4|(Z<<4|0>>>28))^(0>>>2|0<<30|(X<<30|Z>>>2))^(0>>>7|0<<25|(X<<25|Z>>>7)),Z&(W|T)|W&T,X&(U|R)|U&R)|0;aa=YGb(Q,F,O,_)|0;_=F;O=b+64|0;Q=O|0;ba=O+4|0;O=d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0;ba=fe(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Q=fe(O|0)|0;O=Q|0;ca=ba|0;ba=YGb(O,ca,-1560083902,-670586216)|0;da=YGb(ba,F,z,D)|0;D=YGb(da,F,q&(t^w)^w,M&(J^G)^G)|0;da=YGb(D,F,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=F;z=YGb(da,D,T,R)|0;R=F;T=YGb((aa>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(aa<<30|0>>>2))^(_>>>7|0<<25|(aa<<25|0>>>7)),(_>>>28|0<<4|(aa<<4|0>>>28))^(0>>>2|0<<30|(_<<30|aa>>>2))^(0>>>7|0<<25|(_<<25|aa>>>7)),aa&(Z|W)|Z&W,_&(X|U)|X&U)|0;ba=YGb(T,F,da,D)|0;D=F;da=b+72|0;T=da|0;ea=da+4|0;da=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0;ea=fe(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0;T=fe(da|0)|0;da=T|0;fa=ea|0;ea=YGb(da,fa,1164996542,310598401)|0;ga=YGb(ea,F,w,G)|0;G=YGb(ga,F,z&(q^t)^t,R&(M^J)^J)|0;ga=YGb(G,F,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;G=F;w=YGb(ga,G,W,U)|0;U=F;W=YGb((ba>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(ba<<30|0>>>2))^(D>>>7|0<<25|(ba<<25|0>>>7)),(D>>>28|0<<4|(ba<<4|0>>>28))^(0>>>2|0<<30|(D<<30|ba>>>2))^(0>>>7|0<<25|(D<<25|ba>>>7)),ba&(aa|Z)|aa&Z,D&(_|X)|_&X)|0;ea=YGb(W,F,ga,G)|0;G=F;ga=b+80|0;W=ga|0;ha=ga+4|0;ga=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;ha=fe(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0;W=fe(ga|0)|0;ga=W|0;ia=ha|0;ha=YGb(ga,ia,1323610764,607225278)|0;ja=YGb(ha,F,t,J)|0;J=YGb(ja,F,w&(z^q)^q,U&(R^M)^M)|0;ja=YGb(J,F,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=F;t=YGb(ja,J,Z,X)|0;X=F;Z=YGb((ea>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(ea<<30|0>>>2))^(G>>>7|0<<25|(ea<<25|0>>>7)),(G>>>28|0<<4|(ea<<4|0>>>28))^(0>>>2|0<<30|(G<<30|ea>>>2))^(0>>>7|0<<25|(G<<25|ea>>>7)),ea&(ba|aa)|ba&aa,G&(D|_)|D&_)|0;ha=YGb(Z,F,ja,J)|0;J=F;ja=b+88|0;Z=ja|0;ka=ja+4|0;ja=d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0;ka=fe(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0;Z=fe(ja|0)|0;ja=Z|0;la=ka|0;ka=YGb(ja,la,-704662302,1426881987)|0;ma=YGb(ka,F,q,M)|0;M=YGb(ma,F,t&(w^z)^z,X&(U^R)^R)|0;ma=YGb(M,F,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=F;q=YGb(ma,M,aa,_)|0;_=F;aa=YGb((ha>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(ha<<30|0>>>2))^(J>>>7|0<<25|(ha<<25|0>>>7)),(J>>>28|0<<4|(ha<<4|0>>>28))^(0>>>2|0<<30|(J<<30|ha>>>2))^(0>>>7|0<<25|(J<<25|ha>>>7)),ha&(ea|ba)|ea&ba,J&(G|D)|G&D)|0;ka=YGb(aa,F,ma,M)|0;M=F;ma=b+96|0;aa=ma|0;na=ma+4|0;ma=d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0;na=fe(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0;aa=fe(ma|0)|0;ma=aa|0;oa=na|0;na=YGb(ma,oa,-226784913,1925078388)|0;pa=YGb(na,F,z,R)|0;R=YGb(pa,F,q&(t^w)^w,_&(X^U)^U)|0;pa=YGb(R,F,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=F;z=YGb(pa,R,ba,D)|0;D=F;ba=YGb((ka>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(ka<<30|0>>>2))^(M>>>7|0<<25|(ka<<25|0>>>7)),(M>>>28|0<<4|(ka<<4|0>>>28))^(0>>>2|0<<30|(M<<30|ka>>>2))^(0>>>7|0<<25|(M<<25|ka>>>7)),ka&(ha|ea)|ha&ea,M&(J|G)|J&G)|0;na=YGb(ba,F,pa,R)|0;R=F;pa=b+104|0;ba=pa|0;qa=pa+4|0;pa=d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0;qa=fe(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0;ba=fe(pa|0)|0;pa=ba|0;ra=qa|0;qa=YGb(pa,ra,991336113,-2132889090)|0;sa=YGb(qa,F,w,U)|0;U=YGb(sa,F,z&(q^t)^t,D&(_^X)^X)|0;sa=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(sa,U,ea,G)|0;G=F;ea=YGb((na>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(na<<30|0>>>2))^(R>>>7|0<<25|(na<<25|0>>>7)),(R>>>28|0<<4|(na<<4|0>>>28))^(0>>>2|0<<30|(R<<30|na>>>2))^(0>>>7|0<<25|(R<<25|na>>>7)),na&(ka|ha)|ka&ha,R&(M|J)|M&J)|0;qa=YGb(ea,F,sa,U)|0;U=F;sa=b+112|0;ea=sa|0;ta=sa+4|0;sa=d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0;ta=fe(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0;ea=0;ua=fe(sa|0)|0;sa=ua|0;va=ta|0;wa=YGb(sa,va,633803317,-1680079193)|0;xa=YGb(wa,F,t,X)|0;X=YGb(xa,F,w&(z^q)^q,G&(D^_)^_)|0;xa=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(xa,X,ha,J)|0;J=F;ha=YGb((qa>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(qa<<30|0>>>2))^(U>>>7|0<<25|(qa<<25|0>>>7)),(U>>>28|0<<4|(qa<<4|0>>>28))^(0>>>2|0<<30|(U<<30|qa>>>2))^(0>>>7|0<<25|(U<<25|qa>>>7)),qa&(na|ka)|na&ka,U&(R|M)|R&M)|0;wa=YGb(ha,F,xa,X)|0;X=F;xa=b+120|0;b=xa|0;ha=xa+4|0;xa=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;ha=fe(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;b=0;ya=fe(xa|0)|0;xa=ya|0;za=ha|0;Aa=YGb(xa,za,-815192428,-1046744716)|0;Ba=YGb(Aa,F,q,_)|0;_=YGb(Ba,F,t&(w^z)^z,J&(G^D)^D)|0;Ba=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb(Ba,_,ka,M)|0;M=F;ka=YGb((wa>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(wa<<30|0>>>2))^(X>>>7|0<<25|(wa<<25|0>>>7)),(X>>>28|0<<4|(wa<<4|0>>>28))^(0>>>2|0<<30|(X<<30|wa>>>2))^(0>>>7|0<<25|(X<<25|wa>>>7)),wa&(qa|na)|qa&na,X&(U|R)|U&R)|0;Aa=YGb(ka,F,Ba,_)|0;_=F;Ba=YGb((A>>>8|H<<24|(0<<24|0>>>8))^(A>>>7|H<<25)^(A>>>1|H<<31|(0<<31|0>>>1)),(H>>>8|0<<24|(n<<24|0>>>8))^(H>>>7|0<<25)^(H>>>1|0<<31|(n<<31|0>>>1)),C,B)|0;B=YGb(Ba,F,da,fa)|0;Ba=YGb(B,F,(sa<<3|0>>>29|(ta>>>29|ea<<3))^(sa>>>6|va<<26)^(sa>>>19|va<<13|(0<<13|0>>>19)),(va<<3|sa>>>29|(ea>>>29|0<<3))^(va>>>6|0<<26)^(va>>>19|0<<13|(ua<<13|0>>>19)))|0;ea=F;ta=YGb(Ba,ea,-1628353838,-459576895)|0;B=YGb(ta,F,z,D)|0;D=YGb(B,F,q&(t^w)^w,M&(J^G)^G)|0;B=YGb(D,F,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=F;z=YGb(B,D,na,R)|0;R=F;na=YGb((Aa>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(Aa<<30|0>>>2))^(_>>>7|0<<25|(Aa<<25|0>>>7)),(_>>>28|0<<4|(Aa<<4|0>>>28))^(0>>>2|0<<30|(_<<30|Aa>>>2))^(0>>>7|0<<25|(_<<25|Aa>>>7)),Aa&(wa|qa)|wa&qa,_&(X|U)|X&U)|0;ta=YGb(na,F,B,D)|0;D=F;B=YGb((x>>>8|K<<24|(0<<24|0>>>8))^(x>>>7|K<<25)^(x>>>1|K<<31|(0<<31|0>>>1)),(K>>>8|0<<24|(k<<24|0>>>8))^(K>>>7|0<<25)^(K>>>1|0<<31|(k<<31|0>>>1)),A,H)|0;H=YGb(B,F,ga,ia)|0;B=YGb(H,F,(xa<<3|0>>>29|(ha>>>29|b<<3))^(xa>>>6|za<<26)^(xa>>>19|za<<13|(0<<13|0>>>19)),(za<<3|xa>>>29|(b>>>29|0<<3))^(za>>>6|0<<26)^(za>>>19|0<<13|(ya<<13|0>>>19)))|0;b=F;ha=YGb(B,b,944711139,-272742522)|0;H=YGb(ha,F,w,G)|0;G=YGb(H,F,z&(q^t)^t,R&(M^J)^J)|0;H=YGb(G,F,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;G=F;w=YGb(H,G,qa,U)|0;U=F;qa=YGb((ta>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(ta<<30|0>>>2))^(D>>>7|0<<25|(ta<<25|0>>>7)),(D>>>28|0<<4|(ta<<4|0>>>28))^(0>>>2|0<<30|(D<<30|ta>>>2))^(0>>>7|0<<25|(D<<25|ta>>>7)),ta&(Aa|wa)|Aa&wa,D&(_|X)|_&X)|0;ha=YGb(qa,F,H,G)|0;G=F;H=YGb((u>>>8|N<<24|(0<<24|0>>>8))^(u>>>7|N<<25)^(u>>>1|N<<31|(0<<31|0>>>1)),(N>>>8|0<<24|(h<<24|0>>>8))^(N>>>7|0<<25)^(N>>>1|0<<31|(h<<31|0>>>1)),x,K)|0;K=YGb(H,F,ja,la)|0;H=YGb(K,F,(ea>>>29|0<<3|(Ba<<3|0>>>29))^(Ba>>>6|ea<<26)^(Ba>>>19|ea<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ea<<3|Ba>>>29))^(ea>>>6|0<<26)^(ea>>>19|0<<13|(Ba<<13|0>>>19)))|0;K=F;x=YGb(H,K,-1953704523,264347078)|0;h=YGb(x,F,t,J)|0;J=YGb(h,F,w&(z^q)^q,U&(R^M)^M)|0;h=YGb(J,F,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=F;t=YGb(h,J,wa,X)|0;X=F;wa=YGb((ha>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(ha<<30|0>>>2))^(G>>>7|0<<25|(ha<<25|0>>>7)),(G>>>28|0<<4|(ha<<4|0>>>28))^(0>>>2|0<<30|(G<<30|ha>>>2))^(0>>>7|0<<25|(G<<25|ha>>>7)),ha&(ta|Aa)|ta&Aa,G&(D|_)|D&_)|0;x=YGb(wa,F,h,J)|0;J=F;h=YGb((r>>>8|S<<24|(0<<24|0>>>8))^(r>>>7|S<<25)^(r>>>1|S<<31|(0<<31|0>>>1)),(S>>>8|0<<24|(P<<24|0>>>8))^(S>>>7|0<<25)^(S>>>1|0<<31|(P<<31|0>>>1)),u,N)|0;N=YGb(h,F,ma,oa)|0;h=YGb(N,F,(b>>>29|0<<3|(B<<3|0>>>29))^(B>>>6|b<<26)^(B>>>19|b<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(b<<3|B>>>29))^(b>>>6|0<<26)^(b>>>19|0<<13|(B<<13|0>>>19)))|0;N=F;u=YGb(h,N,2007800933,604807628)|0;P=YGb(u,F,q,M)|0;M=YGb(P,F,t&(w^z)^z,X&(U^R)^R)|0;P=YGb(M,F,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=F;q=YGb(P,M,Aa,_)|0;_=F;Aa=YGb((x>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(x<<30|0>>>2))^(J>>>7|0<<25|(x<<25|0>>>7)),(J>>>28|0<<4|(x<<4|0>>>28))^(0>>>2|0<<30|(J<<30|x>>>2))^(0>>>7|0<<25|(J<<25|x>>>7)),x&(ha|ta)|ha&ta,J&(G|D)|G&D)|0;u=YGb(Aa,F,P,M)|0;M=F;P=YGb((o>>>8|V<<24|(0<<24|0>>>8))^(o>>>7|V<<25)^(o>>>1|V<<31|(0<<31|0>>>1)),(V>>>8|0<<24|(E<<24|0>>>8))^(V>>>7|0<<25)^(V>>>1|0<<31|(E<<31|0>>>1)),r,S)|0;S=YGb(P,F,pa,ra)|0;P=YGb(S,F,(K>>>29|0<<3|(H<<3|0>>>29))^(H>>>6|K<<26)^(H>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|H>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(H<<13|0>>>19)))|0;S=F;r=YGb(P,S,1495990901,770255983)|0;E=YGb(r,F,z,R)|0;R=YGb(E,F,q&(t^w)^w,_&(X^U)^U)|0;E=YGb(R,F,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=F;z=YGb(E,R,ta,D)|0;D=F;ta=YGb((u>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(u<<30|0>>>2))^(M>>>7|0<<25|(u<<25|0>>>7)),(M>>>28|0<<4|(u<<4|0>>>28))^(0>>>2|0<<30|(M<<30|u>>>2))^(0>>>7|0<<25|(M<<25|u>>>7)),u&(x|ha)|x&ha,M&(J|G)|J&G)|0;r=YGb(ta,F,E,R)|0;R=F;E=YGb((l>>>8|Y<<24|(0<<24|0>>>8))^(l>>>7|Y<<25)^(l>>>1|Y<<31|(0<<31|0>>>1)),(Y>>>8|0<<24|(I<<24|0>>>8))^(Y>>>7|0<<25)^(Y>>>1|0<<31|(I<<31|0>>>1)),o,V)|0;V=YGb(E,F,sa,va)|0;E=YGb(V,F,(N>>>29|0<<3|(h<<3|0>>>29))^(h>>>6|N<<26)^(h>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|h>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(h<<13|0>>>19)))|0;V=F;o=YGb(E,V,1856431235,1249150122)|0;I=YGb(o,F,w,U)|0;U=YGb(I,F,z&(q^t)^t,D&(_^X)^X)|0;I=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(I,U,ha,G)|0;G=F;ha=YGb((r>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(r<<30|0>>>2))^(R>>>7|0<<25|(r<<25|0>>>7)),(R>>>28|0<<4|(r<<4|0>>>28))^(0>>>2|0<<30|(R<<30|r>>>2))^(0>>>7|0<<25|(R<<25|r>>>7)),r&(u|x)|u&x,R&(M|J)|M&J)|0;o=YGb(ha,F,I,U)|0;U=F;I=YGb((i>>>8|$<<24|(0<<24|0>>>8))^(i>>>7|$<<25)^(i>>>1|$<<31|(0<<31|0>>>1)),($>>>8|0<<24|(L<<24|0>>>8))^($>>>7|0<<25)^($>>>1|0<<31|(L<<31|0>>>1)),l,Y)|0;Y=YGb(I,F,xa,za)|0;I=YGb(Y,F,(S>>>29|0<<3|(P<<3|0>>>29))^(P>>>6|S<<26)^(P>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|P>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(P<<13|0>>>19)))|0;Y=F;l=YGb(I,Y,-1119749164,1555081692)|0;L=YGb(l,F,t,X)|0;X=YGb(L,F,w&(z^q)^q,G&(D^_)^_)|0;L=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(L,X,x,J)|0;J=F;x=YGb((o>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(o<<30|0>>>2))^(U>>>7|0<<25|(o<<25|0>>>7)),(U>>>28|0<<4|(o<<4|0>>>28))^(0>>>2|0<<30|(U<<30|o>>>2))^(0>>>7|0<<25|(U<<25|o>>>7)),o&(r|u)|r&u,U&(R|M)|R&M)|0;l=YGb(x,F,L,X)|0;X=F;L=YGb((O>>>8|ca<<24|(0<<24|0>>>8))^(O>>>7|ca<<25)^(O>>>1|ca<<31|(0<<31|0>>>1)),(ca>>>8|0<<24|(Q<<24|0>>>8))^(ca>>>7|0<<25)^(ca>>>1|0<<31|(Q<<31|0>>>1)),i,$)|0;$=YGb(L,F,Ba,ea)|0;L=YGb($,F,(V>>>29|0<<3|(E<<3|0>>>29))^(E>>>6|V<<26)^(E>>>19|V<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(V<<3|E>>>29))^(V>>>6|0<<26)^(V>>>19|0<<13|(E<<13|0>>>19)))|0;$=F;i=YGb(L,$,-2096016459,1996064986)|0;Q=YGb(i,F,q,_)|0;_=YGb(Q,F,t&(w^z)^z,J&(G^D)^D)|0;Q=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb(Q,_,u,M)|0;M=F;u=YGb((l>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(l<<30|0>>>2))^(X>>>7|0<<25|(l<<25|0>>>7)),(X>>>28|0<<4|(l<<4|0>>>28))^(0>>>2|0<<30|(X<<30|l>>>2))^(0>>>7|0<<25|(X<<25|l>>>7)),l&(o|r)|o&r,X&(U|R)|U&R)|0;i=YGb(u,F,Q,_)|0;_=F;Q=YGb((da>>>8|fa<<24|(0<<24|0>>>8))^(da>>>7|fa<<25)^(da>>>1|fa<<31|(0<<31|0>>>1)),(fa>>>8|0<<24|(T<<24|0>>>8))^(fa>>>7|0<<25)^(fa>>>1|0<<31|(T<<31|0>>>1)),O,ca)|0;ca=YGb(Q,F,B,b)|0;Q=YGb(ca,F,(Y>>>29|0<<3|(I<<3|0>>>29))^(I>>>6|Y<<26)^(I>>>19|Y<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(Y<<3|I>>>29))^(Y>>>6|0<<26)^(Y>>>19|0<<13|(I<<13|0>>>19)))|0;ca=F;O=YGb(Q,ca,-295247957,-1740746414)|0;T=YGb(O,F,z,D)|0;D=YGb(T,F,q&(t^w)^w,M&(J^G)^G)|0;T=YGb(D,F,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=F;z=YGb(T,D,r,R)|0;R=F;r=YGb((i>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(i<<30|0>>>2))^(_>>>7|0<<25|(i<<25|0>>>7)),(_>>>28|0<<4|(i<<4|0>>>28))^(0>>>2|0<<30|(_<<30|i>>>2))^(0>>>7|0<<25|(_<<25|i>>>7)),i&(l|o)|l&o,_&(X|U)|X&U)|0;O=YGb(r,F,T,D)|0;D=F;T=YGb((ga>>>8|ia<<24|(0<<24|0>>>8))^(ga>>>7|ia<<25)^(ga>>>1|ia<<31|(0<<31|0>>>1)),(ia>>>8|0<<24|(W<<24|0>>>8))^(ia>>>7|0<<25)^(ia>>>1|0<<31|(W<<31|0>>>1)),da,fa)|0;fa=YGb(T,F,H,K)|0;T=YGb(fa,F,($>>>29|0<<3|(L<<3|0>>>29))^(L>>>6|$<<26)^(L>>>19|$<<13|(0<<13|0>>>19)),(0>>>29|0<<3|($<<3|L>>>29))^($>>>6|0<<26)^($>>>19|0<<13|(L<<13|0>>>19)))|0;fa=F;da=YGb(T,fa,766784016,-1473132947)|0;W=YGb(da,F,w,G)|0;G=YGb(W,F,z&(q^t)^t,R&(M^J)^J)|0;W=YGb(G,F,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;G=F;w=YGb(W,G,o,U)|0;U=F;o=YGb((O>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(O<<30|0>>>2))^(D>>>7|0<<25|(O<<25|0>>>7)),(D>>>28|0<<4|(O<<4|0>>>28))^(0>>>2|0<<30|(D<<30|O>>>2))^(0>>>7|0<<25|(D<<25|O>>>7)),O&(i|l)|i&l,D&(_|X)|_&X)|0;da=YGb(o,F,W,G)|0;G=F;W=YGb((ja>>>8|la<<24|(0<<24|0>>>8))^(ja>>>7|la<<25)^(ja>>>1|la<<31|(0<<31|0>>>1)),(la>>>8|0<<24|(Z<<24|0>>>8))^(la>>>7|0<<25)^(la>>>1|0<<31|(Z<<31|0>>>1)),ga,ia)|0;ia=YGb(W,F,h,N)|0;W=YGb(ia,F,(ca>>>29|0<<3|(Q<<3|0>>>29))^(Q>>>6|ca<<26)^(Q>>>19|ca<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ca<<3|Q>>>29))^(ca>>>6|0<<26)^(ca>>>19|0<<13|(Q<<13|0>>>19)))|0;ia=F;ga=YGb(W,ia,-1728372417,-1341970488)|0;Z=YGb(ga,F,t,J)|0;J=YGb(Z,F,w&(z^q)^q,U&(R^M)^M)|0;Z=YGb(J,F,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=F;t=YGb(Z,J,l,X)|0;X=F;l=YGb((da>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(da<<30|0>>>2))^(G>>>7|0<<25|(da<<25|0>>>7)),(G>>>28|0<<4|(da<<4|0>>>28))^(0>>>2|0<<30|(G<<30|da>>>2))^(0>>>7|0<<25|(G<<25|da>>>7)),da&(O|i)|O&i,G&(D|_)|D&_)|0;ga=YGb(l,F,Z,J)|0;J=F;Z=YGb((ma>>>8|oa<<24|(0<<24|0>>>8))^(ma>>>7|oa<<25)^(ma>>>1|oa<<31|(0<<31|0>>>1)),(oa>>>8|0<<24|(aa<<24|0>>>8))^(oa>>>7|0<<25)^(oa>>>1|0<<31|(aa<<31|0>>>1)),ja,la)|0;la=YGb(Z,F,P,S)|0;Z=YGb(la,F,(fa>>>29|0<<3|(T<<3|0>>>29))^(T>>>6|fa<<26)^(T>>>19|fa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(fa<<3|T>>>29))^(fa>>>6|0<<26)^(fa>>>19|0<<13|(T<<13|0>>>19)))|0;la=F;ja=YGb(Z,la,-1091629340,-1084653625)|0;aa=YGb(ja,F,q,M)|0;M=YGb(aa,F,t&(w^z)^z,X&(U^R)^R)|0;aa=YGb(M,F,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=F;q=YGb(aa,M,i,_)|0;_=F;i=YGb((ga>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(ga<<30|0>>>2))^(J>>>7|0<<25|(ga<<25|0>>>7)),(J>>>28|0<<4|(ga<<4|0>>>28))^(0>>>2|0<<30|(J<<30|ga>>>2))^(0>>>7|0<<25|(J<<25|ga>>>7)),ga&(da|O)|da&O,J&(G|D)|G&D)|0;ja=YGb(i,F,aa,M)|0;M=F;aa=YGb((pa>>>8|ra<<24|(0<<24|0>>>8))^(pa>>>7|ra<<25)^(pa>>>1|ra<<31|(0<<31|0>>>1)),(ra>>>8|0<<24|(ba<<24|0>>>8))^(ra>>>7|0<<25)^(ra>>>1|0<<31|(ba<<31|0>>>1)),ma,oa)|0;oa=YGb(aa,F,E,V)|0;aa=YGb(oa,F,(ia>>>29|0<<3|(W<<3|0>>>29))^(W>>>6|ia<<26)^(W>>>19|ia<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ia<<3|W>>>29))^(ia>>>6|0<<26)^(ia>>>19|0<<13|(W<<13|0>>>19)))|0;oa=F;ma=YGb(aa,oa,1034457026,-958395405)|0;ba=YGb(ma,F,z,R)|0;R=YGb(ba,F,q&(t^w)^w,_&(X^U)^U)|0;ba=YGb(R,F,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=F;z=YGb(ba,R,O,D)|0;D=F;O=YGb((ja>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(ja<<30|0>>>2))^(M>>>7|0<<25|(ja<<25|0>>>7)),(M>>>28|0<<4|(ja<<4|0>>>28))^(0>>>2|0<<30|(M<<30|ja>>>2))^(0>>>7|0<<25|(M<<25|ja>>>7)),ja&(ga|da)|ga&da,M&(J|G)|J&G)|0;ma=YGb(O,F,ba,R)|0;R=F;ba=YGb((sa>>>8|va<<24|(0<<24|0>>>8))^(sa>>>7|va<<25)^(sa>>>1|va<<31|(0<<31|0>>>1)),(va>>>8|0<<24|(ua<<24|0>>>8))^(va>>>7|0<<25)^(va>>>1|0<<31|(ua<<31|0>>>1)),pa,ra)|0;ra=YGb(ba,F,I,Y)|0;ba=YGb(ra,F,(la>>>29|0<<3|(Z<<3|0>>>29))^(Z>>>6|la<<26)^(Z>>>19|la<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(la<<3|Z>>>29))^(la>>>6|0<<26)^(la>>>19|0<<13|(Z<<13|0>>>19)))|0;ra=F;pa=YGb(ba,ra,-1828018395,-710438585)|0;ua=YGb(pa,F,w,U)|0;U=YGb(ua,F,z&(q^t)^t,D&(_^X)^X)|0;ua=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(ua,U,da,G)|0;G=F;da=YGb((ma>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(ma<<30|0>>>2))^(R>>>7|0<<25|(ma<<25|0>>>7)),(R>>>28|0<<4|(ma<<4|0>>>28))^(0>>>2|0<<30|(R<<30|ma>>>2))^(0>>>7|0<<25|(R<<25|ma>>>7)),ma&(ja|ga)|ja&ga,R&(M|J)|M&J)|0;pa=YGb(da,F,ua,U)|0;U=F;ua=YGb((xa>>>8|za<<24|(0<<24|0>>>8))^(xa>>>7|za<<25)^(xa>>>1|za<<31|(0<<31|0>>>1)),(za>>>8|0<<24|(ya<<24|0>>>8))^(za>>>7|0<<25)^(za>>>1|0<<31|(ya<<31|0>>>1)),sa,va)|0;va=YGb(ua,F,L,$)|0;ua=YGb(va,F,(oa>>>29|0<<3|(aa<<3|0>>>29))^(aa>>>6|oa<<26)^(aa>>>19|oa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(oa<<3|aa>>>29))^(oa>>>6|0<<26)^(oa>>>19|0<<13|(aa<<13|0>>>19)))|0;va=F;sa=YGb(ua,va,-536640913,113926993)|0;ya=YGb(sa,F,t,X)|0;X=YGb(ya,F,w&(z^q)^q,G&(D^_)^_)|0;ya=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(ya,X,ga,J)|0;J=F;ga=YGb((pa>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(pa<<30|0>>>2))^(U>>>7|0<<25|(pa<<25|0>>>7)),(U>>>28|0<<4|(pa<<4|0>>>28))^(0>>>2|0<<30|(U<<30|pa>>>2))^(0>>>7|0<<25|(U<<25|pa>>>7)),pa&(ma|ja)|ma&ja,U&(R|M)|R&M)|0;sa=YGb(ga,F,ya,X)|0;X=F;ya=YGb((Ba>>>8|ea<<24|(0<<24|0>>>8))^(Ba>>>7|ea<<25)^(Ba>>>1|ea<<31|(0<<31|0>>>1)),(ea>>>8|0<<24|(Ba<<24|0>>>8))^(ea>>>7|0<<25)^(ea>>>1|0<<31|(Ba<<31|0>>>1)),xa,za)|0;za=YGb(ya,F,Q,ca)|0;ya=YGb(za,F,(ra>>>29|0<<3|(ba<<3|0>>>29))^(ba>>>6|ra<<26)^(ba>>>19|ra<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ra<<3|ba>>>29))^(ra>>>6|0<<26)^(ra>>>19|0<<13|(ba<<13|0>>>19)))|0;za=F;xa=YGb(ya,za,168717936,338241895)|0;ga=YGb(xa,F,q,_)|0;_=YGb(ga,F,t&(w^z)^z,J&(G^D)^D)|0;ga=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb(ga,_,ja,M)|0;M=F;ja=YGb((sa>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(sa<<30|0>>>2))^(X>>>7|0<<25|(sa<<25|0>>>7)),(X>>>28|0<<4|(sa<<4|0>>>28))^(0>>>2|0<<30|(X<<30|sa>>>2))^(0>>>7|0<<25|(X<<25|sa>>>7)),sa&(pa|ma)|pa&ma,X&(U|R)|U&R)|0;xa=YGb(ja,F,ga,_)|0;_=F;ga=YGb((B>>>8|b<<24|(0<<24|0>>>8))^(B>>>7|b<<25)^(B>>>1|b<<31|(0<<31|0>>>1)),(b>>>8|0<<24|(B<<24|0>>>8))^(b>>>7|0<<25)^(b>>>1|0<<31|(B<<31|0>>>1)),Ba,ea)|0;ea=YGb(ga,F,T,fa)|0;ga=YGb(ea,F,(va>>>29|0<<3|(ua<<3|0>>>29))^(ua>>>6|va<<26)^(ua>>>19|va<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(va<<3|ua>>>29))^(va>>>6|0<<26)^(va>>>19|0<<13|(ua<<13|0>>>19)))|0;ea=F;Ba=YGb(ga,ea,1188179964,666307205)|0;ja=YGb(Ba,F,z,D)|0;D=YGb(ja,F,q&(t^w)^w,M&(J^G)^G)|0;ja=YGb(D,F,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=F;z=YGb(ja,D,ma,R)|0;R=F;ma=YGb((xa>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(xa<<30|0>>>2))^(_>>>7|0<<25|(xa<<25|0>>>7)),(_>>>28|0<<4|(xa<<4|0>>>28))^(0>>>2|0<<30|(_<<30|xa>>>2))^(0>>>7|0<<25|(_<<25|xa>>>7)),xa&(sa|pa)|sa&pa,_&(X|U)|X&U)|0;Ba=YGb(ma,F,ja,D)|0;D=F;ja=YGb((H>>>8|K<<24|(0<<24|0>>>8))^(H>>>7|K<<25)^(H>>>1|K<<31|(0<<31|0>>>1)),(K>>>8|0<<24|(H<<24|0>>>8))^(K>>>7|0<<25)^(K>>>1|0<<31|(H<<31|0>>>1)),B,b)|0;b=YGb(ja,F,W,ia)|0;ja=YGb(b,F,(za>>>29|0<<3|(ya<<3|0>>>29))^(ya>>>6|za<<26)^(ya>>>19|za<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(za<<3|ya>>>29))^(za>>>6|0<<26)^(za>>>19|0<<13|(ya<<13|0>>>19)))|0;b=F;B=YGb(ja,b,1546045734,773529912)|0;ma=YGb(B,F,w,G)|0;G=YGb(ma,F,z&(q^t)^t,R&(M^J)^J)|0;ma=YGb(G,F,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;G=F;w=YGb(ma,G,pa,U)|0;U=F;pa=YGb((Ba>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(Ba<<30|0>>>2))^(D>>>7|0<<25|(Ba<<25|0>>>7)),(D>>>28|0<<4|(Ba<<4|0>>>28))^(0>>>2|0<<30|(D<<30|Ba>>>2))^(0>>>7|0<<25|(D<<25|Ba>>>7)),Ba&(xa|sa)|xa&sa,D&(_|X)|_&X)|0;B=YGb(pa,F,ma,G)|0;G=F;ma=YGb((h>>>8|N<<24|(0<<24|0>>>8))^(h>>>7|N<<25)^(h>>>1|N<<31|(0<<31|0>>>1)),(N>>>8|0<<24|(h<<24|0>>>8))^(N>>>7|0<<25)^(N>>>1|0<<31|(h<<31|0>>>1)),H,K)|0;K=YGb(ma,F,Z,la)|0;ma=YGb(K,F,(ea>>>29|0<<3|(ga<<3|0>>>29))^(ga>>>6|ea<<26)^(ga>>>19|ea<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ea<<3|ga>>>29))^(ea>>>6|0<<26)^(ea>>>19|0<<13|(ga<<13|0>>>19)))|0;K=F;H=YGb(ma,K,1522805485,1294757372)|0;pa=YGb(H,F,t,J)|0;J=YGb(pa,F,w&(z^q)^q,U&(R^M)^M)|0;pa=YGb(J,F,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=F;t=YGb(pa,J,sa,X)|0;X=F;sa=YGb((B>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(B<<30|0>>>2))^(G>>>7|0<<25|(B<<25|0>>>7)),(G>>>28|0<<4|(B<<4|0>>>28))^(0>>>2|0<<30|(G<<30|B>>>2))^(0>>>7|0<<25|(G<<25|B>>>7)),B&(Ba|xa)|Ba&xa,G&(D|_)|D&_)|0;H=YGb(sa,F,pa,J)|0;J=F;pa=YGb((P>>>8|S<<24|(0<<24|0>>>8))^(P>>>7|S<<25)^(P>>>1|S<<31|(0<<31|0>>>1)),(S>>>8|0<<24|(P<<24|0>>>8))^(S>>>7|0<<25)^(S>>>1|0<<31|(P<<31|0>>>1)),h,N)|0;N=YGb(pa,F,aa,oa)|0;pa=YGb(N,F,(b>>>29|0<<3|(ja<<3|0>>>29))^(ja>>>6|b<<26)^(ja>>>19|b<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(b<<3|ja>>>29))^(b>>>6|0<<26)^(b>>>19|0<<13|(ja<<13|0>>>19)))|0;N=F;h=YGb(pa,N,-1651133473,1396182291)|0;sa=YGb(h,F,q,M)|0;M=YGb(sa,F,t&(w^z)^z,X&(U^R)^R)|0;sa=YGb(M,F,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=F;q=YGb(sa,M,xa,_)|0;_=F;xa=YGb((H>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(H<<30|0>>>2))^(J>>>7|0<<25|(H<<25|0>>>7)),(J>>>28|0<<4|(H<<4|0>>>28))^(0>>>2|0<<30|(J<<30|H>>>2))^(0>>>7|0<<25|(J<<25|H>>>7)),H&(B|Ba)|B&Ba,J&(G|D)|G&D)|0;h=YGb(xa,F,sa,M)|0;M=F;sa=YGb((E>>>8|V<<24|(0<<24|0>>>8))^(E>>>7|V<<25)^(E>>>1|V<<31|(0<<31|0>>>1)),(V>>>8|0<<24|(E<<24|0>>>8))^(V>>>7|0<<25)^(V>>>1|0<<31|(E<<31|0>>>1)),P,S)|0;S=YGb(sa,F,ba,ra)|0;sa=YGb(S,F,(K>>>29|0<<3|(ma<<3|0>>>29))^(ma>>>6|K<<26)^(ma>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|ma>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(ma<<13|0>>>19)))|0;S=F;P=YGb(sa,S,-1951439906,1695183700)|0;xa=YGb(P,F,z,R)|0;R=YGb(xa,F,q&(t^w)^w,_&(X^U)^U)|0;xa=YGb(R,F,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=F;z=YGb(xa,R,Ba,D)|0;D=F;Ba=YGb((h>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(h<<30|0>>>2))^(M>>>7|0<<25|(h<<25|0>>>7)),(M>>>28|0<<4|(h<<4|0>>>28))^(0>>>2|0<<30|(M<<30|h>>>2))^(0>>>7|0<<25|(M<<25|h>>>7)),h&(H|B)|H&B,M&(J|G)|J&G)|0;P=YGb(Ba,F,xa,R)|0;R=F;xa=YGb((I>>>8|Y<<24|(0<<24|0>>>8))^(I>>>7|Y<<25)^(I>>>1|Y<<31|(0<<31|0>>>1)),(Y>>>8|0<<24|(I<<24|0>>>8))^(Y>>>7|0<<25)^(Y>>>1|0<<31|(I<<31|0>>>1)),E,V)|0;V=YGb(xa,F,ua,va)|0;xa=YGb(V,F,(N>>>29|0<<3|(pa<<3|0>>>29))^(pa>>>6|N<<26)^(pa>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|pa>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(pa<<13|0>>>19)))|0;V=F;E=YGb(xa,V,1014477480,1986661051)|0;Ba=YGb(E,F,w,U)|0;U=YGb(Ba,F,z&(q^t)^t,D&(_^X)^X)|0;Ba=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(Ba,U,B,G)|0;G=F;B=YGb((P>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(P<<30|0>>>2))^(R>>>7|0<<25|(P<<25|0>>>7)),(R>>>28|0<<4|(P<<4|0>>>28))^(0>>>2|0<<30|(R<<30|P>>>2))^(0>>>7|0<<25|(R<<25|P>>>7)),P&(h|H)|h&H,R&(M|J)|M&J)|0;E=YGb(B,F,Ba,U)|0;U=F;Ba=YGb((L>>>8|$<<24|(0<<24|0>>>8))^(L>>>7|$<<25)^(L>>>1|$<<31|(0<<31|0>>>1)),($>>>8|0<<24|(L<<24|0>>>8))^($>>>7|0<<25)^($>>>1|0<<31|(L<<31|0>>>1)),I,Y)|0;Y=YGb(Ba,F,ya,za)|0;Ba=YGb(Y,F,(S>>>29|0<<3|(sa<<3|0>>>29))^(sa>>>6|S<<26)^(sa>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|sa>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(sa<<13|0>>>19)))|0;Y=F;I=YGb(Ba,Y,1206759142,-2117940946)|0;B=YGb(I,F,t,X)|0;X=YGb(B,F,w&(z^q)^q,G&(D^_)^_)|0;B=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(B,X,H,J)|0;J=F;H=YGb((E>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(E<<30|0>>>2))^(U>>>7|0<<25|(E<<25|0>>>7)),(U>>>28|0<<4|(E<<4|0>>>28))^(0>>>2|0<<30|(U<<30|E>>>2))^(0>>>7|0<<25|(U<<25|E>>>7)),E&(P|h)|P&h,U&(R|M)|R&M)|0;I=YGb(H,F,B,X)|0;X=F;B=YGb((Q>>>8|ca<<24|(0<<24|0>>>8))^(Q>>>7|ca<<25)^(Q>>>1|ca<<31|(0<<31|0>>>1)),(ca>>>8|0<<24|(Q<<24|0>>>8))^(ca>>>7|0<<25)^(ca>>>1|0<<31|(Q<<31|0>>>1)),L,$)|0;$=YGb(B,F,ga,ea)|0;B=YGb($,F,(V>>>29|0<<3|(xa<<3|0>>>29))^(xa>>>6|V<<26)^(xa>>>19|V<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(V<<3|xa>>>29))^(V>>>6|0<<26)^(V>>>19|0<<13|(xa<<13|0>>>19)))|0;$=F;L=YGb(B,$,344077627,-1838011259)|0;H=YGb(L,F,q,_)|0;_=YGb(H,F,t&(w^z)^z,J&(G^D)^D)|0;H=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb(H,_,h,M)|0;M=F;h=YGb((I>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(I<<30|0>>>2))^(X>>>7|0<<25|(I<<25|0>>>7)),(X>>>28|0<<4|(I<<4|0>>>28))^(0>>>2|0<<30|(X<<30|I>>>2))^(0>>>7|0<<25|(X<<25|I>>>7)),I&(E|P)|E&P,X&(U|R)|U&R)|0;L=YGb(h,F,H,_)|0;_=F;H=YGb((T>>>8|fa<<24|(0<<24|0>>>8))^(T>>>7|fa<<25)^(T>>>1|fa<<31|(0<<31|0>>>1)),(fa>>>8|0<<24|(T<<24|0>>>8))^(fa>>>7|0<<25)^(fa>>>1|0<<31|(T<<31|0>>>1)),Q,ca)|0;ca=YGb(H,F,ja,b)|0;H=YGb(ca,F,(Y>>>29|0<<3|(Ba<<3|0>>>29))^(Ba>>>6|Y<<26)^(Ba>>>19|Y<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(Y<<3|Ba>>>29))^(Y>>>6|0<<26)^(Y>>>19|0<<13|(Ba<<13|0>>>19)))|0;ca=F;Q=YGb(H,ca,1290863460,-1564481375)|0;h=YGb(Q,F,z,D)|0;D=YGb(h,F,q&(t^w)^w,M&(J^G)^G)|0;h=YGb(D,F,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=F;z=YGb(h,D,P,R)|0;R=F;P=YGb((L>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(L<<30|0>>>2))^(_>>>7|0<<25|(L<<25|0>>>7)),(_>>>28|0<<4|(L<<4|0>>>28))^(0>>>2|0<<30|(_<<30|L>>>2))^(0>>>7|0<<25|(_<<25|L>>>7)),L&(I|E)|I&E,_&(X|U)|X&U)|0;Q=YGb(P,F,h,D)|0;D=F;h=YGb((W>>>8|ia<<24|(0<<24|0>>>8))^(W>>>7|ia<<25)^(W>>>1|ia<<31|(0<<31|0>>>1)),(ia>>>8|0<<24|(W<<24|0>>>8))^(ia>>>7|0<<25)^(ia>>>1|0<<31|(W<<31|0>>>1)),T,fa)|0;fa=YGb(h,F,ma,K)|0;h=YGb(fa,F,($>>>29|0<<3|(B<<3|0>>>29))^(B>>>6|$<<26)^(B>>>19|$<<13|(0<<13|0>>>19)),(0>>>29|0<<3|($<<3|B>>>29))^($>>>6|0<<26)^($>>>19|0<<13|(B<<13|0>>>19)))|0;fa=F;T=YGb(h,fa,-1136513023,-1474664885)|0;P=YGb(T,F,w,G)|0;G=YGb(P,F,z&(q^t)^t,R&(M^J)^J)|0;P=YGb(G,F,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;G=F;w=YGb(P,G,E,U)|0;U=F;E=YGb((Q>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(Q<<30|0>>>2))^(D>>>7|0<<25|(Q<<25|0>>>7)),(D>>>28|0<<4|(Q<<4|0>>>28))^(0>>>2|0<<30|(D<<30|Q>>>2))^(0>>>7|0<<25|(D<<25|Q>>>7)),Q&(L|I)|L&I,D&(_|X)|_&X)|0;T=YGb(E,F,P,G)|0;G=F;P=YGb((Z>>>8|la<<24|(0<<24|0>>>8))^(Z>>>7|la<<25)^(Z>>>1|la<<31|(0<<31|0>>>1)),(la>>>8|0<<24|(Z<<24|0>>>8))^(la>>>7|0<<25)^(la>>>1|0<<31|(Z<<31|0>>>1)),W,ia)|0;ia=YGb(P,F,pa,N)|0;P=YGb(ia,F,(ca>>>29|0<<3|(H<<3|0>>>29))^(H>>>6|ca<<26)^(H>>>19|ca<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ca<<3|H>>>29))^(ca>>>6|0<<26)^(ca>>>19|0<<13|(H<<13|0>>>19)))|0;ia=F;W=YGb(P,ia,-789014639,-1035236496)|0;E=YGb(W,F,t,J)|0;J=YGb(E,F,w&(z^q)^q,U&(R^M)^M)|0;E=YGb(J,F,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=F;t=YGb(E,J,I,X)|0;X=F;I=YGb((T>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(T<<30|0>>>2))^(G>>>7|0<<25|(T<<25|0>>>7)),(G>>>28|0<<4|(T<<4|0>>>28))^(0>>>2|0<<30|(G<<30|T>>>2))^(0>>>7|0<<25|(G<<25|T>>>7)),T&(Q|L)|Q&L,G&(D|_)|D&_)|0;W=YGb(I,F,E,J)|0;J=F;E=YGb((aa>>>8|oa<<24|(0<<24|0>>>8))^(aa>>>7|oa<<25)^(aa>>>1|oa<<31|(0<<31|0>>>1)),(oa>>>8|0<<24|(aa<<24|0>>>8))^(oa>>>7|0<<25)^(oa>>>1|0<<31|(aa<<31|0>>>1)),Z,la)|0;la=YGb(E,F,sa,S)|0;E=YGb(la,F,(fa>>>29|0<<3|(h<<3|0>>>29))^(h>>>6|fa<<26)^(h>>>19|fa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(fa<<3|h>>>29))^(fa>>>6|0<<26)^(fa>>>19|0<<13|(h<<13|0>>>19)))|0;la=F;Z=YGb(E,la,106217008,-949202525)|0;I=YGb(Z,F,q,M)|0;M=YGb(I,F,t&(w^z)^z,X&(U^R)^R)|0;I=YGb(M,F,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=F;q=YGb(I,M,L,_)|0;_=F;L=YGb((W>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(W<<30|0>>>2))^(J>>>7|0<<25|(W<<25|0>>>7)),(J>>>28|0<<4|(W<<4|0>>>28))^(0>>>2|0<<30|(J<<30|W>>>2))^(0>>>7|0<<25|(J<<25|W>>>7)),W&(T|Q)|T&Q,J&(G|D)|G&D)|0;Z=YGb(L,F,I,M)|0;M=F;I=YGb((ba>>>8|ra<<24|(0<<24|0>>>8))^(ba>>>7|ra<<25)^(ba>>>1|ra<<31|(0<<31|0>>>1)),(ra>>>8|0<<24|(ba<<24|0>>>8))^(ra>>>7|0<<25)^(ra>>>1|0<<31|(ba<<31|0>>>1)),aa,oa)|0;oa=YGb(I,F,xa,V)|0;I=YGb(oa,F,(ia>>>29|0<<3|(P<<3|0>>>29))^(P>>>6|ia<<26)^(P>>>19|ia<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ia<<3|P>>>29))^(ia>>>6|0<<26)^(ia>>>19|0<<13|(P<<13|0>>>19)))|0;oa=F;aa=YGb(I,oa,-688958952,-778901479)|0;L=YGb(aa,F,z,R)|0;R=YGb(L,F,q&(t^w)^w,_&(X^U)^U)|0;L=YGb(R,F,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=F;z=YGb(L,R,Q,D)|0;D=F;Q=YGb((Z>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(Z<<30|0>>>2))^(M>>>7|0<<25|(Z<<25|0>>>7)),(M>>>28|0<<4|(Z<<4|0>>>28))^(0>>>2|0<<30|(M<<30|Z>>>2))^(0>>>7|0<<25|(M<<25|Z>>>7)),Z&(W|T)|W&T,M&(J|G)|J&G)|0;aa=YGb(Q,F,L,R)|0;R=F;L=YGb((ua>>>8|va<<24|(0<<24|0>>>8))^(ua>>>7|va<<25)^(ua>>>1|va<<31|(0<<31|0>>>1)),(va>>>8|0<<24|(ua<<24|0>>>8))^(va>>>7|0<<25)^(va>>>1|0<<31|(ua<<31|0>>>1)),ba,ra)|0;ra=YGb(L,F,Ba,Y)|0;L=YGb(ra,F,(la>>>29|0<<3|(E<<3|0>>>29))^(E>>>6|la<<26)^(E>>>19|la<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(la<<3|E>>>29))^(la>>>6|0<<26)^(la>>>19|0<<13|(E<<13|0>>>19)))|0;ra=F;ba=YGb(L,ra,1432725776,-694614492)|0;Q=YGb(ba,F,w,U)|0;U=YGb(Q,F,z&(q^t)^t,D&(_^X)^X)|0;Q=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(Q,U,T,G)|0;G=F;T=YGb((aa>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(aa<<30|0>>>2))^(R>>>7|0<<25|(aa<<25|0>>>7)),(R>>>28|0<<4|(aa<<4|0>>>28))^(0>>>2|0<<30|(R<<30|aa>>>2))^(0>>>7|0<<25|(R<<25|aa>>>7)),aa&(Z|W)|Z&W,R&(M|J)|M&J)|0;ba=YGb(T,F,Q,U)|0;U=F;Q=YGb((ya>>>8|za<<24|(0<<24|0>>>8))^(ya>>>7|za<<25)^(ya>>>1|za<<31|(0<<31|0>>>1)),(za>>>8|0<<24|(ya<<24|0>>>8))^(za>>>7|0<<25)^(za>>>1|0<<31|(ya<<31|0>>>1)),ua,va)|0;va=YGb(Q,F,B,$)|0;Q=YGb(va,F,(oa>>>29|0<<3|(I<<3|0>>>29))^(I>>>6|oa<<26)^(I>>>19|oa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(oa<<3|I>>>29))^(oa>>>6|0<<26)^(oa>>>19|0<<13|(I<<13|0>>>19)))|0;va=F;ua=YGb(Q,va,1467031594,-200395387)|0;T=YGb(ua,F,t,X)|0;X=YGb(T,F,w&(z^q)^q,G&(D^_)^_)|0;T=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(T,X,W,J)|0;J=F;W=YGb((ba>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(ba<<30|0>>>2))^(U>>>7|0<<25|(ba<<25|0>>>7)),(U>>>28|0<<4|(ba<<4|0>>>28))^(0>>>2|0<<30|(U<<30|ba>>>2))^(0>>>7|0<<25|(U<<25|ba>>>7)),ba&(aa|Z)|aa&Z,U&(R|M)|R&M)|0;ua=YGb(W,F,T,X)|0;X=F;T=YGb((ga>>>8|ea<<24|(0<<24|0>>>8))^(ga>>>7|ea<<25)^(ga>>>1|ea<<31|(0<<31|0>>>1)),(ea>>>8|0<<24|(ga<<24|0>>>8))^(ea>>>7|0<<25)^(ea>>>1|0<<31|(ga<<31|0>>>1)),ya,za)|0;za=YGb(T,F,H,ca)|0;T=YGb(za,F,(ra>>>29|0<<3|(L<<3|0>>>29))^(L>>>6|ra<<26)^(L>>>19|ra<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ra<<3|L>>>29))^(ra>>>6|0<<26)^(ra>>>19|0<<13|(L<<13|0>>>19)))|0;za=F;ya=YGb(T,za,851169720,275423344)|0;W=YGb(ya,F,q,_)|0;_=YGb(W,F,t&(w^z)^z,J&(G^D)^D)|0;W=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb(W,_,Z,M)|0;M=F;Z=YGb((ua>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(ua<<30|0>>>2))^(X>>>7|0<<25|(ua<<25|0>>>7)),(X>>>28|0<<4|(ua<<4|0>>>28))^(0>>>2|0<<30|(X<<30|ua>>>2))^(0>>>7|0<<25|(X<<25|ua>>>7)),ua&(ba|aa)|ba&aa,X&(U|R)|U&R)|0;ya=YGb(Z,F,W,_)|0;_=F;W=YGb((ja>>>8|b<<24|(0<<24|0>>>8))^(ja>>>7|b<<25)^(ja>>>1|b<<31|(0<<31|0>>>1)),(b>>>8|0<<24|(ja<<24|0>>>8))^(b>>>7|0<<25)^(b>>>1|0<<31|(ja<<31|0>>>1)),ga,ea)|0;ea=YGb(W,F,h,fa)|0;W=YGb(ea,F,(va>>>29|0<<3|(Q<<3|0>>>29))^(Q>>>6|va<<26)^(Q>>>19|va<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(va<<3|Q>>>29))^(va>>>6|0<<26)^(va>>>19|0<<13|(Q<<13|0>>>19)))|0;ea=F;ga=YGb(W,ea,-1194143544,430227734)|0;Z=YGb(ga,F,z,D)|0;D=YGb(Z,F,q&(t^w)^w,M&(J^G)^G)|0;Z=YGb(D,F,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=F;z=YGb(Z,D,aa,R)|0;R=F;aa=YGb((ya>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(ya<<30|0>>>2))^(_>>>7|0<<25|(ya<<25|0>>>7)),(_>>>28|0<<4|(ya<<4|0>>>28))^(0>>>2|0<<30|(_<<30|ya>>>2))^(0>>>7|0<<25|(_<<25|ya>>>7)),ya&(ua|ba)|ua&ba,_&(X|U)|X&U)|0;ga=YGb(aa,F,Z,D)|0;D=F;Z=YGb((ma>>>8|K<<24|(0<<24|0>>>8))^(ma>>>7|K<<25)^(ma>>>1|K<<31|(0<<31|0>>>1)),(K>>>8|0<<24|(ma<<24|0>>>8))^(K>>>7|0<<25)^(K>>>1|0<<31|(ma<<31|0>>>1)),ja,b)|0;b=YGb(Z,F,P,ia)|0;Z=YGb(b,F,(za>>>29|0<<3|(T<<3|0>>>29))^(T>>>6|za<<26)^(T>>>19|za<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(za<<3|T>>>29))^(za>>>6|0<<26)^(za>>>19|0<<13|(T<<13|0>>>19)))|0;b=F;ja=YGb(Z,b,1363258195,506948616)|0;aa=YGb(ja,F,w,G)|0;G=YGb(aa,F,z&(q^t)^t,R&(M^J)^J)|0;aa=YGb(G,F,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;G=F;w=YGb(aa,G,ba,U)|0;U=F;ba=YGb((ga>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(ga<<30|0>>>2))^(D>>>7|0<<25|(ga<<25|0>>>7)),(D>>>28|0<<4|(ga<<4|0>>>28))^(0>>>2|0<<30|(D<<30|ga>>>2))^(0>>>7|0<<25|(D<<25|ga>>>7)),ga&(ya|ua)|ya&ua,D&(_|X)|_&X)|0;ja=YGb(ba,F,aa,G)|0;G=F;aa=YGb((pa>>>8|N<<24|(0<<24|0>>>8))^(pa>>>7|N<<25)^(pa>>>1|N<<31|(0<<31|0>>>1)),(N>>>8|0<<24|(pa<<24|0>>>8))^(N>>>7|0<<25)^(N>>>1|0<<31|(pa<<31|0>>>1)),ma,K)|0;K=YGb(aa,F,E,la)|0;aa=YGb(K,F,(ea>>>29|0<<3|(W<<3|0>>>29))^(W>>>6|ea<<26)^(W>>>19|ea<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ea<<3|W>>>29))^(ea>>>6|0<<26)^(ea>>>19|0<<13|(W<<13|0>>>19)))|0;K=F;ma=YGb(aa,K,-544281703,659060556)|0;ba=YGb(ma,F,t,J)|0;J=YGb(ba,F,w&(z^q)^q,U&(R^M)^M)|0;ba=YGb(J,F,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=F;t=YGb(ba,J,ua,X)|0;X=F;ua=YGb((ja>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(ja<<30|0>>>2))^(G>>>7|0<<25|(ja<<25|0>>>7)),(G>>>28|0<<4|(ja<<4|0>>>28))^(0>>>2|0<<30|(G<<30|ja>>>2))^(0>>>7|0<<25|(G<<25|ja>>>7)),ja&(ga|ya)|ga&ya,G&(D|_)|D&_)|0;ma=YGb(ua,F,ba,J)|0;J=F;ba=YGb((sa>>>8|S<<24|(0<<24|0>>>8))^(sa>>>7|S<<25)^(sa>>>1|S<<31|(0<<31|0>>>1)),(S>>>8|0<<24|(sa<<24|0>>>8))^(S>>>7|0<<25)^(S>>>1|0<<31|(sa<<31|0>>>1)),pa,N)|0;N=YGb(ba,F,I,oa)|0;ba=YGb(N,F,(b>>>29|0<<3|(Z<<3|0>>>29))^(Z>>>6|b<<26)^(Z>>>19|b<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(b<<3|Z>>>29))^(b>>>6|0<<26)^(b>>>19|0<<13|(Z<<13|0>>>19)))|0;N=F;pa=YGb(ba,N,-509917016,883997877)|0;ua=YGb(pa,F,q,M)|0;M=YGb(ua,F,t&(w^z)^z,X&(U^R)^R)|0;ua=YGb(M,F,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=F;q=YGb(ua,M,ya,_)|0;_=F;ya=YGb((ma>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(ma<<30|0>>>2))^(J>>>7|0<<25|(ma<<25|0>>>7)),(J>>>28|0<<4|(ma<<4|0>>>28))^(0>>>2|0<<30|(J<<30|ma>>>2))^(0>>>7|0<<25|(J<<25|ma>>>7)),ma&(ja|ga)|ja&ga,J&(G|D)|G&D)|0;pa=YGb(ya,F,ua,M)|0;M=F;ua=YGb((xa>>>8|V<<24|(0<<24|0>>>8))^(xa>>>7|V<<25)^(xa>>>1|V<<31|(0<<31|0>>>1)),(V>>>8|0<<24|(xa<<24|0>>>8))^(V>>>7|0<<25)^(V>>>1|0<<31|(xa<<31|0>>>1)),sa,S)|0;S=YGb(ua,F,L,ra)|0;ua=YGb(S,F,(K>>>29|0<<3|(aa<<3|0>>>29))^(aa>>>6|K<<26)^(aa>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|aa>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(aa<<13|0>>>19)))|0;S=F;sa=YGb(ua,S,-976659869,958139571)|0;ya=YGb(sa,F,z,R)|0;R=YGb(ya,F,q&(t^w)^w,_&(X^U)^U)|0;ya=YGb(R,F,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=F;z=YGb(ya,R,ga,D)|0;D=F;ga=YGb((pa>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(pa<<30|0>>>2))^(M>>>7|0<<25|(pa<<25|0>>>7)),(M>>>28|0<<4|(pa<<4|0>>>28))^(0>>>2|0<<30|(M<<30|pa>>>2))^(0>>>7|0<<25|(M<<25|pa>>>7)),pa&(ma|ja)|ma&ja,M&(J|G)|J&G)|0;sa=YGb(ga,F,ya,R)|0;R=F;ya=YGb((Ba>>>8|Y<<24|(0<<24|0>>>8))^(Ba>>>7|Y<<25)^(Ba>>>1|Y<<31|(0<<31|0>>>1)),(Y>>>8|0<<24|(Ba<<24|0>>>8))^(Y>>>7|0<<25)^(Y>>>1|0<<31|(Ba<<31|0>>>1)),xa,V)|0;V=YGb(ya,F,Q,va)|0;ya=YGb(V,F,(N>>>29|0<<3|(ba<<3|0>>>29))^(ba>>>6|N<<26)^(ba>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|ba>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(ba<<13|0>>>19)))|0;V=F;xa=YGb(ya,V,-482243893,1322822218)|0;ga=YGb(xa,F,w,U)|0;U=YGb(ga,F,z&(q^t)^t,D&(_^X)^X)|0;ga=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(ga,U,ja,G)|0;G=F;ja=YGb((sa>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(sa<<30|0>>>2))^(R>>>7|0<<25|(sa<<25|0>>>7)),(R>>>28|0<<4|(sa<<4|0>>>28))^(0>>>2|0<<30|(R<<30|sa>>>2))^(0>>>7|0<<25|(R<<25|sa>>>7)),sa&(pa|ma)|pa&ma,R&(M|J)|M&J)|0;xa=YGb(ja,F,ga,U)|0;U=F;ga=YGb((B>>>8|$<<24|(0<<24|0>>>8))^(B>>>7|$<<25)^(B>>>1|$<<31|(0<<31|0>>>1)),($>>>8|0<<24|(B<<24|0>>>8))^($>>>7|0<<25)^($>>>1|0<<31|(B<<31|0>>>1)),Ba,Y)|0;Y=YGb(ga,F,T,za)|0;ga=YGb(Y,F,(S>>>29|0<<3|(ua<<3|0>>>29))^(ua>>>6|S<<26)^(ua>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|ua>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(ua<<13|0>>>19)))|0;Y=F;Ba=YGb(ga,Y,2003034995,1537002063)|0;ja=YGb(Ba,F,t,X)|0;X=YGb(ja,F,w&(z^q)^q,G&(D^_)^_)|0;ja=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(ja,X,ma,J)|0;J=F;ma=YGb((xa>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(xa<<30|0>>>2))^(U>>>7|0<<25|(xa<<25|0>>>7)),(U>>>28|0<<4|(xa<<4|0>>>28))^(0>>>2|0<<30|(U<<30|xa>>>2))^(0>>>7|0<<25|(U<<25|xa>>>7)),xa&(sa|pa)|sa&pa,U&(R|M)|R&M)|0;Ba=YGb(ma,F,ja,X)|0;X=F;ja=YGb((H>>>8|ca<<24|(0<<24|0>>>8))^(H>>>7|ca<<25)^(H>>>1|ca<<31|(0<<31|0>>>1)),(ca>>>8|0<<24|(H<<24|0>>>8))^(ca>>>7|0<<25)^(ca>>>1|0<<31|(H<<31|0>>>1)),B,$)|0;$=YGb(ja,F,W,ea)|0;ja=YGb($,F,(V>>>29|0<<3|(ya<<3|0>>>29))^(ya>>>6|V<<26)^(ya>>>19|V<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(V<<3|ya>>>29))^(V>>>6|0<<26)^(V>>>19|0<<13|(ya<<13|0>>>19)))|0;$=F;B=YGb(ja,$,-692930397,1747873779)|0;ma=YGb(B,F,q,_)|0;_=YGb(ma,F,t&(w^z)^z,J&(G^D)^D)|0;ma=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb(ma,_,pa,M)|0;M=F;pa=YGb((Ba>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(Ba<<30|0>>>2))^(X>>>7|0<<25|(Ba<<25|0>>>7)),(X>>>28|0<<4|(Ba<<4|0>>>28))^(0>>>2|0<<30|(X<<30|Ba>>>2))^(0>>>7|0<<25|(X<<25|Ba>>>7)),Ba&(xa|sa)|xa&sa,X&(U|R)|U&R)|0;B=YGb(pa,F,ma,_)|0;_=F;ma=YGb((h>>>8|fa<<24|(0<<24|0>>>8))^(h>>>7|fa<<25)^(h>>>1|fa<<31|(0<<31|0>>>1)),(fa>>>8|0<<24|(h<<24|0>>>8))^(fa>>>7|0<<25)^(fa>>>1|0<<31|(h<<31|0>>>1)),H,ca)|0;ca=YGb(ma,F,Z,b)|0;ma=YGb(ca,F,(Y>>>29|0<<3|(ga<<3|0>>>29))^(ga>>>6|Y<<26)^(ga>>>19|Y<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(Y<<3|ga>>>29))^(Y>>>6|0<<26)^(Y>>>19|0<<13|(ga<<13|0>>>19)))|0;ca=F;H=YGb(ma,ca,1575990012,1955562222)|0;pa=YGb(H,F,z,D)|0;D=YGb(pa,F,q&(t^w)^w,M&(J^G)^G)|0;pa=YGb(D,F,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=F;z=YGb(pa,D,sa,R)|0;R=F;sa=YGb((B>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(B<<30|0>>>2))^(_>>>7|0<<25|(B<<25|0>>>7)),(_>>>28|0<<4|(B<<4|0>>>28))^(0>>>2|0<<30|(_<<30|B>>>2))^(0>>>7|0<<25|(_<<25|B>>>7)),B&(Ba|xa)|Ba&xa,_&(X|U)|X&U)|0;H=YGb(sa,F,pa,D)|0;D=F;pa=YGb((P>>>8|ia<<24|(0<<24|0>>>8))^(P>>>7|ia<<25)^(P>>>1|ia<<31|(0<<31|0>>>1)),(ia>>>8|0<<24|(P<<24|0>>>8))^(ia>>>7|0<<25)^(ia>>>1|0<<31|(P<<31|0>>>1)),h,fa)|0;fa=YGb(pa,F,aa,K)|0;pa=YGb(fa,F,($>>>29|0<<3|(ja<<3|0>>>29))^(ja>>>6|$<<26)^(ja>>>19|$<<13|(0<<13|0>>>19)),(0>>>29|0<<3|($<<3|ja>>>29))^($>>>6|0<<26)^($>>>19|0<<13|(ja<<13|0>>>19)))|0;fa=F;h=YGb(pa,fa,1125592928,2024104815)|0;sa=YGb(h,F,w,G)|0;G=YGb(sa,F,z&(q^t)^t,R&(M^J)^J)|0;sa=YGb(G,F,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;G=F;w=YGb(sa,G,xa,U)|0;U=F;xa=YGb((H>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(H<<30|0>>>2))^(D>>>7|0<<25|(H<<25|0>>>7)),(D>>>28|0<<4|(H<<4|0>>>28))^(0>>>2|0<<30|(D<<30|H>>>2))^(0>>>7|0<<25|(D<<25|H>>>7)),H&(B|Ba)|B&Ba,D&(_|X)|_&X)|0;h=YGb(xa,F,sa,G)|0;G=F;sa=YGb((E>>>8|la<<24|(0<<24|0>>>8))^(E>>>7|la<<25)^(E>>>1|la<<31|(0<<31|0>>>1)),(la>>>8|0<<24|(E<<24|0>>>8))^(la>>>7|0<<25)^(la>>>1|0<<31|(E<<31|0>>>1)),P,ia)|0;ia=YGb(sa,F,ba,N)|0;sa=YGb(ia,F,(ca>>>29|0<<3|(ma<<3|0>>>29))^(ma>>>6|ca<<26)^(ma>>>19|ca<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ca<<3|ma>>>29))^(ca>>>6|0<<26)^(ca>>>19|0<<13|(ma<<13|0>>>19)))|0;ia=F;P=YGb(sa,ia,-1578062990,-2067236844)|0;xa=YGb(P,F,t,J)|0;J=YGb(xa,F,w&(z^q)^q,U&(R^M)^M)|0;xa=YGb(J,F,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=F;t=YGb(xa,J,Ba,X)|0;X=F;Ba=YGb((h>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(h<<30|0>>>2))^(G>>>7|0<<25|(h<<25|0>>>7)),(G>>>28|0<<4|(h<<4|0>>>28))^(0>>>2|0<<30|(G<<30|h>>>2))^(0>>>7|0<<25|(G<<25|h>>>7)),h&(H|B)|H&B,G&(D|_)|D&_)|0;P=YGb(Ba,F,xa,J)|0;J=F;xa=YGb((I>>>8|oa<<24|(0<<24|0>>>8))^(I>>>7|oa<<25)^(I>>>1|oa<<31|(0<<31|0>>>1)),(oa>>>8|0<<24|(I<<24|0>>>8))^(oa>>>7|0<<25)^(oa>>>1|0<<31|(I<<31|0>>>1)),E,la)|0;la=YGb(xa,F,ua,S)|0;xa=YGb(la,F,(fa>>>29|0<<3|(pa<<3|0>>>29))^(pa>>>6|fa<<26)^(pa>>>19|fa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(fa<<3|pa>>>29))^(fa>>>6|0<<26)^(fa>>>19|0<<13|(pa<<13|0>>>19)))|0;la=F;E=YGb(xa,la,442776044,-1933114872)|0;Ba=YGb(E,F,q,M)|0;M=YGb(Ba,F,t&(w^z)^z,X&(U^R)^R)|0;Ba=YGb(M,F,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=F;q=YGb(Ba,M,B,_)|0;_=F;B=YGb((P>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(P<<30|0>>>2))^(J>>>7|0<<25|(P<<25|0>>>7)),(J>>>28|0<<4|(P<<4|0>>>28))^(0>>>2|0<<30|(J<<30|P>>>2))^(0>>>7|0<<25|(J<<25|P>>>7)),P&(h|H)|h&H,J&(G|D)|G&D)|0;E=YGb(B,F,Ba,M)|0;M=F;Ba=YGb((L>>>8|ra<<24|(0<<24|0>>>8))^(L>>>7|ra<<25)^(L>>>1|ra<<31|(0<<31|0>>>1)),(ra>>>8|0<<24|(L<<24|0>>>8))^(ra>>>7|0<<25)^(ra>>>1|0<<31|(L<<31|0>>>1)),I,oa)|0;oa=YGb(Ba,F,ya,V)|0;Ba=YGb(oa,F,(ia>>>29|0<<3|(sa<<3|0>>>29))^(sa>>>6|ia<<26)^(sa>>>19|ia<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ia<<3|sa>>>29))^(ia>>>6|0<<26)^(ia>>>19|0<<13|(sa<<13|0>>>19)))|0;oa=F;I=YGb(Ba,oa,593698344,-1866530822)|0;B=YGb(I,F,z,R)|0;R=YGb(B,F,q&(t^w)^w,_&(X^U)^U)|0;B=YGb(R,F,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=F;z=YGb(B,R,H,D)|0;D=F;H=YGb((E>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(E<<30|0>>>2))^(M>>>7|0<<25|(E<<25|0>>>7)),(M>>>28|0<<4|(E<<4|0>>>28))^(0>>>2|0<<30|(M<<30|E>>>2))^(0>>>7|0<<25|(M<<25|E>>>7)),E&(P|h)|P&h,M&(J|G)|J&G)|0;I=YGb(H,F,B,R)|0;R=F;B=YGb((Q>>>8|va<<24|(0<<24|0>>>8))^(Q>>>7|va<<25)^(Q>>>1|va<<31|(0<<31|0>>>1)),(va>>>8|0<<24|(Q<<24|0>>>8))^(va>>>7|0<<25)^(va>>>1|0<<31|(Q<<31|0>>>1)),L,ra)|0;ra=YGb(B,F,ga,Y)|0;B=YGb(ra,F,(la>>>29|0<<3|(xa<<3|0>>>29))^(xa>>>6|la<<26)^(xa>>>19|la<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(la<<3|xa>>>29))^(la>>>6|0<<26)^(la>>>19|0<<13|(xa<<13|0>>>19)))|0;ra=F;L=YGb(B,ra,-561857047,-1538233109)|0;H=YGb(L,F,w,U)|0;U=YGb(H,F,z&(q^t)^t,D&(_^X)^X)|0;H=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(H,U,h,G)|0;G=F;h=YGb((I>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(I<<30|0>>>2))^(R>>>7|0<<25|(I<<25|0>>>7)),(R>>>28|0<<4|(I<<4|0>>>28))^(0>>>2|0<<30|(R<<30|I>>>2))^(0>>>7|0<<25|(R<<25|I>>>7)),I&(E|P)|E&P,R&(M|J)|M&J)|0;L=YGb(h,F,H,U)|0;U=F;H=YGb((T>>>8|za<<24|(0<<24|0>>>8))^(T>>>7|za<<25)^(T>>>1|za<<31|(0<<31|0>>>1)),(za>>>8|0<<24|(T<<24|0>>>8))^(za>>>7|0<<25)^(za>>>1|0<<31|(T<<31|0>>>1)),Q,va)|0;va=YGb(H,F,ja,$)|0;H=YGb(va,F,(oa>>>29|0<<3|(Ba<<3|0>>>29))^(Ba>>>6|oa<<26)^(Ba>>>19|oa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(oa<<3|Ba>>>29))^(oa>>>6|0<<26)^(oa>>>19|0<<13|(Ba<<13|0>>>19)))|0;va=F;Q=YGb(H,va,-1295615723,-1090935817)|0;h=YGb(Q,F,t,X)|0;X=YGb(h,F,w&(z^q)^q,G&(D^_)^_)|0;h=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(h,X,P,J)|0;J=F;P=YGb((L>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(L<<30|0>>>2))^(U>>>7|0<<25|(L<<25|0>>>7)),(U>>>28|0<<4|(L<<4|0>>>28))^(0>>>2|0<<30|(U<<30|L>>>2))^(0>>>7|0<<25|(U<<25|L>>>7)),L&(I|E)|I&E,U&(R|M)|R&M)|0;Q=YGb(P,F,h,X)|0;X=F;h=YGb((W>>>8|ea<<24|(0<<24|0>>>8))^(W>>>7|ea<<25)^(W>>>1|ea<<31|(0<<31|0>>>1)),(ea>>>8|0<<24|(W<<24|0>>>8))^(ea>>>7|0<<25)^(ea>>>1|0<<31|(W<<31|0>>>1)),T,za)|0;za=YGb(h,F,ma,ca)|0;h=YGb(za,F,(ra>>>29|0<<3|(B<<3|0>>>29))^(B>>>6|ra<<26)^(B>>>19|ra<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ra<<3|B>>>29))^(ra>>>6|0<<26)^(ra>>>19|0<<13|(B<<13|0>>>19)))|0;za=F;T=YGb(h,za,-479046869,-965641998)|0;P=YGb(T,F,q,_)|0;_=YGb(P,F,t&(w^z)^z,J&(G^D)^D)|0;P=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb(P,_,E,M)|0;M=F;E=YGb((Q>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(Q<<30|0>>>2))^(X>>>7|0<<25|(Q<<25|0>>>7)),(X>>>28|0<<4|(Q<<4|0>>>28))^(0>>>2|0<<30|(X<<30|Q>>>2))^(0>>>7|0<<25|(X<<25|Q>>>7)),Q&(L|I)|L&I,X&(U|R)|U&R)|0;T=YGb(E,F,P,_)|0;_=F;P=YGb((Z>>>8|b<<24|(0<<24|0>>>8))^(Z>>>7|b<<25)^(Z>>>1|b<<31|(0<<31|0>>>1)),(b>>>8|0<<24|(Z<<24|0>>>8))^(b>>>7|0<<25)^(b>>>1|0<<31|(Z<<31|0>>>1)),W,ea)|0;ea=YGb(P,F,pa,fa)|0;P=YGb(ea,F,(va>>>29|0<<3|(H<<3|0>>>29))^(H>>>6|va<<26)^(H>>>19|va<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(va<<3|H>>>29))^(va>>>6|0<<26)^(va>>>19|0<<13|(H<<13|0>>>19)))|0;ea=F;W=YGb(P,ea,-366583396,-903397682)|0;E=YGb(W,F,z,D)|0;D=YGb(E,F,q&(t^w)^w,M&(J^G)^G)|0;E=YGb(D,F,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=F;z=YGb(E,D,I,R)|0;R=F;I=YGb((T>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(T<<30|0>>>2))^(_>>>7|0<<25|(T<<25|0>>>7)),(_>>>28|0<<4|(T<<4|0>>>28))^(0>>>2|0<<30|(_<<30|T>>>2))^(0>>>7|0<<25|(_<<25|T>>>7)),T&(Q|L)|Q&L,_&(X|U)|X&U)|0;W=YGb(I,F,E,D)|0;D=F;E=YGb((aa>>>8|K<<24|(0<<24|0>>>8))^(aa>>>7|K<<25)^(aa>>>1|K<<31|(0<<31|0>>>1)),(K>>>8|0<<24|(aa<<24|0>>>8))^(K>>>7|0<<25)^(K>>>1|0<<31|(aa<<31|0>>>1)),Z,b)|0;b=YGb(E,F,sa,ia)|0;E=YGb(b,F,(za>>>29|0<<3|(h<<3|0>>>29))^(h>>>6|za<<26)^(h>>>19|za<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(za<<3|h>>>29))^(za>>>6|0<<26)^(za>>>19|0<<13|(h<<13|0>>>19)))|0;b=F;Z=YGb(E,b,566280711,-779700025)|0;I=YGb(Z,F,w,G)|0;G=YGb(I,F,z&(q^t)^t,R&(M^J)^J)|0;I=YGb(G,F,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;G=F;w=YGb(I,G,L,U)|0;U=F;L=YGb((W>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(W<<30|0>>>2))^(D>>>7|0<<25|(W<<25|0>>>7)),(D>>>28|0<<4|(W<<4|0>>>28))^(0>>>2|0<<30|(D<<30|W>>>2))^(0>>>7|0<<25|(D<<25|W>>>7)),W&(T|Q)|T&Q,D&(_|X)|_&X)|0;Z=YGb(L,F,I,G)|0;G=F;I=YGb((ba>>>8|N<<24|(0<<24|0>>>8))^(ba>>>7|N<<25)^(ba>>>1|N<<31|(0<<31|0>>>1)),(N>>>8|0<<24|(ba<<24|0>>>8))^(N>>>7|0<<25)^(N>>>1|0<<31|(ba<<31|0>>>1)),aa,K)|0;K=YGb(I,F,xa,la)|0;I=YGb(K,F,(ea>>>29|0<<3|(P<<3|0>>>29))^(P>>>6|ea<<26)^(P>>>19|ea<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ea<<3|P>>>29))^(ea>>>6|0<<26)^(ea>>>19|0<<13|(P<<13|0>>>19)))|0;K=F;aa=YGb(I,K,-840897762,-354779690)|0;L=YGb(aa,F,t,J)|0;J=YGb(L,F,w&(z^q)^q,U&(R^M)^M)|0;L=YGb(J,F,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=F;t=YGb(L,J,Q,X)|0;X=F;Q=YGb((Z>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(Z<<30|0>>>2))^(G>>>7|0<<25|(Z<<25|0>>>7)),(G>>>28|0<<4|(Z<<4|0>>>28))^(0>>>2|0<<30|(G<<30|Z>>>2))^(0>>>7|0<<25|(G<<25|Z>>>7)),Z&(W|T)|W&T,G&(D|_)|D&_)|0;aa=YGb(Q,F,L,J)|0;J=F;L=YGb((ua>>>8|S<<24|(0<<24|0>>>8))^(ua>>>7|S<<25)^(ua>>>1|S<<31|(0<<31|0>>>1)),(S>>>8|0<<24|(ua<<24|0>>>8))^(S>>>7|0<<25)^(S>>>1|0<<31|(ua<<31|0>>>1)),ba,N)|0;N=YGb(L,F,Ba,oa)|0;L=YGb(N,F,(b>>>29|0<<3|(E<<3|0>>>29))^(E>>>6|b<<26)^(E>>>19|b<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(b<<3|E>>>29))^(b>>>6|0<<26)^(b>>>19|0<<13|(E<<13|0>>>19)))|0;N=F;ba=YGb(L,N,-294727304,-176337025)|0;Q=YGb(ba,F,q,M)|0;M=YGb(Q,F,t&(w^z)^z,X&(U^R)^R)|0;Q=YGb(M,F,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=F;q=YGb(Q,M,T,_)|0;_=F;T=YGb((aa>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(aa<<30|0>>>2))^(J>>>7|0<<25|(aa<<25|0>>>7)),(J>>>28|0<<4|(aa<<4|0>>>28))^(0>>>2|0<<30|(J<<30|aa>>>2))^(0>>>7|0<<25|(J<<25|aa>>>7)),aa&(Z|W)|Z&W,J&(G|D)|G&D)|0;ba=YGb(T,F,Q,M)|0;M=F;Q=YGb((ya>>>8|V<<24|(0<<24|0>>>8))^(ya>>>7|V<<25)^(ya>>>1|V<<31|(0<<31|0>>>1)),(V>>>8|0<<24|(ya<<24|0>>>8))^(V>>>7|0<<25)^(V>>>1|0<<31|(ya<<31|0>>>1)),ua,S)|0;S=YGb(Q,F,B,ra)|0;Q=YGb(S,F,(K>>>29|0<<3|(I<<3|0>>>29))^(I>>>6|K<<26)^(I>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|I>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(I<<13|0>>>19)))|0;S=F;ua=YGb(Q,S,1914138554,116418474)|0;T=YGb(ua,F,z,R)|0;R=YGb(T,F,q&(t^w)^w,_&(X^U)^U)|0;T=YGb(R,F,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=F;z=YGb(T,R,W,D)|0;D=F;W=YGb((ba>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(ba<<30|0>>>2))^(M>>>7|0<<25|(ba<<25|0>>>7)),(M>>>28|0<<4|(ba<<4|0>>>28))^(0>>>2|0<<30|(M<<30|ba>>>2))^(0>>>7|0<<25|(M<<25|ba>>>7)),ba&(aa|Z)|aa&Z,M&(J|G)|J&G)|0;ua=YGb(W,F,T,R)|0;R=F;T=YGb((ga>>>8|Y<<24|(0<<24|0>>>8))^(ga>>>7|Y<<25)^(ga>>>1|Y<<31|(0<<31|0>>>1)),(Y>>>8|0<<24|(ga<<24|0>>>8))^(Y>>>7|0<<25)^(Y>>>1|0<<31|(ga<<31|0>>>1)),ya,V)|0;V=YGb(T,F,H,va)|0;T=YGb(V,F,(N>>>29|0<<3|(L<<3|0>>>29))^(L>>>6|N<<26)^(L>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|L>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(L<<13|0>>>19)))|0;V=F;ya=YGb(T,V,-1563912026,174292421)|0;W=YGb(ya,F,w,U)|0;U=YGb(W,F,z&(q^t)^t,D&(_^X)^X)|0;W=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(W,U,Z,G)|0;G=F;Z=YGb((ua>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(ua<<30|0>>>2))^(R>>>7|0<<25|(ua<<25|0>>>7)),(R>>>28|0<<4|(ua<<4|0>>>28))^(0>>>2|0<<30|(R<<30|ua>>>2))^(0>>>7|0<<25|(R<<25|ua>>>7)),ua&(ba|aa)|ba&aa,R&(M|J)|M&J)|0;ya=YGb(Z,F,W,U)|0;U=F;W=YGb((ja>>>8|$<<24|(0<<24|0>>>8))^(ja>>>7|$<<25)^(ja>>>1|$<<31|(0<<31|0>>>1)),($>>>8|0<<24|(ja<<24|0>>>8))^($>>>7|0<<25)^($>>>1|0<<31|(ja<<31|0>>>1)),ga,Y)|0;Y=YGb(W,F,h,za)|0;W=YGb(Y,F,(S>>>29|0<<3|(Q<<3|0>>>29))^(Q>>>6|S<<26)^(Q>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|Q>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(Q<<13|0>>>19)))|0;Y=F;ga=YGb(W,Y,-1090974290,289380356)|0;Z=YGb(ga,F,t,X)|0;X=YGb(Z,F,w&(z^q)^q,G&(D^_)^_)|0;Z=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(Z,X,aa,J)|0;J=F;aa=YGb((ya>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(ya<<30|0>>>2))^(U>>>7|0<<25|(ya<<25|0>>>7)),(U>>>28|0<<4|(ya<<4|0>>>28))^(0>>>2|0<<30|(U<<30|ya>>>2))^(0>>>7|0<<25|(U<<25|ya>>>7)),ya&(ua|ba)|ua&ba,U&(R|M)|R&M)|0;ga=YGb(aa,F,Z,X)|0;X=F;Z=YGb((ma>>>8|ca<<24|(0<<24|0>>>8))^(ma>>>7|ca<<25)^(ma>>>1|ca<<31|(0<<31|0>>>1)),(ca>>>8|0<<24|(ma<<24|0>>>8))^(ca>>>7|0<<25)^(ca>>>1|0<<31|(ma<<31|0>>>1)),ja,$)|0;$=YGb(Z,F,P,ea)|0;Z=YGb($,F,(V>>>29|0<<3|(T<<3|0>>>29))^(T>>>6|V<<26)^(T>>>19|V<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(V<<3|T>>>29))^(V>>>6|0<<26)^(V>>>19|0<<13|(T<<13|0>>>19)))|0;$=F;ja=YGb(Z,$,320620315,460393269)|0;aa=YGb(ja,F,q,_)|0;_=YGb(aa,F,t&(w^z)^z,J&(G^D)^D)|0;aa=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb(aa,_,ba,M)|0;M=F;ba=YGb((ga>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(ga<<30|0>>>2))^(X>>>7|0<<25|(ga<<25|0>>>7)),(X>>>28|0<<4|(ga<<4|0>>>28))^(0>>>2|0<<30|(X<<30|ga>>>2))^(0>>>7|0<<25|(X<<25|ga>>>7)),ga&(ya|ua)|ya&ua,X&(U|R)|U&R)|0;ja=YGb(ba,F,aa,_)|0;_=F;aa=YGb((pa>>>8|fa<<24|(0<<24|0>>>8))^(pa>>>7|fa<<25)^(pa>>>1|fa<<31|(0<<31|0>>>1)),(fa>>>8|0<<24|(pa<<24|0>>>8))^(fa>>>7|0<<25)^(fa>>>1|0<<31|(pa<<31|0>>>1)),ma,ca)|0;ca=YGb(aa,F,E,b)|0;b=YGb(ca,F,(Y>>>29|0<<3|(W<<3|0>>>29))^(W>>>6|Y<<26)^(W>>>19|Y<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(Y<<3|W>>>29))^(Y>>>6|0<<26)^(Y>>>19|0<<13|(W<<13|0>>>19)))|0;ca=F;E=YGb(b,ca,587496836,685471733)|0;aa=YGb(E,F,z,D)|0;D=YGb(aa,F,q&(t^w)^w,M&(J^G)^G)|0;aa=YGb(D,F,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=F;z=YGb(aa,D,ua,R)|0;R=F;ua=YGb((ja>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(ja<<30|0>>>2))^(_>>>7|0<<25|(ja<<25|0>>>7)),(_>>>28|0<<4|(ja<<4|0>>>28))^(0>>>2|0<<30|(_<<30|ja>>>2))^(0>>>7|0<<25|(_<<25|ja>>>7)),ja&(ga|ya)|ga&ya,_&(X|U)|X&U)|0;E=YGb(ua,F,aa,D)|0;D=F;aa=YGb((sa>>>8|ia<<24|(0<<24|0>>>8))^(sa>>>7|ia<<25)^(sa>>>1|ia<<31|(0<<31|0>>>1)),(ia>>>8|0<<24|(sa<<24|0>>>8))^(ia>>>7|0<<25)^(ia>>>1|0<<31|(sa<<31|0>>>1)),pa,fa)|0;fa=YGb(aa,F,I,K)|0;K=YGb(fa,F,($>>>29|0<<3|(Z<<3|0>>>29))^(Z>>>6|$<<26)^(Z>>>19|$<<13|(0<<13|0>>>19)),(0>>>29|0<<3|($<<3|Z>>>29))^($>>>6|0<<26)^($>>>19|0<<13|(Z<<13|0>>>19)))|0;fa=F;I=YGb(K,fa,1086792851,852142971)|0;aa=YGb(I,F,w,G)|0;G=YGb(aa,F,z&(q^t)^t,R&(M^J)^J)|0;aa=YGb(G,F,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;G=F;w=YGb(aa,G,ya,U)|0;U=F;ya=YGb((E>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(E<<30|0>>>2))^(D>>>7|0<<25|(E<<25|0>>>7)),(D>>>28|0<<4|(E<<4|0>>>28))^(0>>>2|0<<30|(D<<30|E>>>2))^(0>>>7|0<<25|(D<<25|E>>>7)),E&(ja|ga)|ja&ga,D&(_|X)|_&X)|0;I=YGb(ya,F,aa,G)|0;G=F;aa=YGb((xa>>>8|la<<24|(0<<24|0>>>8))^(xa>>>7|la<<25)^(xa>>>1|la<<31|(0<<31|0>>>1)),(la>>>8|0<<24|(xa<<24|0>>>8))^(la>>>7|0<<25)^(la>>>1|0<<31|(xa<<31|0>>>1)),sa,ia)|0;ia=YGb(aa,F,L,N)|0;N=YGb(ia,F,(ca>>>29|0<<3|(b<<3|0>>>29))^(b>>>6|ca<<26)^(b>>>19|ca<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ca<<3|b>>>29))^(ca>>>6|0<<26)^(ca>>>19|0<<13|(b<<13|0>>>19)))|0;ia=F;L=YGb(N,ia,365543100,1017036298)|0;aa=YGb(L,F,t,J)|0;J=YGb(aa,F,w&(z^q)^q,U&(R^M)^M)|0;aa=YGb(J,F,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=F;t=YGb(aa,J,ga,X)|0;X=F;ga=YGb((I>>>28|G<<4|(0<<4|0>>>28))^(G>>>2|0<<30|(I<<30|0>>>2))^(G>>>7|0<<25|(I<<25|0>>>7)),(G>>>28|0<<4|(I<<4|0>>>28))^(0>>>2|0<<30|(G<<30|I>>>2))^(0>>>7|0<<25|(G<<25|I>>>7)),I&(E|ja)|E&ja,G&(D|_)|D&_)|0;L=YGb(ga,F,aa,J)|0;J=F;aa=YGb((Ba>>>8|oa<<24|(0<<24|0>>>8))^(Ba>>>7|oa<<25)^(Ba>>>1|oa<<31|(0<<31|0>>>1)),(oa>>>8|0<<24|(Ba<<24|0>>>8))^(oa>>>7|0<<25)^(oa>>>1|0<<31|(Ba<<31|0>>>1)),xa,la)|0;la=YGb(aa,F,Q,S)|0;S=YGb(la,F,(fa>>>29|0<<3|(K<<3|0>>>29))^(K>>>6|fa<<26)^(K>>>19|fa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(fa<<3|K>>>29))^(fa>>>6|0<<26)^(fa>>>19|0<<13|(K<<13|0>>>19)))|0;K=F;fa=YGb(S,K,-1676669620,1126000580)|0;la=YGb(fa,F,q,M)|0;M=YGb(la,F,t&(w^z)^z,X&(U^R)^R)|0;la=YGb(M,F,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=F;q=YGb(la,M,ja,_)|0;_=F;ja=YGb((L>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(L<<30|0>>>2))^(J>>>7|0<<25|(L<<25|0>>>7)),(J>>>28|0<<4|(L<<4|0>>>28))^(0>>>2|0<<30|(J<<30|L>>>2))^(0>>>7|0<<25|(J<<25|L>>>7)),L&(I|E)|I&E,J&(G|D)|G&D)|0;fa=YGb(ja,F,la,M)|0;M=F;la=YGb((B>>>8|ra<<24|(0<<24|0>>>8))^(B>>>7|ra<<25)^(B>>>1|ra<<31|(0<<31|0>>>1)),(ra>>>8|0<<24|(B<<24|0>>>8))^(ra>>>7|0<<25)^(ra>>>1|0<<31|(B<<31|0>>>1)),Ba,oa)|0;oa=YGb(la,F,T,V)|0;V=YGb(oa,F,(ia>>>29|0<<3|(N<<3|0>>>29))^(N>>>6|ia<<26)^(N>>>19|ia<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ia<<3|N>>>29))^(ia>>>6|0<<26)^(ia>>>19|0<<13|(N<<13|0>>>19)))|0;N=F;ia=YGb(V,N,-885112138,1288033470)|0;oa=YGb(ia,F,z,R)|0;R=YGb(oa,F,q&(t^w)^w,_&(X^U)^U)|0;oa=YGb(R,F,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=F;z=YGb(oa,R,E,D)|0;D=F;E=YGb((fa>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(fa<<30|0>>>2))^(M>>>7|0<<25|(fa<<25|0>>>7)),(M>>>28|0<<4|(fa<<4|0>>>28))^(0>>>2|0<<30|(M<<30|fa>>>2))^(0>>>7|0<<25|(M<<25|fa>>>7)),fa&(L|I)|L&I,M&(J|G)|J&G)|0;ia=YGb(E,F,oa,R)|0;R=F;oa=YGb((H>>>8|va<<24|(0<<24|0>>>8))^(H>>>7|va<<25)^(H>>>1|va<<31|(0<<31|0>>>1)),(va>>>8|0<<24|(H<<24|0>>>8))^(va>>>7|0<<25)^(va>>>1|0<<31|(H<<31|0>>>1)),B,ra)|0;ra=YGb(oa,F,W,Y)|0;Y=YGb(ra,F,(K>>>29|0<<3|(S<<3|0>>>29))^(S>>>6|K<<26)^(S>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|S>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(S<<13|0>>>19)))|0;S=F;K=YGb(Y,S,-60457430,1501505948)|0;ra=YGb(K,F,w,U)|0;U=YGb(ra,F,z&(q^t)^t,D&(_^X)^X)|0;ra=YGb(U,F,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=F;w=YGb(ra,U,I,G)|0;G=F;I=YGb((ia>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(ia<<30|0>>>2))^(R>>>7|0<<25|(ia<<25|0>>>7)),(R>>>28|0<<4|(ia<<4|0>>>28))^(0>>>2|0<<30|(R<<30|ia>>>2))^(0>>>7|0<<25|(R<<25|ia>>>7)),ia&(fa|L)|fa&L,R&(M|J)|M&J)|0;K=YGb(I,F,ra,U)|0;U=F;ra=YGb(H,va,987167468,1607167915)|0;va=YGb(ra,F,(h>>>8|za<<24|(0<<24|0>>>8))^(h>>>7|za<<25)^(h>>>1|za<<31|(0<<31|0>>>1)),(za>>>8|0<<24|(h<<24|0>>>8))^(za>>>7|0<<25)^(za>>>1|0<<31|(h<<31|0>>>1)))|0;ra=YGb(va,F,Z,$)|0;$=YGb(ra,F,(N>>>29|0<<3|(V<<3|0>>>29))^(V>>>6|N<<26)^(V>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|V>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(V<<13|0>>>19)))|0;V=YGb($,F,t,X)|0;X=YGb(V,F,w&(z^q)^q,G&(D^_)^_)|0;V=YGb(X,F,(w>>>14|G<<18|(0<<18|0>>>14))^(w>>>18|G<<14|(0<<14|0>>>18))^(G>>>9|0<<23|(w<<23|0>>>9)),(G>>>14|0<<18|(w<<18|0>>>14))^(G>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(G<<23|w>>>9)))|0;X=F;t=YGb(V,X,L,J)|0;J=F;L=YGb((K>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(K<<30|0>>>2))^(U>>>7|0<<25|(K<<25|0>>>7)),(U>>>28|0<<4|(K<<4|0>>>28))^(0>>>2|0<<30|(U<<30|K>>>2))^(0>>>7|0<<25|(U<<25|K>>>7)),K&(ia|fa)|ia&fa,U&(R|M)|R&M)|0;$=YGb(L,F,V,X)|0;X=F;V=YGb(h,za,1246189591,1816402316)|0;za=YGb(V,F,(P>>>8|ea<<24|(0<<24|0>>>8))^(P>>>7|ea<<25)^(P>>>1|ea<<31|(0<<31|0>>>1)),(ea>>>8|0<<24|(P<<24|0>>>8))^(ea>>>7|0<<25)^(ea>>>1|0<<31|(P<<31|0>>>1)))|0;P=YGb(za,F,b,ca)|0;ca=YGb(P,F,(S>>>29|0<<3|(Y<<3|0>>>29))^(Y>>>6|S<<26)^(Y>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|Y>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(Y<<13|0>>>19)))|0;Y=YGb(ca,F,q,_)|0;_=YGb(Y,F,t&(w^z)^z,J&(G^D)^D)|0;Y=YGb(_,F,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=F;q=YGb($&(K|ia)|K&ia,X&(U|R)|U&R,e,f)|0;f=YGb(q,F,($>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|($<<30|0>>>2))^(X>>>7|0<<25|($<<25|0>>>7)),(X>>>28|0<<4|($<<4|0>>>28))^(0>>>2|0<<30|(X<<30|$>>>2))^(0>>>7|0<<25|(X<<25|$>>>7)))|0;q=YGb(f,F,Y,_)|0;c[a>>2]=q;c[a+4>>2]=F;a=YGb($,X,c[g>>2]|0,c[g+4>>2]|0)|0;c[g>>2]=a;c[g+4>>2]=F;g=YGb(K,U,c[j>>2]|0,c[j+4>>2]|0)|0;c[j>>2]=g;c[j+4>>2]=F;j=YGb(ia,R,c[m>>2]|0,c[m+4>>2]|0)|0;c[m>>2]=j;c[m+4>>2]=F;m=YGb(fa,M,c[p>>2]|0,c[p+4>>2]|0)|0;M=YGb(m,F,Y,_)|0;c[p>>2]=M;c[p+4>>2]=F;p=YGb(t,J,c[s>>2]|0,c[s+4>>2]|0)|0;c[s>>2]=p;c[s+4>>2]=F;s=YGb(w,G,c[v>>2]|0,c[v+4>>2]|0)|0;c[v>>2]=s;c[v+4>>2]=F;v=YGb(z,D,c[y>>2]|0,c[y+4>>2]|0)|0;c[y>>2]=v;c[y+4>>2]=F;return}function TFb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+16|0;f=e|0;g=e+8|0;c[f>>2]=0;c[f+4>>2]=0;h=b+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;l=fe(j<<3|0>>>29|0)|0;c[g>>2]=fe(j>>>29|k<<3|0)|0;c[g+4>>2]=l;l=j&127;m=YGb(j,k,1,0)|0;c[h>>2]=m;c[h+4>>2]=F;if((l+1|0)>>>0>127>>>0){m=128-l|0;UGb(b+16+l|0,2156248,m)|0;SFb(b+144|0,b+16|0);n=0;o=m}else{n=l;o=0}UGb(b+16+n|0,2156248+o|0,1-o|0)|0;o=c[h>>2]|0;n=c[h+4>>2]|0;if((o&127|0)==112&(n&0|0)==0){p=n;q=o}else{l=b+144|0;m=b+16|0;k=n;n=o;while(1){o=n&127;j=YGb(n,k,1,0)|0;c[h>>2]=j;c[h+4>>2]=F;if((o+1|0)>>>0>127>>>0){j=128-o|0;UGb(b+16+o|0,9203584,j)|0;SFb(l,m);r=0;s=j}else{r=o;s=0}UGb(b+16+r|0,9203584+s|0,1-s|0)|0;o=c[h>>2]|0;j=c[h+4>>2]|0;if((o&127|0)==112&(j&0|0)==0){p=j;q=o;break}else{k=j;n=o}}}n=f;k=q&127;s=YGb(q,p,8,0)|0;c[h>>2]=s;c[h+4>>2]=F;do{if((k+8|0)>>>0>127>>>0){s=128-k|0;UGb(b+16+k|0,n|0,s)|0;p=b+144|0;SFb(p,b+16|0);if((s+127|0)>>>0<8>>>0){t=s}else{u=0;v=s;break}while(1){SFb(p,n+t|0);s=t+128|0;if((t+255|0)>>>0<8>>>0){t=s}else{u=0;v=s;break}}}else{u=k;v=0}}while(0);UGb(b+16+u|0,n+v|0,8-v|0)|0;v=g;g=c[h>>2]|0;n=g&127;u=YGb(g,c[h+4>>2]|0,8,0)|0;c[h>>2]=u;c[h+4>>2]=F;do{if((n+8|0)>>>0>127>>>0){h=128-n|0;UGb(b+16+n|0,v|0,h)|0;u=b+144|0;SFb(u,b+16|0);if((h+127|0)>>>0<8>>>0){w=h}else{y=0;z=h;break}while(1){SFb(u,v+w|0);h=w+128|0;if((w+255|0)>>>0<8>>>0){w=h}else{y=0;z=h;break}}}else{y=n;z=0}}while(0);UGb(b+16+y|0,v+z|0,8-z|0)|0;c[f>>2]=0;c[f+4>>2]=0;z=b|0;if((a[z]|0)==0){i=e;return}else{A=0;B=0}while(1){v=b+144+(B<<3)|0;y=c[v+4>>2]|0;n=fe(c[v>>2]|0)|0;v=fe(y|0)|0;y=d+(B<<3|0>>>29)|0;w=y|0;x=v;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;w=y+4|0;x=n|0;a[w]=x;x=x>>8;a[w+1|0]=x;x=x>>8;a[w+2|0]=x;x=x>>8;a[w+3|0]=x;C=YGb(B,A,1,0)|0;D=F;E=a[z]|0;w=0;if(D>>>0<w>>>0|D>>>0==w>>>0&C>>>0<(E&255)>>>0){A=D;B=C}else{break}}c[f>>2]=C;c[f+4>>2]=D;if((E&1)==0){i=e;return}E=fe(c[b+144+(C<<3)+4>>2]|0)|0;b=d+(C<<3|0>>>29)|0;x=E;a[b]=x;x=x>>8;a[b+1|0]=x;x=x>>8;a[b+2|0]=x;x=x>>8;a[b+3|0]=x;i=e;return}function UFb(){return cEb(8)|0}function VFb(a){a=a|0;var b=0,d=0;b=TCb(a,2,8)|0;if((b|0)==0){d=0;return d|0}d=c[b+4>>2]|0;return d|0}function WFb(){var a=0,b=0,d=0,e=0;a=i;i=i+8|0;b=a|0;fd(b|0,0)|0;d=c[b>>2]|0;e=gHb(d,(d|0)<0|0?-1:0,1e6,0)|0;d=c[b+4>>2]|0;b=YGb(e,F,d,(d|0)<0|0?-1:0)|0;d=F;i=a;return(F=d,b)|0}function XFb(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+8|0;d=b|0;c[d>>2]=(a>>>0)/1e6|0;c[d+4>>2]=((a>>>0)%1e6|0)*1e3|0;while(1){if((zc(d|0,d|0)|0)>=0){e=4;break}if((c[(ld()|0)>>2]|0)!=4){e=4;break}}if((e|0)==4){i=b;return 0}return 0}function YFb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)==60){c=35964;d=4}else if((b|0)==30){c=17982;d=2}else{e=a;return e|0}e=(ba(((((a|0)%(c|0)|0)-d|0)/((c>>>0)/10|0|0)|0)+(((a|0)/(c|0)|0)*9|0)|0,d)|0)+a|0;return e|0}function ZFb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+16>>2]|0;e=c[a+4>>2]&1;f=(c[a>>2]|0)+b|0;do{if((e|0)==0){g=f}else{if((d|0)==30){h=17982;i=2}else if((d|0)==60){h=35964;i=4}else{g=f;break}g=(ba(((((f|0)%(h|0)|0)-i|0)/((h>>>0)/10|0|0)|0)+(((f|0)/(h|0)|0)*9|0)|0,i)|0)+f|0}}while(0);f=(g>>>0)%(d>>>0)|0;i=(((g>>>0)/(d>>>0)|0)>>>0)%60|0;h=(((g>>>0)/((d*60|0)>>>0)|0)>>>0)%60|0;b=(((g>>>0)/((d*3600|0)>>>0)|0)>>>0)%24|0;return((f|0)/10|0)<<28|e<<30|((f|0)%10|0)<<24|((i>>>0)/10|0)<<20|((i>>>0)%10|0)<<16|((h>>>0)/10|0)<<12|((h>>>0)%10|0)<<8|((b>>>0)/10|0)<<4|((b>>>0)%10|0)|0}function _Fb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=c[a+16>>2]|0;g=c[a+4>>2]|0;h=g&1;j=(c[a>>2]|0)+d|0;do{if((h|0)==0){k=j}else{if((f|0)==60){l=35964;m=4}else if((f|0)==30){l=17982;m=2}else{k=j;break}k=(ba(((((j|0)%(l|0)|0)-m|0)/((l>>>0)/10|0|0)|0)+(((j|0)/(l|0)|0)*9|0)|0,m)|0)+j|0}}while(0);if((k|0)<0){n=g&4;o=-k|0}else{n=0;o=k}k=(o|0)/(f*3600|0|0)|0;if((g&2|0)==0){p=k}else{p=(k|0)%24|0}Lb(b|0,16,2156096,(k=i,i=i+48|0,c[k>>2]=(n|0)!=0?2299736:9203400,c[k+8>>2]=p,c[k+16>>2]=((o|0)/(f*60|0|0)|0|0)%60|0,c[k+24>>2]=((o|0)/(f|0)|0|0)%60|0,c[k+32>>2]=h|58,c[k+40>>2]=(o|0)%(f|0)|0,k)|0)|0;i=k;i=e;return b|0}function $Fb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b&15;if(f>>>0>9>>>0){g=0}else{g=((b>>>4&3)*10|0)+f|0}f=b>>>8&15;if(f>>>0>9>>>0){h=0}else{h=((b>>>12&7)*10|0)+f|0}f=b>>>16&15;if(f>>>0>9>>>0){j=0}else{j=((b>>>20&7)*10|0)+f|0}f=b>>>24&15;if(f>>>0>9>>>0){k=0}else{k=((b>>>28&3)*10|0)+f|0}if((b&1073741824|0)==0){l=58}else{l=(d|0)!=0?58:59}Lb(a|0,16,2096880,(d=i,i=i+40|0,c[d>>2]=g,c[d+8>>2]=h,c[d+16>>2]=j,c[d+24>>2]=l,c[d+32>>2]=k,d)|0)|0;i=d;i=e;return a|0}function aGb(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;Lb(a|0,16,2096880,(e=i,i=i+40|0,c[e>>2]=b>>>19&31,c[e+8>>2]=b>>>13&63,c[e+16>>2]=b>>>6&63,c[e+24>>2]=b>>>24&1|58,c[e+32>>2]=b&63,e)|0)|0;i=e;i=d;return a|0}function bGb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a;a=i;i=i+8|0;c[a>>2]=c[d>>2];c[a+4>>2]=c[d+4>>2];d=c[a>>2]|0;e=c[a+4>>2]|0;if((e|0)==0|(d|0)==0){f=-1}else{f=(((e|0)/2|0)+d|0)/(e|0)|0}e=0;while(1){if(!(e>>>0<5>>>0)){g=-1;h=6;break}if((c[1488168+(e<<2)>>2]|0)==(f|0)){g=0;h=6;break}else{e=e+1|0}}if((h|0)==6){i=b;return g|0}return 0}function cGb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=b;b=i;i=i+8|0;c[b>>2]=c[h>>2];c[b+4>>2]=c[h+4>>2];TGb(a|0,0,20)|0;c[a>>2]=e;c[a+4>>2]=d;e=b;h=a+8|0;j=c[e>>2]|0;k=c[e+4>>2]|0;c[h>>2]=j;c[h+4>>2]=k;h=j;j=c[b+4>>2]|0;b=k;do{if((j|0)==0|(h|0)==0){c[a+16>>2]=-1;l=-1}else{k=(((j|0)/2|0)+h|0)/(j|0)|0;c[a+16>>2]=k;if((k|0)!=0){l=k;break}yDb(f,16,1960744,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=g;return n|0}}while(0);if((d&1|0)==0|(l|0)==30|(l|0)==60){o=0}else{yDb(f,16,1932904,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=g;return n|0}while(1){if(!(o>>>0<5>>>0)){break}if((c[1488168+(o<<2)>>2]|0)==(l|0)){n=0;p=10;break}else{o=o+1|0}}if((p|0)==10){i=g;return n|0}yDb(f,16,1910016,(m=i,i=i+16|0,c[m>>2]=h,c[m+8>>2]=b,m)|0);i=m;n=-1163346256;i=g;return n|0}function dGb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+40|0;h=d;d=i;i=i+8|0;c[d>>2]=c[h>>2];c[d+4>>2]=c[h+4>>2];h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=xd(e|0,2041784,(e=i,i=i+40|0,c[e>>2]=j,c[e+8>>2]=k,c[e+16>>2]=l,c[e+24>>2]=h,c[e+32>>2]=m,e)|0)|0;i=e;if((n|0)!=5){yDb(f,16,1997048,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;o=-1094995529;i=g;return o|0}TGb(b|0,0,20)|0;n=(a[h]|0)!=58;c[b+4>>2]=n&1;h=d;p=b+8|0;q=c[h>>2]|0;r=c[h+4>>2]|0;c[p>>2]=q;c[p+4>>2]=r;p=q;q=c[d+4>>2]|0;d=r;do{if((q|0)==0|(p|0)==0){c[b+16>>2]=-1;s=-1}else{r=(((q|0)/2|0)+p|0)/(q|0)|0;c[b+16>>2]=r;if((r|0)!=0){s=r;break}yDb(f,16,1960744,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;o=-22;i=g;return o|0}}while(0);do{if(n){if((s|0)==60|(s|0)==30){t=0;break}yDb(f,16,1932904,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;o=-22;i=g;return o|0}else{t=0}}while(0);while(1){if(!(t>>>0<5>>>0)){u=12;break}if((c[1488168+(t<<2)>>2]|0)==(s|0)){break}else{t=t+1|0}}if((u|0)==12){yDb(f,16,1910016,(e=i,i=i+16|0,c[e>>2]=p,c[e+8>>2]=d,e)|0);i=e;o=-1163346256;i=g;return o|0}e=c[j>>2]|0;j=c[k>>2]|0;k=ba((j*60|0)+(e*3600|0)+(c[l>>2]|0)|0,s)|0;s=k+(c[m>>2]|0)|0;m=b|0;c[m>>2]=s;if(!n){o=0;i=g;return o|0}n=(e*60|0)+j|0;c[m>>2]=s-(n-((n|0)/10|0)<<1);o=0;i=g;return o|0}function eGb(){return cEb(16)|0}function fGb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){f=0;return f|0}g=(e|0)!=0;a:do{if(g){h=a;while(1){i=h+8|0;j=Oe[d&1023](b,c[i>>2]|0)|0;if((j|0)==0){k=h;l=i;break a}m=j>>>31;c[e+(m<<2)>>2]=c[i>>2];i=c[h+((m^1)<<2)>>2]|0;if((i|0)==0){f=0;break}else{h=i}}return f|0}else{h=a;while(1){i=h+8|0;m=Oe[d&1023](b,c[i>>2]|0)|0;if((m|0)==0){k=h;l=i;break a}i=c[h+((m>>>31^1)<<2)>>2]|0;if((i|0)==0){f=0;break}else{h=i}}return f|0}}while(0);if(g){fGb(c[k>>2]|0,b,d,e)|0;fGb(c[k+4>>2]|0,b,d,e)|0}f=c[l>>2]|0;return f|0}function gGb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+8|0;g=f|0;h=c[a>>2]|0;if((h|0)==0){c[a>>2]=c[e>>2];c[e>>2]=0;j=c[a>>2]|0;if((j|0)==0){k=b;i=f;return k|0}c[j+8>>2]=b;k=0;i=f;return k|0}j=h+8|0;l=Oe[d&1023](c[j>>2]|0,b)|0;if((l|0)==0){if((c[e>>2]|0)!=0){k=c[j>>2]|0;i=f;return k|0}m=(c[h>>2]|0)==0;do{if(m){if((c[h+4>>2]|0)!=0){break}c[e>>2]=h;c[a>>2]=0;k=0;i=f;return k|0}}while(0);n=m&1;fGb(c[h+(n<<2)>>2]|0,b,d,g|0)|0;m=c[g+(n<<2)>>2]|0;c[j>>2]=m;o=m;p=-n|0}else{o=b;p=l}l=p>>>31;p=gGb(h+(l<<2)|0,o,d,e)|0;do{if((p|0)==0){d=(c[e>>2]|0)!=0^l;b=h+(d<<2)|0;n=h+12|0;m=(c[n>>2]|0)-1+(d<<1)|0;c[n>>2]=m;if((m&1|0)!=0|(m|0)==0){q=c[(c[a>>2]|0)+12>>2]|0}else{j=c[b>>2]|0;if((c[j+12>>2]<<1|0)==(-m|0)){m=d^1;g=c[j+(m<<2)>>2]|0;c[a>>2]=g;c[(c[b>>2]|0)+(m<<2)>>2]=c[g+(d<<2)>>2];c[(c[a>>2]|0)+(d<<2)>>2]=c[b>>2];c[b>>2]=c[(c[a>>2]|0)+(m<<2)>>2];c[(c[a>>2]|0)+(m<<2)>>2]=h;m=c[a>>2]|0;g=m+12|0;c[(c[m>>2]|0)+12>>2]=-((c[g>>2]|0)>0|0);c[(c[m+4>>2]|0)+12>>2]=(c[g>>2]|0)>>>31;c[g>>2]=0;if((c[e>>2]|0)==0){k=o}else{break}i=f;return k|0}c[a>>2]=j;j=d^1;c[b>>2]=c[(c[b>>2]|0)+(j<<2)>>2];c[(c[a>>2]|0)+(j<<2)>>2]=h;if((c[(c[a>>2]|0)+12>>2]|0)==0){r=c[n>>2]>>1}else{r=0}c[n>>2]=r;n=-r|0;c[(c[a>>2]|0)+12>>2]=n;q=n}if((q|0)==0^(c[e>>2]|0)!=0){k=o}else{break}i=f;return k|0}}while(0);k=p;i=f;return k|0}function hGb(a){a=a|0;if((a|0)==0){return}else{hGb(c[a>>2]|0);hGb(c[a+4>>2]|0);ZDb(a);return}}function iGb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((a|0)==0){return}if((d|0)==0){f=a;do{iGb(c[f>>2]|0,b,0,e);Oe[e&1023](b,c[f+8>>2]|0)|0;f=c[f+4>>2]|0;}while((f|0)!=0);return}else{g=a}while(1){a=Oe[d&1023](b,c[g+8>>2]|0)|0;if((a|0)>-1){iGb(c[g>>2]|0,b,d,e);if((a|0)!=0){h=8;break}Oe[e&1023](b,c[g+8>>2]|0)|0}a=c[g+4>>2]|0;if((a|0)==0){h=8;break}else{g=a}}if((h|0)==8){return}}function jGb(){var b=0,d=0;b=i;if(a[1739464]|0){i=b;return 3424868}d=ce(+1152921504606847000.0)|0;if(!((d|0)==0&(F|0)==268435456)){yDb(0,16,2299672,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d}a[1739464]=1;i=b;return 3424868}function kGb(){return 2170616}function lGb(a){a=a|0;var b=0;switch(a|0){case 4:{b=191e4;break};case 1:{b=1997040;break};case 3:{b=1932888;break};case 0:{b=2041776;break};case 2:{b=1960736;break};default:{b=0}}return b|0}function mGb(a){a=a|0;var b=0;switch(a|0){case 2:{b=80;break};case 6:{b=112;break};case 4:{b=83;break};case 1:{b=73;break};case 7:{b=98;break};case 3:{b=66;break};case 5:{b=105;break};default:{b=63}}return b|0}function nGb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;if((e|0)==0){j=0;i=h;return j|0}if((d|0)==2){k=e;l=f&65535;m=0;while(1){if((b[k+(m<<1)>>1]|0)==l<<16>>16){j=m;break}else{m=m+1|0}}i=h;return j|0}else if((d|0)==8){m=e;l=0;while(1){k=m+(l<<3)|0;if((c[k>>2]|0)==(f|0)&(c[k+4>>2]|0)==(g|0)){j=l;break}else{l=l+1|0}}i=h;return j|0}else if((d|0)==1){l=f&255;g=0;while(1){if((a[e+g|0]|0)==l<<24>>24){j=g;break}else{g=g+1|0}}i=h;return j|0}else if((d|0)==4){d=f;f=e;e=0;while(1){if((c[f+(e<<2)>>2]|0)==(d|0)){j=e;break}else{e=e+1|0}}i=h;return j|0}else{yDb(0,0,1889760,(j=i,i=i+24|0,c[j>>2]=2347040,c[j+8>>2]=2326576,c[j+16>>2]=112,j)|0);i=j;Cd();return 0}return 0}function oGb(a,b){a=a|0;b=b|0;var e=0,f=0;e=pGb(a)|0;do{if(!((e|0)==-1)){a=pGb(b)|0;if((a|0)==-1){break}if((d[1488192+e|0]|0)>>>0>207>>>0){break}f=a<<16|e;return f|0}}while(0);c[(ld()|0)>>2]=22;f=-1;return f|0}function pGb(b){b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;c=a[b]|0;a:do{if(c<<24>>24==0){d=1488192;while(1){if((a[d]|0)==0){e=d;break a}f=SGb(d|0)|0;g=d+(f+1)|0;do{if((a[g]|0)==0){h=a[d+(f+2)|0]|0;if((h&255)>>>0>128>>>0){i=d+(f+3)|0;break}else{i=d+(f+3+(((128-(h&255)|0)>>>2)*5|0))|0;break}}else{i=g}}while(0);if((a[i]|0)==0){j=-1;break}else{d=i}}return j|0}else{d=1488192;while(1){g=b;f=d;h=c;while(1){k=a[f]|0;if(k<<24>>24==0){l=f;m=h;n=15;break}o=h&255;p=o|32;b:do{if(h<<24>>24==0){q=g;r=p}else{s=g;t=o;u=p;while(1){v=s+1|0;if(!((u-97|0)>>>0>26>>>0&(t-48|0)>>>0>10>>>0)){q=s;r=u;break b}w=a[v]|0;x=w&255;y=x|32;if(w<<24>>24==0){q=v;r=y;break}else{s=v;t=x;u=y}}}}while(0);if((r|0)!=(k&255|0)){break}p=q+1|0;o=f+1|0;u=a[p]|0;if(u<<24>>24==0){l=o;m=0;n=15;break}else{g=p;f=o;h=u}}if((n|0)==15){n=0;if(m<<24>>24==(a[l]|0)){break}}h=SGb(d|0)|0;f=d+(h+1)|0;do{if((a[f]|0)==0){g=a[d+(h+2)|0]|0;if((g&255)>>>0>128>>>0){z=d+(h+3)|0;break}else{z=d+(h+3+(((128-(g&255)|0)>>>2)*5|0))|0;break}}else{z=f}}while(0);if((a[z]|0)==0){j=-1;n=24;break}else{d=z}}if((n|0)==24){return j|0}if((a[d]|0)==0){e=d;break}else{A=d}while(1){f=A+((SGb(A|0)|0)+1)|0;if((a[f]|0)==0){e=f;break}else{A=f}}}}while(0);j=e+1-1488192|0;return j|0}function qGb(a){a=a|0;return 0}function rGb(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;l=i;i=i+8|0;m=l|0;n=m;o=i;i=i+4|0;i=i+7&-8;p=i;i=i+4|0;i=i+7&-8;q=i;i=i+4|0;i=i+7&-8;r=i;i=i+4|0;i=i+7&-8;s=f;f=s&65535;t=s>>>16;s=t+1|0;u=f+1|0;c[m>>2]=0;c[m+4>>2]=0;m=a[1488192+t|0]|0;if((g|0)==0){v=0;i=l;return v|0}w=c[g>>2]|0;if((w|0)==0){v=0;i=l;return v|0}x=c[h>>2]|0;if((x|0)==0){v=0;i=l;return v|0}y=m&255;z=y+128|0;A=t+2|0;t=y&3;B=t^1;C=t^2;D=t^3;E=y&1;F=E^1;G=(y-196|0)>>>0<2>>>0;H=E|2;I=F|2;J=m<<24>>24==-38;K=m<<24>>24==-40;m=d[1488192+f|0]|0;L=m-192|0;M=L>>>0>8>>>0;N=f;O=2113792+L|0;L=m+128|0;P=128-m|0;Q=f+2|0;f=r|0;r=m&1;R=r^1;S=r|2;T=R|2;U=m&3;V=U^1;W=U^2;X=U^3;Y=(y-192|0)>>>0<7>>>0;Z=0;_=w;w=x;a:while(1){x=a[_]|0;$=x&255;b:do{if(x<<24>>24<0|Y){switch(y|0){case 200:{aa=vGb(o,_,w,n)|0;if((aa|0)==0){ba=1}else if((aa|0)==(-1|0)){ca=84;da=114;break a}else if((aa|0)==(-2|0)){ea=22;break a}else{ba=aa}fa=ba;ga=c[o>>2]|0;da=90;break b;break};case 192:case 195:{if(w>>>0<4>>>0){ea=22;break a}ha=d[_+B|0]<<16|d[_+t|0]<<24|d[_+C|0]<<8|d[_+D|0];da=14;break};case 208:{if(w>>>0<2>>>0){ea=22;break a}aa=d[_+1|0]|0;if(x<<24>>24==-114){if((aa-161|0)>>>0>62>>>0){ca=84;da=114;break a}fa=2;ga=aa+65216|0;da=90;break b}else{ia=$-161|0;ja=aa-161|0;if(ia>>>0>83>>>0|ja>>>0>93>>>0){ca=84;da=114;break a}aa=b[880368+(ia*188|0)+(ja<<1)>>1]|0;if(aa<<16>>16==0){ca=84;da=114;break a}else{fa=2;ga=aa&65535;da=90;break b}}break};case 209:{if(($-161|0)>>>0<63>>>0){fa=1;ga=$+65216|0;da=90;break b}if(w>>>0<2>>>0){ea=22;break a}aa=a[_+1|0]|0;ja=aa&255;ia=$-129|0;if(ia>>>0<31>>>0){ka=ia}else{if(!(($-224|0)>>>0<16>>>0)){ca=84;da=114;break a}ka=$-193|0}ia=ka<<1;la=ja-64|0;if(la>>>0<95>>>0){if(aa<<24>>24==127){ca=84;da=114;break a}ma=la+(aa<<24>>24>>7<<24>>24)|0;na=ia}else{aa=ja-159|0;la=aa>>>0<94>>>0;ma=la?aa:ja;na=ia|la&1}la=b[880368+(na*188|0)+(ma<<1)>>1]|0;if(la<<16>>16==0){ca=84;da=114;break a}else{fa=2;ga=la&65535;da=90;break b}break};case 196:case 197:case 194:case 193:{if(w>>>0<2>>>0){ea=22;break a}la=d[_+E|0]<<8|d[_+F|0];if((la-56320|0)>>>0<1024>>>0){ca=84;da=114;break a}if(!((la-55296|0)>>>0<1024>>>0)){fa=2;ga=la;da=90;break b}if(G){ca=84;da=114;break a}if(w>>>0<4>>>0){ea=22;break a}ia=(d[_+H|0]<<8|d[_+I|0])-56320|0;if(ia>>>0>1023>>>0){ca=84;da=114;break a}fa=4;ga=(la<<10)-56557568+ia|0;da=90;break b;break};case 217:case 216:{break};case 199:{ca=84;da=114;break a;break};case 218:{if((x&255)>>>0<161>>>0){ca=84;da=114;break a}break};case 198:{if(w>>>0<4>>>0){ea=22;break a}ha=c[_>>2]|0;da=14;break};case 232:{if(w>>>0<2>>>0){ea=22;break a}ia=a[_+1|0]|0;la=ia&255;ja=$-161|0;aa=la-161|0;if(!(ja>>>0>92>>>0|aa>>>0>93>>>0)){oa=b[862376+(ja*188|0)+(aa<<1)>>1]|0;if(oa<<16>>16==0){ca=84;da=114;break a}else{fa=2;ga=oa&65535;da=90;break b}}oa=$-129|0;if(oa>>>0>92>>>0){ca=84;da=114;break a}if(oa>>>0>68>>>0&(ia&255)>>>0>82>>>0){ca=84;da=114;break a}ia=la-65|0;do{if(ia>>>0<26>>>0){pa=ia}else{if((la-97|0)>>>0<26>>>0){pa=la-71|0;break}if(!((la-129|0)>>>0<126>>>0)){ca=84;da=114;break a}pa=la-77|0}}while(0);if(oa>>>0<32>>>0){qa=oa*178|0}else{qa=(ja*84|0)+5696|0}la=pa+44032+qa|0;if(la>>>0<44032>>>0){fa=2;ga=la;da=90;break b}else{ra=la;sa=44032}while(1){la=ra-sa|0;ia=0;aa=0;while(1){ta=ia;ua=0;do{ta=(((e[862376+(aa*188|0)+(ua<<1)>>1]|0)-sa|0)>>>0<=la>>>0)+ta|0;ua=ua+1|0;}while((ua|0)<94);ua=aa+1|0;if((ua|0)<93){ia=ta;aa=ua}else{break}}aa=ra+1|0;ia=ta+ra|0;if(aa>>>0>ia>>>0){fa=2;ga=ia;da=90;break b}else{ra=ia;sa=aa}}break};case 224:{if(w>>>0<2>>>0){ea=22;break a}ja=d[_+1|0]|0;oa=ja-64|0;if(oa>>>0>190>>>0|(ja-127|0)>>>0<34>>>0){ca=84;da=114;break a}aa=oa>>>0>62>>>0?ja-98|0:oa;oa=$-161|0;if(!(oa>>>0>88>>>0)){ja=e[1703720+(oa*314|0)+(aa<<1)>>1]|0;do{if((oa|0)==39){if((aa|0)==60|(aa|0)==58){va=131072;break}va=((aa|0)==66)<<17}else{va=0}}while(0);oa=va|ja;if((oa|0)==0){ca=84;da=114;break a}else{fa=2;ga=oa;da=90;break b}}oa=$-135|0;if(oa>>>0>119>>>0){ca=84;da=114;break a}ia=aa+(((x&255)>>>0<161>>>0?oa:$-224|0)*157|0)|0;oa=e[931720+(ia<<1)>>1]|0;la=oa|(((e[931720+((ia>>>4)+4867<<1)>>1]|0)>>>((ia&15)>>>0)|0)%2|0)<<17;if((la&-65792|0)!=56320){if((la|0)==0){ca=84;da=114;break a}else{fa=2;ga=la;da=90;break b}}if(M){wa=2}else{wa=a[O]|0}if(wa>>>0>(c[k>>2]|0)>>>0){ca=7;da=114;break a}c[p>>2]=2285568+(oa&255);c[q>>2]=4;xa=(rGb(N,p,q,j,k)|0)+Z|0;ya=2;break b;break};default:{if($>>>0<z>>>0){fa=1;ga=$;da=90;break b}oa=$-z|0;la=(oa*5|0)>>>2;ia=oa<<1&6;oa=d[1488192+(A+la)|0]<<8-ia&1023|(d[1488192+(la+s)|0]|0)>>>(ia>>>0);ia=(oa|0)==0?$:e[856632+(oa<<1)>>1]|0;if((ia|0)==1){ca=84;da=114;break a}else{fa=1;ga=ia;da=90;break b}}}if((da|0)==14){da=0;if((ha-55296|0)>>>0<2048>>>0|ha>>>0>1114111>>>0){ca=84;da=114;break a}else{fa=4;ga=ha;da=90;break}}ia=$-129|0;if(ia>>>0>125>>>0){ca=84;da=114;break a}if(w>>>0<2>>>0){ea=22;break a}oa=a[_+1|0]|0;la=oa&255;if((oa&255)>>>0<161>>>0&J){ca=84;da=114;break a}ua=la-64|0;if(!(ua>>>0>190>>>0|oa<<24>>24==127)){fa=2;ga=e[987056+(ia*380|0)+((ua>>>0>63>>>0?la-65|0:ua)<<1)>>1]|0;da=90;break}if(!((la-48|0)>>>0<10>>>0&K)){ca=84;da=114;break a}if(w>>>0<4>>>0){ea=22;break a}ua=(d[_+2|0]|0)-129|0;if(ua>>>0>126>>>0){ca=84;da=114;break a}oa=(d[_+3|0]|0)-48|0;if(oa>>>0>9>>>0){ca=84;da=114;break a}za=((la+(ia*10|0)|0)*1260|0)-60352+(ua*10|0)+oa|0;oa=0;while(1){ua=za-oa|0;ia=0;la=0;while(1){Aa=ia;Ba=0;do{Aa=(((e[987056+(la*380|0)+(Ba<<1)>>1]|0)-oa|0)>>>0<=ua>>>0)+Aa|0;Ba=Ba+1|0;}while((Ba|0)<190);Ba=la+1|0;if((Ba|0)<126){ia=Aa;la=Ba}else{break}}la=za+1|0;ia=Aa+za|0;if(la>>>0>ia>>>0){fa=4;ga=ia;da=90;break}else{za=ia;oa=la}}}else{fa=1;ga=$;da=90}}while(0);c:do{if((da|0)==90){da=0;switch(m|0){case 198:{if((c[k>>2]|0)>>>0<4>>>0){ca=7;da=114;break a}$=c[j>>2]|0;c[$>>2]=ga;c[j>>2]=$+4;c[k>>2]=(c[k>>2]|0)-4;xa=Z;ya=fa;break c;break};case 200:{if((c[k>>2]|0)>>>0<4>>>0){$=xGb(f,ga)|0;if((c[k>>2]|0)>>>0<$>>>0){ca=7;da=114;break a}x=c[j>>2]|0;UGb(x|0,f|0,$)|0;Ca=$;Da=x}else{x=c[j>>2]|0;Ca=xGb(x,ga)|0;Da=x}c[j>>2]=Da+Ca;c[k>>2]=(c[k>>2]|0)-Ca;xa=Z;ya=fa;break c;break};case 199:{if(ga>>>0>127>>>0){Ea=Z;da=99}else{Fa=Z;Ga=ga}break};case 192:case 195:{if((c[k>>2]|0)>>>0<4>>>0){ca=7;da=114;break a}x=c[j>>2]|0;a[x+U|0]=ga>>>24;a[x+V|0]=ga>>>16;a[x+W|0]=ga>>>8;a[x+X|0]=ga;c[j>>2]=x+4;c[k>>2]=(c[k>>2]|0)-4;xa=Z;ya=fa;break c;break};case 196:case 197:case 194:case 193:{if(ga>>>0<65536>>>0|G){x=ga>>>0>65535>>>0?65533:ga;if((c[k>>2]|0)>>>0<2>>>0){ca=7;da=114;break a}$=c[j>>2]|0;a[$+r|0]=x>>>8;a[$+R|0]=x;c[j>>2]=$+2;c[k>>2]=(c[k>>2]|0)-2;xa=Z;ya=fa;break c}else{if((c[k>>2]|0)>>>0<4>>>0){ca=7;da=114;break a}$=ga-65536|0;x=c[j>>2]|0;a[x+r|0]=$>>>18|216;a[x+R|0]=$>>>10;a[x+S|0]=$>>>8&3|220;a[x+T|0]=$;c[j>>2]=x+4;c[k>>2]=(c[k>>2]|0)-4;xa=Z;ya=fa;break c}break};default:{Fa=Z;Ga=ga}}d:while(1){if((da|0)==99){da=0;Fa=Ea+1|0;Ga=42}if((c[k>>2]|0)==0){ca=7;da=114;break a}if(Ga>>>0<L>>>0){Ha=Ga&255;break}else{Ia=0}while(1){if(!(Ia>>>0<P>>>0)){Ea=Fa;da=99;continue d}x=(Ia*5|0)>>>2;$=Ia<<1&6;if((Ga|0)==(e[856632+((d[1488192+(Q+x)|0]<<8-$&1023|(d[1488192+(x+u)|0]|0)>>>($>>>0))<<1)>>1]|0)){da=105;break d}else{Ia=Ia+1|0}}}if((da|0)==105){da=0;Ha=Ia+128&255}$=c[j>>2]|0;c[j>>2]=$+1;a[$]=Ha;c[k>>2]=(c[k>>2]|0)-1;xa=Fa;ya=fa}}while(0);$=(c[g>>2]|0)+ya|0;c[g>>2]=$;x=w-ya|0;c[h>>2]=x;if((w|0)==(ya|0)){v=xa;da=116;break}else{Z=xa;_=$;w=x}}if((da|0)==114){ea=ca}else if((da|0)==116){i=l;return v|0}c[(ld()|0)>>2]=ea;v=-1;i=l;return v|0}function sGb(a,b){a=+a;b=b|0;return+(+JGb(a,b))}function tGb(a,b){a=+a;b=b|0;return+(+uGb(a,b))}function uGb(a,b){a=+a;b=b|0;var d=0.0,e=0,f=0.0,h=0;do{if((b|0)>127){d=a*1.7014118346046923e+38;e=b-127|0;if((e|0)<=127){f=d;h=e;break}e=b-254|0;f=d*1.7014118346046923e+38;h=(e|0)>127?127:e}else{if(!((b|0)<-126)){f=a;h=b;break}d=a*1.1754943508222875e-38;e=b+126|0;if(!((e|0)<-126)){f=d;h=e;break}e=b+252|0;f=d*1.1754943508222875e-38;h=(e|0)<-126?-126:e}}while(0);return+(f*(c[k>>2]=(h<<23)+1065353216,+g[k>>2]))}function vGb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+8|0;h=g|0;c[h>>2]=b;j=((f|0)==0?4977208:f)|0;f=c[j>>2]|0;a:do{if((d|0)==0){if((f|0)==0){k=0}else{break}i=g;return k|0}else{if((b|0)==0){l=h;c[h>>2]=l;m=l}else{m=b}if((e|0)==0){k=-2;i=g;return k|0}do{if((f|0)==0){l=a[d]|0;n=l&255;if(l<<24>>24>-1){c[m>>2]=n;k=l<<24>>24!=0|0;i=g;return k|0}else{l=n-194|0;if(l>>>0>50>>>0){break a}o=d+1|0;p=c[2360064+(l<<2)>>2]|0;q=e-1|0;break}}else{o=d;p=f;q=e}}while(0);b:do{if((q|0)==0){r=p}else{l=a[o]|0;n=(l&255)>>>3;if((n-16|n+(p>>26))>>>0>7>>>0){break a}else{s=o;t=p;u=q;v=l}while(1){s=s+1|0;t=(v&255)-128|t<<6;u=u-1|0;if((t|0)>=0){break}if((u|0)==0){r=t;break b}v=a[s]|0;if(((v&255)-128|0)>>>0>63>>>0){break a}}c[j>>2]=0;c[m>>2]=t;k=e-u|0;i=g;return k|0}}while(0);c[j>>2]=r;k=-2;i=g;return k|0}}while(0);c[j>>2]=0;c[(ld()|0)>>2]=84;k=-1;i=g;return k|0}function wGb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((b|0)==0){f=1;return f|0}if(d>>>0<128>>>0){a[b]=d;f=1;return f|0}if(d>>>0<2048>>>0){a[b]=d>>>6|192;a[b+1|0]=d&63|128;f=2;return f|0}if(d>>>0<55296>>>0|(d-57344|0)>>>0<8192>>>0){a[b]=d>>>12|224;a[b+1|0]=d>>>6&63|128;a[b+2|0]=d&63|128;f=3;return f|0}if((d-65536|0)>>>0<1048576>>>0){a[b]=d>>>18|240;a[b+1|0]=d>>>12&63|128;a[b+2|0]=d>>>6&63|128;a[b+3|0]=d&63|128;f=4;return f|0}else{c[(ld()|0)>>2]=84;f=-1;return f|0}return 0}function xGb(a,b){a=a|0;b=b|0;var c=0;if((a|0)==0){c=0}else{c=wGb(a,b,0)|0}return c|0}function yGb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;do{if(a>>>0<245>>>0){if(a>>>0<11>>>0){b=16}else{b=a+11&-8}d=b>>>3;e=c[2300916]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=9203704+(h<<2)|0;j=9203704+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[2300916]=e&~(1<<g)}else{if(l>>>0<(c[2300920]|0)>>>0){Cd();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{Cd();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(!(b>>>0>(c[2300918]|0)>>>0)){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=9203704+(p<<2)|0;m=9203704+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[2300916]=e&~(1<<r)}else{if(l>>>0<(c[2300920]|0)>>>0){Cd();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{Cd();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[2300918]|0;if((l|0)!=0){q=c[2300921]|0;d=l>>>3;l=d<<1;f=9203704+(l<<2)|0;k=c[2300916]|0;h=1<<d;do{if((k&h|0)==0){c[2300916]=k|h;s=f;t=9203704+(l+2<<2)|0}else{d=9203704+(l+2<<2)|0;g=c[d>>2]|0;if(!(g>>>0<(c[2300920]|0)>>>0)){s=g;t=d;break}Cd();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[2300918]=m;c[2300921]=e;n=i;return n|0}l=c[2300917]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[9203968+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[2300920]|0;if(r>>>0<i>>>0){Cd();return 0}e=r+b|0;m=e;if(!(r>>>0<e>>>0)){Cd();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){Cd();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){Cd();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){Cd();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{Cd();return 0}}}while(0);a:do{if((e|0)!=0){f=c[d+28>>2]|0;i=9203968+(f<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[2300917]=c[2300917]&~(1<<f);break a}else{if(e>>>0<(c[2300920]|0)>>>0){Cd();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break a}}}while(0);if(v>>>0<(c[2300920]|0)>>>0){Cd();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16>>>0){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[2300918]|0;if((f|0)!=0){e=c[2300921]|0;i=f>>>3;f=i<<1;q=9203704+(f<<2)|0;k=c[2300916]|0;g=1<<i;do{if((k&g|0)==0){c[2300916]=k|g;y=q;z=9203704+(f+2<<2)|0}else{i=9203704+(f+2<<2)|0;l=c[i>>2]|0;if(!(l>>>0<(c[2300920]|0)>>>0)){y=l;z=i;break}Cd();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[2300918]=p;c[2300921]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231>>>0){o=-1;break}f=a+11|0;g=f&-8;k=c[2300917]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215>>>0){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[9203968+(A<<2)>>2]|0;b:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break b}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=k&(i|-i);if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[9203968+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(!(J>>>0<((c[2300918]|0)-g|0)>>>0)){o=g;break}q=K;m=c[2300920]|0;if(q>>>0<m>>>0){Cd();return 0}p=q+g|0;k=p;if(!(q>>>0<p>>>0)){Cd();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){Cd();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){Cd();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){Cd();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{Cd();return 0}}}while(0);c:do{if((e|0)!=0){i=c[K+28>>2]|0;m=9203968+(i<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[2300917]=c[2300917]&~(1<<i);break c}else{if(e>>>0<(c[2300920]|0)>>>0){Cd();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break c}}}while(0);if(L>>>0<(c[2300920]|0)>>>0){Cd();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16>>>0){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256>>>0){e=i<<1;m=9203704+(e<<2)|0;r=c[2300916]|0;j=1<<i;do{if((r&j|0)==0){c[2300916]=r|j;O=m;P=9203704+(e+2<<2)|0}else{i=9203704+(e+2<<2)|0;d=c[i>>2]|0;if(!(d>>>0<(c[2300920]|0)>>>0)){O=d;P=i;break}Cd();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215>>>0){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=9203968+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[2300917]|0;l=1<<Q;if((m&l|0)==0){c[2300917]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=151;break}else{l=l<<1;m=j}}if((T|0)==151){if(S>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[2300920]|0;if(m>>>0<i>>>0){Cd();return 0}if(j>>>0<i>>>0){Cd();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[2300918]|0;if(!(o>>>0>K>>>0)){S=K-o|0;J=c[2300921]|0;if(S>>>0>15>>>0){R=J;c[2300921]=R+o;c[2300918]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[2300918]=0;c[2300921]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[2300919]|0;if(o>>>0<J>>>0){S=J-o|0;c[2300919]=S;J=c[2300922]|0;K=J;c[2300922]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[1219208]|0)==0){J=db(30)|0;if((J-1&J|0)==0){c[1219210]=J;c[1219209]=J;c[1219211]=-1;c[1219212]=-1;c[1219213]=0;c[2301027]=0;c[1219208]=(ee(0)|0)&-16^1431655768;break}else{Cd();return 0}}}while(0);J=o+48|0;S=c[1219210]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(!(S>>>0>o>>>0)){n=0;return n|0}O=c[2301026]|0;do{if((O|0)!=0){P=c[2301024]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);d:do{if((c[2301027]&4|0)==0){O=c[2300922]|0;e:do{if((O|0)==0){T=181}else{L=O;P=9204112;while(1){U=P|0;M=c[U>>2]|0;if(!(M>>>0>L>>>0)){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=181;break e}else{P=M}}if((P|0)==0){T=181;break}L=R-(c[2300919]|0)&Q;if(!(L>>>0<2147483647>>>0)){W=0;break}m=jd(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=190}}while(0);do{if((T|0)==181){O=jd(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[1219209]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[2301024]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647>>>0)){W=0;break}m=c[2301026]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=jd($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=190}}while(0);f:do{if((T|0)==190){m=-_|0;if(!((X|0)==-1)){aa=Y;ba=X;T=201;break d}do{if((Z|0)!=-1&_>>>0<2147483647>>>0&_>>>0<J>>>0){g=c[1219210]|0;O=K-_+g&-g;if(!(O>>>0<2147483647>>>0)){ca=_;break}if((jd(O|0)|0)==-1){jd(m|0)|0;W=Y;break f}else{ca=O+_|0;break}}else{ca=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ca;ba=Z;T=201;break d}}}while(0);c[2301027]=c[2301027]|4;da=W;T=198}else{da=0;T=198}}while(0);do{if((T|0)==198){if(!(S>>>0<2147483647>>>0)){break}W=jd(S|0)|0;Z=jd(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ca=Z-W|0;Z=ca>>>0>(o+40|0)>>>0;Y=Z?W:-1;if(!((Y|0)==-1)){aa=Z?ca:da;ba=Y;T=201}}}while(0);do{if((T|0)==201){da=(c[2301024]|0)+aa|0;c[2301024]=da;if(da>>>0>(c[2301025]|0)>>>0){c[2301025]=da}da=c[2300922]|0;g:do{if((da|0)==0){S=c[2300920]|0;if((S|0)==0|ba>>>0<S>>>0){c[2300920]=ba}c[2301028]=ba;c[2301029]=aa;c[2301031]=0;c[2300925]=c[1219208];c[2300924]=-1;S=0;do{Y=S<<1;ca=9203704+(Y<<2)|0;c[9203704+(Y+3<<2)>>2]=ca;c[9203704+(Y+2<<2)>>2]=ca;S=S+1|0;}while(S>>>0<32>>>0);S=ba+8|0;if((S&7|0)==0){ea=0}else{ea=-S&7}S=aa-40-ea|0;c[2300922]=ba+ea;c[2300919]=S;c[ba+(ea+4)>>2]=S|1;c[ba+(aa-36)>>2]=40;c[2300923]=c[1219212]}else{S=9204112;while(1){fa=c[S>>2]|0;ga=S+4|0;ha=c[ga>>2]|0;if((ba|0)==(fa+ha|0)){T=213;break}ca=c[S+8>>2]|0;if((ca|0)==0){break}else{S=ca}}do{if((T|0)==213){if((c[S+12>>2]&8|0)!=0){break}ca=da;if(!(ca>>>0>=fa>>>0&ca>>>0<ba>>>0)){break}c[ga>>2]=ha+aa;Y=(c[2300919]|0)+aa|0;Z=da+8|0;if((Z&7|0)==0){ia=0}else{ia=-Z&7}Z=Y-ia|0;c[2300922]=ca+ia;c[2300919]=Z;c[ca+(ia+4)>>2]=Z|1;c[ca+(Y+4)>>2]=40;c[2300923]=c[1219212];break g}}while(0);if(ba>>>0<(c[2300920]|0)>>>0){c[2300920]=ba}S=ba+aa|0;Y=9204112;while(1){ja=Y|0;if((c[ja>>2]|0)==(S|0)){T=223;break}ca=c[Y+8>>2]|0;if((ca|0)==0){break}else{Y=ca}}do{if((T|0)==223){if((c[Y+12>>2]&8|0)!=0){break}c[ja>>2]=ba;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ba+8|0;if((S&7|0)==0){ka=0}else{ka=-S&7}S=ba+(aa+8)|0;if((S&7|0)==0){la=0}else{la=-S&7}S=ba+(la+aa)|0;ca=S;Z=ka+o|0;W=ba+Z|0;_=W;K=S-(ba+ka)-o|0;c[ba+(ka+4)>>2]=o|3;do{if((ca|0)==(c[2300922]|0)){J=(c[2300919]|0)+K|0;c[2300919]=J;c[2300922]=_;c[ba+(Z+4)>>2]=J|1}else{if((ca|0)==(c[2300921]|0)){J=(c[2300918]|0)+K|0;c[2300918]=J;c[2300921]=_;c[ba+(Z+4)>>2]=J|1;c[ba+(J+Z)>>2]=J;break}J=aa+4|0;X=c[ba+(J+la)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;h:do{if(X>>>0<256>>>0){U=c[ba+((la|8)+aa)>>2]|0;Q=c[ba+(aa+12+la)>>2]|0;R=9203704+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[2300920]|0)>>>0){Cd();return 0}if((c[U+12>>2]|0)==(ca|0)){break}Cd();return 0}}while(0);if((Q|0)==(U|0)){c[2300916]=c[2300916]&~(1<<V);break}do{if((Q|0)==(R|0)){ma=Q+8|0}else{if(Q>>>0<(c[2300920]|0)>>>0){Cd();return 0}m=Q+8|0;if((c[m>>2]|0)==(ca|0)){ma=m;break}Cd();return 0}}while(0);c[U+12>>2]=Q;c[ma>>2]=U}else{R=S;m=c[ba+((la|24)+aa)>>2]|0;P=c[ba+(aa+12+la)>>2]|0;do{if((P|0)==(R|0)){O=la|16;g=ba+(J+O)|0;L=c[g>>2]|0;if((L|0)==0){e=ba+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){na=0;break}else{oa=O;pa=e}}else{oa=L;pa=g}while(1){g=oa+20|0;L=c[g>>2]|0;if((L|0)!=0){oa=L;pa=g;continue}g=oa+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{oa=L;pa=g}}if(pa>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[pa>>2]=0;na=oa;break}}else{g=c[ba+((la|8)+aa)>>2]|0;if(g>>>0<(c[2300920]|0)>>>0){Cd();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){Cd();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;na=P;break}else{Cd();return 0}}}while(0);if((m|0)==0){break}P=c[ba+(aa+28+la)>>2]|0;U=9203968+(P<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=na;if((na|0)!=0){break}c[2300917]=c[2300917]&~(1<<P);break h}else{if(m>>>0<(c[2300920]|0)>>>0){Cd();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=na}else{c[m+20>>2]=na}if((na|0)==0){break h}}}while(0);if(na>>>0<(c[2300920]|0)>>>0){Cd();return 0}c[na+24>>2]=m;R=la|16;P=c[ba+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[na+16>>2]=P;c[P+24>>2]=na;break}}}while(0);P=c[ba+(J+R)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[na+20>>2]=P;c[P+24>>2]=na;break}}}while(0);qa=ba+(($|la)+aa)|0;ra=$+K|0}else{qa=ca;ra=K}J=qa+4|0;c[J>>2]=c[J>>2]&-2;c[ba+(Z+4)>>2]=ra|1;c[ba+(ra+Z)>>2]=ra;J=ra>>>3;if(ra>>>0<256>>>0){V=J<<1;X=9203704+(V<<2)|0;P=c[2300916]|0;m=1<<J;do{if((P&m|0)==0){c[2300916]=P|m;sa=X;ta=9203704+(V+2<<2)|0}else{J=9203704+(V+2<<2)|0;U=c[J>>2]|0;if(!(U>>>0<(c[2300920]|0)>>>0)){sa=U;ta=J;break}Cd();return 0}}while(0);c[ta>>2]=_;c[sa+12>>2]=_;c[ba+(Z+8)>>2]=sa;c[ba+(Z+12)>>2]=X;break}V=W;m=ra>>>8;do{if((m|0)==0){ua=0}else{if(ra>>>0>16777215>>>0){ua=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;ua=ra>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=9203968+(ua<<2)|0;c[ba+(Z+28)>>2]=ua;c[ba+(Z+20)>>2]=0;c[ba+(Z+16)>>2]=0;X=c[2300917]|0;Q=1<<ua;if((X&Q|0)==0){c[2300917]=X|Q;c[m>>2]=V;c[ba+(Z+24)>>2]=m;c[ba+(Z+12)>>2]=V;c[ba+(Z+8)>>2]=V;break}if((ua|0)==31){va=0}else{va=25-(ua>>>1)|0}Q=ra<<va;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ra|0)){break}wa=X+16+(Q>>>31<<2)|0;m=c[wa>>2]|0;if((m|0)==0){T=296;break}else{Q=Q<<1;X=m}}if((T|0)==296){if(wa>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[wa>>2]=V;c[ba+(Z+24)>>2]=X;c[ba+(Z+12)>>2]=V;c[ba+(Z+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[2300920]|0;if(X>>>0<$>>>0){Cd();return 0}if(m>>>0<$>>>0){Cd();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ba+(Z+8)>>2]=m;c[ba+(Z+12)>>2]=X;c[ba+(Z+24)>>2]=0;break}}}while(0);n=ba+(ka|8)|0;return n|0}}while(0);Y=da;Z=9204112;while(1){xa=c[Z>>2]|0;if(!(xa>>>0>Y>>>0)){ya=c[Z+4>>2]|0;za=xa+ya|0;if(za>>>0>Y>>>0){break}}Z=c[Z+8>>2]|0}Z=xa+(ya-39)|0;if((Z&7|0)==0){Aa=0}else{Aa=-Z&7}Z=xa+(ya-47+Aa)|0;W=Z>>>0<(da+16|0)>>>0?Y:Z;Z=W+8|0;_=ba+8|0;if((_&7|0)==0){Ba=0}else{Ba=-_&7}_=aa-40-Ba|0;c[2300922]=ba+Ba;c[2300919]=_;c[ba+(Ba+4)>>2]=_|1;c[ba+(aa-36)>>2]=40;c[2300923]=c[1219212];c[W+4>>2]=27;c[Z>>2]=c[2301028];c[Z+4>>2]=c[2301029];c[Z+8>>2]=c[2301030];c[Z+12>>2]=c[2301031];c[2301028]=ba;c[2301029]=aa;c[2301031]=0;c[2301030]=Z;Z=W+28|0;c[Z>>2]=7;if((W+32|0)>>>0<za>>>0){_=Z;while(1){Z=_+4|0;c[Z>>2]=7;if((_+8|0)>>>0<za>>>0){_=Z}else{break}}}if((W|0)==(Y|0)){break}_=W-da|0;Z=Y+(_+4)|0;c[Z>>2]=c[Z>>2]&-2;c[da+4>>2]=_|1;c[Y+_>>2]=_;Z=_>>>3;if(_>>>0<256>>>0){K=Z<<1;ca=9203704+(K<<2)|0;S=c[2300916]|0;m=1<<Z;do{if((S&m|0)==0){c[2300916]=S|m;Ca=ca;Da=9203704+(K+2<<2)|0}else{Z=9203704+(K+2<<2)|0;Q=c[Z>>2]|0;if(!(Q>>>0<(c[2300920]|0)>>>0)){Ca=Q;Da=Z;break}Cd();return 0}}while(0);c[Da>>2]=da;c[Ca+12>>2]=da;c[da+8>>2]=Ca;c[da+12>>2]=ca;break}K=da;m=_>>>8;do{if((m|0)==0){Ea=0}else{if(_>>>0>16777215>>>0){Ea=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;W=(Y+520192|0)>>>16&4;Z=Y<<W;Y=(Z+245760|0)>>>16&2;Q=14-(W|S|Y)+(Z<<Y>>>15)|0;Ea=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=9203968+(Ea<<2)|0;c[da+28>>2]=Ea;c[da+20>>2]=0;c[da+16>>2]=0;ca=c[2300917]|0;Q=1<<Ea;if((ca&Q|0)==0){c[2300917]=ca|Q;c[m>>2]=K;c[da+24>>2]=m;c[da+12>>2]=da;c[da+8>>2]=da;break}if((Ea|0)==31){Fa=0}else{Fa=25-(Ea>>>1)|0}Q=_<<Fa;ca=c[m>>2]|0;while(1){if((c[ca+4>>2]&-8|0)==(_|0)){break}Ga=ca+16+(Q>>>31<<2)|0;m=c[Ga>>2]|0;if((m|0)==0){T=331;break}else{Q=Q<<1;ca=m}}if((T|0)==331){if(Ga>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[Ga>>2]=K;c[da+24>>2]=ca;c[da+12>>2]=da;c[da+8>>2]=da;break}}Q=ca+8|0;_=c[Q>>2]|0;m=c[2300920]|0;if(ca>>>0<m>>>0){Cd();return 0}if(_>>>0<m>>>0){Cd();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[da+8>>2]=_;c[da+12>>2]=ca;c[da+24>>2]=0;break}}}while(0);da=c[2300919]|0;if(!(da>>>0>o>>>0)){break}_=da-o|0;c[2300919]=_;da=c[2300922]|0;Q=da;c[2300922]=Q+o;c[Q+(o+4)>>2]=_|1;c[da+4>>2]=o|3;n=da+8|0;return n|0}}while(0);c[(ld()|0)>>2]=12;n=0;return n|0}function zGb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[2300920]|0;if(b>>>0<e>>>0){Cd()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){Cd()}h=f&-8;i=a+(h-8)|0;j=i;a:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){Cd()}if((n|0)==(c[2300921]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[2300918]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256>>>0){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=9203704+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){Cd()}if((c[k+12>>2]|0)==(n|0)){break}Cd()}}while(0);if((s|0)==(k|0)){c[2300916]=c[2300916]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){Cd()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}Cd()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){Cd()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){Cd()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){Cd()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{Cd()}}}while(0);if((p|0)==0){q=n;r=o;break}v=c[a+(l+28)>>2]|0;m=9203968+(v<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[2300917]=c[2300917]&~(1<<v);q=n;r=o;break a}else{if(p>>>0<(c[2300920]|0)>>>0){Cd()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break a}}}while(0);if(A>>>0<(c[2300920]|0)>>>0){Cd()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[2300920]|0)>>>0){Cd()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[2300920]|0)>>>0){Cd()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(!(d>>>0<i>>>0)){Cd()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){Cd()}do{if((e&2|0)==0){if((j|0)==(c[2300922]|0)){B=(c[2300919]|0)+r|0;c[2300919]=B;c[2300922]=q;c[q+4>>2]=B|1;if((q|0)!=(c[2300921]|0)){return}c[2300921]=0;c[2300918]=0;return}if((j|0)==(c[2300921]|0)){B=(c[2300918]|0)+r|0;c[2300918]=B;c[2300921]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;b:do{if(e>>>0<256>>>0){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=9203704+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[2300920]|0)>>>0){Cd()}if((c[u+12>>2]|0)==(j|0)){break}Cd()}}while(0);if((g|0)==(u|0)){c[2300916]=c[2300916]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[2300920]|0)>>>0){Cd()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}Cd()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[2300920]|0)>>>0){Cd()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[2300920]|0)>>>0){Cd()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){Cd()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{Cd()}}}while(0);if((f|0)==0){break}t=c[a+(h+20)>>2]|0;u=9203968+(t<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[2300917]=c[2300917]&~(1<<t);break b}else{if(f>>>0<(c[2300920]|0)>>>0){Cd()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break b}}}while(0);if(E>>>0<(c[2300920]|0)>>>0){Cd()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[2300920]|0)>>>0){Cd()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[2300920]|0)>>>0){Cd()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[2300921]|0)){H=B;break}c[2300918]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256>>>0){d=r<<1;e=9203704+(d<<2)|0;A=c[2300916]|0;E=1<<r;do{if((A&E|0)==0){c[2300916]=A|E;I=e;J=9203704+(d+2<<2)|0}else{r=9203704+(d+2<<2)|0;h=c[r>>2]|0;if(!(h>>>0<(c[2300920]|0)>>>0)){I=h;J=r;break}Cd()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215>>>0){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=9203968+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[2300917]|0;d=1<<K;do{if((r&d|0)==0){c[2300917]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=129;break}else{A=A<<1;J=E}}if((N|0)==129){if(M>>>0<(c[2300920]|0)>>>0){Cd()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[2300920]|0;if(J>>>0<E>>>0){Cd()}if(B>>>0<E>>>0){Cd()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[2300924]|0)-1|0;c[2300924]=q;if((q|0)==0){O=9204120}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[2300924]=-1;return}function AGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==0){d=yGb(b)|0;return d|0}if(b>>>0>4294967231>>>0){c[(ld()|0)>>2]=12;d=0;return d|0}if(b>>>0<11>>>0){e=16}else{e=b+11&-8}f=BGb(a-8|0,e)|0;if((f|0)!=0){d=f+8|0;return d|0}f=yGb(b)|0;if((f|0)==0){d=0;return d|0}e=c[a-4>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;UGb(f|0,a|0,g>>>0<b>>>0?g:b)|0;zGb(a);d=f;return d|0}function BGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=a+4|0;e=c[d>>2]|0;f=e&-8;g=a;h=g+f|0;i=h;j=c[2300920]|0;if(g>>>0<j>>>0){Cd();return 0}k=e&3;if(!((k|0)!=1&g>>>0<h>>>0)){Cd();return 0}l=g+(f|4)|0;m=c[l>>2]|0;if((m&1|0)==0){Cd();return 0}if((k|0)==0){if(b>>>0<256>>>0){n=0;return n|0}do{if(!(f>>>0<(b+4|0)>>>0)){if((f-b|0)>>>0>c[1219210]<<1>>>0){break}else{n=a}return n|0}}while(0);n=0;return n|0}if(!(f>>>0<b>>>0)){k=f-b|0;if(!(k>>>0>15>>>0)){n=a;return n|0}c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|3;c[l>>2]=c[l>>2]|1;EGb(g+b|0,k);n=a;return n|0}if((i|0)==(c[2300922]|0)){k=(c[2300919]|0)+f|0;if(!(k>>>0>b>>>0)){n=0;return n|0}l=k-b|0;c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=l|1;c[2300922]=g+b;c[2300919]=l;n=a;return n|0}if((i|0)==(c[2300921]|0)){l=(c[2300918]|0)+f|0;if(l>>>0<b>>>0){n=0;return n|0}k=l-b|0;if(k>>>0>15>>>0){c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|1;c[g+l>>2]=k;o=g+(l+4)|0;c[o>>2]=c[o>>2]&-2;p=g+b|0;q=k}else{c[d>>2]=e&1|l|2;e=g+(l+4)|0;c[e>>2]=c[e>>2]|1;p=0;q=0}c[2300918]=q;c[2300921]=p;n=a;return n|0}if((m&2|0)!=0){n=0;return n|0}p=(m&-8)+f|0;if(p>>>0<b>>>0){n=0;return n|0}q=p-b|0;e=m>>>3;a:do{if(m>>>0<256>>>0){l=c[g+(f+8)>>2]|0;k=c[g+(f+12)>>2]|0;o=9203704+(e<<1<<2)|0;do{if((l|0)!=(o|0)){if(l>>>0<j>>>0){Cd();return 0}if((c[l+12>>2]|0)==(i|0)){break}Cd();return 0}}while(0);if((k|0)==(l|0)){c[2300916]=c[2300916]&~(1<<e);break}do{if((k|0)==(o|0)){r=k+8|0}else{if(k>>>0<j>>>0){Cd();return 0}s=k+8|0;if((c[s>>2]|0)==(i|0)){r=s;break}Cd();return 0}}while(0);c[l+12>>2]=k;c[r>>2]=l}else{o=h;s=c[g+(f+24)>>2]|0;t=c[g+(f+12)>>2]|0;do{if((t|0)==(o|0)){u=g+(f+20)|0;v=c[u>>2]|0;if((v|0)==0){w=g+(f+16)|0;x=c[w>>2]|0;if((x|0)==0){y=0;break}else{z=x;A=w}}else{z=v;A=u}while(1){u=z+20|0;v=c[u>>2]|0;if((v|0)!=0){z=v;A=u;continue}u=z+16|0;v=c[u>>2]|0;if((v|0)==0){break}else{z=v;A=u}}if(A>>>0<j>>>0){Cd();return 0}else{c[A>>2]=0;y=z;break}}else{u=c[g+(f+8)>>2]|0;if(u>>>0<j>>>0){Cd();return 0}v=u+12|0;if((c[v>>2]|0)!=(o|0)){Cd();return 0}w=t+8|0;if((c[w>>2]|0)==(o|0)){c[v>>2]=t;c[w>>2]=u;y=t;break}else{Cd();return 0}}}while(0);if((s|0)==0){break}t=c[g+(f+28)>>2]|0;l=9203968+(t<<2)|0;do{if((o|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[2300917]=c[2300917]&~(1<<t);break a}else{if(s>>>0<(c[2300920]|0)>>>0){Cd();return 0}k=s+16|0;if((c[k>>2]|0)==(o|0)){c[k>>2]=y}else{c[s+20>>2]=y}if((y|0)==0){break a}}}while(0);if(y>>>0<(c[2300920]|0)>>>0){Cd();return 0}c[y+24>>2]=s;o=c[g+(f+16)>>2]|0;do{if((o|0)!=0){if(o>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[y+16>>2]=o;c[o+24>>2]=y;break}}}while(0);o=c[g+(f+20)>>2]|0;if((o|0)==0){break}if(o>>>0<(c[2300920]|0)>>>0){Cd();return 0}else{c[y+20>>2]=o;c[o+24>>2]=y;break}}}while(0);if(q>>>0<16>>>0){c[d>>2]=p|c[d>>2]&1|2;y=g+(p|4)|0;c[y>>2]=c[y>>2]|1;n=a;return n|0}else{c[d>>2]=c[d>>2]&1|b|2;c[g+(b+4)>>2]=q|3;d=g+(p|4)|0;c[d>>2]=c[d>>2]|1;EGb(g+b|0,q);n=a;return n|0}return 0}function CGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a>>>0<16>>>0?16:a;if((d-1&d|0)==0){e=d}else{a=16;while(1){if(a>>>0<d>>>0){a=a<<1}else{e=a;break}}}if(!((-64-e|0)>>>0>b>>>0)){c[(ld()|0)>>2]=12;f=0;return f|0}if(b>>>0<11>>>0){g=16}else{g=b+11&-8}b=yGb(e+12+g|0)|0;if((b|0)==0){f=0;return f|0}a=b-8|0;d=a;h=e-1|0;do{if((b&h|0)==0){i=d}else{j=b+h&-e;k=j-8|0;l=a;if((k-l|0)>>>0>15>>>0){m=k}else{m=j+(e-8)|0}j=m;k=m-l|0;l=b-4|0;n=c[l>>2]|0;o=(n&-8)-k|0;if((n&3|0)==0){c[m>>2]=(c[a>>2]|0)+k;c[m+4>>2]=o;i=j;break}else{n=m+4|0;c[n>>2]=o|c[n>>2]&1|2;n=m+(o+4)|0;c[n>>2]=c[n>>2]|1;c[l>>2]=k|c[l>>2]&1|2;l=b+(k-4)|0;c[l>>2]=c[l>>2]|1;EGb(d,k);i=j;break}}}while(0);d=i+4|0;b=c[d>>2]|0;do{if((b&3|0)!=0){m=b&-8;if(!(m>>>0>(g+16|0)>>>0)){break}a=m-g|0;e=i;c[d>>2]=g|b&1|2;c[e+(g|4)>>2]=a|3;h=e+(m|4)|0;c[h>>2]=c[h>>2]|1;EGb(e+g|0,a)}}while(0);f=i+8|0;return f|0}function DGb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if((b|0)==8){e=yGb(d)|0}else{f=b>>>2;if((b&3|0)!=0|(f|0)==0){g=22;return g|0}if((f+1073741823&f|0)!=0){g=22;return g|0}if((-64-b|0)>>>0<d>>>0){g=12;return g|0}else{e=CGb(b>>>0<16>>>0?16:b,d)|0;break}}}while(0);if((e|0)==0){g=12;return g|0}c[a>>2]=e;g=0;return g|0}function EGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;a:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[2300920]|0;if(i>>>0<l>>>0){Cd()}if((j|0)==(c[2300921]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[2300918]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256>>>0){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=9203704+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){Cd()}if((c[p+12>>2]|0)==(j|0)){break}Cd()}}while(0);if((q|0)==(p|0)){c[2300916]=c[2300916]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){Cd()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}Cd()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){Cd()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){Cd()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){Cd()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{Cd()}}}while(0);if((m|0)==0){n=j;o=k;break}t=c[d+(28-h)>>2]|0;l=9203968+(t<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[2300917]=c[2300917]&~(1<<t);n=j;o=k;break a}else{if(m>>>0<(c[2300920]|0)>>>0){Cd()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break a}}}while(0);if(y>>>0<(c[2300920]|0)>>>0){Cd()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[2300920]|0)>>>0){Cd()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[2300920]|0)>>>0){Cd()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[2300920]|0;if(e>>>0<a>>>0){Cd()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[2300922]|0)){A=(c[2300919]|0)+o|0;c[2300919]=A;c[2300922]=n;c[n+4>>2]=A|1;if((n|0)!=(c[2300921]|0)){return}c[2300921]=0;c[2300918]=0;return}if((f|0)==(c[2300921]|0)){A=(c[2300918]|0)+o|0;c[2300918]=A;c[2300921]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;b:do{if(z>>>0<256>>>0){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=9203704+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){Cd()}if((c[g+12>>2]|0)==(f|0)){break}Cd()}}while(0);if((t|0)==(g|0)){c[2300916]=c[2300916]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){Cd()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}Cd()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){Cd()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){Cd()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){Cd()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{Cd()}}}while(0);if((m|0)==0){break}l=c[d+(b+28)>>2]|0;g=9203968+(l<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[2300917]=c[2300917]&~(1<<l);break b}else{if(m>>>0<(c[2300920]|0)>>>0){Cd()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break b}}}while(0);if(C>>>0<(c[2300920]|0)>>>0){Cd()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[2300920]|0)>>>0){Cd()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[2300920]|0)>>>0){Cd()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[2300921]|0)){F=A;break}c[2300918]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256>>>0){z=o<<1;y=9203704+(z<<2)|0;C=c[2300916]|0;b=1<<o;do{if((C&b|0)==0){c[2300916]=C|b;G=y;H=9203704+(z+2<<2)|0}else{o=9203704+(z+2<<2)|0;d=c[o>>2]|0;if(!(d>>>0<(c[2300920]|0)>>>0)){G=d;H=o;break}Cd()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215>>>0){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=9203968+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[2300917]|0;z=1<<I;if((o&z|0)==0){c[2300917]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=126;break}else{I=I<<1;J=G}}if((L|0)==126){if(K>>>0<(c[2300920]|0)>>>0){Cd()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[2300920]|0;if(J>>>0<I>>>0){Cd()}if(L>>>0<I>>>0){Cd()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function FGb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0.0,T=0.0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0.0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0.0,ya=0,za=0.0,Aa=0,Ba=0.0,Ca=0,Da=0,Ea=0,Fa=0.0,Ga=0,Ha=0.0,Ia=0.0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0.0,zc=0,Ac=0,Bc=0.0,Cc=0.0,Dc=0.0,Ec=0.0,Fc=0.0,Gc=0.0,Hc=0.0,Ic=0,Jc=0,Kc=0.0,Lc=0,Mc=0;g=i;i=i+512|0;h=g|0;if((e|0)==0){j=-149;k=24}else if((e|0)==1){j=-1074;k=53}else if((e|0)==2){j=-1074;k=53}else{l=0.0;i=g;return+l}e=b+4|0;m=b+100|0;do{n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;o=d[n]|0}else{o=IGb(b)|0}}while((tb(o|0)|0)!=0);do{if((o|0)==45|(o|0)==43){n=1-(((o|0)==45)<<1)|0;p=c[e>>2]|0;if(p>>>0<(c[m>>2]|0)>>>0){c[e>>2]=p+1;s=d[p]|0;t=n;break}else{s=IGb(b)|0;t=n;break}}else{s=o;t=1}}while(0);o=0;n=s;while(1){if((n|32|0)!=(a[1963592+o|0]|0)){u=o;v=n;break}do{if(o>>>0<7>>>0){s=c[e>>2]|0;if(s>>>0<(c[m>>2]|0)>>>0){c[e>>2]=s+1;w=d[s]|0;break}else{w=IGb(b)|0;break}}else{w=n}}while(0);s=o+1|0;if(s>>>0<8>>>0){o=s;n=w}else{u=s;v=w;break}}do{if((u|0)==3){x=23}else if((u|0)!=8){w=(f|0)==0;if(!(u>>>0<4>>>0|w)){if((u|0)==8){break}else{x=23;break}}do{if((u|0)==0){if((v|32|0)==110){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;y=d[n]|0}else{y=IGb(b)|0}if((y|32|0)!=97){break}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;z=d[n]|0}else{z=IGb(b)|0}if((z|32|0)!=110){break}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;A=d[n]|0}else{A=IGb(b)|0}if((A|0)==40){B=1}else{if((c[m>>2]|0)==0){l=+q;i=g;return+l}c[e>>2]=(c[e>>2]|0)-1;l=+q;i=g;return+l}while(1){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;C=d[n]|0}else{C=IGb(b)|0}if(!((C-48|0)>>>0<10>>>0|(C-65|0)>>>0<26>>>0)){if(!((C-97|0)>>>0<26>>>0|(C|0)==95)){break}}B=B+1|0}if((C|0)==41){l=+q;i=g;return+l}n=(c[m>>2]|0)==0;if(!n){c[e>>2]=(c[e>>2]|0)-1}if(w){c[(ld()|0)>>2]=22;HGb(b,0);l=0.0;i=g;return+l}if((B|0)==0|n){l=+q;i=g;return+l}else{D=B}while(1){n=D-1|0;c[e>>2]=(c[e>>2]|0)-1;if((n|0)==0){l=+q;break}else{D=n}}i=g;return+l}do{if((v|0)==48){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;E=d[n]|0}else{E=IGb(b)|0}if((E|32|0)!=120){if((c[m>>2]|0)==0){G=48;break}c[e>>2]=(c[e>>2]|0)-1;G=48;break}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;H=d[n]|0;I=0}else{H=IGb(b)|0;I=0}while(1){if((H|0)==46){x=68;break}else if((H|0)!=48){J=H;K=0;L=0;M=0;N=0;O=I;P=0;R=0;S=1.0;T=0.0;U=0;break}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;H=d[n]|0;I=1;continue}else{H=IGb(b)|0;I=1;continue}}a:do{if((x|0)==68){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;V=d[n]|0}else{V=IGb(b)|0}if((V|0)==48){W=-1;X=-1}else{J=V;K=0;L=0;M=0;N=0;O=I;P=1;R=0;S=1.0;T=0.0;U=0;break}while(1){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;Y=d[n]|0}else{Y=IGb(b)|0}if((Y|0)!=48){J=Y;K=0;L=0;M=W;N=X;O=1;P=1;R=0;S=1.0;T=0.0;U=0;break a}n=YGb(X,W,-1,-1)|0;W=F;X=n}}}while(0);b:while(1){n=J-48|0;do{if(n>>>0<10>>>0){Z=n;x=82}else{o=J|32;s=(J|0)==46;if(!((o-97|0)>>>0<6>>>0|s)){_=J;break b}if(s){if((P|0)==0){$=K;aa=L;ca=K;da=L;ea=O;fa=1;ga=R;ha=S;ia=T;ja=U;break}else{_=46;break b}}else{Z=(J|0)>57?o-87|0:n;x=82;break}}}while(0);if((x|0)==82){x=0;n=0;do{if((K|0)<(n|0)|(K|0)==(n|0)&L>>>0<8>>>0){ka=R;la=S;ma=T;na=Z+(U<<4)|0}else{o=0;if((K|0)<(o|0)|(K|0)==(o|0)&L>>>0<14>>>0){oa=S*.0625;ka=R;la=oa;ma=T+oa*+(Z|0);na=U;break}if(!((Z|0)!=0&(R|0)==0)){ka=R;la=S;ma=T;na=U;break}ka=1;la=S;ma=T+S*.5;na=U}}while(0);n=YGb(L,K,1,0)|0;$=F;aa=n;ca=M;da=N;ea=1;fa=P;ga=ka;ha=la;ia=ma;ja=na}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;J=d[n]|0;K=$;L=aa;M=ca;N=da;O=ea;P=fa;R=ga;S=ha;T=ia;U=ja;continue}else{J=IGb(b)|0;K=$;L=aa;M=ca;N=da;O=ea;P=fa;R=ga;S=ha;T=ia;U=ja;continue}}if((O|0)==0){n=(c[m>>2]|0)==0;if(!n){c[e>>2]=(c[e>>2]|0)-1}do{if(w){HGb(b,0)}else{if(n){break}o=c[e>>2]|0;c[e>>2]=o-1;if((P|0)==0){break}c[e>>2]=o-2}}while(0);l=+(t|0)*0.0;i=g;return+l}n=(P|0)==0;o=n?L:N;s=n?K:M;n=0;if((K|0)<(n|0)|(K|0)==(n|0)&L>>>0<8>>>0){n=U;p=K;pa=L;while(1){qa=n<<4;ra=YGb(pa,p,1,0)|0;sa=F;ta=0;if((sa|0)<(ta|0)|(sa|0)==(ta|0)&ra>>>0<8>>>0){n=qa;p=sa;pa=ra}else{ua=qa;break}}}else{ua=U}do{if((_|32|0)==112){pa=GGb(b,f)|0;p=F;if(!((pa|0)==0&(p|0)==(-2147483648|0))){va=p;wa=pa;break}if(w){HGb(b,0);l=0.0;i=g;return+l}else{if((c[m>>2]|0)==0){va=0;wa=0;break}c[e>>2]=(c[e>>2]|0)-1;va=0;wa=0;break}}else{if((c[m>>2]|0)==0){va=0;wa=0;break}c[e>>2]=(c[e>>2]|0)-1;va=0;wa=0}}while(0);pa=YGb(o<<2|0>>>30,s<<2|o>>>30,-32,-1)|0;p=YGb(pa,F,wa,va)|0;pa=F;if((ua|0)==0){l=+(t|0)*0.0;i=g;return+l}n=0;if((pa|0)>(n|0)|(pa|0)==(n|0)&p>>>0>(-j|0)>>>0){c[(ld()|0)>>2]=34;l=+(t|0)*1.7976931348623157e+308*1.7976931348623157e+308;i=g;return+l}n=j-106|0;qa=(n|0)<0|0?-1:0;if((pa|0)<(qa|0)|(pa|0)==(qa|0)&p>>>0<n>>>0){c[(ld()|0)>>2]=34;l=+(t|0)*2.2250738585072014e-308*2.2250738585072014e-308;i=g;return+l}if((ua|0)>-1){n=ua;oa=T;qa=pa;ra=p;while(1){sa=n<<1;if(oa<.5){xa=oa;ya=sa}else{xa=oa+-1.0;ya=sa|1}za=oa+xa;sa=YGb(ra,qa,-1,-1)|0;ta=F;if((ya|0)>-1){n=ya;oa=za;qa=ta;ra=sa}else{Aa=ya;Ba=za;Ca=ta;Da=sa;break}}}else{Aa=ua;Ba=T;Ca=pa;Da=p}ra=0;qa=ZGb(32,0,j,(j|0)<0|0?-1:0)|0;n=YGb(Da,Ca,qa,F)|0;qa=F;if((ra|0)>(qa|0)|(ra|0)==(qa|0)&k>>>0>n>>>0){qa=n;Ea=(qa|0)<0?0:qa}else{Ea=k}do{if((Ea|0)<53){oa=+(t|0);za=+jc(+(+JGb(1.0,84-Ea|0)),+oa);if(!((Ea|0)<32&Ba!=0.0)){Fa=Ba;Ga=Aa;Ha=za;Ia=oa;break}qa=Aa&1;Fa=(qa|0)==0?0.0:Ba;Ga=(qa^1)+Aa|0;Ha=za;Ia=oa}else{Fa=Ba;Ga=Aa;Ha=0.0;Ia=+(t|0)}}while(0);oa=Ia*Fa+(Ha+Ia*+(Ga>>>0>>>0))-Ha;if(!(oa!=0.0)){c[(ld()|0)>>2]=34}l=+KGb(oa,Da);i=g;return+l}else{G=v}}while(0);p=j+k|0;pa=3-p|0;qa=G;n=0;while(1){if((qa|0)==46){x=137;break}else if((qa|0)!=48){Ja=qa;Ka=0;La=n;Ma=0;Na=0;break}ra=c[e>>2]|0;if(ra>>>0<(c[m>>2]|0)>>>0){c[e>>2]=ra+1;qa=d[ra]|0;n=1;continue}else{qa=IGb(b)|0;n=1;continue}}c:do{if((x|0)==137){qa=c[e>>2]|0;if(qa>>>0<(c[m>>2]|0)>>>0){c[e>>2]=qa+1;Oa=d[qa]|0}else{Oa=IGb(b)|0}if((Oa|0)==48){Pa=-1;Qa=-1}else{Ja=Oa;Ka=1;La=n;Ma=0;Na=0;break}while(1){qa=c[e>>2]|0;if(qa>>>0<(c[m>>2]|0)>>>0){c[e>>2]=qa+1;Ra=d[qa]|0}else{Ra=IGb(b)|0}if((Ra|0)!=48){Ja=Ra;Ka=1;La=1;Ma=Pa;Na=Qa;break c}qa=YGb(Qa,Pa,-1,-1)|0;Pa=F;Qa=qa}}}while(0);n=h|0;c[n>>2]=0;qa=Ja-48|0;ra=(Ja|0)==46;d:do{if(qa>>>0<10>>>0|ra){o=h+496|0;s=Ma;sa=Na;ta=0;Sa=0;Ta=0;Ua=La;Va=Ka;Wa=0;Xa=0;Ya=Ja;Za=qa;_a=ra;while(1){do{if(_a){if((Va|0)==0){$a=Xa;ab=Wa;bb=1;cb=Ua;db=Ta;eb=ta;fb=Sa;gb=ta;hb=Sa}else{ib=s;jb=sa;kb=ta;lb=Sa;mb=Ta;nb=Ua;ob=Wa;pb=Xa;qb=Ya;break d}}else{rb=YGb(Sa,ta,1,0)|0;sb=F;ub=(Ya|0)!=48;if((Wa|0)>=125){if(!ub){$a=Xa;ab=Wa;bb=Va;cb=Ua;db=Ta;eb=sb;fb=rb;gb=s;hb=sa;break}c[o>>2]=c[o>>2]|1;$a=Xa;ab=Wa;bb=Va;cb=Ua;db=Ta;eb=sb;fb=rb;gb=s;hb=sa;break}vb=h+(Wa<<2)|0;if((Xa|0)==0){wb=Za}else{wb=Ya-48+((c[vb>>2]|0)*10|0)|0}c[vb>>2]=wb;vb=Xa+1|0;xb=(vb|0)==9;$a=xb?0:vb;ab=(xb&1)+Wa|0;bb=Va;cb=1;db=ub?rb:Ta;eb=sb;fb=rb;gb=s;hb=sa}}while(0);rb=c[e>>2]|0;if(rb>>>0<(c[m>>2]|0)>>>0){c[e>>2]=rb+1;yb=d[rb]|0}else{yb=IGb(b)|0}rb=yb-48|0;sb=(yb|0)==46;if(rb>>>0<10>>>0|sb){s=gb;sa=hb;ta=eb;Sa=fb;Ta=db;Ua=cb;Va=bb;Wa=ab;Xa=$a;Ya=yb;Za=rb;_a=sb}else{zb=gb;Ab=hb;Bb=eb;Cb=fb;Db=db;Eb=cb;Gb=bb;Hb=ab;Ib=$a;Jb=yb;x=160;break}}}else{zb=Ma;Ab=Na;Bb=0;Cb=0;Db=0;Eb=La;Gb=Ka;Hb=0;Ib=0;Jb=Ja;x=160}}while(0);if((x|0)==160){ra=(Gb|0)==0;ib=ra?Bb:zb;jb=ra?Cb:Ab;kb=Bb;lb=Cb;mb=Db;nb=Eb;ob=Hb;pb=Ib;qb=Jb}ra=(nb|0)!=0;do{if(ra){if((qb|32|0)!=101){x=169;break}qa=GGb(b,f)|0;_a=F;do{if((qa|0)==0&(_a|0)==(-2147483648|0)){if(w){HGb(b,0);l=0.0;i=g;return+l}else{if((c[m>>2]|0)==0){Kb=0;Lb=0;break}c[e>>2]=(c[e>>2]|0)-1;Kb=0;Lb=0;break}}else{Kb=_a;Lb=qa}}while(0);qa=YGb(Lb,Kb,jb,ib)|0;Mb=F;Nb=qa}else{x=169}}while(0);do{if((x|0)==169){if(!((qb|0)>-1)){Mb=ib;Nb=jb;break}if((c[m>>2]|0)==0){Mb=ib;Nb=jb;break}c[e>>2]=(c[e>>2]|0)-1;Mb=ib;Nb=jb}}while(0);if(!ra){c[(ld()|0)>>2]=22;HGb(b,0);l=0.0;i=g;return+l}qa=c[n>>2]|0;if((qa|0)==0){l=+(t|0)*0.0;i=g;return+l}_a=0;do{if((Nb|0)==(lb|0)&(Mb|0)==(kb|0)&((kb|0)<(_a|0)|(kb|0)==(_a|0)&lb>>>0<10>>>0)){if(!(k>>>0>30>>>0)){if((qa>>>(k>>>0)|0)!=0){break}}l=+(t|0)*+(qa>>>0>>>0);i=g;return+l}}while(0);qa=(j|0)/-2|0;_a=(qa|0)<0|0?-1:0;if((Mb|0)>(_a|0)|(Mb|0)==(_a|0)&Nb>>>0>qa>>>0){c[(ld()|0)>>2]=34;l=+(t|0)*1.7976931348623157e+308*1.7976931348623157e+308;i=g;return+l}qa=j-106|0;_a=(qa|0)<0|0?-1:0;if((Mb|0)<(_a|0)|(Mb|0)==(_a|0)&Nb>>>0<qa>>>0){c[(ld()|0)>>2]=34;l=+(t|0)*2.2250738585072014e-308*2.2250738585072014e-308;i=g;return+l}if((pb|0)==0){Ob=ob}else{if((pb|0)<9){qa=h+(ob<<2)|0;_a=pb;ra=c[qa>>2]|0;do{ra=ra*10|0;_a=_a+1|0;}while((_a|0)<9);c[qa>>2]=ra}Ob=ob+1|0}_a=Nb;do{if((mb|0)<9){if(!((mb|0)<=(_a|0)&(_a|0)<18)){break}if((_a|0)==9){l=+(t|0)*+((c[n>>2]|0)>>>0>>>0);i=g;return+l}if((_a|0)<9){l=+(t|0)*+((c[n>>2]|0)>>>0>>>0)/+(c[1404464+(8-_a<<2)>>2]|0);i=g;return+l}Za=k+27+(_a*-3|0)|0;Ya=c[n>>2]|0;if((Za|0)<=30){if((Ya>>>(Za>>>0)|0)!=0){break}}l=+(t|0)*+(Ya>>>0>>>0)*+(c[1404464+(_a-10<<2)>>2]|0);i=g;return+l}}while(0);n=(_a|0)%9|0;if((n|0)==0){Pb=0;Qb=Ob;Rb=0;Sb=_a}else{ra=(_a|0)>-1?n:n+9|0;n=c[1404464+(8-ra<<2)>>2]|0;do{if((Ob|0)==0){Tb=0;Ub=0;Vb=_a}else{qa=1e9/(n|0)|0;Ya=_a;Za=0;Xa=0;Wa=0;while(1){Va=h+(Xa<<2)|0;Ua=c[Va>>2]|0;Ta=((Ua>>>0)/(n>>>0)|0)+Wa|0;c[Va>>2]=Ta;Wb=ba((Ua>>>0)%(n>>>0)|0,qa)|0;Ua=Xa+1|0;if((Xa|0)==(Za|0)&(Ta|0)==0){Xb=Ua&127;Yb=Ya-9|0}else{Xb=Za;Yb=Ya}if((Ua|0)==(Ob|0)){break}else{Ya=Yb;Za=Xb;Xa=Ua;Wa=Wb}}if((Wb|0)==0){Tb=Ob;Ub=Xb;Vb=Yb;break}c[h+(Ob<<2)>>2]=Wb;Tb=Ob+1|0;Ub=Xb;Vb=Yb}}while(0);Pb=Ub;Qb=Tb;Rb=0;Sb=9-ra+Vb|0}e:while(1){n=h+(Pb<<2)|0;if((Sb|0)<18){_a=Qb;Wa=Rb;while(1){Xa=0;Za=_a+127|0;Ya=_a;while(1){qa=Za&127;Ua=h+(qa<<2)|0;Ta=c[Ua>>2]|0;Va=YGb(Ta<<29|0>>>3,0<<29|Ta>>>3,Xa,0)|0;Ta=F;Sa=0;if(Ta>>>0>Sa>>>0|Ta>>>0==Sa>>>0&Va>>>0>1e9>>>0){Sa=hHb(Va,Ta,1e9,0)|0;ta=iHb(Va,Ta,1e9,0)|0;Zb=Sa;_b=ta}else{Zb=0;_b=Va}c[Ua>>2]=_b;Ua=(qa|0)==(Pb|0);if((qa|0)!=(Ya+127&127|0)|Ua){$b=Ya}else{$b=(_b|0)==0?qa:Ya}if(Ua){break}else{Xa=Zb;Za=qa-1|0;Ya=$b}}Ya=Wa-29|0;if((Zb|0)==0){_a=$b;Wa=Ya}else{ac=Ya;bc=$b;cc=Zb;break}}}else{if((Sb|0)==18){dc=Qb;ec=Rb}else{fc=Pb;gc=Qb;hc=Rb;ic=Sb;break}while(1){if(!((c[n>>2]|0)>>>0<9007199>>>0)){fc=Pb;gc=dc;hc=ec;ic=18;break e}Wa=0;_a=dc+127|0;Ya=dc;while(1){Za=_a&127;Xa=h+(Za<<2)|0;qa=c[Xa>>2]|0;Ua=YGb(qa<<29|0>>>3,0<<29|qa>>>3,Wa,0)|0;qa=F;Va=0;if(qa>>>0>Va>>>0|qa>>>0==Va>>>0&Ua>>>0>1e9>>>0){Va=hHb(Ua,qa,1e9,0)|0;ta=iHb(Ua,qa,1e9,0)|0;kc=Va;lc=ta}else{kc=0;lc=Ua}c[Xa>>2]=lc;Xa=(Za|0)==(Pb|0);if((Za|0)!=(Ya+127&127|0)|Xa){mc=Ya}else{mc=(lc|0)==0?Za:Ya}if(Xa){break}else{Wa=kc;_a=Za-1|0;Ya=mc}}Ya=ec-29|0;if((kc|0)==0){dc=mc;ec=Ya}else{ac=Ya;bc=mc;cc=kc;break}}}n=Pb+127&127;if((n|0)==(bc|0)){Ya=bc+127&127;_a=h+((bc+126&127)<<2)|0;c[_a>>2]=c[_a>>2]|c[h+(Ya<<2)>>2];nc=Ya}else{nc=bc}c[h+(n<<2)>>2]=cc;Pb=n;Qb=nc;Rb=ac;Sb=Sb+9|0}f:while(1){oc=gc+1&127;ra=h+((gc+127&127)<<2)|0;n=fc;Ya=hc;_a=ic;while(1){Wa=(_a|0)==18;Za=(_a|0)>27?9:1;pc=n;qc=Ya;while(1){Xa=0;while(1){if((Xa|0)>=2){rc=Xa;break}Ua=Xa+pc&127;if((Ua|0)==(gc|0)){rc=2;break}ta=c[h+(Ua<<2)>>2]|0;Ua=c[1404456+(Xa<<2)>>2]|0;if(ta>>>0<Ua>>>0){rc=2;break}if(ta>>>0>Ua>>>0){rc=Xa;break}else{Xa=Xa+1|0}}if((rc|0)==2&Wa){break f}sc=Za+qc|0;if((pc|0)==(gc|0)){pc=gc;qc=sc}else{break}}Wa=(1<<Za)-1|0;Xa=1e9>>>(Za>>>0);tc=_a;uc=pc;Ua=pc;vc=0;do{ta=h+(Ua<<2)|0;Va=c[ta>>2]|0;qa=(Va>>>(Za>>>0))+vc|0;c[ta>>2]=qa;vc=ba(Va&Wa,Xa)|0;Va=(Ua|0)==(uc|0)&(qa|0)==0;Ua=Ua+1&127;tc=Va?tc-9|0:tc;uc=Va?Ua:uc;}while((Ua|0)!=(gc|0));if((vc|0)==0){n=uc;Ya=sc;_a=tc;continue}if((oc|0)!=(uc|0)){break}c[ra>>2]=c[ra>>2]|1;n=uc;Ya=sc;_a=tc}c[h+(gc<<2)>>2]=vc;fc=uc;gc=oc;hc=sc;ic=tc}_a=pc&127;if((_a|0)==(gc|0)){c[h+(oc-1<<2)>>2]=0;wc=oc}else{wc=gc}oa=+((c[h+(_a<<2)>>2]|0)>>>0>>>0);_a=pc+1&127;if((_a|0)==(wc|0)){Ya=wc+1&127;c[h+(Ya-1<<2)>>2]=0;xc=Ya}else{xc=wc}za=+(t|0);yc=za*(oa*1.0e9+ +((c[h+(_a<<2)>>2]|0)>>>0>>>0));_a=qc+53|0;Ya=_a-j|0;if((Ya|0)<(k|0)){zc=(Ya|0)<0?0:Ya;Ac=1}else{zc=k;Ac=0}if((zc|0)<53){oa=+jc(+(+JGb(1.0,105-zc|0)),+yc);Bc=+Fb(+yc,+(+JGb(1.0,53-zc|0)));Cc=oa;Dc=Bc;Ec=oa+(yc-Bc)}else{Cc=0.0;Dc=0.0;Ec=yc}n=pc+2&127;do{if((n|0)==(xc|0)){Fc=Dc}else{ra=c[h+(n<<2)>>2]|0;do{if(ra>>>0<5e8>>>0){if((ra|0)==0){if((pc+3&127|0)==(xc|0)){Gc=Dc;break}}Gc=za*.25+Dc}else{if(ra>>>0>5e8>>>0){Gc=za*.75+Dc;break}if((pc+3&127|0)==(xc|0)){Gc=za*.5+Dc;break}else{Gc=za*.75+Dc;break}}}while(0);if((53-zc|0)<=1){Fc=Gc;break}if(+Fb(+Gc,+1.0)!=0.0){Fc=Gc;break}Fc=Gc+1.0}}while(0);za=Ec+Fc-Cc;do{if((_a&2147483647|0)>(-2-p|0)){if(+Q(+za)<9007199254740992.0){Hc=za;Ic=Ac;Jc=qc}else{Hc=za*.5;Ic=(Ac|0)!=0&(zc|0)==(Ya|0)?0:Ac;Jc=qc+1|0}if((Jc+53|0)<=(pa|0)){if(!((Ic|0)!=0&Fc!=0.0)){Kc=Hc;Lc=Jc;break}}c[(ld()|0)>>2]=34;Kc=Hc;Lc=Jc}else{Kc=za;Lc=qc}}while(0);l=+KGb(Kc,Lc);i=g;return+l}}while(0);if((c[m>>2]|0)!=0){c[e>>2]=(c[e>>2]|0)-1}c[(ld()|0)>>2]=22;HGb(b,0);l=0.0;i=g;return+l}}while(0);do{if((x|0)==23){b=(c[m>>2]|0)==0;if(!b){c[e>>2]=(c[e>>2]|0)-1}if(u>>>0<4>>>0|(f|0)==0|b){break}else{Mc=u}do{c[e>>2]=(c[e>>2]|0)-1;Mc=Mc-1|0;}while(Mc>>>0>3>>>0)}}while(0);l=+(t|0)*r;i=g;return+l}function GGb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=a+4|0;f=c[e>>2]|0;g=a+100|0;if(f>>>0<(c[g>>2]|0)>>>0){c[e>>2]=f+1;h=d[f]|0}else{h=IGb(a)|0}do{if((h|0)==45|(h|0)==43){f=(h|0)==45|0;i=c[e>>2]|0;if(i>>>0<(c[g>>2]|0)>>>0){c[e>>2]=i+1;j=d[i]|0}else{j=IGb(a)|0}if((j-48|0)>>>0<10>>>0|(b|0)==0){k=f;l=j;break}if((c[g>>2]|0)==0){k=f;l=j;break}c[e>>2]=(c[e>>2]|0)-1;k=f;l=j}else{k=0;l=h}}while(0);if((l-48|0)>>>0>9>>>0){if((c[g>>2]|0)==0){m=-2147483648;n=0;return(F=m,n)|0}c[e>>2]=(c[e>>2]|0)-1;m=-2147483648;n=0;return(F=m,n)|0}else{o=l;p=0}while(1){q=o-48+p|0;l=c[e>>2]|0;if(l>>>0<(c[g>>2]|0)>>>0){c[e>>2]=l+1;r=d[l]|0}else{r=IGb(a)|0}if(!((r-48|0)>>>0<10>>>0&(q|0)<214748364)){break}o=r;p=q*10|0}p=q;o=(q|0)<0|0?-1:0;if((r-48|0)>>>0<10>>>0){q=r;l=o;h=p;while(1){j=gHb(h,l,10,0)|0;b=F;f=YGb(q,(q|0)<0|0?-1:0,-48,-1)|0;i=YGb(f,F,j,b)|0;b=F;j=c[e>>2]|0;if(j>>>0<(c[g>>2]|0)>>>0){c[e>>2]=j+1;s=d[j]|0}else{s=IGb(a)|0}j=21474836;if((s-48|0)>>>0<10>>>0&((b|0)<(j|0)|(b|0)==(j|0)&i>>>0<2061584302>>>0)){q=s;l=b;h=i}else{t=s;u=b;v=i;break}}}else{t=r;u=o;v=p}if((t-48|0)>>>0<10>>>0){do{t=c[e>>2]|0;if(t>>>0<(c[g>>2]|0)>>>0){c[e>>2]=t+1;w=d[t]|0}else{w=IGb(a)|0}}while((w-48|0)>>>0<10>>>0)}if((c[g>>2]|0)!=0){c[e>>2]=(c[e>>2]|0)-1}e=(k|0)!=0;k=ZGb(0,0,v,u)|0;m=e?F:u;n=e?k:v;return(F=m,n)|0}function HGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;c[a+104>>2]=b;d=c[a+8>>2]|0;e=c[a+4>>2]|0;f=d-e|0;c[a+108>>2]=f;if((b|0)!=0&(f|0)>(b|0)){c[a+100>>2]=e+b;return}else{c[a+100>>2]=d;return}}function IGb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b+104|0;f=c[e>>2]|0;if((f|0)==0){g=3}else{if((c[b+108>>2]|0)<(f|0)){g=3}}do{if((g|0)==3){f=MGb(b)|0;if((f|0)<0){break}h=c[e>>2]|0;i=c[b+8>>2]|0;do{if((h|0)==0){g=8}else{j=c[b+4>>2]|0;k=h-(c[b+108>>2]|0)-1|0;if((i-j|0)<=(k|0)){g=8;break}c[b+100>>2]=j+k}}while(0);if((g|0)==8){c[b+100>>2]=i}h=c[b+4>>2]|0;if((i|0)!=0){k=b+108|0;c[k>>2]=i+1-h+(c[k>>2]|0)}k=h-1|0;if((d[k]|0|0)==(f|0)){l=f;return l|0}a[k]=f;l=f;return l|0}}while(0);c[b+100>>2]=0;l=-1;return l|0}function JGb(a,b){a=+a;b=b|0;var d=0.0,e=0,f=0.0,g=0;do{if((b|0)>1023){d=a*8.98846567431158e+307;e=b-1023|0;if((e|0)<=1023){f=d;g=e;break}e=b-2046|0;f=d*8.98846567431158e+307;g=(e|0)>1023?1023:e}else{if(!((b|0)<-1022)){f=a;g=b;break}d=a*2.2250738585072014e-308;e=b+1022|0;if(!((e|0)<-1022)){f=d;g=e;break}e=b+2044|0;f=d*2.2250738585072014e-308;g=(e|0)<-1022?-1022:e}}while(0);return+(f*(c[k>>2]=0<<20|0>>>12,c[k+4>>2]=g+1023<<20|0>>>12,+h[k>>3]))}function KGb(a,b){a=+a;b=b|0;return+(+JGb(a,b))}function LGb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+74|0;e=a[d]|0;a[d]=e-1&255|e;e=b+20|0;d=b+44|0;if((c[e>>2]|0)>>>0>(c[d>>2]|0)>>>0){ze[c[b+36>>2]&511](b,0,0)|0}c[b+16>>2]=0;c[b+28>>2]=0;c[e>>2]=0;e=b|0;f=c[e>>2]|0;if((f&20|0)==0){g=c[d>>2]|0;c[b+8>>2]=g;c[b+4>>2]=g;h=0;return h|0}if((f&4|0)==0){h=-1;return h|0}c[e>>2]=f|32;h=-1;return h|0}function MGb(a){a=a|0;var b=0,e=0,f=0,g=0;b=i;i=i+8|0;e=b|0;if((c[a+8>>2]|0)==0){if((LGb(a)|0)==0){f=3}else{g=-1}}else{f=3}do{if((f|0)==3){if((ze[c[a+32>>2]&511](a,e,1)|0)!=1){g=-1;break}g=d[e]|0}}while(0);i=b;return g|0}function NGb(a){a=a|0;return+(+OGb(a,0))}function OGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0.0,j=0,k=0;d=i;i=i+112|0;e=d|0;TGb(e|0,0,112)|0;f=e+4|0;c[f>>2]=a;g=e+8|0;c[g>>2]=-1;c[e+44>>2]=a;c[e+76>>2]=-1;HGb(e,0);h=+FGb(e,1,1);j=(c[f>>2]|0)-(c[g>>2]|0)+(c[e+108>>2]|0)|0;if((b|0)==0){i=d;return+h}if((j|0)==0){k=a}else{k=a+j|0}c[b>>2]=k;i=d;return+h}function PGb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==0){e=0;return e|0}else{f=d;g=b;h=c}while(1){i=a[g]|0;j=a[h]|0;if(!(i<<24>>24==j<<24>>24)){break}c=f-1|0;if((c|0)==0){e=0;k=5;break}else{f=c;g=g+1|0;h=h+1|0}}if((k|0)==5){return e|0}e=(i&255)-(j&255)|0;return e|0}function QGb(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a[b]|0;e=a[c]|0;if(d<<24>>24!=e<<24>>24|d<<24>>24==0|e<<24>>24==0){f=d;g=e;h=f&255;i=g&255;j=h-i|0;return j|0}else{k=b;l=c}while(1){c=k+1|0;b=l+1|0;e=a[c]|0;d=a[b]|0;if(e<<24>>24!=d<<24>>24|e<<24>>24==0|d<<24>>24==0){f=e;g=d;break}else{k=c;l=b}}h=f&255;i=g&255;j=h-i|0;return j|0}function RGb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((e|0)==0){f=0;return f|0}g=a[b]|0;a:do{if(g<<24>>24==0){h=c;i=0}else{j=b;k=c;l=e;m=g;while(1){n=l-1|0;o=a[k]|0;if(!((n|0)!=0&o<<24>>24!=0&m<<24>>24==o<<24>>24)){h=k;i=m;break a}o=j+1|0;p=k+1|0;q=a[o]|0;if(q<<24>>24==0){h=p;i=0;break}else{j=o;k=p;l=n;m=q}}}}while(0);f=(i&255)-(d[h]|0)|0;return f|0}function SGb(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function TGb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+e|0;if((e|0)>=20){d=d&255;g=b&3;h=d|d<<8|d<<16|d<<24;i=f&~3;if(g){g=b+4-g|0;while((b|0)<(g|0)){a[b]=d;b=b+1|0}}while((b|0)<(i|0)){c[b>>2]=h;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}return b-e|0}function UGb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((e|0)>=4096)return pc(b|0,d|0,e|0)|0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function VGb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;if((c|0)<(b|0)&(b|0)<(c+d|0)){e=b;c=c+d|0;b=b+d|0;while((d|0)>0){b=b-1|0;c=c-1|0;d=d-1|0;a[b]=a[c]|0}b=e}else{UGb(b,c,d)|0}return b|0}function WGb(b,c){b=b|0;c=c|0;var d=0;do{a[b+d|0]=a[c+d|0];d=d+1|0}while(a[c+(d-1)|0]|0);return b|0}function XGb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;c=b+d>>>0;d=c>>>0<b>>>0|0;if(e>>>0<a>>>0){c=c+1>>>0;d=d|!c}return(F=c,G=d,e|0)|0}function YGb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(F=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function ZGb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(F=e,a-c>>>0|0)|0}function _Gb(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}F=a<<c-32;return 0}function $Gb(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}F=0;return b>>>c-32|0}function aHb(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}F=(b|0)<0?-1:0;return b>>c-32|0}function bHb(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function cHb(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function dHb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ba(d,c)|0;f=a>>>16;a=(e>>>16)+(ba(d,f)|0)|0;d=b>>>16;b=ba(d,c)|0;return(F=(a>>>16)+(ba(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function eHb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=ZGb(e^a,f^b,e,f)|0;b=F;a=g^e;e=h^f;f=ZGb((jHb(i,b,ZGb(g^c,h^d,g,h)|0,F,0)|0)^a,F^e,a,e)|0;return(F=F,f)|0}function fHb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=ZGb(h^a,j^b,h,j)|0;b=F;jHb(m,b,ZGb(k^d,l^e,k,l)|0,F,g)|0;l=ZGb(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=F;i=f;return(F=j,l)|0}function gHb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=dHb(e,a)|0;f=F;return(F=(ba(b,a)|0)+(ba(d,e)|0)+f|f&0,c|0|0)|0}function hHb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jHb(a,b,c,d,0)|0;return(F=F,e)|0}function iHb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;jHb(a,b,d,e,g)|0;i=f;return(F=c[g+4>>2]|0,c[g>>2]|0)|0}function jHb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(F=n,o)|0}else{if(!m){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(F=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(F=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(F=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((cHb(l|0)|0)>>>0);return(F=n,o)|0}p=(bHb(l|0)|0)-(bHb(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(F=n,o)|0}else{if(!m){r=(bHb(l|0)|0)-(bHb(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(F=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(bHb(j|0)|0)+33-(bHb(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(F=n,o)|0}else{p=cHb(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(F=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;G=0;H=0}else{g=d|0|0;d=k|e&0;e=YGb(g,d,-1,-1)|0;k=F;i=w;w=v;v=u;u=t;t=s;s=0;while(1){I=w>>>31|i<<1;J=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;ZGb(e,k,j,a)|0;b=F;h=b>>31|((b|0)<0?-1:0)<<1;K=h&1;L=ZGb(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=F;b=t-1|0;if((b|0)==0){break}else{i=I;w=J;v=M;u=L;t=b;s=K}}B=I;C=J;D=M;E=L;G=0;H=K}K=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(K|0)>>>31|(B|C)<<1|(C<<1|K>>>31)&0|G;o=(K<<1|0>>>31)&-2|H;return(F=n,o)|0}function kHb(a){a=+a;return+Eb(+a)}function lHb(a){a=+a;return+X(+a)}function mHb(a){a=+a;return+Y(+a)}function nHb(a){a=+a;return+$(+a)}function oHb(a){a=+a;return+W(+a)}function pHb(a){a=+a;return+T(+a)}function qHb(a){a=+a;return+Q(+a)}function rHb(a){a=+a;return+Ob(+a)}function sHb(a){a=+a;return+_(+a)}function tHb(a){a=+a;return+U(+a)}function uHb(a){a=+a;return+oc(+a)}function vHb(a){a=+a;return+V(+a)}function wHb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return je[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0)|0}function xHb(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;i=i|0;ke[a&3](b|0,c|0,d|0,e|0,f|0,g|0,+h,i|0)}function yHb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;le[a&1023](b|0,c|0,d|0,e|0,f|0)}function zHb(a,b){a=a|0;b=b|0;me[a&511](b|0)}function AHb(a,b,c){a=a|0;b=b|0;c=c|0;ne[a&1023](b|0,c|0)}function BHb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return oe[a&63](b|0,c|0,d|0,e|0,f|0,g|0)|0}function CHb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;pe[a&7](b|0,c|0,d|0,e|0,+f)}function DHb(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=+f;g=g|0;h=h|0;i=i|0;qe[a&3](b|0,c|0,d|0,+e,+f,g|0,h|0,i|0)}function EHb(a,b){a=a|0;b=b|0;return re[a&4095](b|0)|0}function FHb(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;se[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)}function GHb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;te[a&7](b|0,c|0,+d,e|0)}function HHb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;ue[a&3](b|0,c|0,+d,e|0)}function IHb(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=+l;ve[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,+l)}function JHb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return+we[a&7](b|0,c|0,d|0)}function KHb(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;return xe[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)|0}function LHb(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=+i;j=+j;k=k|0;return+ye[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,+i,+j,k|0)}function MHb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ze[a&511](b|0,c|0,d|0)|0}function NHb(a,b,c,d,e,f,g,h){a=a|0;b=+b;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return Ae[a&7](+b,+c,d|0,e|0,f|0,g|0,h|0)|0}function OHb(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;Be[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function PHb(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=+i;Ce[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,+i)}function QHb(a,b,c){a=a|0;b=b|0;c=c|0;return+De[a&3](b|0,c|0)}function RHb(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return Ee[a&63](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)|0}function SHb(a,b,c,d,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;i=i|0;j=j|0;k=k|0;l=+l;m=m|0;return Fe[a&3](b|0,c|0,d|0,e|0,f|0,g|0,+h,i|0,j|0,k|0,+l,m|0)|0}function THb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=+f;g=g|0;Ge[a&3](b|0,c|0,d|0,+e,+f,g|0)}function UHb(a,b){a=a|0;b=+b;return+He[a&31](+b)}function VHb(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;Ie[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0,m|0,n|0,o|0)}function WHb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;h=h|0;Je[a&7](b|0,c|0,d|0,e|0,f|0,+g,h|0)}function XHb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;Ke[a&1023](b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function YHb(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;Le[a&255](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)}function ZHb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;Me[a&3](b|0,c|0,d|0,e|0,f|0,g|0,+h)}function _Hb(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;Ne[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0)}function $Hb(a,b,c){a=a|0;b=b|0;c=c|0;return Oe[a&1023](b|0,c|0)|0}function aIb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return Pe[a&255](b|0,c|0,d|0,e|0,f|0)|0}function bIb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return+Qe[a&3](b|0,c|0,d|0)}function cIb(a,b,c,d){a=a|0;b=b|0;c=+c;d=+d;return+Re[a&1](b|0,+c,+d)}function dIb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;Se[a&511](b|0,c|0,d|0,e|0,f|0,g|0)}function eIb(a,b,c){a=a|0;b=b|0;c=+c;return+Te[a&15](b|0,+c)}function fIb(a,b,c,d,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;Ue[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0,m|0)}function gIb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;Ve[a&15](b|0,c|0,d|0,+e)}function hIb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;g=g|0;h=h|0;We[a&7](b|0,c|0,d|0,e|0,+f,g|0,h|0)}function iIb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Xe[a&4095](b|0,c|0,d|0)}function jIb(a){a=a|0;Ye[a&1]()}function kIb(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;return Ze[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)|0}function lIb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return _e[a&1023](b|0,c|0,d|0,e|0)|0}function mIb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;$e[a&3](b|0,c|0,+d)}function nIb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=+d;e=+e;f=f|0;af[a&3](b|0,c|0,+d,+e,f|0)}function oIb(a,b,c,d,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=+i;j=+j;k=+k;l=+l;m=+m;bf[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,+i,+j,+k,+l,+m)}function pIb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;cf[a&1023](b|0,c|0,d|0,e|0)}function qIb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ca(0);return 0}function rIb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;h=h|0;ca(1)}function sIb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ca(2)}function tIb(a){a=a|0;ca(3)}function uIb(a,b){a=a|0;b=b|0;ca(4)}function vIb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ca(5);return 0}function wIb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;ca(6)}function xIb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=+d;e=+e;f=f|0;g=g|0;h=h|0;ca(7)}function yIb(a){a=a|0;ca(8);return 0}function zIb(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;ca(9)}function AIb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;ca(10)}function BIb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;ca(11)}function CIb(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=+k;ca(12)}function DIb(a,b,c){a=a|0;b=b|0;c=c|0;ca(13);return 0.0}function EIb(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;ca(14);return 0}function FIb(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;i=+i;j=j|0;ca(15);return 0.0}function GIb(a,b,c){a=a|0;b=b|0;c=c|0;ca(16);return 0}function HIb(a,b,c,d,e,f,g){a=+a;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ca(17);return 0}function IIb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ca(18)}function JIb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;ca(19)}function KIb(a,b){a=a|0;b=b|0;ca(20);return 0.0}function LIb(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ca(21);return 0}function MIb(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;h=h|0;i=i|0;j=j|0;k=+k;l=l|0;ca(22);return 0}function NIb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=+d;e=+e;f=f|0;ca(23)}function OIb(a){a=+a;ca(24);return 0.0}function PIb(a,b,c,d,e,f,g,h,i,j,k,l,m,n){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;ca(25)}function QIb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;g=g|0;ca(26)}function RIb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ca(27)}function SIb(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ca(28)}function TIb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;ca(29)}function UIb(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;ca(30)}function VIb(a,b){a=a|0;b=b|0;ca(31);return 0}function WIb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ca(32);return 0}function XIb(a,b,c){a=a|0;b=b|0;c=c|0;ca(33);return 0.0}function YIb(a,b,c){a=a|0;b=+b;c=+c;ca(34);return 0.0}function ZIb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ca(35)}function _Ib(a,b){a=a|0;b=+b;ca(36);return 0.0}function $Ib(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;ca(37)}function aJb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;ca(38)}function bJb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=f|0;g=g|0;ca(39)}function cJb(a,b,c){a=a|0;b=b|0;c=c|0;ca(40)}function dJb(){ca(41)}function eJb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ca(42);return 0}function fJb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ca(43);return 0}function gJb(a,b,c){a=a|0;b=b|0;c=+c;ca(44)}function hJb(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=+d;e=e|0;ca(45)}function iJb(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;i=+i;j=+j;k=+k;l=+l;ca(46)}function jJb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ca(47)}




// EMSCRIPTEN_END_FUNCS
var je=[qIb,qIb,OWa,qIb,Hyb,qIb,Gyb,qIb,kL,qIb,mL,qIb,azb,qIb,Xyb,qIb,Rsb,qIb,Jsb,qIb,$yb,qIb,lL,qIb,Iyb,qIb,gL,qIb,Lyb,qIb,Tyb,qIb,hL,qIb,Qsb,qIb,Ksb,qIb,iL,qIb,nL,qIb,Wyb,qIb,Msb,qIb,NWa,qIb,Zyb,qIb,Myb,qIb,oL,qIb,czb,qIb,Nyb,qIb,Gsb,qIb,Ssb,qIb,pL,qIb,_yb,qIb,Osb,qIb,Uyb,qIb,asb,qIb,Psb,qIb,qL,qIb,Tsb,qIb,Nsb,qIb,Vyb,qIb,Hsb,qIb,Isb,qIb,jL,qIb,Jyb,qIb,Syb,qIb,Lsb,qIb,bzb,qIb,Qyb,qIb,Ryb,qIb,eL,qIb,Pyb,qIb,fL,qIb,Oyb,qIb,Yyb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb,qIb];var ke=[rIb,rIb,Jpb,rIb];var le=[sIb,sIb,D9a,sIb,xfb,sIb,P5a,sIb,Lzb,sIb,Wfa,sIb,Wha,sIb,orb,sIb,qrb,sIb,I4a,sIb,Baa,sIb,Hga,sIb,z4,sIb,trb,sIb,Drb,sIb,G9a,sIb,Zha,sIb,lga,sIb,qga,sIb,Xzb,sIb,hOa,sIb,vfa,sIb,taa,sIb,E4,sIb,y9a,sIb,_Ca,sIb,z$,sIb,$bb,sIb,_bb,sIb,Tbb,sIb,Sbb,sIb,Vbb,sIb,Ubb,sIb,Xbb,sIb,Wbb,sIb,Zbb,sIb,Ybb,sIb,I4,sIb,waa,sIb,Uzb,sIb,tkb,sIb,yfa,sIb,Aob,sIb,naa,sIb,rga,sIb,bAb,sIb,G1,sIb,dE,sIb,xqb,sIb,xkb,sIb,atb,sIb,L5a,sIb,Irb,sIb,J1,sIb,q7,sIb,Oga,sIb,Pga,sIb,WEa,sIb,oFa,sIb,I$a,sIb,Oha,sIb,Aha,sIb,vaa,sIb,L4,sIb,svb,sIb,cOa,sIb,acb,sIb,aha,sIb,Kha,sIb,pu,sIb,lrb,sIb,Vlb,sIb,ju,sIb,zfa,sIb,KEa,sIb,YCa,sIb,eFa,sIb,mrb,sIb,Ufa,sIb,H4,sIb,lLa,sIb,Tfa,sIb,Yha,sIb,Ip,sIb,jkb,sIb,M5a,sIb,jga,sIb,Arb,sIb,gvb,sIb,Vzb,sIb,Bqb,sIb,Gzb,sIb,Bha,sIb,$sb,sIb,J7,sIb,I7,sIb,H7,sIb,nu,sIb,yrb,sIb,vqb,sIb,vfb,sIb,Daa,sIb,M4,sIb,mha,sIb,pha,sIb,nrb,sIb,Kpb,sIb,qha,sIb,gtb,sIb,zqb,sIb,B4,sIb,ovb,sIb,Caa,sIb,F1,sIb,qfa,sIb,Erb,sIb,LEa,sIb,ZCa,sIb,$ea,sIb,F9a,sIb,btb,sIb,_ha,sIb,Mha,sIb,K3a,sIb,Crb,sIb,uaa,sIb,E9a,sIb,cvb,sIb,Izb,sIb,Pzb,sIb,bvb,sIb,bha,sIb,L3a,sIb,Faa,sIb,Gpb,sIb,krb,sIb,Jzb,sIb,yha,sIb,xrb,sIb,Xfa,sIb,dha,sIb,lu,sIb,zrb,sIb,lCb,sIb,paa,sIb,bcb,sIb,dcb,sIb,ccb,sIb,ku,sIb,Rga,sIb,cE,sIb,rfa,sIb,htb,sIb,N4,sIb,wfa,sIb,Mzb,sIb,pga,sIb,Eaa,sIb,K9a,sIb,Nzb,sIb,_ea,sIb,_zb,sIb,Jga,sIb,Q5a,sIb,H1,sIb,oSa,sIb,Iga,sIb,Szb,sIb,kvb,sIb,M9a,sIb,RDa,sIb,afa,sIb,P4,sIb,kba,sIb,Zfb,sIb,I1,sIb,urb,sIb,Tea,sIb,nvb,sIb,Gaa,sIb,xfa,sIb,z9a,sIb,A9a,sIb,Lha,sIb,oha,sIb,tvb,sIb,tga,sIb,dtb,sIb,Ozb,sIb,Qzb,sIb,K4,sIb,aAb,sIb,saa,sIb,itb,sIb,Ofa,sIb,F4,sIb,raa,sIb,A4,sIb,Kzb,sIb,y$,sIb,kCb,sIb,Tzb,sIb,prb,sIb,Grb,sIb,t5a,sIb,Nfa,sIb,D4,sIb,Aaa,sIb,J9a,sIb,mu,sIb,K1,sIb,srb,sIb,N9a,sIb,Uea,sIb,zaa,sIb,Hrb,sIb,Zea,sIb,Frb,sIb,rvb,sIb,Wzb,sIb,Lpb,sIb,sga,sIb,ou,sIb,ctb,sIb,eha,sIb,SDa,sIb,cha,sIb,Pfa,sIb,Xha,sIb,jtb,sIb,y4,sIb,xaa,sIb,ftb,sIb,O4,sIb,etb,sIb,Yzb,sIb,H9a,sIb,Brb,sIb,J3a,sIb,Hzb,sIb,G4,sIb,L9a,sIb,J4,sIb,Qga,sIb,mkb,sIb,TDa,sIb,fCa,sIb,Nga,sIb,yaa,sIb,C4,sIb,B9a,sIb,Vfa,sIb,Nha,sIb,fvb,sIb,$zb,sIb,zha,sIb,jvb,sIb,Rzb,sIb,vrb,sIb,C9a,sIb,rrb,sIb,kga,sIb,bfa,sIb,Cha,sIb,nha,sIb,iu,sIb,wrb,sIb,Zzb,sIb,pfa,sIb,pkb,sIb,fkb,sIb,Vea,sIb,I9a,sIb,v1a,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb,sIb];var me=[tIb,tIb,n8,tIb,_v,tIb,Yu,tIb,gJa,tIb,bqb,tIb,XRa,tIb,p9,tIb,ht,tIb,vq,tIb,Wt,tIb,X_a,tIb,IE,tIb,gl,tIb,Ecb,tIb,ni,tIb,IXa,tIb,NXa,tIb,Lcb,tIb,EMa,tIb,pn,tIb,hi,tIb,ZGa,tIb,hqb,tIb,Im,tIb,hp,tIb,fu,tIb,ETa,tIb,Ypb,tIb,kca,tIb,lJa,tIb,kgb,tIb,zp,tIb,Ll,tIb,ycb,tIb,kJa,tIb,Qu,tIb,Op,tIb,Um,tIb,r_,tIb,iJa,tIb,g$,tIb,$pb,tIb,hda,tIb,zZa,tIb,h9,tIb,cl,tIb,cqb,tIb,Ppb,tIb,n1,tIb,cUa,tIb,g9,tIb,_gb,tIb,l9,tIb,iqb,tIb,z5a,tIb,Mr,tIb,eq,tIb,UJa,tIb,WJa,tIb,VJa,tIb,Q4a,tIb,Go,tIb,o2a,tIb,ai,tIb,qcb,tIb,z4a,tIb,Gp,tIb,SNa,tIb,Pv,tIb,Eq,tIb,eca,tIb,J2a,tIb,xZ,tIb,Aj,tIb,jl,tIb,j9,tIb,$9,tIb,xm,tIb,r1,tIb,Urb,tIb,Vs,tIb,bPa,tIb,n5a,tIb,Zpb,tIb,Ym,tIb,W8,tIb,m5a,tIb,m9,tIb,ogb,tIb,No,tIb,e9,tIb,f9,tIb,Vv,tIb,BHa,tIb,kqb,tIb,Au,tIb,tMa,tIb,ugb,tIb,rob,tIb,bs,tIb,nbb,tIb,sm,tIb,JZa,tIb,su,tIb,sl,tIb,Ah,tIb,ak,tIb,dt,tIb,NNa,tIb,qr,tIb,Fv,tIb,s9,tIb,U8,tIb,xAa,tIb,ok,tIb,tJa,tIb,job,tIb,Keb,tIb,r9,tIb,hJa,tIb,Qt,tIb,go,tIb,R4a,tIb,uob,tIb,gqb,tIb,vw,tIb,un,tIb,dqb,tIb,EXa,tIb,FE,tIb,ik,tIb,Xo,tIb,kw,tIb,q5a,tIb,DLa,tIb,Iu,tIb,INa,tIb,u7,tIb,Ln,tIb,fqb,tIb,c0,tIb,DE,tIb,bo,tIb,aq,tIb,ps,tIb,r5a,tIb,jqb,tIb,aqb,tIb,XNa,tIb,n9,tIb,G6a,tIb,k9,tIb,kY,tIb,Uj,tIb,Uba,tIb,q9,tIb,qMa,tIb,Fh,tIb,k4a,tIb,Ai,tIb,V8,tIb,st,tIb,bKa,tIb,to,tIb,vHa,tIb,i9,tIb,PX,tIb,t7,tIb,Fr,tIb,vi,tIb,TJa,tIb,Ku,tIb,hv,tIb,_q,tIb,eqb,tIb,_pb,tIb,kob,tIb,tob,tIb,us,tIb,kn,tIb,Uq,tIb,Nj,tIb,o9,tIb,jJa,tIb,oq,tIb,S4a,tIb,Ar,tIb,Hcb,tIb,is,tIb,Nm,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb,tIb];var ne=[uIb,uIb,toa,uIb,Qs,uIb,pY,uIb,Oia,uIb,V0,uIb,soa,uIb,gja,uIb,jna,uIb,qoa,uIb,Tmb,uIb,lY,uIb,koa,uIb,_ia,uIb,CUa,uIb,Pma,uIb,Js,uIb,fna,uIb,cfb,uIb,Jj,uIb,yob,uIb,zka,uIb,Ola,uIb,bna,uIb,Tla,uIb,pka,uIb,Fla,uIb,bfb,uIb,poa,uIb,dja,uIb,Yla,uIb,mMa,uIb,Sma,uIb,DL,uIb,$ma,uIb,iK,uIb,vY,uIb,qna,uIb,$na,uIb,dBb,uIb,hja,uIb,Lla,uIb,Xia,uIb,Zma,uIb,Vpb,uIb,vZa,uIb,k5a,uIb,kVa,uIb,Ula,uIb,TAb,uIb,lja,uIb,Ps,uIb,ioa,uIb,Yia,uIb,dna,uIb,Bka,uIb,Qla,uIb,nY,uIb,tka,uIb,Ila,uIb,Xma,uIb,Lka,uIb,sha,uIb,hN,uIb,NBa,uIb,mY,uIb,xja,uIb,tha,uIb,U2a,uIb,GL,uIb,ena,uIb,CL,uIb,goa,uIb,Gka,uIb,T2a,uIb,xZa,uIb,tY,uIb,nka,uIb,eja,uIb,Aoa,uIb,Eoa,uIb,Ms,uIb,joa,uIb,Zia,uIb,mja,uIb,Wla,uIb,mna,uIb,_ma,uIb,W0,uIb,xoa,uIb,Upb,uIb,Eha,uIb,Mka,uIb,MFb,uIb,Nma,uIb,qja,uIb,gna,uIb,aoa,uIb,qka,uIb,coa,uIb,Xeb,uIb,Foa,uIb,Qia,uIb,lna,uIb,zY,uIb,Kj,uIb,F5a,uIb,X0,uIb,ckb,uIb,Z0,uIb,sY,uIb,Y0,uIb,nsb,uIb,wob,uIb,woa,uIb,boa,uIb,Dla,uIb,doa,uIb,Hs,uIb,P4a,uIb,Mla,uIb,Web,uIb,bma,uIb,Wma,uIb,ska,uIb,Hla,uIb,Kla,uIb,ks,uIb,rY,uIb,hna,uIb,aja,uIb,kka,uIb,_la,uIb,yla,uIb,sja,uIb,Bla,uIb,yoa,uIb,xY,uIb,zoa,uIb,rZa,uIb,Ria,uIb,Fha,uIb,xla,uIb,yka,uIb,Nla,uIb,ana,uIb,Vla,uIb,Rla,uIb,ls,uIb,Cla,uIb,g1a,uIb,S2a,uIb,Qha,uIb,s0,uIb,Zla,uIb,Xla,uIb,foa,uIb,hoa,uIb,Vma,uIb,rka,uIb,Gla,uIb,uZa,uIb,$la,uIb,wka,uIb,Dka,uIb,nja,uIb,roa,uIb,fja,uIb,Nka,uIb,moa,uIb,Tma,uIb,Tia,uIb,Doa,uIb,Qma,uIb,Hka,uIb,ffb,uIb,lsb,uIb,a9,uIb,oka,uIb,uja,uIb,xka,uIb,wZa,uIb,Ika,uIb,Coa,uIb,Oka,uIb,uoa,uIb,voa,uIb,kna,uIb,G5a,uIb,bja,uIb,loa,uIb,$ia,uIb,FL,uIb,vka,uIb,EL,uIb,Via,uIb,ija,uIb,mka,uIb,Ala,uIb,nna,uIb,zla,uIb,Uma,uIb,$0,uIb,ika,uIb,b9,uIb,oY,uIb,uY,uIb,Pia,uIb,Mma,uIb,cja,uIb,ina,uIb,Cka,uIb,Rma,uIb,LFb,uIb,rDb,uIb,R2a,uIb,jsb,uIb,vja,uIb,vob,uIb,Sia,uIb,Kka,uIb,h1a,uIb,cna,uIb,Pla,uIb,tja,uIb,Aka,uIb,noa,uIb,Fka,uIb,aia,uIb,gha,uIb,Sla,uIb,hha,uIb,ama,uIb,jka,uIb,Eka,uIb,Ela,uIb,pja,uIb,Wia,uIb,Os,uIb,kja,uIb,psb,uIb,Jka,uIb,Rha,uIb,jja,uIb,ooa,uIb,yja,uIb,Boa,uIb,uka,uIb,Jla,uIb,Yma,uIb,oja,uIb,wY,uIb,Uia,uIb,yY,uIb,FVa,uIb,ona,uIb,lka,uIb,Oma,uIb,pna,uIb,rja,uIb,wja,uIb,zja,uIb,nPa,uIb,eoa,uIb,qY,uIb,Ss,uIb,bia,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb,uIb];var oe=[vIb,vIb,Eeb,vIb,Eca,vIb,mw,vIb,lKa,vIb,_9,vIb,TLa,vIb,ws,vIb,Io,vIb,D0,vIb,Vrb,vIb,m1,vIb,FNa,vIb,wfb,vIb,Qp,vIb,e_a,vIb,a0a,vIb,_u,vIb,ZMa,vIb,xq,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb,vIb];var pe=[wIb,wIb,hpb,wIb,mpb,wIb,wIb,wIb];var qe=[xIb,xIb,p0,xIb];var re=[yIb,yIb,XV,yIb,CA,yIb,W_,yIb,xGa,yIb,hE,yIb,UV,yIb,zU,yIb,gp,yIb,eC,yIb,Wn,yIb,pU,yIb,MNa,yIb,CV,yIb,aKa,yIb,Ev,yIb,Or,yIb,bl,yIb,B1a,yIb,sR,yIb,rKa,yIb,NRa,yIb,TZa,yIb,dV,yIb,Vp,yIb,NZa,yIb,Bn,yIb,Di,yIb,CW,yIb,vK,yIb,Zu,yIb,Su,yIb,WF,yIb,Ks,yIb,NC,yIb,oR,yIb,Fl,yIb,Icb,yIb,io,yIb,fl,yIb,nR,yIb,HU,yIb,YG,yIb,lRa,yIb,oca,yIb,Ldb,yIb,Om,yIb,cJ,yIb,YU,yIb,r8,yIb,RK,yIb,nn,yIb,OL,yIb,ex,yIb,tDb,yIb,rA,yIb,heb,yIb,KYa,yIb,_G,yIb,nN,yIb,CHa,yIb,VN,yIb,v0,yIb,TN,yIb,i_,yIb,DW,yIb,QV,yIb,zW,yIb,jJ,yIb,oK,yIb,Wrb,yIb,F8,yIb,Br,yIb,Wgb,yIb,fXa,yIb,Z3a,yIb,gXa,yIb,_t,yIb,EHa,yIb,Wj,yIb,dq,yIb,gG,yIb,GTa,yIb,zN,yIb,x$a,yIb,WNa,yIb,SQ,yIb,eu,yIb,meb,yIb,wy,yIb,WL,yIb,kB,yIb,MX,yIb,Yp,yIb,ji,yIb,nK,yIb,jYa,yIb,Hm,yIb,kP,yIb,Ydb,yIb,K$,yIb,vgb,yIb,sRa,yIb,dRa,yIb,yJ,yIb,ns,yIb,jaa,yIb,L8,yIb,$F,yIb,kbb,yIb,FSa,yIb,sAa,yIb,UD,yIb,USa,yIb,tW,yIb,pW,yIb,Tv,yIb,DB,yIb,TW,yIb,v8,yIb,_Ka,yIb,_K,yIb,b8,yIb,Eba,yIb,pPa,yIb,SLa,yIb,Qo,yIb,wUa,yIb,kcb,yIb,Zaa,yIb,FQa,yIb,bt,yIb,HGa,yIb,Av,yIb,sS,yIb,cKa,yIb,kO,yIb,oi,yIb,$I,yIb,hG,yIb,vt,yIb,$K,yIb,vQ,yIb,qs,yIb,FC,yIb,BNa,yIb,ZF,yIb,pr,yIb,Mv,yIb,el,yIb,LSa,yIb,Xt,yIb,mgb,yIb,dQ,yIb,Hv,yIb,nQa,yIb,XZ,yIb,aA,yIb,PA,yIb,pLa,yIb,SY,yIb,bu,yIb,hY,yIb,z1a,yIb,MU,yIb,MP,yIb,a1,yIb,Tdb,yIb,In,yIb,HS,yIb,Tu,yIb,Bo,yIb,by,yIb,Xx,yIb,mx,yIb,MG,yIb,ww,yIb,Ndb,yIb,VX,yIb,bP,yIb,cYa,yIb,$X,yIb,gx,yIb,Qq,yIb,o_a,yIb,F1a,yIb,_V,yIb,$db,yIb,Ov,yIb,UB,yIb,Y_,yIb,ii,yIb,Tp,yIb,eKa,yIb,nm,yIb,wC,yIb,vx,yIb,iO,yIb,QNa,yIb,gHa,yIb,xN,yIb,CC,yIb,LG,yIb,$Ia,yIb,oU,yIb,c_,yIb,Mpb,yIb,Oj,yIb,$V,yIb,Hfb,yIb,py,yIb,o5a,yIb,OG,yIb,o$,yIb,cu,yIb,ZN,yIb,pS,yIb,aV,yIb,ID,yIb,_n,yIb,rLa,yIb,pgb,yIb,Dn,yIb,hu,yIb,rMa,yIb,ek,yIb,sba,yIb,AN,yIb,web,yIb,T_a,yIb,op,yIb,xcb,yIb,w0,yIb,bS,yIb,Z_,yIb,cca,yIb,KU,yIb,ay,yIb,uba,yIb,q$a,yIb,rV,yIb,on,yIb,eJ,yIb,NO,yIb,Ci,yIb,ul,yIb,FUa,yIb,BVa,yIb,ep,yIb,_I,yIb,AA,yIb,Nt,yIb,VU,yIb,IV,yIb,lt,yIb,jt,yIb,haa,yIb,jF,yIb,z8,yIb,jo,yIb,HRa,yIb,XE,yIb,lx,yIb,PW,yIb,KRa,yIb,SL,yIb,fS,yIb,ey,yIb,xo,yIb,q1,yIb,mSa,yIb,Vfb,yIb,Aeb,yIb,Np,yIb,lw,yIb,d2,yIb,Gba,yIb,JD,yIb,mbb,yIb,Sj,yIb,rdb,yIb,Zrb,yIb,np,yIb,XB,yIb,HUa,yIb,uo,yIb,kp,yIb,tU,yIb,mOa,yIb,kSa,yIb,UL,yIb,FZa,yIb,Mu,yIb,Kl,yIb,pD,yIb,VG,yIb,xC,yIb,fO,yIb,Qj,yIb,kS,yIb,$kb,yIb,sE,yIb,Bt,yIb,ibb,yIb,xdb,yIb,I1a,yIb,BF,yIb,ms,yIb,EF,yIb,X$,yIb,gu,yIb,dy,yIb,Bv,yIb,_Z,yIb,qW,yIb,JG,yIb,t1a,yIb,rx,yIb,Qba,yIb,EVa,yIb,cO,yIb,iA,yIb,ZIa,yIb,Uaa,yIb,Bba,yIb,y0,yIb,cw,yIb,GC,yIb,IU,yIb,Xs,yIb,QW,yIb,jVa,yIb,vU,yIb,oKa,yIb,iW,yIb,lv,yIb,wHa,yIb,$q,yIb,uJ,yIb,y1a,yIb,TJ,yIb,nl,yIb,cG,yIb,QQa,yIb,Yq,yIb,vO,yIb,ym,yIb,kD,yIb,JN,yIb,jG,yIb,hj,yIb,AB,yIb,iv,yIb,Ts,yIb,at,yIb,JB,yIb,mN,yIb,oH,yIb,jK,yIb,eSa,yIb,Dl,yIb,VB,yIb,WR,yIb,WV,yIb,VAb,yIb,fRa,yIb,bY,yIb,CQ,yIb,oB,yIb,Nr,yIb,$N,yIb,Fp,yIb,gKa,yIb,vXa,yIb,YO,yIb,Zm,yIb,bMa,yIb,ol,yIb,wM,yIb,ESa,yIb,_3a,yIb,Beb,yIb,OY,yIb,bk,yIb,OR,yIb,gV,yIb,hD,yIb,GF,yIb,Lo,yIb,WO,yIb,gr,yIb,NTa,yIb,u_a,yIb,Vq,yIb,ov,yIb,JA,yIb,qXa,yIb,VD,yIb,H8,yIb,zIa,yIb,sN,yIb,ON,yIb,_C,yIb,Waa,yIb,os,yIb,v9,yIb,oV,yIb,R_a,yIb,si,yIb,dMa,yIb,h_a,yIb,NSa,yIb,YGa,yIb,jA,yIb,FN,yIb,h8,yIb,R9,yIb,jTa,yIb,cV,yIb,qK,yIb,_x,yIb,Cu,yIb,jQ,yIb,_z,yIb,bUa,yIb,gNa,yIb,$o,yIb,eS,yIb,j0,yIb,F$a,yIb,yM,yIb,vl,yIb,tu,yIb,T1a,yIb,uLa,yIb,V7,yIb,FS,yIb,gB,yIb,ND,yIb,BQ,yIb,JP,yIb,oo,yIb,UQ,yIb,pA,yIb,Pbb,yIb,LRa,yIb,I$,yIb,$gb,yIb,p2,yIb,HSa,yIb,iB,yIb,sP,yIb,hs,yIb,l0,yIb,gH,yIb,wba,yIb,CU,yIb,zba,yIb,Yz,yIb,RUa,yIb,iy,yIb,Gq,yIb,D6a,yIb,scb,yIb,OMa,yIb,LF,yIb,TE,yIb,bw,yIb,qC,yIb,Tm,yIb,mv,yIb,PV,yIb,ar,yIb,qE,yIb,bG,yIb,W$,yIb,yC,yIb,nW,yIb,qVa,yIb,xKa,yIb,qbb,yIb,AF,yIb,qD,yIb,bi,yIb,aO,yIb,sbb,yIb,Saa,yIb,Vo,yIb,t0,yIb,iMa,yIb,xu,yIb,z0,yIb,Fm,yIb,jn,yIb,dD,yIb,lk,yIb,rr,yIb,Vj,yIb,IA,yIb,E9,yIb,Pj,yIb,kv,yIb,KQ,yIb,qTa,yIb,R8,yIb,Lx,yIb,d0,yIb,Mj,yIb,OGa,yIb,lB,yIb,lP,yIb,pE,yIb,KNa,yIb,dR,yIb,FGa,yIb,Qk,yIb,lp,yIb,y4a,yIb,Ls,yIb,rM,yIb,fy,yIb,IZa,yIb,en,yIb,xS,yIb,hYa,yIb,JR,yIb,xJ,yIb,xRa,yIb,YK,yIb,iH,yIb,Pu,yIb,ySa,yIb,pz,yIb,Edb,yIb,zUa,yIb,t4a,yIb,Un,yIb,On,yIb,Paa,yIb,_Ja,yIb,Wq,yIb,mJ,yIb,c4a,yIb,dn,yIb,ZJa,yIb,kW,yIb,OX,yIb,hr,yIb,ts,yIb,Gdb,yIb,fW,yIb,K1a,yIb,MR,yIb,i5a,yIb,rU,yIb,aba,yIb,PE,yIb,Sba,yIb,hk,yIb,mca,yIb,jw,yIb,RF,yIb,QYa,yIb,RL,yIb,oC,yIb,N1a,yIb,KY,yIb,AC,yIb,KR,yIb,xW,yIb,Efb,yIb,Fca,yIb,rv,yIb,ifb,yIb,K8,yIb,pk,yIb,$Wa,yIb,cC,yIb,k1a,yIb,sn,yIb,bp,yIb,$Ta,yIb,VZa,yIb,vcb,yIb,zm,yIb,BTa,yIb,$aa,yIb,Gfb,yIb,kr,yIb,Xu,yIb,YX,yIb,xG,yIb,mLa,yIb,h5a,yIb,kl,yIb,ZQ,yIb,aS,yIb,mdb,yIb,Ys,yIb,oRa,yIb,DMa,yIb,QN,yIb,vRa,yIb,T4a,yIb,w5a,yIb,nq,yIb,zn,yIb,Sv,yIb,tt,yIb,tA,yIb,hq,yIb,Rt,yIb,jRa,yIb,tl,yIb,b$a,yIb,LN,yIb,Qv,yIb,F6a,yIb,kdb,yIb,zI,yIb,pV,yIb,k4,yIb,ll,yIb,FB,yIb,lHa,yIb,NW,yIb,E0,yIb,LD,yIb,vu,yIb,uA,yIb,ox,yIb,yA,yIb,UWa,yIb,Lu,yIb,AD,yIb,CSa,yIb,JF,yIb,NF,yIb,Z7,yIb,wKa,yIb,DQ,yIb,Raa,yIb,Hp,yIb,wS,yIb,o_,yIb,rL,yIb,tn,yIb,QK,yIb,ME,yIb,HR,yIb,xi,yIb,aC,yIb,lZa,yIb,vC,yIb,GV,yIb,mK,yIb,YQ,yIb,ieb,yIb,C8,yIb,Dcb,yIb,U$,yIb,yr,yIb,nZa,yIb,vW,yIb,yD,yIb,vn,yIb,pv,yIb,HV,yIb,Ir,yIb,GN,yIb,tXa,yIb,bC,yIb,Es,yIb,nC,yIb,fH,yIb,CLa,yIb,hSa,yIb,js,yIb,P1a,yIb,yq,yIb,BK,yIb,g_,yIb,mO,yIb,LW,yIb,xK,yIb,Ix,yIb,dK,yIb,lE,yIb,yeb,yIb,$v,yIb,beb,yIb,s_a,yIb,LL,yIb,rRa,yIb,BI,yIb,$Xa,yIb,bZa,yIb,ocb,yIb,Yn,yIb,UU,yIb,c$a,yIb,pO,yIb,_Ra,yIb,dP,yIb,uV,yIb,yFa,yIb,uq,yIb,Vm,yIb,K9,yIb,WWa,yIb,Ns,yIb,DC,yIb,dH,yIb,aD,yIb,ITa,yIb,$u,yIb,Ct,yIb,OO,yIb,wSa,yIb,qR,yIb,uW,yIb,o1,yIb,mKa,yIb,JUa,yIb,QE,yIb,wi,yIb,H_,yIb,igb,yIb,Qx,yIb,jV,yIb,Tj,yIb,nMa,yIb,iq,yIb,Qm,yIb,oXa,yIb,pMa,yIb,dO,yIb,KW,yIb,qhb,yIb,Xz,yIb,wAa,yIb,tL,yIb,K7,yIb,Ux,yIb,fs,yIb,tC,yIb,XQa,yIb,bhb,yIb,O4a,yIb,jO,yIb,CN,yIb,wq,yIb,cq,yIb,uE,yIb,_U,yIb,sgb,yIb,l$a,yIb,as,yIb,ci,yIb,DTa,yIb,mm,yIb,ZWa,yIb,jQa,yIb,u2,yIb,yXa,yIb,Ru,yIb,IQ,yIb,PUa,yIb,Ot,yIb,Co,yIb,eV,yIb,rHa,yIb,_Q,yIb,ER,yIb,Z9,yIb,mV,yIb,z_,yIb,ho,yIb,HB,yIb,DZa,yIb,Hq,yIb,B$a,yIb,w1a,yIb,pH,yIb,Sgb,yIb,KD,yIb,uAa,yIb,aF,yIb,RU,yIb,nD,yIb,EV,yIb,r2,yIb,RQ,yIb,MN,yIb,MYa,yIb,wXa,yIb,FW,yIb,ZC,yIb,YF,yIb,Zj,yIb,iP,yIb,m2,yIb,dx,yIb,XQ,yIb,YUa,yIb,BS,yIb,Fo,yIb,Ut,yIb,e$a,yIb,Oo,yIb,cQ,yIb,FJ,yIb,Zdb,yIb,TL,yIb,r4a,yIb,gdb,yIb,rt,yIb,$U,yIb,UAb,yIb,Sp,yIb,bA,yIb,iRa,yIb,Xh,yIb,YMa,yIb,ERa,yIb,MY,yIb,fhb,yIb,j4a,yIb,a_,yIb,bVa,yIb,eR,yIb,UN,yIb,Zcb,yIb,e$,yIb,v_a,yIb,lM,yIb,TA,yIb,WZ,yIb,eA,yIb,oE,yIb,q8,yIb,li,yIb,eeb,yIb,uU,yIb,w4a,yIb,rS,yIb,es,yIb,Zt,yIb,gfb,yIb,UNa,yIb,sM,yIb,Uv,yIb,pq,yIb,Wp,yIb,o$a,yIb,Feb,yIb,G$,yIb,rH,yIb,cy,yIb,um,yIb,yp,yIb,gda,yIb,Eo,yIb,xv,yIb,YTa,yIb,gMa,yIb,d_,yIb,Vdb,yIb,YC,yIb,SG,yIb,aTa,yIb,gR,yIb,vdb,yIb,VQ,yIb,cY,yIb,f_a,yIb,feb,yIb,Cp,yIb,rQ,yIb,Dj,yIb,jHa,yIb,Bx,yIb,BMa,yIb,nF,yIb,NL,yIb,AFa,yIb,EU,yIb,P9,yIb,Iw,yIb,Rj,yIb,jx,yIb,Gv,yIb,UR,yIb,$h,yIb,b0,yIb,Jaa,yIb,h$a,yIb,S1a,yIb,SPa,yIb,nP,yIb,tK,yIb,X7,yIb,fA,yIb,BB,yIb,VO,yIb,z$a,yIb,Sm,yIb,STa,yIb,Z$,yIb,bD,yIb,kJ,yIb,jSa,yIb,eZa,yIb,uB,yIb,hQa,yIb,LUa,yIb,Y1,yIb,teb,yIb,wO,yIb,G0,yIb,iQ,yIb,Ugb,yIb,oOa,yIb,xF,yIb,nZ,yIb,lQa,yIb,PL,yIb,HA,yIb,Jl,yIb,cba,yIb,gy,yIb,KTa,yIb,QU,yIb,WUa,yIb,jM,yIb,nO,yIb,OF,yIb,f8,yIb,tB,yIb,PR,yIb,gbb,yIb,Zv,yIb,GHa,yIb,d8,yIb,sO,yIb,I8,yIb,Rdb,yIb,yUa,yIb,uP,yIb,M7,yIb,FQ,yIb,IRa,yIb,hca,yIb,UTa,yIb,X3a,yIb,As,yIb,vs,yIb,gZa,yIb,bL,yIb,AJ,yIb,Jeb,yIb,qm,yIb,Ho,yIb,IW,yIb,wA,yIb,Fs,yIb,ck,yIb,sB,yIb,r$,yIb,Lr,yIb,Gr,yIb,Lm,yIb,reb,yIb,Wo,yIb,Ap,yIb,_B,yIb,XY,yIb,lD,yIb,wo,yIb,jY,yIb,lV,yIb,Pf,yIb,fG,yIb,GRa,yIb,_4a,yIb,mRa,yIb,rSa,yIb,fq,yIb,cR,yIb,mA,yIb,WE,yIb,WSa,yIb,Mm,yIb,zr,yIb,cA,yIb,peb,yIb,khb,yIb,IF,yIb,KM,yIb,it,yIb,eo,yIb,YD,yIb,Al,yIb,Yh,yIb,mYa,yIb,ZZ,yIb,Wx,yIb,fdb,yIb,SYa,yIb,mE,yIb,L1a,yIb,Bi,yIb,oP,yIb,Bs,yIb,qgb,yIb,An,yIb,pB,yIb,ew,yIb,_h,yIb,ur,yIb,Pr,yIb,Taa,yIb,AK,yIb,yi,yIb,Sx,yIb,YA,yIb,fp,yIb,WU,yIb,Tt,yIb,aSa,yIb,y5a,yIb,ZA,yIb,OUa,yIb,zu,yIb,$p,yIb,fD,yIb,sQ,yIb,RA,yIb,Bm,yIb,Dx,yIb,sK,yIb,nv,yIb,SA,yIb,QJa,yIb,gW,yIb,dVa,yIb,c$,yIb,Ds,yIb,o8,yIb,ZQa,yIb,oS,yIb,gQ,yIb,pSa,yIb,Iv,yIb,jeb,yIb,C9,yIb,fZ,yIb,AW,yIb,wn,yIb,D1a,yIb,Fu,yIb,Ycb,yIb,QJ,yIb,Bu,yIb,Xp,yIb,hLa,yIb,_N,yIb,h4a,yIb,ULa,yIb,MB,yIb,Kcb,yIb,aM,yIb,Yo,yIb,tJ,yIb,ys,yIb,ihb,yIb,sV,yIb,m2a,yIb,Pt,yIb,QY,yIb,jH,yIb,Ws,yIb,xn,yIb,PF,yIb,fj,yIb,cM,yIb,gv,yIb,Rm,yIb,yQ,yIb,yF,yIb,dF,yIb,et,yIb,t2,yIb,m$a,yIb,tw,yIb,pF,yIb,fv,yIb,sTa,yIb,SB,yIb,AS,yIb,ft,yIb,lQ,yIb,$_,yIb,q_a,yIb,Jfb,yIb,sA,yIb,Kx,yIb,qB,yIb,ZLa,yIb,VA,yIb,B_a,yIb,Bcb,yIb,PB,yIb,a4a,yIb,Gs,yIb,zTa,yIb,WGa,yIb,Ml,yIb,wu,yIb,Rs,yIb,KP,yIb,c1,yIb,mW,yIb,fr,yIb,Bj,yIb,uS,yIb,eY,yIb,yl,yIb,so,yIb,$A,yIb,Cs,yIb,A4a,yIb,vN,yIb,ix,yIb,Tq,yIb,Bh,yIb,WG,yIb,mi,yIb,Ep,yIb,xs,yIb,RN,yIb,A8,yIb,_Sa,yIb,dZa,yIb,Dp,yIb,qPa,yIb,QP,yIb,i1a,yIb,Mo,yIb,J_,yIb,bW,yIb,q$,yIb,dZ,yIb,Dr,yIb,SE,yIb,aca,yIb,YWa,yIb,fib,yIb,fLa,yIb,vG,yIb,leb,yIb,gVa,yIb,oA,yIb,f_,yIb,fF,yIb,yv,yIb,gRa,yIb,Pp,yIb,Vn,yIb,uQ,yIb,gA,yIb,LC,yIb,bXa,yIb,DF,yIb,Dba,yIb,NB,yIb,LE,yIb,WTa,yIb,NU,yIb,f0,yIb,VF,yIb,Xm,yIb,di,yIb,Zq,yIb,aXa,yIb,dXa,yIb,cXa,yIb,idb,yIb,eXa,yIb,kYa,yIb,hXa,yIb,Cv,yIb,Zz,yIb,LA,yIb,OJa,yIb,hS,yIb,IM,yIb,zs,yIb,M9,yIb,dB,yIb,WD,yIb,tz,yIb,TG,yIb,ss,yIb,o1a,yIb,fK,yIb,C0,yIb,tKa,yIb,Haa,yIb,rs,yIb,WXa,yIb,HN,yIb,Fkb,yIb,Px,yIb,IC,yIb,K$a,yIb,_Y,yIb,$_a,yIb,B_,yIb,cs,yIb,Kn,yIb,ceb,yIb,HQ,yIb,il,yIb,kK,yIb,qv,yIb,Q1a,yIb,DJ,yIb,_1,yIb,_o,yIb,gn,yIb,keb,yIb,oJ,yIb,zo,yIb,Gca,yIb,ZE,yIb,aH,yIb,qO,yIb,uy,yIb,wW,yIb,Cdb,yIb,uKa,yIb,eHa,yIb,hhb,yIb,To,yIb,UE,yIb,Dm,yIb,x8,yIb,Wdb,yIb,Gu,yIb,GZa,yIb,Cm,yIb,er,yIb,crb,yIb,px,yIb,nba,yIb,oeb,yIb,EA,yIb,vM,yIb,IY,yIb,PZa,yIb,Cl,yIb,PTa,yIb,Z_a,yIb,ql,yIb,Lq,yIb,nk,yIb,ZY,yIb,yK,yIb,Vt,yIb,Ax,yIb,t$,yIb,sq,yIb,cH,yIb,VW,yIb,xl,yIb,ti,yIb,iLa,yIb,dr,yIb,an,yIb,RJ,yIb,ln,yIb,FA,yIb,qA,yIb,Ww,yIb,jv,yIb,Zo,yIb,wQ,yIb,pm,yIb,Mn,yIb,GNa,yIb,$$,yIb,XJa,yIb,ny,yIb,P3a,yIb,ao,yIb,$j,yIb,QGa,yIb,AU,yIb,Ygb,yIb,dhb,yIb,RTa,yIb,TB,yIb,Gl,yIb,$L,yIb,DQa,yIb,BA,yIb,ut,yIb,fQ,yIb,t8,yIb,Fq,yIb,Wca,yIb,Zh,yIb,cSa,yIb,Q0,yIb,qn,yIb,pJ,yIb,wx,yIb,MA,yIb,oF,yIb,ica,yIb,Deb,yIb,yN,yIb,qz,yIb,V1a,yIb,Lp,yIb,Heb,yIb,TF,yIb,OQa,yIb,WA,yIb,bF,yIb,M$a,yIb,q_,yIb,Wba,yIb,Hr,yIb,gC,yIb,S$,yIb,Zn,yIb,jgb,yIb,mS,yIb,FR,yIb,l2a,yIb,IS,yIb,ZU,yIb,vGa,yIb,gib,yIb,fca,yIb,MTa,yIb,cW,yIb,q1a,yIb,G1a,yIb,Us,yIb,pba,yIb,$n,yIb,M$,yIb,x_a,yIb,KB,yIb,f2,yIb,gk,yIb,Jm,yIb,aZ,yIb,Leb,yIb,Wv,yIb,fB,yIb,RR,yIb,kMa,yIb,SGa,yIb,V3a,yIb,yx,yIb,z_a,yIb,odb,yIb,Yx,yIb,kq,yIb,bYa,yIb,tm,yIb,HW,yIb,xHa,yIb,QB,yIb,My,yIb,j$a,yIb,MUa,yIb,Mq,yIb,s$a,yIb,_F,yIb,fE,yIb,sXa,yIb,dW,yIb,pRa,yIb,nB,yIb,iF,yIb,qP,yIb,zQ,yIb,UZ,yIb,ct,yIb,Et,yIb,HX,yIb,PRa,yIb,uRa,yIb,$La,yIb,YV,yIb,hP,yIb,co,yIb,lr,yIb,ml,yIb,sW,yIb,PP,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb,yIb];var se=[zIb,zIb,dm,zIb,$l,zIb,xCa,zIb,Xl,zIb,uCa,zIb,gEa,zIb,Nl,zIb,Tl,zIb,bm,zIb,Ul,zIb,Wl,zIb,jm,zIb,hEa,zIb,Fob,zIb,Sl,zIb,Pl,zIb,nDa,zIb,vCa,zIb,Rl,zIb,cm,zIb,Zl,zIb,gm,zIb,am,zIb,im,zIb,hm,zIb,em,zIb,_l,zIb,oDa,zIb,Ql,zIb,pDa,zIb,fm,zIb,Ol,zIb,jEa,zIb,Vl,zIb,qDa,zIb,Yl,zIb,wCa,zIb,iEa,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb,zIb];var te=[AIb,AIb,jba,AIb,hCb,AIb,iCb,AIb];var ue=[BIb,BIb,jCb,BIb];var ve=[CIb,CIb,O0,CIb];var we=[DIb,DIb,D$,DIb,eCb,DIb,DIb,DIb];var xe=[EIb,EIb,_m,EIb];var ye=[FIb,FIb,rpb,FIb,tpb,FIb,spb,FIb,qpb,FIb,ppb,FIb,opb,FIb,FIb,FIb];var ze=[GIb,GIb,fI,GIb,qI,GIb,gI,GIb,NH,GIb,QH,GIb,tHa,GIb,jC,GIb,AV,GIb,o4a,GIb,tI,GIb,Yrb,GIb,$g,GIb,Zf,GIb,mI,GIb,Tz,GIb,LH,GIb,Qh,GIb,Smb,GIb,Rq,GIb,p5a,GIb,Ng,GIb,eI,GIb,Yf,GIb,Y$a,GIb,cI,GIb,PH,GIb,BH,GIb,TD,GIb,kC,GIb,XH,GIb,Of,GIb,fJa,GIb,YH,GIb,pi,GIb,LK,GIb,hI,GIb,o7,GIb,dh,GIb,aI,GIb,bI,GIb,UH,GIb,PQ,GIb,If,GIb,GH,GIb,Rp,GIb,JH,GIb,lI,GIb,Dg,GIb,Fg,GIb,Rf,GIb,ah,GIb,eg,GIb,gg,GIb,lC,GIb,sI,GIb,Wf,GIb,dg,GIb,Qf,GIb,Eg,GIb,ip,GIb,iVa,GIb,DVa,GIb,wr,GIb,Mg,GIb,Yg,GIb,Hy,GIb,TR,GIb,YRa,GIb,Kg,GIb,Yr,GIb,Zg,GIb,Qg,GIb,jg,GIb,bh,GIb,Qz,GIb,Fhb,GIb,Pg,GIb,Chb,GIb,dJa,GIb,iI,GIb,ig,GIb,CVa,GIb,uI,GIb,Xf,GIb,wL,GIb,Xrb,GIb,VH,GIb,rI,GIb,_g,GIb,ES,GIb,c7,GIb,Wg,GIb,Zp,GIb,KH,GIb,bE,GIb,Rg,GIb,Ig,GIb,sr,GIb,kI,GIb,FH,GIb,HH,GIb,km,GIb,Jg,GIb,cg,GIb,zH,GIb,Vf,GIb,cJa,GIb,Hg,GIb,_H,GIb,ZH,GIb,$H,GIb,Sz,GIb,EH,GIb,MH,GIb,pI,GIb,gq,GIb,TH,GIb,Xg,GIb,SH,GIb,RH,GIb,Gg,GIb,Ghb,GIb,CD,GIb,Sg,GIb,eh,GIb,ch,GIb,jI,GIb,Dhb,GIb,CH,GIb,nI,GIb,zHa,GIb,OH,GIb,tH,GIb,Hhb,GIb,IH,GIb,hVa,GIb,$f,GIb,Tg,GIb,WH,GIb,bg,GIb,Vg,GIb,Og,GIb,oI,GIb,nH,GIb,p4a,GIb,Cg,GIb,Ehb,GIb,fg,GIb,mr,GIb,Yba,GIb,DH,GIb,dS,GIb,Fy,GIb,hg,GIb,iz,GIb,AH,GIb,U4a,GIb,dI,GIb,Lg,GIb,eJa,GIb,Bg,GIb,Ug,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb,GIb];var Ae=[HIb,HIb,bx,HIb,ax,HIb,$w,HIb];var Be=[IIb,IIb,mq,IIb,gga,IIb,YLa,IIb,Rea,IIb,lq,IIb,pzb,IIb,yyb,IIb,Mfa,IIb,hga,IIb,Fzb,IIb,lzb,IIb,Bzb,IIb,Pea,IIb,wzb,IIb,Azb,IIb,qCa,IIb,cEa,IIb,lfa,IIb,uzb,IIb,Czb,IIb,Dzb,IIb,zzb,IIb,vzb,IIb,xyb,IIb,kzb,IIb,izb,IIb,ofa,IIb,qzb,IIb,Tfb,IIb,ozb,IIb,mfa,IIb,Qea,IIb,Ega,IIb,nfa,IIb,sCa,IIb,eEa,IIb,Ezb,IIb,Jfa,IIb,lDa,IIb,jDa,IIb,Sea,IIb,tzb,IIb,Fga,IIb,xzb,IIb,nzb,IIb,Dga,IIb,jzb,IIb,fga,IIb,dEa,IIb,rCa,IIb,szb,IIb,Kfa,IIb,Gga,IIb,mzb,IIb,iga,IIb,mDa,IIb,kDa,IIb,rzb,IIb,yzb,IIb,fsb,IIb,Lfa,IIb,fEa,IIb,tCa,IIb];var Ce=[JIb,JIb,a_a,JIb];var De=[KIb,KIb,sob,KIb];var Ee=[LIb,LIb,wK,LIb,NR,LIb,KN,LIb,MF,LIb,hV,LIb,rR,LIb,aB,LIb,BJ,LIb,LU,LIb,NP,LIb,iS,LIb,tO,LIb,zx,LIb,ZG,LIb,TP,LIb,IR,LIb,Tx,LIb,rK,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb,LIb];var Fe=[MIb,MIb,Trb,MIb];var Ge=[NIb,NIb,Mgb,NIb];var He=[OIb,OIb,kHb,OIb,lHb,OIb,mHb,OIb,TBb,OIb,nHb,OIb,oHb,OIb,pHb,OIb,qHb,OIb,rHb,OIb,sHb,OIb,tHb,OIb,uHb,OIb,vHb,OIb,OIb,OIb,OIb,OIb];var Ie=[PIb,PIb,z2,PIb];var Je=[QIb,QIb,H$a,QIb,kLa,QIb,QIb,QIb];var Ke=[RIb,RIb,C8a,RIb,U7a,RIb,L8a,RIb,P0,RIb,m8a,RIb,M1,RIb,w7a,RIb,a8a,RIb,$6a,RIb,z8a,RIb,$8a,RIb,qtb,RIb,K8a,RIb,Ptb,RIb,uvb,RIb,yZa,RIb,_8a,RIb,q7a,RIb,H7a,RIb,U6a,RIb,mtb,RIb,Y8a,RIb,z7a,RIb,nEa,RIb,BCa,RIb,yEa,RIb,MCa,RIb,b6a,RIb,Y6a,RIb,Aqb,RIb,x7a,RIb,vvb,RIb,o7a,RIb,q8a,RIb,vtb,RIb,W6a,RIb,Q8a,RIb,ivb,RIb,Utb,RIb,Xtb,RIb,L1,RIb,kEa,RIb,yCa,RIb,h6a,RIb,wtb,RIb,zDa,RIb,bub,RIb,$tb,RIb,K7a,RIb,Y7a,RIb,Etb,RIb,mvb,RIb,S7a,RIb,h7a,RIb,X6a,RIb,j6a,RIb,u6a,RIb,M7a,RIb,J7a,RIb,k7a,RIb,L7a,RIb,xtb,RIb,rtb,RIb,h9a,RIb,Itb,RIb,f6a,RIb,a6a,RIb,_sb,RIb,T8a,RIb,l6a,RIb,Ktb,RIb,d7a,RIb,ltb,RIb,Ytb,RIb,Jtb,RIb,Z7a,RIb,P7a,RIb,Htb,RIb,X5a,RIb,F8a,RIb,B8a,RIb,qvb,RIb,g7a,RIb,X7a,RIb,y6a,RIb,yqb,RIb,Ctb,RIb,A7a,RIb,Q7a,RIb,Wtb,RIb,BDa,RIb,qqb,RIb,j7a,RIb,uYa,RIb,Ftb,RIb,p6a,RIb,G8a,RIb,_tb,RIb,w6a,RIb,m7a,RIb,s8a,RIb,lEa,RIb,zCa,RIb,ptb,RIb,xgb,RIb,O8a,RIb,f8a,RIb,ECa,RIb,Mtb,RIb,Dtb,RIb,g8a,RIb,h8a,RIb,NCa,RIb,zEa,RIb,U8a,RIb,ztb,RIb,b7a,RIb,DDa,RIb,MQa,RIb,evb,RIb,W7a,RIb,w$a,RIb,eub,RIb,C1,RIb,Ntb,RIb,wqb,RIb,yjb,RIb,Otb,RIb,z6a,RIb,y7a,RIb,Bjb,RIb,pvb,RIb,B7a,RIb,Cqb,RIb,tEa,RIb,HCa,RIb,P8a,RIb,M3a,RIb,i6a,RIb,Z5a,RIb,b8a,RIb,ttb,RIb,u8a,RIb,w8a,RIb,oEa,RIb,CCa,RIb,Z8a,RIb,N1,RIb,$5a,RIb,e6a,RIb,N7a,RIb,vEa,RIb,JCa,RIb,ADa,RIb,gsb,RIb,x6a,RIb,xDa,RIb,o6a,RIb,X8a,RIb,N8a,RIb,n6a,RIb,S6a,RIb,yDa,RIb,e9a,RIb,p7a,RIb,Z6a,RIb,GDa,RIb,r8a,RIb,aub,RIb,R8a,RIb,Btb,RIb,Gtb,RIb,o8a,RIb,Vtb,RIb,Xsb,RIb,m6a,RIb,l7a,RIb,W8a,RIb,s6a,RIb,c9a,RIb,uDa,RIb,GCa,RIb,sEa,RIb,Ylb,RIb,f7a,RIb,j8a,RIb,DCa,RIb,pEa,RIb,t8a,RIb,S8a,RIb,g9a,RIb,I8a,RIb,b9a,RIb,_6a,RIb,hvb,RIb,Wsb,RIb,dub,RIb,sDa,RIb,V6a,RIb,FEa,RIb,TCa,RIb,t7a,RIb,Ysb,RIb,FCa,RIb,rEa,RIb,A6a,RIb,t6a,RIb,n8a,RIb,k8a,RIb,a7a,RIb,vDa,RIb,i7a,RIb,y8a,RIb,D8a,RIb,C7a,RIb,ktb,RIb,Zsb,RIb,x8a,RIb,V7a,RIb,zjb,RIb,l4,RIb,fub,RIb,$ub,RIb,Ajb,RIb,G7a,RIb,MDa,RIb,v8a,RIb,D1,RIb,wEa,RIb,KCa,RIb,u7a,RIb,Ttb,RIb,Y5a,RIb,d6a,RIb,Ltb,RIb,lvb,RIb,A8a,RIb,CDa,RIb,Qtb,RIb,ntb,RIb,rDa,RIb,r6a,RIb,f9a,RIb,M8a,RIb,FDa,RIb,d9a,RIb,j9a,RIb,c8a,RIb,H8a,RIb,k6a,RIb,EDa,RIb,wDa,RIb,hsb,RIb,I7a,RIb,k9a,RIb,Rtb,RIb,s7,RIb,tDa,RIb,a9a,RIb,c7a,RIb,LCa,RIb,xEa,RIb,T7a,RIb,c6a,RIb,E8a,RIb,R7a,RIb,$7a,RIb,_5a,RIb,i7,RIb,ytb,RIb,s7a,RIb,p8a,RIb,r7a,RIb,J8a,RIb,Stb,RIb,Atb,RIb,i9a,RIb,Ztb,RIb,q6a,RIb,utb,RIb,B6a,RIb,T6a,RIb,l8a,RIb,e8a,RIb,Xlb,RIb,isb,RIb,cub,RIb,E7a,RIb,_7a,RIb,C6a,RIb,V5a,RIb,g6a,RIb,n7a,RIb,v6a,RIb,d8a,RIb,qEa,RIb,ACa,RIb,mEa,RIb,l9a,RIb,ICa,RIb,uEa,RIb,stb,RIb,O7a,RIb,v7a,RIb,V8a,RIb,otb,RIb,F7a,RIb,W5a,RIb,i8a,RIb,avb,RIb,dvb,RIb,e7a,RIb,D7a,RIb,dsb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb,RIb];var Le=[SIb,SIb,Jwb,SIb,$wb,SIb,Cyb,SIb,lxb,SIb,jwb,SIb,rxb,SIb,KWa,SIb,Swb,SIb,Rr,SIb,Mt,SIb,gwb,SIb,KQa,SIb,It,SIb,Nvb,SIb,AEa,SIb,OCa,SIb,yvb,SIb,Jt,SIb,lwb,SIb,Ht,SIb,Ywb,SIb,Lt,SIb,Gwb,SIb,Tvb,SIb,DEa,SIb,Hvb,SIb,Zvb,SIb,rwb,SIb,oxb,SIb,dwb,SIb,NDa,SIb,Sr,SIb,xwb,SIb,Qr,SIb,vda,SIb,Byb,SIb,owb,SIb,Tr,SIb,Mwb,SIb,ryb,SIb,uwb,SIb,IDa,SIb,JDa,SIb,RCa,SIb,ixb,SIb,Dyb,SIb,Awb,SIb,uxb,SIb,CEa,SIb,QCa,SIb,awb,SIb,cxb,SIb,Ft,SIb,syb,SIb,hPa,SIb,Kvb,SIb,Pwb,SIb,Bvb,SIb,tyb,SIb,Wvb,SIb,Qvb,SIb,JWa,SIb,UCa,SIb,GEa,SIb,Eyb,SIb,BEa,SIb,PCa,SIb,Kt,SIb,fxb,SIb,Evb,SIb,Vwb,SIb,Axb,SIb,HDa,SIb,N3a,SIb,KDa,SIb,uyb,SIb,Dwb,SIb,vyb,SIb,xxb,SIb,Gt,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb,SIb];var Me=[TIb,TIb,ipb,TIb];var Ne=[UIb,UIb,Twb,UIb,$vb,UIb,Ayb,UIb,Bxb,UIb,Kwb,UIb,Mvb,UIb,Avb,UIb,zyb,UIb,Svb,UIb,iwb,UIb,cwb,UIb,Dxb,UIb,Vvb,UIb,dxb,UIb,mwb,UIb,ywb,UIb,Ewb,UIb,axb,UIb,l5a,UIb,Pvb,UIb,Wwb,UIb,Bwb,UIb,Dvb,UIb,R3a,UIb,yxb,UIb,mxb,UIb,Hwb,UIb,jxb,UIb,Gvb,UIb,S3a,UIb,Jvb,UIb,Qwb,UIb,Zwb,UIb,fwb,UIb,pwb,UIb,gxb,UIb,Nwb,UIb,Yvb,UIb,pxb,UIb,xvb,UIb,vwb,UIb,swb,UIb,vxb,UIb,sxb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb,UIb];var Oe=[VIb,VIb,WN,VIb,ru,VIb,_E,VIb,xM,VIb,aL,VIb,vJ,VIb,Rh,VIb,zg,VIb,gE,VIb,sU,VIb,Jr,VIb,MC,VIb,cF,VIb,$z,VIb,yo,VIb,OB,VIb,oO,VIb,s5a,VIb,JW,VIb,Il,VIb,ri,VIb,rba,VIb,SK,VIb,QL,VIb,dA,VIb,cP,VIb,lW,VIb,$C,VIb,ML,VIb,TM,VIb,_y,VIb,PHa,VIb,jq,VIb,LP,VIb,kR,VIb,At,VIb,gj,VIb,YE,VIb,yG,VIb,KS,VIb,vo,VIb,WQ,VIb,Pq,VIb,oN,VIb,Do,VIb,mD,VIb,uC,VIb,PM,VIb,Cfb,VIb,yS,VIb,Xga,VIb,JS,VIb,KG,VIb,nA,VIb,UW,VIb,hW,VIb,qQa,VIb,fV,VIb,lK,VIb,VJ,VIb,ev,VIb,du,VIb,BAa,VIb,_p,VIb,bq,VIb,fn,VIb,hB,VIb,d0a,VIb,x1,VIb,Rx,VIb,vm,VIb,ZK,VIb,CB,VIb,HC,VIb,SN,VIb,gN,VIb,kF,VIb,Bq,VIb,eW,VIb,Jv,VIb,sHa,VIb,_A,VIb,GA,VIb,NE,VIb,SJ,VIb,Pm,VIb,mp,VIb,zK,VIb,yn,VIb,REb,VIb,jk,VIb,hA,VIb,kV,VIb,UHa,VIb,iR,VIb,SHa,VIb,Xn,VIb,Vx,VIb,_j,VIb,NA,VIb,cN,VIb,Xcb,VIb,VE,VIb,rm,VIb,gS,VIb,rC,VIb,HF,VIb,dC,VIb,mk,VIb,rl,VIb,mB,VIb,fN,VIb,nx,VIb,oQa,VIb,fo,VIb,QF,VIb,EJ,VIb,Km,VIb,s1a,VIb,XO,VIb,po,VIb,WM,VIb,Dq,VIb,dG,VIb,mP,VIb,dw,VIb,Cn,VIb,bO,VIb,tAa,VIb,tPa,VIb,xr,VIb,CK,VIb,eO,VIb,_L,VIb,jB,VIb,rn,VIb,pl,VIb,JQ,VIb,xw,VIb,Iq,VIb,rO,VIb,kt,VIb,Lv,VIb,rB,VIb,qV,VIb,UF,VIb,Wz,VIb,cD,VIb,zv,VIb,FF,VIb,DV,VIb,S9,VIb,NHa,VIb,JU,VIb,uw,VIb,gt,VIb,NN,VIb,gD,VIb,MD,VIb,zX,VIb,JM,VIb,tg,VIb,Ju,VIb,EC,VIb,lO,VIb,LR,VIb,VR,VIb,mo,VIb,$s,VIb,pR,VIb,BN,VIb,ZV,VIb,zl,VIb,kM,VIb,Nn,VIb,RP,VIb,mn,VIb,tV,VIb,XM,VIb,uu,VIb,XF,VIb,ki,VIb,RV,VIb,Pfb,VIb,OW,VIb,fx,VIb,zC,VIb,kx,VIb,lJ,VIb,pC,VIb,SU,VIb,aW,VIb,xO,VIb,Zx,VIb,kN,VIb,EQ,VIb,cn,VIb,XU,VIb,Yv,VIb,iG,VIb,XD,VIb,hR,VIb,bH,VIb,ap,VIb,$y,VIb,kk,VIb,pK,VIb,xR,VIb,$x,VIb,qJ,VIb,VHa,VIb,nNa,VIb,DN,VIb,jr,VIb,eD,VIb,THa,VIb,UM,VIb,sk,VIb,oW,VIb,uK,VIb,m4,VIb,VM,VIb,rD,VIb,Dv,VIb,KF,VIb,aG,VIb,HHa,VIb,KHa,VIb,Rv,VIb,vy,VIb,vB,VIb,wR,VIb,zF,VIb,RE,VIb,fC,VIb,hl,VIb,VV,VIb,OU,VIb,lS,VIb,VL,VIb,oy,VIb,dl,VIb,tR,VIb,Ag,VIb,Ei,VIb,Jn,VIb,Uo,VIb,jR,VIb,mR,VIb,Sq,VIb,Yt,VIb,Yj,VIb,lR,VIb,Q7,VIb,Ko,VIb,cS,VIb,rq,VIb,fJ,VIb,jN,VIb,zD,VIb,x9,VIb,Em,VIb,tM,VIb,vA,VIb,fR,VIb,wm,VIb,TPa,VIb,xA,VIb,Jx,VIb,Ph,VIb,Ro,VIb,wPa,VIb,Fj,VIb,z1,VIb,XA,VIb,Xq,VIb,qS,VIb,GQ,VIb,DA,VIb,bR,VIb,pP,VIb,Wu,VIb,nE,VIb,tP,VIb,El,VIb,Cr,VIb,Ej,VIb,Up,VIb,om,VIb,rE,VIb,NG,VIb,KA,VIb,sL,VIb,Wm,VIb,tr,VIb,DU,VIb,Dt,VIb,wG,VIb,OM,VIb,qu,VIb,MW,VIb,Cj,VIb,YM,VIb,no,VIb,gF,VIb,BW,VIb,qi,VIb,_M,VIb,yX,VIb,RM,VIb,IHa,VIb,JHa,VIb,LHa,VIb,MHa,VIb,XHa,VIb,YHa,VIb,ZHa,VIb,_Ha,VIb,$Ha,VIb,aIa,VIb,bIa,VIb,cIa,VIb,dIa,VIb,eIa,VIb,e8,VIb,RHa,VIb,bN,VIb,XG,VIb,Nu,VIb,$M,VIb,GB,VIb,hy,VIb,Cx,VIb,hx,VIb,hF,VIb,GQa,VIb,hQ,VIb,UA,VIb,wv,VIb,tS,VIb,xx,VIb,qH,VIb,nr,VIb,uPa,VIb,fk,VIb,LB,VIb,kQ,VIb,AI,VIb,Nq,VIb,GR,VIb,Nv,VIb,dJ,VIb,IN,VIb,Kp,VIb,G9,VIb,y1,VIb,rW,VIb,Hu,VIb,EW,VIb,$G,VIb,zJ,VIb,QA,VIb,Ly,VIb,AQ,VIb,Oq,VIb,xQ,VIb,vPa,VIb,mIa,VIb,hO,VIb,wl,VIb,kA,VIb,zi,VIb,QR,VIb,oda,VIb,CS,VIb,jP,VIb,CF,VIb,Eu,VIb,aJ,VIb,tE,VIb,GS,VIb,D_a,VIb,PO,VIb,eQ,VIb,hH,VIb,FRa,VIb,zA,VIb,Bp,VIb,tQ,VIb,eH,VIb,bM,VIb,Kv,VIb,yHa,VIb,yu,VIb,cr,VIb,RB,VIb,GW,VIb,hn,VIb,O_,VIb,Wh,VIb,TQ,VIb,QHa,VIb,nV,VIb,OHa,VIb,xp,VIb,bV,VIb,XC,VIb,CX,VIb,Imb,VIb,UPa,VIb,qU,VIb,eK,VIb,ej,VIb,BU,VIb,aw,VIb,$m,VIb,oD,VIb,Vr,VIb,qx,VIb,$B,VIb,IQa,VIb,n4,VIb,UG,VIb,ZM,VIb,RW,VIb,aN,VIb,Am,VIb,eB,VIb,wN,VIb,ei,VIb,OSa,VIb,Yob,VIb,St,VIb,WB,VIb,$r,VIb,hNa,VIb,wU,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb,VIb];var Pe=[WIb,WIb,mPa,WIb,b7,WIb,PU,WIb,R6,WIb,Ex,WIb,M6,WIb,bJ,WIb,rJ,WIb,uM,WIb,SP,WIb,p7,WIb,Geb,WIb,W6,WIb,dM,WIb,QM,WIb,V6,WIb,sD,WIb,ZO,WIb,G6,WIb,tD,WIb,dN,WIb,b0a,WIb,OA,WIb,DS,WIb,oPa,WIb,sC,WIb,H6,WIb,t4,WIb,x4,WIb,K6,WIb,YB,WIb,vV,WIb,lA,WIb,nJ,WIb,UJ,WIb,TU,WIb,eM,WIb,_O,WIb,cL,WIb,$6,WIb,Z6,WIb,zM,WIb,W3,WIb,P6,WIb,T6,WIb,SV,WIb,FYa,WIb,O6,WIb,N6,WIb,q4,WIb,a7,WIb,S6,WIb,j2,WIb,Y6,WIb,Fx,WIb,ufb,WIb,Q6,WIb,Wlb,WIb,SM,WIb,DYa,WIb,v4,WIb,jy,WIb,CYa,WIb,gO,WIb,pN,WIb,ZD,WIb,X6,WIb,JC,WIb,IX,WIb,r4,WIb,I6,WIb,EYa,WIb,J6,WIb,lN,WIb,PN,WIb,SF,WIb,XL,WIb,EN,WIb,sx,WIb,EB,WIb,XN,WIb,u4,WIb,U6,WIb,zS,WIb,w4,WIb,QO,WIb,F6,WIb,wJ,WIb,eF,WIb,sH,WIb,OE,WIb,s4,WIb,L6,WIb,_6,WIb,Wi,WIb,AM,WIb,kG,WIb,TK,WIb,jW,WIb,pmb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb,WIb];var Qe=[XIb,XIb,sDb,XIb];var Re=[YIb,YIb];var Se=[ZIb,ZIb,wyb,ZIb,CE,ZIb,sea,ZIb,Xub,ZIb,Ffa,ZIb,DWa,ZIb,Aub,ZIb,jfa,ZIb,qo,ZIb,IWa,ZIb,Bob,ZIb,Dob,ZIb,vub,ZIb,jFa,ZIb,tFa,ZIb,lOa,ZIb,xea,ZIb,Cea,ZIb,Bub,ZIb,WCa,ZIb,IEa,ZIb,Bga,ZIb,Eea,ZIb,Mub,ZIb,dga,ZIb,Fea,ZIb,EEa,ZIb,SCa,ZIb,Dea,ZIb,slb,ZIb,Gub,ZIb,gw,ZIb,I3a,ZIb,uFa,ZIb,aFa,ZIb,iDb,ZIb,uea,ZIb,Bea,ZIb,QDa,ZIb,LDa,ZIb,qaa,ZIb,LWa,ZIb,xub,ZIb,Cga,ZIb,Aea,ZIb,Nea,ZIb,tea,ZIb,zea,ZIb,Nub,ZIb,GWa,ZIb,E1,ZIb,bga,ZIb,Wub,ZIb,wea,ZIb,Aga,ZIb,wub,ZIb,G3a,ZIb,xt,ZIb,Rub,ZIb,oaa,ZIb,Jub,ZIb,Lub,ZIb,H3a,ZIb,Cub,ZIb,vea,ZIb,mFa,ZIb,kFa,ZIb,kfa,ZIb,zub,ZIb,HE,ZIb,Oea,ZIb,EWa,ZIb,Uub,ZIb,f7,ZIb,Fub,ZIb,rea,ZIb,wFa,ZIb,cFa,ZIb,cga,ZIb,bHa,ZIb,CWa,ZIb,Iub,ZIb,PDa,ZIb,nkb,ZIb,$Ea,ZIb,hkb,ZIb,esb,ZIb,HWa,ZIb,gOa,ZIb,Mea,ZIb,zga,ZIb,Hub,ZIb,bFa,ZIb,vFa,ZIb,zt,ZIb,Gfa,ZIb,Kub,ZIb,qea,ZIb,iw,ZIb,yt,ZIb,Ifa,ZIb,O5a,ZIb,g7,ZIb,sub,ZIb,dHa,ZIb,hw,ZIb,nFa,ZIb,lFa,ZIb,Yub,ZIb,Cob,ZIb,Vub,ZIb,Eob,ZIb,yea,ZIb,cHa,ZIb,Qub,ZIb,yub,ZIb,MWa,ZIb,EE,ZIb,R5a,ZIb,hfa,ZIb,Pub,ZIb,Sub,ZIb,Hfa,ZIb,S5a,ZIb,XCa,ZIb,JEa,ZIb,uub,ZIb,FWa,ZIb,Lea,ZIb,dFa,ZIb,xFa,ZIb,ifa,ZIb,F3a,ZIb,ro,ZIb,ega,ZIb,o0,ZIb,Npb,ZIb,wt,ZIb,tub,ZIb,N5a,ZIb,Dub,ZIb,Zub,ZIb,Eub,ZIb,Oub,ZIb,fw,ZIb,Tub,ZIb,GE,ZIb,BWa,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb,ZIb];var Te=[_Ib,_Ib,zq,_Ib,Aq,_Ib,dp,_Ib,mUa,_Ib,cp,_Ib,lUa,_Ib,_s,_Ib];var Ue=[$Ib,$Ib,bwb,$Ib,Fwb,$Ib,Ivb,$Ib,Xvb,$Ib,hxb,$Ib,wwb,$Ib,ODa,$Ib,HEa,$Ib,VCa,$Ib,kwb,$Ib,Ovb,$Ib,Cwb,$Ib,txb,$Ib,_vb,$Ib,Lwb,$Ib,Rwb,$Ib,zvb,$Ib,zwb,$Ib,nxb,$Ib,Iwb,$Ib,nwb,$Ib,exb,$Ib,Uvb,$Ib,qxb,$Ib,ewb,$Ib,Rvb,$Ib,qwb,$Ib,kxb,$Ib,wvb,$Ib,Owb,$Ib,LQa,$Ib,bxb,$Ib,Cxb,$Ib,_wb,$Ib,wxb,$Ib,zxb,$Ib,Uwb,$Ib,Cvb,$Ib,twb,$Ib,Xwb,$Ib,Lvb,$Ib,Fvb,$Ib,hwb,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib,$Ib];var Ve=[aJb,aJb,lpb,aJb,gpb,aJb,kpb,aJb,npb,aJb,aJb,aJb,aJb,aJb,aJb,aJb];var We=[bJb,bJb,zgb,bJb,zob,bJb,bJb,bJb];var Xe=[cJb,cJb,znb,cJb,xva,cJb,P5,cJb,axa,cJb,zia,cJb,N2,cJb,Apa,cJb,Vxb,cJb,t5,cJb,qxa,cJb,cpa,cJb,_ta,cJb,Gib,cJb,jha,cJb,Lib,cJb,H5a,cJb,Zka,cJb,Tva,cJb,Sja,cJb,Dha,cJb,Epa,cJb,Aqa,cJb,fsa,cJb,Hpa,cJb,yva,cJb,N4a,cJb,jqa,cJb,nWa,cJb,gla,cJb,dwa,cJb,uua,cJb,Lsa,cJb,Bna,cJb,Ova,cJb,Nya,cJb,k6,cJb,vya,cJb,Gnb,cJb,Fsa,cJb,Oya,cJb,Rya,cJb,Zxa,cJb,Asa,cJb,iza,cJb,pya,cJb,ewa,cJb,R4,cJb,Qya,cJb,YVa,cJb,lxa,cJb,Bra,cJb,Tya,cJb,Rxa,cJb,HXa,cJb,fwa,cJb,OJ,cJb,Spa,cJb,Eva,cJb,$3,cJb,esa,cJb,Isa,cJb,kza,cJb,V2a,cJb,zva,cJb,vWa,cJb,Mib,cJb,Cya,cJb,xob,cJb,ssa,cJb,ayb,cJb,_ya,cJb,l5,cJb,rra,cJb,pta,cJb,_ib,cJb,G2,cJb,bta,cJb,rjb,cJb,Inb,cJb,Jra,cJb,Tra,cJb,L4a,cJb,Uxa,cJb,hCa,cJb,VDa,cJb,Voa,cJb,m7,cJb,jra,cJb,Oxa,cJb,Rnb,cJb,sxa,cJb,C6,cJb,Sya,cJb,rta,cJb,Mpa,cJb,Cua,cJb,U4,cJb,Wxa,cJb,Sqa,cJb,unb,cJb,cta,cJb,sua,cJb,usa,cJb,aEa,cJb,qkb,cJb,Vra,cJb,e5,cJb,z3,cJb,msb,cJb,Nja,cJb,rlb,cJb,KXa,cJb,FXa,cJb,I5,cJb,Ipa,cJb,lua,cJb,$ib,cJb,q6,cJb,Z2,cJb,sia,cJb,D5,cJb,Zwa,cJb,CXa,cJb,Xra,cJb,Hea,cJb,Fxb,cJb,nCa,cJb,$Da,cJb,Cnb,cJb,T5a,cJb,Aib,cJb,Qta,cJb,oya,cJb,f3,cJb,Txb,cJb,Gpa,cJb,c4,cJb,_5,cJb,Lca,cJb,A5,cJb,Jya,cJb,_ka,cJb,HKa,cJb,l6,cJb,dma,cJb,p3,cJb,Gqa,cJb,Fta,cJb,uma,cJb,oyb,cJb,lkb,cJb,Vqa,cJb,Wua,cJb,tjb,cJb,rva,cJb,Vxa,cJb,Zib,cJb,Qpa,cJb,j5,cJb,e5a,cJb,tia,cJb,gpa,cJb,cva,cJb,qua,cJb,oWa,cJb,zta,cJb,Jsa,cJb,wjb,cJb,Mnb,cJb,yWa,cJb,Wja,cJb,x3,cJb,o5,cJb,ikb,cJb,Pib,cJb,Cib,cJb,_oa,cJb,Xqa,cJb,M2,cJb,Bja,cJb,F5,cJb,Awa,cJb,Ioa,cJb,jWa,cJb,Mva,cJb,Nva,cJb,l3,cJb,kCa,cJb,zra,cJb,o6,cJb,Axa,cJb,Uta,cJb,bra,cJb,d4,cJb,M4a,cJb,rsa,cJb,Gna,cJb,V4,cJb,UVa,cJb,Bwa,cJb,Xta,cJb,Mqa,cJb,Iib,cJb,zWa,cJb,bDa,cJb,pma,cJb,p5,cJb,v6,cJb,W2a,cJb,Npa,cJb,Vya,cJb,qta,cJb,eDa,cJb,gqa,cJb,mjb,cJb,qwa,cJb,fpa,cJb,cLa,cJb,q3,cJb,Fpa,cJb,Ppa,cJb,jia,cJb,fia,cJb,ata,cJb,mia,cJb,s3,cJb,hrb,cJb,$5,cJb,gyb,cJb,lva,cJb,vsa,cJb,bza,cJb,Oqa,cJb,AWa,cJb,Kxa,cJb,V2,cJb,F2,cJb,Xya,cJb,eya,cJb,cqa,cJb,q5,cJb,Ora,cJb,$xb,cJb,bpa,cJb,c5a,cJb,gCa,cJb,UDa,cJb,k7,cJb,nia,cJb,bya,cJb,Mra,cJb,dza,cJb,ynb,cJb,u6,cJb,Kpa,cJb,xwa,cJb,w3,cJb,kla,cJb,Bsa,cJb,qya,cJb,s5,cJb,Q4,cJb,nya,cJb,uxa,cJb,o3,cJb,jsa,cJb,OXa,cJb,Dta,cJb,Pya,cJb,Ava,cJb,Fxa,cJb,iha,cJb,Fib,cJb,owa,cJb,kva,cJb,hqa,cJb,ema,cJb,Kra,cJb,Dwa,cJb,n5,cJb,X2a,cJb,Vja,cJb,cma,cJb,W5,cJb,Gya,cJb,Ewa,cJb,sma,cJb,Rva,cJb,dra,cJb,Jqa,cJb,Pqa,cJb,qWa,cJb,aza,cJb,tnb,cJb,Yua,cJb,Ksa,cJb,eia,cJb,qia,cJb,Cra,cJb,asa,cJb,Zua,cJb,fla,cJb,mva,cJb,cwa,cJb,Fra,cJb,Vnb,cJb,VVa,cJb,yqa,cJb,Ura,cJb,lyb,cJb,Q5,cJb,mma,cJb,Xxa,cJb,Xsa,cJb,Joa,cJb,Qua,cJb,vua,cJb,SXa,cJb,vib,cJb,Dra,cJb,M0,cJb,Wfb,cJb,Tja,cJb,$ta,cJb,kjb,cJb,Kta,cJb,s6,cJb,_ua,cJb,Anb,cJb,Pja,cJb,cra,cJb,cyb,cJb,pWa,cJb,Zta,cJb,tma,cJb,aua,cJb,Z4,cJb,Msa,cJb,tqa,cJb,hva,cJb,gia,cJb,xib,cJb,ylb,cJb,zlb,cJb,Alb,cJb,tlb,cJb,ulb,cJb,vlb,cJb,wlb,cJb,Blb,cJb,Clb,cJb,Dxa,cJb,cya,cJb,Sta,cJb,kyb,cJb,Q2,cJb,_3,cJb,Wwa,cJb,d5,cJb,$ua,cJb,jya,cJb,Iqa,cJb,Ixa,cJb,lob,cJb,tva,cJb,OVa,cJb,mxa,cJb,Fqa,cJb,$ya,cJb,nra,cJb,_ga,cJb,lia,cJb,fWa,cJb,Qsa,cJb,lra,cJb,d7,cJb,cWa,cJb,isa,cJb,a5,cJb,ala,cJb,oia,cJb,yia,cJb,M2a,cJb,wwa,cJb,Yta,cJb,Dqa,cJb,Iva,cJb,Ysa,cJb,j7,cJb,O5,cJb,qjb,cJb,pwa,cJb,wpa,cJb,Mua,cJb,Rib,cJb,Ena,cJb,Jea,cJb,IVa,cJb,jua,cJb,Y8,cJb,$wa,cJb,kwa,cJb,B6,cJb,hra,cJb,d3,cJb,iWa,cJb,e3,cJb,$xa,cJb,Uva,cJb,sib,cJb,rWa,cJb,j3,cJb,E_,cJb,$4,cJb,Fwa,cJb,Bva,cJb,Wya,cJb,Ywa,cJb,g6,cJb,wra,cJb,qra,cJb,ksa,cJb,pjb,cJb,U3a,cJb,_wa,cJb,qZa,cJb,Cpa,cJb,Qka,cJb,Jva,cJb,ukb,cJb,eLa,cJb,K5a,cJb,lya,cJb,Ckb,cJb,D_,cJb,d5a,cJb,L5,cJb,Lna,cJb,gDa,cJb,nta,cJb,vha,cJb,w7,cJb,hsa,cJb,Dya,cJb,JVa,cJb,r5,cJb,qpa,cJb,lta,cJb,psa,cJb,A6,cJb,$sa,cJb,lba,cJb,Yoa,cJb,bjb,cJb,c5,cJb,ipa,cJb,f6,cJb,i3,cJb,fta,cJb,Hib,cJb,Dva,cJb,xha,cJb,Cjb,cJb,x5,cJb,dca,cJb,v3,cJb,H2,cJb,Yra,cJb,Csa,cJb,tpa,cJb,M5,cJb,Uha,cJb,dLa,cJb,Ira,cJb,Tnb,cJb,Lra,cJb,$oa,cJb,Jta,cJb,wua,cJb,Dja,cJb,Kya,cJb,Ita,cJb,N0,cJb,gjb,cJb,Rua,cJb,u5,cJb,wva,cJb,w6,cJb,Hta,cJb,Bqa,cJb,Mwa,cJb,ywa,cJb,Xoa,cJb,wqa,cJb,rua,cJb,Lpa,cJb,P2,cJb,b5,cJb,Fya,cJb,xsa,cJb,e4,cJb,i6,cJb,$Va,cJb,r3,cJb,Lqa,cJb,Bib,cJb,qsb,cJb,skb,cJb,sWa,cJb,Iwa,cJb,Onb,cJb,Gxa,cJb,uha,cJb,tYa,cJb,qma,cJb,Rra,cJb,bK,cJb,Rwa,cJb,Dpa,cJb,vkb,cJb,uva,cJb,v5,cJb,Qqa,cJb,oCa,cJb,Zya,cJb,pyb,cJb,jpa,cJb,uya,cJb,Qra,cJb,cua,cJb,Unb,cJb,KVa,cJb,Hwa,cJb,r7,cJb,Z8,cJb,eva,cJb,djb,cJb,J5a,cJb,Y4,cJb,Mxa,cJb,h6,cJb,hta,cJb,Vsa,cJb,Rpa,cJb,fyb,cJb,yua,cJb,Zva,cJb,Ona,cJb,Sua,cJb,Mna,cJb,m6,cJb,snb,cJb,Kib,cJb,tua,cJb,MVa,cJb,bmb,cJb,zma,cJb,E2,cJb,k3,cJb,vqa,cJb,yra,cJb,ora,cJb,Qxb,cJb,i4,cJb,Yib,cJb,Eib,cJb,Exa,cJb,oxa,cJb,Lta,cJb,Wpa,cJb,kua,cJb,opa,cJb,tna,cJb,xya,cJb,Lja,cJb,hwa,cJb,ZVa,cJb,xWa,cJb,una,cJb,Vha,cJb,wxa,cJb,rha,cJb,Iya,cJb,c6,cJb,rna,cJb,hla,cJb,ljb,cJb,MJ,cJb,Lnb,cJb,tta,cJb,bxa,cJb,U5a,cJb,ita,cJb,mCa,cJb,gya,cJb,x6,cJb,Enb,cJb,pia,cJb,$ha,cJb,zib,cJb,Gsa,cJb,ura,cJb,Uwa,cJb,Rxb,cJb,L2a,cJb,Ixb,cJb,Pxa,cJb,NVa,cJb,jCa,cJb,XDa,cJb,_4,cJb,gra,cJb,xpa,cJb,ava,cJb,P2a,cJb,Fua,cJb,jyb,cJb,pra,cJb,sjb,cJb,Jnb,cJb,dta,cJb,cxa,cJb,Jxa,cJb,Jua,cJb,Rta,cJb,YXa,cJb,Upa,cJb,cla,cJb,Toa,cJb,uqa,cJb,bwa,cJb,xra,cJb,Gua,cJb,_qa,cJb,Lua,cJb,Qja,cJb,Wnb,cJb,ela,cJb,_va,cJb,$ka,cJb,Wva,cJb,f5a,cJb,gxa,cJb,fza,cJb,dxa,cJb,j6,cJb,osa,cJb,Cja,cJb,xxa,cJb,Xpa,cJb,R5,cJb,y5,cJb,mob,cJb,mfb,cJb,iva,cJb,vpa,cJb,Cva,cJb,msa,cJb,Xwa,cJb,jxa,cJb,Gta,cJb,mya,cJb,zxa,cJb,N2a,cJb,Fna,cJb,e6,cJb,yxa,cJb,Uxb,cJb,Kua,cJb,Vpa,cJb,XVa,cJb,dDa,cJb,kta,cJb,Pha,cJb,Nib,cJb,Kea,cJb,Mya,cJb,Lxb,cJb,Kxb,cJb,Bia,cJb,Aya,cJb,awa,cJb,dsa,cJb,Knb,cJb,kxa,cJb,Eta,cJb,Hra,cJb,Hna,cJb,Zpa,cJb,Q2a,cJb,tya,cJb,Nnb,cJb,Qwa,cJb,Xua,cJb,zqa,cJb,b3,cJb,Lya,cJb,i5,cJb,eyb,cJb,X5,cJb,jta,cJb,rqa,cJb,Epb,cJb,gua,cJb,h5,cJb,Txa,cJb,myb,cJb,T4,cJb,Xva,cJb,Yxa,cJb,Bua,cJb,xta,cJb,Hxb,cJb,Kca,cJb,vnb,cJb,Nxa,cJb,lfb,cJb,uta,cJb,Swa,cJb,T5,cJb,_2,cJb,nqa,cJb,Dna,cJb,sva,cJb,Opa,cJb,Lwa,cJb,Era,cJb,Nta,cJb,fqa,cJb,cmb,cJb,Sfb,cJb,nfb,cJb,ajb,cJb,_ra,cJb,Zga,cJb,upa,cJb,k2,cJb,zwa,cJb,QVa,cJb,p6,cJb,bqa,cJb,pva,cJb,$Ca,cJb,qlb,cJb,Jha,cJb,ksb,cJb,Wxb,cJb,yya,cJb,dva,cJb,Kja,cJb,Z5,cJb,yma,cJb,g4a,cJb,Hxa,cJb,wnb,cJb,lha,cJb,jva,cJb,I2,cJb,Kna,cJb,okb,cJb,ypa,cJb,Ypa,cJb,Bta,cJb,Iha,cJb,z6,cJb,byb,cJb,uWa,cJb,Bpa,cJb,Bnb,cJb,Jna,cJb,sZa,cJb,U5,cJb,Dib,cJb,Rsa,cJb,Cqa,cJb,aqa,cJb,dyb,cJb,Yqa,cJb,oua,cJb,C5,cJb,oqa,cJb,RVa,cJb,nua,cJb,aya,cJb,vma,cJb,tZa,cJb,jza,cJb,Jpa,cJb,iyb,cJb,njb,cJb,uia,cJb,sta,cJb,a6,cJb,Dnb,cJb,Wqa,cJb,Iua,cJb,tra,cJb,Zqa,cJb,b4,cJb,bla,cJb,tib,cJb,NJ,cJb,Nsa,cJb,_sa,cJb,Nua,cJb,iwa,cJb,wma,cJb,Eua,cJb,Mxb,cJb,Gha,cJb,dya,cJb,Woa,cJb,Y2a,cJb,Mta,cJb,V5,cJb,SVa,cJb,Psa,cJb,A2,cJb,vra,cJb,iqa,cJb,Dua,cJb,xia,cJb,Xib,cJb,kha,cJb,kia,cJb,gwa,cJb,mqa,cJb,ixa,cJb,Cta,cJb,_Va,cJb,Vva,cJb,Hya,cJb,rxa,cJb,eqa,cJb,d6,cJb,Sva,cJb,wkb,cJb,lWa,cJb,Hsa,cJb,rya,cJb,Pua,cJb,O2a,cJb,R2,cJb,Vta,cJb,Uqa,cJb,PVa,cJb,S5,cJb,pqa,cJb,I5a,cJb,v7,cJb,Ara,cJb,Dsa,cJb,Sib,cJb,E5,cJb,iia,cJb,aDa,cJb,_xb,cJb,bsa,cJb,Lxa,cJb,Fnb,cJb,fua,cJb,iua,cJb,mta,cJb,nva,cJb,dia,cJb,WVa,cJb,wsa,cJb,ejb,cJb,X4,cJb,wib,cJb,Pva,cJb,Ata,cJb,PXa,cJb,nyb,cJb,K4a,cJb,dua,cJb,xma,cJb,dqa,cJb,xlb,cJb,fma,cJb,l2,cJb,mWa,cJb,kra,cJb,spa,cJb,Hha,cJb,cza,cJb,Uja,cJb,Hnb,cJb,Uoa,cJb,era,cJb,$va,cJb,H5,cJb,eza,cJb,t3,cJb,Tqa,cJb,_Da,cJb,Gra,cJb,j4,cJb,kfb,cJb,Sra,cJb,hia,cJb,c3,cJb,Rja,cJb,csa,cJb,wya,cJb,k5,cJb,yib,cJb,Tib,cJb,oma,cJb,Hoa,cJb,Pta,cJb,B5,cJb,Yya,cJb,Xxb,cJb,Lva,cJb,hyb,cJb,HVa,cJb,fjb,cJb,S4,cJb,gWa,cJb,b6,cJb,$ga,cJb,m3,cJb,exa,cJb,Sxa,cJb,Jwa,cJb,Pnb,cJb,Kwa,cJb,Zoa,cJb,gza,cJb,rma,cJb,Nwa,cJb,fya,cJb,Nqa,cJb,u3,cJb,E6,cJb,hza,cJb,bua,cJb,Gxb,cJb,Qnb,cJb,dla,cJb,Pwa,cJb,Uib,cJb,vta,cJb,J5,cJb,G5,cJb,h4,cJb,Mja,cJb,Wta,cJb,_xa,cJb,Ry,cJb,Y2,cJb,Tua,cJb,r6,cJb,Iea,cJb,cjb,cJb,Nra,cJb,fva,cJb,jjb,cJb,eta,cJb,yta,cJb,Sha,cJb,Nna,cJb,Kva,cJb,$qa,cJb,ppa,cJb,Owa,cJb,Osa,cJb,Xnb,cJb,$lb,cJb,Y5,cJb,qqa,cJb,y6,cJb,W_a,cJb,Aia,cJb,Oxb,cJb,vva,cJb,y3,cJb,ova,cJb,O2,cJb,Vib,cJb,Ssa,cJb,wWa,cJb,ZXa,cJb,z5,cJb,X2,cJb,gsa,cJb,m5,cJb,f4,cJb,Usa,cJb,rpa,cJb,fra,cJb,gva,cJb,hjb,cJb,K5,cJb,Nxb,cJb,Vua,cJb,qsa,cJb,MXa,cJb,xqa,cJb,n3,cJb,ara,cJb,Rqa,cJb,epa,cJb,Yga,cJb,sFb,cJb,RXa,cJb,lsa,cJb,adb,cJb,Qfb,cJb,Ufb,cJb,Oua,cJb,tsa,cJb,Hua,cJb,ota,cJb,Oib,cJb,Aja,cJb,iCa,cJb,WDa,cJb,t6,cJb,jwa,cJb,sna,cJb,zsa,cJb,Pka,cJb,erb,cJb,frb,cJb,grb,cJb,twa,cJb,F_,cJb,kpa,cJb,Jxb,cJb,TVa,cJb,sqa,cJb,ijb,cJb,Tha,cJb,Snb,cJb,sra,cJb,vxa,cJb,B3,cJb,Sxb,cJb,_2a,cJb,Bxa,cJb,Esa,cJb,fha,cJb,txa,cJb,hxa,cJb,wia,cJb,fDa,cJb,uwa,cJb,nsa,cJb,hWa,cJb,zpa,cJb,nxa,cJb,Z2a,cJb,Hqa,cJb,Yxb,cJb,ojb,cJb,Pxb,cJb,Fva,cJb,jla,cJb,_pa,cJb,g5,cJb,wha,cJb,D6,cJb,uib,cJb,Cxa,cJb,osb,cJb,swa,cJb,Gwa,cJb,g3,cJb,ZDa,cJb,lCa,cJb,Cna,cJb,AXa,cJb,Wra,cJb,hya,cJb,Eqa,cJb,Pra,cJb,Eya,cJb,rwa,cJb,npa,cJb,lwa,cJb,fxa,cJb,Qxa,cJb,iDa,cJb,zya,cJb,iya,cJb,Rfb,cJb,Wib,cJb,lpa,cJb,Ofb,cJb,vjb,cJb,Yva,cJb,dWa,cJb,W2,cJb,ysa,cJb,xua,cJb,cDa,cJb,Oja,cJb,Tsa,cJb,hpa,cJb,Qib,cJb,N5,cJb,eua,cJb,Uua,cJb,amb,cJb,lMa,cJb,n6,cJb,xnb,cJb,Wsa,cJb,kqa,cJb,aWa,cJb,$ra,cJb,Zxb,cJb,J2,cJb,$cb,cJb,hDa,cJb,Qva,cJb,LVa,cJb,Ina,cJb,ujb,cJb,mua,cJb,qyb,cJb,kya,cJb,Kqa,cJb,nCb,cJb,rkb,cJb,tFb,cJb,Tpa,cJb,K2a,cJb,Zra,cJb,tWa,cJb,Gva,cJb,vwa,cJb,J4a,cJb,dpa,cJb,apa,cJb,Jib,cJb,Ota,cJb,$pa,cJb,pCa,cJb,bEa,cJb,eWa,cJb,ila,cJb,nwa,cJb,Uya,cJb,hua,cJb,Twa,cJb,pxa,cJb,Dlb,cJb,Elb,cJb,bva,cJb,Bya,cJb,qva,cJb,mpa,cJb,w5,cJb,Xja,cJb,Tta,cJb,mwa,cJb,Vwa,cJb,Zsa,cJb,ira,cJb,Hva,cJb,ria,cJb,xjb,cJb,bWa,cJb,a4,cJb,gta,cJb,sya,cJb,W4,cJb,Rka,cJb,zua,cJb,f5,cJb,YDa,cJb,nma,cJb,pua,cJb,wta,cJb,kWa,cJb,via,cJb,lqa,cJb,Ska,cJb,Cwa,cJb,Aua,cJb,Goa,cJb,mra,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb,cJb];var Ye=[dJb,dJb];var Ze=[eJb,eJb,_J,eJb,rmb,eJb,nmb,eJb,omb,eJb,mmb,eJb,eJb,eJb,eJb,eJb];var _e=[fJb,fJb,h2,fJb,iTa,fJb,vba,fJb,ISa,fJb,EZa,fJb,A0,fJb,T8,fJb,iYa,fJb,iY,fJb,wH,fJb,xeb,fJb,vAa,fJb,XWa,fJb,b_,fJb,v5a,fJb,iSa,fJb,gLa,fJb,Vgb,fJb,f$,fJb,rXa,fJb,aeb,fJb,lYa,fJb,i1,fJb,dKa,fJb,a$,fJb,n2,fJb,H$,fJb,EQa,fJb,Fba,fJb,WX,fJb,FPa,fJb,pcb,fJb,ZTa,fJb,QUa,fJb,$Ja,fJb,Jcb,fJb,gcb,fJb,L$a,fJb,Cq,fJb,e2,fJb,Ccb,fJb,chb,fJb,_7,fJb,hfb,fJb,wRa,fJb,Kdb,fJb,X_,fJb,TNa,fJb,c8,fJb,WK,fJb,M8,fJb,nca,fJb,E6a,fJb,Q3a,fJb,ORa,fJb,h_,fJb,pdb,fJb,rbb,fJb,_Wa,fJb,Fn,fJb,_aa,fJb,W4a,fJb,RGa,fJb,cMa,fJb,qdb,fJb,_db,fJb,tba,fJb,$Ra,fJb,Ifb,fJb,pXa,fJb,XGa,fJb,fHa,fJb,nSa,fJb,__a,fJb,Vaa,fJb,xSa,fJb,aUa,fJb,V_,fJb,FHa,fJb,uHa,fJb,B8,fJb,j1,fJb,BD,fJb,qSa,fJb,CMa,fJb,k$a,fJb,t_a,fJb,dY,fJb,sp,fJb,Hdb,fJb,up,fJb,nRa,fJb,kZa,fJb,jMa,fJb,f1,fJb,Ieb,fJb,o2,fJb,k0,fJb,e_,fJb,C1a,fJb,A$a,fJb,F0,fJb,zFa,fJb,Jdb,fJb,EUa,fJb,bJa,fJb,I_,fJb,CTa,fJb,pOa,fJb,H1a,fJb,i$a,fJb,So,fJb,U1a,fJb,JY,fJb,w8,fJb,PQa,fJb,V$,fJb,ZX,fJb,A_,fJb,OTa,fJb,O1a,fJb,oMa,fJb,Ddb,fJb,cVa,fJb,Tgb,fJb,hMa,fJb,nLa,fJb,yKa,fJb,h1,fJb,Sdb,fJb,fKa,fJb,r$a,fJb,pp,fJb,G8,fJb,neb,fJb,MRa,fJb,jLa,fJb,AHa,fJb,CZa,fJb,zeb,fJb,NUa,fJb,HTa,fJb,M1a,fJb,l7,fJb,RNa,fJb,BV,fJb,GSa,fJb,Udb,fJb,KUa,fJb,UZa,fJb,a$a,fJb,RYa,fJb,hRa,fJb,R0,fJb,W3a,fJb,p8,fJb,G7,fJb,VLa,fJb,w_a,fJb,tLa,fJb,lm,fJb,Hca,fJb,deb,fJb,wcb,fJb,fSa,fJb,x1a,fJb,Q9,fJb,ngb,fJb,mQa,fJb,Cba,fJb,vL,fJb,nOa,fJb,qRa,fJb,uJa,fJb,hbb,fJb,kRa,fJb,p1a,fJb,kTa,fJb,iaa,fJb,$Sa,fJb,YJa,fJb,Zgb,fJb,XUa,fJb,seb,fJb,n$a,fJb,DSa,fJb,jhb,fJb,n_a,fJb,En,fJb,QLa,fJb,d$a,fJb,JAa,fJb,e1,fJb,Po,fJb,i8,fJb,h7,fJb,qp,fJb,s$,fJb,R1a,fJb,b1,fJb,y8,fJb,S_a,fJb,Q8,fJb,GGa,fJb,eZ,fJb,r_a,fJb,ATa,fJb,TTa,fJb,Xba,fJb,qeb,fJb,TY,fJb,a0,fJb,Meb,fJb,XXa,fJb,oZ,fJb,uXa,fJb,$Z,fJb,tp,fJb,kHa,fJb,VZ,fJb,s2,fJb,LYa,fJb,LEb,fJb,J1a,fJb,Xr,fJb,Ao,fJb,mC,fJb,Ffb,fJb,A_a,fJb,D9,fJb,Y$,fJb,sKa,fJb,BLa,fJb,d$,fJb,uL,fJb,VK,fJb,s4a,fJb,TWa,fJb,s8,fJb,n2a,fJb,Z1,fJb,BZa,fJb,Aba,fJb,e0,fJb,g_a,fJb,p_a,fJb,mZa,fJb,geb,fJb,hdb,fJb,JRa,fJb,XK,fJb,QTa,fJb,p$,fJb,cZa,fJb,MSa,fJb,PJa,fJb,LNa,fJb,Qaa,fJb,gSa,fJb,vH,fJb,tgb,fJb,xUa,fJb,p_,fJb,J$a,fJb,xH,fJb,Gn,fJb,X4a,fJb,$3a,fJb,oba,fJb,HNa,fJb,bca,fJb,iQa,fJb,AUa,fJb,wdb,fJb,aY,fJb,dSa,fJb,d1,fJb,v2,fJb,Mp,fJb,lSa,fJb,b$,fJb,u5a,fJb,YZ,fJb,J8,fJb,LS,fJb,dYa,fJb,wGa,fJb,Ceb,fJb,sMa,fJb,g8,fJb,g1,fJb,ZRa,fJb,y$a,fJb,bTa,fJb,v0a,fJb,ahb,fJb,uH,fJb,Hba,fJb,QQ,fJb,yIa,fJb,g2,fJb,u1a,fJb,sdb,fJb,_Ia,fJb,Fdb,fJb,P7,fJb,Ay,fJb,eRa,fJb,L7,fJb,b4a,fJb,HZa,fJb,E1a,fJb,gca,fJb,$Y,fJb,A1a,fJb,x0,fJb,or,fJb,VNa,fJb,PGa,fJb,ghb,fJb,Xdb,fJb,NX,fJb,j1a,fJb,jZa,fJb,k1,fJb,W7,fJb,YQa,fJb,BSa,fJb,PY,fJb,rp,fJb,Rba,fJb,pVa,fJb,_La,fJb,jdb,fJb,Tba,fJb,ldb,fJb,tRa,fJb,G$a,fJb,q2,fJb,LY,fJb,bba,fJb,VTa,fJb,YY,fJb,NY,fJb,Gm,fJb,$Ka,fJb,L$,fJb,Uz,fJb,rPa,fJb,Obb,fJb,rTa,fJb,fZa,fJb,p1,fJb,xXa,fJb,Y3a,fJb,OZa,fJb,T$,fJb,VSa,fJb,fda,fJb,x4a,fJb,w9,fJb,i2,fJb,L9,fJb,Hn,fJb,Iaa,fJb,nKa,fJb,t0a,fJb,vKa,fJb,Mdb,fJb,KK,fJb,JNa,fJb,u0,fJb,__,fJb,aYa,fJb,i4a,fJb,LTa,fJb,GUa,fJb,lbb,fJb,tcb,fJb,jca,fJb,qLa,fJb,VWa,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb,fJb];var $e=[gJb,gJb,jpb,gJb];var af=[hJb,hJb,n7,hJb];var bf=[iJb,iJb,tv,iJb,uv,iJb,vv,iJb,sv,iJb,iJb,iJb,iJb,iJb,iJb,iJb];var cf=[jJb,jJb,b2,jJb,MIa,jJb,Wna,jJb,ot,jJb,pab,jJb,XIa,jJb,WFa,jJb,hub,jJb,Vna,jJb,fGa,jJb,Qfa,jJb,cbb,jJb,GIa,jJb,r0,jJb,cka,jJb,sw,jJb,Yka,jJb,vga,jJb,wla,jJb,fka,jJb,Rfa,jJb,oub,jJb,KFa,jJb,vOa,jJb,Wka,jJb,Fma,jJb,N3,jJb,z3a,jJb,Koa,jJb,D3,jJb,rw,jJb,Ija,jJb,hba,jJb,vSa,jJb,Cab,jJb,Tka,jJb,Cma,jJb,M3,jJb,Dfa,jJb,R1,jJb,hGa,jJb,qab,jJb,mla,jJb,Zab,jJb,Yfb,jJb,Hma,jJb,qw,jJb,G3,jJb,Iqb,jJb,fzb,jJb,e7,jJb,zab,jJb,Fab,jJb,aGa,jJb,ebb,jJb,Gia,jJb,nub,jJb,sOa,jJb,e3a,jJb,o4,jJb,gzb,jJb,qt,jJb,lib,jJb,Ipb,jJb,s3a,jJb,sab,jJb,S1,jJb,Efa,jJb,TIa,jJb,IIa,jJb,FIa,jJb,abb,jJb,T3,jJb,tOa,jJb,KIa,jJb,mba,jJb,vab,jJb,f3a,jJb,pGa,jJb,K3,jJb,gGa,jJb,Tna,jJb,Uga,jJb,OFa,jJb,D3a,jJb,Ooa,jJb,JFa,jJb,GFa,jJb,dzb,jJb,Hab,jJb,t3a,jJb,S9a,jJb,Pna,jJb,ola,jJb,dGa,jJb,iGa,jJb,Xfb,jJb,Bma,jJb,_Fa,jJb,JIa,jJb,Wea,jJb,OIa,jJb,wDb,jJb,Gja,jJb,Lqb,jJb,a3a,jJb,rla,jJb,oGa,jJb,Lma,jJb,jub,jJb,tfa,jJb,Cfa,jJb,J3,jJb,n3a,jJb,Hqb,jJb,Fqb,jJb,V9a,jJb,Ulb,jJb,Una,jJb,Wab,jJb,a2,jJb,xna,jJb,Fpb,jJb,k3a,jJb,YIa,jJb,Lab,jJb,pub,jJb,kab,jJb,hma,jJb,Ima,jJb,IKa,jJb,nla,jJb,Xab,jJb,Dma,jJb,WIa,jJb,$fa,jJb,Xka,jJb,XEa,jJb,pFa,jJb,F3,jJb,Zja,jJb,Sab,jJb,cab,jJb,Qna,jJb,qub,jJb,rub,jJb,O9a,jJb,P1,jJb,l3a,jJb,Kia,jJb,VFa,jJb,Jia,jJb,mab,jJb,Kga,jJb,gCb,jJb,Ana,jJb,m3a,jJb,QFa,jJb,Oab,jJb,Akb,jJb,ykb,jJb,Z9a,jJb,mub,jJb,bab,jJb,hFa,jJb,fFa,jJb,efb,jJb,wga,jJb,_ab,jJb,YFa,jJb,Poa,jJb,O1,jJb,EFa,jJb,Gab,jJb,uga,jJb,Q3,jJb,yna,jJb,Kma,jJb,Kab,jJb,Gh,jJb,bka,jJb,XFa,jJb,Ema,jJb,j3a,jJb,Nia,jJb,kGa,jJb,Bab,jJb,Loa,jJb,rab,jJb,bbb,jJb,u3a,jJb,o3a,jJb,gma,jJb,nt,jJb,nab,jJb,oga,jJb,Bkb,jJb,zkb,jJb,iib,jJb,Tab,jJb,gkb,jJb,Yea,jJb,YEa,jJb,tla,jJb,eab,jJb,DFa,jJb,NIa,jJb,RIa,jJb,oib,jJb,$2a,jJb,nGa,jJb,sla,jJb,q0,jJb,h3a,jJb,lla,jJb,R3,jJb,ZFa,jJb,NFa,jJb,iub,jJb,Bfa,jJb,QIa,jJb,mGa,jJb,L3,jJb,pw,jJb,Nab,jJb,jib,jJb,Q1,jJb,Xea,jJb,pla,jJb,P3,jJb,Dab,jJb,Cia,jJb,w3a,jJb,g3a,jJb,qGa,jJb,Sfa,jJb,_ja,jJb,xga,jJb,uOa,jJb,Yna,jJb,ZEa,jJb,rFa,jJb,wf,jJb,dfb,jJb,q3a,jJb,MFa,jJb,_fb,jJb,gab,jJb,hzb,jJb,Rob,jJb,Mia,jJb,ffa,jJb,dka,jJb,pt,jJb,EIa,jJb,Lob,jJb,HIa,jJb,kib,jJb,O3,jJb,$Fa,jJb,Fia,jJb,Hpb,jJb,Rna,jJb,Eja,jJb,Yja,jJb,Iia,jJb,CFa,jJb,Nob,jJb,Moa,jJb,Mab,jJb,Gma,jJb,Pab,jJb,_fa,jJb,bGa,jJb,Jp,jJb,yga,jJb,Jma,jJb,T1,jJb,DIa,jJb,iab,jJb,Jab,jJb,IFa,jJb,qla,jJb,Yfa,jJb,SFa,jJb,jGa,jJb,jma,jJb,vla,jJb,ezb,jJb,Vka,jJb,aab,jJb,iFa,jJb,gFa,jJb,p3a,jJb,PFa,jJb,kma,jJb,mt,jJb,C3a,jJb,Rab,jJb,kkb,jJb,Eab,jJb,vna,jJb,eGa,jJb,Sga,jJb,Lia,jJb,g4,jJb,qFa,jJb,dfa,jJb,tab,jJb,rOa,jJb,Qob,jJb,B3a,jJb,Dia,jJb,Opb,jJb,VIa,jJb,Sob,jJb,jab,jJb,Vga,jJb,$ab,jJb,mib,jJb,HFa,jJb,TSa,jJb,Y9a,jJb,Sna,jJb,Eia,jJb,Ama,jJb,uab,jJb,Aab,jJb,kub,jJb,U3,jJb,FFa,jJb,c2,jJb,H3,jJb,xOa,jJb,E3a,jJb,sfa,jJb,d3a,jJb,i3a,jJb,hka,jJb,I3,jJb,ula,jJb,nga,jJb,pib,jJb,lub,jJb,gub,jJb,b3a,jJb,aka,jJb,Jja,jJb,UFa,jJb,oab,jJb,Tga,jJb,S3,jJb,R9a,jJb,r3a,jJb,wOa,jJb,UIa,jJb,LIa,jJb,W9a,jJb,_na,jJb,RFa,jJb,eka,jJb,gfa,jJb,wab,jJb,Iab,jJb,ufa,jJb,ow,jJb,x3a,jJb,$9a,jJb,zna,jJb,Fja,jJb,Uka,jJb,yab,jJb,ug,jJb,$ja,jJb,y3a,jJb,p4,jJb,lab,jJb,Lga,jJb,fbb,jJb,mCb,jJb,Mga,jJb,cfa,jJb,_9a,jJb,Oob,jJb,xab,jJb,Q9a,jJb,hTa,jJb,TFa,jJb,mga,jJb,LFa,jJb,Qab,jJb,Mob,jJb,U9a,jJb,Jqb,jJb,NQa,jJb,PIa,jJb,SIa,jJb,A3a,jJb,X9a,jJb,Zna,jJb,E3,jJb,Pob,jJb,Zfa,jJb,P9a,jJb,hib,jJb,qmb,jJb,Hia,jJb,Kqb,jJb,aga,jJb,nib,jJb,Uab,jJb,lGa,jJb,Afa,jJb,T9a,jJb,gka,jJb,Gqb,jJb,cGa,jJb,hab,jJb,ima,jJb,Yab,jJb,efa,jJb,v3a,jJb,lma,jJb,dab,jJb,wna,jJb,dbb,jJb,Wga,jJb,Noa,jJb,Vab,jJb,fab,jJb,c3a,jJb,Mqb,jJb,Hja,jJb,Xna,jJb,sFa,jJb,_Ea,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb,jJb];return{_strlen:SGb,_free:zGb,_main:Eh,_realloc:AGb,_memmove:VGb,_memset:TGb,_malloc:yGb,_memcpy:UGb,_llvm_uadd_with_overflow_i64:XGb,_strcpy:WGb,runPostSets:uf,stackAlloc:df,stackSave:ef,stackRestore:ff,setThrew:gf,setTempRet0:kf,setTempRet1:lf,setTempRet2:mf,setTempRet3:nf,setTempRet4:of,setTempRet5:pf,setTempRet6:qf,setTempRet7:rf,setTempRet8:sf,setTempRet9:tf,dynCall_iiiiiiii:wHb,dynCall_viiiiiifi:xHb,dynCall_viiiii:yHb,dynCall_vi:zHb,dynCall_vii:AHb,dynCall_iiiiiii:BHb,dynCall_viiiif:CHb,dynCall_viiiffiii:DHb,dynCall_ii:EHb,dynCall_viiiiiiiiiii:FHb,dynCall_viifi:GHb,dynCall_viidi:HHb,dynCall_viiiiiiiiiif:IHb,dynCall_fiii:JHb,dynCall_iiiiiiiiiiii:KHb,dynCall_fiiiiiiiffi:LHb,dynCall_iiii:MHb,dynCall_iffiiiii:NHb,dynCall_viiiiiiii:OHb,dynCall_viiiiiiif:PHb,dynCall_fii:QHb,dynCall_iiiiiiiiii:RHb,dynCall_iiiiiiidiiidi:SHb,dynCall_viiiffi:THb,dynCall_dd:UHb,dynCall_viiiiiiiiiiiiii:VHb,dynCall_viiiiifi:WHb,dynCall_viiiiiii:XHb,dynCall_viiiiiiiii:YHb,dynCall_viiiiiif:ZHb,dynCall_viiiiiiiiii:_Hb,dynCall_iii:$Hb,dynCall_iiiiii:aIb,dynCall_diii:bIb,dynCall_didd:cIb,dynCall_viiiiii:dIb,dynCall_did:eIb,dynCall_viiiiiiiiiiii:fIb,dynCall_viiif:gIb,dynCall_viiiifii:hIb,dynCall_viii:iIb,dynCall_v:jIb,dynCall_iiiiiiiii:kIb,dynCall_iiiii:lIb,dynCall_viif:mIb,dynCall_viiffi:nIb,dynCall_viiiiiiiddddd:oIb,dynCall_viiii:pIb}})


// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_viiiiiifi": invoke_viiiiiifi, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_viiiif": invoke_viiiif, "invoke_viiiffiii": invoke_viiiffiii, "invoke_ii": invoke_ii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_viifi": invoke_viifi, "invoke_viidi": invoke_viidi, "invoke_viiiiiiiiiif": invoke_viiiiiiiiiif, "invoke_fiii": invoke_fiii, "invoke_iiiiiiiiiiii": invoke_iiiiiiiiiiii, "invoke_fiiiiiiiffi": invoke_fiiiiiiiffi, "invoke_iiii": invoke_iiii, "invoke_iffiiiii": invoke_iffiiiii, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_viiiiiiif": invoke_viiiiiiif, "invoke_fii": invoke_fii, "invoke_iiiiiiiiii": invoke_iiiiiiiiii, "invoke_iiiiiiidiiidi": invoke_iiiiiiidiiidi, "invoke_viiiffi": invoke_viiiffi, "invoke_dd": invoke_dd, "invoke_viiiiiiiiiiiiii": invoke_viiiiiiiiiiiiii, "invoke_viiiiifi": invoke_viiiiifi, "invoke_viiiiiii": invoke_viiiiiii, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_viiiiiif": invoke_viiiiiif, "invoke_viiiiiiiiii": invoke_viiiiiiiiii, "invoke_iii": invoke_iii, "invoke_iiiiii": invoke_iiiiii, "invoke_diii": invoke_diii, "invoke_didd": invoke_didd, "invoke_viiiiii": invoke_viiiiii, "invoke_did": invoke_did, "invoke_viiiiiiiiiiii": invoke_viiiiiiiiiiii, "invoke_viiif": invoke_viiif, "invoke_viiiifii": invoke_viiiifii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiiiiiii": invoke_iiiiiiiii, "invoke_iiiii": invoke_iiiii, "invoke_viif": invoke_viif, "invoke_viiffi": invoke_viiffi, "invoke_viiiiiiiddddd": invoke_viiiiiiiddddd, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_sysconf": _sysconf, "__scanString": __scanString, "_fclose": _fclose, "_mkdir": _mkdir, "_strtoul": _strtoul, "_fflush": _fflush, "_sinf": _sinf, "_strtol": _strtol, "_fputc": _fputc, "_strtok": _strtok, "_fwrite": _fwrite, "_deflateBound": _deflateBound, "_send": _send, "_llvm_pow_f32": _llvm_pow_f32, "_fputs": _fputs, "_cbrt": _cbrt, "_isspace": _isspace, "_localtime": _localtime, "_mmap": _mmap, "_read": _read, "_ceil": _ceil, "_strstr": _strstr, "_fileno": _fileno, "_perror": _perror, "_fsync": _fsync, "_munmap": _munmap, "_signal": _signal, "_tanh": _tanh, "_fmod": _fmod, "_compress2": _compress2, "_round": _round, "_memchr": _memchr, "_llvm_va_end": _llvm_va_end, "_cosf": _cosf, "_snprintf": _snprintf, "_fgetc": _fgetc, "_stat": _stat, "_cosh": _cosh, "__getFloat": __getFloat, "_mknod": _mknod, "_hypot": _hypot, "_deflateInit_": _deflateInit_, "_fgets": _fgets, "_close": _close, "_strchr": _strchr, "_tcgetattr": _tcgetattr, "_clock": _clock, "___setErrNo": ___setErrNo, "_uncompress": _uncompress, "_access": _access, "_ftell": _ftell, "_exit": _exit, "_inflateReset": _inflateReset, "_strrchr": _strrchr, "_atan2f": _atan2f, "_setrlimit": _setrlimit, "_fcntl": _fcntl, "_log2": _log2, "_strcspn": _strcspn, "__isLeapYear": __isLeapYear, "_copysign": _copysign, "_ferror": _ferror, "_llvm_uadd_with_overflow_i32": _llvm_uadd_with_overflow_i32, "_gmtime": _gmtime, "_localtime_r": _localtime_r, "_sinh": _sinh, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_recv": _recv, "__parseInt64": __parseInt64, "_trunc": _trunc, "_cos": _cos, "_putchar": _putchar, "_mkport": _mkport, "_bsearch": _bsearch, "_deflateInit2_": _deflateInit2_, "__exit": __exit, "_nanosleep": _nanosleep, "_strftime": _strftime, "_rename": _rename, "_tzset": _tzset, "_fabsf": _fabsf, "_floorf": _floorf, "_llvm_va_copy": _llvm_va_copy, "_rint": _rint, "_crc32": _crc32, "_printf": _printf, "_pread": _pread, "_fopen": _fopen, "_open": _open, "_sqrtf": _sqrtf, "_select": _select, "_getchar": _getchar, "_usleep": _usleep, "_frexp": _frexp, "__arraySum": __arraySum, "_log": _log, "_puts": _puts, "_mktime": _mktime, "_fdopen": _fdopen, "_exp2": _exp2, "_scanf": _scanf, "_qsort": _qsort, "_deflateEnd": _deflateEnd, "_rmdir": _rmdir, "_inflate": _inflate, "_log10": _log10, "_deflateReset": _deflateReset, "_isatty": _isatty, "__formatString": __formatString, "_getenv": _getenv, "_gettimeofday": _gettimeofday, "_atoi": _atoi, "_vfprintf": _vfprintf, "_llvm_pow_f64": _llvm_pow_f64, "_sbrk": _sbrk, "_fscanf": _fscanf, "___errno_location": ___errno_location, "_strerror": _strerror, "_getrusage": _getrusage, "_fstat": _fstat, "_llvm_lifetime_start": _llvm_lifetime_start, "_strspn": _strspn, "__parseInt": __parseInt, "_ungetc": _ungetc, "_exp": _exp, "_expf": _expf, "_gmtime_r": _gmtime_r, "_vsnprintf": _vsnprintf, "_sscanf": _sscanf, "___assert_fail": ___assert_fail, "_fread": _fread, "_strtok_r": _strtok_r, "_globfree": _globfree, "_abort": _abort, "_fprintf": _fprintf, "_strtoll": _strtoll, "_tan": _tan, "___buildEnvironment": ___buildEnvironment, "__reallyNegative": __reallyNegative, "__addDays": __addDays, "_inflateSync": _inflateSync, "_atanf": _atanf, "_fabs": _fabs, "_floor": _floor, "_fseek": _fseek, "_sqrt": _sqrt, "_write": _write, "_inflateInit_": _inflateInit_, "_sin": _sin, "_ceilf": _ceilf, "_tcsetattr": _tcsetattr, "_atan": _atan, "_asin": _asin, "_glob": _glob, "_compress": _compress, "_deflate": _deflate, "_unlink": _unlink, "_acos": _acos, "_pwrite": _pwrite, "_strerror_r": _strerror_r, "_atan2": _atan2, "_llrint": _llrint, "_llvm_bswap_i16": _llvm_bswap_i16, "_time": _time, "_llvm_bswap_i32": _llvm_bswap_i32, "_setvbuf": _setvbuf, "_inflateEnd": _inflateEnd, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stdout": _stdout, "_stderr": _stderr }, buffer);
var _strlen = Module["_strlen"] = asm["_strlen"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _llvm_uadd_with_overflow_i64 = Module["_llvm_uadd_with_overflow_i64"] = asm["_llvm_uadd_with_overflow_i64"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_viiiiiifi = Module["dynCall_viiiiiifi"] = asm["dynCall_viiiiiifi"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_viiiif = Module["dynCall_viiiif"] = asm["dynCall_viiiif"];
var dynCall_viiiffiii = Module["dynCall_viiiffiii"] = asm["dynCall_viiiffiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_viifi = Module["dynCall_viifi"] = asm["dynCall_viifi"];
var dynCall_viidi = Module["dynCall_viidi"] = asm["dynCall_viidi"];
var dynCall_viiiiiiiiiif = Module["dynCall_viiiiiiiiiif"] = asm["dynCall_viiiiiiiiiif"];
var dynCall_fiii = Module["dynCall_fiii"] = asm["dynCall_fiii"];
var dynCall_iiiiiiiiiiii = Module["dynCall_iiiiiiiiiiii"] = asm["dynCall_iiiiiiiiiiii"];
var dynCall_fiiiiiiiffi = Module["dynCall_fiiiiiiiffi"] = asm["dynCall_fiiiiiiiffi"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_iffiiiii = Module["dynCall_iffiiiii"] = asm["dynCall_iffiiiii"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_viiiiiiif = Module["dynCall_viiiiiiif"] = asm["dynCall_viiiiiiif"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_iiiiiiiiii = Module["dynCall_iiiiiiiiii"] = asm["dynCall_iiiiiiiiii"];
var dynCall_iiiiiiidiiidi = Module["dynCall_iiiiiiidiiidi"] = asm["dynCall_iiiiiiidiiidi"];
var dynCall_viiiffi = Module["dynCall_viiiffi"] = asm["dynCall_viiiffi"];
var dynCall_dd = Module["dynCall_dd"] = asm["dynCall_dd"];
var dynCall_viiiiiiiiiiiiii = Module["dynCall_viiiiiiiiiiiiii"] = asm["dynCall_viiiiiiiiiiiiii"];
var dynCall_viiiiifi = Module["dynCall_viiiiifi"] = asm["dynCall_viiiiifi"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_viiiiiif = Module["dynCall_viiiiiif"] = asm["dynCall_viiiiiif"];
var dynCall_viiiiiiiiii = Module["dynCall_viiiiiiiiii"] = asm["dynCall_viiiiiiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_diii = Module["dynCall_diii"] = asm["dynCall_diii"];
var dynCall_didd = Module["dynCall_didd"] = asm["dynCall_didd"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_did = Module["dynCall_did"] = asm["dynCall_did"];
var dynCall_viiiiiiiiiiii = Module["dynCall_viiiiiiiiiiii"] = asm["dynCall_viiiiiiiiiiii"];
var dynCall_viiif = Module["dynCall_viiif"] = asm["dynCall_viiif"];
var dynCall_viiiifii = Module["dynCall_viiiifii"] = asm["dynCall_viiiifii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiiiiiii = Module["dynCall_iiiiiiiii"] = asm["dynCall_iiiiiiiii"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viif = Module["dynCall_viif"] = asm["dynCall_viif"];
var dynCall_viiffi = Module["dynCall_viiffi"] = asm["dynCall_viiffi"];
var dynCall_viiiiiiiddddd = Module["dynCall_viiiiiiiddddd"] = asm["dynCall_viiiiiiiddddd"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];

Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };

// TODO: strip out parts of this we do not need

//======= begin closure i64 code =======

// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */

var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };


  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.

    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };


  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.


  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};


  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }

    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };


  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };


  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };


  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }

    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }

    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));

    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };


  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.


  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;


  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);


  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);


  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);


  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);


  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);


  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);


  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };


  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };


  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (this.isZero()) {
      return '0';
    }

    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }

    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));

    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);

      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };


  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };


  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };


  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };


  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };


  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };


  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };


  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };


  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }

    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }

    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };


  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };


  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };


  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }

    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }

    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }

    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));

      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);

      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }

      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }

      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };


  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };


  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };


  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };


  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };


  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };


  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };

  //======= begin jsbn =======

  var navigator = { appName: 'Modern Browser' }; // polyfill a little

  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/

  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */

  // Basic JavaScript BN library - subset useful for RSA encryption.

  // Bits per digit
  var dbits;

  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);

  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }

  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }

  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.

  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }

  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);

  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;

  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;

  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }

  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }

  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }

  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }

  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }

  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }

  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }

  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }

  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }

  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }

  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }

  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }

  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }

  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }

  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }

  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }

  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }

  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }

  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }

  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }

  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;

  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }

  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }

  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }

  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }

  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }

  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;

  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }

  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }

  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }

  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;

  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;

  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);

  // jsbn2 stuff

  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }

  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }

  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }

  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }

  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }

  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }

  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }

  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;

  //======= end jsbn =======

  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();

//======= end closure i64 code =======



// === Auto-generated postamble setup entry stuff ===

if (memoryInitializer) {
  if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
    var data = Module['readBinary'](memoryInitializer);
    HEAPU8.set(data, STATIC_BASE);
  } else {
    addRunDependency('memory initializer');
    Browser.asyncLoad(memoryInitializer, function(data) {
      HEAPU8.set(data, STATIC_BASE);
      removeRunDependency('memory initializer');
    }, function(data) {
      throw 'could not load memory initializer ' + memoryInitializer;
    });
  }
}

function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun'] && shouldRunNow) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
    Module.printErr('preload time: ' + (Date.now() - preloadStartTime) + ' ms');
  }

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);

  initialStackTop = STACKTOP;

  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}




function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    ensureInitRuntime();

    preMain();

    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;

function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;

  // exit the runtime
  exitRuntime();

  // TODO We should handle this differently based on environment.
  // In the browser, the best we can do is throw an exception
  // to halt execution, but in node we could process.exit and
  // I'd imagine SM shell would have something equivalent.
  // This would let us set a proper exit status (which
  // would be great for checking test exit statuses).
  // https://github.com/kripken/emscripten/issues/1371

  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;

function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }

  ABORT = true;
  EXITSTATUS = 1;

  throw 'abort() at ' + stackTrace();
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}


run();

// {{POST_RUN_ADDITIONS}}






// {{MODULE_ADDITIONS}}






  return Module['return'];
}

if (typeof(exports) !== 'undefined') {
  ffmpeg_run.call(this);
}

